(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3666422,      65406]*)
(*NotebookOutlinePosition[   3667120,      65430]*)
(*  CellTagsIndexPosition[   3667076,      65426]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Threshold-based classification of single model: synthetic data \
example\
\>", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize annular region in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nF, 
              nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One-class classification", "Subsection"],

Cell[BoxData[
    \(\(OneClassClassify1[model_, \ threshold_, \ 
          pts_:  150] := \[IndentingNewLine]Module[{reg, class, \ 
            classPlot}, \[IndentingNewLine]reg\  = 
            MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, model]; 
          class\  = \ Map[If[#\  > \ threshold, \ 0, \ 1] &, \ reg, \ {2}]; 
          classPlot\  = 
            ListDensityPlot[class, \ 
              ColorFunction -> \((If[# == 1, RGBColor[0, 0, #], \ 
                      RGBColor[1, 0, #]] &)\), \ Mesh -> False, \ 
              MeshRange -> {{0, 1}, {0, 1}}, nF, 
              nS]; \[IndentingNewLine]idealPlot\  = 
            Show[Graphics[{Blue, 
                  Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, 
                rr1, rr2, \ pr, Red, Blue, \ nS]\ , 
              AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF, \ nS]; 
          Show[GraphicsArray[{idealPlot, \ classPlot}], yS, 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation and visualization", "Section"],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooo
ooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglC
ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooo
oglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4ooo
ogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
oooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo
4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooo
oomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooon6ooooO`P0OoooQ?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooN_oooglP07ooogSooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooogGooomo:@1ooomdooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom`ooooOc<0OoooKoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
K_oooglg07ooofgooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooof[ooomo@01o
oomXooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomWooooOdD0OoooI_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooIOooogm907ooofCooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooof?ooomoC@1ooomRooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomQooooOe40OoooH?ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooGoooogmF07oooegooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooecooomoF`1ooomKooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomJoooo
Oel0OoooFOooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooF?ooogmS07oooeOo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooeOooomoI@1ooomFooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooomFooooOfL0OoooEOooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooE?ooogm[07oooe?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooe;ooomoK`1ooomAooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooomAooooOg40OoooD?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
D?ooogmc07ooodoooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodkooomoM`1o
oom=ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom=ooooOgP0OoooCOooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooCOooogmi07ooodcooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooood_ooomoO@1ooom:ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooom:ooooOgl0OoooBOooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooBOooogn107ooodSooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooodSooomoP`1ooom7ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom7oooo
OhD0OoooA_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooA_ooogn707ooodGo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodGooomoR@1ooom4ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooom4ooooOh/0Oooo@oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo@oooogn=07oood;ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooood;ooomoS`1ooom1ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom1ooooOi00Oooo@Oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
@OooognA07oood3ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocoooomoU@1o
oolnooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolnooooOiH0Oooo?_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo?_ooognG07ooocgooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocgooomoV@1ooollooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooollooooOi/0Oooo>oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo>oooognL07oooc_ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc_ooomoW@1oooljooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooljoooo
Oih0Oooo>_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo>_ooognO07ooocWo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocWooomoX@1ooolhooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolhooooOj<0Oooo=oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo=oooognT07ooocOooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooocOooomoY@1ooolfooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolfooooOjH0Oooo=_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=_ooognW07ooocGooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocGooomoZ01o
ooleooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooleooooOjT0Oooo=?ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=?ooognZ07ooocCooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocCooomoZ`1ooolcooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolcooooOj`0Oooo<oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo<oooogn/07oooc?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc?ooomo[@1ooolbooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolboooo
Ojh0Oooo<_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo<_ooogn_07oooc7o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc7ooomo/01ooolaooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolaooooOk40Oooo<?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo<?ooognb07oooc3ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooc3ooomo/`1oool_ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooool_ooooOeD0Oooo2`3oogmD07oooboooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooboooomoD@1ooolC0?ooOe40Oooo;_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo;_ooogm?07oooaX0oomoC@1oool^ooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00oooool^ooooOdd0Oooo7@3oogm<07ooobkooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooobkooomoC01ooolQ0?ooOdT0Oooo;_ooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo;_ooogm:07ooob@0oomoB01oool^ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool^ooooOdL0Oooo:03oogm807ooobgooomo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooobgooomoA`1ooolZ0?ooOdL0Oooo;Oooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo;Oooogm607ooob`0oomoA`1oool/ooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooool/ooooOdL0Oooo;@3oogm607ooobcooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooobcooomoAP1oool_0?ooOdD0Oooo;?ooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo;?ooogm507oooc40oomoA01oool/ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool/ooooOd@0Oooo<P3oogm407ooobcooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooobcooomo@`1ooold0?ooOd@0Oooo:oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm407ooocD0oomo@`1oool[oooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd<0Oooo=`3oogm207ooob_o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomo@P1oooli0?ooOd40Oooo
:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm207ooocT0oomo@P1o
oolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd80Oooo>`3oogm1
07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@@1oooll0?oo
Od40Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm107oooc`0
oomo@@1ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd00Oooo
?P3oogm007ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@01o
ooln0?ooOd00Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm0
07oooch0oomo@01ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZoooo
Od00Oooo?`3ooglo07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[o
oomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
:_oooglo07oood00oomo?`1ooolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oolZooooOcl0Oooo@03ooglo07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooob[ooomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooo:_oooglo07oood40oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolYooooOcl0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooobWooomo?`1ooom20?ooOcl0Oooo:Oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo:Ooooglo07oood80oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooolYooooOcl0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooobWooomo?`1ooom20?ooOcl0Oooo:Oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo:Ooooglo07oood80oomo?`1ooolYooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolZooooOch0Oooo@P3ooglo07ooobWooomo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooob[ooomo?`1ooom10?ooOch0Oooo:_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo:_oooglo07oood00oomo?`1ooolZooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooolZooooOcl0Oooo@03ooglo07ooob[ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooob[ooomo?`1ooom00?ooOcl0Oooo:_ooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo:_oooglo07oood00oomo?`1ooolZooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd00Oooo?`3ooglo07ooob[ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@01oooln0?ooOd00Oooo:_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm007oooch0oomo@01ooolZoooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolZooooOd40Oooo?@3oogm007ooob[o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob[ooomo@@1oooll0?ooOd40Oooo
:_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:_ooogm107oooc`0oomo@@1o
oolZooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd40Oooo>P3oogm2
07ooob[ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomo@P1oooli0?oo
Od40Oooo:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo:oooogm207ooocP0
oomo@P1oool[ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool[ooooOd<0Oooo
=P3oogm307ooob_ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooob_ooomoA01o
oole0?ooOd<0Oooo:oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo;?ooogm4
07oooc<0oomoA01oool[ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool/oooo
OdD0Oooo<@3oogm407ooobcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooobco
oomoA@1oool`0?ooOdD0Oooo;?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
;?ooogm607ooobh0oomoAP1oool/ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool/ooooOdL0Oooo;03oogm707ooobcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooobgooomoB01ooolY0?ooOdP0Oooo;?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooo;Oooogm907ooobL0oomoB01oool]ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooool^ooooOd/0Oooo8`3oogm907ooobgooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooobkooomoC@1ooolO0?ooOdX0Oooo;_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo;_ooogm>07oooa/0oomoC@1oool^ooooO`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00oooool^ooooOe40Oooo5`3oogm>07ooobkooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooboooomoD@1ooolC0?ooOe40Oooo;_ooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo;oooogmF07ooo`T0oomoE@1oool_ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool_ooooOk@0Oooo;oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo<?ooognc07oooboooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooc3ooomo/P1oool`ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolaoooo
Ok40Oooo<?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo<Oooogn`07oooc7o
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc;ooomo[`1ooolaooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolbooooOjh0Oooo<_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo<oooogn]07oooc;ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooc?ooomo[01ooolcooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooldooooOj/0Oooo<oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=?ooognZ07ooocCooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocCooomoZP1o
ooldooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooleooooOjT0Oooo=?ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=OooognX07ooocGooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocKooomoY`1oooleooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolfooooOjH0Oooo=_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo=oooognU07ooocKooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooocSooomoX`1ooolgooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolioooo
Oj40Oooo>?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo>OooognP07ooocWo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooc[ooomoW`1oooliooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooooljooooOih0Oooo>_ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo>oooognM07oooc[ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooccooomoV`1ooolkooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolmooooOiT0Oooo??ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
?OooognH07ooocgooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooockooomoU`1o
oolmooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom0ooooOi<0Oooo?oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo@?ooognB07oood3ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooood7ooomoT@1ooom0ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooom2ooooOhl0Oooo@Oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo@oooogn=07oood;ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooodCooomoR`1ooom3ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom5oooo
OhT0OoooA?ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooA_ooogn707ooodGo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodOooomoQ@1ooom6ooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooom8ooooOh<0OoooAoooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooBOooogn107ooodSooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooood[ooomoO`1ooom9ooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooom<ooooOg/0OoooBoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
C?ooogmj07ooodcooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooodgooomoN@1o
oom<ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom?ooooOgD0OoooC_ooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooD?ooogmc07ooodoooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooe7ooomoL@1ooom@ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomCooooOfd0OoooD_ooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooEOooogmY07oooeCooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooeKooomoI`1ooomEooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooomGoooo
OfD0OoooE_ooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooFOooogmQ07oooeSo
oomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooe_ooomoG@1ooomJooooO`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooomMooooOeT0OoooG?ooogl6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?oooooH?ooogmD07oooekooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooof;ooomoC`1ooomQooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooomTooooOd/0OoooHoooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
I_ooogm707ooofGooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooofSooomo@`1o
oomWooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooom[ooooOch0OoooJOooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?oooooKoooogle07ooofkooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooog7ooomo<@1ooom`ooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooomfooooObL0OoooMOooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?oooooNooooglN07ooogWooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooohOooomo1P1ooon5ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooooooo
Oa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCoooo
O`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooo
ooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglC
ooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooo
oglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4ooo
ogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
oooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooooooooomo
4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooooooooglCooooO`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooooooooooOa?ooomo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03oooooooooomo4oooogl6ooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\), "\n", 
    \(\(data2\  = AntiAnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.71587 .2829 Mdot
.74257 .73497 Mdot
.25826 .70483 Mdot
.75329 .69045 Mdot
.6804 .40452 Mdot
.78819 .35195 Mdot
.66039 .3211 Mdot
.45103 .32738 Mdot
.61377 .766 Mdot
.66872 .57091 Mdot
.70378 .7307 Mdot
.64897 .70178 Mdot
.62639 .72221 Mdot
.52865 .72449 Mdot
.6504 .57541 Mdot
.32433 .70666 Mdot
.71643 .53615 Mdot
.34209 .39564 Mdot
.25953 .61329 Mdot
.53132 .37354 Mdot
.43395 .19924 Mdot
.67067 .48597 Mdot
.62812 .34059 Mdot
.20115 .6069 Mdot
.25632 .45924 Mdot
.39389 .18836 Mdot
.77513 .59571 Mdot
.40388 .62032 Mdot
.21866 .38154 Mdot
.79917 .44628 Mdot
.53047 .16486 Mdot
.70294 .52203 Mdot
.65865 .75826 Mdot
.63764 .60407 Mdot
.42162 .72677 Mdot
.64695 .79193 Mdot
.69091 .50252 Mdot
.42547 .71691 Mdot
.3257 .25548 Mdot
.56567 .35174 Mdot
.43173 .19217 Mdot
.75016 .43662 Mdot
.63723 .43124 Mdot
.77472 .42288 Mdot
.28464 .47409 Mdot
.43686 .81471 Mdot
.2431 .69099 Mdot
.26803 .71609 Mdot
.67943 .68079 Mdot
.61354 .21635 Mdot
.19907 .40642 Mdot
.28501 .5065 Mdot
.66048 .21683 Mdot
.82599 .50945 Mdot
.30563 .4952 Mdot
.21939 .64735 Mdot
.43483 .66492 Mdot
.54196 .3081 Mdot
.59853 .82727 Mdot
.64341 .58524 Mdot
.82606 .52527 Mdot
.46285 .24159 Mdot
.76 .54685 Mdot
.61477 .38272 Mdot
.48203 .72507 Mdot
.72664 .74094 Mdot
.32717 .32009 Mdot
.7246 .56905 Mdot
.51807 .7155 Mdot
.68391 .68543 Mdot
.50175 .78061 Mdot
.226 .45957 Mdot
.29308 .3146 Mdot
.69506 .40208 Mdot
.2413 .42546 Mdot
.676 .28895 Mdot
.66583 .78428 Mdot
.83522 .44666 Mdot
.76976 .60213 Mdot
.23155 .35692 Mdot
.19911 .63902 Mdot
.72376 .35247 Mdot
.80094 .37042 Mdot
.29198 .42928 Mdot
.21254 .61687 Mdot
.81417 .42561 Mdot
.28959 .62979 Mdot
.6698 .47748 Mdot
.66165 .68709 Mdot
.28828 .67074 Mdot
.61941 .20494 Mdot
.6616 .67766 Mdot
.3599 .4116 Mdot
.30422 .63786 Mdot
.55545 .82278 Mdot
.72878 .50216 Mdot
.22399 .65821 Mdot
.52024 .30968 Mdot
.44772 .61014 Mdot
.26945 .67769 Mdot
.62926 .77562 Mdot
.75269 .42296 Mdot
.25964 .52723 Mdot
.60533 .62823 Mdot
.5907 .62016 Mdot
.66167 .2023 Mdot
.78217 .63973 Mdot
.59454 .38723 Mdot
.30368 .62023 Mdot
.3062 .65236 Mdot
.51756 .68775 Mdot
.39665 .38626 Mdot
.41478 .31738 Mdot
.63446 .60117 Mdot
.7106 .61292 Mdot
.20579 .56749 Mdot
.26158 .34128 Mdot
.45438 .33712 Mdot
.68593 .6975 Mdot
.30757 .56003 Mdot
.53659 .20201 Mdot
.63315 .71542 Mdot
.2968 .65888 Mdot
.37523 .5549 Mdot
.50548 .21457 Mdot
.50776 .78512 Mdot
.46172 .23356 Mdot
.45884 .37449 Mdot
.357 .73542 Mdot
.51421 .19478 Mdot
.69689 .47734 Mdot
.2206 .60506 Mdot
.68083 .33389 Mdot
.33221 .27618 Mdot
.33761 .26504 Mdot
.72191 .73369 Mdot
.51348 .3072 Mdot
.71746 .69632 Mdot
.79996 .61392 Mdot
.34081 .78577 Mdot
.26831 .56376 Mdot
.77384 .45558 Mdot
.29498 .62383 Mdot
.20879 .56503 Mdot
.62463 .47349 Mdot
.33447 .71184 Mdot
.62536 .36107 Mdot
.3139 .49287 Mdot
.60372 .24141 Mdot
.35707 .72209 Mdot
.41978 .29878 Mdot
.24562 .31519 Mdot
.31492 .70275 Mdot
.27306 .69477 Mdot
.263 .29459 Mdot
.49157 .37814 Mdot
.77166 .42588 Mdot
.61463 .77615 Mdot
.41442 .21093 Mdot
.68585 .63374 Mdot
.32566 .73887 Mdot
.43153 .31513 Mdot
.31533 .4635 Mdot
.6669 .24222 Mdot
.81921 .47252 Mdot
.36145 .53951 Mdot
.69507 .29263 Mdot
.79017 .48544 Mdot
.16608 .50203 Mdot
.62137 .58971 Mdot
.57769 .34376 Mdot
.61064 .55358 Mdot
.41922 .7234 Mdot
.70603 .65518 Mdot
.59546 .63804 Mdot
.72995 .33953 Mdot
.6379 .56975 Mdot
.52537 .64315 Mdot
.78597 .43399 Mdot
.57834 .31457 Mdot
.8001 .568 Mdot
.35592 .5882 Mdot
.48344 .35924 Mdot
.34125 .22677 Mdot
.59662 .17657 Mdot
.22811 .37656 Mdot
.60365 .22303 Mdot
.49291 .21885 Mdot
.67004 .29107 Mdot
.34648 .47956 Mdot
.53428 .6812 Mdot
.70618 .27718 Mdot
.34989 .61129 Mdot
.26642 .25747 Mdot
.64654 .268 Mdot
.5454 .66207 Mdot
.37284 .75389 Mdot
.745 .36475 Mdot
.66297 .68853 Mdot
.36758 .52669 Mdot
.79993 .56821 Mdot
.69037 .4676 Mdot
.37115 .6474 Mdot
.65206 .58668 Mdot
.32826 .60244 Mdot
.25407 .59965 Mdot
.21042 .48379 Mdot
.43424 .75426 Mdot
.47744 .34291 Mdot
.63021 .71844 Mdot
.2826 .635 Mdot
.71462 .36401 Mdot
.32718 .78646 Mdot
.61741 .60749 Mdot
.27363 .45953 Mdot
.34004 .69637 Mdot
.70573 .51033 Mdot
.23238 .63502 Mdot
.3085 .22329 Mdot
.25423 .50327 Mdot
.18277 .43143 Mdot
.38275 .29612 Mdot
.69872 .48811 Mdot
.58196 .18544 Mdot
.42529 .67853 Mdot
.30803 .52615 Mdot
.5627 .32506 Mdot
.54553 .22229 Mdot
.3898 .18677 Mdot
.36798 .56757 Mdot
.5124 .23632 Mdot
.39859 .35889 Mdot
.81643 .5235 Mdot
.62241 .52472 Mdot
.4106 .3553 Mdot
.23375 .4593 Mdot
.76656 .66527 Mdot
.683 .4603 Mdot
.53361 .63536 Mdot
.47188 .73586 Mdot
.52656 .7447 Mdot
.80261 .6564 Mdot
.28483 .54267 Mdot
.18589 .60553 Mdot
.40662 .23767 Mdot
.74408 .66387 Mdot
.32974 .62151 Mdot
.48988 .31807 Mdot
.44391 .36325 Mdot
.17486 .42535 Mdot
.76049 .46168 Mdot
.21539 .61208 Mdot
.63252 .76214 Mdot
.47785 .74297 Mdot
.62287 .76889 Mdot
.5769 .23596 Mdot
.45 .30425 Mdot
.59938 .23736 Mdot
.31234 .71725 Mdot
.78526 .56082 Mdot
.39498 .41244 Mdot
.28462 .5936 Mdot
.62437 .71219 Mdot
.79461 .434 Mdot
.66425 .72602 Mdot
.63914 .55989 Mdot
.72213 .32206 Mdot
.40101 .30431 Mdot
.63855 .65402 Mdot
.29815 .43112 Mdot
.5108 .21728 Mdot
.22377 .41469 Mdot
.80308 .54592 Mdot
.62143 .66276 Mdot
.36934 .55203 Mdot
.74244 .49756 Mdot
.81146 .40458 Mdot
.74705 .28111 Mdot
.32977 .5937 Mdot
.60577 .69312 Mdot
.66212 .53328 Mdot
.25318 .7328 Mdot
.69369 .71858 Mdot
.47489 .2269 Mdot
.48122 .32342 Mdot
.51289 .76197 Mdot
.67167 .44823 Mdot
.33998 .32514 Mdot
.22277 .59824 Mdot
.521 .63499 Mdot
.52705 .31981 Mdot
.66197 .64763 Mdot
.79898 .3601 Mdot
.38026 .63076 Mdot
.55173 .3394 Mdot
.63419 .51852 Mdot
.27005 .72666 Mdot
.80192 .42135 Mdot
.45121 .23589 Mdot
.52805 .83434 Mdot
.48294 .30685 Mdot
.5722 .63109 Mdot
.83902 .54436 Mdot
.6402 .66094 Mdot
.38753 .33905 Mdot
.31124 .23351 Mdot
.27435 .45553 Mdot
.35246 .6553 Mdot
.66627 .3765 Mdot
.66755 .6641 Mdot
.34019 .22651 Mdot
.34431 .5253 Mdot
.3226 .66773 Mdot
.26321 .37174 Mdot
.7782 .48555 Mdot
.7751 .66197 Mdot
.65426 .58387 Mdot
.67975 .62896 Mdot
.46681 .21543 Mdot
.77634 .59628 Mdot
.30108 .39084 Mdot
.66999 .38141 Mdot
.36601 .74843 Mdot
.71803 .24317 Mdot
.54843 .71841 Mdot
.27538 .60338 Mdot
.55398 .22176 Mdot
.34342 .78455 Mdot
.74286 .48103 Mdot
.50681 .31245 Mdot
.74675 .33476 Mdot
.76583 .28319 Mdot
.37426 .40791 Mdot
.75335 .48821 Mdot
.66342 .34301 Mdot
.7637 .70512 Mdot
.21685 .39121 Mdot
.48638 .67505 Mdot
.35582 .40791 Mdot
.43313 .28159 Mdot
.64383 .7605 Mdot
.23391 .37056 Mdot
.47488 .66868 Mdot
.53068 .3043 Mdot
.79105 .65028 Mdot
.35513 .69651 Mdot
.39387 .40158 Mdot
.74396 .44902 Mdot
.51613 .27052 Mdot
.42594 .62348 Mdot
.49907 .29117 Mdot
.43872 .39433 Mdot
.65045 .41623 Mdot
.6266 .77814 Mdot
.31278 .58317 Mdot
.19029 .45079 Mdot
.41196 .29101 Mdot
.5173 .33713 Mdot
.82916 .51067 Mdot
.5473 .27321 Mdot
.73998 .70011 Mdot
.44466 .29412 Mdot
.40277 .7875 Mdot
.28874 .55409 Mdot
.36934 .49358 Mdot
.71992 .41994 Mdot
.69518 .3133 Mdot
.67694 .26734 Mdot
.34346 .63607 Mdot
.62709 .20824 Mdot
.44661 .77909 Mdot
.59772 .32887 Mdot
.35181 .3845 Mdot
.7132 .2446 Mdot
.28729 .57762 Mdot
.75906 .27932 Mdot
.66954 .41576 Mdot
.46932 .34336 Mdot
.72001 .70239 Mdot
.60402 .63227 Mdot
.60711 .39071 Mdot
.50149 .71688 Mdot
.31048 .76671 Mdot
.58557 .59442 Mdot
.27312 .40792 Mdot
.41226 .42091 Mdot
.64889 .70639 Mdot
.20845 .40632 Mdot
.64099 .59332 Mdot
.44757 .6172 Mdot
.19075 .35947 Mdot
.72341 .4359 Mdot
.3605 .30589 Mdot
.39619 .77123 Mdot
.82706 .50719 Mdot
.4385 .19159 Mdot
.44853 .78867 Mdot
.38692 .6284 Mdot
.65068 .35222 Mdot
.73652 .55685 Mdot
.63278 .80499 Mdot
.4972 .62875 Mdot
.54539 .22074 Mdot
.51327 .27843 Mdot
.2216 .3329 Mdot
.71997 .40076 Mdot
.41407 .82382 Mdot
.78062 .38956 Mdot
.74703 .43109 Mdot
.31142 .31682 Mdot
.40669 .64547 Mdot
.60916 .25294 Mdot
.73656 .5239 Mdot
.50227 .22379 Mdot
.67182 .34787 Mdot
.62544 .66616 Mdot
.41461 .36719 Mdot
.68795 .43347 Mdot
.61734 .37926 Mdot
.74375 .31166 Mdot
.46361 .3027 Mdot
.57019 .62193 Mdot
.47776 .67498 Mdot
.74151 .43093 Mdot
.48376 .2206 Mdot
.70956 .68448 Mdot
.26375 .42054 Mdot
.2208 .53761 Mdot
.36444 .68627 Mdot
.35694 .26779 Mdot
.71375 .63253 Mdot
.25005 .69039 Mdot
.71764 .73936 Mdot
.342 .30576 Mdot
.37969 .33722 Mdot
.31575 .64275 Mdot
.61348 .35639 Mdot
.57872 .32574 Mdot
.4134 .24546 Mdot
.7081 .53634 Mdot
.32022 .39822 Mdot
.58786 .8198 Mdot
.64847 .49122 Mdot
.55003 .23891 Mdot
.42564 .31087 Mdot
.57211 .19624 Mdot
.26675 .51126 Mdot
.53117 .34238 Mdot
.6662 .64918 Mdot
.38187 .35303 Mdot
.63714 .37637 Mdot
.18413 .51784 Mdot
.24397 .29432 Mdot
.60163 .36384 Mdot
.515 .25494 Mdot
.49174 .69572 Mdot
.80371 .5102 Mdot
.29437 .70415 Mdot
.62929 .46767 Mdot
.46177 .69509 Mdot
.4345 .33411 Mdot
.39003 .6989 Mdot
.34114 .27456 Mdot
.67679 .44068 Mdot
.38057 .6075 Mdot
.66564 .61997 Mdot
.62442 .20825 Mdot
.34678 .71728 Mdot
.29604 .26403 Mdot
.5139 .747 Mdot
.74914 .40827 Mdot
.32963 .62931 Mdot
.40671 .34762 Mdot
.706 .27533 Mdot
.37036 .19531 Mdot
.7348 .34981 Mdot
.37776 .44594 Mdot
.28098 .46201 Mdot
.20499 .65977 Mdot
.20863 .49442 Mdot
.25593 .63796 Mdot
.64506 .30367 Mdot
.43156 .26522 Mdot
.31148 .4524 Mdot
.26227 .28778 Mdot
.41982 .25946 Mdot
.23216 .4175 Mdot
.19893 .65665 Mdot
.74255 .46107 Mdot
.73801 .35893 Mdot
.25436 .31427 Mdot
.50181 .68258 Mdot
.66594 .20591 Mdot
.34719 .38704 Mdot
.56053 .76127 Mdot
.72844 .47093 Mdot
.7345 .47405 Mdot
.63464 .24094 Mdot
.53714 .7698 Mdot
.71435 .72075 Mdot
.37699 .76106 Mdot
.66858 .45884 Mdot
.29139 .75683 Mdot
.60032 .81608 Mdot
.49989 .67276 Mdot
.60383 .70096 Mdot
.26601 .42527 Mdot
.80479 .37977 Mdot
.26914 .60702 Mdot
.49267 .19877 Mdot
.47785 .17742 Mdot
.73198 .34096 Mdot
.51511 .27447 Mdot
.62283 .75882 Mdot
.42357 .24912 Mdot
.66118 .53591 Mdot
.48585 .18326 Mdot
.37358 .41938 Mdot
.39583 .5692 Mdot
.49085 .17416 Mdot
.76112 .54864 Mdot
.60201 .67634 Mdot
.40287 .43103 Mdot
.318 .38161 Mdot
.49346 .31237 Mdot
.2415 .30755 Mdot
.27674 .73613 Mdot
.72405 .32379 Mdot
.61026 .23104 Mdot
.80607 .61829 Mdot
.56006 .34412 Mdot
.18593 .48031 Mdot
.71106 .25556 Mdot
.24416 .69298 Mdot
.62643 .79115 Mdot
.52532 .69967 Mdot
.24336 .63306 Mdot
.7582 .6255 Mdot
.74995 .38452 Mdot
.56352 .67064 Mdot
.72088 .74735 Mdot
.38339 .70064 Mdot
.6847 .3824 Mdot
.78615 .37547 Mdot
.56113 .36764 Mdot
.84075 .54014 Mdot
.31532 .2436 Mdot
.3055 .43808 Mdot
.27623 .74567 Mdot
.76525 .58058 Mdot
.34816 .73021 Mdot
.22091 .57961 Mdot
.2779 .36101 Mdot
.2417 .37006 Mdot
.79101 .59689 Mdot
.62087 .68838 Mdot
.69876 .26466 Mdot
.4655 .24615 Mdot
.63471 .52819 Mdot
.80203 .58462 Mdot
.51368 .32404 Mdot
.17028 .44759 Mdot
.42884 .79712 Mdot
.22241 .69384 Mdot
.50247 .67066 Mdot
.47572 .83857 Mdot
.39127 .34629 Mdot
.20819 .32152 Mdot
.44874 .22513 Mdot
.78941 .39761 Mdot
.22154 .41533 Mdot
.36412 .21286 Mdot
.19556 .54085 Mdot
.3539 .30672 Mdot
.64744 .35142 Mdot
.76985 .32917 Mdot
.26467 .26813 Mdot
.47797 .2609 Mdot
.29231 .24491 Mdot
.53169 .70643 Mdot
.45247 .19348 Mdot
.42831 .75024 Mdot
.73446 .6739 Mdot
.62401 .55568 Mdot
.58875 .6887 Mdot
.6973 .38337 Mdot
.3762 .27933 Mdot
.34549 .48939 Mdot
.68764 .41604 Mdot
.73615 .45277 Mdot
.37749 .81122 Mdot
.6478 .47215 Mdot
.75648 .64138 Mdot
.32516 .5053 Mdot
.471 .27879 Mdot
.68679 .37525 Mdot
.49816 .729 Mdot
.40716 .58342 Mdot
.60515 .43309 Mdot
.18653 .61534 Mdot
.23736 .55436 Mdot
.71942 .36688 Mdot
.44119 .77027 Mdot
.34639 .77082 Mdot
.53447 .26263 Mdot
.78236 .34426 Mdot
.77246 .67267 Mdot
.75269 .57206 Mdot
.77109 .54903 Mdot
.20853 .33902 Mdot
.47568 .19837 Mdot
.28615 .27069 Mdot
.48456 .24162 Mdot
.34693 .76956 Mdot
.43737 .35436 Mdot
.60831 .33666 Mdot
.69144 .36802 Mdot
.60366 .65544 Mdot
.37263 .32651 Mdot
.25693 .38016 Mdot
.73955 .28626 Mdot
.54482 .81121 Mdot
.45904 .77504 Mdot
.80468 .42458 Mdot
.69386 .59524 Mdot
.30621 .43012 Mdot
.54569 .61782 Mdot
.62979 .21444 Mdot
.70413 .77274 Mdot
.6469 .71549 Mdot
.34473 .78359 Mdot
.35463 .53695 Mdot
.49401 .34521 Mdot
.49159 .80426 Mdot
.70494 .74668 Mdot
.54168 .33611 Mdot
.31849 .74493 Mdot
.68069 .4065 Mdot
.51472 .1863 Mdot
.32686 .24585 Mdot
.32361 .75115 Mdot
.67599 .74377 Mdot
.2752 .64432 Mdot
.34126 .78265 Mdot
.6156 .31217 Mdot
.47946 .19283 Mdot
.31784 .29104 Mdot
.39324 .56956 Mdot
.64625 .2616 Mdot
.71499 .28146 Mdot
.47625 .17261 Mdot
.54824 .37345 Mdot
.6434 .27198 Mdot
.459 .33246 Mdot
.65744 .41695 Mdot
.34714 .71446 Mdot
.5392 .72812 Mdot
.77018 .37329 Mdot
.73894 .613 Mdot
.49713 .64416 Mdot
.68283 .38407 Mdot
.45726 .29776 Mdot
.63869 .2923 Mdot
.62324 .39157 Mdot
.2409 .50659 Mdot
.50671 .26557 Mdot
.3451 .73673 Mdot
.16643 .46454 Mdot
.75144 .45619 Mdot
.32674 .23733 Mdot
.45105 .31529 Mdot
.22743 .29415 Mdot
.31839 .22229 Mdot
.18911 .63142 Mdot
.72778 .58344 Mdot
.37794 .47474 Mdot
.60311 .38809 Mdot
.69481 .77504 Mdot
.40062 .61661 Mdot
.8142 .63558 Mdot
.58827 .59361 Mdot
.65267 .57015 Mdot
.55602 .80533 Mdot
.60781 .68051 Mdot
.16156 .44928 Mdot
.33544 .50176 Mdot
.30989 .51737 Mdot
.29381 .57204 Mdot
.32275 .77959 Mdot
.321 .30715 Mdot
.51322 .36631 Mdot
.60812 .34496 Mdot
.58834 .3796 Mdot
.15717 .50759 Mdot
.70596 .36587 Mdot
.68573 .54094 Mdot
.56901 .63698 Mdot
.77646 .64017 Mdot
.40312 .70052 Mdot
.73304 .49108 Mdot
.30156 .26834 Mdot
.26016 .4007 Mdot
.39734 .19169 Mdot
.67146 .39785 Mdot
.38923 .39791 Mdot
.62004 .75116 Mdot
.5353 .20625 Mdot
.61583 .60624 Mdot
.3906 .78106 Mdot
.61194 .81205 Mdot
.28731 .53722 Mdot
.60366 .38989 Mdot
.73311 .5024 Mdot
.43797 .35181 Mdot
.63645 .56408 Mdot
.4287 .20275 Mdot
.25801 .51469 Mdot
.656 .43964 Mdot
.71055 .57677 Mdot
.20093 .47074 Mdot
.5801 .19642 Mdot
.44041 .23771 Mdot
.69013 .53716 Mdot
.62848 .43261 Mdot
.52501 .72924 Mdot
.73402 .35383 Mdot
.71214 .44646 Mdot
.18034 .6202 Mdot
.38453 .73802 Mdot
.59637 .20035 Mdot
.81103 .61088 Mdot
.42839 .23386 Mdot
.74652 .34776 Mdot
.24184 .54538 Mdot
.3663 .76871 Mdot
.61813 .34454 Mdot
.59967 .17857 Mdot
.21073 .53331 Mdot
.32814 .78784 Mdot
.23487 .63409 Mdot
.42476 .59695 Mdot
.39038 .69565 Mdot
.77467 .32039 Mdot
.29165 .6748 Mdot
.44264 .71769 Mdot
.23778 .29835 Mdot
.15978 .5074 Mdot
.68974 .3329 Mdot
.16674 .41868 Mdot
.38984 .65718 Mdot
.63015 .44763 Mdot
.54923 .30614 Mdot
.54631 .64188 Mdot
.53644 .38006 Mdot
.52986 .35323 Mdot
.45809 .28177 Mdot
.25457 .64293 Mdot
.53629 .15934 Mdot
.74928 .55484 Mdot
.35692 .40556 Mdot
.65374 .60682 Mdot
.25561 .35988 Mdot
.27417 .38362 Mdot
.65921 .25871 Mdot
.47118 .36372 Mdot
.27978 .25624 Mdot
.60645 .37796 Mdot
.37363 .54453 Mdot
.68892 .3317 Mdot
.60409 .29507 Mdot
.36298 .53216 Mdot
.50534 .77833 Mdot
.24567 .3054 Mdot
.4296 .20356 Mdot
.70196 .34372 Mdot
.77618 .40278 Mdot
.40895 .71695 Mdot
.19181 .37956 Mdot
.72827 .43224 Mdot
.64306 .2584 Mdot
.63003 .24637 Mdot
.37794 .37256 Mdot
.48241 .34772 Mdot
.82606 .54191 Mdot
.25465 .26653 Mdot
.36222 .72019 Mdot
.30256 .23707 Mdot
.57533 .63068 Mdot
.2668 .31456 Mdot
.35426 .41498 Mdot
.62752 .80998 Mdot
.60966 .20225 Mdot
.37276 .5572 Mdot
.62674 .50348 Mdot
.36748 .57861 Mdot
.38325 .3136 Mdot
.42992 .22773 Mdot
.23252 .65589 Mdot
.48893 .18906 Mdot
.35259 .67484 Mdot
.25253 .48333 Mdot
.61236 .53903 Mdot
.56672 .24638 Mdot
.6071 .68062 Mdot
.34034 .77592 Mdot
.33404 .60975 Mdot
.5781 .74468 Mdot
.74893 .27903 Mdot
.69883 .75787 Mdot
.60315 .4314 Mdot
.3136 .46549 Mdot
.54964 .62801 Mdot
.69609 .4091 Mdot
.62907 .47536 Mdot
.20784 .57382 Mdot
.36515 .78537 Mdot
.35215 .65908 Mdot
.43919 .78084 Mdot
.59213 .38454 Mdot
.28245 .47221 Mdot
.5557 .19953 Mdot
.57595 .68734 Mdot
.70275 .63357 Mdot
.36036 .66907 Mdot
.23054 .31507 Mdot
.24629 .60468 Mdot
.17957 .58439 Mdot
.72428 .66244 Mdot
.67056 .76845 Mdot
.44195 .72474 Mdot
.23529 .54076 Mdot
.31636 .40939 Mdot
.66312 .70767 Mdot
.38005 .73926 Mdot
.29063 .29145 Mdot
.56674 .80821 Mdot
.81068 .59054 Mdot
.66089 .499 Mdot
.65118 .33801 Mdot
.22449 .61595 Mdot
.47505 .29323 Mdot
.68757 .71983 Mdot
.72874 .58691 Mdot
.31887 .62183 Mdot
.30118 .26997 Mdot
.33364 .52257 Mdot
.60494 .23993 Mdot
.5256 .34143 Mdot
.46677 .23903 Mdot
.61354 .69192 Mdot
.26299 .35889 Mdot
.78726 .58019 Mdot
.52143 .84126 Mdot
.44972 .67603 Mdot
.45799 .73024 Mdot
.35187 .52821 Mdot
.76808 .60549 Mdot
.40775 .79116 Mdot
.42773 .29778 Mdot
.52011 .3588 Mdot
.61646 .45039 Mdot
.21898 .47169 Mdot
.63179 .58135 Mdot
.45936 .8386 Mdot
.69733 .36394 Mdot
.57304 .20243 Mdot
.42646 .22303 Mdot
.23997 .65194 Mdot
.43846 .60443 Mdot
.31074 .39363 Mdot
.69451 .39817 Mdot
.24563 .68327 Mdot
.27833 .3526 Mdot
.66231 .61711 Mdot
.51825 .34187 Mdot
.60739 .56229 Mdot
.41415 .35282 Mdot
.51912 .77791 Mdot
.57616 .7307 Mdot
.48739 .20429 Mdot
.28743 .36528 Mdot
.66822 .43032 Mdot
.61232 .18027 Mdot
.33404 .49035 Mdot
.76303 .29439 Mdot
.37278 .81855 Mdot
.65961 .3352 Mdot
.63976 .24471 Mdot
.40758 .61731 Mdot
.27701 .40889 Mdot
.42333 .74205 Mdot
.33065 .73827 Mdot
.53143 .83187 Mdot
.41076 .60075 Mdot
.59428 .42242 Mdot
.51889 .76861 Mdot
.34357 .64824 Mdot
.36651 .7282 Mdot
.22343 .39621 Mdot
.72549 .27497 Mdot
.55874 .16759 Mdot
.45902 .37605 Mdot
.38496 .27245 Mdot
.77073 .38732 Mdot
.81733 .51484 Mdot
.61208 .374 Mdot
.37991 .24929 Mdot
.25005 .44852 Mdot
.19321 .44418 Mdot
.72667 .56346 Mdot
.41104 .1941 Mdot
.54216 .22616 Mdot
.61457 .68198 Mdot
.20875 .40681 Mdot
.15936 .46484 Mdot
.67198 .31439 Mdot
.63563 .71335 Mdot
.18264 .45286 Mdot
.66585 .66538 Mdot
.41167 .62813 Mdot
.48243 .78135 Mdot
.38558 .70648 Mdot
.71099 .25623 Mdot
.33369 .45653 Mdot
.7085 .63453 Mdot
.50485 .29901 Mdot
.79918 .6182 Mdot
.71236 .4288 Mdot
.77341 .3222 Mdot
.20337 .60656 Mdot
.74881 .31469 Mdot
.42324 .37648 Mdot
.40612 .27194 Mdot
.55539 .27711 Mdot
.2293 .65855 Mdot
.69003 .48572 Mdot
.73398 .71065 Mdot
.69836 .24447 Mdot
.80371 .54531 Mdot
.65184 .48105 Mdot
.21176 .38748 Mdot
.17386 .50262 Mdot
.61088 .38754 Mdot
.38624 .40503 Mdot
.53482 .83533 Mdot
.4468 .82759 Mdot
.69141 .59371 Mdot
.67906 .59692 Mdot
.61514 .70296 Mdot
.38575 .4548 Mdot
.35553 .76822 Mdot
.71874 .32037 Mdot
.30037 .52939 Mdot
.1842 .5698 Mdot
.46445 .77561 Mdot
.4122 .70997 Mdot
.32383 .75083 Mdot
.18331 .41204 Mdot
.29295 .49475 Mdot
.78056 .56967 Mdot
.35279 .42387 Mdot
.21868 .40615 Mdot
.58796 .80514 Mdot
.62228 .81266 Mdot
.421 .21117 Mdot
.42378 .27253 Mdot
.45974 .2196 Mdot
.48068 .33482 Mdot
.28475 .75409 Mdot
.4605 .24378 Mdot
.42602 .40742 Mdot
.48751 .21134 Mdot
.64687 .43789 Mdot
.64273 .72764 Mdot
.5913 .66081 Mdot
.31891 .54968 Mdot
.22585 .3246 Mdot
.19103 .63872 Mdot
.60848 .23769 Mdot
.80183 .62224 Mdot
.33933 .67341 Mdot
.60508 .6831 Mdot
.73639 .6943 Mdot
.44303 .29028 Mdot
.66741 .52656 Mdot
.21579 .44573 Mdot
.45017 .71559 Mdot
.71959 .61546 Mdot
.34086 .37995 Mdot
.69945 .71111 Mdot
.29566 .49026 Mdot
.27421 .26902 Mdot
.66717 .39657 Mdot
.36028 .42908 Mdot
.68819 .24875 Mdot
.27074 .51166 Mdot
.31996 .33802 Mdot
.3015 .61454 Mdot
.3569 .3212 Mdot
.21811 .67407 Mdot
0 0 1 r
.96359 .68506 Mdot
.97428 .36726 Mdot
.8116 .8408 Mdot
.41226 .9476 Mdot
.12649 .71283 Mdot
.92599 .17599 Mdot
.039 .95435 Mdot
.0656 .2791 Mdot
.67152 .81688 Mdot
.3828 .97311 Mdot
.72773 .75692 Mdot
.86603 .60882 Mdot
.32528 .79952 Mdot
.20859 .09649 Mdot
.1794 .13233 Mdot
.89102 .93044 Mdot
.1236 .84343 Mdot
.2293 .12336 Mdot
.731 .86052 Mdot
.01307 .1134 Mdot
.65623 .05512 Mdot
.06991 .358 Mdot
.30961 .09487 Mdot
.19581 .24164 Mdot
.92998 .30419 Mdot
.76395 .95382 Mdot
.35632 .97147 Mdot
.97515 .66116 Mdot
.13693 .21532 Mdot
.19715 .90133 Mdot
.34394 .06782 Mdot
.77962 .27088 Mdot
.88239 .7903 Mdot
.04774 .66614 Mdot
.12825 .82667 Mdot
.82389 .09025 Mdot
.3952 .07139 Mdot
.83894 .41929 Mdot
.26807 .84627 Mdot
.0596 .98015 Mdot
.08072 .93514 Mdot
.70585 .92214 Mdot
.81365 .14164 Mdot
.25336 .01773 Mdot
.86152 .22471 Mdot
.17655 .26147 Mdot
.03239 .79562 Mdot
.89868 .4054 Mdot
.96299 .80566 Mdot
.26694 .87372 Mdot
.86715 .23163 Mdot
.84456 .42621 Mdot
.87177 .61074 Mdot
.81818 .3379 Mdot
.18095 .97551 Mdot
.96919 .77302 Mdot
.43267 .53878 Mdot
.674 .13345 Mdot
.70136 .88094 Mdot
.02806 .3351 Mdot
.81979 .28001 Mdot
.20008 .9874 Mdot
.90857 .44571 Mdot
.04382 .55768 Mdot
.92957 .66289 Mdot
.60134 .0287 Mdot
.05542 .70194 Mdot
.02715 .22164 Mdot
.34426 .8112 Mdot
.98928 .87673 Mdot
.51466 .54099 Mdot
.799 .87953 Mdot
.3095 .98819 Mdot
.88063 .44363 Mdot
.94126 .77094 Mdot
.24237 .22362 Mdot
.28427 .88867 Mdot
.43447 .44775 Mdot
.54404 .01393 Mdot
.19443 .90937 Mdot
.52029 .49776 Mdot
.89177 .77829 Mdot
.1105 .57411 Mdot
.61731 .87982 Mdot
.85742 .24682 Mdot
.8477 .53214 Mdot
.87891 .78515 Mdot
.21278 .26328 Mdot
.94287 .76403 Mdot
.78111 .96762 Mdot
.84217 .19973 Mdot
.1736 .09761 Mdot
.97495 .9431 Mdot
.90889 .38301 Mdot
.70591 .12953 Mdot
.03304 .36402 Mdot
.42466 .04289 Mdot
.07833 .29879 Mdot
.58794 .88045 Mdot
.75243 .73332 Mdot
.04575 .72661 Mdot
.83374 .36012 Mdot
.13763 .24039 Mdot
.98552 .5608 Mdot
.1144 .86657 Mdot
.57066 .52771 Mdot
.86247 .48978 Mdot
.98817 .68455 Mdot
.79395 .2008 Mdot
.05132 .45767 Mdot
.37409 .07749 Mdot
.20778 .10736 Mdot
.01122 .69996 Mdot
.07995 .85717 Mdot
.0159 .14896 Mdot
.95575 .9808 Mdot
.10309 .50082 Mdot
.43746 .91709 Mdot
.03724 .13259 Mdot
.25782 .84235 Mdot
.65335 .06491 Mdot
.05985 .7448 Mdot
.97009 .87782 Mdot
.02415 .88722 Mdot
.91126 .39621 Mdot
.62172 .09618 Mdot
.10196 .48996 Mdot
.44023 .14461 Mdot
.7846 .91882 Mdot
.77683 .23199 Mdot
.05577 .12096 Mdot
.41293 .97815 Mdot
.94401 .6212 Mdot
.09907 .49853 Mdot
.51358 .48639 Mdot
.7455 .88693 Mdot
.15479 .23369 Mdot
.02733 .86379 Mdot
.81797 .65365 Mdot
.35375 .82551 Mdot
.7287 .16492 Mdot
.83036 .34893 Mdot
.9734 .26819 Mdot
.12098 .78136 Mdot
.55731 .08603 Mdot
.95639 .55748 Mdot
.61268 .98 Mdot
.48112 .89757 Mdot
.95138 .69798 Mdot
.13082 .35885 Mdot
.01964 .56768 Mdot
.05344 .02001 Mdot
.43096 .0302 Mdot
.12583 .48711 Mdot
.8723 .72701 Mdot
.16465 .77933 Mdot
.13949 .97476 Mdot
.04363 .43028 Mdot
.03379 .8528 Mdot
.16818 .10247 Mdot
.97055 .84259 Mdot
.49606 .88745 Mdot
.14264 .26287 Mdot
.13084 .54149 Mdot
.24469 .13528 Mdot
.75077 .05079 Mdot
.2207 .27268 Mdot
.59239 .93852 Mdot
.10614 .06087 Mdot
.95369 .7882 Mdot
.2576 .2532 Mdot
.96928 .68764 Mdot
.82135 .67967 Mdot
.23877 .73134 Mdot
.29294 .8692 Mdot
.14243 .68028 Mdot
.17894 .88228 Mdot
.35419 .04732 Mdot
.87444 .88967 Mdot
.06289 .21981 Mdot
.11723 .48842 Mdot
.51256 .8965 Mdot
.85832 .29098 Mdot
.0562 .28617 Mdot
.49302 .9313 Mdot
.17195 .38669 Mdot
.8523 .1632 Mdot
.11887 .17669 Mdot
.92059 .06535 Mdot
.60325 .88985 Mdot
.10049 .98354 Mdot
.83997 .44587 Mdot
.0541 .70718 Mdot
.87234 .33029 Mdot
.76328 .1634 Mdot
.47834 .46537 Mdot
.86529 .56572 Mdot
.1113 .8842 Mdot
.73031 .85539 Mdot
.89497 .93357 Mdot
.84817 .53491 Mdot
.0947 .38131 Mdot
.66034 .90561 Mdot
.60655 .90614 Mdot
.84096 .29437 Mdot
.94705 .76804 Mdot
.48774 .94243 Mdot
.22654 .90284 Mdot
.58297 .01866 Mdot
.28367 .98662 Mdot
.51251 .50143 Mdot
.66732 .09029 Mdot
.92605 .73027 Mdot
.91249 .8067 Mdot
.9692 .95243 Mdot
.43455 .85447 Mdot
.75246 .05939 Mdot
.84177 .84561 Mdot
.11983 .67542 Mdot
.16621 .92734 Mdot
.44271 .59493 Mdot
.50685 .85486 Mdot
.57236 .90378 Mdot
.52784 .89263 Mdot
.14762 .05911 Mdot
.76558 .84305 Mdot
.29604 .2037 Mdot
.81914 .89104 Mdot
.95646 .1077 Mdot
.3221 .04599 Mdot
.78445 .14355 Mdot
.25609 .1448 Mdot
.02868 .2907 Mdot
.95024 .9313 Mdot
.6372 .1195 Mdot
.34272 .18579 Mdot
.872 .35781 Mdot
.90573 .25992 Mdot
.52163 .07561 Mdot
.43985 .54314 Mdot
.27535 .921 Mdot
.31531 .9799 Mdot
.77397 .15255 Mdot
.96278 .80391 Mdot
.40843 .52884 Mdot
.10058 .4559 Mdot
.85223 .80597 Mdot
.18504 .20579 Mdot
.62793 .13889 Mdot
.65361 .13998 Mdot
.08256 .21947 Mdot
.98334 .19076 Mdot
.10997 .40575 Mdot
.01919 .94004 Mdot
.72268 .83635 Mdot
.82435 .74406 Mdot
.10456 .70727 Mdot
.89687 .13112 Mdot
.13956 .78781 Mdot
.70993 .20486 Mdot
.14642 .60685 Mdot
.5519 .94492 Mdot
.60037 .83946 Mdot
.81941 .11837 Mdot
.76622 .1052 Mdot
.59548 .48151 Mdot
.81798 .27998 Mdot
.80299 .0768 Mdot
.10287 .86214 Mdot
.5516 .86572 Mdot
.4833 .08264 Mdot
.98989 .911 Mdot
.87313 .23338 Mdot
.18028 .80243 Mdot
.11672 .13798 Mdot
.44582 .41093 Mdot
.61804 .14075 Mdot
.92001 .64857 Mdot
.13208 .6349 Mdot
.37852 .85225 Mdot
.20804 .05962 Mdot
.14223 .28315 Mdot
.14418 .50795 Mdot
.91253 .0568 Mdot
.21436 .84957 Mdot
.82634 .08633 Mdot
.19447 .69455 Mdot
.93552 .29303 Mdot
.2594 .17446 Mdot
.80309 .01969 Mdot
.49718 .52576 Mdot
.36281 .02762 Mdot
.15825 .16824 Mdot
.94302 .98715 Mdot
.3221 .09172 Mdot
.85467 .85764 Mdot
.81303 .01918 Mdot
.01974 .98969 Mdot
.11769 .17703 Mdot
.74508 .15921 Mdot
.59663 .98117 Mdot
.28433 .89926 Mdot
.83727 .98071 Mdot
.41986 .05143 Mdot
.03404 .97134 Mdot
.0241 .97185 Mdot
.6971 .18142 Mdot
.94222 .03201 Mdot
.62821 .0853 Mdot
.3554 .04103 Mdot
.03258 .78258 Mdot
.08087 .13197 Mdot
.18551 .79206 Mdot
.6512 .09035 Mdot
.16128 .81092 Mdot
.83641 .73191 Mdot
.14698 .82927 Mdot
.14911 .56029 Mdot
.94091 .4737 Mdot
.12402 .80396 Mdot
.11942 .30415 Mdot
.95294 .98323 Mdot
.81576 .16376 Mdot
.1339 .01194 Mdot
.86504 .68026 Mdot
.92701 .46405 Mdot
.10493 .94738 Mdot
.1482 .86247 Mdot
.22469 .27815 Mdot
.18546 .86943 Mdot
.94168 .70592 Mdot
.81759 .70378 Mdot
.48506 .04502 Mdot
.88077 .24953 Mdot
.92292 .74337 Mdot
.78565 .29235 Mdot
.67031 .07694 Mdot
.98655 .60016 Mdot
.46739 .03201 Mdot
.5113 .56495 Mdot
.89847 .74464 Mdot
.09355 .33838 Mdot
.02991 .23413 Mdot
.03356 .62416 Mdot
.51246 .06902 Mdot
.74475 .79792 Mdot
.92408 .24744 Mdot
.95359 .3176 Mdot
.03542 .493 Mdot
.64926 .93343 Mdot
.60539 .09475 Mdot
.42929 .02596 Mdot
.10273 .03553 Mdot
.16884 .77829 Mdot
.71134 .89083 Mdot
.14323 .29509 Mdot
.08777 .36311 Mdot
.84522 .63294 Mdot
.15671 .52227 Mdot
.97806 .73417 Mdot
.94252 .43239 Mdot
.84464 .44888 Mdot
.86456 .07909 Mdot
.37027 .10683 Mdot
.34603 .90532 Mdot
.51525 .46408 Mdot
.27542 .90628 Mdot
.23016 .80627 Mdot
.12852 .39382 Mdot
.5567 .48305 Mdot
.14066 .64984 Mdot
.60438 .06046 Mdot
.28621 .21076 Mdot
.73002 .97157 Mdot
.90614 .11373 Mdot
.3938 .07605 Mdot
.81545 .70872 Mdot
.13507 .72376 Mdot
.59509 .89265 Mdot
.01635 .33974 Mdot
.04819 .41941 Mdot
.86589 .6801 Mdot
.58948 .47914 Mdot
.48494 .60261 Mdot
.15739 .01161 Mdot
.88005 .70016 Mdot
.15085 .66207 Mdot
.84166 .29055 Mdot
.27516 .97217 Mdot
.41745 .912 Mdot
.01214 .13742 Mdot
.91833 .61067 Mdot
.04809 .9007 Mdot
.16569 .7464 Mdot
.06571 .17354 Mdot
.47767 .12576 Mdot
.64283 .94065 Mdot
.18589 .32347 Mdot
.71041 .11117 Mdot
.11895 .58551 Mdot
.6545 .92783 Mdot
.02147 .97738 Mdot
.87348 .74584 Mdot
.94254 .83709 Mdot
.13097 .41859 Mdot
.36319 .01781 Mdot
.61278 .94314 Mdot
.72949 .20711 Mdot
.04191 .76512 Mdot
.08956 .91823 Mdot
.7059 .10831 Mdot
.71657 .91023 Mdot
.47232 .49753 Mdot
.5487 .4115 Mdot
.84974 .54458 Mdot
.80411 .0289 Mdot
.13005 .34728 Mdot
.09794 .57235 Mdot
.01818 .64432 Mdot
.81372 .65849 Mdot
.51857 .8674 Mdot
.80968 .23656 Mdot
.96007 .46571 Mdot
.95014 .68218 Mdot
.82989 .3447 Mdot
.78967 .17254 Mdot
.74176 .76254 Mdot
.73338 .12803 Mdot
.45137 .39393 Mdot
.91814 .86024 Mdot
.63189 .16717 Mdot
.94827 .40434 Mdot
.79231 .94792 Mdot
.83224 .1403 Mdot
.01245 .78518 Mdot
.10029 .36795 Mdot
.89593 .84599 Mdot
.75006 .09274 Mdot
.8627 .24526 Mdot
.2185 .81172 Mdot
.14248 .92084 Mdot
.2009 .03424 Mdot
.13094 .89969 Mdot
.71349 .16428 Mdot
.14666 .56101 Mdot
.91836 .73948 Mdot
.27947 .87473 Mdot
.12933 .30516 Mdot
.72909 .17712 Mdot
.91862 .28073 Mdot
.93858 .54284 Mdot
.34244 .87119 Mdot
.81744 .63334 Mdot
.01838 .20871 Mdot
.55412 .41623 Mdot
.4346 .12087 Mdot
.17354 .94935 Mdot
.81225 .1655 Mdot
.80367 .94698 Mdot
.07211 .08673 Mdot
.88048 .06406 Mdot
.08339 .54963 Mdot
.65312 .91374 Mdot
.83107 .75804 Mdot
.84929 .5177 Mdot
.0372 .80126 Mdot
.81034 .24781 Mdot
.92006 .19355 Mdot
.21501 .23046 Mdot
.96453 .54763 Mdot
.24391 .75103 Mdot
.14327 .77979 Mdot
.11588 .96872 Mdot
.30923 .03208 Mdot
.10402 .79182 Mdot
.72862 .0856 Mdot
.82771 .29628 Mdot
.22882 .03913 Mdot
.93046 .47165 Mdot
.85315 .48235 Mdot
.83625 .67003 Mdot
.13433 .40655 Mdot
.37025 .86859 Mdot
.1771 .84997 Mdot
.73962 .13982 Mdot
.09991 .07938 Mdot
.01566 .34065 Mdot
.15964 .59793 Mdot
.15271 .8485 Mdot
.31359 .9181 Mdot
.02818 .45174 Mdot
.91417 .53852 Mdot
.89871 .44334 Mdot
.41708 .12506 Mdot
.67383 .08317 Mdot
.32697 .05549 Mdot
.52506 .87441 Mdot
.85374 .51986 Mdot
.50668 .43247 Mdot
.92977 .97153 Mdot
.84874 .84932 Mdot
.19271 .30259 Mdot
.94023 .41578 Mdot
.76583 .18733 Mdot
.44866 .14165 Mdot
.08318 .71569 Mdot
.29531 .8803 Mdot
.75813 .02792 Mdot
.08083 .57093 Mdot
.88349 .08559 Mdot
.7897 .87703 Mdot
.25322 .07688 Mdot
.8937 .5299 Mdot
.09832 .92722 Mdot
.2854 .92956 Mdot
.02729 .3661 Mdot
.39211 .85377 Mdot
.57219 .50347 Mdot
.83626 .75666 Mdot
.93275 .23656 Mdot
.78372 .79341 Mdot
.0262 .18815 Mdot
.01038 .80458 Mdot
.76669 .87194 Mdot
.16432 .05773 Mdot
.44772 .44535 Mdot
.22176 .81136 Mdot
.87759 .2342 Mdot
.89701 .22481 Mdot
.42241 .47623 Mdot
.78164 .94805 Mdot
.05594 .60714 Mdot
.67973 .86057 Mdot
.16854 .38274 Mdot
.05173 .40658 Mdot
.14491 .19158 Mdot
.104 .51767 Mdot
.67179 .05124 Mdot
.45161 .87182 Mdot
.36756 .01579 Mdot
.76208 .02106 Mdot
.68183 .81495 Mdot
.58505 .42289 Mdot
.01788 .08071 Mdot
.90604 .26565 Mdot
.76114 .79515 Mdot
.14438 .63673 Mdot
.98926 .78389 Mdot
.92575 .0233 Mdot
.2789 .18903 Mdot
.25373 .19854 Mdot
.65629 .88165 Mdot
.46323 .01846 Mdot
.24811 .97327 Mdot
.69229 .21351 Mdot
.11353 .34634 Mdot
.17797 .33285 Mdot
.91444 .14411 Mdot
.06411 .77922 Mdot
.88898 .56685 Mdot
.17567 .29745 Mdot
.20556 .15684 Mdot
.98789 .95479 Mdot
.77163 .90644 Mdot
.08326 .82048 Mdot
.05116 .44179 Mdot
.97725 .65276 Mdot
.2976 .95076 Mdot
.39598 .8724 Mdot
.02801 .32657 Mdot
.84254 .03893 Mdot
.30143 .16832 Mdot
.84484 .07434 Mdot
.77139 .24405 Mdot
.95609 .65662 Mdot
.10542 .27532 Mdot
.59842 .95016 Mdot
.30679 .79165 Mdot
.94308 .28563 Mdot
.1815 .05139 Mdot
.87763 .30961 Mdot
.12251 .36591 Mdot
.0897 .94965 Mdot
.13681 .67382 Mdot
.03873 .02487 Mdot
.94551 .63224 Mdot
.90423 .67476 Mdot
.0902 .98298 Mdot
.11767 .6253 Mdot
.16236 .98326 Mdot
.51497 .14712 Mdot
.60093 .46255 Mdot
.21065 .17761 Mdot
.40783 .11366 Mdot
.87628 .89943 Mdot
.32744 .12088 Mdot
.06277 .68274 Mdot
.53354 .9652 Mdot
.80741 .27926 Mdot
.38098 .97214 Mdot
.30224 .14195 Mdot
.95833 .24596 Mdot
.75748 .07816 Mdot
.8714 .16893 Mdot
.95623 .45466 Mdot
.90327 .76212 Mdot
.10566 .49266 Mdot
.11192 .68112 Mdot
.80864 .1252 Mdot
.70867 .13824 Mdot
.84261 .66074 Mdot
.47867 .56962 Mdot
.92954 .88882 Mdot
.77241 .976 Mdot
.83368 .40597 Mdot
.04987 .05526 Mdot
.10959 .02802 Mdot
.92815 .36433 Mdot
.12931 .24894 Mdot
.32258 .03261 Mdot
.54036 .0468 Mdot
.09323 .65306 Mdot
.97384 .63484 Mdot
.51605 .86403 Mdot
.47373 .90418 Mdot
.12945 .05629 Mdot
.80954 .26176 Mdot
.29783 .0929 Mdot
.83402 .84493 Mdot
.74248 .95425 Mdot
.32778 .9711 Mdot
.27855 .05988 Mdot
.92144 .35601 Mdot
.8018 .30952 Mdot
.02951 .93301 Mdot
.72188 .84991 Mdot
.87805 .01479 Mdot
.93882 .61485 Mdot
.56007 .03389 Mdot
.0836 .82645 Mdot
.81723 .36836 Mdot
.82743 .3967 Mdot
.08545 .56583 Mdot
.76068 .02515 Mdot
.10042 .45057 Mdot
.98908 .85889 Mdot
.02662 .61432 Mdot
.18938 .22743 Mdot
.37432 .08459 Mdot
.76937 .01833 Mdot
.06987 .37834 Mdot
.11088 .93831 Mdot
.47335 .41135 Mdot
.20877 .90262 Mdot
.47447 .54266 Mdot
.19196 .29811 Mdot
.30262 .05213 Mdot
.01238 .08048 Mdot
.91849 .95773 Mdot
.2332 .07195 Mdot
.17314 .68381 Mdot
.52855 .51046 Mdot
.86395 .33062 Mdot
.065 .10892 Mdot
.58073 .55645 Mdot
.48283 .12989 Mdot
.48025 .05921 Mdot
.25685 .97746 Mdot
.72019 .09782 Mdot
.09352 .30345 Mdot
.21976 .96303 Mdot
.14626 .47843 Mdot
.54497 .55464 Mdot
.55573 .91218 Mdot
.07195 .43456 Mdot
.9082 .85146 Mdot
.19781 .76345 Mdot
.25113 .10424 Mdot
.98656 .1957 Mdot
.04117 .1314 Mdot
.85011 .70746 Mdot
.4864 .56695 Mdot
.30418 .78548 Mdot
.42425 .1422 Mdot
.03637 .38743 Mdot
.83255 .74725 Mdot
.11837 .52617 Mdot
.91075 .75292 Mdot
.91439 .56702 Mdot
.23481 .14314 Mdot
.07409 .84975 Mdot
.7601 .07408 Mdot
.62497 .16048 Mdot
.9645 .32756 Mdot
.70812 .07263 Mdot
.78022 .82093 Mdot
.48311 .91969 Mdot
.71594 .96137 Mdot
.94604 .8971 Mdot
.42033 .91933 Mdot
.22231 .23006 Mdot
.92872 .25221 Mdot
.58753 .07939 Mdot
.95442 .91485 Mdot
.87332 .67183 Mdot
.2561 .85202 Mdot
.1029 .8411 Mdot
.76319 .92253 Mdot
.37716 .86992 Mdot
.0383 .56922 Mdot
.42132 .96301 Mdot
.20882 .74275 Mdot
.72836 .01114 Mdot
.63526 .16024 Mdot
.65763 .11944 Mdot
.83678 .3077 Mdot
.05927 .46956 Mdot
.37982 .08169 Mdot
.03609 .87217 Mdot
.29793 .87083 Mdot
.21529 .97787 Mdot
.39477 .44968 Mdot
.85193 .19918 Mdot
.54819 .15177 Mdot
.80246 .71981 Mdot
.90062 .58682 Mdot
.87433 .70485 Mdot
.75804 .05887 Mdot
.55255 .07119 Mdot
.92354 .11362 Mdot
.043 .75257 Mdot
.98058 .51217 Mdot
.369 .83358 Mdot
.08976 .91554 Mdot
.92675 .19545 Mdot
.20563 .2205 Mdot
.17851 .14639 Mdot
.61615 .085 Mdot
.14751 .61872 Mdot
.15713 .11636 Mdot
.05231 .90624 Mdot
.07717 .19101 Mdot
.11576 .72059 Mdot
.86174 .96071 Mdot
.92744 .584 Mdot
.72833 .19598 Mdot
.17818 .79011 Mdot
.24093 .21591 Mdot
.09979 .83053 Mdot
.91004 .6973 Mdot
.51414 .52917 Mdot
.0858 .83674 Mdot
.85508 .08437 Mdot
.78519 .27046 Mdot
.58076 .55406 Mdot
.57154 .86579 Mdot
.13946 .6109 Mdot
.26141 .84093 Mdot
.61551 .09153 Mdot
.0797 .33961 Mdot
.21481 .26504 Mdot
.74452 .96472 Mdot
.18279 .10874 Mdot
.22166 .93723 Mdot
.94354 .6477 Mdot
.05021 .39899 Mdot
.81389 .04661 Mdot
.20818 .94528 Mdot
.7091 .21845 Mdot
.50409 .94361 Mdot
.90454 .73557 Mdot
.87004 .25224 Mdot
.7782 .97912 Mdot
.61778 .89641 Mdot
.95451 .94231 Mdot
.82898 .35795 Mdot
.75613 .98723 Mdot
.12969 .1493 Mdot
.10707 .28694 Mdot
.73594 .93385 Mdot
.45137 .89514 Mdot
.08756 .63844 Mdot
.66336 .90622 Mdot
.69905 .9541 Mdot
.93312 .95706 Mdot
.83585 .67992 Mdot
.87572 .0585 Mdot
.65293 .14815 Mdot
.14958 .11484 Mdot
.21136 .2432 Mdot
.07182 .4666 Mdot
.82933 .36328 Mdot
.97104 .35029 Mdot
.88641 .39642 Mdot
.47953 .11551 Mdot
.06036 .7067 Mdot
.594 .06682 Mdot
.45422 .94217 Mdot
.19608 .33495 Mdot
.3922 .48537 Mdot
.64809 .01757 Mdot
.78036 .75101 Mdot
.91273 .25787 Mdot
.86217 .54137 Mdot
.47434 .96321 Mdot
.87957 .80066 Mdot
.10902 .05946 Mdot
.81142 .976 Mdot
.88888 .72794 Mdot
.96009 .34411 Mdot
.03651 .19637 Mdot
.2439 .10611 Mdot
.95252 .80047 Mdot
.08275 .99 Mdot
.63413 .9354 Mdot
.96393 .94035 Mdot
.81291 .9496 Mdot
.91422 .23146 Mdot
.70415 .95711 Mdot
.88751 .04489 Mdot
.47006 .86081 Mdot
.34495 .81173 Mdot
.50773 .07015 Mdot
.08064 .24604 Mdot
.43479 .07034 Mdot
.46105 .12018 Mdot
.7772 .79935 Mdot
.68996 .11977 Mdot
.08286 .83244 Mdot
.79265 .08468 Mdot
.603 .96182 Mdot
.10507 .90148 Mdot
.38666 .02691 Mdot
.66048 .84095 Mdot
.94015 .71628 Mdot
.20923 .73057 Mdot
.42222 .92141 Mdot
.34917 .09878 Mdot
.83375 .19982 Mdot
.73637 .12715 Mdot
.38605 .92688 Mdot
.98958 .90977 Mdot
.97082 .36511 Mdot
.05923 .20329 Mdot
.71347 .80883 Mdot
.08707 .54394 Mdot
.01961 .60455 Mdot
.84767 .41724 Mdot
.84828 .49766 Mdot
.64191 .90622 Mdot
.79885 .30417 Mdot
.86071 .29128 Mdot
.09519 .48554 Mdot
.51154 .58795 Mdot
.01792 .93179 Mdot
.50173 .9736 Mdot
.90712 .18024 Mdot
.06864 .67277 Mdot
.95404 .30885 Mdot
.10314 .02738 Mdot
.1746 .88306 Mdot
.5818 .42962 Mdot
.16648 .94147 Mdot
.08987 .44622 Mdot
.84198 .94021 Mdot
.41631 .51058 Mdot
.16612 .14198 Mdot
.98172 .24911 Mdot
.59724 .96909 Mdot
.82505 .29784 Mdot
.51717 .53267 Mdot
.44278 .92444 Mdot
.95783 .74109 Mdot
.42917 .84771 Mdot
.1568 .43142 Mdot
.39501 .10814 Mdot
.95815 .03271 Mdot
.40348 .84923 Mdot
.37071 .05382 Mdot
.56863 .56119 Mdot
.84374 .51135 Mdot
.13565 .62695 Mdot
.18815 .91889 Mdot
.16802 .87606 Mdot
.74918 .08099 Mdot
.80839 .68818 Mdot
.24957 .13679 Mdot
.41978 .0713 Mdot
.12372 .50004 Mdot
.24143 .1426 Mdot
.94589 .61417 Mdot
.48245 .07142 Mdot
.34881 .95882 Mdot
.87047 .42185 Mdot
.13693 .42141 Mdot
.24604 .7952 Mdot
.96292 .23216 Mdot
.07897 .59643 Mdot
.94545 .1062 Mdot
.32132 .03787 Mdot
.98975 .48222 Mdot
.82906 .95665 Mdot
.94879 .5446 Mdot
.52361 .102 Mdot
.14552 .76254 Mdot
.19027 .66615 Mdot
.86557 .32831 Mdot
.19072 .19373 Mdot
.04631 .36186 Mdot
.08771 .80745 Mdot
.01636 .57814 Mdot
.36535 .07766 Mdot
.79188 .21917 Mdot
.55345 .86592 Mdot
.51694 .51386 Mdot
.7548 .9068 Mdot
.08349 .62875 Mdot
.94656 .12911 Mdot
.45797 .08795 Mdot
.03895 .87411 Mdot
.81471 .89181 Mdot
.4757 .018 Mdot
.94895 .49433 Mdot
.02669 .0694 Mdot
.07033 .93049 Mdot
.97825 .09082 Mdot
.76031 .26781 Mdot
.94911 .20691 Mdot
.9358 .36619 Mdot
.41587 .06132 Mdot
.01455 .89685 Mdot
.8478 .03915 Mdot
.13834 .27066 Mdot
.44174 .96803 Mdot
.17676 .72074 Mdot
.05042 .91212 Mdot
.60343 .077 Mdot
.80022 .67166 Mdot
.84841 .79589 Mdot
.94262 .64231 Mdot
.12561 .95896 Mdot
.47586 .38722 Mdot
.92969 .55215 Mdot
.01571 .13176 Mdot
.13927 .87068 Mdot
.15749 .32607 Mdot
.18684 .23818 Mdot
.31201 .81247 Mdot
.94667 .2238 Mdot
.31968 .13571 Mdot
.47406 .05231 Mdot
.31377 .01375 Mdot
.3446 .17182 Mdot
.16609 .67787 Mdot
.16756 .92384 Mdot
.72847 .88684 Mdot
.42626 .08418 Mdot
.53492 .15576 Mdot
.13117 .5513 Mdot
.01688 .4314 Mdot
.84099 .74373 Mdot
.15475 .41313 Mdot
.12233 .84708 Mdot
.65355 .05317 Mdot
.12843 .88761 Mdot
.06534 .22127 Mdot
.98746 .34612 Mdot
.73468 .77612 Mdot
.34996 .82752 Mdot
.04725 .49055 Mdot
.8768 .60099 Mdot
.88269 .08723 Mdot
.76428 .7441 Mdot
.23894 .04386 Mdot
.08782 .96158 Mdot
.12031 .14644 Mdot
.03228 .75012 Mdot
.12305 .79052 Mdot
.2878 .9642 Mdot
.76329 .95319 Mdot
.66378 .02831 Mdot
.83335 .39501 Mdot
.8897 .2744 Mdot
.81169 .30302 Mdot
.51122 .56909 Mdot
.60735 .461 Mdot
.95102 .9398 Mdot
.8717 .97875 Mdot
.29704 .92129 Mdot
.04815 .59354 Mdot
.93063 .02788 Mdot
.77703 .81058 Mdot
.55999 .59408 Mdot
.94283 .14289 Mdot
.08093 .15434 Mdot
.02755 .3706 Mdot
.04258 .55099 Mdot
.05397 .35043 Mdot
.10802 .69645 Mdot
.98172 .28855 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`0Rooooo`?o003o0oooool3o`00oj7o
oooo0ol00?m<ooooo`7o00000Oooool00003o`000?oooooooooo027ooooo1Ol00?l00ooooooo003o
o`00o`03o`00obWooooo0ol00?l=ooooo`?o003o;oooool3o`00oc7ooooo1Ol00?lWooooo`?o003o
8Oooool1o`00007ooooo00000ol0003oooooooooo`0Qooooo`Go003o00?oooooo`00ool00?l00ol0
0?lHooooo`?o003o3Oooool5o`00o`[ooooo1_l00?lGooooo`?o003o00Coooooo`00ool00?oo003o
3oooool5o`00o`Oooooo0ol00?l@ooooo`?o003o4oooool5o`00o`Sooooo0ol00?l9ooooo`?o003o
3oooool5o`00ob3ooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3o`00oa?ooooo1Ol0
0?l00ooooooo003oo`00o`03o`00oaOooooo1Ol00?l<ooooo`Go003o2Oooool7o`00oaKooooo2Ol0
0?l>ooooo`Go003o1_ooool5o`00o`kooooo1Ol00?lBooooo`Go003o1_ooool6o`00o`Kooooo1_l0
0?l>ooooo`Go003o8?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`?o003o00?ooooo
o`00ool00?l00ol00?lCooooo`?o003o0oooool3o`00oaSooooo1Ol00?l<ooooo`Go003o2Oooool7
o`00o`gooooo0ol00?l6ooooo`Wo003o3_ooool5o`00o`Kooooo1Ol00?l>ooooo`Go003o4oooool3
o`00o`Kooooo1ol00?l5ooooo`Oo003o3_ooool5o`00o`[ooooo0ol00?lCooooo`7o00000Oooool0
0003o`000?oooooooooo00Gooooo2_l00?l:ooooo`Go003o9Oooool5o`00o`gooooo0ol00?l:oooo
o`Ko003o0_ooool3o`00o`Sooooo1Ol00?l5ooooo`Wo003o3oooool3o`00o`Oooooo1Ol00?l2oooo
o`?o003o2Oooool5o`00o`04ooooool00?oo003oo`00oaOooooo2?l00?l5ooooo`Oo003o3oooool3
o`00o`[ooooo1Ol00?lBooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo2_l00?l9oooo
o`Oo003o9Oooool3o`00o`gooooo0ol00?l01?oooooo003oo`00ool00?l7ooooo`Go003o0_ooool5
o`00o`Oooooo1Ol00?l6ooooo`Oo003o6oooool3o`00o`;ooooo1Ol00?l9ooooo`?o003o00?ooooo
o`00ool00?l00ol00?lFooooo`Oo003o1_ooool6o`00oagooooo2?l00?l2ooooo`?o003o2_ooool1
o`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o00Coooooo`00ool00?oo003o2_ooool7
o`00oaKooooo0ol00?lKooooo`Wo003o1_ooool5o`00o`;ooooo1Ol00?l7ooooo`Ko003o1Oooool5
o`00oaOooooo0ol00?l8ooooo`Go003o3Oooool5o`00oaKooooo1Ol00?l8ooooo`Go003o7_ooool>
o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool3o`00o`oooooo1ol00?lEoooo
o`Go003o1?ooool3o`00oa?ooooo2Ol00?l6ooooo`Go003o0_ooool5o`00o`Sooooo1Ol00?l5oooo
o`Go003o5_ooool5o`00o`Oooooo1Ol00?l=ooooo`Go003o5_ooool5o`00o`Sooooo1Ol00?l7oooo
o`Co003o5?ooool=o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool06?ooool6o`00oaKo
oooo1Ol00?l3ooooo`Go003o4_ooool9o`00o`Gooooo1Ol00?l4ooooo`?o003o2?ooool6o`00o`Go
oooo1Ol00?lFooooo`Go003o2?ooool3o`00o`oooooo0ol00?lHooooo`?o003o2_ooool3o`00o`Oo
oooo1_l00?lDooooo`co003o2Oooool1o`00007ooooo00000ol0003oooooooooo`0Hooooo`Go003o
5oooool5o`00o`?ooooo1ol00?lAooooo`Oo003o1Oooool5o`00o`oooooo1_l00?l7ooooo`?o003o
0_ooool3o`00o`gooooo0ol00?l2ooooo`Go003oAOooool3o`00o`Cooooo1_l00?l8ooooo`?o003o
3?ooool3o`00o`;ooooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0ol0
0?lIooooo`?o003o1?ooool8o`00oa;ooooo1_l00?l4ooooo`Go003o3oooool5o`00o`cooooo1Ol0
0?l;ooooo`Go003o0_ooool3o`00odGooooo1Ol00?l3ooooo`Ko003o1oooool5o`00oagooooo0Ol0
0001ooooo`0000?o0000ooooooooool0;oooool3o`00o`_ooooo1ol00?l>ooooo`?o003o0_ooool5
o`00o`Cooooo1Ol00?l01?oooooo003oo`00ool00?l;ooooo`Go003o2_ooool7o`00o`_ooooo1Ol0
0?lMooooo`?o003o0_ooool3o`00oaCooooo0ol00?l>ooooo`Go003o1?ooool4o`00o`Sooooo1Ol0
0?lMooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo0ol00?lCooooo`?o003o1oooool3
o`00o`03ooooool00?oo003o00?o003o3?ooool5o`00o`gooooo1Ol00?l00ooooooo003oo`00o`03
o`00o`Cooooo2_l00?l9ooooo`Go003o2_ooool8o`00o`_ooooo1Ol00?lLooooo`[o003o4_ooool5
o`00o`gooooo1Ol00?l@ooooo`Go003o0oooool3o`00oaOooooo0Ol00001ooooo`0000?o0000oooo
ooooool02Oooool5o`00o`cooooo1?l00?l00ooooooo003oo`00o`03o`00o`;ooooo3Ol00?l4oooo
o`?o003o1_ooool3o`00o`Sooooo0ol00?l3ooooo`Go003o0_ooool5o`00o`?ooooo2_l00?l9oooo
o`Go003o2_ooool7o`00o`gooooo0ol00?l@ooooo`?o003o2_ooool:o`00oa;ooooo1_l00?l=oooo
o`?o003o3_ooool3o`00o`04ooooool00?oo003oo`00o`?ooooo1Ol00?lFooooo`7o00000Oooool0
0003o`000?oooooooooo00Wooooo1Ol00?l;ooooo`_o003o00?oooooo`00ool00?l03?l00?l3oooo
o`Go003o3oooool5o`00o`;ooooo1Ol00?l2ooooo`Go003o1?ooool3o`00o`03ooooool00?oo003o
00?o003o2Oooool5o`00o`[ooooo1ol00?lOooooo`Go003o2Oooool:o`00oa;ooooo1ol00?lLoooo
o`Ko003o1Oooool5o`00oaKooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool5o`00o`_o
oooo2ol00?l00ooooooo003oo`00o`07o`00o`04ooooool00?oo003oo`00o`Cooooo1Ol00?l?oooo
o`Go003o0oooool3o`00o`?ooooo1Ol00?l01?oooooo003oo`00ool00?l5ooooo`?o003o2Oooool5
o`00o`cooooo1_l00?lMooooo`Oo003o2Oooool5o`00o`04ooooool00?oo003oo`00oa?ooooo1ol0
0?lLooooo`Oo003o1?ooool6o`00oaGooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3
o`00o`Cooooo0ol00?l<ooooo`Ko003o00Coooooo`00ool00?oo003o0_ooool8o`00o`Wooooo1Ol0
0?l?ooooo`Go003o2_ooool3o`00o`03ooooool00?oo003o00?o003o2oooool3o`00o`;ooooo1Ol0
0?l01?oooooo003oo`00ool00?l9ooooo`Go003o1?ooool4o`00o`Wooooo0ol00?l8ooooo`So003o
2Oooool5o`00oaOooooo1ol00?lLooooo`Oo003o1Oooool6o`00oaCooooo0Ol00001ooooo`0000?o
0000ooooooooool00_ooool5o`00oa?ooooo1?l00?l8ooooo`?o003o3_ooool3o`00o`Cooooo0ol0
0?l:ooooo`?o003o3oooool5o`00o`[ooooo1Ol00?l00ooooooo003oo`00o`08o`00o`Wooooo1Ol0
0?l2ooooo`Ko003o1oooool5o`00o`Oooooo1ol00?l:ooooo`Go003o2oooool3o`00o`[ooooo1Ol0
0?lFooooo`?o003o1Oooool6o`00o`Kooooo1Ol00?lDooooo`7o00000Oooool00003o`000?oooooo
oooo00;ooooo1Ol00?lfooooo`Go003o0_ooool3o`00oaKooooo1Ol00?l2ooooo`Ko003o0_ooool5
o`00o`;ooooo2Ol00?l9ooooo`Go003o0_ooool8o`00o`Gooooo1Ol00?l7ooooo`Ko003o2oooool5
o`00o`04ooooool00?oo003oo`00o`Kooooo1Ol00?l:ooooo`Go003o2Oooool3o`00o`Sooooo1Ol0
0?l6ooooo`?o003o1oooool5o`00oaCooooo0Ol00001ooooo`0000?o0000ooooool00?l01ol00?lA
ooooo`?o003o8_ooool5o`00o`03ooooool00?oo003o00?o003o5_ooool3o`00o`;ooooo3_l00?l2
ooooo`Wo003o2Oooool5o`00o`;ooooo2Ol00?l4ooooo`Go003o1_ooool8o`00o`_ooooo0ol00?l0
0ooooooo003oo`00o`03o`00o`Gooooo1Ol00?l8ooooo`Oo003o2?ooool5o`00o`Oooooo1Ol00?l0
1?oooooo003oo`00ool00?l=ooooo`?o003o5Oooool1o`00007ooooo00000ol0003o003oo`00o`06
o`00oa7ooooo1Ol00?lQooooo`Go003o00?oooooo`00ool00?l00ol00?lKooooo`go003o1?ooool7
o`00o`_ooooo0ol00?l4ooooo`So003o1Oooool3o`00o`Kooooo3ol00?l9ooooo`Go003o1Oooool5
o`00o`;ooooo0ol00?l2ooooo`So003o1_ooool7o`00o`Oooooo2_l00?l2ooooo`?o003o7oooool1
o`00007ooooo00000ol0003o003oo`00o`04o`00o`cooooo0ol00?l4ooooo`Go003o8_ooool3o`00
o`;ooooo1Ol00?lKooooo`go003o1Oooool5o`00o`Gooooo0ol00?l3ooooo`Go003o1_ooool5o`00
o`Kooooo0ol00?l5oooooa3o003o2?ooool6o`00o`Gooooo0ol00?l2ooooo`Go003o00?oooooo`00
ool00?l01_l00?l5ooooo`So003o0_ooool3o`00o`?ooooo2Ol00?l00ooooooo003oo`00o`03o`00
oakooooo0Ol00001ooooo`0000?o0000o`00ool00?l01?l00?l;ooooo`Go003o0oooool5o`00obSo
oooo0ol00?lAooooo`?o003o2Oooool;o`00o`Kooooo1Ol00?l4ooooo`Go003o0_ooool5o`00o`Oo
oooo0ol00?l6ooooo`Go003o1?ooool@o`00o`?ooooo0ol00?l2ooooo`Ko003o2_ooool5o`00o`03
ooooool00?oo003o00Go003o1_ooool7o`00o`;ooooo1Ol00?l4ooooo`go003o5oooool3o`00o`Co
oooo0Ol00001ooooo`0000?o0000ooooool00?l00ol00?l<ooooo`Go003o1?ooool3o`00ocKooooo
2ol00?l:ooooo`Go003o2_ooool5o`00o`Cooooo1Ol00?l2ooooo`Go003o4?ooool5o`00o`Gooooo
0ol00?l2ooooo`[o003o0_ooool<o`00o`[ooooo1Ol00?l2ooooo`?o003o2Oooool5o`00o`Cooooo
1Ol00?l4ooooo`Ko003o00?oooooo`00ool00?l01?l00?lFooooo`Go003o0oooool1o`00007ooooo
00000ol0003oooooooooo`0?ooooo`Go003o6Oooool3o`00o`Oooooo0ol00?lFooooo`co003o0ooo
ool3o`00o`Gooooo0ol00?l<ooooo`?o003o1Oooool5o`00o`?ooooo0ol00?lAooooo`Go003o2Ooo
ool:o`00o`?ooooo2ol00?l:ooooo`Go003o0_ooool5o`00o`Wooooo0ol00?l5ooooo`Go003o1Ooo
ool3o`00o`?ooooo1Ol00?lGooooo`Go003o0oooool1o`00007ooooo00000ol0003oooooooooo`0@
ooooo`?o003o6Oooool5o`00o`Gooooo1Ol00?lEooooo`co003o0_ooool5o`00oacooooo0ol00?l?
ooooo`?o003o1oooool3o`00o`[ooooo2_l00?l3ooooo`[o003o2_ooool5o`00o`?ooooo1Ol00?lA
ooooo`Go003o3?ooool3o`00oaSooooo1Ol00?l3ooooo`7o00000Oooool00003o`000?oooooooooo
02_ooooo1_l00?l5ooooo`Go003o1_ooool5o`00o`[ooooo2ol00?l3ooooo`Go003o;Oooool5o`00
oa?ooooo2_l00?l4ooooo`?o003o0_ooool3o`00o`_ooooo1Ol00?l3ooooo`Go003o00Coooooo`00
ool00?oo003o3_ooool3o`00oaoooooo0ol00?l7ooooo`?o003o1?ooool1o`00007ooooo00000ol0
003oooooooooo`0>ooooo`?o003o6_ooool8o`00o`?ooooo1Ol00?l5ooooo`Oo003o2_ooool6o`00
o`Oooooo1Ol00?l2ooooo`?o003o1Oooool3o`00ob3ooooo1Ol00?lDooooo`?o003o00?oooooo`00
ool00?l00ol00?lDooooo`So003o1?ooool3o`00o`03ooooool00?oo003o00?o003o;_ooool8o`00
o`[ooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?l;ooooo`Go003o6Oooool9o`00o`;o
oooo1Ol00?l5ooooo`Oo003o6?ooool3o`00o`;ooooo1Ol00?l3ooooo`Go003o7oooool5o`00oaWo
oooo0ol00?lDooooo`So003o2Oooool5o`00obkooooo2Ol00?l9ooooo`7o00000Oooool00003o`00
0?l00?oo003o00?o003o2_ooool5o`00oaCooooo1Ol00?l00ooooooo003oo`00o`06o`00o`;ooooo
1Ol00?l5ooooo`Oo003o7Oooool5o`00o`?ooooo1ol00?lBooooo`?o003o2Oooool3o`00oc7ooooo
1_l00?l;ooooo`Go003o9?ooool3o`00o`;ooooo0ol00?l2ooooo`Wo003o2Oooool1o`00007ooooo
00000ol0003o003oo`00o`03o`00o`[ooooo1Ol00?lCooooo`Oo003o0oooool5o`00o`;ooooo1Ol0
0?l6ooooo`Go003o7_ooool5o`00o`?ooooo2?l00?l<ooooo`?o003o00?oooooo`00ool00?l00ol0
0?lYooooo`?o003o0oooool3o`00o`Kooooo0ol00?l00ooooooo003oo`00o`04o`00o`cooooo0ol0
0?l<ooooo`?o003o5Oooool:o`00o`;ooooo2?l00?l9ooooo`7o00000Oooool00003o`000?l00?oo
003o00?o003o2?ooool6o`00oaCooooo1ol00?l4ooooo`?o003o1?ooool3o`00o`?ooooo0ol00?lI
ooooo`?o003o2Oooool3o`00o`Gooooo1ol00?l4ooooo`?o003o1?ooool:o`00obSooooo1Ol00?l0
0ooooooo003oo`00o`03o`00o`Cooooo1Ol00?l00ooooooo003oo`00o`03o`00oa[ooooo1Ol00?lD
ooooo`[o003o1_ooool3o`00o`[ooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?l8oooo
o`Go003o5_ooool7o`00oa3ooooo1Ol00?lGooooo`Go003o4_ooool7o`00o`03ooooool00?oo003o
00?o003o0oooool:o`00obSooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo1Ol00?l2oooo
o`?o003o1?ooool3o`00oa;ooooo1ol00?lDooooo`[o003o4oooool1o`00007ooooo00000ol0003o
ooooooooo`0:ooooo`Go003o5oooool5o`00oa7ooooo1Ol00?lGooooo`Go003o4oooool<o`00o`?o
oooo2_l00?lXooooo`Go003o00?oooooo`00ool00?l00ol00?l4ooooo`Go003o00Coooooo`00ool0
0?oo003o1?ooool5o`00oa3ooooo2?l00?lEooooo`?o003o0_ooool3o`00o`Cooooo0ol00?l=oooo
o`7o00000Oooool00003o`000?oooooooooo00?o003o0oooool9o`00o`Cooooo0ol00?lIooooo`?o
003o2_ooool5o`00oaOooooo1Ol00?lEooooo`[o003o1?ooool:o`00obSooooo0ol00?l3ooooo`?o
003o0_ooool3o`00o`05ooooool00?oo003oo`00ooooool01Ol00?l3ooooo`Go003o4?ooool7o`00
oa?ooooo0ol00?l;ooooo`Go003o3?ooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`03
ooooool00?oo003o00Oo003o1?ooool5o`00oaOooooo1Ol00?l:ooooo`?o003o00?oooooo`00ool0
0?l00ol00?lAooooo`Go003o5_ooool5o`00o`04ooooool00?oo003oo`00o`Sooooo1ol00?lboooo
o`Go003o1?ooool5o`00o`?ooooo1Ol00?l@ooooo`Go003o5?ooool5o`00o`[ooooo1Ol00?l<oooo
o`7o00000Oooool00003o`000?l00?oo003o00Co003o00?oooooo`00ool00?l01?l00?l7ooooo`Go
003o1_ooool3o`00o`kooooo1Ol00?l=ooooo`Oo003o3oooool5o`00oaSooooo0ol00?l>ooooo`Ko
003o8oooool5o`00o`Gooooo0ol00?l2ooooo`Go003o1?ooool5o`00o`?ooooo1Ol00?lAooooo`?o
003o1?ooool3o`00o`kooooo1Ol00?l:ooooo`Go003o3?ooool1o`00007ooooo00000ol0003o003o
o`00o`04o`00o`03ooooool00?oo003o00Co003o1oooool5o`00o`Gooooo1Ol00?l:ooooo`So003o
3?ooool9o`00o`[ooooo0ol00?l00ooooooo003oo`00o`03o`00oa[ooooo0ol00?l2ooooo`Go003o
1oooool3o`00ob?ooooo1ol00?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?l5ooooo`Go003o
0oooool5o`00o`Wooooo0ol00?l6ooooo`?o003o00?oooooo`00ool00?l00ol00?l=ooooo`Go003o
0_ooool3o`00o`Gooooo1?l00?l=ooooo`7o00000Oooool00003o`000?l00?oo003o00?o003o0ooo
ool4o`00o`Wooooo0ol00?l6ooooo`Go003o2Oooool8o`00o`cooooo2ol00?l8ooooo`[o003o6Ooo
ool<o`00o`oooooo0ol00?lJooooo`Oo003o0oooool5o`00o`;ooooo0ol00?l6ooooo`Go003o0ooo
ool5o`00o`Sooooo1Ol00?l4ooooo`[o003o3_ooool3o`00o`;ooooo1Ol00?l3ooooo`Go003o3Ooo
ool1o`00007ooooo00000ol0003oooooo`00o`03o`00oaWooooo2?l00?l6ooooo`Wo003o2oooool;
o`00o`Sooooo1Ol00?l01?oooooo003oo`00ool00?lJooooo`co003o3_ooool5o`00o`Kooooo0ol0
0?l@ooooo`Oo003o0oooool5o`00o`_ooooo1Ol00?l3ooooo`Go003o2?ooool5o`00o`Cooooo2_l0
0?lCooooo`Go003o0oooool5o`00o`gooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l?
ooooo`?o003o1oooool8o`00o`Gooooo2Ol00?l;ooooo`_o003o2?ooool5o`00oakooooo3?l00?l>
ooooo`Go003o1Oooool5o`00oa3ooooo1Ol00?l4ooooo`Go003o3?ooool3o`00o`Gooooo0ol00?l7
ooooo`Oo003o1?ooool5o`00o`04ooooool00?oo003oo`00oaCooooo1Ol00?l3ooooo`Go003o3Ooo
ool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`kooooo1Ol00?l6ooooo`So003o1_ooool8
o`00o`?ooooo0ol00?l6ooooo`Go003o00Coooooo`00ool00?oo003o2_ooool3o`00ob3ooooo0ol0
0?l2ooooo`Go003o3oooool5o`00o`;ooooo2?l00?lIooooo`Go003o7Oooool7o`00o`Kooooo0ol0
0?lJooooo`?o003o1Oooool3o`00o`kooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l>
ooooo`Go003o1oooool7o`00o`[ooooo0ol00?l3ooooo`Go003oEOooool3o`00o`;ooooo2Ol00?lB
ooooo`Go003o0oooool3o`00oaOooooo0ol00?l4ooooo`Go003o?_ooool1o`00007ooooo00000ol0
003oooooooooo`03o`00o`oooooo1Ol00?l:ooooo`?o003o4Oooool5o`00oeWooooo00?oo`00o`00
ool00?l01_l00?lBooooo`Oo003o4oooool3o`00o`05ooooool00?oo003oo`00ooooool01Ol00?l0
0ooooooo003oo`00o`05o`00o`Oooooo1?l00?l8ooooo`?o003o:?ooool1o`00007ooooo00000ol0
003oooooooooo`0Cooooo`?o003o4oooool3o`00o`Wooooo1Ol00?lHooooo`?o003o?Oooool2ool0
00Go003o0oooool3ool000oooooo1ol00?lBoooooaGo003o1oooool6o`00o`Kooooo1Ol00?l01?oo
oooo003oo`00ool00?lSooooo`7o00000Oooool00003o`000?oooooooooo02Sooooo1Ol00?l9oooo
o`?o003o6?ooool5o`00o`Sooooo0ol00?lSooooo`?oo`002oooool3ool000?o003o00?oo`00oooo
ooooool01Ooo000>ooooo`Oo003o4_oooolCo`00o`Cooooo0ol00?l2ooooo`Ko003o1_ooool:o`00
ob;ooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool3o`00oaOooooo1Ol00?lIooooo`?o
003o2?ooool5o`00o`Oooooo1Ol00?lQooooo`Soo`001oooool6ool000?ooooo1Ooo000?ooooo`Ko
003o4_ooool9o`00o`05ooooool00?oo003oo`00ooooool01Ol00?l3ooooo`Go003o00?oooooo`00
ool00?l01?l00?l6ooooo`[o003o3?ooool3o`00oa?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool03Oooool5o`00o`_ooooo0ol00?l8ooooo`Go003o2oooool3o`00o`[ooooo1Ol00?l7ooooo`Go
003o1oooool5o`00ob7ooooo2Ooo0007ooooo`?oo`001Oooool5ool000Kooooo1?oo0006ooooo`Go
003o4oooool3o`00o`04ooooool00?oo003oo`00o`Oooooo0ol00?l4ooooo`Go003o0_ooool4o`00
o`Sooooo0ol00?l00ooooooo003oo`00o`03o`00o`_ooooo1Ol00?lBooooo`7o00000Oooool00003
o`000?oooooooooo00gooooo1Ol00?l:ooooo`Go003o2?ooool3o`00o`_ooooo1Ol00?l9ooooo`Go
003o2?ooool3o`00o`Sooooo1Ol00?lQooooo`Woo`004?ooool3ool000Kooooo2Ooo0003ooooo`?o
003o3oooool3o`00o`Gooooo1Ol00?l=ooooo`Go003o4oooool3o`00o`Oooooo0ol00?l2ooooo`Go
003o4_ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`Go003o2_ooool5o`00oaKooooo
1Ol00?l9ooooo`Go003o5?ooool3o`00o`[ooooo0ooo000Eooooo`Woo`000oooool3ool0013ooooo
3Ooo000Cooooo`Go003o1?ooool5o`00o`kooooo0ol00?lMooooo`Go003o00?oooooo`00ool00?l0
0ol00?lBooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo0ol00?l8ooooo`?o003o2ooo
ool5o`00oaKooooo1Ol00?l:ooooo`?o003o0_ooool3o`00o`oooooo1Ol00?l8ooooo`Goo`005?oo
ool8ool000?ooooo1Ooo000>ooooo`koo`004oooool5o`00o`Cooooo1Ol00?l7ooooo`?o003o9?oo
ool5o`00o`;ooooo0ol00?lCooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ol00?l:
ooooo`?o003o2Oooool3o`00o`Gooooo0ol00?l:ooooo`?o003o0oooool3o`00o`oooooo1Ol00?l>
ooooo`Go003o2?ooool6ool000Oooooo1Ooo00001?ooooooo`00ool00?oo0004ooooo`Soo`000_oo
ool5ool000kooooo3_oo000Cooooo`Go003o1Oooool3o`00o`Oooooo1Ol00?lSooooo`So003o3ooo
ool3o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool7o`00o`Oooooo1Ol00?l?
ooooo`Go003o2?ooool5o`00oaCooooo1Ol00?l>ooooo`Go003o1?ooool3ool00003oooooooo003o
o`0000Soo`000_ooool;ool000?ooooo2?oo0002ooooo`Goo`003?ooool7ool000Gooooo0ooo000E
ooooo`?o003o1_ooool3o`00o`Oooooo1Ol00?lTooooo`Wo003o3?ooool5o`00o`;ooooo0Ol00001
ooooo`0000?o0000ooooooooool00_ooool8o`00o`Kooooo1Ol00?l?ooooo`Go003o2?ooool5o`00
o`kooooo0ol00?l3ooooo`Go003o3oooool3o`00o`Cooooo1Ooo00000oooooooo`00ool00008ool0
0003oooooooo003oo`0000Woo`000oooool8ool000;ooooo1Ooo0008ooooo`koo`008_ooool5o`00
o`Kooooo1Ol00?l?ooooo`Wo003o3oooool7o`00o`_ooooo1_l00?l1ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo1ol00?l2ooooo`?o003o00?oooooo`00ool00?l00ol00?l?ooooo`Go
003o2?ooool5o`00o`gooooo1Ol00?l3ooooo`?o003o0_ooool3o`00oa;ooooo1Ooo0002ooooo`Wo
o`0000?oooooool00?oo00002Ooo0002ooooo`[oo`0000?oooooool00?oo00000ooo0002ooooo`?o
o`000_oooolCool000cooooo0ooo000?ooooo`Go003o1oooool3o`00o`Gooooo0ol00?l7ooooo`_o
003o3_ooool7o`00o`_ooooo1_l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo
1Ol00?l00ooooooo003oo`00o`03o`00o`04ooooool00?oo003oo`00oa7ooooo0ol00?l8ooooo`Go
003o3_ooool5o`00o`Oooooo1Ol00?lAooooo`Goo`000oooool?ool00004oooooooo003oo`00ool0
00?ooooo2_oo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`0000?oooooool0
0?oo00005?oo0008ooooo`Goo`002_ooool3o`00o`03ooooool00?oo003o00?o003o3_ooool5o`00
o`Kooooo2ol00?l?ooooo`Ko003o0_ooool3o`00o`Oooooo1Ol00?l1ooooo`7o00000Oooool00004
o`000?ooooooooooooooo`?o003o0_ooool3o`00o`;ooooo1Ol00?lOooooo`Go003o3oooool5o`00
o`Gooooo1ol00?lBooooo`?oo`002?ooool;ool000Oooooo2_oo0002ooooo`?oo`000_ooool5ool0
0003oooooooo003oo`0001Koo`001_ooool6ool000Sooooo2_l00?l>ooooo`Go003o1_ooool;o`00
oa7ooooo0ol00?l2ooooo`Go003o1oooool3o`00o`;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool01Ol00?l6ooooo`Go003o7oooool5o`00oa3ooooo0ol00?l5ooooo`So003o4?ooool3ool000[o
oooo2_oo0009ooooo`_oo`001Oooool5ool000;ooooo0ooo00000oooooooo`00ool00003ool000;o
oooo3Ooo0005ooooo`Koo`001?ooool3o`00o`03ooooool00?oo003o00So003o3_ooool5o`00o`Oo
oooo2Ol00?lGooooo`Go003o3?ooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`Oooooo
0ol00?lDooooo`?o003o2Oooool5o`00o`cooooo0ol00?l9ooooo`Oo003o4?ooool5ool000Wooooo
2Ooo0007ooooo`?oo`000_ooool;ool000?ooooo1Ooo0007ooooo`?oo`001oooool:ool000Gooooo
1Ooo0003ooooo`oo003o3oooool3o`00obSooooo1Ol00?l<ooooo`7o00000Oooool00003o`000?oo
oooooooo00Ko003o1oooool4o`00o`;ooooo0ol00?l<ooooo`Go003o2Oooool3o`00o`?ooooo0ol0
0?l6ooooo`Go003o2?ooool5o`00oa;ooooo1Ooo0009ooooo`Ooo`001oooool6ool00003oooooooo
003oo`0000[oo`000oooool6ool000oooooo2_oo0004ooooo`Goo`001?ooool5o`00o`04ooooool0
0?oo003oo`00o`;ooooo0ol00?l?ooooo`?o003o:_ooool3o`00o`gooooo0Ol00001ooooo`0000Co
0000oooooooooooooooo1_l00?l5ooooo`_o003o2oooool5o`00o`kooooo1Ol00?l5ooooo`Go003o
2Oooool3o`00o`Cooooo1_oo0009ooooo`Goo`002_ooool7ool000?ooooo5_oo0005ooooo`Koo`00
2oooool<ool000Cooooo1Ooo0004ooooo`[o003o4_ooool5o`00oa3ooooo0ol00?l8ooooo`?o003o
2oooool3o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5o`00o`Gooooo2ol0
0?l;ooooo`Go003o2oooool8o`00o`Gooooo1_l00?l>ooooo`Soo`000_ooool3ool000Cooooo0ooo
000>ooooo`Goo`0000?oooooool00?oo00005Ooo0005ooooo`Ooo`002Oooool8ool00004oooooooo
003oo`00ool000Gooooo1Ooo0005ooooo`?o003o00?oooooo`00ool00?l00ol00?lBooooo`Go003o
3oooool5o`00o`Kooooo1Ol00?l9ooooo`Go003o3?ooool1o`00007ooooo00000ol0003ooooooooo
o`02ooooo`Go003o1Oooool;o`00o`cooooo0ol00?l;ooooo`go003o0_ooool5o`00o`kooooo2?oo
00000oooooooo`00ool00003ool001Cooooo7?oo0005ooooo`Soo`002Oooool7ool000_ooooo0ooo
000:ooooo`Go003o3oooool8o`00o`oooooo1_l00?l5ooooo`So003o1_ooool5o`00o`cooooo0Ol0
0001ooooo`0000?o0000ooooooooool00oooool4o`00o`Kooooo1?l00?l2ooooo`?o003o4_ooool3
o`00o`Kooooo3_l00?l00ooooooo003oo`00o`03o`00o`kooooo2?oo00000oooooooo`00ool00003
ool001Cooooo6_oo0007ooooo`Soo`002Oooool7ool001Wooooo0ol00?l?ooooo`So003o4?ooool9
o`00o`;ooooo2Ol00?l5ooooo`So003o2Oooool1o`00007ooooo00000ol0003oooooooooo`03oooo
o`Go003o7oooool5o`00o`Gooooo1Ol00?l2ooooo`Oo003o0_ooool3o`00o`kooooo3ooo000?oooo
o`?oo`000_oooolBool000Cooooo1_oo0005ooooo`Ooo`001?ooool3ool000?ooooo1ooo000[oooo
o`Go003o1Oooool3o`00o`cooooo2Ol00?l2ooooo`So003o0_ooool3o`00o`03ooooool00?oo003o
00Ko003o2?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o6oooool3o`00o`03
ooooool00?oo003o00?o003o1?ooool6o`00o`;ooooo1ol00?lBooooo`ooo`003oooool5ool00003
oooooooo003oo`0001;oo`001?ooool5ool000Gooooo1_oo0003ooooo`Goo`0000?oooooool00?oo
00001_oo0003ooooo`?oo`001oooool3ool001_ooooo1Ol00?l4ooooo`Go003o3?ooool8o`00o`Go
oooo1Ol00?l00ooooooo003oo`00o`03o`00o`?ooooo1Ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo1Ol00?l:ooooo`?o003o3Oooool:o`00o`Cooooo1ol00?l00ooooooo003o
o`00o`04o`00oa7ooooo3_oo000Boooooa_oo`000oooool5ool000Kooooo1Ooo0003ooooo`Goo`00
00?oooooool00?oo00001_oo0002ooooo`Koo`001?ooool5ool000Gooooo0ooo00000oooooooo`00
ool00002ool000gooooo1?l00?l5ooooo`Go003o3?ooool8o`00o`Kooooo0ol00?l2ooooo`Go003o
0oooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool3o`00o`[ooooo1Ol0
0?l:ooooo`Oo003o00Coooooo`00ool00?oo003o1Oooool<o`00oa;ooooo3ooo000;ooooo`?oo`00
1?oooolKool000?ooooo1Ooo0006ooooo`Goo`0000?oooooool00?oo00001Ooo00000oooooooo`00
ool00006ool000;ooooo1ooo0003ooooo`Goo`000_ooool<ool000_ooooo1Ol00?l5ooooo`Go003o
2_ooool:o`00o`Wooooo1ol00?l2ooooo`Go003o0oooool3o`00o`?ooooo0Ol00001ooooo`0000?o
0000ooooooooool04Oooool5o`00o`Wooooo2?l00?l:ooooo`_o003o4_ooool?ool000[ooooo1Ooo
0004ooooo`Woo`0000?oooooool00?oo00003_oo0004ooooo`?oo`002?ooool3ool00003oooooooo
003oo`0000Goo`000oooool6ool000;ooooo2?oo0003ooooo`Goo`0000?oooooool00?oo00002ooo
000;ooooo`Go003o1_ooool5o`00o`Sooooo3?l00?l7ooooo`Oo003o0oooool5o`00o`;ooooo1Ol0
0?l2ooooo`7o00000Oooool00003o`000?oooooooooo017ooooo1Ol00?l9ooooo`Oo003o3Oooool3
o`00o`03ooooool00?oo003o00?o003o2Oooool3o`00o`Cooooo1ooo0002ooooo`Soo`002_ooool5
ool000Gooooo2?oo0005ooooo`Ooo`0000Coooooool00?oo003oo`001_ooool3ool000_ooooo1Ooo
0006ooooo`Koo`0000?oooooool00?oo00001_oo0004ooooo`?oo`000_ooool=ool000_ooooo1Ol0
0?l6ooooo`Go003o2?ooool<o`00o`Oooooo1ol00?l3ooooo`Go003o0_ooool5o`00o`;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool04_ooool3o`00o`[ooooo1Ol00?lDooooo`?o003o2Oooool5
o`00o`Woo`001?ooool7ool000[ooooo1Ooo0006ooooo`Ooo`001_ooool6ool000Wooooo1Ooo000:
ooooo`Goo`001oooool5ool00003oooooooo003oo`0000Koo`0000Coooooool00?oo003oo`001Ooo
ool<ool000gooooo0ol00?l7ooooo`Go003o2?ooool<o`00o`?ooooo2ol00?l4ooooo`?o003o0ooo
ool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3o`00o`04ooooool00?oo
003oo`00o`Oooooo0ol00?l7ooooo`?o003o2Oooool5o`00o`Ooo`002?ooool5ool000_ooooo0ooo
0008ooooo`Goo`002Oooool6ool000Oooooo1Ooo0002ooooo`?oo`001_ooool3ool000Sooooo1Ooo
0002ooooo`coo`001Oooool3ool000;ooooo1Ooo000Hooooo`Co003o2_ooool:o`00o`?ooooo3?l0
0?l;ooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`0Sooooo`Go003o1Oooool5
o`00o`Gooooo1Ol00?l8ooooo`Go003o2_oo0005ooooo`Ooo`005?ooool7ool000Wooooo1Ooo0005
ooooo`Koo`0000?oooooool00?oo00000ooo000Aooooo`?oo`001_ooool9ool000Sooooo1ooo000G
ooooo`Go003o3_ooool3o`00o`Kooooo1ol00?l01?oooooo003oo`00ool00?lBooooo`7o00000Ooo
ool00003o`000?oooooooooo02?ooooo1Ol00?l5ooooo`Go003o1Oooool6o`00o`Kooooo0_oo0003
o`00o`goo`001?ooool7ool000;ooooo0ooo000>ooooo`Soo`002?ooool5ool000Cooooo1_oo0002
ooooo`Goo`006_ooool9ool00004oooooooo003oo`00ool000?ooooo1ooo000;ooooo`?o003o1?oo
ool3o`00o`?ooooo1Ol00?lGooooo`Oo003o3Oooool3o`00o`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool08oooool5o`00o`Gooooo1Ol00?l5ooooo`Oo003o1OoooolCool000Gooooo1Ooo0000
0oooooooo`00ool00003ool000Cooooo0ooo0003ooooo`?oo`0000?oooooool00?oo00001Ooo0008
ooooo`Goo`001?ooool6ool000;ooooo1ooo000Iooooo`Ooo`0000?oooooool00?oo00000ooo0002
ooooo`Goo`003?ooool5o`00o`;ooooo1Ol00?l2ooooo`Go003o5oooool6o`00o`gooooo1Ol00?l5
ooooo`7o00000Oooool00003o`000?oooooooooo01[ooooo0ol00?l5ooooo`Go003o1oooool3o`00
o`Oooooo1ol00?l4oooooa?oo`001Oooool5ool00003oooooooo003oo`0000?oo`000oooool5ool0
0003oooooooo003oo`0000[oo`002Oooool3ool000Gooooo1ooo0002ooooo`Woo`005Oooool6ool0
00?ooooo1Ooo0002ooooo`Koo`000_ooool3ool000Kooooo1Ol00?l00ooooooo003oo`00o`04o`00
o`?ooooo0ol00?lDooooo`?o003o00?oooooo`00ool00?l00ol00?l>ooooo`Go003o1Oooool1o`00
007ooooo00000ol0003oooooooooo`0>ooooo`?o003o2?ooool5o`00o`Cooooo1Ol00?lBooooo`Ko
003o1OoooolBool000Cooooo3?oo00000oooooooo`00ool00005ool00003oooooooo003oo`0000Wo
o`002?ooool3ool000Sooooo1_oo0004ooooo`Soo`005?ooool6ool000?ooooo1Ooo0003ooooo`_o
o`000oooool2ool000Go003o00?oooooo`00ool00?l01?l00?l3ooooo`Ko003o4?ooool5o`00o`05
ooooool00?oo003oo`00ooooool00ol00?l;ooooo`Go003o1Oooool1o`00007ooooo00000ol0003o
ooooooooo`0=ooooo`Go003o1oooool5o`00o`Cooooo1Ol00?lCooooo`Ko003o1oooool:ool00004
oooooooo003oo`00ool000Gooooo1ooo00001Oooooooo`00ool00?oo003ooooo00Soo`0000?ooooo
ool00?oo00002_oo0004ooooo`Ooo`001oooool6ool000Cooooo2?oo000Dooooo`Goo`001Oooool3
ool000Gooooo2_oo0002ooooo`Coo`000ol00?l2ool000Go003o0oooool8o`00o`oooooo1Ol00?l4
ooooo`Go003o2oooool3o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool7o`00
o`Oooooo1Ol00?l5ooooo`Go003o4oooool5o`00o`Oooooo0ooo0003ooooo`?oo`002_ooool7ool0
00Gooooo1ooo0003ooooo`?oo`000_ooool7ool000;ooooo2?oo0007ooooo`Koo`001Oooool7ool0
01Gooooo0ooo000>oooooaKoo`000ol00?l4ooooo`So003o3oooool5o`00o`Cooooo1Ol00?l3oooo
o`?o003o3_ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`?o003o0oooool8o`00o`Oo
oooo1Ol00?l5ooooo`Go003o4oooool5o`00o`Kooooo1Ooo000;ooooo`?oo`000_ooool5ool000Ko
oooo1Ooo0006ooooo`?oo`000oooool6ool00003oooooooo003oo`0000Koo`001?ooool8ool000Wo
oooo0ooo000Mooooo`Goo`001_oooolEool000Oooooo2?l00?l3ooooo`?o003o00?oooooo`00ool0
0?l00_l00?l5ooooo`?o003o1Oooool5o`00o`;ooooo1Ol00?l7ooooo`?o003o0oooool1o`00007o
oooo00000ol0003oooooooooo`03ooooo`Go003o0_ooool7o`00o`Sooooo1Ol00?l5ooooo`Go003o
5?ooool3o`00o`03ool00?ooooooo`0000;oo`000_ooool5ool000Cooooo0ooo0003ooooo`Goo`00
3Oooool3ool000Kooooo1Ooo0002oooooa3oo`000_ooool8ool0027ooooo0ooo0005ooooo`Ooo`00
0_ooool3ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00002ooo0002ooooo`?o003o
0oooool6o`00o`?ooooo2_l00?l=ooooo`?o003o0_ooool6o`00o`Kooooo1Ol00?l2ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooo1Ol00?l2ooooo`Go003o2_ooool5o`00o`Kooooo0ol0
0?l7ooooo`?o003o00Coooooo`00ool00?oo003o1oooool9ool00003oooooooo003oo`0000?oo`00
0oooool5ool000;ooooo1Ooo000?ooooo`?oo`001?ooool5ool00003oooooooo003oo`0000[oo`00
00?oooooool00?oo00000ooo00000oooooooo`00ool00003ool001_ooooo0ooo0005ooooo`Goo`00
1?ooool7ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00000_oo0002ooooo`coo`00
0_ooool5o`00o`Oooooo3_l00?lAooooo`Oo003o1_ooool5o`00o`;ooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooool5o`00o`?ooooo0ol00?l4ooooo`?o003o1Oooool3o`00o`Kooooo1Ol0
0?l5ooooo`Wo003o1_ooool9ool00003oooooooo003oo`0000?oo`000oooool5ool000;ooooo1Ooo
000>ooooo`Goo`000ooooolBool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00001?oo
000Iooooo`Goo`001?ooool5ool000Cooooo1ooo00000oooooooo`00ool00003ool000Sooooo0ooo
0003ooooo`Goo`000_ooool5o`00o`Kooooo3ol00?lAooooo`Ko003o1oooool5o`00o`;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool01?ooool3o`00o`[ooooo2?l00?l5ooooo`[o003o1Oooool9
o`00o`Kooooo2Ooo00000oooooooo`00ool00003ool000?ooooo1Ooo0003ooooo`?oo`003oooool5
ool00003oooooooo003oo`0001Soo`000_ooool6ool000?ooooo0ooo000Booooo`Goo`001?ooool6
ool000Cooooo1Ooo0002ooooo`Goo`003_ooool5ool000;ooooo1ol00?l00ooooooo003oo`00o`0:
o`00o`03ooooool00?oo003o00;o003o4Oooool6o`00o`Wooooo0ol00?l3ooooo`7o00000Oooool0
0003o`000?oooooooooo017ooooo2Ol00?l3ooooo`_o003o1Oooool:o`00o`Kooooo2?oo0002oooo
o`?oo`001Oooool3ool000Gooooo0ooo0003ooooo`?oo`0000?oooooool00?oo00000ooo0002oooo
o`[oo`0000?oooooool00?oo00001Ooo00000oooooooo`00ool0000<ool000;ooooo4Ooo000<oooo
o`Goo`001Oooool6ool000_ooooo0ooo000@ooooo`?oo`001?oooolBo`00oaKooooo1_l00?l2oooo
o`?o003o2oooool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`Wo003o0oooool:o`00o`Oo
oooo0ol00?l00ooooooo003oo`00o`03o`00o`Sooooo1ooo000@ooooo`Goo`0000?oooooool00?oo
00002Ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00004ool000;o
oooo2Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`00013oo`003?ooool6ool000Co
oooo1Ooo000Iooooo`?oo`002oooool@o`00o`Sooooo0ol00?l;ooooo`Go003o0_ooool5o`00o`[o
oooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool8o`00o`?ooooo1ol00?l>ooooo`Go003o
1_ooool:ool00004oooooooo003oo`00ool000Cooooo0ooo0004ooooo`Goo`0000?oooooool00?oo
00002Ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo0002ooooo`Koo`0000?oooooool00?oo
00001ooo00000oooooooo`00ool0000Fool000Cooooo0ooo0007ooooo`Goo`000oooool5ool000Co
oooo0ooo0004ooooo`?oo`002_ooool5ool000[ooooo2Ol00?l2ooooo`Go003o1oooool5o`00o`[o
oooo1Ol00?l2ooooo`Go003o2_ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`?o003o
1Oooool5o`00oa3ooooo0ol00?l6oooooa3oo`000_ooool5ool000;ooooo1_oo00000oooooooo`00
ool00009ool00003oooooooo003oo`0000?oo`0000Goooooool00?oo003oo`00ooooo`09ool00003
oooooooo003oo`0000Goo`000_oooolHool000?ooooo1Ooo0006ooooo`Goo`001?ooool3ool000Co
oooo1Ooo0002ooooo`Goo`002Oooool6ool000[ooooo1ol00?l3ooooo`Go003o1oooool5o`00o`_o
oooo0ol00?l3ooooo`Go003o2_ooool1o`00007ooooo00000ol0003oooooooooo`0gooooo`?oo`00
0_ooool@ool000;ooooo1Ooo00000oooooooo`00ool00006ool00005oooooooo003oo`00ool00?oo
ool01Ooo0002ooooo`Goo`001?ooool:ool00003oooooooo003oo`0000?oo`001Oooool?ool000;o
oooo1Ooo0004ooooo`Goo`001_ooool5ool000Wooooo1ooo0002ooooo`Goo`000_ooool4ool000?o
oooo1_oo0003ooooo`?oo`001?ooool5o`00o`Kooooo0ol00?l8ooooo`Go003o4Oooool5o`00o`[o
oooo0Ol00001ooooo`0000?o0000ooooooooool0:?ooool3o`00o`Kooooo0ol00?l2ooooo`Goo`00
00?oooooool00?oo00003_oo0002ooooo`Goo`0000?oooooool00?oo00002_oo00000oooooooo`00
ool00003ool000;ooooo1Ooo0004ooooo`[oo`0000?oooooool00?oo00000ooo0004oooooa7oo`00
1oooool8ool000Oooooo0ooo0009ooooo`Soo`000_ooool5ool00003oooooooo003oo`0000Coo`00
0oooool5ool000;ooooo1Ooo0004ooooo`?o003o4oooool3o`00oa;ooooo1Ol00?l:ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooo0ol00?lQooooo`Go003o1?ooool5o`00o`03oooooooo
003oo`0000Soo`000_ooool5ool00004oooooooo003oo`00ool000Cooooo0ooo0002oooooaSoo`00
1Oooool5ool00004oooooooo003oo`00ool000?ooooo0ooo0004ooooo`Soo`0000?oooooool00?oo
00001ooo0006ooooo`Woo`000_ooool3ool000kooooo1ooo0004ooooo`?oo`000_ooool7ool000?o
oooo0ooo0003ooooo`Goo`005oooool3o`00oaGooooo1ol00?l8ooooo`7o00000Oooool00003o`00
0?oooooooooo00;ooooo1Ol00?lPooooo`Go003o0_ooool7o`00o`03oooooooo003oo`0000Soo`00
5OoooolEool000Sooooo0ooo0007ooooo`Koo`000_ooool7ool000?ooooo2?oo0006ooooo`Woo`00
00?oooooool00?oo00000ooo000=ooooo`Goo`001?ooool3ool000Cooooo1ooo0008ooooo`Koo`00
5_ooool5o`00oaGooooo1ol00?l7ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo1Ol0
0?lPooooo`Go003o00?oooooo`00ool00?l02?l00?l9ool001Wooooo2?oo00000oooooooo`00ool0
0006ool000kooooo0ooo00000oooooooo`00ool00005ool00003oooooooo003oo`0000?oo`001Ooo
ool7ool000;ooooo0ooo0002ooooo`Woo`0000?oooooool00?oo00001Ooo000;ooooo`Coo`000ooo
ool6ool000Cooooo1_oo0002ooooo`?oo`000oooool5ool001Kooooo1ol00?lFooooo`Go003o1ooo
ool1o`00007ooooo00000ol0003oooooooooo`07o`00o`_ooooo0ol00?l01?oooooo003oo`00ool0
0?l?ooooo`?o003o0_ooool;o`00o`Ooo`006?ooool3ool000?ooooo0ooo0005ooooo`Soo`002_oo
ool<ool00003oooooooo003oo`0000?oo`001_ooool4ool000?ooooo2_oo00001?ooooooo`00ool0
0?oo0002ooooo`Soo`002?ooool6ool000;ooooo1ooo0006ooooo`[oo`000_ooool5ool000[ooooo
0ol00?l9ooooo`Oo003o5_ooool5o`00o`Oooooo0Ol00001ooooo`0000?o0000ooooool00?l01ol0
0?l:ooooo`Wo003o4oooool5o`00o`03ooooool00?oo003o00?o003o1ooo0007ooooo`?oo`003Ooo
ool5ool000_ooooo2?oo0009ooooo`Goo`0000?oooooool00?oo00002_oo0006ooooo`ooo`002Ooo
ool7ool00004oooooooo003oo`00ool000?ooooo2?oo00000oooooooo`00ool00008ool000Cooooo
2Ooo0003ooooo`?oo`002_ooool5o`00o`Sooooo1ol00?lGooooo`?o003o2?ooool1o`00007ooooo
00000ol0003oooooo`00o`07o`00o`[ooooo2Ol00?l2ooooo`?o003o3oooool3o`00o`;ooooo1Ol0
0?l6ool000Oooooo1Ooo000<ooooo`Goo`003?ooool8ool000Sooooo1Ooo00000oooooooo`00ool0
000=ool000?ooooo4?oo0002ooooo`?oo`001Oooool:ool000;ooooo5?oo0003ooooo`Woo`001ooo
ool3ool000Kooooo1ol00?l7ooooo`Go003o5oooool3o`00o`Cooooo0ol00?l2ooooo`7o00000Ooo
ool00003o`000?oooooo003o00Ko003o1Oooool3o`00o`?ooooo2Ol00?l00ooooooo003oo`00o`03
o`00o`04ooooool00?oo003oo`00oa3ooooo0ol00?l4ool000[ooooo1Ooo000<ooooo`Goo`003?oo
ool<ool000Gooooo0ooo0002oooooa3oo`000_oooolFool000Cooooo2_oo0002ooooo`goo`000_oo
ool5ool000?ooooo2?oo0007ooooo`Goo`001Oooool8o`00ob7ooooo3?l00?l1ooooo`7o00000Ooo
ool00003o`000?oooooo003o00Co003o1_ooool5o`00o`?ooooo0ol00?l01?oooooo003oo`00ool0
0?l2ooooo`[o003o4_ooool3ool000_ooooo1Ooo00001?ooooooo`00ool00?oo0009ooooo`?oo`00
3_ooool=ool000Cooooo0ooo0002ooooo`ooo`000_ooool9ool000;ooooo2ooo0004ooooo`[oo`00
0_ooool;ool000Cooooo1Ooo0002ooooo`[oo`001_ooool5ool000Kooooo1ol00?lQooooo`co003o
0Oooool1o`00007ooooo00000ol0003oooooooooo`03o`00o`Oooooo1Ol00?l<ooooo`[o003o6Ooo
ool3ool000Gooooo0ooo00000oooooooo`00ool00003ool001Wooooo3_oo0002ooooo`Goo`001Ooo
ool;ool000?ooooo1ooo0004ooooo`[oo`001?ooool9ool000;ooooo3?oo0005ooooo`?oo`000_oo
ool;ool000Kooooo1_oo0007ooooo`Go003o5oooool3o`00o`Oooooo3?l00?l1ooooo`7o00000Ooo
ool00003o`000?oooooooooo00[ooooo2?l00?l:ooooo`?o003o00?oooooo`00ool00?l00ol00?l=
ooooo`?oo`002?ooool5ool000?ooooo2_oo000Iooooo`koo`000_ooool5ool000Sooooo1ooo0004
ooooo`Ooo`001Oooool8ool000Kooooo2?oo0002ooooo`Koo`0000?oooooool00?oo00000ooo000:
ooooo`_oo`001oooool7ool000Gooooo1Ol00?l8ooooo`?o003o2oooool5o`00o`Oooooo2_l00?l2
ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0ol00?l00ooooooo003oo`00o`08o`00
o`04ooooool00?oo003oo`00o`Wooooo1Ol00?l<ooooo`Goo`001oooool5ool000;ooooo2ooo000I
ooooo`koo`000_ooool6ool000Cooooo2?oo0005ooooo`Soo`001_ooool5ool000Kooooo2ooo0000
0oooooooo`00ool00004ool000;ooooo0ooo0004ooooo`?oo`000_ooool<ool000Sooooo2?oo0004
ooooo`Ko003o1_ooool5o`00o`[ooooo1Ol00?l:ooooo`?o003o1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooo`[o003o00?oooooo`00ool00?l02ol00?l3ooooo`Oo003o3?ooool5ool0
00Oooooo1Ooo0002ooooo`goo`006?ooool3ool00003oooooooo003oo`0000Koo`000oooool7ool0
00;ooooo2Ooo0004ooooo`Soo`001_ooool5ool000Kooooo3?oo0002ooooo`Coo`002OoooolBool0
00Wooooo1ooo0004ooooo`Ko003o1_ooool5o`00o`[ooooo2?l00?l7ooooo`Co003o1Oooool1o`00
007ooooo00000ol0003oooooooooo`02ooooo`_o003o00?oooooo`00ool00?l03?l00?l00ooooooo
003oo`00o`06o`00o`cooooo1Ooo0008oooooaCoo`006oooool9ool000?ooooo1_oo0002ooooo`Wo
o`000oooool7ool000Oooooo1Ooo0007ooooo`coo`003_oooolDool000[ooooo1Ooo0002ooooo`So
003o1_ooool5o`00o`_ooooo2?l00?l5ooooo`Ko003o1?ooool1o`00007ooooo00000ol0003ooooo
ooooo`02ooooo`_o003o0_ooool3o`00o`03ooooool00?oo003o00Oo003o00?oooooo`00ool00?l0
1Ol00?l>ooooo`?oo`002?ooool=ool00003oooooooo003oo`0000Goo`005_ooool3ool000?ooooo
2?oo0004ooooo`ooo`001?ooool6ool00004oooooooo003oo`00ool000;ooooo1ooo0007ooooo`Oo
o`0000Coooooool00?oo003oo`003oooool=ool00003oooooooo003oo`0000Coo`000oooool3ool0
00Gooooo1Ooo0008o`00o`Sooooo0ol00?l<ooooo`So003o1Oooool6o`00o`Cooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool6o`00o`04ooooool00?oo003oo`00o`?ooooo0ol00?l2oooo
o`So003o00?oooooo`00ool00?l00ol00?lKooooo`Soo`0000?oooooool00?oo00000ooo0002oooo
o`Goo`005Oooool5ool000Gooooo1ooo0003ooooo`[oo`000oooool3ool000;ooooo1Ooo00000ooo
ooooo`00ool0000;ool000Sooooo1ooo0003ooooo`?oo`001Oooool3ool000?ooooo3_oo0002oooo
o`Goo`000_ooool5ool00003oooooooo003oo`0000Koo`001ol00?lIooooo`Oo003o1Oooool6o`00
o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5o`00o`Oooooo1Ol00?l3ooooo`Go
003o0oooool3o`00oa7ooooo0ooo0005oooooa7oo`000oooool3ool000Kooooo0ooo0003ooooo`?o
o`001oooool5ool000Kooooo1ooo0005ooooo`Goo`001?ooool5ool000;ooooo0ooo0002ooooo`co
o`001Oooool3ool00003oooooooo003oo`0000Goo`000_ooool5ool000?ooooo1Ooo00000ooooooo
o`00ool00004ool00005oooooooo003oo`00ool00?ooool00ooo0004ooooo`?oo`000oooool>ool0
00Go003o7_ooool3o`00o`Oooooo1?l00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo0ol00?l8ooooo`Go003o0_ooool5o`00oa;ooooo0ol00?l2ooooo`Goo`000ooooolDool000Wo
oooo1Ooo00000oooooooo`00ool00005ool000Cooooo1Ooo0008ooooo`Goo`001Oooool5ool000Co
oooo1Ooo0007ooooo`[oo`001_ooool=ool00003oooooooo003oo`0000?oo`000oooool=ool000co
oooo0ooo0002ooooo`ooo`000ol00?lGooooo`?o003o6?ooool1o`00007ooooo00000ol0003ooooo
ooooo`06ooooo`?o003o1Oooool5o`00o`;ooooo1Ol00?lAooooo`Go003o00?oooooool00?oo0000
0ooo0002ooooo`Woo`000oooool:ool000Sooooo1Ooo00000oooooooo`00ool00006ool000Cooooo
0ooo0002ooooo`?oo`001?ooool5ool000Gooooo1Ooo00001?oooooo003oo`00ool00?l5ool000So
oooo2?oo0007ooooo`goo`0000?oooooool00?oo00000ooo0003ooooo`koo`002_ooool5ool000;o
oooo0ooo00000oooooooo`00ool00008ool001Wooooo1Ol00?lGooooo`7o00000Oooool00003o`00
0?oooooooooo00Gooooo1Ol00?l5ooooo`?o003o0oooool5o`00oa7ooooo1_l00?l5ool00003oooo
oooo003oo`0000Ooo`001?ooool:ool000Cooooo0ooo00000oooooooo`00ool00003ool00003oooo
oooo003oo`0000Koo`002?ooool5ool000Cooooo0ooo0007ooooo`?oo`0000?oooooo`00ool00?l0
0ol00?l3ool000Wooooo1Ooo000:ooooo`koo`0000Coooooool00?oo003oo`001Oooool=ool000[o
oooo1Ooo00000oooooooo`00ool00007ool00003oooooooo003oo`0000?oo`006Oooool5o`00oaOo
oooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00o`cooooo0ol00?l7ooooo`?o003o
2?ooool6o`00o`04oooooooo003oo`00ool000;ooooo1_oo0008ooooo`?oo`0000?oooooool00?oo
00000ooo0003ooooo`Woo`000oooool7ool000Sooooo1Ooo0008ooooo`?oo`0000Coooooo`00ool0
0?oo003o0oooool5o`00o`gooooo0ooo000<ooooo`koo`002Oooool<ool000[ooooo1Ooo00000ooo
ooooo`00ool00006ool000?ooooo0ooo0005ooooo`?o003o4_ooool5o`00oaOooooo0Ol00001oooo
o`0000?o0000ooooooooool01Oooool8o`00oa;ooooo1Ol00?l8ooooo`Go003o1_ooool7ool000co
oooo0ooo0004ooooo`Woo`000_ooool7ool000Sooooo1_oo0007ooooo`Coo`001Ol00?l2ooooo`Go
003o7Oooool=ool000Wooooo2ooo000<ooooo`?oo`000_ooool:ool000Sooooo1Ol00?l;ooooo`?o
003o1?ooool4o`00oaOooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool8o`00oa7ooooo
1Ol00?l9ooooo`?o003o2?ooool7ool000Oooooo0ooo0008ooooo`[oo`0000?oooooool00?oo0000
1?oo0008ooooo`Koo`002?ooool4ool000Go003o0oooool3o`00oaoooooo3?oo0008ooooo`Koo`00
00?oooooool00?oo00000ooo0004ooooo`?oo`002oooool:ool000Kooooo1_l00?l:ooooo`Go003o
0oooool5o`00oaKooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool5o`00o`gooooo0ol0
0?l00ooooooo003oo`00o`03o`00oa3ooooo2ooo0006ooooo`Goo`002?ooool9ool00003oooooooo
003oo`0000?oo`0000Coooooool00?oo003oo`001Oooool6ool000Sooooo1?oo0005o`00obOooooo
1?oo0002ooooo`?oo`002Oooool=ool000;ooooo1Ooo000;ooooo`Woo`000_ooool3ool00003oooo
ool00?oo003o00Co003o2_ooool=o`00o`Kooooo0ol00?l=ooooo`7o00000Oooool00003o`000?oo
oooooooo00Wooooo1Ol00?l<ooooo`Go003o00?oooooo`00ool00?l00ol00?l>ooooo`coo`001_oo
ool9ool000Kooooo1ooo0002ooooo`?oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool0
0007ool000Gooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?o003o>_ooool=ool000;ooooo
1Ooo0004ooooo`?oo`001?ooool9ool00003oooooooo003oo`0000?oo`001_l00?l:ooooo`go003o
1Oooool5o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool5o`00o`cooooo1Ol0
0?l2ooooo`Go003o0_ooool3o`00o`Gooooo3_oo0007ooooo`[oo`001_ooool5ool000Kooooo4?oo
0004ooooo`Goo`000_ooool3o`00o`Gooooo0ol00?lCooooo`?o003o7oooool<ool000;ooooo1Ooo
0003ooooo`Goo`000oooool8ool000;ooooo1Ooo00000ooooooo003oo`00o`03o`00o`_ooooo2ol0
0?l6ooooo`Go003o3?ooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o3?ooool5
o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`?ooooo3ooo0008ooooo`Woo`001_ooool5
ool000Kooooo4Ooo0003ooooo`Goo`0000?oooooo`00ool00?l00ol00?l3ooooo`Go003o4Oooool5
o`00oaWooooo4Ooo0003ooooo`?oo`001?ooool5ool000Cooooo0ooo0006ooooo`Goo`0000?ooooo
o`00ool00?l00ol00?l>ooooo`Go003o2?ooool6o`00o`cooooo0Ol00001ooooo`0000?o0000oooo
ooooool02Oooool5o`00o`gooooo0ol00?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?l2ool0
0003oooooooo003oo`00013oo`002?ooool6ool000Kooooo1Ooo0006oooooa7oo`000oooool5ool0
0003ooooool00?oo003o00?o003o0oooool5o`00oa7ooooo1_l00?lGoooooa;oo`000oooool3ool0
00Cooooo1Ooo000>ooooo`?oo`000oooool7o`00o`cooooo0ol00?l8ooooo`Ko003o3Oooool1o`00
007ooooo00000ol0003oooooooooo`08ooooo`Go003o4oooool6o`00o`03ooooool00?oo003o00?o
003o2?oo0003ooooo`_oo`001Oooool7ool000Sooooo0ooo0007ooooo`[oo`000_ooool5ool00003
oooooooo003oo`0000Coo`000_ooool5o`00o`?ooooo1Ol00?lAooooo`Ko003o1Oooool3o`00o`?o
o`003?oooolAool000?ooooo1Ooo0004ooooo`Coo`000oooool3ool000Gooooo0ooo0007ooooo`Oo
003o0oooool3o`00oa3ooooo1Ol00?l>ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo
1Ol00?lCooooo`Oo003o00Coooooo`00ool00?oo003o2?oo0007ooooo`[oo`000_ooool5ool001Co
oooo2ooo0003ooooo`?oo`0000?oooooool00?oo00000ooo0005ooooo`?o003o1Oooool3o`00oa?o
oooo1Ol00?l4ooooo`Go003o0ooo000;ooooo`ooo`001Oooool5ool000Cooooo1Ooo00000ooooooo
o`00ool00003ool000?ooooo2?oo0003ooooo`Oo003o0_ooool5o`00o`oooooo1Ol00?l>ooooo`7o
00000Oooool00003o`000?oooooooooo00Sooooo1Ol00?lCooooo`Oo003o0oooool7ool000[ooooo
2_oo00000oooooooo`00ool00004ool000?ooooo0ooo00001?ooooooo`00ool00?oo0009ooooo`_o
o`001oooool5ool002Cooooo0ol00?l5ooooo`Go003o0ooo000<ooooo`Soo`000_ooool3ool000Go
oooo1_oo0004ooooo`Goo`0000?oooooool00?oo00000ooo0003ooooo`Woo`000_ooool7o`00o`;o
oooo1Ol00?l@ooooo`?o003o3oooool1o`00007ooooo00000ol0003oooooooooo`03o`00o`Cooooo
1Ol00?lEooooo`Ko003o00Coooooo`00ool00?oo003o2?oo000;ooooo`Ooo`0000?oooooool00?oo
00001?oo0002ooooo`Woo`002?ooool:ool000Kooooo1ooo000Gooooo`?o003o4Oooool6o`00o`Go
o`001?ooool5ool000Gooooo1Ooo0002ooooo`?oo`000oooool8ool00003oooooooo003oo`0000Go
o`0000?oooooool00?oo00003ooo0003ooooo`Go003o0oooool5o`00oa7ooooo0ol00?l>ooooo`7o
00000Oooool00003o`000?oooooo003o00Co003o0oooool5o`00o`Cooooo0ol00?l@ooooo`?o003o
00?oooooo`00ool00?l00ol00?l8ool000cooooo1Ooo0002ooooo`Goo`000_ooool9ool000Wooooo
1ooo0007ooooo`Ooo`005oooool5o`00oa3ooooo1Ol00?l7ool000;ooooo1ooo0004ooooo`Goo`00
00?oooooool00?oo00000ooo0002ooooo`ooo`000_oooolAool000?ooooo1Ol00?l4ooooo`?o003o
4Oooool5o`00o`gooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l3ooooo`Go003o0ooo
ool5o`00oa?ooooo1Ol00?l00oooooooo`00ool00005ool000gooooo0ooo0004ooooo`?oo`000ooo
ool9ool000_ooooo1Ooo0007ooooo`Goo`006Oooool5o`00oa3ooooo1Ol00?l00oooooooo`00ool0
0004ool000;ooooo5_oo0002ooooo`ooo`000oooool?ool000Gooooo0ol00?lIooooo`Go003o3Ooo
ool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`Cooooo1Ol00?l2ooooo`Go003o4oooool5
o`00o`?ooooo1ooo000Iooooo`Soo`003?ooool3ool000Sooooo1Ooo000Iooooo`Go003o4Oooool3
o`00o`;ooooo1_oo0002oooooaKoo`000oooool>ool000Kooooo1ooo000Eooooo`?o003o0_ooool3
o`00o`Wooooo1Ol00?l=ooooo`7o00000Oooool00003o`000?oooooooooo00?o003o1_ooool5o`00
o`03ooooool00?oo003o00?o003o00Coooooo`00ool00?oo003o4?ooool3o`00o`05oooooooo003o
o`00ool00?ooool01ooo0002ooooo`?oo`005Oooool6ool0017ooooo0ooo0004ooooo`?oo`001_oo
ool3o`00o`04ooooool00?oo003oo`00o`kooooo0ol00?lHooooo`Coo`001?ooool;ool00003oooo
oooo003oo`0000Koo`001?ooool7ool00003oooooooo003oo`0000Coo`001oooool6ool000Sooooo
00Coo`00o`00ool00?oo003o2?ooool<o`00o`Oooooo0ol00?l>ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo0ol00?l3ooooo`Go003o0_ooool3o`00o`03ooooool00?oo003o00Go003o
3oooool6ool000;ooooo1Ooo00000oooooooo`00ool00003ool000Kooooo0ooo000<ooooo`Goo`00
4?ooool5ool00004ooooool00?oo003oo`00o`Oooooo2Ol00?l/oooooaGoo`001_ooool7ool000?o
oooo1?oo000:ooooo`Goo`001_ooool00ooo003o003oo`00o`04o`00o`Kooooo3Ol00?lGooooo`7o
00000Oooool00003o`000?oooooooooo00;ooooo1Ol00?l2ooooo`Go003o1_ooool8o`00o`gooooo
3_oo00000oooooooo`00ool00003ool000Gooooo1Ooo000<ooooo`Goo`003oooool5ool000Go003o
1_ooool9o`00ob_ooooo2Ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`00
1oooool5ool000;ooooo1ooo000:ooooo`Goo`001_ooool00ooo003o003oo`00o`05o`00o`Gooooo
3Ol00?l:ooooo`?o003o2_ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go003o0ooo
ool3o`00o`Oooooo2?l00?l=ooooo`goo`000_ooool5ool000Gooooo1Ooo0003ooooo`?oo`001ooo
ool5ool000;ooooo0ooo0009ooooo`Goo`001Ol00?l6ooooo`Wo003o:oooool9ool000Oooooo1Ooo
0007ooooo`Goo`0000?oooooool00?oo00001ooo0003ooooo`?oo`000oooool5ool000Kooooo00?o
o`00o`00ool00?l01Ol00?l6ooooo`?o003o0_ooool7o`00o`Wooooo1Ol00?l9ooooo`7o00000Ooo
ool00003o`000?oooooooooo00;ooooo1Ol00?l2ooooo`Go003o1oooool7o`00o`gooooo3Ooo0003
ooooo`Soo`0000?oooooool00?oo00001?oo00000oooooooo`00ool00004ool000Gooooo1Ooo0000
0oooooooo`00ool00003ool000Wooooo1?oo0005o`00o`Oooooo0ol00?l01?oooooo003oo`00ool0
0?lZooooo`?o003o1ooo0008ooooo`Ooo`001_ooool3ool000;ooooo4?oo0003ooooo`?oo`002?oo
ool00ooo003o003oo`00o`04o`00o`kooooo0ol00?l:ooooo`Go003o2Oooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooo`?o003o0oooool5o`00o`Wooooo1Ol00?l=ooooo`Goo`0000?ooooo
ool00?oo00001?oo0006ooooo`Ooo`0000?oooooool00?oo00002ooo0004ooooo`Goo`0000?ooooo
ool00?oo00000ooo000:ooooo`Coo`000ol00?lDooooo`?o003o2?ooool3o`00oaKooooo1Ol00?l2
ool000_ooooo2Ooo000:oooooa3oo`004Oooool3o`00oaCooooo0ol00?l5ooooo`Go003o2Oooool1
o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o0_ooool3o`00o`Cooooo1Ol00?l<oooo
o`Ooo`0000Coooooool00?oo003oo`002?ooool7ool000;ooooo3?oo0004ooooo`_oo`002oooool3
ool001Kooooo1Ol00?l6ooooo`Go003o5?ooool6o`00o`?ooooo0ooo0007ooooo`[oo`002_ooool?
ool002Oooooo1Ol00?l5ooooo`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0:oooo
o`[o003o1?ooool3o`00o`gooooo1ooo0006ooooo`?oo`000_ooool8ool000;ooooo3?oo0004oooo
o`Koo`0000Coooooool00?oo003oo`009Oooool5o`00o`Kooooo1Ol00?lDooooo`Ko003o0_ooool5
ool00004oooooooo003oo`00ool000;ooooo2ooo0007oooooa3oo`002_ooool3ool001_ooooo1Ol0
0?l5ooooo`Go003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`Wo003o5?ooool7
ool000Gooooo3Ooo0004ooooo`?oo`000_ooool6ool000Cooooo1_oo000>ooooo`?oo`002Oooool3
o`00o`cooooo1Ol00?l6ooooo`Go003o5?ooool5o`00o`;ooooo2ooo0002ooooo`?oo`0000?ooooo
ool00?oo00001?oo0006ooooo`Soo`000_ooool3ool000gooooo1Ooo000Jooooo`So003o0_ooool5
o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool9o`00oa7ooooo0ol00?l00ooo
ooooo`00ool00003ool000Kooooo2_oo000=ooooo`Koo`001?ooool4ool000Kooooo0ooo0005oooo
o`Goo`001oooool5o`00o`cooooo0ol00?l8ooooo`?o003o4_ooool3o`00o`04ooooool00?oo003o
o`00o`;ooooo3?oo0002ooooo`?oo`000_ooool6ool000Gooooo1ooo000Cooooo`Goo`006oooool8
o`00o`;ooooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo2?l00?lAoooo
o`Go003o2?ooool=ool000gooooo1_oo000=ooooo`Goo`001?ooool5ool000Oooooo1Ol00?lSoooo
o`?o003o1Oooool6o`00o`Cooooo3?oo00000oooooooo`00ool00003ool000;ooooo1_oo0004oooo
o`Soo`004_ooool5ool000Kooooo0ol00?lBooooo`So003o2_ooool3o`00o`7ooooo0Ol00001oooo
o`0000?o0000ooooooooool03?ooool3o`00o`Sooooo0ol00?l:ooooo`Go003o1oooool=ool000Oo
oooo0ooo0005ooooo`Goo`003Oooool5ool000Cooooo1Ooo0003o`00o`Cooooo1Ol00?lGooooo`?o
003o2?ooool5o`00o`Cooooo1ol00?l3ooooo`Ooo`0000?oooooool00?oo00002?oo0002ooooo`Ko
o`001Oooool8ool000Kooooo0ooo00001?ooooooo`00ool00?oo0005ooooo`?oo`001_ooool5o`00
oa;ooooo1ol00?l9ooooo`Go003o0Ol00001ooooo`0000?o0000ooooooooool05_ooool6o`00o`03
ooooool00?oo003o00?o003o0_ooool5o`00o`Oooooo1Ooo0002ooooo`Goo`001oooool5ool000Go
oooo0ooo000>ooooo`Goo`001Oooool3ool000Go003o1?ooool3o`00oaOooooo1Ol00?l7ooooo`Go
003o1?ooool7o`00o`Cooooo1Ooo0002oooooa;oo`001oooool8ool000?ooooo2Ooo000=ooooo`Oo
003o4oooool3o`00o`[ooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o
00Coooooo`00ool00?oo003o2_ooool=o`00o`;ooooo0ol00?l8ooooo`Goo`000_ooool5ool000Oo
oooo1Ooo0008ooooo`?oo`000_ooool3ool000?ooooo1ooo0003ooooo`?oo`000oooool5o`00oako
oooo1Ol00?l7ooooo`Go003o1Oooool6o`00o`_ooooo1Ooo00000oooooooo`00ool0000;ool000Ko
oooo2Ooo0002ooooo`Woo`003Oooool8o`00oaoooooo1Ol00?l1o`00007ooooo00000ol0003ooooo
ooooo`04ooooo`Wo003o2Oooool=o`00o`kooooo0ooo0003ooooo`Goo`001oooool5ool000Oooooo
2_oo00000oooooooo`00ool00006ool000;ooooo1Ooo0002ooooo`Go003o7_ooool5o`00o`Sooooo
0ol00?l8ooooo`?o003o2oooool5ool000;ooooo3Ooo0005ooooo`[oo`000_ooool9ool000kooooo
1ol00?lDooooo`?o003o2Oooool3o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool01?oo
ool9o`00o`[ooooo3?l00?lCooooo`Goo`002Oooool3ool000Oooooo2ooo00000oooooooo`00ool0
0006ool000;ooooo1Ooo0003ooooo`?o003o5?ooool3o`00o`Wooooo1Ol00?lPooooo`_oo`000_oo
ool7ool000Gooooo2_oo0003ooooo`?oo`0000Coooooool00?oo003oo`003_ooool8o`00oa?ooooo
1Ol00?l<ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo2Ol00?l:ooooo`co003o2?oo
ool5ool000Kooooo1Ooo0009ooooo`?oo`001oooool;ool00003oooooooo003oo`0000Goo`000ooo
ool5ool001Wooooo1Ol00?l7ooooo`Oo003o2_ooool3o`00o`gooooo0ooo0002ooooo`Woo`001?oo
ool6ool000Gooooo2_oo000Hooooo`So003o5?ooool5o`00o`cooooo0Ol00001ooooo`0000?o0000
ooooooooool01Oooool3o`00o`04ooooool00?oo003oo`00o`_ooooo1_l00?l00ooooooo003oo`00
o`03o`00o`Gooooo2Ooo0005ooooo`Goo`001Oooool8ool000Gooooo2ooo00000oooooooo`00ool0
0005ool000Gooooo0ooo000Jooooo`Go003o1_ooool8o`00o`Wooooo1Ol00?l;ooooo`Goo`000_oo
ool8ool000?ooooo1Ooo0006ooooo`Woo`005?ooool3ool000?ooooo1Ol00?lGooooo`Go003o3?oo
ool1o`00007ooooo00000ol0003oooooooooo`0Gooooo`Ko003o00?oooooo`00ool00?l00ol00?l2
ooooo`?o003o2Ooo0006ooooo`?oo`001Oooool9ool000Cooooo1_oo00001?ooooooo`00ool00?oo
0002ooooo`Soo`004oooool3o`00o`cooooo1Ol00?l6ooooo`Wo003o2?ooool5o`00o`_ooooo1Ooo
0005ooooo`Goo`000oooool5ool00004oooooooo003oo`00ool000;ooooo2Ooo000>ooooo`?oo`00
0_ooool5ool000;ooooo1Ol00?lHooooo`?o003o3Oooool1o`00007ooooo00000ol0003ooooooooo
o`0Hooooo`Go003o0_ooool3o`00o`;ooooo1Ol00?l8ool000kooooo4_oo0007ooooo`Soo`004_oo
ool5o`00o`cooooo0ol00?l7ooooo`[o003o1oooool5o`00o`_ooooo1Ooo0006ooooo`?oo`001?oo
ool:ool00003oooooooo003oo`0000Koo`003_ooool5ool00003oooooooo003oo`0000Coo`001Ol0
0?lRooooo`?o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`0Iooooo`?o003o2?ooool5
o`00o`[oo`003?oooolBool000?ooooo0ooo00000oooooooo`00ool00005ool001?ooooo1Ol00?lG
ooooo`Wo003o2?ooool3o`00o`gooooo0ooo000?ooooo`?oo`0000?oooooool00?oo00000ooo0002
ooooo`Goo`004?ooool;ool000Ko003o8Oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool06?ooool5o`00o`Oooooo1Ol00?l3ool000?ooooo1Ooo000<ooooo`?oo`0000?oooooool0
0?oo00002_oo0003ooooo`Goo`0000Coooooool00?oo003oo`005_ooool5o`00oaSooooo2?l00?lJ
ooooo`?oo`004Oooool5ool001Oooooo2ooo0007o`00ob3ooooo1Ol00?l3ooooo`7o00000Oooool0
0003o`000?oooooooooo01Sooooo1Ol00?l8ooooo`Ko003o1?ooool5ool0013ooooo2Ooo0006oooo
o`Goo`000oooool3ool001Gooooo0ol00?lIooooo`Oo003o6?ooool7ool0013ooooo1?oo0006oooo
o`?oo`004?ooool:ool000So003o7oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool06?ooool8o`00o`Oooooo1Ol00?l3ooooo`Goo`004?ooool8ool000Oooooo1Ooo0002ooooo`Wo
o`000_ooool3ool002;ooooo0ol00?l3ooooo`?o003o3?ooool3o`00o`_ooooo2?oo0006ooooo`?o
o`001_ooool5ool000Gooooo1Ooo000Aooooo`Ooo`000_ooool7o`00ob3ooooo0ol00?l4ooooo`7o
00000Oooool00003o`000?oooooooooo01Wooooo2?l00?l6ooooo`Go003o1?ooool3ool001;ooooo
1Ooo0007ooooo`Ooo`000_ooool?ool000Oooooo0ol00?lFooooo`Go003o00Coooooo`00ool00?oo
003o3?ooool5o`00o`[ooooo2?oo0005ooooo`Goo`001Oooool5ool000Gooooo1Ooo000Aooooo`So
o`000oooool5o`00o`Sooooo0ol00?lLooooo`7o00000Oooool00003o`000?oooooooooo01cooooo
1Ol00?l6ooooo`Go003o3?ooool3ool000[ooooo1Ooo0006ooooo`Soo`000_ooool?ool000Kooooo
1Ol00?lEooooo`[o003o2oooool5o`00o`[ooooo2?oo0004ooooo`Koo`001Oooool5ool000Gooooo
1Ooo000Aooooo`Soo`000_ooool5o`00o`Sooooo1Ol00?lKooooo`7o00000Oooool00003o`000?oo
oooooooo01cooooo1Ol00?l7ooooo`?o003o3?ooool7ool000Oooooo1Ooo0004ooooo`[oo`000ooo
ool>ool000Kooooo1Ol00?l3ooooo`?o003o3oooool;o`00o`[ooooo1Ol00?l;ooooo`Ooo`000ooo
ool7ool000;ooooo0ooo00000oooooooo`00ool00005ool000?ooooo0ooo000Cooooo`Ooo`0000?o
ooooo`00ool00?l01?l00?l8ooooo`Go003o00Coooooo`00ool00?oo003o5oooool1o`00007ooooo
00000ol0003oooooooooo`0Mooooo`?o003o00Coooooo`00ool00?oo003o3oooool3ool00003oooo
oooo003oo`0000Woo`001?ooool3ool000Cooooo2_oo0007ooooo`[oo`001oooool5o`00o`;ooooo
1Ol00?l?ooooo`?o003o00?oooooo`00ool00?l01?l00?l;ooooo`?o003o2Oooool3ool000?ooooo
0ooo0004ooooo`Koo`000_ooool=ool001_ooooo0ooo00000oooooooo`00o`00o`08o`00o`Gooooo
2_l00?lFooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo0ol00?l9ooooo`Go003o3Ooo
oolBool000Wooooo1ooo000<ooooo`Woo`001oooool3o`00o`?ooooo1_l00?l7ooooo`?o003o2?oo
ool6o`00oaKooooo1Ooo0009ooooo`Goo`000_ooool>ool001Gooooo0ooo0002ooooo`Koo`002_l0
0?l5ooooo`?o003o00?oooooo`00ool00?l00ol00?l3ooooo`Ko003o3Oooool1o`00007ooooo0000
0ol0003oooooooooo`0Cooooo`Go003o2?ooool5o`00o`gooooo1Ooo00000oooooooo`00ool0000;
ool000Oooooo1_oo000>ooooo`[oo`003?ooool7o`00o`Gooooo1Ol00?l7ooooo`Go003o5oooool5
ool000Wooooo1Ooo0002ooooo`koo`002?ooool6ool000Kooooo1Ooo00000oooooooo`00ool00005
ool000Wo003o2Oooool5o`00o`;ooooo2?l00?l01?oooooo003oo`00ool00?l8ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Sooooo0ol00?l8ooooo`Go003o2?ooool5o`00o`gooooo1Ooo0004
ooooo`[oo`001oooool5ool000Kooooo0ooo0007ooooo`Woo`003Oooool6o`00o`Gooooo1Ol00?l7
ooooo`Go003o5oooool5ool000[ooooo0ooo0003ooooo`Goo`000_ooool6ool000Sooooo2?oo0005
ooooo`Goo`0000?oooooool00?oo00001Ooo0009o`00o`[ooooo0ol00?l2ooooo`ko003o1oooool1
o`00007ooooo00000ol0003oooooooooo`07ooooo`Go003o1_ooool6o`00o`Sooooo1Ol00?l>oooo
o`?oo`002Oooool6ool000Oooooo1Ooo0005ooooo`Goo`002?ooool7ool000kooooo1Ol00?l5oooo
o`Go003o2?ooool3o`00o`Kooooo0ol00?l7ooooo`?o003o1Oooool7ool000oooooo0ooo000?oooo
o`[oo`001Oooool5ool000;ooooo1_oo0008o`00o`oooooo3ol00?l7ooooo`7o00000Oooool00003
o`000?oooooooooo00Oooooo1Ol00?l6ooooo`Go003o2Oooool5o`00oaWooooo1_oo0009ooooo`Go
o`001?ooool5ool000Wooooo1ooo000>ooooo`?o003o1oooool3o`00oa7ooooo1Ol00?l5ooooo`Go
003o0oooool9ool00004oooooooo003oo`00ool001Wooooo3Ooo0006ooooo`?oo`001oooool3ool0
00?o003o4oooool?o`00o`Oooooo0Ol00001ooooo`0000?o0000ooooooooool01oooool5o`00o`Ko
oooo1Ol00?l9ooooo`Wo003o5Oooool5ool000[ooooo1Ooo0002ooooo`Ooo`002Oooool7ool002co
oooo1Ol00?l2ooooo`So003o0oooool>ool001Oooooo3Ooo00001?ooooooo`00ool00?oo000Voooo
o`Go003o0oooool6o`00o`?ooooo0ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Oo
oooo1Ol00?l7ooooo`Co003o2_ooool9o`00o`gooooo0ooo0004ooooo`Goo`001Oooool3ool000;o
oooo1Ooo00000oooooooo`00ool00005ool000_ooooo1_oo000Sooooo`?o003o1_ooool5o`00o`03
ooooool00?oo003o00Oo003o0_ooool?ool001Gooooo2_oo0005ooooo`Goo`004oooool3o`00o`Co
oooo0ol00?l9ooooo`?o003o1?ooool5o`00o`?ooooo1Ol00?l1ooooo`7o00000Oooool00004o`00
0?ooooooooooooooo`?o003o0_ooool6o`00o`Oooooo1Ol00?l<ooooo`Ko003o1_ooool3ool000?o
oooo1Ooo0004ooooo`?oo`001Oooool5ool000;ooooo0ooo0002ooooo`Goo`003Oooool5ool000;o
oooo1?oo000Eooooo`Go003o0oooool5o`00o`Kooooo0ol00?l2ooooo`So003o0oooool5ool00003
oooooooo003oo`0000Woo`004_ooool:ool000Kooooo1Ooo00001?ooooooo`00ool00?oo000>oooo
o`Go003o0_ooool5o`00o`Cooooo0ol00?l8ooooo`Go003o0oooool5o`00o`7ooooo0Ol00001oooo
o`0000?o0000ooooooooool02ol00?l7ooooo`So003o2_ooool6o`00o`Gooooo1Ooo00000ooooooo
o`00ool00004ool000cooooo1Ooo0004ooooo`Soo`003?ooool5ool000;ooooo1_oo000Cooooo`Oo
003o0_ooool5o`00o`_ooooo1Ol00?l6ooooo`Goo`001?ooool9ool00004oooooooo003oo`00ool0
00cooooo2?oo00001?ooooooo`00ool00?oo0004ooooo`_oo`003Oooool5o`00o`;ooooo1Ol00?l3
ooooo`Go003o2?ooool3o`00o`Cooooo1Ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo
00[o003o1oooool=o`00o`Oooooo1?l00?l6ooooo`Goo`0000?oooooool00?oo00001?oo000<oooo
o`Goo`000oooool8ool000gooooo1Ooo0002ooooo`Koo`004oooool7o`00o`;ooooo1Ol00?l<oooo
o`?o003o2?ooool3ool000Gooooo3_oo0008ooooo`Woo`000_ooool5ool000?ooooo1Ooo00000ooo
ooooo`00ool00003ool000gooooo1Ol00?l2ooooo`Go003o0oooool5o`00oa3ooooo0ol00?l2oooo
o`7o00000Oooool00003o`000?oooooooooo00[o003o1oooool>o`00oa3ooooo1Ooo00000ooooooo
o`00ool00007ool000[ooooo0ooo0003ooooo`Koo`004?ooool5ool000;ooooo1_oo000Cooooo`Oo
003o0_ooool5o`00oaoooooo3_oo0007ooooo`Woo`000ooooolCool000kooooo0ol00?l4ooooo`?o
003o1?ooool5o`00oaGooooo0Ol00001ooooo`0000?o0000ooooool00?l01?l00?l2ooooo`?o003o
2?ooool>o`00oa7ooooo0ooo0003ooooo`Woo`003_ooool7ool00004oooooooo003oo`00ool000co
oooo1Ooo0003ooooo`Ooo`004_ooool5o`00o`Cooooo0ol00?lOooooo`ooo`001oooool9ool000?o
oooo4_oo000Nooooo`Ko003o4oooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`kooooo
0ol00?l2ooooo`Wo003o3oooool3ool000Gooooo2?oo000>ooooo`Koo`0000?oooooool00?oo0000
0ooo000;ooooo`Goo`001_ooool5ool003_ooooo3ooo0008ooooo`[oo`000oooool8ool00003oooo
oooo003oo`0000Koo`006_ooool3o`00o`?ooooo1Ol00?lBooooo`7o00000Oooool00003o`000?oo
oooo003o00Co003o5oooool6o`00o`gooooo1Ooo0007ooooo`Goo`003_ooool5ool000;ooooo1Ooo
0008ooooo`Soo`001_ooool5ool001[ooooo0ol00?lLooooo`koo`003?ooool3ool00003oooooooo
003oo`0000?oo`001_ooool5ool00003oooooooo003oo`0000Woo`005_ooool5o`00o`;ooooo1Ol0
0?lBooooo`7o00000Oooool00003o`000?oooooooooo00?o003o1_ooool3o`00oa3ooooo1Ol00?l=
ooooo`Goo`002?ooool3ool000oooooo1?oo0003ooooo`Goo`0000Coooooool00?oo003oo`000ooo
ool8ool000Oooooo1Ooo000Iooooo`Go003o2_ooool3o`00o`Cooooo1?oo0005ooooo`ooo`001ooo
ool3ool000Kooooo1Ooo0007ooooo`?oo`000oooool;ool001Gooooo1Ol00?l2ooooo`Go003o4_oo
ool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Go003o1Oooool3o`00o`Oooooo1Ol00?l8
ooooo`?o003o0_ooool5ool000Sooooo0ooo000>ooooo`Goo`001?ooool3ool00003oooooooo003o
o`0000?oo`000_ooool5ool000_ooooo0ooo0002ooooo`?oo`000_ooool3o`00oa3ooooo1Ol00?l9
ooooo`Go003o0_ooool6ool000Cooooo3_oo0004ooooo`Soo`001Oooool5ool000[ooooo0ooo0000
0oooooooo`00ool00008ool001Gooooo1Ol00?l3ooooo`?o003o4oooool1o`00007ooooo00000ol0
003oooooooooo`08ooooo`Go003o1?ooool5o`00o`Oooooo0ol00?l8ooooo`Go003o0_ooool3ool0
00Sooooo1Ooo0005ooooo`?oo`001Oooool5ool000Sooooo1Ooo0002ooooo`Goo`003?ooool8ool0
00Go003o3oooool5o`00o`Wooooo1Ol00?l2ooooo`Koo`001?ooool=ool000Cooooo2Ooo0006oooo
o`?oo`002_ooool?ool000oooooo0ol00?l4ooooo`?o003o5Oooool3o`00o`;ooooo0Ol00001oooo
o`0000Co0000oooooooooooooooo0ol00?l4ooooo`Go003o1?ooool5o`00oa;ooooo1Ol00?l=oooo
o`Goo`000oooool6ool000;ooooo1ooo0008ooooo`Goo`000oooool3ool000cooooo2Ooo0005o`00
o`Sooooo0ol00?l5ooooo`?o003o2_ooool5o`00o`;ooooo1_oo0005ooooo`[oo`001_ooool9ool0
01;ooooo2_oo0002ooooo`?oo`003oooool5o`00oa[ooooo1Ol00?l1ooooo`7o00000Oooool00003
o`000?oooooooooo00Go003o1?ooool5o`00o`?ooooo1Ol00?l?ooooo`So003o1?ooool3ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000ooo0002ooooo`ooo`002?ooool5ool000_o
oooo0ooo0005ooooo`Woo`001Ol00?l7ooooo`Go003o4_ooool3o`00o`Cooooo1?oo0005ooooo`?o
o`0000?oooooool00?oo00001?oo00001?ooooooo`00ool00?oo0003ooooo`Woo`004Oooool;ool0
01Cooooo1Ol00?lJooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`Go
oooo1Ol00?l3ooooo`?o003o3_ooool9o`00o`Cooooo3ooo0002ooooo`goo`002_ooool6ool000;o
oooo0ooo0004ooooo`Goo`001?ooool:ool000?o003o0_oo0006ooooo`Go003o8Oooool@ool000?o
oooo0ooo00001?ooooooo`00ool00?oo000Booooo`Koo`0000Coooooool00?oo003oo`000oooool3
ool000gooooo1ol00?l8ooooo`?o003o3oooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000oooo
ooooool01_l00?l4ooooo`Go003o4oooool7o`00o`Oooooo3ooo0002ooooo`goo`001?ooool3ool0
00?ooooo3?oo0003ooooo`Goo`001Oooool3ool000Cooooo2?oo0005ooooo`Go003o8Oooool5ool0
0003oooooooo003oo`0000Soo`003?ooool6ool000;ooooo0ooo0005ooooo`Goo`001Oooool7ool0
00_ooooo1ol00?l8ooooo`Go003o0_ooool5o`00o`Sooooo0ol00?l2ooooo`7o00000Oooool00004
o`000?ooooooooooooooo`Ko003o0oooool5o`00oa?ooooo1ol00?l7ooooo`ooo`000oooool;ool0
00Cooooo1Ooo0003ooooo`_oo`000oooool5ool000;ooooo1Ooo0006ooooo`Ooo`001_ooool3o`00
o`oooooo0ooo000@ooooo`Goo`000_ooool3ool00003oooooooo003oo`0000Coo`002_ooool=ool0
00Cooooo1Ooo0004ooooo`Soo`002oooool6o`00o`Wooooo1Ol00?l00ooooooo003oo`00o`05o`00
o`cooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool5o`00o`Cooooo0ol00?lDooooo`So
003o1OoooolAool000Gooooo1_oo0006ooooo`Goo`0000?oooooool00?oo00002ooo0004ooooo`?o
o`000_ooool7ool000Oooooo1Ooo000Gooooo`Goo`000oooool3ool000?ooooo0ooo0004ooooo`?o
o`002?ooool6ool000Wooooo3Ooo0005ooooo`?oo`001?ooool9ool000_ooooo1_l00?l9ooooo`Go
003o00?oooooo`00ool00?l01Ol00?l<ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo
1_l00?lEooooo`?o003o0oooool7o`00o`Cooooo1ooo0002ooooo`Woo`001Oooool5ool000Kooooo
3_oo0002ooooo`?oo`002_ooool7ool00004oooooooo003oo`00ool000?ooooo1Ooo000Gooooo`Go
o`000_ooool5ool00003oooooooo003oo`0000?oo`003oooool6ool000Sooooo3Ooo0002ooooo`?o
o`001oooool8ool000gooooo1?l00?l;ooooo`?o003o0_ooool7o`00o`cooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool6o`00o`[ooooo0ol00?l6ooooo`Go003o00?oooooo`00ool00?l0
1_l00?l4ooooo`Koo`000oooool9ool000Kooooo0ooo0006ooooo`ooo`003?ooool?ool000;ooooo
1Ooo000:ooooo`?oo`002_ooool5ool000;ooooo1Ooo00000oooooooo`00ool00006ool000cooooo
2Ooo0006ooooo`Koo`000_ooool3ool000;ooooo1Ooo0006ooooo`Ooo`008oooool5o`00o`gooooo
0Ol00001ooooo`0000?o0000ooooooooool01?ooool5o`00o`Wooooo1Ol00?l5ooooo`go003o1Ooo
ool7ool000?ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`?oo`002_ooool@ool000[ooooo
4Ooo0003ooooo`?oo`002_ooool5ool000[ooooo1Ooo00000oooooooo`00ool00003ool00003oooo
oooo003oo`0000Ooo`003?ooool9ool000Kooooo0ooo0009ooooo`Goo`001oooool5ool000Wooooo
0ol00?lHooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Go003o2Ooo
ool5o`00o`Gooooo2_l00?l9ooooo`Ooo`002?ooool7ool000Oooooo2Ooo0002ooooo`[oo`001_oo
ool7ool00003oooooooo003oo`0000Soo`004?ooool5ool000?ooooo1_oo00000oooooooo`00ool0
0003ool00003oooooooo003oo`0000Coo`0000?oooooool00?oo00001_oo000=ooooo`Woo`000_oo
ool7ool000Sooooo1Ooo0008ooooo`?oo`0000?oooooool00?l00?l00_l00?l4ooooo`Go003o5ooo
ool5o`00o`Gooooo0ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0ol00?l:
ooooo`Go003o1_ooool;o`00o`Wooooo1_oo0006ooooo`_oo`000oooool;ool000?ooooo2Ooo0005
ooooo`Ooo`000_ooool8ool0017ooooo1Ooo0002ooooo`goo`0000?oooooool00?oo00001?oo0002
ooooo`Ooo`004?ooool?ool000Wooooo0ooo0004ooooo`?oo`001Oooool00ooo003o003oo`00o`03
o`00o`?ooooo1Ol00?lGooooo`Go003o1?ooool5o`00o`Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool04oooool5o`00o`Sooooo2Ol00?l8ooooo`Ooo`001Oooool<ool000;ooooo3_oo00000ooo
ooooo`00ool00006ool000Gooooo1_oo0004ooooo`?oo`005_ooool3ool000?ooooo3?oo00000ooo
ooooo`00ool00005ool00003oooooooo003oo`0000Koo`004Oooool>ool000Sooooo0ooo0003oooo
o`Koo`001?ooool00ooo003o003oo`00o`03o`00o`?ooooo1Ol00?lGooooo`Go003o1?ooool5o`00
o`Cooooo0Ol00001ooooo`0000Co0000oooooooooooooooo0ol00?l?ooooo`Go003o2?ooool9o`00
o`Sooooo1ooo0005ooooo`coo`0000?oooooool00?oo00001Ooo00000oooooooo`00ool00006ool0
00?ooooo1Ooo0006ooooo`?oo`001Oooool3ool001Oooooo0ooo0003ooooo`coo`0000?oooooool0
0?oo00001?oo0002ooooo`Ooo`004oooool<ool000Sooooo1Ooo00000oooooooo`00ool00005ool0
00Cooooo00?oo`00o`00ool00?l00ol00?l4ooooo`?o003o6?ooool5o`00o`Cooooo1Ol00?l4oooo
o`7o00000Oooool00003o`000?oooooooooo00Go003o3_ooool5o`00o`Wooooo2?l00?l8ooooo`Oo
o`000_ooool3ool00003oooooooo003oo`0000;oo`0000?oooooool00?oo00002_oo0003ooooo`So
o`001?ooool3ool000Gooooo0ooo0006ooooo`Goo`005Oooool5ool000?ooooo2ooo00000ooooooo
o`00ool00003ool000?ooooo1Ooo000?ooooo`Coo`000oooool3ool000;ooooo1?oo000:ooooo`Go
o`0000?oooooool00?oo00001_oo0004ooooo`04ool00?l00?oo003oo`00oa[ooooo0ol00?l3oooo
o`Go003o1Oooool3o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l?ooooo`Go
003o2_ooool5o`00o`[ooooo1Ooo0002ooooo`Goo`000_ooool8ool00003oooooooo003oo`0000?o
o`001Oooool7ool000?ooooo1Ooo0003ooooo`Goo`001Oooool5ool001Gooooo1Ooo0003ooooo`Go
o`0000?oooooool00?oo00000ooo0002ooooo`?oo`001Oooool3ool000Wooooo0ooo0003ooooo`Ko
o`005Oooool5ool00003oooooooo003oo`0000Ooo`001?ooool3o`00oaWooooo1Ol00?l2ooooo`Go
003o1_ooool3o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l@ooooo`Go003o
2Oooool5o`00o`cooooo0ooo0002ooooo`koo`000_ooool5ool000Cooooo1ooo0004ooooo`Koo`00
0_ooool5ool00005oooooooo003oo`00ool00?ooool01Ooo000Eooooo`Goo`001?ooool3ool000?o
oooo0ooo000=ooooo`?oo`001_ooool5ool000;ooooo1_oo0008ooooo`?oo`002oooool3ool000?o
oooo2_oo00000ooooooo003oo`00o`03o`00oaSooooo1Ol00?l2ooooo`Oo003o0oooool5o`00o`?o
oooo0Ol00001ooooo`0000Co0000oooooooooooooooo0ol00?lAooooo`Go003o2Oooool5o`00o`_o
oooo4Ooo0006ooooo`?oo`000oooool7ool000Kooooo1ooo00000oooooooo`00ool00008ool00004
oooooooo003oo`00ool001Oooooo0ooo000Hooooo`Ooo`001Oooool5ool000;ooooo1_oo0007oooo
o`Goo`004oooool8ool000Go003o0oooool3o`00oa;ooooo1Ol00?l2ooooo`So003o0_ooool5o`00
o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool5o`00o`[ooooo1_l00?l9oooooa7o
o`002oooool8ool000Oooooo1_oo0002ooooo`?oo`0000?oooooool00?oo00000ooo000Yooooo`?o
o`002Oooool8ool000;ooooo2Ooo0002ooooo`Goo`001oooool5ool00004oooooooo003oo`00ool0
00?ooooo0ooo0006ooooo`?oo`0000?oooooool00?oo00001?oo0006o`00o`;ooooo1Ol00?lBoooo
o`Ko003o00?oooooo`00ool00?l01Ol00?l2ooooo`Go003o0oooool1o`00007ooooo00000ol0003o
ooooooooo`09ooooo`?o003o2_ooool3o`00o`gooooo1Ol00?l7ooooo`?o003o1Ooo00000ooooooo
o`00ool00006ool000cooooo1ooo0002ooooo`?oo`001?ooool5ool000Kooooo1Ooo0009ooooo`?o
o`007?ooool5ool000Sooooo2?oo00000oooooooo`00ool00008ool000?ooooo1Ooo0006ooooo`[o
o`0000?oooooool00?oo00000ooo0002ooooo`Ooo`000_ooool4ool000Go003o0oooool5o`00oaCo
oooo1Ol00?l2ooooo`Go003o00?oooooo`00ool00?l00ol00?l4ooooo`7o00000Oooool00003o`00
0?oooooooooo00Sooooo1Ol00?lIooooo`Go003o1_ooool5o`00o`Coo`0000?oooooool00?oo0000
1?oo000=ooooo`Koo`000oooool5ool000?ooooo1ooo0005ooooo`?oo`002Oooool5ool000Oooooo
0ooo0005ooooo`?oo`002Oooool5ool00004oooooooo003oo`00ool000Cooooo1ooo0002ooooo`[o
o`000_ooool6ool000Oooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?o
o`0000?oooooool00?oo00001_oo0003ooooo`?oo`001Ol00?l2ooooo`Ko003o5?ooool5o`00o`?o
oooo0ol00?l2ooooo`Go003o1?ooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`Go003o
0_ooool3o`00oa7ooooo2?l00?l6ooooo`Go003o0ooo00000oooooooo`00ool00004ool000gooooo
1_oo0004ooooo`Goo`0000?oooooool00?oo00002?oo000@ooooo`Goo`001_ooool5ool000?ooooo
1Ooo0008ooooo`[oo`001?ooool3ool000Gooooo2Ooo0003ooooo`Koo`002oooool;ool00003oooo
oooo003oo`0000Koo`000oooool3o`00o`04ooooool00?oo003oo`00o`;ooooo1_l00?l6ooooo`?o
003o1_ooool3o`00o`?ooooo1Ol00?l8ooooo`Go003o1?ooool1o`00007ooooo00000ol0003ooooo
ooooo`08ooooo`Go003o00?oooooo`00ool00?l00ol00?l;ooooo`?o003o00?oooooo`00ool00?l0
1_l00?l01?oooooo003oo`00ool00?l3ooooo`Go003o0oooool5ool000_ooooo0ooo00000ooooooo
o`00ool00004ool000Cooooo4?oo000@ooooo`Soo`000oooool=ool000Wooooo0ooo00000ooooooo
o`00ool00003ool000Oooooo0ooo0003ooooo`Goo`001_ooool5ool000gooooo2Ooo0002ooooo`Oo
o`000oooool5o`00o`Gooooo1Ol00?l6ooooo`Go003o1?ooool5o`00o`?ooooo0ol00?l:ooooo`?o
003o1Oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`?o003o0_ooool5o`00o`Sooooo
3?l00?l3ooooo`Go003o0oooool3o`00o`Cooooo1Ooo000:ooooo`_oo`001Oooool3ool00003oooo
oooo003oo`0000Woo`003_ooool;ool000;ooooo3Ooo0006ooooo`?oo`001?ooool5ool000Kooooo
2ooo0006ooooo`Goo`0000Coooooool00?oo003oo`003?ooool5ool000Gooooo1_oo0003ooooo`Go
003o0_ooool8o`00o`Cooooo1ol00?l4ooooo`Go003o6?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0=ooooo`Ko003o1oooool>o`00o`;ooooo1_l00?l9ooooo`Goo`001?ooool3ool000?ooooo
1Ooo00000oooooooo`00ool00003ool000Wooooo2_oo000>ooooo`Goo`000_ooool5ool000?ooooo
3?oo0005ooooo`Goo`001?ooool3ool000Oooooo2Ooo0008ooooo`[oo`001Oooool3ool000?ooooo
1Ooo0006ooooo`Goo`000oooool5o`00o`03ooooool00?oo003o00Oo003o0oooool8o`00o`Cooooo
1Ol00?l9ooooo`?o003o00Coooooo`00ool00?oo003o1?ooool3o`00o`7ooooo0Ol00001ooooo`00
00?o0000ooooooooool03?ooool6o`00o`Sooooo2?l00?l00ooooooo003oo`00o`03o`00o`;ooooo
1ol00?l9ooooo`?oo`001?ooool5ool000;ooooo1Ooo0002ooooo`?oo`002oooool6ool00004oooo
oooo003oo`00ool000gooooo1Ooo0002ooooo`Goo`001?ooool;ool00005oooooooo003oo`00ool0
0?ooool01Ooo0007ooooo`?oo`0000?oooooool00?oo00002_oo0008ooooo`_oo`000oooool5ool0
00?ooooo0ooo0008ooooo`?oo`001Oooool>o`00o`?ooooo1ol00?l6ooooo`?o003o2Oooool9o`00
o`;ooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`0<ooooo`Go003o2Oooool7o`00o`;o
oooo1Ol00?l3ooooo`Ko003o4?ooool5ool000?ooooo0ooo000Gooooo`Goo`003?ooool5ool000?o
oooo0ooo0008oooooa;oo`001_oooolBool000Oooooo2ooo0003ooooo`Goo`002?ooool3ool000co
oooo3Ol00?l3ooooo`Ko003o4oooool:o`00o`03ooooool00?oo003o00?o003o0Ol00001ooooo`00
00?o0000ooooooooool03?ooool5o`00o`[ooooo0ol00?l6ooooo`?o003o1Oooool5o`00o`;ooooo
0ol00?l5ooooo`?oo`000_ooool7ool000?ooooo0ooo000Fooooo`Goo`000oooool3ool000Oooooo
0ooo0008ooooo`?oo`001Oooool<ool00004oooooooo003oo`00ool000Oooooo4_oo0007ooooo`Go
o`0000?oooooool00?oo00000ooo0003ooooo`Goo`000oooool3ool00003oooooooo003oo`0000?o
o`002oooool8o`00o`04ooooool00?oo003oo`00o`Gooooo1?l00?lDooooo`[o003o00?oooooo`00
ool00?l00ol00?l1o`00007ooooo00000ol0003oooooooooo`0=ooooo`?o003o2_ooool3o`00oa3o
oooo0ol00?l2ooooo`Go003o0oooool5ool00003oooooooo003oo`0000Goo`000_ooool5ool000oo
oooo0ooo00000oooooooo`00ool00005ool000;ooooo1Ooo000@ooooo`Goo`000oooool7ool00003
oooooooo003oo`0000?oo`002ooooolBool000Oooooo1Ooo0002ooooo`Coo`001?ooool5ool00003
oooooooo003oo`0000Soo`002oooool5o`00oaWooooo0ol00?l9ooooo`?o003o00?oooooo`00ool0
0?l00ol00?l2ooooo`?o003o0Oooool1o`00007ooooo00000ol0003oooooo`00o`02o`00o`Wooooo
0ol00?l;ooooo`Go003o5?ooool5o`00o`?ooooo1Ooo00000oooooooo`00ool00005ool000;ooooo
1Ooo0008ooooo`?oo`000oooool;ool000;ooooo2Ooo000=ooooo`Goo`000oooool5ool000Cooooo
1Ooo000;ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`08ool000Gooooo0ooo00001?oooooo
o`00ool00?oo0003ooooo`Goo`001?ooool?ool000cooooo0ol00?lBooooo`?o003o1?ooool5o`00
o`Oooooo1Ol00?l01?oooooo003oo`00ool00?l7ooooo`7o00000Oooool00003o`000?l00?oo003o
00?o003o1oooool5o`00o`[ooooo1Ol00?lDooooo`Go003o0oooool5ool00003oooooooo003oo`00
00Koo`0000?oooooool00?oo00000ooo0002ooooo`?oo`000_ooool5ool000;ooooo2Ooo0003oooo
o`_oo`003?ooool5ool000?ooooo1Ooo0005ooooo`Goo`004Oooool8ool000Gooooo1Ooo0006oooo
o`Goo`001?oooolAool000gooooo0ol00?l=ooooo`Ko003o0oooool5o`00o`Gooooo1ol00?l;oooo
o`7o00000Oooool00003o`000?l00?oo003o00?o003o1oooool6o`00o`Wooooo1Ol00?lEooooo`?o
003o1Oooool3ool000?ooooo2?oo00001?ooooooo`00ool00?oo0002ooooo`Goo`0000?oooooool0
0?oo00001?oo00000oooooooo`00ool00007ool000?ooooo2ooo000=ooooo`?oo`001Oooool3ool0
00Kooooo1_oo000@ooooo`Woo`001?ooool8ool000?ooooo1Ooo0004ooooo`coo`0000?oooooool0
0?oo00000ooo000;ooooo`Go003o1Oooool3o`00o`?ooooo1ol00?l3ooooo`Go003o1?ooool8o`00
o`_ooooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l7ooooo`Oo003o1oooool5o`00o`?o
oooo0ol00?lQooooo`Goo`001_ooool5ool00003oooooooo003oo`0000Woo`0000Coooooool00?oo
003oo`001?ooool=ool001cooooo1ooo000?ooooo`[oo`0000?oooooool00?oo00002Ooo0003oooo
o`?oo`0000Coooooool00?oo003oo`000_ooool;ool00003oooooooo003oo`0000?oo`002_ooool6
o`00o`Cooooo1Ol00?l2ooooo`Oo003o1?ooool3o`00o`Gooooo1ol00?l<ooooo`7o00000Oooool0
0003o`000?oooooo003o00;o003o2?ooool7o`00o`;ooooo0ol00?l2ooooo`Go003o0_ooool5o`00
ob3ooooo1ooo0004ooooo`Goo`000_ooool<ool000Oooooo1Ooo00000oooooooo`00ool00005ool0
00Kooooo0ooo000Aooooo`Soo`004?oooolEool000Kooooo1Ooo0002ooooo`Woo`000_ooool5ool0
00[ooooo1_l00?l4ooooo`Go003o0_ooool6o`00o`gooooo1Ol00?l>ooooo`7o00000Oooool00003
o`000?oooooooooo00[ooooo1ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00?o
003o0_ooool5o`00ob7ooooo1ooo0004ooooo`?oo`000_oooolAool000?ooooo1Ooo0003ooooo`Oo
o`000_ooool6ool000_ooooo0ooo00000oooooooo`00ool00007ool00004oooooooo003oo`00ool0
013ooooo4Ooo0003ooooo`Soo`001Oooool5ool000Cooooo0ooo0008ooooo`So003o1Oooool5o`00
o`?ooooo0ol00?l?ooooo`Go003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0;ooooo`Go
003o0_ooool5o`00o`;ooooo0ol00?l00ooooooo003oo`00o`06o`00o`Wooooo0ol00?lFooooo`Go
o`002?oooolCool000?ooooo0ooo0003oooooa3oo`002_ooool=ool00003oooooooo003oo`0000?o
o`004?ooool?ool000?ooooo3?oo0002ooooo`Goo`003_ooool8o`00o`Oooooo0ol00?lFooooo`Go
003o3_ooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`?o003o1oooool5o`00o`Gooooo
2_l00?l7ooooo`Go003o5Oooool5ool000Sooooo1Ooo0002ooooo`coo`002Oooool@ool000Kooooo
0ooo00000oooooooo`00ool0000:ool000;ooooo1Ooo000Aooooo`_oo`0000Coooooool00?oo003o
o`000_ooool=ool000;ooooo0ooo000?ooooo`Go003o4?ooool3o`00oa3ooooo1Ol00?l>ooooo`7o
00000Oooool00003o`000?oooooooooo00Oooooo1Ol00?l7ooooo`?o003o1_ooool:o`00o`Oooooo
1Ol00?l5ooooo`?o003o3_ooool5ool000Oooooo1Ooo0005ooooo`Woo`002OoooolBool000?ooooo
2_oo00000oooooooo`00ool0000;ool000Cooooo0ooo000:ooooo`[oo`0000?oooooool00?oo0000
0ooo00000oooooooo`00ool0000;ool001Cooooo1Ol00?l?ooooo`Go003o00Coooooo`00ool00?oo
003o2?ooool3o`00o`04ooooool00?oo003oo`00o`oooooo0Ol00001ooooo`0000?o0000oooooooo
ool01oooool5o`00oa3ooooo2_l00?l7ooooo`Go003o1?ooool5o`00o`Gooooo0ol00?l01Ooooooo
o`00ool00?oo003ooooo00Goo`002?ooool3ool000Kooooo2_oo0009ooooo`Ooo`0000?oooooool0
0?oo00002?oo0002ooooo`Woo`000oooool;ool000Cooooo1Ooo0009ooooo`[oo`0000?oooooool0
0?oo00000ooo0002ooooo`goo`001_ooool3o`00o`_ooooo0ol00?l7ooooo`?o003o1_ooool:o`00
o`Kooooo1Ol00?l;ooooo`?o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`Go
003o4Oooool3o`00o`;ooooo0ol00?l9ooooo`?o003o1Oooool5o`00o`Cooooo1Ol00?l:ool0013o
oooo2_oo000;ooooo`Goo`0000?oooooool00?oo00004ooo0003ooooo`Woo`001_ooool5ool000[o
oooo0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000?oo`001_ooool:ool000;o
oooo0_oo0005o`00oa?ooooo1Ol00?l5ooooo`[o003o00Coooooo`00ool00?oo003o0_ooool5o`00
o`[ooooo1Ol00?l3ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo0ol00?l[ooooo`Go
003o1?ooool5o`00o`Coo`0000?oooooool00?oo00001?oo000:oooooaCoo`001oooool3ool000?o
oooo0ooo00000oooooooo`00ool0000>ool000?ooooo2Ooo0006ooooo`Goo`003_ooool5ool000;o
oooo0ooo0007ooooo`koo`001Ol00?lCooooo`Go003o1_ooool3o`00o`03ooooool00?oo003o00ko
003o1Oooool3o`00o`;ooooo1Ol00?l3ooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo
0ol00?l5ooooo`Go003o1?oo0002ooooo`Goo`002OoooolFool000Oooooo0ooo0007ooooo`Soo`00
0oooool3ool000Gooooo0ooo00001?ooooooo`00ool00?oo0008ooooo`?oo`004?ooool3ool000Ko
oooo0ooo0005ooooo`goo`001ol00?l?ooooo`Oo003o2oooool>o`00o`Gooooo1Ol00?l00ooooooo
003oo`00o`03o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool3o`00oacooooo
0ol00?l8ooooo`Go003o1Oooool3o`00o`04oooooooo003oo`00ool000?ooooo1Ooo0008ooooo`oo
o`0000?oooooool00?oo00001Ooo0006ooooo`Goo`002Oooool6ool000Oooooo1ooo000:ooooo`Go
o`005oooool5ool000Cooooo3_oo0007o`00o`gooooo2Ol00?l6ooooo`?o003o0oooool<o`00o`Go
oooo1Ol00?l2ooooo`?o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o
0oooool5o`00oa[ooooo1Ol00?l7ooooo`Go003o1_ooool3o`00o`Kooooo1Ooo0007ooooo`_oo`00
00?oooooool00?oo00002_oo0006ooooo`Goo`002_ooool5ool000Kooooo2?oo000:ooooo`Goo`00
2?ooool3ool000cooooo1Ooo0003ooooo`ooo`000_ooool5o`00o`04ooooool00?oo003oo`00o`Wo
oooo2Ol00?l5ooooo`Go003o0_ooool<o`00o`Gooooo1Ol00?l9ooooo`7o00000Oooool00003o`00
0?oooooooooo00Cooooo3?l00?lJooooo`Go003o1oooool5o`00o`Gooooo1Ol00?l5ooooo`Koo`00
1_ooool7ool000Kooooo2_oo0007ooooo`Ooo`002?ooool5ool000Kooooo2?oo000:ooooo`Goo`00
1oooool5ool000_ooooo1Ooo0003ooooo`_oo`001_ooool:o`00o`Sooooo2Ol00?l5ooooo`Go003o
0_ooool<o`00o`Kooooo0ol00?l:ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo3?l0
0?lJooooo`Go003o2?ooool3o`00o`Kooooo1Ol00?l5ooooo`Soo`001?ooool6ool000Oooooo1ooo
000;ooooo`Ooo`002?ooool3ool000Oooooo1ooo000<ooooo`?oo`002?ooool5ool000Oooooo0ooo
0002ooooo`?oo`001?ooool8ool000?o003o1oooool3o`00o`03ooooool00?oo003o00?o003o2Ooo
ool7o`00o`Kooooo1Ol00?l3ooooo`[o003o5?ooool1o`00007ooooo00000ol0003oooooooooo`04
ooooo`_o003o7?ooool3o`00oa;ooooo1Ol00?l6ooooo`Soo`001?ooool5ool000Oooooo1ooo000;
ooooo`Ooo`004_ooool4ool000[ooooo0ooo000=oooooa3oo`001oooool5ool000;ooooo00?oo`00
o`00ool00?l00ol00?l:ooooo`Go003o2_ooool6o`00o`Oooooo0ol00?l5ooooo`Ko003o5oooool1
o`00007ooooo00000ol0003oooooooooo`05ooooo`Oo003o6Oooool3o`00o`cooooo0ol00?l:oooo
o`?o003o2?ooool7ool000Gooooo0ooo0009ooooo`Ooo`002oooool6ool0017ooooo1Ooo0009oooo
o`Goo`003Oooool?ool000Oooooo1Ooo0003ooooo`So003o2?ooool3o`00o`_ooooo1_l00?l>oooo
o`Oo003o1_ooool3o`00o`kooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00oaWo
oooo1Ol00?l:ooooo`Go003o5Oooool6ool00004oooooooo003oo`00ool000[ooooo2_oo000=oooo
o`?oo`004_ooool6ool000Sooooo1Ooo000;oooooaCoo`001?ooool5ool000?ooooo2Ol00?lEoooo
o`Ko003o3_ooool6o`00o`Kooooo1Ol00?l=ooooo`7o00000Oooool00003o`000?oooooooooo00Ko
oooo1Ol00?lIooooo`Go003o2_ooool5o`00oaOooooo0ooo00000oooooooo`00ool00003ool000Oo
oooo3?oo0002ooooo`?oo`002_ooool3ool0013ooooo1ooo00001?ooooooo`00ool00?oo0003oooo
o`Goo`002_oooolFool000Cooooo0ooo0005ooooo`So003o5_ooool4o`00o`oooooo1Ol00?l7oooo
o`Ko003o3?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`Go003o6Oooool5o`00o`[o
oooo1Ol00?lKooooo`Goo`001Oooool=ool000;ooooo1Ooo0008ooooo`Goo`0000?oooooool00?oo
00000_oo000;ooooo`_oo`000oooool3ool000_ooooo3Ooo0004ooooo`Goo`000oooool5ool000Ko
oooo1_l00?lZooooo`?o003o1oooool7o`00o`;ooooo0ol00?l7ooooo`7o00000Oooool00003o`00
0?oooooooooo00Oooooo0ol00?l4ooooo`?o003o5?ooool3o`00o`?ooooo1?l00?l5ooooo`?o003o
7?ooool8ool00003oooooooo003oo`0000[oo`001?ooool5ool000Sooooo2ooo0008ooooo`goo`00
4Oooool:ool000Oooooo1Ooo0002ooooo`Ooo`001?ooool6o`00obSooooo0ol00?l:ooooo`Oo003o
00?oooooo`00ool00?l00ol00?l6ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo0ol0
0?l5ooooo`Go003o3?ooool3o`00o`?ooooo0ol00?l3ooooo`Ko003o9?oooolCool000Cooooo1_oo
0008ooooo`_oo`000_ooool3ool000;ooooo3_oo000Booooo`Woo`002?ooool3ool000?ooooo1ooo
0004ooooo`Go003o:?ooool5o`00o`Wooooo1_l00?l2ooooo`Go003o1_ooool1o`00007ooooo0000
0ol0003oooooo`00o`02o`00o`;ooooo1Ol00?l4ooooo`Go003o2oooool5o`00o`03ooooool00?oo
003o00?o003o0_ooool6o`00ob?ooooo0ol00?l00oooooooo`00ool00009ool000;ooooo0ooo0003
ooooo`Koo`002?ooool<ool00003oooooooo003oo`0000goo`0000Coooooool00?oo003oo`004ooo
ool9ool000Kooooo0ooo0005ooooo`Ooo`001?ooool5o`00obGooooo2?l00?l:ooooo`?o003o1?oo
ool5o`00o`;ooooo0ol00?l1ooooo`7o00000Oooool00003o`000?l00?oo003o00?o003o00?ooooo
o`00ool00?l00ol00?l4ooooo`Go003o2oooool5o`00o`03ooooool00?oo003o00?o003o0_ooool7
o`00ob7ooooo1Ol00?l;ool00003oooooooo003oo`0000?oo`000_ooool8ool000Kooooo2ooo0002
ooooo`ooo`006?ooool7ool000Kooooo1Ooo0005ooooo`Goo`001_ooool3o`00obGooooo2Ol00?l>
ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool5o`00o`7o00000Oooool00003o`000?l00?oo
003o00?o003o00?oooooo`00ool00?l00ol00?l5ooooo`?o003o2?ooool3o`00o`03ooooool00?oo
003o00Wo003o0oooool9o`00oakooooo1Ol00?l00oooooooo`00ool00008ool00003oooooooo003o
o`0000?oo`000_ooool9ool000Gooooo2?oo0005ooooo`koo`007?ooool3ool000?ooooo0ooo0000
0oooooooo`00ool00003ool001kooooo0ol00?lGooooo`So003o3_ooool5o`00o`Gooooo1Ol00?l1
o`00007ooooo00000ol0003o003oo`00o`03o`00o`;ooooo0ol00?l@ooooo`Go003o00?oooooo`00
ool00?l01ol00?l6ooooo`So003o3Oooool3o`00o`gooooo1Ol00?l00oooooooo`00ool00008ool0
0003oooooooo003oo`0000?oo`000oooool9ool000Gooooo1ooo0006ooooo`?oo`000_ooool6ool0
01gooooo1Ooo00000oooooooo`00ool00008ool001Sooooo0ol00?l2ooooo`Go003o3oooool3o`00
o`Cooooo1_l00?l@ooooo`Go003o1Oooool5o`00o`7o00000Oooool00003o`000?oooooo003o00;o
003o0_ooool5o`00o`oooooo1Ol00?l00ooooooo003oo`00o`07o`00o`Kooooo2?l00?l<ooooo`Go
003o3?ooool5o`00o`03oooooooo003o003o00;o003o1Ooo0003ooooo`?oo`001oooool6ool000;o
oooo0ooo0002ooooo`Goo`003Oooool3ool001kooooo1Ooo00000oooooooo`00ool00003ool00004
oooooooo003oo`00ool001Cooooo0ol00?l00ooooooo003oo`00o`09o`00o`kooooo1Ol00?l4oooo
o`Go003o4?ooool5o`00o`Kooooo0ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00Co
oooo1Ol00?l?ooooo`Go003o00?oooooo`00ool00?l01_l00?l8ooooo`Oo003o3?ooool5o`00o`co
oooo1Ol00?l00ooooooo003oo`00o`03o`00oa;ooooo1Ooo00000oooooooo`00ool00003ool000;o
oooo0ooo000_ooooo`Goo`0000?oooooool00?oo00000ooo000Goooooa3o003o3_ooool5o`00o`Co
oooo1Ol00?l?ooooo`Oo003o2Oooool1o`00007ooooo00001?l0003o003oo`00ool00?l3ooooo`Ko
003o2_ooool3o`00o`;ooooo0ol00?l2ooooo`Go003o2oooool6o`00o`Wooooo0ol00?l00ooooooo
003oo`00o`03o`00o`gooooo0ol00?l2ooooo`Go003o4oooool3ool000;ooooo1Ooo000>ooooo`?o
o`004?ooool3ool000Kooooo0ooo0008ooooo`Goo`0000Coooooool00?oo003oo`006?ooool?o`00
o`oooooo1Ol00?l4ooooo`Go003o1Oooool3o`00o`Oooooo2?l00?l8ooooo`7o00000Oooool000Go
003o0oooool5o`00o`Wooooo1Ol00?l6ooooo`Go003o1oooool3o`00o`03ooooool00?oo003o00?o
003o2Oooool5o`00o`04ooooool00?oo003oo`00oa?ooooo1Ol00?lHooooo`Goo`003Oooool5ool0
00kooooo1ooo0002ooooo`Goo`001oooool6ool001?ooooo0ol00?l5ooooo`Go003o00?oooooo`00
ool00?l01_l00?lAooooo`Go003o0oooool5o`00o`Cooooo1Ol00?l6ooooo`So003o2?ooool1o`00
007ooooo0005o`00o`?ooooo1Ol00?l9ooooo`Go003o1_ooool5o`00o`Kooooo2_l00?l7ooooo`Oo
003o5?ooool3o`00o`04ooooool00?oo003oo`00o`;ooooo0ol00?l7ooooo`?oo`002oooool3ool0
00kooooo1Ooo000<ooooo`[oo`0000?oooooool00?oo00000ooo0003ooooo`[oo`004_ooool5o`00
o`Gooooo0ol00?l5ooooo`Go003o4Oooool5o`00o`?ooooo1Ol00?l4ooooo`Go003o1oooool7o`00
o`Sooooo0Ol00001ooooo`001Ol00?l4ooooo`?o003o2_ooool5o`00o`Oooooo0ol00?l7ooooo`Go
003o00Coooooo`00ool00?oo003o1oooool8o`00oa?ooooo1Ol00?l4ooooo`Go003o1Oooool5ool0
00gooooo0ooo000;ooooo`Goo`002oooool;ool00003oooooooo003oo`00013oo`001oooool6o`00
o`Gooooo1Ol00?l=ooooo`Go003o4Oooool5o`00o`Cooooo0ol00?l5ooooo`Go003o2Oooool5o`00
o`Sooooo0Ol00001ooooo`0000Co0000o`00ool00?oo003o4_ooool4o`00oa;ooooo1Ol00?l;oooo
o`Oo003o5?ooool5o`00o`Cooooo1Ol00?l4ooooo`Koo`003?ooool5ool000_ooooo0ooo000<oooo
o`_oo`000_ooool@ool000Oooooo2?l00?l4ooooo`Go003o3Oooool5o`00oa;ooooo0ol00?l>oooo
o`?o003o2oooool3o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool5o`00oa?o
oooo0ol00?l<ooooo`Ko003o5Oooool5o`00o`Cooooo1Ol00?l3ooooo`Ooo`001_ooool3ool000?o
oooo1Ooo000Jooooo`[oo`000_ooool?ool000Wooooo2?l00?l5ooooo`?o003o3oooool5o`00occo
oooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool5o`00o`Wooooo0ol00?lGooooo`Co003o
5oooool3o`00o`Kooooo1_l00?l00oooooooo`00ool00004ool000Kooooo1Ooo0002ooooo`Koo`00
6_ooool7ool000Cooooo3_oo000:ooooo`So003o5oooool5o`00occooooo0Ol00001ooooo`0000?o
0000ooooooooool04_ooool5o`00o`04ooooool00?oo003oo`00o`Cooooo1Ol00?l01?oooooo003o
o`00ool00?lgooooo`Ko003o1Ooo0007ooooo`Goo`000oooool6ool001Gooooo0ooo0003ooooo`Go
o`001?ooool8ool0017ooooo1_l00?lHooooo`Go003o??ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Booooo`[o003o0oooool:o`00ocKooooo2Ol00?l00ooo003oooooooooo`06ooooo`Goo`00
1?ooool5ool001Cooooo1Ooo0002ooooo`Goo`001Oooool7ool0033ooooo0ol00?lmooooo`7o0000
0Oooool00003o`000?oooooooooo01;ooooo2_l00?l3ooooo`[o003o=_ooool:o`00o`Wooooo0ooo
0005ooooo`Soo`000_ooool3ool000_ooooo1ooo0002ooooo`?oo`002?ooool5ool0023ooooo0ol0
0?llooooo`?o003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`[o003o1?ooool3
o`00o`03ooooool00?oo003o00?o003o7?ooool4o`00oaOooooo2Ol00?lBooooo`goo`002Oooool8
ool000kooooo0ol00?l?ooooo`?o003o3_ooool5o`00oaGooooo0ol00?lRooooo`Go003o3Oooool1
o`00007ooooo00000ol0003oooooooooo`0Booooo`_o003o0_ooool3o`00o`?ooooo0ol00?lLoooo
o`Ko003o6_ooool5o`00oaGooooo2_oo0008ooooo`Woo`003Oooool5o`00o`gooooo1Ol00?l=oooo
o`Go003o2?ooool3o`00o`Wooooo1Ol00?l2ooooo`Ko003o6Oooool5o`00o`Cooooo0ol00?l6oooo
o`7o00000Oooool00003o`000?oooooooooo01?ooooo2_l00?l00ooooooo003oo`00o`03o`00o`Co
oooo0ol00?lJooooo`Oo003o6_ooool3o`00o`Oooooo0ol00?l4ooooo`?o003o1Oooool:ool000So
oooo2?oo000>ooooo`Go003o3Oooool5o`00o`gooooo1Ol00?l7ooooo`Go003o2?ooool5o`00o`03
ooooool00?oo003o00Oo003o2_ooool3o`00o`[ooooo1Ol00?l3ooooo`Go003o1Oooool1o`00007o
oooo00000ol0003oooooooooo`05ooooo`?o003o2Oooool6o`00o`03ooooool00?oo003o00Wo003o
0oooool5o`00o`?ooooo0ol00?l8ooooo`?o003o2?ooool8o`00oacooooo0ol00?l3ooooo`Go003o
0_ooool5o`00o`Gooooo0ooo0002ooooo`?oo`002Oooool5ool0017ooooo1Ol00?l=ooooo`Go003o
3Oooool4o`00o`Sooooo1Ol00?l8ooooo`Go003o00?oooooo`00ool00?l02?l00?l8ooooo`So003o
1oooool3o`00o`Cooooo1Ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1Ol0
0?l7ooooo`Go003o1?ooool3o`00o`03ooooool00?oo003o00Co003o0oooool5o`00o`;ooooo1Ol0
0?l6ooooo`Go003o1oooool8o`00oa_ooooo3?l00?l2ooooo`Ko003o4_ooool3o`00o`04oooooooo
003oo`00ool001?ooooo0ol00?l?ooooo`?o003o3Oooool7o`00o`Kooooo1Ol00?l9ooooo`?o003o
0_ooool:o`00o`Sooooo2Ol00?l=ooooo`Go003o1Oooool1o`00007ooooo00000ol0003ooooooooo
o`04ooooo`Go003o1oooool5o`00o`Sooooo1Ol00?l4ooooo`Go003o0_ooool5o`00o`Kooooo1Ol0
0?l7ooooo`So003o6oooool<o`00o`;ooooo1ol00?l@ooooo`Go003o>?ooool8o`00o`Kooooo0ol0
0?l@ooooo`Wo003o2?ooool9o`00o`kooooo0ol00?l2ooooo`?o003o0Oooool1o`00007ooooo0000
0ol0003oooooooooo`04ooooo`Go003o1oooool6o`00o`?ooooo0ol00?l2ooooo`?o003o1Oooool4
o`00o`?ooooo1Ol00?l6ooooo`Go003o1oooool7o`00oacooooo2ol00?l4ooooo`Ko003o1_ooool3
o`00o`Oooooo1Ol00?l]ooooo`?o003o2?ooool8o`00oakooooo1Ol00?l8ooooo`[o003o4?ooool5
o`00o`7o00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?l9ooooo`Go003o0_ooool7o`00
o`Kooooo1Ol00?l4ooooo`?o003o2?ooool3o`00o`Wooooo0ol00?lPooooo`So003o1oooool5o`00
o`Gooooo1Ol00?l6ooooo`Ko003o1oooool4o`00o`;ooooo0ol00?lKooooo`Go003o2?ooool7o`00
oakooooo1Ol00?l<ooooo`Oo003o3oooool5o`00o`7o00000Oooool00003o`000?oooooooooo00;o
oooo1Ol00?l:ooooo`Go003o0_ooool8o`00o`Gooooo1Ol00?l6ooooo`?o003o7?ooool3o`00oa?o
oooo1Ol00?l2ooooo`?o003o2Oooool3o`00o`Kooooo1Ol00?l7ooooo`Ko003o1Oooool;o`00oa[o
oooo1Ol00?l:ooooo`Go003o7_ooool5o`00o`kooooo1Ol00?l?ooooo`Go003o0Ol00001ooooo`00
00?o0000ooooooooool00_ooool7o`00o`Wooooo0ol00?l3ooooo`So003o0oooool7o`00o`Gooooo
1Ol00?lDooooo`?o003o0oooool6o`00o`[ooooo0ol00?l3ooooo`Oo003o0_ooool3o`00o`gooooo
0ol00?l00ooooooo003oo`00o`03o`00o`Sooooo1_l00?l4ooooo`_o003o6_ooool5o`00o`[ooooo
1Ol00?l6ooooo`?o003o5_ooool3o`00o`oooooo1Ol00?l@ooooo`?o003o0Oooool1o`00007ooooo
00000ol0003oooooooooo`02ooooo`So003o3oooool7o`00o`;ooooo1ol00?l2ooooo`?o003o00?o
ooooo`00ool00?l00ol00?lCooooo`ko003o2?ooool5o`00o`;ooooo1ol00?l00ooooooo003oo`00
o`03o`00o`_ooooo1Ol00?l01?oooooo003oo`00ool00?l9ooooo`Oo003o0oooool;o`00oa_ooooo
0ol00?l<ooooo`?o003o1_ooool5o`00o`?ooooo0ol00?lRooooo`?o003o4Oooool3o`00o`7ooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool7o`00oa;ooooo0ol00?l3ooooo`Go003o0ooo
ool:o`00oa?ooooo3_l00?l8ooooo`Go003o0_ooool7o`00o`03ooooool00?oo003o00?o003o2ooo
ool5o`00o`kooooo1ol00?l3ooooo`Co003o0_ooool3o`00o`;ooooo0ol00?l5ooooo`?o003o9ooo
ool5o`00o`;ooooo1_l00?l^ooooo`?o003o0_ooool5o`00o`7o00000Oooool00003o`000?oooooo
oooo00Gooooo1Ol00?lAooooo`?o003o1?ooool5o`00o`?ooooo2Ol00?lDooooo`ko003o2?ooool5
o`00o`?ooooo1Ol00?l2ooooo`Go003o2oooool5o`00o`oooooo1_l00?l=ooooo`Go003o0oooool5
o`00o`Sooooo0ol00?l9ooooo`?o003o3oooool5o`00o`;ooooo1ol00?l/ooooo`Go003o00?ooooo
o`00ool00?l00ol00?l1o`00007ooooo00000ol0003oooooooooo`02ooooo`So003o4?ooool5o`00
o`03ooooool00?oo003o00Co003o1?ooool9o`00oaGooooo3?l00?l:ooooo`?o003o3?ooool3o`00
o`gooooo0ol00?l:ooooo`?o003o1?ooool5o`00o`gooooo1Ol00?l3ooooo`Go003o1oooool5o`00
o`Oooooo1Ol00?l4ooooo`?o003o0_ooool3o`00o`?ooooo0ol00?l3ooooo`Oo003o;?ooool5o`00
o`03ooooool00?oo003o00?o003o0Ol00001ooooo`0000Co0000oooooooooooooooo2?l00?lAoooo
o`[o003o1oooool8o`00oaSooooo2Ol00?leooooo`Go003o1?ooool3o`00o`kooooo3Ol00?l7oooo
o`Go003o1oooool7o`00o`03ooooool00?oo003o00So003o2Oooool6o`00o`;ooooo0ol00?l=oooo
o`?o003o3Oooool3o`00o`Oooooo1Ol00?l2ooooo`?o003o0Oooool1o`00007ooooo00001?l0003o
ooooooooooooool5o`00oaCooooo2_l00?l8ooooo`Oo003o6Oooool7o`00ocKooooo1Ol00?l5oooo
o`?o003o3_ooool;o`00o`Sooooo1Ol00?l7oooooa;o003o2oooool3o`00o`;ooooo1Ol00?l;oooo
o`Go003o2oooool5o`00o`Oooooo0ol00?l7ooooo`7o00000Oooool00003o`000?oooooo003o00Ko
003o5Oooool3o`00o`03ooooool00?oo003o00?o003o2Oooool5o`00oa[ooooo1Ol00?l/ooooo`?o
003o1Oooool3o`00o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l00ol00?l>ooooo`[o
003o2Oooool3o`00o`Wooooo4Ol00?l?ooooo`Ko003o2oooool5o`00o`_ooooo1Ol00?l01?oooooo
003oo`00ool00?l=ooooo`7o00000Oooool00003o`000?l00?oo003o00Go003o1?ooool3o`00o`go
oooo0ol00?l4ooooo`Co003o4?ooool3o`00oaGooooo1Ol00?l[ooooo`Go003o0oooool5o`00o`03
ooooool00?oo003o00_o003o3_ooool;o`00oaKooooo1Ol00?l01?oooooo003oo`00ool00?l2oooo
o`?o003o4?ooool6o`00o`_ooooo1Ol00?l;ooooo`[o003o3?ooool1o`00007ooooo00000ol0003o
003oo`00o`03o`00o`Gooooo1Ol00?l;ooooo`Go003o0oooool5o`00o`kooooo1ol00?l2ooooo`?o
003o3Oooool5o`00ob_ooooo1Ol00?l2ooooo`Ko003o1?ooool:o`00o`Sooooo0ol00?l3ooooo`_o
003o5oooool3o`00oa[ooooo1Ol00?l=ooooo`Go003o2oooool3o`00o`03ooooool00?oo003o00?o
003o3?ooool1o`00007ooooo00000ol0003o003oo`00o`03o`00o`Gooooo1Ol00?l;ooooo`Go003o
0oooool5o`00o`kooooo3Ol00?l:ooooo`Oo003o3_ooool3o`00oa[ooooo1Ol00?l00ooooooo003o
o`00o`05o`00o`Cooooo1Ol00?l01?oooooo003oo`00ool00?l8ooooo`Go003o0oooool:o`00o`?o
oooo0ol00?l3ooooo`Co003o5oooool3o`00o`;ooooo0ol00?l9ooooo`?o003o3_ooool5o`00o`oo
oooo1Ol00?l<ooooo`7o00000Oooool00003o`000?oooooo003o00;o003o1_ooool6o`00o`[ooooo
1Ol00?l3ooooo`Go003o3_ooool=o`00o`Wooooo2?l00?l=ooooo`Go003o4?ooool3o`00o`Oooooo
0ol00?l2ooooo`Ko003o1_ooool3o`00o`gooooo1Ol00?l5ooooo`Oo003o0oooool5o`00o`03oooo
ool00?oo003o00Co003o2oooool3o`00o`Oooooo2_l00?lIooooo`Go003o4?ooool3o`00o`Wooooo
0ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo1Ol00?l7ooooo`?o003o00Co
ooooo`00ool00?oo003o1Oooool3o`00o`kooooo3_l00?l9ooooo`Oo003o3_ooool5o`00o`oooooo
1Ol00?l;ooooo`Go003o5?ooool8o`00o`Gooooo1Ol00?l5ooooo`co003o2_ooool5o`00o`Kooooo
2_l00?lJooooo`?o003o4oooool3o`00o`Kooooo1Ol00?l1o`00007ooooo00000ol0003ooooooooo
o`09ooooo`Go003o1_ooool5o`00oaSooooo2Ol00?l2ooooo`?o003o2_ooool5o`00o`Oooooo0ol0
0?l6ooooo`Go003o3oooool5o`00o`;ooooo0ol00?l7ooooo`?o003o5?ooool8o`00o`Kooooo1Ol0
0?l5ooooo`co003o2_ooool5o`00o`Kooooo3?l00?l]ooooo`Go003o1Oooool5o`00o`7o00000Ooo
ool00003o`000?oooooooooo00Wooooo1Ol00?l6ooooo`Go003o2oooool3o`00o`Wooooo1ol00?lC
ooooo`?o003o0oooool3o`00o`03ooooool00?oo003o00?o003o1_ooool3o`00oa3ooooo1Ol00?l0
0ooooooo003oo`00o`03o`00o`Wooooo0ol00?lAooooo`Go003o2_ooool3o`00o`Oooooo2_l00?l9
ooooo`Oo003o1oooool<o`00obcooooo1Ol00?l5ooooo`Go003o0Ol00001ooooo`0000?o0000oooo
ooooool02_ooool3o`00o`Oooooo1Ol00?l:ooooo`Go003o0oooool3o`00o`;ooooo1_l00?lCoooo
o`Go003o00?oooooo`00ool00?l02?l00?lJooooo`[o003o2?ooool5o`00oa3ooooo1Ol00?lGoooo
o`Go003o2_ooool7o`00o`Wooooo1Ol00?l00ooooooo003oo`00o`03o`00obcooooo1Ol00?l6oooo
o`?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0Dooooo`Oo003o2?ooool5o`00o`;o
oooo1Ol00?l00ooooooo003oo`00o`03o`00oaCooooo4?l00?lAooooo`?o003o1_ooool;o`00o`Oo
oooo1Ol00?lAooooo`?o003o6Oooool3o`00o`_ooooo1Ol00?l;ooooo`Go003o00?oooooo`00ool0
0?l00ol00?l]ooooo`?o003o2oooool1o`00007ooooo00000ol0003oooooooooo`03o`00o`04oooo
ool00?oo003oo`00o`Sooooo0ol00?l3ooooo`Oo003o1oooool5o`00o`;ooooo1Ol00?l2ooooo`?o
003o5Oooool;o`00o`04ooooool00?oo003oo`00oa7ooooo1Ol00?l5ooooo`Go003o00?oooooo`00
ool00?l00ol00?l7ooooo`Oo003o:_ooool5o`00o`[ooooo1Ol00?l;ooooo`Go003o0_ooool3o`00
oacooooo0ol00?l>ooooo`?o003o3?ooool1o`00007ooooo00000ol0003oooooo`00o`08o`00o`Ko
oooo1ol00?l2ooooo`Go003o2?ooool3o`00o`?ooooo1Ol00?lKooooo`Wo003o5_ooool5o`00o`Ko
oooo0ol00?l2ooooo`Go003o2?ooool7o`00obCooooo0ol00?l00ooooooo003oo`00o`04o`00o`_o
oooo0ol00?l5ooooo`?o003o1Oooool3o`00ob7ooooo1Ol00?l<ooooo`Go003o2oooool1o`00007o
oooo00000ol0003oooooo`00o`08o`00o`Kooooo2?l00?l00ooooooo003oo`00o`05o`00o`cooooo
1Ol00?l<ooooo`?o003o3_ooool5o`00oaSooooo1Ol00?l<ooooo`?o003o2oooool5o`00oaSooooo
0ol00?l8ooooo`_o003o4_ooool5o`00obSooooo1_l00?l;ooooo`Go003o2oooool1o`00007ooooo
00000ol0003oooooo`00o`08o`00o`Kooooo2?l00?l2ooooo`Oo003o3?ooool3o`00o`cooooo1Ol0
0?l>ooooo`?o003o6_ooool3o`00oa7ooooo0ol00?l6ooooo`Ko003o5oooool5o`00o`;ooooo0ol0
0?l2ooooo`[o003o4oooool5o`00oa_ooooo0ol00?l:ooooo`Ko003o2oooool;o`00o`Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool01ol00?l8ooooo`Oo003o1?ooool5o`00o`_ooooo1Ol00?l8
ooooo`So003o?_ooool5o`00o`Cooooo2Ol00?l;ooooo`?o003o1oooool5o`00o`03ooooool00?oo
003o00?o003o00?oooooo`00ool00?l01ol00?lDooooo`Go003o4?ooool3o`00o`Oooooo1Ol00?l:
ooooo`Go003o2oooool<o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l=oooo
o`Ko003o00?oooooo`00ool00?l01?l00?l;ooooo`Ko003o1_ooool9o`00oc?ooooo0ol00?l8oooo
o`Go003o1?ooool:o`00o`Wooooo1Ol00?l6ooooo`_o003o0_ooool7o`00oaKooooo0ol00?l:oooo
o`?o003o00?oooooo`00ool00?l01_l00?l5ooooo`Go003o2oooool3o`00o`cooooo3?l00?l4oooo
o`7o00000Oooool00004o`000?ooooooooooooooo`?o003o4?ooool:o`00o`cooooo1ol00?l5oooo
o`So003o4oooool3o`00oagooooo1Ol00?l7ooooo`Go003o1?ooool:o`00o`Wooooo1Ol00?l7oooo
o`[o003o1?ooool5o`00oakooooo0ol00?l00ooooooo003oo`00o`0<o`00o`Cooooo1Ol00?lKoooo
o`_o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`?o003o2oooool9o`00o`ko
oooo1_l00?l5ooooo`Go003o5Oooool5o`00oacooooo1Ol00?l8ooooo`?o003o1_ooool3o`00o`03
ooooool00?oo003o00?o003o2Oooool5o`00o`Sooooo2?l00?l6ooooo`?o003o3Oooool4o`00o`So
oooo0ol00?l2oooooa?o003o00Goooooo`00ool00?oo003oooooo`03o`00oaOooooo0ol00?l3oooo
o`Wo003o00Koooooo`00ool00?oo003oooooool00001ooooo`0000?o0000ooooooooool01Oooool5
o`00o`[ooooo2Ol00?l2ooooo`?o003o2_ooool5o`00o`Kooooo0ol00?lFooooo`Go003o2_ooool3
o`00o`oooooo1Ol00?lFooooo`?o003o2oooool3o`00o`Wooooo1Ol00?lHooooo`Ko003o1_ooool5
o`00o`03ooooool00?oo003o01Ko003o1Oooool3o`00o`kooooo2?l00?l5ooooo`Go003o00?ooooo
o`00ool00?l00ol00?l1o`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o2_ooool4o`00
o`04ooooool00?oo003oo`00o`;ooooo1Ol00?l:ooooo`?o003o2_ooool3o`00oa7ooooo1ol00?l9
ooooo`Go003o3oooool5o`00o`cooooo0ol00?lQooooo`Co003o6?ooool9o`00o`?ooooo1Ol00?l0
0ooooooo003oo`00o`03o`00o`05ooooool00?oo003oo`00ooooool00ol00?l2ooooo`?o003o00?o
ooooo`00ool00?l00ol00?l4ooooo`Go003o3?ooool9o`00o`Gooooo1Ol00?l00ooooooo003oo`00
o`03o`00o`7o00000Oooool00003o`000?oooooooooo00Gooooo1Ol00?l9ooooo`Go003o1_ooool5
o`00oaKooooo1Ol00?l?ooooo`Oo003o2_ooool5o`00oa3ooooo1Ol00?l:ooooo`Go003o3Oooool3
o`00oa3ooooo1Ol00?lGooooo`[o003o0_ooool5o`00o`;ooooo0ol00?l2ooooo`?o003o2_ooool5
o`00o`Cooooo1Ol00?l<ooooo`Wo003o1_ooool3o`00o`;ooooo1Ol00?l1o`00007ooooo00000ol0
003oooooooooo`05ooooo`Co003o2_ooool5o`00o`Gooooo1_l00?lFooooo`Go003o3oooool5o`00
o`Oooooo0ol00?l2ooooo`Go003o4?ooool5o`00o`;ooooo0ol00?l5ooooo`Go003o3?ooool5o`00
o`oooooo1Ol00?lHooooo`Wo003o0oooool5o`00o`Gooooo1Ol00?l:ooooo`?o003o1Oooool5o`00
o`cooooo2?l00?l=ooooo`?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Oo
003o2_ooool5o`00o`Cooooo1_l00?l01?oooooo003oo`00ool00?lCooooo`Go003o1?ooool3o`00
o`Gooooo2?l00?l6ooooo`Go003o0_ooool5o`00o`Gooooo0ol00?l7ooooo`Go003o00?oooooo`00
ool00?l00ol00?l4ooooo`Go003o1?ooool3o`00o`Gooooo1Ol00?l>ooooo`Ko003o7?ooool=o`00
o`Gooooo1Ol00?lCooooo`?o003o3_ooool6o`00oa;ooooo0Ol00001ooooo`0000Co0000oooooooo
oooooooo2?l00?l;ooooo`?o003o1Oooool5o`00o`03ooooool00?oo003o00?o003o2?ooool3o`00
o`Oooooo1?l00?l4ooooo`Oo003o00?oooooo`00ool00?l01_l00?l7ooooo`Go003o0oooool5o`00
o`?ooooo1Ol00?l5ooooo`Go003o0_ooool5o`00o`Gooooo0ol00?l4ooooo`Go003o1?ooool5o`00
o`kooooo1Ol00?lNooooo`co003o1?ooool6o`00o`Gooooo0ol00?lNooooo`Go003o4Oooool1o`00
007ooooo00000ol0003oooooooooo`09o`00o`?ooooo0ol00?l=ooooo`Go003o00?oooooo`00ool0
0?l00ol00?l7ooooo`Go003o1Oooool5o`00o`Cooooo3Ol00?l8ooooo`Oo003o0oooool5o`00o`?o
oooo1Ol00?l4ooooo`Go003o0oooool5o`00o`cooooo1Ol00?l5ooooo`?o003o3oooool8o`00oako
oooo2?l00?l4ooooo`Ko003o1Oooool5o`00o`?ooooo0ol00?l7ooooo`?o003o3Oooool5o`00o`?o
oooo0ol00?l;ooooo`7o00000Oooool00003o`000?oooooooooo00So003o0oooool5o`00o`Gooooo
1_l00?l2ooooo`?o003o0_ooool5o`00o`?ooooo0ol00?l00ooooooo003oo`00o`03o`00o`Gooooo
1Ol00?l4ooooo`go003o1oooool7o`00o`Cooooo1Ol00?l3ooooo`Go003o1?ooool5o`00o`Cooooo
0ol00?l=ooooo`Go003o5_ooool:o`00oagooooo1Ol00?l7ooooo`Ko003o1Oooool5o`00o`;ooooo
1Ol00?l5ooooo`Go003o3?ooool5o`00o`;ooooo1Ol00?l:ooooo`7o00000Oooool00003o`000?oo
oooooooo00Go003o1_ooool5o`00o`Cooooo2?l00?l7ooooo`?o003o0oooool:o`00o`;ooooo2?l0
0?l5ooooo`Oo003o00?oooooo`00ool00?l01?l00?l4ooooo`Ko003o1oooool3o`00o`Gooooo0ol0
0?l5ooooo`Go003o5Oooool3o`00oaOooooo2_l00?lNooooo`?o003o1?ooool3o`00o`03ooooool0
0?oo003o00Co003o1Oooool5o`00o`;ooooo1Ol00?l5ooooo`Go003o3Oooool3o`00o`03ooooool0
0?oo003o00Go003o2_ooool1o`00007ooooo00001?l0003oooooooooooooool3o`00o`Oooooo1Ol0
0?l3ooooo`Wo003o3Oooool5o`00o`04ooooool00?oo003oo`00o`;ooooo2?l00?l9ooooo`?o003o
1?ooool5o`00o`;ooooo1ol00?lHooooo`?o003o<?ooool:o`00obCooooo1Ol00?l00ooooooo003o
o`00o`03o`00o`Kooooo0ol00?l3ooooo`Go003o1Oooool5o`00oa3ooooo2?l00?l:ooooo`7o0000
0Oooool00003o`000?oooooooooo00Go003o1oooool3o`00o`?ooooo2_l00?l=ooooo`Go003o1_oo
ool5o`00oa?ooooo1Ol00?l2ooooo`Ko003oCOooool3o`00o`;ooooo0ol00?lUooooo`Go003o0_oo
ool3o`00o`kooooo0ol00?l7ooooo`?o003o4Oooool8o`00o`[ooooo0Ol00001ooooo`0000?o0000
ooooooooool01Ol00?l=ooooo`Wo003o3oooool3o`00o`Oooooo1Ol00?lCooooo`Go003o0_ooool5
o`00og_ooooo1Ol00?laooooo`Oo003o2oooool1o`00007ooooo00000ol0003oooooooooo`05o`00
o`gooooo1Ol00?lNooooo`?o003o5Oooool3o`00o`Cooooo0ol00?mmooooo`?o003o<oooool3o`00
o`kooooo0Ol00001ooooo`001?l00003o`00o`oo00000ol00?ooo`0000Oo00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment: red class, full covariances", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes full covariance matrices", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data1, k];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.30000000000000027`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.01923 .63104 m
.02236 .63462 L
.03846 .65291 L
.03929 .65385 L
.0562 .67308 L
.05769 .67479 L
.07281 .69231 L
.07692 .69716 L
.0889 .71154 L
.09615 .72047 L
.10435 .73077 L
.11538 .74503 L
.11916 .75 L
.13338 .76923 L
.13462 .77094 L
.14715 .78846 L
.15385 .798 L
.16061 .80769 L
.17308 .82569 L
.17393 .82692 L
.18732 .84615 L
.19231 .85325 L
.20095 .86538 L
.21154 .87996 L
.21499 .88462 L
.22967 .90385 L
.23077 .90525 L
.24519 .92308 L
.25 .92881 L
.26177 .94231 L
.26923 .95051 L
.2797 .96154 L
.28846 .97036 L
.29931 .98077 L
.01923 .98077 L
F
.01923 .63104 m
.02236 .63462 L
.03846 .65291 L
.03929 .65385 L
.0562 .67308 L
.05769 .67479 L
.07281 .69231 L
.07692 .69716 L
.0889 .71154 L
.09615 .72047 L
.10435 .73077 L
.11538 .74503 L
.11916 .75 L
.13338 .76923 L
.13462 .77094 L
.14715 .78846 L
.15385 .798 L
.16061 .80769 L
.17308 .82569 L
.17393 .82692 L
.18732 .84615 L
.19231 .85325 L
.20095 .86538 L
.21154 .87996 L
.21499 .88462 L
.22967 .90385 L
.23077 .90525 L
.24519 .92308 L
.25 .92881 L
.26177 .94231 L
.26923 .95051 L
.2797 .96154 L
.28846 .97036 L
.29931 .98077 L
s
.2 g
.44866 .98077 m
.44231 .97723 L
.42308 .96547 L
.41717 .96154 L
.40385 .95205 L
.3913 .94231 L
.38462 .93677 L
.36927 .92308 L
.36538 .91939 L
.35006 .90385 L
.34615 .89962 L
.33305 .88462 L
.32692 .87713 L
.31778 .86538 L
.30769 .85157 L
.30391 .84615 L
.29117 .82692 L
.28846 .82264 L
.27933 .80769 L
.26923 .79033 L
.26817 .78846 L
.25753 .76923 L
.25 .75523 L
.24722 .75 L
.23709 .73077 L
.23077 .71875 L
.22697 .71154 L
.21673 .69231 L
.21154 .68271 L
.20627 .67308 L
.19548 .65385 L
.19231 .64831 L
.18433 .63462 L
.17308 .6158 L
.17282 .61538 L
.16102 .59615 L
.15385 .58464 L
.14902 .57692 L
.13698 .55769 L
.13462 .5539 L
.12508 .53846 L
.11538 .52237 L
.11353 .51923 L
.10252 .5 L
.09615 .48829 L
.09223 .48077 L
.08279 .46154 L
.07692 .44845 L
.07434 .44231 L
.06696 .42308 L
.06071 .40385 L
.05769 .39303 L
.05565 .38462 L
.05179 .36538 L
.04917 .34615 L
.04781 .32692 L
.04772 .30769 L
.04892 .28846 L
.05145 .26923 L
.05533 .25 L
.05769 .24064 L
.0606 .23077 L
.06731 .21154 L
.07549 .19231 L
.07692 .18927 L
.08522 .17308 L
.09615 .15448 L
.09655 .15385 L
.10955 .13462 L
.11538 .12672 L
.12428 .11538 L
.13462 .1031 L
.1408 .09615 L
.15385 .08229 L
.15917 .07692 L
.17308 .06354 L
.17946 .05769 L
.19231 .04639 L
.20175 .03846 L
.21154 .03054 L
.22618 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44866 .98077 m
.44231 .97723 L
.42308 .96547 L
.41717 .96154 L
.40385 .95205 L
.3913 .94231 L
.38462 .93677 L
.36927 .92308 L
.36538 .91939 L
.35006 .90385 L
.34615 .89962 L
.33305 .88462 L
.32692 .87713 L
.31778 .86538 L
.30769 .85157 L
.30391 .84615 L
.29117 .82692 L
.28846 .82264 L
.27933 .80769 L
.26923 .79033 L
.26817 .78846 L
.25753 .76923 L
.25 .75523 L
.24722 .75 L
.23709 .73077 L
.23077 .71875 L
.22697 .71154 L
.21673 .69231 L
.21154 .68271 L
.20627 .67308 L
.19548 .65385 L
.19231 .64831 L
.18433 .63462 L
.17308 .6158 L
.17282 .61538 L
.16102 .59615 L
.15385 .58464 L
.14902 .57692 L
.13698 .55769 L
.13462 .5539 L
.12508 .53846 L
.11538 .52237 L
.11353 .51923 L
.10252 .5 L
.09615 .48829 L
.09223 .48077 L
.08279 .46154 L
.07692 .44845 L
.07434 .44231 L
.06696 .42308 L
Mistroke
.06071 .40385 L
.05769 .39303 L
.05565 .38462 L
.05179 .36538 L
.04917 .34615 L
.04781 .32692 L
.04772 .30769 L
.04892 .28846 L
.05145 .26923 L
.05533 .25 L
.05769 .24064 L
.0606 .23077 L
.06731 .21154 L
.07549 .19231 L
.07692 .18927 L
.08522 .17308 L
.09615 .15448 L
.09655 .15385 L
.10955 .13462 L
.11538 .12672 L
.12428 .11538 L
.13462 .1031 L
.1408 .09615 L
.15385 .08229 L
.15917 .07692 L
.17308 .06354 L
.17946 .05769 L
.19231 .04639 L
.20175 .03846 L
.21154 .03054 L
.22618 .01923 L
Mfstroke
.3 g
.75357 .01923 m
.76923 .03458 L
.77283 .03846 L
.78846 .05713 L
.78889 .05769 L
.80246 .07692 L
.80769 .08525 L
.81401 .09615 L
.82388 .11538 L
.82692 .12197 L
.83232 .13462 L
.83956 .15385 L
.84577 .17308 L
.84615 .17437 L
.8511 .19231 L
.85572 .21154 L
.85978 .23077 L
.86343 .25 L
.86538 .26098 L
.86682 .26923 L
.87011 .28846 L
.87346 .30769 L
.87706 .32692 L
.88105 .34615 L
.88462 .36148 L
.88558 .36538 L
.89077 .38462 L
.8967 .40385 L
.90337 .42308 L
.90385 .42439 L
.91069 .44231 L
.91853 .46154 L
.92308 .47234 L
.92665 .48077 L
.93479 .5 L
.94231 .51831 L
.94267 .51923 L
.95004 .53846 L
.95668 .55769 L
.96154 .57368 L
.96244 .57692 L
.96717 .59615 L
.9708 .61538 L
.97326 .63462 L
.9745 .65385 L
.97448 .67308 L
.97317 .69231 L
.97051 .71154 L
.96646 .73077 L
.96154 .74822 L
.96096 .75 L
.95391 .76923 L
.94521 .78846 L
.94231 .79415 L
.93472 .80769 L
.92308 .82572 L
.92223 .82692 L
.90749 .84615 L
.90385 .85046 L
.89012 .86538 L
.88462 .87086 L
.86955 .88462 L
.86538 .88813 L
.84615 .90295 L
.8449 .90385 L
.82692 .91576 L
.81456 .92308 L
.80769 .92685 L
.78846 .93642 L
.775 .94231 L
.76923 .94463 L
.75 .95157 L
.73077 .95734 L
.71358 .96154 L
.71154 .96197 L
.69231 .96552 L
.67308 .96801 L
.65385 .96944 L
.63462 .96981 L
.61538 .96911 L
.59615 .96731 L
.57692 .96439 L
.56292 .96154 L
.55769 .96028 L
.53846 .95492 L
.51923 .94824 L
.50483 .94231 L
.5 .94012 L
.48077 .93043 L
.46803 .92308 L
.46154 .91901 L
.44231 .90562 L
.43997 .90385 L
.42308 .89 L
.41709 .88462 L
.40385 .87176 L
.39777 .86538 L
.38462 .85044 L
.38109 .84615 L
.36645 .82692 L
.36538 .82543 L
.35342 .80769 L
.34615 .79603 L
.34166 .78846 L
.33091 .76923 L
.32692 .76171 L
.32093 .75 L
.31151 .73077 L
.30769 .72273 L
.30247 .71154 L
.29363 .69231 L
.28846 .68101 L
.28483 .67308 L
.27595 .65385 L
.26923 .63954 L
.26689 .63462 L
.25759 .61538 L
.25 .60007 L
.24803 .59615 L
.23826 .57692 L
.23077 .56238 L
.22835 .55769 L
.21842 .53846 L
.21154 .52499 L
.20863 .51923 L
.19915 .5 L
.19231 .48551 L
.19014 .48077 L
.18177 .46154 L
.17416 .44231 L
.17308 .43939 L
.16746 .42308 L
.16175 .40385 L
.15712 .38462 L
.15385 .36677 L
.15365 .36538 L
.15137 .34615 L
.15034 .32692 L
.15058 .30769 L
.15214 .28846 L
.15385 .27535 L
.15504 .26923 L
.15931 .25 L
.16498 .23077 L
.17208 .21154 L
.17308 .20911 L
.18064 .19231 L
.1907 .17308 L
.19231 .17025 L
.20232 .15385 L
.21154 .14017 L
.21553 .13462 L
.23042 .11538 L
.23077 .11496 L
.24711 .09615 L
.25 .09303 L
.26574 .07692 L
.26923 .07355 L
.28657 .05769 L
.28846 .05605 L
.30769 .04023 L
.30997 .03846 L
.32692 .0259 L
.33657 .01923 L
F
0 g
.75357 .01923 m
.76923 .03458 L
.77283 .03846 L
.78846 .05713 L
.78889 .05769 L
.80246 .07692 L
.80769 .08525 L
.81401 .09615 L
.82388 .11538 L
.82692 .12197 L
.83232 .13462 L
.83956 .15385 L
.84577 .17308 L
.84615 .17437 L
.8511 .19231 L
.85572 .21154 L
.85978 .23077 L
.86343 .25 L
.86538 .26098 L
.86682 .26923 L
.87011 .28846 L
.87346 .30769 L
.87706 .32692 L
.88105 .34615 L
.88462 .36148 L
.88558 .36538 L
.89077 .38462 L
.8967 .40385 L
.90337 .42308 L
.90385 .42439 L
.91069 .44231 L
.91853 .46154 L
.92308 .47234 L
.92665 .48077 L
.93479 .5 L
.94231 .51831 L
.94267 .51923 L
.95004 .53846 L
.95668 .55769 L
.96154 .57368 L
.96244 .57692 L
.96717 .59615 L
.9708 .61538 L
.97326 .63462 L
.9745 .65385 L
.97448 .67308 L
.97317 .69231 L
.97051 .71154 L
.96646 .73077 L
.96154 .74822 L
Mistroke
.96096 .75 L
.95391 .76923 L
.94521 .78846 L
.94231 .79415 L
.93472 .80769 L
.92308 .82572 L
.92223 .82692 L
.90749 .84615 L
.90385 .85046 L
.89012 .86538 L
.88462 .87086 L
.86955 .88462 L
.86538 .88813 L
.84615 .90295 L
.8449 .90385 L
.82692 .91576 L
.81456 .92308 L
.80769 .92685 L
.78846 .93642 L
.775 .94231 L
.76923 .94463 L
.75 .95157 L
.73077 .95734 L
.71358 .96154 L
.71154 .96197 L
.69231 .96552 L
.67308 .96801 L
.65385 .96944 L
.63462 .96981 L
.61538 .96911 L
.59615 .96731 L
.57692 .96439 L
.56292 .96154 L
.55769 .96028 L
.53846 .95492 L
.51923 .94824 L
.50483 .94231 L
.5 .94012 L
.48077 .93043 L
.46803 .92308 L
.46154 .91901 L
.44231 .90562 L
.43997 .90385 L
.42308 .89 L
.41709 .88462 L
.40385 .87176 L
.39777 .86538 L
.38462 .85044 L
.38109 .84615 L
.36645 .82692 L
Mistroke
.36538 .82543 L
.35342 .80769 L
.34615 .79603 L
.34166 .78846 L
.33091 .76923 L
.32692 .76171 L
.32093 .75 L
.31151 .73077 L
.30769 .72273 L
.30247 .71154 L
.29363 .69231 L
.28846 .68101 L
.28483 .67308 L
.27595 .65385 L
.26923 .63954 L
.26689 .63462 L
.25759 .61538 L
.25 .60007 L
.24803 .59615 L
.23826 .57692 L
.23077 .56238 L
.22835 .55769 L
.21842 .53846 L
.21154 .52499 L
.20863 .51923 L
.19915 .5 L
.19231 .48551 L
.19014 .48077 L
.18177 .46154 L
.17416 .44231 L
.17308 .43939 L
.16746 .42308 L
.16175 .40385 L
.15712 .38462 L
.15385 .36677 L
.15365 .36538 L
.15137 .34615 L
.15034 .32692 L
.15058 .30769 L
.15214 .28846 L
.15385 .27535 L
.15504 .26923 L
.15931 .25 L
.16498 .23077 L
.17208 .21154 L
.17308 .20911 L
.18064 .19231 L
.1907 .17308 L
.19231 .17025 L
.20232 .15385 L
Mistroke
.21154 .14017 L
.21553 .13462 L
.23042 .11538 L
.23077 .11496 L
.24711 .09615 L
.25 .09303 L
.26574 .07692 L
.26923 .07355 L
.28657 .05769 L
.28846 .05605 L
.30769 .04023 L
.30997 .03846 L
.32692 .0259 L
.33657 .01923 L
Mfstroke
.4 g
.6841 .01923 m
.69231 .0241 L
.71154 .03731 L
.71304 .03846 L
.73077 .05355 L
.73509 .05769 L
.75 .07367 L
.75274 .07692 L
.76723 .09615 L
.76923 .09911 L
.77928 .11538 L
.78846 .13274 L
.78937 .13462 L
.79783 .15385 L
.80493 .17308 L
.80769 .18157 L
.81088 .19231 L
.81588 .21154 L
.82009 .23077 L
.82368 .25 L
.82682 .26923 L
.82692 .26992 L
.82965 .28846 L
.83237 .30769 L
.83513 .32692 L
.83811 .34615 L
.84147 .36538 L
.84538 .38462 L
.84615 .38806 L
.84997 .40385 L
.8553 .42308 L
.86141 .44231 L
.86538 .45376 L
.86822 .46154 L
.87557 .48077 L
.88324 .5 L
.88462 .50343 L
.89092 .51923 L
.89833 .53846 L
.90385 .55379 L
.90517 .55769 L
.9112 .57692 L
.91624 .59615 L
.92012 .61538 L
.92273 .63462 L
.92308 .63824 L
.924 .65385 L
.92385 .67308 L
.92308 .68437 L
.92222 .69231 L
.91902 .71154 L
.91418 .73077 L
.90757 .75 L
.90385 .75903 L
.89906 .76923 L
.88844 .78846 L
.88462 .79453 L
.87543 .80769 L
.86538 .82034 L
.85962 .82692 L
.84615 .84078 L
.84037 .84615 L
.82692 .85756 L
.81662 .86538 L
.80769 .87159 L
.78846 .88339 L
.78627 .88462 L
.76923 .89331 L
.75 .90156 L
.74396 .90385 L
.73077 .9083 L
.71154 .91364 L
.69231 .91766 L
.67308 .9204 L
.65385 .92188 L
.63462 .9221 L
.61538 .92104 L
.59615 .91868 L
.57692 .91495 L
.55769 .90977 L
.54054 .90385 L
.53846 .90303 L
.51923 .8946 L
.50057 .88462 L
.5 .88428 L
.48077 .87181 L
.47208 .86538 L
.46154 .85685 L
.44964 .84615 L
.44231 .83894 L
.43112 .82692 L
.42308 .81744 L
.41542 .80769 L
.40385 .79148 L
.40183 .78846 L
.38986 .76923 L
.38462 .76006 L
.37915 .75 L
.36938 .73077 L
.36538 .72245 L
.3603 .71154 L
.35168 .69231 L
.34615 .67964 L
.34332 .67308 L
.33503 .65385 L
.32692 .63521 L
.32666 .63462 L
.31812 .61538 L
.30935 .59615 L
.30769 .59259 L
.30033 .57692 L
.29113 .55769 L
.28846 .55216 L
.28184 .53846 L
.27261 .51923 L
.26923 .5121 L
.2636 .5 L
.25498 .48077 L
.25 .46907 L
.24693 .46154 L
.23959 .44231 L
.23309 .42308 L
.23077 .41548 L
.22756 .40385 L
.22307 .38462 L
.21971 .36538 L
.21754 .34615 L
.2166 .32692 L
.21693 .30769 L
.21856 .28846 L
.22154 .26923 L
.22589 .25 L
.23077 .23339 L
.23165 .23077 L
.23887 .21154 L
.24759 .19231 L
.25 .1875 L
.25787 .17308 L
.26923 .15472 L
.26981 .15385 L
.28353 .13462 L
.28846 .12828 L
.2992 .11538 L
.30769 .10593 L
.31708 .09615 L
.32692 .08658 L
.33757 .07692 L
.34615 .06962 L
.3613 .05769 L
.36538 .05468 L
.38462 .04151 L
.38945 .03846 L
.40385 .02996 L
.42308 .01991 L
.42448 .01923 L
F
0 g
.6841 .01923 m
.69231 .0241 L
.71154 .03731 L
.71304 .03846 L
.73077 .05355 L
.73509 .05769 L
.75 .07367 L
.75274 .07692 L
.76723 .09615 L
.76923 .09911 L
.77928 .11538 L
.78846 .13274 L
.78937 .13462 L
.79783 .15385 L
.80493 .17308 L
.80769 .18157 L
.81088 .19231 L
.81588 .21154 L
.82009 .23077 L
.82368 .25 L
.82682 .26923 L
.82692 .26992 L
.82965 .28846 L
.83237 .30769 L
.83513 .32692 L
.83811 .34615 L
.84147 .36538 L
.84538 .38462 L
.84615 .38806 L
.84997 .40385 L
.8553 .42308 L
.86141 .44231 L
.86538 .45376 L
.86822 .46154 L
.87557 .48077 L
.88324 .5 L
.88462 .50343 L
.89092 .51923 L
.89833 .53846 L
.90385 .55379 L
.90517 .55769 L
.9112 .57692 L
.91624 .59615 L
.92012 .61538 L
.92273 .63462 L
.92308 .63824 L
.924 .65385 L
.92385 .67308 L
.92308 .68437 L
.92222 .69231 L
Mistroke
.91902 .71154 L
.91418 .73077 L
.90757 .75 L
.90385 .75903 L
.89906 .76923 L
.88844 .78846 L
.88462 .79453 L
.87543 .80769 L
.86538 .82034 L
.85962 .82692 L
.84615 .84078 L
.84037 .84615 L
.82692 .85756 L
.81662 .86538 L
.80769 .87159 L
.78846 .88339 L
.78627 .88462 L
.76923 .89331 L
.75 .90156 L
.74396 .90385 L
.73077 .9083 L
.71154 .91364 L
.69231 .91766 L
.67308 .9204 L
.65385 .92188 L
.63462 .9221 L
.61538 .92104 L
.59615 .91868 L
.57692 .91495 L
.55769 .90977 L
.54054 .90385 L
.53846 .90303 L
.51923 .8946 L
.50057 .88462 L
.5 .88428 L
.48077 .87181 L
.47208 .86538 L
.46154 .85685 L
.44964 .84615 L
.44231 .83894 L
.43112 .82692 L
.42308 .81744 L
.41542 .80769 L
.40385 .79148 L
.40183 .78846 L
.38986 .76923 L
.38462 .76006 L
.37915 .75 L
.36938 .73077 L
.36538 .72245 L
Mistroke
.3603 .71154 L
.35168 .69231 L
.34615 .67964 L
.34332 .67308 L
.33503 .65385 L
.32692 .63521 L
.32666 .63462 L
.31812 .61538 L
.30935 .59615 L
.30769 .59259 L
.30033 .57692 L
.29113 .55769 L
.28846 .55216 L
.28184 .53846 L
.27261 .51923 L
.26923 .5121 L
.2636 .5 L
.25498 .48077 L
.25 .46907 L
.24693 .46154 L
.23959 .44231 L
.23309 .42308 L
.23077 .41548 L
.22756 .40385 L
.22307 .38462 L
.21971 .36538 L
.21754 .34615 L
.2166 .32692 L
.21693 .30769 L
.21856 .28846 L
.22154 .26923 L
.22589 .25 L
.23077 .23339 L
.23165 .23077 L
.23887 .21154 L
.24759 .19231 L
.25 .1875 L
.25787 .17308 L
.26923 .15472 L
.26981 .15385 L
.28353 .13462 L
.28846 .12828 L
.2992 .11538 L
.30769 .10593 L
.31708 .09615 L
.32692 .08658 L
.33757 .07692 L
.34615 .06962 L
.3613 .05769 L
.36538 .05468 L
Mistroke
.38462 .04151 L
.38945 .03846 L
.40385 .02996 L
.42308 .01991 L
.42448 .01923 L
Mfstroke
.5 g
.48077 .0361 m
.5 .03067 L
.51923 .02676 L
.53846 .02436 L
.55769 .02348 L
.57692 .02417 L
.59615 .02649 L
.61538 .03055 L
.63462 .03648 L
.63995 .03846 L
.65385 .04449 L
.67308 .05489 L
.67755 .05769 L
.69231 .06812 L
.70299 .07692 L
.71154 .08487 L
.72227 .09615 L
.73077 .10632 L
.73757 .11538 L
.74996 .13462 L
.75 .13469 L
.7601 .15385 L
.76841 .17308 L
.76923 .17518 L
.77523 .19231 L
.78081 .21154 L
.78536 .23077 L
.78846 .2466 L
.78906 .25 L
.7921 .26923 L
.79466 .28846 L
.7969 .30769 L
.799 .32692 L
.80114 .34615 L
.8035 .36538 L
.80626 .38462 L
.80769 .39337 L
.80958 .40385 L
.81359 .42308 L
.81838 .44231 L
.82397 .46154 L
.82692 .47077 L
.83029 .48077 L
.83717 .5 L
.84435 .51923 L
.84615 .52404 L
.85151 .53846 L
.85832 .55769 L
.86446 .57692 L
.86538 .58004 L
.86965 .59615 L
.87368 .61538 L
.87636 .63462 L
.87756 .65385 L
.87716 .67308 L
.87504 .69231 L
.87109 .71154 L
.86538 .7301 L
.86513 .73077 L
.85699 .75 L
.84635 .76923 L
.84615 .76955 L
.83282 .78846 L
.82692 .79563 L
.81573 .80769 L
.80769 .81535 L
.79389 .82692 L
.78846 .831 L
.76923 .84364 L
.76489 .84615 L
.75 .85387 L
.73077 .86205 L
.72145 .86538 L
.71154 .86841 L
.69231 .8731 L
.67308 .87621 L
.65385 .87778 L
.63462 .87783 L
.61538 .87633 L
.59615 .87324 L
.57692 .86846 L
.56718 .86538 L
.55769 .86185 L
.53846 .85323 L
.52548 .84615 L
.51923 .84233 L
.5 .82877 L
.49766 .82692 L
.48077 .81204 L
.47637 .80769 L
.46154 .79139 L
.45912 .78846 L
.44468 .76923 L
.44231 .76576 L
.43228 .75 L
.42308 .7339 L
.42139 .73077 L
.41161 .71154 L
.40385 .69503 L
.40261 .69231 L
.39409 .67308 L
.38583 .65385 L
.38462 .65102 L
.37759 .63462 L
.36923 .61538 L
.36538 .6067 L
.36064 .59615 L
.35178 .57692 L
.34615 .56502 L
.34265 .55769 L
.33337 .53846 L
.32692 .52517 L
.32406 .51923 L
.3149 .5 L
.30769 .48435 L
.30609 .48077 L
.29781 .46154 L
.29023 .44231 L
.28846 .43751 L
.28351 .42308 L
.27776 .40385 L
.27309 .38462 L
.26957 .36538 L
.26923 .36381 L
.26728 .34615 L
.26625 .32692 L
.26654 .30769 L
.26818 .28846 L
.26923 .27999 L
.27122 .26923 L
.2757 .25 L
.28167 .23077 L
.28846 .21321 L
.28918 .21154 L
.29834 .19231 L
.30769 .17564 L
.30925 .17308 L
.32208 .15385 L
.32692 .1473 L
.33706 .13462 L
.34615 .12424 L
.35455 .11538 L
.36538 .10486 L
.37513 .09615 L
.38462 .08831 L
.39981 .07692 L
.40385 .07412 L
.42308 .06198 L
.43068 .05769 L
.44231 .05168 L
.46154 .04309 L
.47373 .03846 L
F
0 g
.48077 .0361 m
.5 .03067 L
.51923 .02676 L
.53846 .02436 L
.55769 .02348 L
.57692 .02417 L
.59615 .02649 L
.61538 .03055 L
.63462 .03648 L
.63995 .03846 L
.65385 .04449 L
.67308 .05489 L
.67755 .05769 L
.69231 .06812 L
.70299 .07692 L
.71154 .08487 L
.72227 .09615 L
.73077 .10632 L
.73757 .11538 L
.74996 .13462 L
.75 .13469 L
.7601 .15385 L
.76841 .17308 L
.76923 .17518 L
.77523 .19231 L
.78081 .21154 L
.78536 .23077 L
.78846 .2466 L
.78906 .25 L
.7921 .26923 L
.79466 .28846 L
.7969 .30769 L
.799 .32692 L
.80114 .34615 L
.8035 .36538 L
.80626 .38462 L
.80769 .39337 L
.80958 .40385 L
.81359 .42308 L
.81838 .44231 L
.82397 .46154 L
.82692 .47077 L
.83029 .48077 L
.83717 .5 L
.84435 .51923 L
.84615 .52404 L
.85151 .53846 L
.85832 .55769 L
.86446 .57692 L
.86538 .58004 L
Mistroke
.86965 .59615 L
.87368 .61538 L
.87636 .63462 L
.87756 .65385 L
.87716 .67308 L
.87504 .69231 L
.87109 .71154 L
.86538 .7301 L
.86513 .73077 L
.85699 .75 L
.84635 .76923 L
.84615 .76955 L
.83282 .78846 L
.82692 .79563 L
.81573 .80769 L
.80769 .81535 L
.79389 .82692 L
.78846 .831 L
.76923 .84364 L
.76489 .84615 L
.75 .85387 L
.73077 .86205 L
.72145 .86538 L
.71154 .86841 L
.69231 .8731 L
.67308 .87621 L
.65385 .87778 L
.63462 .87783 L
.61538 .87633 L
.59615 .87324 L
.57692 .86846 L
.56718 .86538 L
.55769 .86185 L
.53846 .85323 L
.52548 .84615 L
.51923 .84233 L
.5 .82877 L
.49766 .82692 L
.48077 .81204 L
.47637 .80769 L
.46154 .79139 L
.45912 .78846 L
.44468 .76923 L
.44231 .76576 L
.43228 .75 L
.42308 .7339 L
.42139 .73077 L
.41161 .71154 L
.40385 .69503 L
.40261 .69231 L
Mistroke
.39409 .67308 L
.38583 .65385 L
.38462 .65102 L
.37759 .63462 L
.36923 .61538 L
.36538 .6067 L
.36064 .59615 L
.35178 .57692 L
.34615 .56502 L
.34265 .55769 L
.33337 .53846 L
.32692 .52517 L
.32406 .51923 L
.3149 .5 L
.30769 .48435 L
.30609 .48077 L
.29781 .46154 L
.29023 .44231 L
.28846 .43751 L
.28351 .42308 L
.27776 .40385 L
.27309 .38462 L
.26957 .36538 L
.26923 .36381 L
.26728 .34615 L
.26625 .32692 L
.26654 .30769 L
.26818 .28846 L
.26923 .27999 L
.27122 .26923 L
.2757 .25 L
.28167 .23077 L
.28846 .21321 L
.28918 .21154 L
.29834 .19231 L
.30769 .17564 L
.30925 .17308 L
.32208 .15385 L
.32692 .1473 L
.33706 .13462 L
.34615 .12424 L
.35455 .11538 L
.36538 .10486 L
.37513 .09615 L
.38462 .08831 L
.39981 .07692 L
.40385 .07412 L
.42308 .06198 L
.43068 .05769 L
.44231 .05168 L
Mistroke
.46154 .04309 L
.47373 .03846 L
.48077 .0361 L
Mfstroke
.6 g
.55769 .05749 m
.567 .05769 L
.57692 .05839 L
.59615 .06121 L
.61538 .0661 L
.63462 .07329 L
.64245 .07692 L
.65385 .08312 L
.67308 .09613 L
.67311 .09615 L
.69231 .11319 L
.69444 .11538 L
.7106 .13462 L
.71154 .1359 L
.72328 .15385 L
.73077 .16769 L
.73337 .17308 L
.74144 .19231 L
.74787 .21154 L
.75 .219 L
.75296 .23077 L
.75694 .25 L
.76004 .26923 L
.76243 .28846 L
.76431 .30769 L
.76585 .32692 L
.76724 .34615 L
.76866 .36538 L
.76923 .37248 L
.7703 .38462 L
.77235 .40385 L
.77498 .42308 L
.77833 .44231 L
.7825 .46154 L
.7875 .48077 L
.78846 .48414 L
.79326 .5 L
.79957 .51923 L
.80615 .53846 L
.80769 .54295 L
.81264 .55769 L
.81866 .57692 L
.82383 .59615 L
.82692 .61001 L
.82786 .61538 L
.83046 .63462 L
.83142 .65385 L
.83053 .67308 L
.8276 .69231 L
.82692 .69566 L
.8224 .71154 L
.81463 .73077 L
.80769 .74384 L
.80384 .75 L
.78932 .76923 L
.78846 .77021 L
.76979 .78846 L
.76923 .78893 L
.75 .80305 L
.74237 .80769 L
.73077 .81382 L
.71154 .82193 L
.69565 .82692 L
.69231 .82774 L
.67308 .83149 L
.65385 .83327 L
.63462 .83312 L
.61538 .83103 L
.59621 .82692 L
.59615 .8269 L
.57692 .82058 L
.55769 .81181 L
.55023 .80769 L
.53846 .80022 L
.52296 .78846 L
.51923 .78525 L
.50283 .76923 L
.5 .76611 L
.48683 .75 L
.48077 .7416 L
.47358 .73077 L
.46221 .71154 L
.46154 .71031 L
.45216 .69231 L
.44298 .67308 L
.44231 .67163 L
.43429 .65385 L
.4258 .63462 L
.42308 .62846 L
.41725 .61538 L
.40848 .59615 L
.40385 .58626 L
.39939 .57692 L
.38995 .55769 L
.38462 .54707 L
.38025 .53846 L
.37042 .51923 L
.36538 .50933 L
.36068 .5 L
.35124 .48077 L
.34615 .46996 L
.34233 .46154 L
.33414 .44231 L
.32692 .42328 L
.32685 .42308 L
.3206 .40385 L
.3155 .38462 L
.31163 .36538 L
.30906 .34615 L
.30785 .32692 L
.30804 .30769 L
.30967 .28846 L
.31281 .26923 L
.31751 .25 L
.32383 .23077 L
.32692 .22284 L
.3319 .21154 L
.34184 .19231 L
.34615 .18498 L
.35386 .17308 L
.36538 .15742 L
.36827 .15385 L
.38462 .13555 L
.38553 .13462 L
.40385 .1176 L
.40649 .11538 L
.42308 .10268 L
.43274 .09615 L
.44231 .09029 L
.46154 .0801 L
.46844 .07692 L
.48077 .07193 L
.5 .06563 L
.51923 .06114 L
.53846 .05842 L
.54894 .05769 L
F
0 g
.55769 .05749 m
.567 .05769 L
.57692 .05839 L
.59615 .06121 L
.61538 .0661 L
.63462 .07329 L
.64245 .07692 L
.65385 .08312 L
.67308 .09613 L
.67311 .09615 L
.69231 .11319 L
.69444 .11538 L
.7106 .13462 L
.71154 .1359 L
.72328 .15385 L
.73077 .16769 L
.73337 .17308 L
.74144 .19231 L
.74787 .21154 L
.75 .219 L
.75296 .23077 L
.75694 .25 L
.76004 .26923 L
.76243 .28846 L
.76431 .30769 L
.76585 .32692 L
.76724 .34615 L
.76866 .36538 L
.76923 .37248 L
.7703 .38462 L
.77235 .40385 L
.77498 .42308 L
.77833 .44231 L
.7825 .46154 L
.7875 .48077 L
.78846 .48414 L
.79326 .5 L
.79957 .51923 L
.80615 .53846 L
.80769 .54295 L
.81264 .55769 L
.81866 .57692 L
.82383 .59615 L
.82692 .61001 L
.82786 .61538 L
.83046 .63462 L
.83142 .65385 L
.83053 .67308 L
.8276 .69231 L
.82692 .69566 L
Mistroke
.8224 .71154 L
.81463 .73077 L
.80769 .74384 L
.80384 .75 L
.78932 .76923 L
.78846 .77021 L
.76979 .78846 L
.76923 .78893 L
.75 .80305 L
.74237 .80769 L
.73077 .81382 L
.71154 .82193 L
.69565 .82692 L
.69231 .82774 L
.67308 .83149 L
.65385 .83327 L
.63462 .83312 L
.61538 .83103 L
.59621 .82692 L
.59615 .8269 L
.57692 .82058 L
.55769 .81181 L
.55023 .80769 L
.53846 .80022 L
.52296 .78846 L
.51923 .78525 L
.50283 .76923 L
.5 .76611 L
.48683 .75 L
.48077 .7416 L
.47358 .73077 L
.46221 .71154 L
.46154 .71031 L
.45216 .69231 L
.44298 .67308 L
.44231 .67163 L
.43429 .65385 L
.4258 .63462 L
.42308 .62846 L
.41725 .61538 L
.40848 .59615 L
.40385 .58626 L
.39939 .57692 L
.38995 .55769 L
.38462 .54707 L
.38025 .53846 L
.37042 .51923 L
.36538 .50933 L
.36068 .5 L
.35124 .48077 L
Mistroke
.34615 .46996 L
.34233 .46154 L
.33414 .44231 L
.32692 .42328 L
.32685 .42308 L
.3206 .40385 L
.3155 .38462 L
.31163 .36538 L
.30906 .34615 L
.30785 .32692 L
.30804 .30769 L
.30967 .28846 L
.31281 .26923 L
.31751 .25 L
.32383 .23077 L
.32692 .22284 L
.3319 .21154 L
.34184 .19231 L
.34615 .18498 L
.35386 .17308 L
.36538 .15742 L
.36827 .15385 L
.38462 .13555 L
.38553 .13462 L
.40385 .1176 L
.40649 .11538 L
.42308 .10268 L
.43274 .09615 L
.44231 .09029 L
.46154 .0801 L
.46844 .07692 L
.48077 .07193 L
.5 .06563 L
.51923 .06114 L
.53846 .05842 L
.54894 .05769 L
.55769 .05749 L
Mfstroke
.7 g
.51923 .09496 m
.53846 .09189 L
.55769 .09095 L
.57692 .09218 L
.59615 .09573 L
.59794 .09615 L
.61538 .10183 L
.63462 .11088 L
.64226 .11538 L
.65385 .1235 L
.66689 .13462 L
.67308 .14082 L
.68426 .15385 L
.69231 .16509 L
.6973 .17308 L
.70734 .19231 L
.71154 .20206 L
.7151 .21154 L
.72106 .23077 L
.72555 .25 L
.72886 .26923 L
.73077 .28418 L
.7312 .28846 L
.7328 .30769 L
.73382 .32692 L
.73448 .34615 L
.73494 .36538 L
.73541 .38462 L
.73609 .40385 L
.73716 .42308 L
.73882 .44231 L
.74123 .46154 L
.74448 .48077 L
.74861 .5 L
.75 .50576 L
.75352 .51923 L
.75901 .53846 L
.76472 .55769 L
.76923 .57333 L
.77021 .57692 L
.77505 .59615 L
.77877 .61538 L
.78096 .63462 L
.78125 .65385 L
.77928 .67308 L
.77463 .69231 L
.76923 .70663 L
.76676 .71154 L
.75479 .73077 L
.75 .73676 L
.73696 .75 L
.73077 .75511 L
.71154 .76754 L
.70842 .76923 L
.69231 .77595 L
.67308 .78114 L
.65385 .78349 L
.63462 .78317 L
.61538 .78017 L
.59615 .77431 L
.58424 .76923 L
.57692 .76528 L
.55769 .75252 L
.5545 .75 L
.53846 .73516 L
.53437 .73077 L
.51923 .71193 L
.51895 .71154 L
.50631 .69231 L
.5 .68141 L
.49544 .67308 L
.48562 .65385 L
.48077 .64386 L
.47634 .63462 L
.46717 .61538 L
.46154 .60372 L
.45782 .59615 L
.44808 .57692 L
.44231 .56592 L
.43788 .55769 L
.42727 .53846 L
.42308 .531 L
.41641 .51923 L
.40554 .5 L
.40385 .49697 L
.39494 .48077 L
.3849 .46154 L
.38462 .46097 L
.37565 .44231 L
.36741 .42308 L
.36538 .41792 L
.36033 .40385 L
.35453 .38462 L
.35009 .36538 L
.3471 .34615 L
.34615 .3365 L
.34559 .32692 L
.34563 .30769 L
.34615 .29923 L
.34727 .28846 L
.35057 .26923 L
.35562 .25 L
.36253 .23077 L
.36538 .22408 L
.37148 .21154 L
.38271 .19231 L
.38462 .18942 L
.39662 .17308 L
.40385 .16449 L
.41385 .15385 L
.42308 .14511 L
.43565 .13462 L
.44231 .12965 L
.46154 .11728 L
.46489 .11538 L
.48077 .10753 L
.5 .10015 L
.51363 .09615 L
F
0 g
.51923 .09496 m
.53846 .09189 L
.55769 .09095 L
.57692 .09218 L
.59615 .09573 L
.59794 .09615 L
.61538 .10183 L
.63462 .11088 L
.64226 .11538 L
.65385 .1235 L
.66689 .13462 L
.67308 .14082 L
.68426 .15385 L
.69231 .16509 L
.6973 .17308 L
.70734 .19231 L
.71154 .20206 L
.7151 .21154 L
.72106 .23077 L
.72555 .25 L
.72886 .26923 L
.73077 .28418 L
.7312 .28846 L
.7328 .30769 L
.73382 .32692 L
.73448 .34615 L
.73494 .36538 L
.73541 .38462 L
.73609 .40385 L
.73716 .42308 L
.73882 .44231 L
.74123 .46154 L
.74448 .48077 L
.74861 .5 L
.75 .50576 L
.75352 .51923 L
.75901 .53846 L
.76472 .55769 L
.76923 .57333 L
.77021 .57692 L
.77505 .59615 L
.77877 .61538 L
.78096 .63462 L
.78125 .65385 L
.77928 .67308 L
.77463 .69231 L
.76923 .70663 L
.76676 .71154 L
.75479 .73077 L
.75 .73676 L
Mistroke
.73696 .75 L
.73077 .75511 L
.71154 .76754 L
.70842 .76923 L
.69231 .77595 L
.67308 .78114 L
.65385 .78349 L
.63462 .78317 L
.61538 .78017 L
.59615 .77431 L
.58424 .76923 L
.57692 .76528 L
.55769 .75252 L
.5545 .75 L
.53846 .73516 L
.53437 .73077 L
.51923 .71193 L
.51895 .71154 L
.50631 .69231 L
.5 .68141 L
.49544 .67308 L
.48562 .65385 L
.48077 .64386 L
.47634 .63462 L
.46717 .61538 L
.46154 .60372 L
.45782 .59615 L
.44808 .57692 L
.44231 .56592 L
.43788 .55769 L
.42727 .53846 L
.42308 .531 L
.41641 .51923 L
.40554 .5 L
.40385 .49697 L
.39494 .48077 L
.3849 .46154 L
.38462 .46097 L
.37565 .44231 L
.36741 .42308 L
.36538 .41792 L
.36033 .40385 L
.35453 .38462 L
.35009 .36538 L
.3471 .34615 L
.34615 .3365 L
.34559 .32692 L
.34563 .30769 L
.34615 .29923 L
.34727 .28846 L
Mistroke
.35057 .26923 L
.35562 .25 L
.36253 .23077 L
.36538 .22408 L
.37148 .21154 L
.38271 .19231 L
.38462 .18942 L
.39662 .17308 L
.40385 .16449 L
.41385 .15385 L
.42308 .14511 L
.43565 .13462 L
.44231 .12965 L
.46154 .11728 L
.46489 .11538 L
.48077 .10753 L
.5 .10015 L
.51363 .09615 L
.51923 .09496 L
Mfstroke
.8 g
.51923 .13006 m
.53846 .12655 L
.55769 .12565 L
.57692 .12744 L
.59615 .13215 L
.60337 .13462 L
.61538 .14021 L
.63462 .15242 L
.63646 .15385 L
.65385 .17028 L
.65628 .17308 L
.67013 .19231 L
.67308 .19731 L
.68025 .21154 L
.68771 .23077 L
.69231 .24665 L
.69311 .25 L
.69689 .26923 L
.69934 .28846 L
.70072 .30769 L
.70124 .32692 L
.70108 .34615 L
.70045 .36538 L
.69953 .38462 L
.6985 .40385 L
.69756 .42308 L
.69691 .44231 L
.69677 .46154 L
.69731 .48077 L
.69869 .5 L
.70097 .51923 L
.70409 .53846 L
.70779 .55769 L
.71154 .57638 L
.71164 .57692 L
.71511 .59615 L
.71745 .61538 L
.7179 .63462 L
.71557 .65385 L
.71154 .66896 L
.70931 .67308 L
.69672 .69231 L
.69231 .69672 L
.67308 .70939 L
.66756 .71154 L
.65385 .71487 L
.63462 .71505 L
.61871 .71154 L
.61538 .71039 L
.59615 .70065 L
.58464 .69231 L
.57692 .68497 L
.56593 .67308 L
.55769 .66228 L
.55174 .65385 L
.53968 .63462 L
.53846 .63253 L
.52845 .61538 L
.51923 .59925 L
.51742 .59615 L
.50594 .57692 L
.5 .56728 L
.49387 .55769 L
.48117 .53846 L
.48077 .53787 L
.468 .51923 L
.46154 .50983 L
.45478 .5 L
.44231 .48139 L
.4419 .48077 L
.42971 .46154 L
.42308 .45035 L
.41855 .44231 L
.40864 .42308 L
.40385 .41263 L
.40017 .40385 L
.39322 .38462 L
.3879 .36538 L
.38462 .34896 L
.38424 .34615 L
.3823 .32692 L
.38212 .30769 L
.38378 .28846 L
.38462 .28179 L
.38736 .26923 L
.393 .25 L
.4009 .23077 L
.40385 .22477 L
.41137 .21154 L
.42308 .19468 L
.42495 .19231 L
.44231 .17338 L
.44262 .17308 L
.46154 .15734 L
.46649 .15385 L
.48077 .14518 L
.5 .13622 L
.50384 .13462 L
F
0 g
.51923 .13006 m
.53846 .12655 L
.55769 .12565 L
.57692 .12744 L
.59615 .13215 L
.60337 .13462 L
.61538 .14021 L
.63462 .15242 L
.63646 .15385 L
.65385 .17028 L
.65628 .17308 L
.67013 .19231 L
.67308 .19731 L
.68025 .21154 L
.68771 .23077 L
.69231 .24665 L
.69311 .25 L
.69689 .26923 L
.69934 .28846 L
.70072 .30769 L
.70124 .32692 L
.70108 .34615 L
.70045 .36538 L
.69953 .38462 L
.6985 .40385 L
.69756 .42308 L
.69691 .44231 L
.69677 .46154 L
.69731 .48077 L
.69869 .5 L
.70097 .51923 L
.70409 .53846 L
.70779 .55769 L
.71154 .57638 L
.71164 .57692 L
.71511 .59615 L
.71745 .61538 L
.7179 .63462 L
.71557 .65385 L
.71154 .66896 L
.70931 .67308 L
.69672 .69231 L
.69231 .69672 L
.67308 .70939 L
.66756 .71154 L
.65385 .71487 L
.63462 .71505 L
.61871 .71154 L
.61538 .71039 L
.59615 .70065 L
Mistroke
.58464 .69231 L
.57692 .68497 L
.56593 .67308 L
.55769 .66228 L
.55174 .65385 L
.53968 .63462 L
.53846 .63253 L
.52845 .61538 L
.51923 .59925 L
.51742 .59615 L
.50594 .57692 L
.5 .56728 L
.49387 .55769 L
.48117 .53846 L
.48077 .53787 L
.468 .51923 L
.46154 .50983 L
.45478 .5 L
.44231 .48139 L
.4419 .48077 L
.42971 .46154 L
.42308 .45035 L
.41855 .44231 L
.40864 .42308 L
.40385 .41263 L
.40017 .40385 L
.39322 .38462 L
.3879 .36538 L
.38462 .34896 L
.38424 .34615 L
.3823 .32692 L
.38212 .30769 L
.38378 .28846 L
.38462 .28179 L
.38736 .26923 L
.393 .25 L
.4009 .23077 L
.40385 .22477 L
.41137 .21154 L
.42308 .19468 L
.42495 .19231 L
.44231 .17338 L
.44262 .17308 L
.46154 .15734 L
.46649 .15385 L
.48077 .14518 L
.5 .13622 L
.50384 .13462 L
.51923 .13006 L
Mfstroke
.9 g
.51923 .16933 m
.53846 .16512 L
.55769 .16436 L
.57692 .1672 L
.59463 .17308 L
.59615 .17413 L
.61538 .18617 L
.62253 .19231 L
.63462 .20586 L
.63871 .21154 L
.6495 .23077 L
.65385 .24115 L
.65681 .25 L
.66163 .26923 L
.66449 .28846 L
.66575 .30769 L
.66568 .32692 L
.66447 .34615 L
.6623 .36538 L
.65928 .38462 L
.65551 .40385 L
.65385 .41139 L
.6511 .42308 L
.64605 .44231 L
.64024 .46154 L
.63462 .47753 L
.63345 .48077 L
.6253 .5 L
.61538 .51488 L
.61148 .51923 L
.59615 .52837 L
.57692 .5279 L
.55769 .52013 L
.55563 .51923 L
.53846 .50817 L
.52694 .5 L
.51923 .49331 L
.50492 .48077 L
.5 .47588 L
.48603 .46154 L
.48077 .45553 L
.46981 .44231 L
.46154 .4311 L
.45606 .42308 L
.44464 .40385 L
.44231 .3994 L
.43545 .38462 L
.42846 .36538 L
.42364 .34615 L
.42308 .34313 L
.42095 .32692 L
.42044 .30769 L
.42219 .28846 L
.42308 .28175 L
.42631 .26923 L
.43309 .25 L
.44231 .23188 L
.44299 .23077 L
.4568 .21154 L
.46154 .20621 L
.47648 .19231 L
.48077 .18902 L
.5 .17712 L
.50808 .17308 L
F
0 g
.51923 .16933 m
.53846 .16512 L
.55769 .16436 L
.57692 .1672 L
.59463 .17308 L
.59615 .17413 L
.61538 .18617 L
.62253 .19231 L
.63462 .20586 L
.63871 .21154 L
.6495 .23077 L
.65385 .24115 L
.65681 .25 L
.66163 .26923 L
.66449 .28846 L
.66575 .30769 L
.66568 .32692 L
.66447 .34615 L
.6623 .36538 L
.65928 .38462 L
.65551 .40385 L
.65385 .41139 L
.6511 .42308 L
.64605 .44231 L
.64024 .46154 L
.63462 .47753 L
.63345 .48077 L
.6253 .5 L
.61538 .51488 L
.61148 .51923 L
.59615 .52837 L
.57692 .5279 L
.55769 .52013 L
.55563 .51923 L
.53846 .50817 L
.52694 .5 L
.51923 .49331 L
.50492 .48077 L
.5 .47588 L
.48603 .46154 L
.48077 .45553 L
.46981 .44231 L
.46154 .4311 L
.45606 .42308 L
.44464 .40385 L
.44231 .3994 L
.43545 .38462 L
.42846 .36538 L
.42364 .34615 L
.42308 .34313 L
Mistroke
.42095 .32692 L
.42044 .30769 L
.42219 .28846 L
.42308 .28175 L
.42631 .26923 L
.43309 .25 L
.44231 .23188 L
.44299 .23077 L
.4568 .21154 L
.46154 .20621 L
.47648 .19231 L
.48077 .18902 L
.5 .17712 L
.50808 .17308 L
.51923 .16933 L
Mfstroke
1 g
.51923 .2206 m
.53846 .21466 L
.55769 .21438 L
.57692 .22013 L
.59324 .23077 L
.59615 .23418 L
.60809 .25 L
.61538 .26643 L
.61625 .26923 L
.62067 .28846 L
.62211 .30769 L
.62106 .32692 L
.61767 .34615 L
.61538 .35505 L
.61197 .36538 L
.60308 .38462 L
.59615 .39485 L
.58973 .40385 L
.57692 .4126 L
.55769 .41891 L
.53846 .41702 L
.51923 .40824 L
.51219 .40385 L
.5 .39232 L
.4931 .38462 L
.48077 .36543 L
.48074 .36538 L
.47249 .34615 L
.46792 .32692 L
.46667 .30769 L
.46874 .28846 L
.47453 .26923 L
.48077 .25625 L
.48488 .25 L
.5 .23321 L
.50243 .23077 L
F
0 g
.51923 .2206 m
.53846 .21466 L
.55769 .21438 L
.57692 .22013 L
.59324 .23077 L
.59615 .23418 L
.60809 .25 L
.61538 .26643 L
.61625 .26923 L
.62067 .28846 L
.62211 .30769 L
.62106 .32692 L
.61767 .34615 L
.61538 .35505 L
.61197 .36538 L
.60308 .38462 L
.59615 .39485 L
.58973 .40385 L
.57692 .4126 L
.55769 .41891 L
.53846 .41702 L
.51923 .40824 L
.51219 .40385 L
.5 .39232 L
.4931 .38462 L
.48077 .36543 L
.48074 .36538 L
.47249 .34615 L
.46792 .32692 L
.46667 .30769 L
.46874 .28846 L
.47453 .26923 L
.48077 .25625 L
.48488 .25 L
.5 .23321 L
.50243 .23077 L
.51923 .2206 L
s
.1 g
.98077 .46059 m
.9726 .44231 L
.96419 .42308 L
.96154 .41685 L
.95619 .40385 L
.94879 .38462 L
.94231 .36607 L
.94208 .36538 L
.93607 .34615 L
.93074 .32692 L
.92598 .30769 L
.92308 .29494 L
.92166 .28846 L
.91761 .26923 L
.91369 .25 L
.90975 .23077 L
.90562 .21154 L
.90385 .20366 L
.90116 .19231 L
.89622 .17308 L
.89068 .15385 L
.88462 .13524 L
.8844 .13462 L
.87722 .11538 L
.86902 .09615 L
.86538 .08838 L
.85963 .07692 L
.84886 .05769 L
.84615 .05324 L
.83649 .03846 L
.82692 .02526 L
.82222 .01923 L
.98077 .01923 L
F
0 g
.98077 .46059 m
.9726 .44231 L
.96419 .42308 L
.96154 .41685 L
.95619 .40385 L
.94879 .38462 L
.94231 .36607 L
.94208 .36538 L
.93607 .34615 L
.93074 .32692 L
.92598 .30769 L
.92308 .29494 L
.92166 .28846 L
.91761 .26923 L
.91369 .25 L
.90975 .23077 L
.90562 .21154 L
.90385 .20366 L
.90116 .19231 L
.89622 .17308 L
.89068 .15385 L
.88462 .13524 L
.8844 .13462 L
.87722 .11538 L
.86902 .09615 L
.86538 .08838 L
.85963 .07692 L
.84886 .05769 L
.84615 .05324 L
.83649 .03846 L
.82692 .02526 L
.82222 .01923 L
s
.1 g
.98077 .84572 m
.98049 .84615 L
.96699 .86538 L
.96154 .87244 L
.95147 .88462 L
.94231 .89484 L
.93365 .90385 L
.92308 .91409 L
.9131 .92308 L
.90385 .93088 L
.8892 .94231 L
.88462 .94567 L
.86538 .95875 L
.86097 .96154 L
.84615 .97035 L
.82692 .98062 L
.82663 .98077 L
.98077 .98077 L
F
0 g
.98077 .84572 m
.98049 .84615 L
.96699 .86538 L
.96154 .87244 L
.95147 .88462 L
.94231 .89484 L
.93365 .90385 L
.92308 .91409 L
.9131 .92308 L
.90385 .93088 L
.8892 .94231 L
.88462 .94567 L
.86538 .95875 L
.86097 .96154 L
.84615 .97035 L
.82692 .98062 L
.82663 .98077 L
s
.98077 .2043 m
.97783 .19231 L
.97295 .17308 L
.96776 .15385 L
.96214 .13462 L
.96154 .13264 L
.95599 .11538 L
.94919 .09615 L
.94231 .07855 L
.94163 .07692 L
.93317 .05769 L
.92371 .03846 L
.92308 .03724 L
.91309 .01923 L
.98077 .01923 L
F
.98077 .2043 m
.97783 .19231 L
.97295 .17308 L
.96776 .15385 L
.96214 .13462 L
.96154 .13264 L
.95599 .11538 L
.94919 .09615 L
.94231 .07855 L
.94163 .07692 L
.93317 .05769 L
.92371 .03846 L
.92308 .03724 L
.91309 .01923 L
s
.98077 .97619 m
.97563 .98077 L
.98077 .98077 L
F
.98077 .97619 m
.97563 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.651 .749 .922 r
.39901 .59835 .40512 .60371 .41536 .60091 .40927 .59557 Mtetra
.648 .75 .924 r
.40927 .59557 .41536 .60091 .42563 .59815 .41956 .59284 Mtetra
.645 .751 .926 r
.41956 .59284 .42563 .59815 .43595 .59544 .4299 .59016 Mtetra
.642 .752 .929 r
.4299 .59016 .43595 .59544 .4463 .59279 .44028 .58755 Mtetra
.638 .753 .932 r
.44028 .58755 .4463 .59279 .4567 .5902 .4507 .58502 Mtetra
.632 .755 .936 r
.4507 .58502 .4567 .5902 .46713 .5877 .46116 .58259 Mtetra
.626 .756 .94 r
.46116 .58259 .46713 .5877 .47761 .5853 .47167 .58026 Mtetra
.619 .758 .945 r
.47167 .58026 .47761 .5853 .48814 .58301 .48222 .57807 Mtetra
.61 .76 .951 r
.48222 .57807 .48814 .58301 .4987 .58084 .49281 .57602 Mtetra
.6 .762 .957 r
.49281 .57602 .4987 .58084 .50932 .57881 .50345 .57412 Mtetra
.587 .764 .963 r
.50345 .57412 .50932 .57881 .51998 .57692 .51414 .57239 Mtetra
.573 .767 .97 r
.51414 .57239 .51998 .57692 .5307 .57518 .52489 .57083 Mtetra
.556 .769 .977 r
.52489 .57083 .5307 .57518 .54146 .57361 .53568 .56946 Mtetra
.537 .771 .984 r
.53568 .56946 .54146 .57361 .55228 .57219 .54653 .56827 Mtetra
.515 .773 .99 r
.54653 .56827 .55228 .57219 .56316 .57093 .55744 .56727 Mtetra
.489 .775 .995 r
.55744 .56727 .56316 .57093 .57409 .56983 .56841 .56643 Mtetra
.46 .775 .997 r
.56841 .56643 .57409 .56983 .58508 .56885 .57944 .56575 Mtetra
.427 .774 .997 r
.57944 .56575 .58508 .56885 .59613 .56799 .59054 .56521 Mtetra
.392 .77 .991 r
.59054 .56521 .59613 .56799 .60725 .56722 .6017 .56477 Mtetra
.354 .765 .981 r
.6017 .56477 .60725 .56722 .61843 .56651 .61292 .56441 Mtetra
.315 .756 .965 r
.61292 .56441 .61843 .56651 .62967 .56582 .62421 .56407 Mtetra
.277 .746 .943 r
.62421 .56407 .62967 .56582 .64097 .56511 .63557 .56372 Mtetra
.241 .734 .916 r
.63557 .56372 .64097 .56511 .65233 .56434 .64699 .5633 Mtetra
.209 .722 .886 r
.64699 .5633 .65233 .56434 .66375 .56346 .65847 .56277 Mtetra
.184 .711 .854 r
.65847 .56277 .66375 .56346 .67523 .56243 .67001 .56206 Mtetra
.166 .702 .824 r
.67001 .56206 .67523 .56243 .68676 .56119 .6816 .56112 Mtetra
.156 .697 .796 r
.6816 .56112 .68676 .56119 .69834 .55971 .69324 .55991 Mtetra
.156 .697 .773 r
.69324 .55991 .69834 .55971 .70996 .55794 .70493 .55838 Mtetra
.164 .703 .756 r
.70493 .55838 .70996 .55794 .72163 .55585 .71666 .55649 Mtetra
.18 .713 .746 r
.71666 .55649 .72163 .55585 .73333 .55341 .72843 .5542 Mtetra
.205 .73 .742 r
.72843 .5542 .73333 .55341 .74506 .5506 .74023 .55149 Mtetra
.237 .751 .745 r
.74023 .55149 .74506 .5506 .75681 .54741 .75205 .54834 Mtetra
.275 .776 .754 r
.75205 .54834 .75681 .54741 .76859 .54383 .76389 .54475 Mtetra
.319 .804 .769 r
.76389 .54475 .76859 .54383 .78039 .53986 .77575 .54072 Mtetra
.367 .834 .788 r
.77575 .54072 .78039 .53986 .79221 .53552 .78762 .53626 Mtetra
.417 .863 .811 r
.78762 .53626 .79221 .53552 .80404 .53082 .7995 .53139 Mtetra
.468 .891 .835 r
.7995 .53139 .80404 .53082 .81588 .5258 .81139 .52615 Mtetra
.517 .916 .859 r
.81139 .52615 .81588 .5258 .82774 .52047 .82329 .52057 Mtetra
.564 .937 .882 r
.82329 .52057 .82774 .52047 .83961 .51489 .8352 .51468 Mtetra
.606 .952 .902 r
.8352 .51468 .83961 .51489 .8515 .50909 .84712 .50854 Mtetra
.642 .961 .919 r
.84712 .50854 .8515 .50909 .8634 .50311 .85905 .5022 Mtetra
.672 .964 .933 r
.85905 .5022 .8634 .50311 .87532 .497 .87099 .4957 Mtetra
.696 .962 .942 r
.87099 .4957 .87532 .497 .88727 .4908 .88296 .48909 Mtetra
.714 .956 .949 r
.88296 .48909 .88727 .4908 .89924 .48454 .89495 .48243 Mtetra
.727 .946 .952 r
.89495 .48243 .89924 .48454 .91124 .47827 .90697 .47574 Mtetra
.735 .934 .954 r
.90697 .47574 .91124 .47827 .92328 .47203 .91902 .46909 Mtetra
.739 .919 .953 r
.91902 .46909 .92328 .47203 .93536 .46584 .93111 .46249 Mtetra
.74 .904 .951 r
.93111 .46249 .93536 .46584 .94749 .45974 .94324 .456 Mtetra
.739 .889 .948 r
.94324 .456 .94749 .45974 .95966 .45374 .95543 .44962 Mtetra
.736 .874 .945 r
.95543 .44962 .95966 .45374 .97189 .44786 .96766 .44338 Mtetra
.649 .75 .923 r
.39285 .59299 .39901 .59835 .40927 .59557 .40313 .59023 Mtetra
.646 .751 .926 r
.40313 .59023 .40927 .59557 .41956 .59284 .41345 .58753 Mtetra
.643 .752 .928 r
.41345 .58753 .41956 .59284 .4299 .59016 .42381 .58489 Mtetra
.639 .753 .931 r
.42381 .58489 .4299 .59016 .44028 .58755 .43421 .58232 Mtetra
.634 .754 .935 r
.43421 .58232 .44028 .58755 .4507 .58502 .44466 .57986 Mtetra
.628 .756 .939 r
.44466 .57986 .4507 .58502 .46116 .58259 .45515 .57749 Mtetra
.62 .757 .944 r
.45515 .57749 .46116 .58259 .47167 .58026 .46568 .57526 Mtetra
.612 .759 .949 r
.46568 .57526 .47167 .58026 .48222 .57807 .47625 .57317 Mtetra
.602 .76 .955 r
.47625 .57317 .48222 .57807 .49281 .57602 .48687 .57124 Mtetra
.589 .762 .961 r
.48687 .57124 .49281 .57602 .50345 .57412 .49754 .56948 Mtetra
.575 .764 .968 r
.49754 .56948 .50345 .57412 .51414 .57239 .50826 .56792 Mtetra
.558 .766 .975 r
.50826 .56792 .51414 .57239 .52489 .57083 .51903 .56656 Mtetra
.538 .767 .982 r
.51903 .56656 .52489 .57083 .53568 .56946 .52986 .5654 Mtetra
.514 .768 .988 r
.52986 .5654 .53568 .56946 .54653 .56827 .54074 .56445 Mtetra
.487 .768 .994 r
.54074 .56445 .54653 .56827 .55744 .56727 .55168 .56371 Mtetra
.456 .767 .996 r
.55168 .56371 .55744 .56727 .56841 .56643 .56269 .56317 Mtetra
.42 .764 .996 r
.56269 .56317 .56841 .56643 .57944 .56575 .57376 .56281 Mtetra
.38 .758 .99 r
.57376 .56281 .57944 .56575 .59054 .56521 .58489 .5626 Mtetra
.337 .749 .979 r
.58489 .5626 .59054 .56521 .6017 .56477 .5961 .56252 Mtetra
.291 .737 .961 r
.5961 .56252 .6017 .56477 .61292 .56441 .60737 .56252 Mtetra
.244 .722 .936 r
.60737 .56252 .61292 .56441 .62421 .56407 .61871 .56256 Mtetra
.199 .704 .905 r
.61871 .56256 .62421 .56407 .63557 .56372 .63012 .56259 Mtetra
.158 .686 .868 r
.63012 .56259 .63557 .56372 .64699 .5633 .6416 .56255 Mtetra
.124 .667 .829 r
.6416 .56255 .64699 .5633 .65847 .56277 .65314 .56238 Mtetra
.097 .652 .791 r
.65314 .56238 .65847 .56277 .67001 .56206 .66474 .56202 Mtetra
.079 .64 .755 r
.66474 .56202 .67001 .56206 .6816 .56112 .6764 .56141 Mtetra
.071 .633 .723 r
.6764 .56141 .6816 .56112 .69324 .55991 .68811 .5605 Mtetra
0 0 0 r
.68811 .5605 .69324 .55991 .70493 .55838 .69987 .55922 Mtetra
.69987 .55922 .70493 .55838 .71666 .55649 .71167 .55754 Mtetra
.71167 .55754 .71666 .55649 .72843 .5542 .7235 .55542 Mtetra
.7235 .55542 .72843 .5542 .74023 .55149 .73537 .55282 Mtetra
.73537 .55282 .74023 .55149 .75205 .54834 .74725 .54973 Mtetra
.212 .726 .686 r
.74725 .54973 .75205 .54834 .76389 .54475 .75916 .54614 Mtetra
.261 .76 .704 r
.75916 .54614 .76389 .54475 .77575 .54072 .77108 .54205 Mtetra
.315 .795 .728 r
.77108 .54205 .77575 .54072 .78762 .53626 .78301 .53747 Mtetra
.372 .832 .755 r
.78301 .53747 .78762 .53626 .7995 .53139 .79494 .53243 Mtetra
.43 .867 .785 r
.79494 .53243 .7995 .53139 .81139 .52615 .80688 .52696 Mtetra
.487 .899 .815 r
.80688 .52696 .81139 .52615 .82329 .52057 .81883 .5211 Mtetra
.541 .927 .844 r
.81883 .5211 .82329 .52057 .8352 .51468 .83078 .5149 Mtetra
.59 .948 .871 r
.83078 .5149 .8352 .51468 .84712 .50854 .84273 .5084 Mtetra
.633 .962 .894 r
.84273 .5084 .84712 .50854 .85905 .5022 .85469 .50167 Mtetra
.668 .97 .912 r
.85469 .50167 .85905 .5022 .87099 .4957 .86666 .49476 Mtetra
.697 .971 .926 r
.86666 .49476 .87099 .4957 .88296 .48909 .87865 .48772 Mtetra
.719 .967 .937 r
.87865 .48772 .88296 .48909 .89495 .48243 .89065 .48062 Mtetra
.734 .959 .943 r
.89065 .48062 .89495 .48243 .90697 .47574 .90268 .47349 Mtetra
.744 .947 .947 r
.90268 .47349 .90697 .47574 .91902 .46909 .91475 .4664 Mtetra
.749 .933 .948 r
.91475 .4664 .91902 .46909 .93111 .46249 .92685 .45937 Mtetra
.751 .917 .947 r
.92685 .45937 .93111 .46249 .94324 .456 .93899 .45245 Mtetra
.749 .901 .945 r
.93899 .45245 .94324 .456 .95543 .44962 .95118 .44567 Mtetra
.746 .885 .943 r
.95118 .44567 .95543 .44962 .96766 .44338 .96342 .43905 Mtetra
.647 .751 .925 r
.38664 .58763 .39285 .59299 .40313 .59023 .39694 .5849 Mtetra
.644 .752 .928 r
.39694 .5849 .40313 .59023 .41345 .58753 .40729 .58223 Mtetra
.64 .753 .931 r
.40729 .58223 .41345 .58753 .42381 .58489 .41768 .57963 Mtetra
.635 .754 .934 r
.41768 .57963 .42381 .58489 .43421 .58232 .4281 .57712 Mtetra
.63 .755 .938 r
.4281 .57712 .43421 .58232 .44466 .57986 .43857 .57471 Mtetra
.623 .756 .942 r
.43857 .57471 .44466 .57986 .45515 .57749 .44908 .57243 Mtetra
.614 .758 .947 r
.44908 .57243 .45515 .57749 .46568 .57526 .45964 .57029 Mtetra
.604 .759 .953 r
.45964 .57029 .46568 .57526 .47625 .57317 .47024 .56831 Mtetra
.593 .76 .959 r
.47024 .56831 .47625 .57317 .48687 .57124 .48088 .56651 Mtetra
.578 .762 .965 r
.48088 .56651 .48687 .57124 .49754 .56948 .49158 .5649 Mtetra
.561 .763 .972 r
.49158 .5649 .49754 .56948 .50826 .56792 .50232 .56351 Mtetra
.541 .764 .979 r
.50232 .56351 .50826 .56792 .51903 .56656 .51312 .56235 Mtetra
.518 .764 .986 r
.51312 .56235 .51903 .56656 .52986 .5654 .52398 .56142 Mtetra
.49 .763 .992 r
.52398 .56142 .52986 .5654 .54074 .56445 .53489 .56072 Mtetra
.457 .761 .995 r
.53489 .56072 .54074 .56445 .55168 .56371 .54587 .56026 Mtetra
.419 .756 .995 r
.54587 .56026 .55168 .56371 .56269 .56317 .55691 .56002 Mtetra
.377 .749 .99 r
.55691 .56002 .56269 .56317 .57376 .56281 .56802 .55999 Mtetra
.329 .738 .98 r
.56802 .55999 .57376 .56281 .58489 .5626 .5792 .56014 Mtetra
.278 .722 .961 r
.5792 .56014 .58489 .5626 .5961 .56252 .59045 .56042 Mtetra
.224 .703 .935 r
.59045 .56042 .5961 .56252 .60737 .56252 .60177 .56081 Mtetra
.172 .681 .901 r
.60177 .56081 .60737 .56252 .61871 .56256 .61316 .56125 Mtetra
.122 .656 .86 r
.61316 .56125 .61871 .56256 .63012 .56259 .62462 .56167 Mtetra
.078 .632 .816 r
.62462 .56167 .63012 .56259 .6416 .56255 .63615 .56203 Mtetra
.042 .609 .77 r
.63615 .56203 .6416 .56255 .65314 .56238 .64776 .56225 Mtetra
.016 .59 .727 r
.64776 .56225 .65314 .56238 .66474 .56202 .65942 .56226 Mtetra
0 0 0 r
.65942 .56226 .66474 .56202 .6764 .56141 .67115 .562 Mtetra
.005 0 0 r
.67115 .562 .6764 .56141 .68811 .5605 .68293 .5614 Mtetra
0 0 0 r
.68293 .5614 .68811 .5605 .69987 .55922 .69476 .5604 Mtetra
.69476 .5604 .69987 .55922 .71167 .55754 .70663 .55895 Mtetra
.70663 .55895 .71167 .55754 .7235 .55542 .71853 .557 Mtetra
.71853 .557 .7235 .55542 .73537 .55282 .73047 .55453 Mtetra
.73047 .55453 .73537 .55282 .74725 .54973 .74242 .5515 Mtetra
.74242 .5515 .74725 .54973 .75916 .54614 .7544 .54792 Mtetra
.7544 .54792 .75916 .54614 .77108 .54205 .76638 .54377 Mtetra
.274 .761 .676 r
.76638 .54377 .77108 .54205 .78301 .53747 .77837 .53907 Mtetra
.336 .804 .708 r
.77837 .53907 .78301 .53747 .79494 .53243 .79036 .53385 Mtetra
.4 .845 .742 r
.79036 .53385 .79494 .53243 .80688 .52696 .80235 .52815 Mtetra
.464 .883 .776 r
.80235 .52815 .80688 .52696 .81883 .5211 .81434 .522 Mtetra
.524 .916 .81 r
.81434 .522 .81883 .5211 .83078 .5149 .82633 .51547 Mtetra
.579 .943 .841 r
.82633 .51547 .83078 .5149 .84273 .5084 .83832 .5086 Mtetra
.627 .962 .869 r
.83832 .5086 .84273 .5084 .85469 .50167 .85031 .50147 Mtetra
.668 .973 .892 r
.85031 .50147 .85469 .50167 .86666 .49476 .86231 .49413 Mtetra
.7 .978 .91 r
.86231 .49413 .86666 .49476 .87865 .48772 .87431 .48664 Mtetra
.725 .976 .923 r
.87431 .48664 .87865 .48772 .89065 .48062 .88634 .47907 Mtetra
.742 .969 .932 r
.88634 .47907 .89065 .48062 .90268 .47349 .89838 .47148 Mtetra
.754 .958 .938 r
.89838 .47148 .90268 .47349 .91475 .4664 .91046 .46392 Mtetra
.76 .944 .941 r
.91046 .46392 .91475 .4664 .92685 .45937 .92256 .45643 Mtetra
.762 .928 .942 r
.92256 .45643 .92685 .45937 .93899 .45245 .93471 .44907 Mtetra
.761 .912 .941 r
.93471 .44907 .93899 .45245 .95118 .44567 .94691 .44186 Mtetra
.757 .895 .94 r
.94691 .44186 .95118 .44567 .96342 .43905 .95916 .43484 Mtetra
.644 .752 .928 r
.38038 .58228 .38664 .58763 .39694 .5849 .39071 .57958 Mtetra
.641 .753 .93 r
.39071 .57958 .39694 .5849 .40729 .58223 .40108 .57694 Mtetra
.637 .754 .933 r
.40108 .57694 .40729 .58223 .41768 .57963 .41149 .57439 Mtetra
.631 .755 .937 r
.41149 .57439 .41768 .57963 .4281 .57712 .42194 .57194 Mtetra
.625 .756 .941 r
.42194 .57194 .4281 .57712 .43857 .57471 .43243 .5696 Mtetra
.617 .757 .945 r
.43243 .5696 .43857 .57471 .44908 .57243 .44297 .56739 Mtetra
.608 .758 .951 r
.44297 .56739 .44908 .57243 .45964 .57029 .45355 .56535 Mtetra
.597 .759 .956 r
.45355 .56535 .45964 .57029 .47024 .56831 .46417 .56348 Mtetra
.583 .76 .963 r
.46417 .56348 .47024 .56831 .48088 .56651 .47484 .56181 Mtetra
.567 .761 .97 r
.47484 .56181 .48088 .56651 .49158 .5649 .48557 .56036 Mtetra
.547 .761 .977 r
.48557 .56036 .49158 .5649 .50232 .56351 .49634 .55915 Mtetra
.524 .761 .983 r
.49634 .55915 .50232 .56351 .51312 .56235 .50717 .55819 Mtetra
.496 .759 .989 r
.50717 .55819 .51312 .56235 .52398 .56142 .51805 .55749 Mtetra
.463 .756 .993 r
.51805 .55749 .52398 .56142 .53489 .56072 .529 .55706 Mtetra
.425 .75 .994 r
.529 .55706 .53489 .56072 .54587 .56026 .54001 .55689 Mtetra
.381 .742 .991 r
.54001 .55689 .54587 .56026 .55691 .56002 .55108 .55696 Mtetra
.331 .729 .982 r
.55108 .55696 .55691 .56002 .56802 .55999 .56223 .55727 Mtetra
.276 .712 .965 r
.56223 .55727 .56802 .55999 .5792 .56014 .57345 .55777 Mtetra
.218 .691 .939 r
.57345 .55777 .5792 .56014 .59045 .56042 .58474 .55844 Mtetra
.158 .665 .905 r
.58474 .55844 .59045 .56042 .60177 .56081 .59611 .55923 Mtetra
.101 .636 .862 r
.59611 .55923 .60177 .56081 .61316 .56125 .60755 .56007 Mtetra
.049 .606 .814 r
.60755 .56007 .61316 .56125 .62462 .56167 .61907 .56091 Mtetra
.004 .577 .764 r
.61907 .56091 .62462 .56167 .63615 .56203 .63066 .56168 Mtetra
0 .552 .715 r
.63066 .56168 .63615 .56203 .64776 .56225 .64232 .5623 Mtetra
.054 0 0 r
.64232 .5623 .64776 .56225 .65942 .56226 .65405 .5627 Mtetra
.067 0 0 r
.65405 .5627 .65942 .56226 .67115 .562 .66584 .5628 Mtetra
.069 0 0 r
.66584 .5628 .67115 .562 .68293 .5614 .67769 .56253 Mtetra
.06 0 0 r
.67769 .56253 .68293 .5614 .69476 .5604 .68959 .56182 Mtetra
.041 0 0 r
.68959 .56182 .69476 .5604 .70663 .55895 .70154 .56061 Mtetra
.013 0 0 r
.70154 .56061 .70663 .55895 .71853 .557 .71352 .55886 Mtetra
0 0 0 r
.71352 .55886 .71853 .557 .73047 .55453 .72552 .55652 Mtetra
.72552 .55652 .73047 .55453 .74242 .5515 .73755 .55357 Mtetra
.73755 .55357 .74242 .5515 .7544 .54792 .74959 .54999 Mtetra
.74959 .54999 .7544 .54792 .76638 .54377 .76164 .54578 Mtetra
.76164 .54578 .76638 .54377 .77837 .53907 .77369 .54097 Mtetra
.314 .784 .673 r
.77369 .54097 .77837 .53907 .79036 .53385 .78574 .53557 Mtetra
.383 .83 .71 r
.78574 .53557 .79036 .53385 .80235 .52815 .79779 .52963 Mtetra
.452 .872 .748 r
.79779 .52963 .80235 .52815 .81434 .522 .80983 .5232 Mtetra
.517 .909 .784 r
.80983 .5232 .81434 .522 .82633 .51547 .82186 .51632 Mtetra
.576 .94 .818 r
.82186 .51632 .82633 .51547 .83832 .5086 .83388 .50907 Mtetra
.628 .962 .848 r
.83388 .50907 .83832 .5086 .85031 .50147 .84591 .50152 Mtetra
.672 .976 .874 r
.84591 .50152 .85031 .50147 .86231 .49413 .85793 .49373 Mtetra
.707 .982 .894 r
.85793 .49373 .86231 .49413 .87431 .48664 .86996 .48578 Mtetra
.734 .982 .91 r
.86996 .48578 .87431 .48664 .88634 .47907 .882 .47773 Mtetra
.753 .976 .921 r
.882 .47773 .88634 .47907 .89838 .47148 .89406 .46965 Mtetra
.765 .966 .928 r
.89406 .46965 .89838 .47148 .91046 .46392 .90614 .4616 Mtetra
.772 .952 .933 r
.90614 .4616 .91046 .46392 .92256 .45643 .91826 .45364 Mtetra
.774 .937 .935 r
.91826 .45364 .92256 .45643 .93471 .44907 .93042 .44582 Mtetra
.772 .921 .936 r
.93042 .44582 .93471 .44907 .94691 .44186 .94262 .43816 Mtetra
.768 .904 .935 r
.94262 .43816 .94691 .44186 .95916 .43484 .95487 .43071 Mtetra
.642 .753 .93 r
.37408 .57694 .38038 .58228 .39071 .57958 .38443 .57427 Mtetra
.638 .754 .932 r
.38443 .57427 .39071 .57958 .40108 .57694 .39482 .57167 Mtetra
.633 .755 .936 r
.39482 .57167 .40108 .57694 .41149 .57439 .40526 .56917 Mtetra
.627 .756 .939 r
.40526 .56917 .41149 .57439 .42194 .57194 .41573 .56677 Mtetra
.62 .757 .944 r
.41573 .56677 .42194 .57194 .43243 .5696 .42625 .5645 Mtetra
.612 .758 .949 r
.42625 .5645 .43243 .5696 .44297 .56739 .43681 .56238 Mtetra
.601 .759 .954 r
.43681 .56238 .44297 .56739 .45355 .56535 .44741 .56043 Mtetra
.588 .759 .96 r
.44741 .56043 .45355 .56535 .46417 .56348 .45806 .55868 Mtetra
.573 .76 .967 r
.45806 .55868 .46417 .56348 .47484 .56181 .46876 .55715 Mtetra
.554 .759 .973 r
.46876 .55715 .47484 .56181 .48557 .56036 .4795 .55586 Mtetra
.532 .759 .98 r
.4795 .55586 .48557 .56036 .49634 .55915 .4903 .55483 Mtetra
.505 .757 .986 r
.4903 .55483 .49634 .55915 .50717 .55819 .50116 .55408 Mtetra
.473 .753 .991 r
.50116 .55408 .50717 .55819 .51805 .55749 .51207 .55362 Mtetra
.435 .747 .993 r
.51207 .55362 .51805 .55749 .529 .55706 .52305 .55344 Mtetra
.392 .738 .992 r
.52305 .55344 .529 .55706 .54001 .55689 .53409 .55356 Mtetra
.341 .725 .985 r
.53409 .55356 .54001 .55689 .55108 .55696 .5452 .55395 Mtetra
.285 .707 .97 r
.5452 .55395 .55108 .55696 .56223 .55727 .55639 .5546 Mtetra
.223 .684 .947 r
.55639 .5546 .56223 .55727 .57345 .55777 .56764 .55548 Mtetra
.159 .656 .914 r
.56764 .55548 .57345 .55777 .58474 .55844 .57898 .55654 Mtetra
.096 .624 .873 r
.57898 .55654 .58474 .55844 .59611 .55923 .59039 .55772 Mtetra
.036 .59 .824 r
.59039 .55772 .59611 .55923 .60755 .56007 .60189 .55898 Mtetra
0 .556 .771 r
.60189 .55898 .60755 .56007 .61907 .56091 .61346 .56024 Mtetra
0 .526 .718 r
.61346 .56024 .61907 .56091 .63066 .56168 .62511 .56143 Mtetra
.091 0 0 r
.62511 .56143 .63066 .56168 .64232 .5623 .63683 .56246 Mtetra
.112 0 0 r
.63683 .56246 .64232 .5623 .65405 .5627 .64862 .56325 Mtetra
.121 0 0 r
.64862 .56325 .65405 .5627 .66584 .5628 .66048 .56372 Mtetra
.118 0 0 r
.66048 .56372 .66584 .5628 .67769 .56253 .6724 .56379 Mtetra
.105 0 0 r
.6724 .56379 .67769 .56253 .68959 .56182 .68437 .56338 Mtetra
.082 0 0 r
.68437 .56338 .68959 .56182 .70154 .56061 .69639 .56243 Mtetra
.049 0 0 r
.69639 .56243 .70154 .56061 .71352 .55886 .70844 .56087 Mtetra
.007 0 0 r
.70844 .56087 .71352 .55886 .72552 .55652 .72052 .55867 Mtetra
0 0 0 r
.72052 .55867 .72552 .55652 .73755 .55357 .73262 .5558 Mtetra
.73262 .5558 .73755 .55357 .74959 .54999 .74474 .55224 Mtetra
.74474 .55224 .74959 .54999 .76164 .54578 .75685 .54798 Mtetra
.75685 .54798 .76164 .54578 .77369 .54097 .76897 .54306 Mtetra
.307 .776 .655 r
.76897 .54306 .77369 .54097 .78574 .53557 .78108 .53748 Mtetra
.381 .825 .694 r
.78108 .53748 .78574 .53557 .79779 .52963 .79318 .5313 Mtetra
.453 .87 .733 r
.79318 .5313 .79779 .52963 .80983 .5232 .80527 .52457 Mtetra
.522 .909 .77 r
.80527 .52457 .80983 .5232 .82186 .51632 .81734 .51735 Mtetra
.584 .941 .805 r
.81734 .51735 .82186 .51632 .83388 .50907 .82941 .50971 Mtetra
.638 .964 .835 r
.82941 .50971 .83388 .50907 .84591 .50152 .84146 .50173 Mtetra
.683 .979 .861 r
.84146 .50173 .84591 .50152 .85793 .49373 .85352 .49348 Mtetra
.719 .987 .882 r
.85352 .49348 .85793 .49373 .86996 .48578 .86557 .48505 Mtetra
.747 .987 .898 r
.86557 .48505 .86996 .48578 .882 .47773 .87763 .47651 Mtetra
.766 .981 .91 r
.87763 .47651 .882 .47773 .89406 .46965 .8897 .46794 Mtetra
.778 .971 .919 r
.8897 .46794 .89406 .46965 .90614 .4616 .9018 .45939 Mtetra
.785 .958 .924 r
.9018 .45939 .90614 .4616 .91826 .45364 .91392 .45094 Mtetra
.786 .943 .928 r
.91392 .45094 .91826 .45364 .93042 .44582 .92609 .44264 Mtetra
.784 .927 .929 r
.92609 .44264 .93042 .44582 .94262 .43816 .93829 .43452 Mtetra
.78 .91 .929 r
.93829 .43452 .94262 .43816 .95487 .43071 .95055 .42664 Mtetra
.639 .754 .932 r
.36773 .5716 .37408 .57694 .38443 .57427 .3781 .56897 Mtetra
.635 .755 .935 r
.3781 .56897 .38443 .57427 .39482 .57167 .38852 .56642 Mtetra
.63 .756 .938 r
.38852 .56642 .39482 .57167 .40526 .56917 .39897 .56396 Mtetra
.623 .757 .942 r
.39897 .56396 .40526 .56917 .41573 .56677 .40947 .56162 Mtetra
.615 .758 .947 r
.40947 .56162 .41573 .56677 .42625 .5645 .42001 .55943 Mtetra
.606 .759 .952 r
.42001 .55943 .42625 .5645 .43681 .56238 .43059 .55739 Mtetra
.594 .759 .957 r
.43059 .55739 .43681 .56238 .44741 .56043 .44122 .55554 Mtetra
.579 .759 .964 r
.44122 .55554 .44741 .56043 .45806 .55868 .4519 .55391 Mtetra
.562 .759 .97 r
.4519 .55391 .45806 .55868 .46876 .55715 .46262 .55252 Mtetra
.541 .757 .977 r
.46262 .55252 .46876 .55715 .4795 .55586 .47339 .55139 Mtetra
.516 .755 .983 r
.47339 .55139 .4795 .55586 .4903 .55483 .48422 .55054 Mtetra
.486 .751 .988 r
.48422 .55054 .4903 .55483 .50116 .55408 .4951 .55 Mtetra
.45 .745 .992 r
.4951 .55 .50116 .55408 .51207 .55362 .50604 .54977 Mtetra
.407 .736 .992 r
.50604 .54977 .51207 .55362 .52305 .55344 .51705 .54986 Mtetra
.358 .724 .987 r
.51705 .54986 .52305 .55344 .53409 .55356 .52812 .55026 Mtetra
.302 .706 .976 r
.52812 .55026 .53409 .55356 .5452 .55395 .53927 .55097 Mtetra
.24 .683 .957 r
.53927 .55097 .5452 .55395 .55639 .5546 .55049 .55196 Mtetra
.173 .654 .928 r
.55049 .55196 .55639 .5546 .56764 .55548 .56178 .5532 Mtetra
.105 .621 .889 r
.56178 .5532 .56764 .55548 .57898 .55654 .57316 .55465 Mtetra
.04 .584 .842 r
.57316 .55465 .57898 .55654 .59039 .55772 .58462 .55624 Mtetra
0 .547 .789 r
.58462 .55624 .59039 .55772 .60189 .55898 .59616 .55791 Mtetra
0 .512 .735 r
.59616 .55791 .60189 .55898 .61346 .56024 .60779 .5596 Mtetra
.112 0 0 r
.60779 .5596 .61346 .56024 .62511 .56143 .61949 .5612 Mtetra
.14 0 0 r
.61949 .5612 .62511 .56143 .63683 .56246 .63127 .56264 Mtetra
.157 0 0 r
.63127 .56264 .63683 .56246 .64862 .56325 .64313 .56383 Mtetra
.161 0 0 r
.64313 .56383 .64862 .56325 .66048 .56372 .65506 .56467 Mtetra
.155 0 0 r
.65506 .56467 .66048 .56372 .6724 .56379 .66705 .56508 Mtetra
.137 0 0 r
.66705 .56508 .6724 .56379 .68437 .56338 .67909 .56497 Mtetra
.109 0 0 r
.67909 .56497 .68437 .56338 .69639 .56243 .69118 .56427 Mtetra
.071 0 0 r
.69118 .56427 .69639 .56243 .70844 .56087 .70331 .56292 Mtetra
.024 0 0 r
.70331 .56292 .70844 .56087 .72052 .55867 .71546 .56087 Mtetra
0 0 0 r
.71546 .56087 .72052 .55867 .73262 .5558 .72763 .55808 Mtetra
.72763 .55808 .73262 .5558 .74474 .55224 .73982 .55454 Mtetra
.73982 .55454 .74474 .55224 .75685 .54798 .752 .55024 Mtetra
.752 .55024 .75685 .54798 .76897 .54306 .76418 .54519 Mtetra
.318 .782 .656 r
.76418 .54519 .76897 .54306 .78108 .53748 .77635 .53944 Mtetra
.396 .833 .695 r
.77635 .53944 .78108 .53748 .79318 .5313 .78851 .53302 Mtetra
.471 .879 .734 r
.78851 .53302 .79318 .5313 .80527 .52457 .80065 .52599 Mtetra
.541 .917 .77 r
.80065 .52599 .80527 .52457 .81734 .51735 .81277 .51842 Mtetra
.603 .948 .803 r
.81277 .51842 .81734 .51735 .82941 .50971 .82488 .51039 Mtetra
.657 .97 .831 r
.82488 .51039 .82941 .50971 .84146 .50173 .83697 .50198 Mtetra
.702 .984 .855 r
.83697 .50198 .84146 .50173 .85352 .49348 .84905 .49328 Mtetra
.737 .99 .875 r
.84905 .49328 .85352 .49348 .86557 .48505 .86113 .48437 Mtetra
.763 .99 .89 r
.86113 .48437 .86557 .48505 .87763 .47651 .87321 .47533 Mtetra
.781 .984 .901 r
.87321 .47533 .87763 .47651 .8897 .46794 .8853 .46625 Mtetra
.792 .974 .91 r
.8853 .46625 .8897 .46794 .9018 .45939 .89741 .45721 Mtetra
.798 .961 .916 r
.89741 .45721 .9018 .45939 .91392 .45094 .90955 .44826 Mtetra
.799 .946 .919 r
.90955 .44826 .91392 .45094 .92609 .44264 .92172 .43947 Mtetra
.797 .93 .922 r
.92172 .43947 .92609 .44264 .93829 .43452 .93393 .43089 Mtetra
.791 .913 .923 r
.93393 .43089 .93829 .43452 .95055 .42664 .9462 .42256 Mtetra
.636 .756 .934 r
.36132 .56628 .36773 .5716 .3781 .56897 .37172 .56369 Mtetra
.632 .757 .937 r
.37172 .56369 .3781 .56897 .38852 .56642 .38216 .56118 Mtetra
.626 .757 .941 r
.38216 .56118 .38852 .56642 .39897 .56396 .39264 .55877 Mtetra
.619 .758 .945 r
.39264 .55877 .39897 .56396 .40947 .56162 .40316 .5565 Mtetra
.61 .759 .95 r
.40316 .5565 .40947 .56162 .42001 .55943 .41372 .55437 Mtetra
.599 .759 .955 r
.41372 .55437 .42001 .55943 .43059 .55739 .42433 .55242 Mtetra
.586 .759 .961 r
.42433 .55242 .43059 .55739 .44122 .55554 .43498 .55068 Mtetra
.57 .758 .967 r
.43498 .55068 .44122 .55554 .4519 .55391 .44568 .54916 Mtetra
.551 .757 .973 r
.44568 .54916 .4519 .55391 .46262 .55252 .45643 .5479 Mtetra
.528 .755 .979 r
.45643 .5479 .46262 .55252 .47339 .55139 .46723 .54693 Mtetra
.5 .751 .985 r
.46723 .54693 .47339 .55139 .48422 .55054 .47808 .54626 Mtetra
.466 .745 .989 r
.47808 .54626 .48422 .55054 .4951 .55 .48899 .54592 Mtetra
.426 .737 .991 r
.48899 .54592 .4951 .55 .50604 .54977 .49996 .54592 Mtetra
.379 .725 .989 r
.49996 .54592 .50604 .54977 .51705 .54986 .511 .54627 Mtetra
.325 .708 .981 r
.511 .54627 .51705 .54986 .52812 .55026 .5221 .54696 Mtetra
.264 .686 .966 r
.5221 .54696 .52812 .55026 .53927 .55097 .53328 .54798 Mtetra
.197 .658 .942 r
.53328 .54798 .53927 .55097 .55049 .55196 .54453 .54931 Mtetra
.127 .624 .908 r
.54453 .54931 .55049 .55196 .56178 .5532 .55587 .55091 Mtetra
.058 .587 .865 r
.55587 .55091 .56178 .5532 .57316 .55465 .56728 .55273 Mtetra
0 .547 .815 r
.56728 .55273 .57316 .55465 .58462 .55624 .57879 .55472 Mtetra
0 .508 .761 r
.57879 .55472 .58462 .55624 .59616 .55791 .59038 .5568 Mtetra
0 .473 .707 r
.59038 .5568 .59616 .55791 .60779 .5596 .60205 .55889 Mtetra
.153 0 0 r
.60205 .55889 .60779 .5596 .61949 .5612 .61381 .56091 Mtetra
.177 0 0 r
.61381 .56091 .61949 .5612 .63127 .56264 .62565 .56276 Mtetra
.19 0 0 r
.62565 .56276 .63127 .56264 .64313 .56383 .63757 .56434 Mtetra
.63757 .56434 .64313 .56383 .65506 .56467 .64956 .56554 Mtetra
.179 0 0 r
.64956 .56554 .65506 .56467 .66705 .56508 .66162 .56629 Mtetra
.156 0 0 r
.66162 .56629 .66705 .56508 .67909 .56497 .67373 .56648 Mtetra
.123 0 0 r
.67373 .56648 .67909 .56497 .69118 .56427 .6859 .56603 Mtetra
.08 0 0 r
.6859 .56603 .69118 .56427 .70331 .56292 .69809 .56488 Mtetra
.026 0 0 r
.69809 .56488 .70331 .56292 .71546 .56087 .71032 .56297 Mtetra
0 0 0 r
.71032 .56297 .71546 .56087 .72763 .55808 .72257 .56026 Mtetra
.72257 .56026 .72763 .55808 .73982 .55454 .73482 .55674 Mtetra
.73482 .55674 .73982 .55454 .752 .55024 .74708 .55239 Mtetra
.74708 .55239 .752 .55024 .76418 .54519 .75933 .54724 Mtetra
.346 .802 .678 r
.75933 .54724 .76418 .54519 .77635 .53944 .77156 .54131 Mtetra
.427 .853 .715 r
.77156 .54131 .77635 .53944 .78851 .53302 .78377 .53465 Mtetra
.503 .897 .751 r
.78377 .53465 .78851 .53302 .80065 .52599 .79597 .52733 Mtetra
.573 .933 .783 r
.79597 .52733 .80065 .52599 .81277 .51842 .80814 .51942 Mtetra
.634 .961 .812 r
.80814 .51942 .81277 .51842 .82488 .51039 .82029 .51101 Mtetra
.685 .979 .836 r
.82029 .51101 .82488 .51039 .83697 .50198 .83242 .50217 Mtetra
.726 .99 .856 r
.83242 .50217 .83697 .50198 .84905 .49328 .84453 .49301 Mtetra
.759 .993 .872 r
.84453 .49301 .84905 .49328 .86113 .48437 .85664 .48362 Mtetra
.782 .991 .885 r
.85664 .48362 .86113 .48437 .87321 .47533 .86874 .47409 Mtetra
.798 .984 .895 r
.86874 .47409 .87321 .47533 .8853 .46625 .88085 .46451 Mtetra
.808 .974 .902 r
.88085 .46451 .8853 .46625 .89741 .45721 .89297 .45496 Mtetra
.812 .961 .907 r
.89297 .45496 .89741 .45721 .90955 .44826 .90512 .44552 Mtetra
.812 .946 .911 r
.90512 .44552 .90955 .44826 .92172 .43947 .9173 .43625 Mtetra
.808 .93 .914 r
.9173 .43625 .92172 .43947 .93393 .43089 .92953 .42721 Mtetra
.802 .914 .915 r
.92953 .42721 .93393 .43089 .9462 .42256 .9418 .41843 Mtetra
.633 .757 .937 r
.35487 .56097 .36132 .56628 .37172 .56369 .36529 .55842 Mtetra
.628 .758 .94 r
.36529 .55842 .37172 .56369 .38216 .56118 .37575 .55596 Mtetra
.622 .758 .944 r
.37575 .55596 .38216 .56118 .39264 .55877 .38625 .55361 Mtetra
.614 .759 .948 r
.38625 .55361 .39264 .55877 .40316 .5565 .3968 .55139 Mtetra
.604 .759 .953 r
.3968 .55139 .40316 .5565 .41372 .55437 .40739 .54934 Mtetra
.593 .759 .958 r
.40739 .54934 .41372 .55437 .42433 .55242 .41802 .54748 Mtetra
.578 .759 .964 r
.41802 .54748 .42433 .55242 .43498 .55068 .42869 .54583 Mtetra
.561 .758 .97 r
.42869 .54583 .43498 .55068 .44568 .54916 .43942 .54443 Mtetra
.54 .755 .976 r
.43942 .54443 .44568 .54916 .45643 .5479 .45019 .5433 Mtetra
.514 .752 .982 r
.45019 .5433 .45643 .5479 .46723 .54693 .46101 .54248 Mtetra
.484 .747 .987 r
.46101 .54248 .46723 .54693 .47808 .54626 .47189 .54199 Mtetra
.447 .739 .99 r
.47189 .54199 .47808 .54626 .48899 .54592 .48282 .54185 Mtetra
.403 .727 .99 r
.48282 .54185 .48899 .54592 .49996 .54592 .49382 .54207 Mtetra
.352 .712 .986 r
.49382 .54207 .49996 .54592 .511 .54627 .50488 .54267 Mtetra
.294 .691 .975 r
.50488 .54267 .511 .54627 .5221 .54696 .51602 .54363 Mtetra
.229 .665 .956 r
.51602 .54363 .5221 .54696 .53328 .54798 .52723 .54495 Mtetra
.159 .633 .928 r
.52723 .54495 .53328 .54798 .54453 .54931 .53852 .5466 Mtetra
.087 .596 .89 r
.53852 .5466 .54453 .54931 .55587 .55091 .54989 .54855 Mtetra
.017 .555 .845 r
.54989 .54855 .55587 .55091 .56728 .55273 .56134 .55074 Mtetra
0 .515 .794 r
.56134 .55074 .56728 .55273 .57879 .55472 .57289 .5531 Mtetra
0 .476 .741 r
.57289 .5531 .57879 .55472 .59038 .5568 .58452 .55558 Mtetra
.149 0 0 r
.58452 .55558 .59038 .5568 .60205 .55889 .59625 .55807 Mtetra
.182 0 0 r
.59625 .55807 .60205 .55889 .61381 .56091 .60806 .56048 Mtetra
.203 0 0 r
.60806 .56048 .61381 .56091 .62565 .56276 .61996 .56272 Mtetra
.211 0 0 r
.61996 .56272 .62565 .56276 .63757 .56434 .63194 .56467 Mtetra
.207 0 0 r
.63194 .56467 .63757 .56434 .64956 .56554 .64399 .56623 Mtetra
.19 0 0 r
.64399 .56623 .64956 .56554 .66162 .56629 .65612 .56729 Mtetra
.163 0 0 r
.65612 .56729 .66162 .56629 .67373 .56648 .6683 .56777 Mtetra
.123 0 0 r
.6683 .56777 .67373 .56648 .6859 .56603 .68053 .56756 Mtetra
.073 0 0 r
.68053 .56756 .6859 .56603 .69809 .56488 .6928 .56661 Mtetra
.013 0 0 r
.6928 .56661 .69809 .56488 .71032 .56297 .7051 .56483 Mtetra
0 0 0 r
.7051 .56483 .71032 .56297 .72257 .56026 .71742 .5622 Mtetra
.71742 .5622 .72257 .56026 .73482 .55674 .72975 .55869 Mtetra
.72975 .55869 .73482 .55674 .74708 .55239 .74207 .5543 Mtetra
.306 .781 .681 r
.74207 .5543 .74708 .55239 .75933 .54724 .75438 .54904 Mtetra
.392 .836 .717 r
.75438 .54904 .75933 .54724 .77156 .54131 .76668 .54294 Mtetra
.474 .884 .751 r
.76668 .54294 .77156 .54131 .78377 .53465 .77895 .53605 Mtetra
.55 .923 .781 r
.77895 .53605 .78377 .53465 .79597 .52733 .7912 .52844 Mtetra
.616 .954 .807 r
.7912 .52844 .79597 .52733 .80814 .51942 .80342 .5202 Mtetra
.673 .975 .829 r
.80342 .5202 .80814 .51942 .82029 .51101 .81562 .5114 Mtetra
.719 .988 .847 r
.81562 .5114 .82029 .51101 .83242 .50217 .82779 .50215 Mtetra
.756 .994 .862 r
.82779 .50215 .83242 .50217 .84453 .49301 .83993 .49254 Mtetra
.783 .994 .873 r
.83993 .49254 .84453 .49301 .85664 .48362 .85207 .48268 Mtetra
.803 .99 .882 r
.85207 .48268 .85664 .48362 .86874 .47409 .8642 .47267 Mtetra
.816 .981 .889 r
.8642 .47267 .86874 .47409 .88085 .46451 .87633 .4626 Mtetra
.823 .97 .895 r
.87633 .4626 .88085 .46451 .89297 .45496 .88847 .45256 Mtetra
.825 .957 .899 r
.88847 .45256 .89297 .45496 .90512 .44552 .90063 .44263 Mtetra
.824 .943 .903 r
.90063 .44263 .90512 .44552 .9173 .43625 .91283 .43289 Mtetra
.819 .928 .906 r
.91283 .43289 .9173 .43625 .92953 .42721 .92506 .42339 Mtetra
.812 .912 .908 r
.92506 .42339 .92953 .42721 .9418 .41843 .93735 .41419 Mtetra
.63 .758 .939 r
.34836 .55568 .35487 .56097 .36529 .55842 .3588 .55317 Mtetra
.624 .759 .943 r
.3588 .55317 .36529 .55842 .37575 .55596 .36929 .55075 Mtetra
.618 .759 .947 r
.36929 .55075 .37575 .55596 .38625 .55361 .37982 .54846 Mtetra
.609 .76 .951 r
.37982 .54846 .38625 .55361 .3968 .55139 .39038 .54631 Mtetra
.599 .76 .956 r
.39038 .54631 .3968 .55139 .40739 .54934 .40099 .54433 Mtetra
.586 .76 .961 r
.40099 .54433 .40739 .54934 .41802 .54748 .41165 .54255 Mtetra
.571 .759 .967 r
.41165 .54255 .41802 .54748 .42869 .54583 .42235 .541 Mtetra
.552 .757 .973 r
.42235 .541 .42869 .54583 .43942 .54443 .4331 .53971 Mtetra
.529 .753 .979 r
.4331 .53971 .43942 .54443 .45019 .5433 .44389 .53871 Mtetra
.501 .749 .984 r
.44389 .53871 .45019 .5433 .46101 .54248 .45474 .53804 Mtetra
.468 .742 .988 r
.45474 .53804 .46101 .54248 .47189 .54199 .46564 .53772 Mtetra
.428 .732 .99 r
.46564 .53772 .47189 .54199 .48282 .54185 .4766 .53777 Mtetra
.381 .718 .988 r
.4766 .53777 .48282 .54185 .49382 .54207 .48763 .5382 Mtetra
.326 .699 .981 r
.48763 .5382 .49382 .54207 .50488 .54267 .49872 .53903 Mtetra
.265 .675 .967 r
.49872 .53903 .50488 .54267 .51602 .54363 .50988 .54025 Mtetra
.197 .645 .945 r
.50988 .54025 .51602 .54363 .52723 .54495 .52112 .54186 Mtetra
.125 .609 .914 r
.52112 .54186 .52723 .54495 .53852 .5466 .53244 .54382 Mtetra
.053 .569 .875 r
.53244 .54382 .53852 .5466 .54989 .54855 .54385 .54609 Mtetra
0 .528 .829 r
.54385 .54609 .54989 .54855 .56134 .55074 .55534 .54862 Mtetra
0 .487 .779 r
.55534 .54862 .56134 .55074 .57289 .5531 .56693 .55135 Mtetra
0 .451 .728 r
.56693 .55135 .57289 .5531 .58452 .55558 .57861 .55419 Mtetra
.173 0 0 r
.57861 .55419 .58452 .55558 .59625 .55807 .59038 .55705 Mtetra
.202 0 0 r
.59038 .55705 .59625 .55807 .60806 .56048 .60224 .55984 Mtetra
.218 0 0 r
.60224 .55984 .60806 .56048 .61996 .56272 .6142 .56244 Mtetra
.221 0 0 r
.6142 .56244 .61996 .56272 .63194 .56467 .62623 .56474 Mtetra
.212 0 0 r
.62623 .56474 .63194 .56467 .64399 .56623 .63835 .56663 Mtetra
.19 0 0 r
.63835 .56663 .64399 .56623 .65612 .56729 .65054 .56799 Mtetra
.156 0 0 r
.65054 .56799 .65612 .56729 .6683 .56777 .66278 .56873 Mtetra
.11 0 0 r
.66278 .56873 .6683 .56777 .68053 .56756 .67508 .56875 Mtetra
.052 0 0 r
.67508 .56875 .68053 .56756 .6928 .56661 .68743 .56797 Mtetra
0 0 0 r
.68743 .56797 .6928 .56661 .7051 .56483 .6998 .56632 Mtetra
.6998 .56632 .7051 .56483 .71742 .5622 .71218 .56376 Mtetra
.71218 .56376 .71742 .5622 .72975 .55869 .72458 .56025 Mtetra
.274 .768 .706 r
.72458 .56025 .72975 .55869 .74207 .5543 .73697 .55581 Mtetra
.366 .826 .74 r
.73697 .55581 .74207 .5543 .75438 .54904 .74935 .55043 Mtetra
.454 .877 .771 r
.74935 .55043 .75438 .54904 .76668 .54294 .76171 .54416 Mtetra
.534 .919 .798 r
.76171 .54416 .76668 .54294 .77895 .53605 .77404 .53705 Mtetra
.606 .951 .82 r
.77404 .53705 .77895 .53605 .7912 .52844 .78635 .52917 Mtetra
.666 .974 .838 r
.78635 .52917 .7912 .52844 .80342 .5202 .79862 .5206 Mtetra
.716 .988 .852 r
.79862 .5206 .80342 .5202 .81562 .5114 .81086 .51144 Mtetra
.756 .994 .862 r
.81086 .51144 .81562 .5114 .82779 .50215 .82307 .50178 Mtetra
.786 .995 .87 r
.82307 .50178 .82779 .50215 .83993 .49254 .83525 .49175 Mtetra
.808 .991 .876 r
.83525 .49175 .83993 .49254 .85207 .48268 .84742 .48144 Mtetra
.823 .984 .881 r
.84742 .48144 .85207 .48268 .8642 .47267 .85958 .47096 Mtetra
.832 .974 .885 r
.85958 .47096 .8642 .47267 .87633 .4626 .87173 .46042 Mtetra
.837 .963 .889 r
.87173 .46042 .87633 .4626 .88847 .45256 .8839 .44991 Mtetra
.837 .95 .892 r
.8839 .44991 .88847 .45256 .90063 .44263 .89608 .43952 Mtetra
.834 .936 .895 r
.89608 .43952 .90063 .44263 .91283 .43289 .90829 .42932 Mtetra
.828 .922 .897 r
.90829 .42932 .91283 .43289 .92506 .42339 .92054 .41939 Mtetra
.821 .907 .899 r
.92054 .41939 .92506 .42339 .93735 .41419 .93283 .40976 Mtetra
.626 .759 .942 r
.3418 .5504 .34836 .55568 .3588 .55317 .35227 .54793 Mtetra
.62 .76 .945 r
.35227 .54793 .3588 .55317 .36929 .55075 .36278 .54557 Mtetra
.613 .76 .949 r
.36278 .54557 .36929 .55075 .37982 .54846 .37332 .54333 Mtetra
.604 .761 .954 r
.37332 .54333 .37982 .54846 .39038 .54631 .38392 .54125 Mtetra
.593 .76 .959 r
.38392 .54125 .39038 .54631 .40099 .54433 .39455 .53934 Mtetra
.579 .76 .964 r
.39455 .53934 .40099 .54433 .41165 .54255 .40523 .53764 Mtetra
.563 .758 .97 r
.40523 .53764 .41165 .54255 .42235 .541 .41595 .53618 Mtetra
.542 .755 .975 r
.41595 .53618 .42235 .541 .4331 .53971 .42672 .535 Mtetra
.518 .751 .981 r
.42672 .535 .4331 .53971 .44389 .53871 .43754 .53413 Mtetra
.488 .745 .985 r
.43754 .53413 .44389 .53871 .45474 .53804 .44841 .5336 Mtetra
.452 .736 .988 r
.44841 .5336 .45474 .53804 .46564 .53772 .45934 .53343 Mtetra
.409 .724 .989 r
.45934 .53343 .46564 .53772 .4766 .53777 .47033 .53366 Mtetra
.36 .708 .985 r
.47033 .53366 .4766 .53777 .48763 .5382 .48138 .53429 Mtetra
.302 .686 .976 r
.48138 .53429 .48763 .5382 .49872 .53903 .4925 .53534 Mtetra
.238 .659 .96 r
.4925 .53534 .49872 .53903 .50988 .54025 .50369 .53681 Mtetra
.169 .626 .936 r
.50369 .53681 .50988 .54025 .52112 .54186 .51496 .53868 Mtetra
.096 .588 .903 r
.51496 .53868 .52112 .54186 .53244 .54382 .52631 .54092 Mtetra
.025 .547 .862 r
.52631 .54092 .53244 .54382 .54385 .54609 .53775 .54349 Mtetra
0 .505 .817 r
.53775 .54349 .54385 .54609 .55534 .54862 .54928 .54635 Mtetra
0 .466 .769 r
.54928 .54635 .55534 .54862 .56693 .55135 .56091 .5494 Mtetra
0 .431 .722 r
.56091 .5494 .56693 .55135 .57861 .55419 .57263 .55258 Mtetra
.187 0 0 r
.57263 .55258 .57861 .55419 .59038 .55705 .58444 .55579 Mtetra
.212 0 0 r
.58444 .55579 .59038 .55705 .60224 .55984 .59635 .55892 Mtetra
.223 0 0 r
.59635 .55892 .60224 .55984 .6142 .56244 .60836 .56185 Mtetra
.221 0 0 r
.60836 .56185 .6142 .56244 .62623 .56474 .62045 .56447 Mtetra
.207 0 0 r
.62045 .56447 .62623 .56474 .63835 .56663 .63262 .56665 Mtetra
.179 0 0 r
.63262 .56665 .63835 .56663 .65054 .56799 .64487 .56829 Mtetra
.137 0 0 r
.64487 .56829 .65054 .56799 .66278 .56873 .65718 .56926 Mtetra
.083 0 0 r
.65718 .56926 .66278 .56873 .67508 .56875 .66955 .56947 Mtetra
.015 0 0 r
.66955 .56947 .67508 .56875 .68743 .56797 .68196 .56884 Mtetra
0 0 0 r
.68196 .56884 .68743 .56797 .6998 .56632 .69439 .56729 Mtetra
.154 .692 .709 r
.69439 .56729 .6998 .56632 .71218 .56376 .70685 .56478 Mtetra
.249 .758 .745 r
.70685 .56478 .71218 .56376 .72458 .56025 .71931 .56127 Mtetra
.345 .82 .779 r
.71931 .56127 .72458 .56025 .73697 .55581 .73177 .55677 Mtetra
.439 .875 .808 r
.73177 .55677 .73697 .55581 .74935 .55043 .74422 .55128 Mtetra
.525 .919 .832 r
.74422 .55128 .74935 .55043 .76171 .54416 .75664 .54484 Mtetra
.6 .952 .849 r
.75664 .54484 .76171 .54416 .77404 .53705 .76903 .53751 Mtetra
.664 .974 .861 r
.76903 .53751 .77404 .53705 .78635 .52917 .78139 .52936 Mtetra
.717 .987 .868 r
.78139 .52936 .78635 .52917 .79862 .5206 .79371 .52048 Mtetra
.758 .993 .873 r
.79371 .52048 .79862 .5206 .81086 .51144 .806 .51097 Mtetra
.79 .994 .876 r
.806 .51097 .81086 .51144 .82307 .50178 .81825 .50094 Mtetra
.813 .99 .877 r
.81825 .50094 .82307 .50178 .83525 .49175 .83048 .49049 Mtetra
.83 .983 .878 r
.83048 .49049 .83525 .49175 .84742 .48144 .84268 .47976 Mtetra
.84 .974 .879 r
.84268 .47976 .84742 .48144 .85958 .47096 .85487 .46885 Mtetra
.846 .963 .881 r
.85487 .46885 .85958 .47096 .87173 .46042 .86705 .45786 Mtetra
.848 .951 .882 r
.86705 .45786 .87173 .46042 .8839 .44991 .87923 .44691 Mtetra
.847 .939 .884 r
.87923 .44691 .8839 .44991 .89608 .43952 .89144 .43608 Mtetra
.842 .926 .886 r
.89144 .43608 .89608 .43952 .90829 .42932 .90367 .42546 Mtetra
.836 .913 .888 r
.90367 .42546 .90829 .42932 .92054 .41939 .91593 .41511 Mtetra
.827 .899 .891 r
.91593 .41511 .92054 .41939 .93283 .40976 .92825 .40509 Mtetra
.623 .76 .944 r
.33519 .54514 .3418 .5504 .35227 .54793 .34568 .54272 Mtetra
.616 .761 .948 r
.34568 .54272 .35227 .54793 .36278 .54557 .35621 .5404 Mtetra
.609 .761 .952 r
.35621 .5404 .36278 .54557 .37332 .54333 .36678 .53822 Mtetra
.599 .761 .957 r
.36678 .53822 .37332 .54333 .38392 .54125 .37739 .5362 Mtetra
.587 .761 .962 r
.37739 .5362 .38392 .54125 .39455 .53934 .38805 .53437 Mtetra
.572 .76 .967 r
.38805 .53437 .39455 .53934 .40523 .53764 .39875 .53275 Mtetra
.555 .758 .972 r
.39875 .53275 .40523 .53764 .41595 .53618 .4095 .53138 Mtetra
.533 .754 .978 r
.4095 .53138 .41595 .53618 .42672 .535 .42029 .53031 Mtetra
.507 .749 .983 r
.42029 .53031 .42672 .535 .43754 .53413 .43114 .52955 Mtetra
.475 .742 .987 r
.43114 .52955 .43754 .53413 .44841 .5336 .44203 .52915 Mtetra
.437 .731 .989 r
.44203 .52915 .44841 .5336 .45934 .53343 .45299 .52913 Mtetra
.392 .717 .988 r
.45299 .52913 .45934 .53343 .47033 .53366 .464 .52952 Mtetra
.34 .698 .982 r
.464 .52952 .47033 .53366 .48138 .53429 .47507 .53034 Mtetra
.28 .673 .971 r
.47507 .53034 .48138 .53429 .4925 .53534 .48622 .5316 Mtetra
.214 .643 .953 r
.48622 .5316 .4925 .53534 .50369 .53681 .49744 .53329 Mtetra
.144 .608 .926 r
.49744 .53329 .50369 .53681 .51496 .53868 .50874 .5354 Mtetra
.072 .568 .892 r
.50874 .5354 .51496 .53868 .52631 .54092 .52012 .5379 Mtetra
.002 .527 .852 r
.52012 .5379 .52631 .54092 .53775 .54349 .53159 .54075 Mtetra
0 .486 .809 r
.53159 .54075 .53775 .54349 .54928 .54635 .54315 .54389 Mtetra
0 .449 .764 r
.54315 .54389 .54928 .54635 .56091 .5494 .55482 .54725 Mtetra
0 .418 .722 r
.55482 .54725 .56091 .5494 .57263 .55258 .56658 .55073 Mtetra
0 .395 .686 r
.56658 .55073 .57263 .55258 .58444 .55579 .57843 .55424 Mtetra
.213 0 0 r
.57843 .55424 .58444 .55579 .59635 .55892 .59039 .55767 Mtetra
.219 0 0 r
.59039 .55767 .59635 .55892 .60836 .56185 .60244 .56089 Mtetra
.212 0 0 r
.60244 .56089 .60836 .56185 .62045 .56447 .61459 .56379 Mtetra
.19 0 0 r
.61459 .56379 .62045 .56447 .63262 .56665 .62682 .56623 Mtetra
.155 0 0 r
.62682 .56623 .63262 .56665 .64487 .56829 .63912 .56809 Mtetra
.105 0 0 r
.63912 .56809 .64487 .56829 .65718 .56926 .65149 .56926 Mtetra
.041 0 0 r
.65149 .56926 .65718 .56926 .66955 .56947 .66392 .56963 Mtetra
.038 .608 .717 r
.66392 .56963 .66955 .56947 .68196 .56884 .67639 .56912 Mtetra
.128 .677 .754 r
.67639 .56912 .68196 .56884 .69439 .56729 .68889 .56764 Mtetra
.226 .747 .792 r
.68889 .56764 .69439 .56729 .70685 .56478 .70141 .56516 Mtetra
.327 .813 .826 r
.70141 .56516 .70685 .56478 .71931 .56127 .71394 .56163 Mtetra
.426 .87 .855 r
.71394 .56163 .71931 .56127 .73177 .55677 .72646 .55705 Mtetra
.517 .916 .875 r
.72646 .55705 .73177 .55677 .74422 .55128 .73897 .55144 Mtetra
.597 .95 .887 r
.73897 .55144 .74422 .55128 .75664 .54484 .75145 .54483 Mtetra
.664 .972 .893 r
.75145 .54483 .75664 .54484 .76903 .53751 .7639 .53728 Mtetra
.718 .984 .894 r
.7639 .53728 .76903 .53751 .78139 .52936 .77631 .52888 Mtetra
.761 .989 .892 r
.77631 .52888 .78139 .52936 .79371 .52048 .78869 .5197 Mtetra
.793 .988 .889 r
.78869 .5197 .79371 .52048 .806 .51097 .80102 .50986 Mtetra
.818 .984 .885 r
.80102 .50986 .806 .51097 .81825 .50094 .81332 .49948 Mtetra
.835 .977 .881 r
.81332 .49948 .81825 .50094 .83048 .49049 .82559 .48866 Mtetra
.847 .968 .878 r
.82559 .48866 .83048 .49049 .84268 .47976 .83783 .47753 Mtetra
.853 .958 .876 r
.83783 .47753 .84268 .47976 .85487 .46885 .85005 .46621 Mtetra
.857 .947 .875 r
.85005 .46621 .85487 .46885 .86705 .45786 .86226 .45482 Mtetra
.856 .936 .875 r
.86226 .45482 .86705 .45786 .87923 .44691 .87448 .44346 Mtetra
.853 .924 .876 r
.87448 .44346 .87923 .44691 .89144 .43608 .88671 .43223 Mtetra
.848 .913 .878 r
.88671 .43223 .89144 .43608 .90367 .42546 .89896 .42121 Mtetra
.841 .901 .88 r
.89896 .42121 .90367 .42546 .91593 .41511 .91125 .41049 Mtetra
.832 .889 .882 r
.91125 .41049 .91593 .41511 .92825 .40509 .92358 .40011 Mtetra
.619 .761 .947 r
.32852 .53989 .33519 .54514 .34568 .54272 .33903 .53752 Mtetra
.612 .762 .951 r
.33903 .53752 .34568 .54272 .35621 .5404 .34958 .53526 Mtetra
.604 .762 .955 r
.34958 .53526 .35621 .5404 .36678 .53822 .36018 .53314 Mtetra
.593 .762 .959 r
.36018 .53314 .36678 .53822 .37739 .5362 .37081 .53118 Mtetra
.581 .761 .964 r
.37081 .53118 .37739 .5362 .38805 .53437 .3815 .52941 Mtetra
.565 .76 .969 r
.3815 .52941 .38805 .53437 .39875 .53275 .39222 .52788 Mtetra
.547 .757 .975 r
.39222 .52788 .39875 .53275 .4095 .53138 .40299 .5266 Mtetra
.524 .753 .98 r
.40299 .5266 .4095 .53138 .42029 .53031 .41381 .52562 Mtetra
.496 .747 .984 r
.41381 .52562 .42029 .53031 .43114 .52955 .42468 .52497 Mtetra
.462 .738 .987 r
.42468 .52497 .43114 .52955 .44203 .52915 .4356 .52469 Mtetra
.422 .726 .988 r
.4356 .52469 .44203 .52915 .45299 .52913 .44657 .52482 Mtetra
.375 .709 .986 r
.44657 .52482 .45299 .52913 .464 .52952 .45761 .52536 Mtetra
.321 .688 .979 r
.45761 .52536 .464 .52952 .47507 .53034 .46871 .52635 Mtetra
.26 .661 .966 r
.46871 .52635 .47507 .53034 .48622 .5316 .47988 .52779 Mtetra
.193 .629 .946 r
.47988 .52779 .48622 .5316 .49744 .53329 .49113 .52969 Mtetra
.122 .592 .918 r
.49113 .52969 .49744 .53329 .50874 .5354 .50245 .53201 Mtetra
.052 .552 .884 r
.50245 .53201 .50874 .5354 .52012 .5379 .51387 .53475 Mtetra
0 .51 .845 r
.51387 .53475 .52012 .5379 .53159 .54075 .52537 .53784 Mtetra
0 .471 .803 r
.52537 .53784 .53159 .54075 .54315 .54389 .53697 .54124 Mtetra
0 .436 .763 r
.53697 .54124 .54315 .54389 .55482 .54725 .54866 .54486 Mtetra
0 .409 .727 r
.54866 .54486 .55482 .54725 .56658 .55073 .56046 .5486 Mtetra
0 .39 .697 r
.56046 .5486 .56658 .55073 .57843 .55424 .57236 .55238 Mtetra
.208 0 0 r
.57236 .55238 .57843 .55424 .59039 .55767 .58436 .55606 Mtetra
.58436 .55606 .59039 .55767 .60244 .56089 .59646 .55953 Mtetra
.194 0 0 r
.59646 .55953 .60244 .56089 .61459 .56379 .60865 .56265 Mtetra
.165 0 0 r
.60865 .56265 .61459 .56379 .62682 .56623 .62093 .5653 Mtetra
.121 0 0 r
.62093 .5653 .62682 .56623 .63912 .56809 .63329 .56734 Mtetra
0 .524 .72 r
.63329 .56734 .63912 .56809 .65149 .56926 .64571 .56866 Mtetra
.015 .587 .756 r
.64571 .56866 .65149 .56926 .66392 .56963 .6582 .56915 Mtetra
.103 .657 .796 r
.6582 .56915 .66392 .56963 .67639 .56912 .67073 .56871 Mtetra
.203 .728 .836 r
.67073 .56871 .67639 .56912 .68889 .56764 .68329 .56727 Mtetra
.307 .797 .872 r
.68329 .56727 .68889 .56764 .70141 .56516 .69587 .56478 Mtetra
.41 .858 .9 r
.69587 .56478 .70141 .56516 .71394 .56163 .70846 .5612 Mtetra
.506 .906 .919 r
.70846 .5612 .71394 .56163 .72646 .55705 .72104 .55653 Mtetra
.59 .941 .928 r
.72104 .55653 .72646 .55705 .73897 .55144 .73361 .55079 Mtetra
.66 .963 .928 r
.73361 .55079 .73897 .55144 .75145 .54483 .74615 .54401 Mtetra
.716 .975 .923 r
.74615 .54401 .75145 .54483 .7639 .53728 .75866 .53625 Mtetra
.76 .979 .915 r
.75866 .53625 .7639 .53728 .77631 .52888 .77112 .52759 Mtetra
.794 .977 .906 r
.77112 .52759 .77631 .52888 .78869 .5197 .78355 .51814 Mtetra
.819 .972 .896 r
.78355 .51814 .78869 .5197 .80102 .50986 .79593 .508 Mtetra
.837 .965 .888 r
.79593 .508 .80102 .50986 .81332 .49948 .80828 .49728 Mtetra
.849 .956 .88 r
.80828 .49728 .81332 .49948 .82559 .48866 .82059 .48612 Mtetra
.857 .947 .875 r
.82059 .48612 .82559 .48866 .83783 .47753 .83287 .47464 Mtetra
.861 .937 .871 r
.83287 .47464 .83783 .47753 .85005 .46621 .84512 .46296 Mtetra
.862 .927 .868 r
.84512 .46296 .85005 .46621 .86226 .45482 .85737 .4512 Mtetra
.861 .917 .867 r
.85737 .4512 .86226 .45482 .87448 .44346 .86962 .43948 Mtetra
.857 .907 .867 r
.86962 .43948 .87448 .44346 .88671 .43223 .88188 .42789 Mtetra
.851 .897 .869 r
.88188 .42789 .88671 .43223 .89896 .42121 .89416 .41652 Mtetra
.844 .887 .871 r
.89416 .41652 .89896 .42121 .91125 .41049 .90647 .40546 Mtetra
.835 .876 .873 r
.90647 .40546 .91125 .41049 .92358 .40011 .91884 .39476 Mtetra
.615 .762 .95 r
.32179 .53466 .32852 .53989 .33903 .53752 .33232 .53234 Mtetra
.608 .763 .953 r
.33232 .53234 .33903 .53752 .34958 .53526 .3429 .53013 Mtetra
.599 .763 .958 r
.3429 .53013 .34958 .53526 .36018 .53314 .35352 .52807 Mtetra
.588 .763 .962 r
.35352 .52807 .36018 .53314 .37081 .53118 .36418 .52618 Mtetra
.575 .762 .967 r
.36418 .52618 .37081 .53118 .3815 .52941 .37488 .52448 Mtetra
.558 .76 .972 r
.37488 .52448 .3815 .52941 .39222 .52788 .38563 .52302 Mtetra
.538 .756 .977 r
.38563 .52302 .39222 .52788 .40299 .5266 .39643 .52183 Mtetra
.514 .751 .982 r
.39643 .52183 .40299 .5266 .41381 .52562 .40727 .52094 Mtetra
.485 .744 .986 r
.40727 .52094 .41381 .52562 .42468 .52497 .41816 .5204 Mtetra
.45 .734 .988 r
.41816 .5204 .42468 .52497 .4356 .52469 .4291 .52024 Mtetra
.408 .72 .988 r
.4291 .52024 .4356 .52469 .44657 .52482 .4401 .52049 Mtetra
.359 .702 .984 r
.4401 .52049 .44657 .52482 .45761 .52536 .45116 .52117 Mtetra
.303 .679 .976 r
.45116 .52117 .45761 .52536 .46871 .52635 .46229 .52232 Mtetra
.24 .65 .961 r
.46229 .52232 .46871 .52635 .47988 .52779 .47349 .52393 Mtetra
.173 .616 .939 r
.47349 .52393 .47988 .52779 .49113 .52969 .48476 .526 Mtetra
.103 .578 .91 r
.48476 .526 .49113 .52969 .50245 .53201 .49611 .52853 Mtetra
.035 .537 .876 r
.49611 .52853 .50245 .53201 .51387 .53475 .50755 .53147 Mtetra
0 .496 .838 r
.50755 .53147 .51387 .53475 .52537 .53784 .51908 .53478 Mtetra
0 .459 .8 r
.51908 .53478 .52537 .53784 .53697 .54124 .53071 .53839 Mtetra
0 .427 .764 r
.53071 .53839 .53697 .54124 .54866 .54486 .54244 .54223 Mtetra
0 .403 .733 r
.54244 .54223 .54866 .54486 .56046 .5486 .55428 .5462 Mtetra
0 .389 .71 r
.55428 .5462 .56046 .5486 .57236 .55238 .56621 .5502 Mtetra
0 .387 .697 r
.56621 .5502 .57236 .55238 .58436 .55606 .57825 .55409 Mtetra
0 .396 .693 r
.57825 .55409 .58436 .55606 .59646 .55953 .59039 .55775 Mtetra
0 .419 .701 r
.59039 .55775 .59646 .55953 .60865 .56265 .60263 .56105 Mtetra
0 .454 .72 r
.60263 .56105 .60865 .56265 .62093 .5653 .61496 .56385 Mtetra
0 .502 .748 r
.61496 .56385 .62093 .5653 .63329 .56734 .62736 .56601 Mtetra
0 .562 .785 r
.62736 .56601 .63329 .56734 .64571 .56866 .63984 .56743 Mtetra
.079 .63 .827 r
.63984 .56743 .64571 .56866 .6582 .56915 .65238 .56798 Mtetra
.177 .701 .869 r
.65238 .56798 .6582 .56915 .67073 .56871 .66497 .56757 Mtetra
.283 .771 .908 r
.66497 .56757 .67073 .56871 .68329 .56727 .67759 .56612 Mtetra
.388 .834 .937 r
.67759 .56612 .68329 .56727 .69587 .56478 .69022 .56359 Mtetra
.487 .884 .955 r
.69022 .56359 .69587 .56478 .70846 .5612 .70287 .55993 Mtetra
.575 .921 .961 r
.70287 .55993 .70846 .5612 .72104 .55653 .71551 .55514 Mtetra
.648 .944 .959 r
.71551 .55514 .72104 .55653 .73361 .55079 .72813 .54924 Mtetra
.707 .956 .949 r
.72813 .54924 .73361 .55079 .74615 .54401 .74073 .54227 Mtetra
.753 .96 .936 r
.74073 .54227 .74615 .54401 .75866 .53625 .75329 .5343 Mtetra
.788 .959 .922 r
.75329 .5343 .75866 .53625 .77112 .52759 .76581 .52541 Mtetra
.814 .954 .908 r
.76581 .52541 .77112 .52759 .78355 .51814 .77828 .5157 Mtetra
.833 .947 .895 r
.77828 .5157 .78355 .51814 .79593 .508 .79072 .50527 Mtetra
.847 .939 .884 r
.79072 .50527 .79593 .508 .80828 .49728 .80311 .49426 Mtetra
.856 .931 .875 r
.80311 .49426 .80828 .49728 .82059 .48612 .81546 .48279 Mtetra
.861 .922 .868 r
.81546 .48279 .82059 .48612 .83287 .47464 .82778 .47099 Mtetra
.864 .913 .863 r
.82778 .47099 .83287 .47464 .84512 .46296 .84008 .45899 Mtetra
.864 .905 .86 r
.84008 .45899 .84512 .46296 .85737 .4512 .85237 .44692 Mtetra
.861 .896 .858 r
.85237 .44692 .85737 .4512 .86962 .43948 .86465 .43488 Mtetra
.857 .888 .858 r
.86465 .43488 .86962 .43948 .88188 .42789 .87694 .42298 Mtetra
.851 .879 .859 r
.87694 .42298 .88188 .42789 .89416 .41652 .88926 .41131 Mtetra
.844 .871 .862 r
.88926 .41131 .89416 .41652 .90647 .40546 .9016 .39996 Mtetra
.835 .862 .865 r
.9016 .39996 .90647 .40546 .91884 .39476 .914 .38898 Mtetra
.61 .763 .952 r
.31501 .52944 .32179 .53466 .33232 .53234 .32556 .52717 Mtetra
.603 .763 .956 r
.32556 .52717 .33232 .53234 .3429 .53013 .33616 .52502 Mtetra
.594 .764 .96 r
.33616 .52502 .3429 .53013 .35352 .52807 .3468 .52302 Mtetra
.582 .763 .965 r
.3468 .52302 .35352 .52807 .36418 .52618 .35749 .52119 Mtetra
.568 .762 .97 r
.35749 .52119 .36418 .52618 .37488 .52448 .36821 .51957 Mtetra
.551 .76 .974 r
.36821 .51957 .37488 .52448 .38563 .52302 .37899 .51818 Mtetra
.53 .756 .979 r
.37899 .51818 .38563 .52302 .39643 .52183 .3898 .51707 Mtetra
.505 .75 .984 r
.3898 .51707 .39643 .52183 .40727 .52094 .40067 .51627 Mtetra
.474 .742 .987 r
.40067 .51627 .40727 .52094 .41816 .5204 .41158 .51583 Mtetra
.437 .731 .988 r
.41158 .51583 .41816 .5204 .4291 .52024 .42255 .51578 Mtetra
.394 .715 .987 r
.42255 .51578 .4291 .52024 .4401 .52049 .43358 .51615 Mtetra
.343 .695 .982 r
.43358 .51615 .4401 .52049 .45116 .52117 .44466 .51697 Mtetra
.285 .67 .972 r
.44466 .51697 .45116 .52117 .46229 .52232 .45581 .51825 Mtetra
.222 .64 .955 r
.45581 .51825 .46229 .52232 .47349 .52393 .46703 .52002 Mtetra
.155 .604 .932 r
.46703 .52002 .47349 .52393 .48476 .526 .47833 .52226 Mtetra
.086 .565 .903 r
.47833 .52226 .48476 .526 .49611 .52853 .48971 .52495 Mtetra
.019 .524 .869 r
.48971 .52495 .49611 .52853 .50755 .53147 .50118 .52807 Mtetra
0 .484 .833 r
.50118 .52807 .50755 .53147 .51908 .53478 .51274 .53157 Mtetra
0 .449 .797 r
.51274 .53157 .51908 .53478 .53071 .53839 .5244 .53537 Mtetra
0 .42 .766 r
.5244 .53537 .53071 .53839 .54244 .54223 .53616 .53939 Mtetra
0 .4 .741 r
.53616 .53939 .54244 .54223 .55428 .5462 .54803 .54355 Mtetra
0 .391 .724 r
.54803 .54355 .55428 .5462 .56621 .5502 .56 .54771 Mtetra
0 .393 .718 r
.56 .54771 .56621 .5502 .57825 .55409 .57208 .55176 Mtetra
0 .409 .723 r
.57208 .55176 .57825 .55409 .59039 .55775 .58426 .55556 Mtetra
0 .438 .739 r
.58426 .55556 .59039 .55775 .60263 .56105 .59654 .55897 Mtetra
0 .479 .766 r
.59654 .55897 .60263 .56105 .61496 .56385 .60891 .56187 Mtetra
0 .533 .802 r
.60891 .56187 .61496 .56385 .62736 .56601 .62136 .5641 Mtetra
.053 .597 .844 r
.62136 .5641 .62736 .56601 .63984 .56743 .63389 .56555 Mtetra
.148 .667 .888 r
.63389 .56555 .63984 .56743 .65238 .56798 .64647 .56611 Mtetra
.252 .736 .928 r
.64647 .56611 .65238 .56798 .66497 .56757 .65911 .56567 Mtetra
.359 .799 .959 r
.65911 .56567 .66497 .56757 .67759 .56612 .67178 .56416 Mtetra
.46 .852 .978 r
.67178 .56416 .67759 .56612 .69022 .56359 .68447 .56153 Mtetra
.551 .89 .984 r
.68447 .56153 .69022 .56359 .70287 .55993 .69717 .55775 Mtetra
.628 .915 .98 r
.69717 .55775 .70287 .55993 .71551 .55514 .70986 .55281 Mtetra
.69 .929 .968 r
.70986 .55281 .71551 .55514 .72813 .54924 .72253 .54674 Mtetra
.738 .934 .952 r
.72253 .54674 .72813 .54924 .74073 .54227 .73518 .53957 Mtetra
.775 .934 .935 r
.73518 .53957 .74073 .54227 .75329 .5343 .74779 .53138 Mtetra
.803 .93 .917 r
.74779 .53138 .75329 .5343 .76581 .52541 .76036 .52226 Mtetra
.824 .924 .901 r
.76036 .52226 .76581 .52541 .77828 .5157 .77289 .51229 Mtetra
.839 .917 .887 r
.77289 .51229 .77828 .5157 .79072 .50527 .78537 .50161 Mtetra
.849 .909 .875 r
.78537 .50161 .79072 .50527 .80311 .49426 .79781 .49033 Mtetra
.856 .902 .866 r
.79781 .49033 .80311 .49426 .81546 .48279 .81021 .47859 Mtetra
.86 .894 .858 r
.81021 .47859 .81546 .48279 .82778 .47099 .82257 .46652 Mtetra
.862 .887 .853 r
.82257 .46652 .82778 .47099 .84008 .45899 .83492 .45425 Mtetra
.861 .88 .85 r
.83492 .45425 .84008 .45899 .85237 .44692 .84724 .4419 Mtetra
.859 .874 .849 r
.84724 .4419 .85237 .44692 .86465 .43488 .85957 .4296 Mtetra
.855 .867 .849 r
.85957 .4296 .86465 .43488 .87694 .42298 .8719 .41744 Mtetra
.849 .86 .85 r
.8719 .41744 .87694 .42298 .88926 .41131 .88425 .40553 Mtetra
.842 .854 .853 r
.88425 .40553 .88926 .41131 .9016 .39996 .89663 .39394 Mtetra
.834 .847 .856 r
.89663 .39394 .9016 .39996 .914 .38898 .90906 .38274 Mtetra
.606 .764 .955 r
.30817 .52423 .31501 .52944 .32556 .52717 .31875 .52202 Mtetra
.598 .764 .959 r
.31875 .52202 .32556 .52717 .33616 .52502 .32937 .51993 Mtetra
.588 .764 .963 r
.32937 .51993 .33616 .52502 .3468 .52302 .34003 .51799 Mtetra
.576 .763 .967 r
.34003 .51799 .3468 .52302 .35749 .52119 .35074 .51623 Mtetra
.561 .762 .972 r
.35074 .51623 .35749 .52119 .36821 .51957 .36149 .51467 Mtetra
.543 .759 .977 r
.36149 .51467 .36821 .51957 .37899 .51818 .37228 .51336 Mtetra
.522 .755 .981 r
.37228 .51336 .37899 .51818 .3898 .51707 .38312 .51233 Mtetra
.495 .748 .985 r
.38312 .51233 .3898 .51707 .40067 .51627 .39401 .51162 Mtetra
.463 .739 .988 r
.39401 .51162 .40067 .51627 .41158 .51583 .40495 .51128 Mtetra
.424 .727 .989 r
.40495 .51128 .41158 .51583 .42255 .51578 .41594 .51133 Mtetra
.379 .71 .986 r
.41594 .51133 .42255 .51578 .43358 .51615 .42699 .51181 Mtetra
.327 .689 .98 r
.42699 .51181 .43358 .51615 .44466 .51697 .4381 .51275 Mtetra
.268 .662 .968 r
.4381 .51275 .44466 .51697 .45581 .51825 .44927 .51417 Mtetra
.204 .629 .95 r
.44927 .51417 .45581 .51825 .46703 .52002 .46052 .51607 Mtetra
.136 .592 .925 r
.46052 .51607 .46703 .52002 .47833 .52226 .47184 .51846 Mtetra
.068 .552 .895 r
.47184 .51846 .47833 .52226 .48971 .52495 .48325 .52131 Mtetra
.004 .512 .861 r
.48325 .52131 .48971 .52495 .50118 .52807 .49474 .52459 Mtetra
0 .473 .827 r
.49474 .52459 .50118 .52807 .51274 .53157 .50633 .52824 Mtetra
0 .44 .794 r
.50633 .52824 .51274 .53157 .5244 .53537 .51802 .53219 Mtetra
0 .414 .767 r
.51802 .53219 .5244 .53537 .53616 .53939 .52981 .53637 Mtetra
0 .398 .747 r
.52981 .53637 .53616 .53939 .54803 .54355 .54171 .54066 Mtetra
0 .393 .736 r
.54171 .54066 .54803 .54355 .56 .54771 .55372 .54495 Mtetra
0 .401 .737 r
.55372 .54495 .56 .54771 .57208 .55176 .56583 .5491 Mtetra
0 .422 .749 r
.56583 .5491 .57208 .55176 .58426 .55556 .57805 .55299 Mtetra
0 .457 .773 r
.57805 .55299 .58426 .55556 .59654 .55897 .59037 .55646 Mtetra
0 .504 .806 r
.59037 .55646 .59654 .55897 .60891 .56187 .60278 .55939 Mtetra
.024 .562 .847 r
.60278 .55939 .60891 .56187 .62136 .5641 .61528 .56162 Mtetra
.114 .628 .892 r
.61528 .56162 .62136 .5641 .63389 .56555 .62785 .56305 Mtetra
.215 .695 .933 r
.62785 .56305 .63389 .56555 .64647 .56611 .64048 .56354 Mtetra
.321 .759 .967 r
.64048 .56354 .64647 .56611 .65911 .56567 .65316 .56301 Mtetra
.424 .813 .988 r
.65316 .56301 .65911 .56567 .67178 .56416 .66588 .56139 Mtetra
.518 .853 .996 r
.66588 .56139 .67178 .56416 .68447 .56153 .67861 .55861 Mtetra
.599 .881 .992 r
.67861 .55861 .68447 .56153 .69717 .55775 .69136 .55466 Mtetra
.664 .897 .979 r
.69136 .55466 .69717 .55775 .70986 .55281 .7041 .54953 Mtetra
.716 .904 .962 r
.7041 .54953 .70986 .55281 .72253 .54674 .71682 .54326 Mtetra
.756 .905 .943 r
.71682 .54326 .72253 .54674 .73518 .53957 .72952 .53587 Mtetra
.786 .902 .923 r
.72952 .53587 .73518 .53957 .74779 .53138 .74218 .52745 Mtetra
.809 .897 .905 r
.74218 .52745 .74779 .53138 .76036 .52226 .7548 .51809 Mtetra
.826 .891 .889 r
.7548 .51809 .76036 .52226 .77289 .51229 .76737 .50789 Mtetra
.838 .885 .875 r
.76737 .50789 .77289 .51229 .78537 .50161 .7799 .49697 Mtetra
.847 .878 .864 r
.7799 .49697 .78537 .50161 .79781 .49033 .79238 .48545 Mtetra
.852 .872 .854 r
.79238 .48545 .79781 .49033 .81021 .47859 .80483 .47347 Mtetra
.855 .866 .848 r
.80483 .47347 .81021 .47859 .82257 .46652 .81724 .46117 Mtetra
.857 .861 .843 r
.81724 .46117 .82257 .46652 .83492 .45425 .82963 .44867 Mtetra
.856 .856 .84 r
.82963 .44867 .83492 .45425 .84724 .4419 .842 .43611 Mtetra
.854 .851 .839 r
.842 .43611 .84724 .4419 .85957 .4296 .85436 .42359 Mtetra
.85 .846 .839 r
.85436 .42359 .85957 .4296 .8719 .41744 .86674 .41124 Mtetra
.845 .841 .841 r
.86674 .41124 .8719 .41744 .88425 .40553 .87913 .39913 Mtetra
.838 .836 .844 r
.87913 .39913 .88425 .40553 .89663 .39394 .89156 .38736 Mtetra
.831 .832 .848 r
.89156 .38736 .89663 .39394 .90906 .38274 .90403 .37599 Mtetra
.601 .764 .957 r
.30127 .51903 .30817 .52423 .31875 .52202 .31187 .51688 Mtetra
.593 .764 .961 r
.31187 .51688 .31875 .52202 .32937 .51993 .32251 .51485 Mtetra
.582 .764 .965 r
.32251 .51485 .32937 .51993 .34003 .51799 .3332 .51297 Mtetra
.57 .764 .97 r
.3332 .51297 .34003 .51799 .35074 .51623 .34392 .51128 Mtetra
.555 .762 .974 r
.34392 .51128 .35074 .51623 .36149 .51467 .3547 .50979 Mtetra
.536 .759 .979 r
.3547 .50979 .36149 .51467 .37228 .51336 .36552 .50856 Mtetra
.513 .754 .983 r
.36552 .50856 .37228 .51336 .38312 .51233 .37638 .50761 Mtetra
.485 .747 .987 r
.37638 .50761 .38312 .51233 .39401 .51162 .38729 .50699 Mtetra
.451 .737 .989 r
.38729 .50699 .39401 .51162 .40495 .51128 .39825 .50674 Mtetra
.411 .723 .989 r
.39825 .50674 .40495 .51128 .41594 .51133 .40927 .50689 Mtetra
.364 .705 .985 r
.40927 .50689 .41594 .51133 .42699 .51181 .42034 .50748 Mtetra
.311 .682 .977 r
.42034 .50748 .42699 .51181 .4381 .51275 .43147 .50854 Mtetra
.25 .653 .963 r
.43147 .50854 .4381 .51275 .44927 .51417 .44267 .51008 Mtetra
.185 .619 .944 r
.44267 .51008 .44927 .51417 .46052 .51607 .45394 .51212 Mtetra
.117 .581 .918 r
.45394 .51212 .46052 .51607 .47184 .51846 .46529 .51464 Mtetra
.051 .54 .887 r
.46529 .51464 .47184 .51846 .48325 .52131 .47672 .51763 Mtetra
0 .5 .853 r
.47672 .51763 .48325 .52131 .49474 .52459 .48824 .52104 Mtetra
0 .463 .82 r
.48824 .52104 .49474 .52459 .50633 .52824 .49986 .52483 Mtetra
0 .431 .789 r
.49986 .52483 .50633 .52824 .51802 .53219 .51158 .52891 Mtetra
0 .409 .766 r
.51158 .52891 .51802 .53219 .52981 .53637 .5234 .53321 Mtetra
0 .396 .751 r
.5234 .53321 .52981 .53637 .54171 .54066 .53533 .5376 Mtetra
0 .396 .746 r
.53533 .5376 .54171 .54066 .55372 .54495 .54737 .54197 Mtetra
0 .409 .753 r
.54737 .54197 .55372 .54495 .56583 .5491 .55952 .54618 Mtetra
0 .435 .772 r
.55952 .54618 .56583 .5491 .57805 .55299 .57177 .5501 Mtetra
0 .475 .801 r
.57177 .5501 .57805 .55299 .59037 .55646 .58413 .55357 Mtetra
0 .527 .84 r
.58413 .55357 .59037 .55646 .60278 .55939 .59658 .55647 Mtetra
.075 .588 .884 r
.59658 .55647 .60278 .55939 .61528 .56162 .60911 .55864 Mtetra
.171 .653 .927 r
.60911 .55864 .61528 .56162 .62785 .56305 .62172 .55997 Mtetra
.276 .716 .963 r
.62172 .55997 .62785 .56305 .64048 .56354 .6344 .56034 Mtetra
.381 .772 .988 r
.6344 .56034 .64048 .56354 .65316 .56301 .64712 .55965 Mtetra
.478 .815 .999 r
.64712 .55965 .65316 .56301 .66588 .56139 .65988 .55784 Mtetra
.563 .845 .997 r
.65988 .55784 .66588 .56139 .67861 .55861 .67266 .55486 Mtetra
.633 .863 .985 r
.67266 .55486 .67861 .55861 .69136 .55466 .68545 .55069 Mtetra
.688 .872 .968 r
.68545 .55069 .69136 .55466 .7041 .54953 .69823 .54533 Mtetra
.732 .875 .947 r
.69823 .54533 .7041 .54953 .71682 .54326 .711 .53881 Mtetra
.765 .873 .927 r
.711 .53881 .71682 .54326 .72952 .53587 .72374 .53118 Mtetra
.79 .869 .907 r
.72374 .53118 .72952 .53587 .74218 .52745 .73644 .52251 Mtetra
.809 .864 .889 r
.73644 .52251 .74218 .52745 .7548 .51809 .7491 .51291 Mtetra
.823 .859 .874 r
.7491 .51291 .7548 .51809 .76737 .50789 .76172 .50247 Mtetra
.833 .853 .861 r
.76172 .50247 .76737 .50789 .7799 .49697 .7743 .49132 Mtetra
.84 .848 .85 r
.7743 .49132 .7799 .49697 .79238 .48545 .78683 .47959 Mtetra
.845 .844 .842 r
.78683 .47959 .79238 .48545 .80483 .47347 .79932 .46741 Mtetra
.848 .839 .836 r
.79932 .46741 .80483 .47347 .81724 .46117 .81178 .45492 Mtetra
.849 .835 .832 r
.81178 .45492 .81724 .46117 .82963 .44867 .82421 .44225 Mtetra
.849 .832 .83 r
.82421 .44225 .82963 .44867 .842 .43611 .83663 .42951 Mtetra
.847 .829 .829 r
.83663 .42951 .842 .43611 .85436 .42359 .84904 .41684 Mtetra
.843 .825 .83 r
.84904 .41684 .85436 .42359 .86674 .41124 .86147 .40434 Mtetra
.839 .822 .833 r
.86147 .40434 .86674 .41124 .87913 .39913 .87391 .3921 Mtetra
.833 .819 .836 r
.87391 .3921 .87913 .39913 .89156 .38736 .88638 .38021 Mtetra
.826 .816 .84 r
.88638 .38021 .89156 .38736 .90403 .37599 .8989 .36872 Mtetra
.596 .764 .959 r
.29431 .51384 .30127 .51903 .31187 .51688 .30493 .51174 Mtetra
.587 .765 .963 r
.30493 .51174 .31187 .51688 .32251 .51485 .31559 .50978 Mtetra
.577 .764 .968 r
.31559 .50978 .32251 .51485 .3332 .51297 .3263 .50797 Mtetra
.563 .763 .972 r
.3263 .50797 .3332 .51297 .34392 .51128 .33705 .50634 Mtetra
.547 .761 .977 r
.33705 .50634 .34392 .51128 .3547 .50979 .34785 .50493 Mtetra
.528 .758 .981 r
.34785 .50493 .3547 .50979 .36552 .50856 .35869 .50377 Mtetra
.504 .753 .985 r
.35869 .50377 .36552 .50856 .37638 .50761 .36958 .50291 Mtetra
.474 .745 .988 r
.36958 .50291 .37638 .50761 .38729 .50699 .38051 .50238 Mtetra
.439 .734 .989 r
.38051 .50238 .38729 .50699 .39825 .50674 .3915 .50222 Mtetra
.398 .719 .988 r
.3915 .50222 .39825 .50674 .40927 .50689 .40253 .50247 Mtetra
.349 .699 .983 r
.40253 .50247 .40927 .50689 .42034 .50748 .41363 .50317 Mtetra
.293 .675 .974 r
.41363 .50317 .42034 .50748 .43147 .50854 .42479 .50435 Mtetra
.231 .644 .958 r
.42479 .50435 .43147 .50854 .44267 .51008 .43601 .50601 Mtetra
.165 .609 .936 r
.43601 .50601 .44267 .51008 .45394 .51212 .4473 .50817 Mtetra
.097 .569 .909 r
.4473 .50817 .45394 .51212 .46529 .51464 .45868 .51082 Mtetra
.031 .528 .877 r
.45868 .51082 .46529 .51464 .47672 .51763 .47013 .51394 Mtetra
0 .487 .843 r
.47013 .51394 .47672 .51763 .48824 .52104 .48168 .51748 Mtetra
0 .451 .81 r
.48168 .51748 .48824 .52104 .49986 .52483 .49333 .52138 Mtetra
0 .422 .782 r
.49333 .52138 .49986 .52483 .51158 .52891 .50507 .52557 Mtetra
0 .402 .762 r
.50507 .52557 .51158 .52891 .5234 .53321 .51692 .52996 Mtetra
0 .394 .751 r
.51692 .52996 .5234 .53321 .53533 .5376 .52889 .53442 Mtetra
0 .398 .752 r
.52889 .53442 .53533 .5376 .54737 .54197 .54096 .53883 Mtetra
0 .416 .764 r
.54096 .53883 .54737 .54197 .55952 .54618 .55314 .54306 Mtetra
0 .447 .789 r
.55314 .54306 .55952 .54618 .57177 .5501 .56543 .54696 Mtetra
0 .492 .824 r
.56543 .54696 .57177 .5501 .58413 .55357 .57782 .55038 Mtetra
.029 .547 .866 r
.57782 .55038 .58413 .55357 .59658 .55647 .59031 .55319 Mtetra
.121 .61 .911 r
.59031 .55319 .59658 .55647 .60911 .55864 .60288 .55523 Mtetra
.223 .673 .951 r
.60288 .55523 .60911 .55864 .62172 .55997 .61553 .5564 Mtetra
.329 .731 .981 r
.61553 .5564 .62172 .55997 .6344 .56034 .62824 .55657 Mtetra
.43 .778 .997 r
.62824 .55657 .6344 .56034 .64712 .55965 .641 .55566 Mtetra
.521 .812 .999 r
.641 .55566 .64712 .55965 .65988 .55784 .6538 .5536 Mtetra
.596 .833 .989 r
.6538 .5536 .65988 .55784 .67266 .55486 .66662 .55036 Mtetra
.657 .844 .972 r
.66662 .55036 .67266 .55486 .68545 .55069 .67944 .5459 Mtetra
.705 .848 .951 r
.67944 .5459 .68545 .55069 .69823 .54533 .69226 .54026 Mtetra
.741 .848 .93 r
.69226 .54026 .69823 .54533 .711 .53881 .70507 .53345 Mtetra
.769 .844 .909 r
.70507 .53345 .711 .53881 .72374 .53118 .71785 .52554 Mtetra
.79 .84 .89 r
.71785 .52554 .72374 .53118 .73644 .52251 .73059 .51661 Mtetra
.806 .835 .873 r
.73059 .51661 .73644 .52251 .7491 .51291 .7433 .50675 Mtetra
.818 .83 .859 r
.7433 .50675 .7491 .51291 .76172 .50247 .75596 .49607 Mtetra
.827 .825 .847 r
.75596 .49607 .76172 .50247 .7743 .49132 .76858 .48471 Mtetra
.833 .821 .838 r
.76858 .48471 .7743 .49132 .78683 .47959 .78115 .47278 Mtetra
.837 .818 .83 r
.78115 .47278 .78683 .47959 .79932 .46741 .79369 .46043 Mtetra
.84 .815 .825 r
.79369 .46043 .79932 .46741 .81178 .45492 .8062 .44778 Mtetra
.841 .812 .822 r
.8062 .44778 .81178 .45492 .82421 .44225 .81868 .43497 Mtetra
.841 .81 .82 r
.81868 .43497 .82421 .44225 .83663 .42951 .83114 .42212 Mtetra
.839 .808 .82 r
.83114 .42212 .83663 .42951 .84904 .41684 .84361 .40934 Mtetra
.836 .806 .822 r
.84361 .40934 .84904 .41684 .86147 .40434 .85608 .39675 Mtetra
.832 .804 .825 r
.85608 .39675 .86147 .40434 .87391 .3921 .86857 .38444 Mtetra
.827 .803 .828 r
.86857 .38444 .87391 .3921 .88638 .38021 .8811 .37247 Mtetra
.82 .801 .833 r
.8811 .37247 .88638 .38021 .8989 .36872 .89367 .36092 Mtetra
.591 .764 .962 r
.28729 .50864 .29431 .51384 .30493 .51174 .29793 .50661 Mtetra
.582 .764 .966 r
.29793 .50661 .30493 .51174 .31559 .50978 .30862 .50471 Mtetra
.57 .764 .97 r
.30862 .50471 .31559 .50978 .3263 .50797 .31935 .50297 Mtetra
.557 .763 .974 r
.31935 .50297 .3263 .50797 .33705 .50634 .33012 .50141 Mtetra
.54 .761 .979 r
.33012 .50141 .33705 .50634 .34785 .50493 .34094 .50008 Mtetra
.519 .757 .983 r
.34094 .50008 .34785 .50493 .35869 .50377 .3518 .499 Mtetra
.494 .751 .986 r
.3518 .499 .35869 .50377 .36958 .50291 .36271 .49822 Mtetra
.463 .743 .989 r
.36271 .49822 .36958 .50291 .38051 .50238 .37367 .49778 Mtetra
.427 .731 .99 r
.37367 .49778 .38051 .50238 .3915 .50222 .38468 .49773 Mtetra
.383 .715 .987 r
.38468 .49773 .3915 .50222 .40253 .50247 .39574 .49809 Mtetra
.332 .694 .981 r
.39574 .49809 .40253 .50247 .41363 .50317 .40686 .4989 Mtetra
.274 .667 .97 r
.40686 .4989 .41363 .50317 .42479 .50435 .41804 .50019 Mtetra
.211 .635 .952 r
.41804 .50019 .42479 .50435 .43601 .50601 .42928 .50197 Mtetra
.143 .597 .928 r
.42928 .50197 .43601 .50601 .4473 .50817 .4406 .50426 Mtetra
.074 .556 .898 r
.4406 .50426 .4473 .50817 .45868 .51082 .452 .50704 Mtetra
.009 .514 .865 r
.452 .50704 .45868 .51082 .47013 .51394 .46348 .51028 Mtetra
0 .474 .83 r
.46348 .51028 .47013 .51394 .48168 .51748 .47506 .51393 Mtetra
0 .439 .798 r
.47506 .51393 .48168 .51748 .49333 .52138 .48673 .51795 Mtetra
0 .412 .772 r
.48673 .51795 .49333 .52138 .50507 .52557 .4985 .52223 Mtetra
0 .395 .754 r
.4985 .52223 .50507 .52557 .51692 .52996 .51038 .52668 Mtetra
0 .39 .747 r
.51038 .52668 .51692 .52996 .52889 .53442 .52237 .53119 Mtetra
0 .398 .752 r
.52237 .53119 .52889 .53442 .54096 .53883 .53448 .53562 Mtetra
0 .421 .77 r
.53448 .53562 .54096 .53883 .55314 .54306 .54669 .53983 Mtetra
0 .458 .801 r
.54669 .53983 .55314 .54306 .56543 .54696 .55902 .54366 Mtetra
0 .507 .841 r
.55902 .54366 .56543 .54696 .57782 .55038 .57144 .54699 Mtetra
.063 .566 .886 r
.57144 .54699 .57782 .55038 .59031 .55319 .58396 .54964 Mtetra
.161 .629 .93 r
.58396 .54964 .59031 .55319 .60288 .55523 .59657 .5515 Mtetra
.268 .69 .967 r
.59657 .5515 .60288 .55523 .61553 .5564 .60925 .55244 Mtetra
.374 .743 .99 r
.60925 .55244 .61553 .5564 .62824 .55657 .622 .55234 Mtetra
.471 .782 .998 r
.622 .55234 .62824 .55657 .641 .55566 .6348 .55114 Mtetra
.555 .808 .992 r
.6348 .55114 .641 .55566 .6538 .5536 .64763 .54877 Mtetra
.623 .822 .977 r
.64763 .54877 .6538 .5536 .66662 .55036 .66049 .54519 Mtetra
.676 .828 .956 r
.66049 .54519 .66662 .55036 .67944 .5459 .67335 .54039 Mtetra
.716 .828 .934 r
.67335 .54039 .67944 .5459 .69226 .54026 .6862 .5344 Mtetra
.747 .825 .912 r
.6862 .5344 .69226 .54026 .70507 .53345 .69904 .52726 Mtetra
.771 .82 .891 r
.69904 .52726 .70507 .53345 .71785 .52554 .71186 .51903 Mtetra
.789 .815 .873 r
.71186 .51903 .71785 .52554 .73059 .51661 .72464 .5098 Mtetra
.802 .81 .858 r
.72464 .5098 .73059 .51661 .7433 .50675 .73738 .49967 Mtetra
.812 .805 .844 r
.73738 .49967 .7433 .50675 .75596 .49607 .75009 .48875 Mtetra
.82 .801 .834 r
.75009 .48875 .75596 .49607 .76858 .48471 .76274 .47717 Mtetra
.825 .798 .825 r
.76274 .47717 .76858 .48471 .78115 .47278 .77536 .46506 Mtetra
.829 .795 .819 r
.77536 .46506 .78115 .47278 .79369 .46043 .78795 .45255 Mtetra
.831 .793 .815 r
.78795 .45255 .79369 .46043 .8062 .44778 .8005 .43978 Mtetra
.832 .791 .812 r
.8005 .43978 .8062 .44778 .81868 .43497 .81303 .42687 Mtetra
.832 .79 .812 r
.81303 .42687 .81868 .43497 .83114 .42212 .82555 .41394 Mtetra
.831 .789 .812 r
.82555 .41394 .83114 .42212 .84361 .40934 .83806 .40112 Mtetra
.828 .788 .814 r
.83806 .40112 .84361 .40934 .85608 .39675 .85059 .38848 Mtetra
.825 .788 .818 r
.85059 .38848 .85608 .39675 .86857 .38444 .86313 .37614 Mtetra
.82 .787 .822 r
.86313 .37614 .86857 .38444 .8811 .37247 .87571 .36416 Mtetra
.814 .787 .827 r
.87571 .36416 .8811 .37247 .89367 .36092 .88834 .3526 Mtetra
.586 .764 .964 r
.28021 .50342 .28729 .50864 .29793 .50661 .29087 .50146 Mtetra
.576 .764 .968 r
.29087 .50146 .29793 .50661 .30862 .50471 .30158 .49963 Mtetra
.564 .764 .972 r
.30158 .49963 .30862 .50471 .31935 .50297 .31233 .49796 Mtetra
.55 .762 .976 r
.31233 .49796 .31935 .50297 .33012 .50141 .32312 .49648 Mtetra
.532 .76 .98 r
.32312 .49648 .33012 .50141 .34094 .50008 .33396 .49523 Mtetra
.51 .755 .984 r
.33396 .49523 .34094 .50008 .3518 .499 .34485 .49424 Mtetra
.484 .749 .988 r
.34485 .49424 .3518 .499 .36271 .49822 .35578 .49355 Mtetra
.452 .74 .99 r
.35578 .49355 .36271 .49822 .37367 .49778 .36676 .49321 Mtetra
.413 .727 .989 r
.36676 .49321 .37367 .49778 .38468 .49773 .37779 .49326 Mtetra
.367 .709 .986 r
.37779 .49326 .38468 .49773 .39574 .49809 .38888 .49373 Mtetra
.314 .687 .978 r
.38888 .49373 .39574 .49809 .40686 .4989 .40002 .49466 Mtetra
.254 .658 .965 r
.40002 .49466 .40686 .4989 .41804 .50019 .41122 .49607 Mtetra
.188 .624 .944 r
.41122 .49607 .41804 .50019 .42928 .50197 .42249 .49799 Mtetra
.119 .584 .918 r
.42249 .49799 .42928 .50197 .4406 .50426 .43383 .5004 Mtetra
.049 .542 .885 r
.43383 .5004 .4406 .50426 .452 .50704 .44525 .50331 Mtetra
0 .499 .85 r
.44525 .50331 .452 .50704 .46348 .51028 .45676 .50668 Mtetra
0 .458 .814 r
.45676 .50668 .46348 .51028 .47506 .51393 .46836 .51045 Mtetra
0 .424 .782 r
.46836 .51045 .47506 .51393 .48673 .51795 .48006 .51457 Mtetra
0 .399 .757 r
.48006 .51457 .48673 .51795 .4985 .52223 .49186 .51894 Mtetra
0 .385 .742 r
.49186 .51894 .4985 .52223 .51038 .52668 .50377 .52346 Mtetra
0 .384 .738 r
.50377 .52346 .51038 .52668 .52237 .53119 .5158 .52799 Mtetra
0 .397 .748 r
.5158 .52799 .52237 .53119 .53448 .53562 .52793 .53241 Mtetra
0 .424 .771 r
.52793 .53241 .53448 .53562 .54669 .53983 .54018 .53657 Mtetra
0 .466 .807 r
.54018 .53657 .54669 .53983 .55902 .54366 .55254 .54031 Mtetra
0 .52 .851 r
.55254 .54031 .55902 .54366 .57144 .54699 .565 .54348 Mtetra
.09 .583 .9 r
.565 .54348 .57144 .54699 .58396 .54964 .57755 .54594 Mtetra
.196 .648 .944 r
.57755 .54594 .58396 .54964 .59657 .5515 .5902 .54756 Mtetra
.306 .707 .977 r
.5902 .54756 .59657 .5515 .60925 .55244 .60291 .5482 Mtetra
.412 .754 .995 r
.60291 .5482 .60925 .55244 .622 .55234 .6157 .54778 Mtetra
.506 .786 .996 r
.6157 .54778 .622 .55234 .6348 .55114 .62853 .54622 Mtetra
.583 .805 .984 r
.62853 .54622 .6348 .55114 .64763 .54877 .64139 .54346 Mtetra
.644 .814 .965 r
.64139 .54346 .64763 .54877 .66049 .54519 .65428 .53948 Mtetra
.691 .815 .942 r
.65428 .53948 .66049 .54519 .67335 .54039 .66717 .53428 Mtetra
.726 .812 .918 r
.66717 .53428 .67335 .54039 .6862 .5344 .68006 .52789 Mtetra
.753 .807 .896 r
.68006 .52789 .6862 .5344 .69904 .52726 .69293 .52036 Mtetra
.773 .801 .876 r
.69293 .52036 .69904 .52726 .71186 .51903 .70578 .51177 Mtetra
.788 .795 .859 r
.70578 .51177 .71186 .51903 .72464 .5098 .71859 .5022 Mtetra
.799 .79 .844 r
.71859 .5022 .72464 .5098 .73738 .49967 .73137 .49177 Mtetra
.808 .785 .832 r
.73137 .49177 .73738 .49967 .75009 .48875 .74411 .48059 Mtetra
.814 .781 .822 r
.74411 .48059 .75009 .48875 .76274 .47717 .75681 .46879 Mtetra
.818 .778 .815 r
.75681 .46879 .76274 .47717 .77536 .46506 .76947 .45651 Mtetra
.822 .776 .809 r
.76947 .45651 .77536 .46506 .78795 .45255 .78209 .44386 Mtetra
.824 .774 .806 r
.78209 .44386 .78795 .45255 .8005 .43978 .79469 .43098 Mtetra
.824 .773 .804 r
.79469 .43098 .8005 .43978 .81303 .42687 .80727 .418 Mtetra
.80727 .418 .81303 .42687 .82555 .41394 .81984 .40504 Mtetra
.823 .772 .805 r
.81984 .40504 .82555 .41394 .83806 .40112 .83241 .3922 Mtetra
.82 .773 .808 r
.83241 .3922 .83806 .40112 .85059 .38848 .84499 .37957 Mtetra
.817 .773 .811 r
.84499 .37957 .85059 .38848 .86313 .37614 .8576 .36725 Mtetra
.813 .773 .816 r
.8576 .36725 .86313 .37614 .87571 .36416 .87023 .3553 Mtetra
.808 .774 .822 r
.87023 .3553 .87571 .36416 .88834 .3526 .88292 .34378 Mtetra
.58 .763 .965 r
.27307 .49819 .28021 .50342 .29087 .50146 .28375 .4963 Mtetra
.57 .763 .969 r
.28375 .4963 .29087 .50146 .30158 .49963 .29448 .49454 Mtetra
.558 .763 .974 r
.29448 .49454 .30158 .49963 .31233 .49796 .30525 .49295 Mtetra
.542 .761 .978 r
.30525 .49295 .31233 .49796 .32312 .49648 .31607 .49155 Mtetra
.524 .758 .982 r
.31607 .49155 .32312 .49648 .33396 .49523 .32693 .49038 Mtetra
.501 .753 .986 r
.32693 .49038 .33396 .49523 .34485 .49424 .33783 .48948 Mtetra
.473 .746 .989 r
.33783 .48948 .34485 .49424 .35578 .49355 .34879 .48889 Mtetra
.44 .736 .99 r
.34879 .48889 .35578 .49355 .36676 .49321 .35979 .48865 Mtetra
.399 .722 .989 r
.35979 .48865 .36676 .49321 .37779 .49326 .37084 .48881 Mtetra
.351 .704 .984 r
.37084 .48881 .37779 .49326 .38888 .49373 .38195 .4894 Mtetra
.295 .679 .974 r
.38195 .4894 .38888 .49373 .40002 .49466 .39311 .49046 Mtetra
.232 .648 .958 r
.39311 .49046 .40002 .49466 .41122 .49607 .40433 .492 Mtetra
.163 .612 .935 r
.40433 .492 .41122 .49607 .42249 .49799 .41563 .49406 Mtetra
.092 .57 .905 r
.41563 .49406 .42249 .49799 .43383 .5004 .42699 .49662 Mtetra
.021 .525 .87 r
.42699 .49662 .43383 .5004 .44525 .50331 .43844 .49967 Mtetra
0 .481 .832 r
.43844 .49967 .44525 .50331 .45676 .50668 .44997 .50317 Mtetra
0 .441 .795 r
.44997 .50317 .45676 .50668 .46836 .51045 .4616 .50707 Mtetra
0 .407 .762 r
.4616 .50707 .46836 .51045 .48006 .51457 .47332 .5113 Mtetra
0 .384 .738 r
.47332 .5113 .48006 .51457 .49186 .51894 .48515 .51576 Mtetra
0 .372 .725 r
.48515 .51576 .49186 .51894 .50377 .52346 .49709 .52033 Mtetra
0 .374 .724 r
.49709 .52033 .50377 .52346 .5158 .52799 .50915 .52488 Mtetra
0 .392 .738 r
.50915 .52488 .5158 .52799 .52793 .53241 .52132 .52928 Mtetra
0 .424 .766 r
.52132 .52928 .52793 .53241 .54018 .53657 .5336 .53337 Mtetra
0 .472 .807 r
.5336 .53337 .54018 .53657 .55254 .54031 .54599 .53698 Mtetra
.01 .532 .857 r
.54599 .53698 .55254 .54031 .565 .54348 .55848 .53998 Mtetra
.111 .599 .909 r
.55848 .53998 .565 .54348 .57755 .54594 .57108 .5422 Mtetra
.224 .665 .954 r
.57108 .5422 .57755 .54594 .5902 .54756 .58376 .54352 Mtetra
.339 .723 .984 r
.58376 .54352 .5902 .54756 .60291 .5482 .59651 .54383 Mtetra
.445 .766 .997 r
.59651 .54383 .60291 .5482 .6157 .54778 .60932 .54302 Mtetra
.536 .793 .992 r
.60932 .54302 .6157 .54778 .62853 .54622 .62219 .54103 Mtetra
.608 .807 .976 r
.62219 .54103 .62853 .54622 .64139 .54346 .63508 .53782 Mtetra
.664 .81 .953 r
.63508 .53782 .64139 .54346 .65428 .53948 .648 .53337 Mtetra
.705 .808 .929 r
.648 .53337 .65428 .53948 .66717 .53428 .66092 .5277 Mtetra
.736 .802 .904 r
.66092 .5277 .66717 .53428 .68006 .52789 .67384 .52085 Mtetra
.759 .795 .882 r
.67384 .52085 .68006 .52789 .69293 .52036 .68674 .51288 Mtetra
.776 .788 .863 r
.68674 .51288 .69293 .52036 .70578 .51177 .69962 .50388 Mtetra
.788 .781 .846 r
.69962 .50388 .70578 .51177 .71859 .5022 .71246 .49394 Mtetra
.797 .775 .832 r
.71246 .49394 .71859 .5022 .73137 .49177 .72527 .48318 Mtetra
.804 .77 .821 r
.72527 .48318 .73137 .49177 .74411 .48059 .73804 .47172 Mtetra
.809 .766 .812 r
.73804 .47172 .74411 .48059 .75681 .46879 .75078 .45968 Mtetra
.813 .763 .806 r
.75078 .45968 .75681 .46879 .76947 .45651 .76348 .44721 Mtetra
.815 .76 .801 r
.76348 .44721 .76947 .45651 .78209 .44386 .77614 .43444 Mtetra
.817 .759 .798 r
.77614 .43444 .78209 .44386 .79469 .43098 .78879 .42147 Mtetra
.817 .758 .797 r
.78879 .42147 .79469 .43098 .80727 .418 .80142 .40845 Mtetra
.817 .758 .798 r
.80142 .40845 .80727 .418 .81984 .40504 .81404 .39547 Mtetra
.815 .758 .799 r
.81404 .39547 .81984 .40504 .83241 .3922 .82666 .38265 Mtetra
.813 .759 .802 r
.82666 .38265 .83241 .3922 .84499 .37957 .8393 .37007 Mtetra
.81 .76 .806 r
.8393 .37007 .84499 .37957 .8576 .36725 .85197 .35781 Mtetra
.806 .761 .811 r
.85197 .35781 .8576 .36725 .87023 .3553 .86466 .34593 Mtetra
.801 .762 .817 r
.86466 .34593 .87023 .3553 .88292 .34378 .87741 .33449 Mtetra
.574 .762 .967 r
.26587 .49293 .27307 .49819 .28375 .4963 .27657 .49111 Mtetra
.564 .762 .971 r
.27657 .49111 .28375 .4963 .29448 .49454 .28732 .48943 Mtetra
.551 .761 .975 r
.28732 .48943 .29448 .49454 .30525 .49295 .29811 .48791 Mtetra
.535 .759 .979 r
.29811 .48791 .30525 .49295 .31607 .49155 .30895 .4866 Mtetra
.516 .756 .983 r
.30895 .4866 .31607 .49155 .32693 .49038 .31983 .48552 Mtetra
.492 .751 .987 r
.31983 .48552 .32693 .49038 .33783 .48948 .33075 .48472 Mtetra
.462 .743 .989 r
.33075 .48472 .33783 .48948 .34879 .48889 .34173 .48423 Mtetra
.427 .732 .99 r
.34173 .48423 .34879 .48889 .35979 .48865 .35275 .4841 Mtetra
.384 .717 .988 r
.35275 .4841 .35979 .48865 .37084 .48881 .36382 .48438 Mtetra
.333 .697 .982 r
.36382 .48438 .37084 .48881 .38195 .4894 .37495 .4851 Mtetra
.274 .67 .97 r
.37495 .4851 .38195 .4894 .39311 .49046 .38614 .48629 Mtetra
.208 .637 .951 r
.38614 .48629 .39311 .49046 .40433 .492 .39738 .48799 Mtetra
.136 .597 .925 r
.39738 .48799 .40433 .492 .41563 .49406 .4087 .49019 Mtetra
.062 .553 .891 r
.4087 .49019 .41563 .49406 .42699 .49662 .42008 .49291 Mtetra
0 .507 .852 r
.42008 .49291 .42699 .49662 .43844 .49967 .43155 .49611 Mtetra
0 .461 .811 r
.43155 .49611 .43844 .49967 .44997 .50317 .44311 .49977 Mtetra
0 .42 .772 r
.44311 .49977 .44997 .50317 .4616 .50707 .45476 .50381 Mtetra
0 .387 .739 r
.45476 .50381 .4616 .50707 .47332 .5113 .46651 .50816 Mtetra
0 .365 .715 r
.46651 .50816 .47332 .5113 .48515 .51576 .47837 .51271 Mtetra
0 .356 .703 r
.47837 .51271 .48515 .51576 .49709 .52033 .49034 .51735 Mtetra
0 .362 .705 r
.49034 .51735 .49709 .52033 .50915 .52488 .50243 .52193 Mtetra
0 .384 .723 r
.50243 .52193 .50915 .52488 .52132 .52928 .51463 .5263 Mtetra
0 .422 .756 r
.51463 .5263 .52132 .52928 .5336 .53337 .52695 .5303 Mtetra
0 .475 .802 r
.52695 .5303 .5336 .53337 .54599 .53698 .53937 .53378 Mtetra
.017 .541 .857 r
.53937 .53378 .54599 .53698 .55848 .53998 .55191 .53657 Mtetra
.126 .614 .913 r
.55191 .53657 .55848 .53998 .57108 .5422 .56454 .53852 Mtetra
.247 .683 .96 r
.56454 .53852 .57108 .5422 .58376 .54352 .57725 .53952 Mtetra
.367 .741 .989 r
.57725 .53952 .58376 .54352 .59651 .54383 .59004 .53943 Mtetra
.474 .781 .998 r
.59004 .53943 .59651 .54383 .60932 .54302 .60289 .53818 Mtetra
.562 .803 .989 r
.60289 .53818 .60932 .54302 .62219 .54103 .61578 .53571 Mtetra
.631 .812 .969 r
.61578 .53571 .62219 .54103 .63508 .53782 .62871 .53199 Mtetra
.682 .811 .944 r
.62871 .53199 .63508 .53782 .648 .53337 .64166 .52702 Mtetra
.719 .805 .918 r
.64166 .52702 .648 .53337 .66092 .5277 .65461 .52082 Mtetra
.746 .797 .893 r
.65461 .52082 .66092 .5277 .67384 .52085 .66755 .51344 Mtetra
.766 .788 .871 r
.66755 .51344 .67384 .52085 .68674 .51288 .68048 .50498 Mtetra
.78 .779 .852 r
.68048 .50498 .68674 .51288 .69962 .50388 .69338 .49551 Mtetra
.79 .771 .836 r
.69338 .49551 .69962 .50388 .71246 .49394 .70625 .48515 Mtetra
.797 .765 .823 r
.70625 .48515 .71246 .49394 .72527 .48318 .71909 .47402 Mtetra
.803 .759 .812 r
.71909 .47402 .72527 .48318 .73804 .47172 .7319 .46225 Mtetra
.806 .754 .804 r
.7319 .46225 .73804 .47172 .75078 .45968 .74466 .44997 Mtetra
.809 .751 .798 r
.74466 .44997 .75078 .45968 .76348 .44721 .7574 .43731 Mtetra
.811 .748 .794 r
.7574 .43731 .76348 .44721 .77614 .43444 .77011 .42439 Mtetra
.811 .747 .792 r
.77011 .42439 .77614 .43444 .78879 .42147 .7828 .41135 Mtetra
.811 .746 .792 r
.7828 .41135 .78879 .42147 .80142 .40845 .79547 .3983 Mtetra
.81 .746 .792 r
.79547 .3983 .80142 .40845 .81404 .39547 .80815 .38533 Mtetra
.809 .747 .795 r
.80815 .38533 .81404 .39547 .82666 .38265 .82083 .37255 Mtetra
.806 .748 .798 r
.82083 .37255 .82666 .38265 .8393 .37007 .83352 .36004 Mtetra
.803 .749 .802 r
.83352 .36004 .8393 .37007 .85197 .35781 .84625 .34787 Mtetra
.799 .75 .808 r
.84625 .34787 .85197 .35781 .86466 .34593 .85901 .33611 Mtetra
.795 .752 .814 r
.85901 .33611 .86466 .34593 .87741 .33449 .87182 .32478 Mtetra
.569 .76 .968 r
.25861 .48763 .26587 .49293 .27657 .49111 .26933 .48588 Mtetra
.558 .76 .972 r
.26933 .48588 .27657 .49111 .28732 .48943 .28009 .48428 Mtetra
.544 .759 .976 r
.28009 .48428 .28732 .48943 .29811 .48791 .29091 .48284 Mtetra
.528 .757 .98 r
.29091 .48284 .29811 .48791 .30895 .4866 .30176 .48162 Mtetra
.507 .753 .984 r
.30176 .48162 .30895 .4866 .31983 .48552 .31266 .48063 Mtetra
.482 .748 .987 r
.31266 .48063 .31983 .48552 .33075 .48472 .32361 .47993 Mtetra
.451 .739 .99 r
.32361 .47993 .33075 .48472 .34173 .48423 .3346 .47955 Mtetra
.414 .727 .99 r
.3346 .47955 .34173 .48423 .35275 .4841 .34565 .47954 Mtetra
.368 .711 .986 r
.34565 .47954 .35275 .4841 .36382 .48438 .35674 .47995 Mtetra
.314 .688 .978 r
.35674 .47995 .36382 .48438 .37495 .4851 .36789 .48081 Mtetra
.252 .66 .964 r
.36789 .48081 .37495 .4851 .38614 .48629 .37909 .48216 Mtetra
.183 .624 .942 r
.37909 .48216 .38614 .48629 .39738 .48799 .39036 .48402 Mtetra
.108 .582 .912 r
.39036 .48402 .39738 .48799 .4087 .49019 .40169 .48639 Mtetra
.031 .535 .875 r
.40169 .48639 .4087 .49019 .42008 .49291 .4131 .48928 Mtetra
0 .486 .832 r
.4131 .48928 .42008 .49291 .43155 .49611 .42459 .49266 Mtetra
0 .438 .788 r
.42459 .49266 .43155 .49611 .44311 .49977 .43617 .49648 Mtetra
0 .397 .746 r
.43617 .49648 .44311 .49977 .45476 .50381 .44785 .50069 Mtetra
0 .365 .712 r
.44785 .50069 .45476 .50381 .46651 .50816 .45963 .50518 Mtetra
0 .344 .688 r
.45963 .50518 .46651 .50816 .47837 .51271 .47152 .50984 Mtetra
0 .338 .677 r
.47152 .50984 .47837 .51271 .49034 .51735 .48352 .51456 Mtetra
0 .347 .681 r
.48352 .51456 .49034 .51735 .50243 .52193 .49564 .51917 Mtetra
0 .373 .702 r
.49564 .51917 .50243 .52193 .51463 .5263 .50787 .52352 Mtetra
0 .416 .74 r
.50787 .52352 .51463 .5263 .52695 .5303 .52023 .52744 Mtetra
0 .476 .792 r
.52023 .52744 .52695 .5303 .53937 .53378 .53269 .53077 Mtetra
.018 .549 .853 r
.53269 .53077 .53937 .53378 .55191 .53657 .54526 .53334 Mtetra
.137 .628 .914 r
.54526 .53334 .55191 .53657 .56454 .53852 .55793 .535 Mtetra
.265 .701 .964 r
.55793 .535 .56454 .53852 .57725 .53952 .57068 .53563 Mtetra
.39 .759 .992 r
.57068 .53563 .57725 .53952 .59004 .53943 .58351 .53512 Mtetra
.5 .797 .998 r
.58351 .53512 .59004 .53943 .60289 .53818 .59639 .53339 Mtetra
.587 .816 .987 r
.59639 .53339 .60289 .53818 .61578 .53571 .60932 .53039 Mtetra
.653 .82 .964 r
.60932 .53039 .61578 .53571 .62871 .53199 .62228 .52611 Mtetra
.7 .816 .937 r
.62228 .52611 .62871 .53199 .64166 .52702 .63525 .52055 Mtetra
.734 .807 .91 r
.63525 .52055 .64166 .52702 .65461 .52082 .64823 .51376 Mtetra
.757 .796 .884 r
.64823 .51376 .65461 .52082 .66755 .51344 .6612 .50581 Mtetra
.774 .785 .862 r
.6612 .50581 .66755 .51344 .68048 .50498 .67416 .49679 Mtetra
.786 .775 .844 r
.67416 .49679 .68048 .50498 .69338 .49551 .68709 .48681 Mtetra
.794 .766 .828 r
.68709 .48681 .69338 .49551 .70625 .48515 .69998 .47599 Mtetra
.799 .758 .815 r
.69998 .47599 .70625 .48515 .71909 .47402 .71285 .46445 Mtetra
.803 .752 .806 r
.71285 .46445 .71909 .47402 .7319 .46225 .72568 .45234 Mtetra
.805 .747 .798 r
.72568 .45234 .7319 .46225 .74466 .44997 .73848 .43978 Mtetra
.807 .743 .793 r
.73848 .43978 .74466 .44997 .7574 .43731 .75125 .42691 Mtetra
.807 .74 .789 r
.75125 .42691 .7574 .43731 .77011 .42439 .764 .41386 Mtetra
.807 .738 .787 r
.764 .41386 .77011 .42439 .7828 .41135 .77673 .40073 Mtetra
.806 .737 .787 r
.77673 .40073 .7828 .41135 .79547 .3983 .78946 .38765 Mtetra
.805 .737 .789 r
.78946 .38765 .79547 .3983 .80815 .38533 .80218 .3747 Mtetra
.803 .737 .791 r
.80218 .3747 .80815 .38533 .82083 .37255 .81491 .36199 Mtetra
.8 .738 .795 r
.81491 .36199 .82083 .37255 .83352 .36004 .82767 .34957 Mtetra
.797 .74 .8 r
.82767 .34957 .83352 .36004 .84625 .34787 .84046 .33752 Mtetra
.793 .742 .805 r
.84046 .33752 .84625 .34787 .85901 .33611 .85328 .32589 Mtetra
.788 .744 .812 r
.85328 .32589 .85901 .33611 .87182 .32478 .86616 .31471 Mtetra
.563 .758 .969 r
.25129 .48228 .25861 .48763 .26933 .48588 .26202 .4806 Mtetra
.552 .758 .973 r
.26202 .4806 .26933 .48588 .28009 .48428 .27281 .47907 Mtetra
.538 .756 .977 r
.27281 .47907 .28009 .48428 .29091 .48284 .28364 .47772 Mtetra
.52 .754 .981 r
.28364 .47772 .29091 .48284 .30176 .48162 .29451 .47658 Mtetra
.499 .75 .985 r
.29451 .47658 .30176 .48162 .31266 .48063 .30543 .47569 Mtetra
.472 .744 .988 r
.30543 .47569 .31266 .48063 .32361 .47993 .3164 .4751 Mtetra
.44 .734 .989 r
.3164 .4751 .32361 .47993 .3346 .47955 .32741 .47484 Mtetra
.4 .721 .989 r
.32741 .47484 .3346 .47955 .34565 .47954 .33848 .47496 Mtetra
.352 .703 .984 r
.33848 .47496 .34565 .47954 .35674 .47995 .34959 .47551 Mtetra
.295 .679 .974 r
.34959 .47551 .35674 .47995 .36789 .48081 .36075 .47652 Mtetra
.23 .648 .958 r
.36075 .47652 .36789 .48081 .37909 .48216 .37198 .47803 Mtetra
.157 .609 .933 r
.37198 .47803 .37909 .48216 .39036 .48402 .38326 .48007 Mtetra
.079 .564 .899 r
.38326 .48007 .39036 .48402 .40169 .48639 .39462 .48263 Mtetra
0 .514 .857 r
.39462 .48263 .40169 .48639 .4131 .48928 .40605 .48571 Mtetra
0 .463 .81 r
.40605 .48571 .4131 .48928 .42459 .49266 .41756 .48929 Mtetra
0 .414 .762 r
.41756 .48929 .42459 .49266 .43617 .49648 .42916 .49331 Mtetra
0 .372 .719 r
.42916 .49331 .43617 .49648 .44785 .50069 .44086 .49769 Mtetra
0 .34 .683 r
.44086 .49769 .44785 .50069 .45963 .50518 .45267 .50235 Mtetra
0 .321 .658 r
.45267 .50235 .45963 .50518 .47152 .50984 .46458 .50715 Mtetra
.269 0 0 r
.46458 .50715 .47152 .50984 .48352 .51456 .47662 .51196 Mtetra
.258 0 0 r
.47662 .51196 .48352 .51456 .49564 .51917 .48877 .51662 Mtetra
0 .359 .679 r
.48877 .51662 .49564 .51917 .50787 .52352 .50104 .52097 Mtetra
0 .407 .72 r
.50104 .52097 .50787 .52352 .52023 .52744 .51343 .52482 Mtetra
0 .474 .778 r
.51343 .52482 .52023 .52744 .53269 .53077 .52593 .528 Mtetra
.016 .554 .845 r
.52593 .528 .53269 .53077 .54526 .53334 .53854 .53035 Mtetra
.143 .64 .912 r
.53854 .53035 .54526 .53334 .55793 .535 .55125 .53171 Mtetra
.28 .719 .965 r
.55125 .53171 .55793 .535 .57068 .53563 .56404 .53196 Mtetra
.412 .779 .994 r
.56404 .53196 .57068 .53563 .58351 .53512 .57691 .531 Mtetra
.523 .815 .999 r
.57691 .531 .58351 .53512 .59639 .53339 .58983 .52875 Mtetra
.61 .831 .984 r
.58983 .52875 .59639 .53339 .60932 .53039 .6028 .52519 Mtetra
.674 .832 .959 r
.6028 .52519 .60932 .53039 .62228 .52611 .61579 .52029 Mtetra
.718 .824 .931 r
.61579 .52029 .62228 .52611 .63525 .52055 .6288 .5141 Mtetra
.749 .813 .903 r
.6288 .5141 .63525 .52055 .64823 .51376 .6418 .50668 Mtetra
.769 .8 .877 r
.6418 .50668 .64823 .51376 .6612 .50581 .6548 .4981 Mtetra
.784 .787 .855 r
.6548 .4981 .6612 .50581 .67416 .49679 .66778 .48848 Mtetra
.793 .775 .837 r
.66778 .48848 .67416 .49679 .68709 .48681 .68073 .47794 Mtetra
.799 .765 .822 r
.68073 .47794 .68709 .48681 .69998 .47599 .69366 .4666 Mtetra
.803 .756 .81 r
.69366 .4666 .69998 .47599 .71285 .46445 .70655 .45462 Mtetra
.805 .749 .8 r
.70655 .45462 .71285 .46445 .72568 .45234 .71941 .44213 Mtetra
.806 .743 .793 r
.71941 .44213 .72568 .45234 .73848 .43978 .73224 .42927 Mtetra
.806 .738 .788 r
.73224 .42927 .73848 .43978 .75125 .42691 .74504 .41617 Mtetra
.806 .735 .785 r
.74504 .41617 .75125 .42691 .764 .41386 .75783 .40295 Mtetra
.805 .732 .784 r
.75783 .40295 .764 .41386 .77673 .40073 .7706 .38974 Mtetra
.803 .731 .784 r
.7706 .38974 .77673 .40073 .78946 .38765 .78337 .37662 Mtetra
.801 .73 .786 r
.78337 .37662 .78946 .38765 .80218 .3747 .79614 .3637 Mtetra
.798 .731 .789 r
.79614 .3637 .80218 .3747 .81491 .36199 .80893 .35105 Mtetra
.795 .732 .793 r
.80893 .35105 .81491 .36199 .82767 .34957 .82175 .33874 Mtetra
.792 .733 .798 r
.82175 .33874 .82767 .34957 .84046 .33752 .83459 .32683 Mtetra
.788 .735 .804 r
.83459 .32683 .84046 .33752 .85328 .32589 .84749 .31534 Mtetra
.783 .737 .81 r
.84749 .31534 .85328 .32589 .86616 .31471 .86043 .30433 Mtetra
.558 .755 .97 r
.2439 .47685 .25129 .48228 .26202 .4806 .25466 .47524 Mtetra
.546 .755 .974 r
.25466 .47524 .26202 .4806 .27281 .47907 .26546 .47379 Mtetra
.531 .753 .978 r
.26546 .47379 .27281 .47907 .28364 .47772 .27631 .47253 Mtetra
.513 .75 .981 r
.27631 .47253 .28364 .47772 .29451 .47658 .2872 .47148 Mtetra
.491 .746 .985 r
.2872 .47148 .29451 .47658 .30543 .47569 .29814 .47069 Mtetra
.463 .739 .988 r
.29814 .47069 .30543 .47569 .3164 .4751 .30913 .47021 Mtetra
.429 .729 .989 r
.30913 .47021 .3164 .4751 .32741 .47484 .32016 .47007 Mtetra
.387 .715 .987 r
.32016 .47007 .32741 .47484 .33848 .47496 .33124 .47033 Mtetra
.337 .695 .982 r
.33124 .47033 .33848 .47496 .34959 .47551 .34237 .47102 Mtetra
.277 .669 .97 r
.34237 .47102 .34959 .47551 .36075 .47652 .35355 .4722 Mtetra
.208 .635 .951 r
.35355 .4722 .36075 .47652 .37198 .47803 .36479 .47389 Mtetra
.131 .594 .922 r
.36479 .47389 .37198 .47803 .38326 .48007 .3761 .47612 Mtetra
.05 .545 .885 r
.3761 .47612 .38326 .48007 .39462 .48263 .38747 .47889 Mtetra
0 .492 .839 r
.38747 .47889 .39462 .48263 .40605 .48571 .39892 .48218 Mtetra
0 .439 .788 r
.39892 .48218 .40605 .48571 .41756 .48929 .41045 .48598 Mtetra
0 .389 .737 r
.41045 .48598 .41756 .48929 .42916 .49331 .42207 .49021 Mtetra
0 .346 .691 r
.42207 .49021 .42916 .49331 .44086 .49769 .4338 .49481 Mtetra
.269 0 0 r
.4338 .49481 .44086 .49769 .45267 .50235 .44563 .49965 Mtetra
.291 0 0 r
.44563 .49965 .45267 .50235 .46458 .50715 .45757 .50462 Mtetra
.296 0 0 r
.45757 .50462 .46458 .50715 .47662 .51196 .46963 .50955 Mtetra
.282 0 0 r
.46963 .50955 .47662 .51196 .48877 .51662 .48182 .51429 Mtetra
.247 0 0 r
.48182 .51429 .48877 .51662 .50104 .52097 .49413 .51865 Mtetra
0 .397 .698 r
.49413 .51865 .50104 .52097 .51343 .52482 .50656 .52244 Mtetra
0 .47 .761 r
.50656 .52244 .51343 .52482 .52593 .528 .5191 .52549 Mtetra
.011 .558 .834 r
.5191 .52549 .52593 .528 .53854 .53035 .53175 .52762 Mtetra
.147 .651 .906 r
.53175 .52762 .53854 .53035 .55125 .53171 .5445 .52869 Mtetra
.293 .735 .964 r
.5445 .52869 .55125 .53171 .56404 .53196 .55734 .52855 Mtetra
.431 .798 .995 r
.55734 .52855 .56404 .53196 .57691 .531 .57025 .52713 Mtetra
.545 .835 .998 r
.57025 .52713 .57691 .531 .58983 .52875 .58321 .52434 Mtetra
.632 .848 .982 r
.58321 .52434 .58983 .52875 .6028 .52519 .59622 .52018 Mtetra
.694 .846 .956 r
.59622 .52018 .6028 .52519 .61579 .52029 .60924 .51464 Mtetra
.736 .835 .926 r
.60924 .51464 .61579 .52029 .6288 .5141 .62229 .50779 Mtetra
.764 .821 .897 r
.62229 .50779 .6288 .5141 .6418 .50668 .63532 .49968 Mtetra
.783 .806 .872 r
.63532 .49968 .6418 .50668 .6548 .4981 .64835 .49043 Mtetra
.794 .792 .85 r
.64835 .49043 .6548 .4981 .66778 .48848 .66136 .48017 Mtetra
.802 .779 .832 r
.66136 .48017 .66778 .48848 .68073 .47794 .67433 .46902 Mtetra
.806 .767 .817 r
.67433 .46902 .68073 .47794 .69366 .4666 .68728 .45713 Mtetra
.808 .757 .805 r
.68728 .45713 .69366 .4666 .70655 .45462 .7002 .44466 Mtetra
.809 .749 .796 r
.7002 .44466 .70655 .45462 .71941 .44213 .71308 .43176 Mtetra
.809 .742 .79 r
.71308 .43176 .71941 .44213 .73224 .42927 .72594 .41856 Mtetra
.808 .736 .785 r
.72594 .41856 .73224 .42927 .74504 .41617 .73878 .4052 Mtetra
.806 .732 .783 r
.73878 .4052 .74504 .41617 .75783 .40295 .7516 .39181 Mtetra
.804 .729 .782 r
.7516 .39181 .75783 .40295 .7706 .38974 .76441 .37848 Mtetra
.801 .727 .782 r
.76441 .37848 .7706 .38974 .78337 .37662 .77723 .36533 Mtetra
.798 .726 .784 r
.77723 .36533 .78337 .37662 .79614 .3637 .79005 .35243 Mtetra
.795 .726 .788 r
.79005 .35243 .79614 .3637 .80893 .35105 .80289 .33985 Mtetra
.791 .727 .792 r
.80289 .33985 .80893 .35105 .82175 .33874 .81577 .32764 Mtetra
.787 .728 .797 r
.81577 .32764 .82175 .33874 .83459 .32683 .82867 .31587 Mtetra
.783 .73 .803 r
.82867 .31587 .83459 .32683 .84749 .31534 .84163 .30455 Mtetra
.778 .732 .81 r
.84163 .30455 .84749 .31534 .86043 .30433 .85464 .29371 Mtetra
.553 .752 .97 r
.23646 .47133 .2439 .47685 .25466 .47524 .24724 .4698 Mtetra
.541 .751 .974 r
.24724 .4698 .25466 .47524 .26546 .47379 .25806 .46843 Mtetra
.526 .749 .978 r
.25806 .46843 .26546 .47379 .27631 .47253 .26892 .46725 Mtetra
.507 .746 .981 r
.26892 .46725 .27631 .47253 .2872 .47148 .27983 .46629 Mtetra
.483 .741 .985 r
.27983 .46629 .2872 .47148 .29814 .47069 .29079 .46561 Mtetra
.454 .734 .987 r
.29079 .46561 .29814 .47069 .30913 .47021 .30179 .46523 Mtetra
.419 .723 .988 r
.30179 .46523 .30913 .47021 .32016 .47007 .31284 .46522 Mtetra
.375 .707 .986 r
.31284 .46522 .32016 .47007 .33124 .47033 .32394 .46562 Mtetra
.322 .686 .979 r
.32394 .46562 .33124 .47033 .34237 .47102 .33508 .46647 Mtetra
.259 .658 .966 r
.33508 .46647 .34237 .47102 .35355 .4722 .34628 .46782 Mtetra
.187 .622 .944 r
.34628 .46782 .35355 .4722 .36479 .47389 .35754 .4697 Mtetra
.107 .577 .912 r
.35754 .4697 .36479 .47389 .3761 .47612 .36886 .47213 Mtetra
.023 .526 .871 r
.36886 .47213 .3761 .47612 .38747 .47889 .38025 .47512 Mtetra
0 .471 .821 r
.38025 .47512 .38747 .47889 .39892 .48218 .39171 .47865 Mtetra
0 .415 .767 r
.39171 .47865 .39892 .48218 .41045 .48598 .40326 .48268 Mtetra
0 .364 .713 r
.40326 .48268 .41045 .48598 .42207 .49021 .41491 .48716 Mtetra
0 .321 .665 r
.41491 .48716 .42207 .49021 .4338 .49481 .42665 .49198 Mtetra
.297 0 0 r
.42665 .49198 .4338 .49481 .44563 .49965 .43851 .49705 Mtetra
.317 0 0 r
.43851 .49705 .44563 .49965 .45757 .50462 .45048 .5022 Mtetra
.32 0 0 r
.45048 .5022 .45757 .50462 .46963 .50955 .46257 .50729 Mtetra
.304 0 0 r
.46257 .50729 .46963 .50955 .48182 .51429 .47479 .51213 Mtetra
.266 0 0 r
.47479 .51213 .48182 .51429 .49413 .51865 .48713 .51653 Mtetra
0 .386 .678 r
.48713 .51653 .49413 .51865 .50656 .52244 .4996 .52029 Mtetra
0 .465 .744 r
.4996 .52029 .50656 .52244 .5191 .52549 .51219 .52323 Mtetra
.007 .56 .822 r
.51219 .52323 .5191 .52549 .53175 .52762 .52489 .52516 Mtetra
.151 .661 .9 r
.52489 .52516 .53175 .52762 .5445 .52869 .53768 .52594 Mtetra
.305 .751 .961 r
.53768 .52594 .5445 .52869 .55734 .52855 .55057 .52542 Mtetra
.449 .817 .994 r
.55057 .52542 .55734 .52855 .57025 .52713 .56352 .52353 Mtetra
.566 .853 .997 r
.56352 .52353 .57025 .52713 .58321 .52434 .57653 .5202 Mtetra
.654 .865 .979 r
.57653 .5202 .58321 .52434 .59622 .52018 .58957 .51543 Mtetra
.714 .86 .951 r
.58957 .51543 .59622 .52018 .60924 .51464 .60264 .50923 Mtetra
.754 .848 .921 r
.60264 .50923 .60924 .51464 .62229 .50779 .61572 .50168 Mtetra
.78 .831 .892 r
.61572 .50168 .62229 .50779 .63532 .49968 .62879 .49286 Mtetra
.796 .815 .866 r
.62879 .49286 .63532 .49968 .64835 .49043 .64185 .48291 Mtetra
.806 .799 .845 r
.64185 .48291 .64835 .49043 .66136 .48017 .65488 .47196 Mtetra
.812 .784 .827 r
.65488 .47196 .66136 .48017 .67433 .46902 .66789 .46017 Mtetra
.814 .771 .813 r
.66789 .46017 .67433 .46902 .68728 .45713 .68086 .44769 Mtetra
.815 .76 .802 r
.68086 .44769 .68728 .45713 .7002 .44466 .6938 .4347 Mtetra
.814 .751 .793 r
.6938 .4347 .7002 .44466 .71308 .43176 .70672 .42135 Mtetra
.813 .743 .787 r
.70672 .42135 .71308 .43176 .72594 .41856 .7196 .40779 Mtetra
.81 .737 .783 r
.7196 .40779 .72594 .41856 .73878 .4052 .73247 .39414 Mtetra
.807 .732 .781 r
.73247 .39414 .73878 .4052 .7516 .39181 .74533 .38054 Mtetra
.804 .728 .781 r
.74533 .38054 .7516 .39181 .76441 .37848 .75818 .36709 Mtetra
.801 .726 .782 r
.75818 .36709 .76441 .37848 .77723 .36533 .77104 .35388 Mtetra
.797 .724 .784 r
.77104 .35388 .77723 .36533 .79005 .35243 .78391 .34098 Mtetra
.793 .724 .787 r
.78391 .34098 .79005 .35243 .80289 .33985 .79681 .32846 Mtetra
.789 .724 .792 r
.79681 .32846 .80289 .33985 .81577 .32764 .80973 .31636 Mtetra
.784 .725 .797 r
.80973 .31636 .81577 .32764 .82867 .31587 .8227 .30472 Mtetra
.779 .726 .804 r
.8227 .30472 .82867 .31587 .84163 .30455 .83572 .29357 Mtetra
.774 .728 .811 r
.83572 .29357 .84163 .30455 .85464 .29371 .8488 .2829 Mtetra
.549 .749 .97 r
.22896 .46571 .23646 .47133 .24724 .4698 .23975 .46425 Mtetra
.536 .747 .973 r
.23975 .46425 .24724 .4698 .25806 .46843 .25059 .46295 Mtetra
.52 .745 .977 r
.25059 .46295 .25806 .46843 .26892 .46725 .26147 .46185 Mtetra
.501 .742 .981 r
.26147 .46185 .26892 .46725 .27983 .46629 .2724 .46099 Mtetra
.476 .736 .984 r
.2724 .46099 .27983 .46629 .29079 .46561 .28338 .4604 Mtetra
.446 .728 .986 r
.28338 .4604 .29079 .46561 .30179 .46523 .2944 .46014 Mtetra
.409 .716 .986 r
.2944 .46014 .30179 .46523 .31284 .46522 .30546 .46025 Mtetra
.364 .699 .984 r
.30546 .46025 .31284 .46522 .32394 .46562 .31657 .46079 Mtetra
.308 .676 .976 r
.31657 .46079 .32394 .46562 .33508 .46647 .32773 .4618 Mtetra
.243 .646 .961 r
.32773 .4618 .33508 .46647 .34628 .46782 .33895 .46333 Mtetra
.168 .608 .938 r
.33895 .46333 .34628 .46782 .35754 .4697 .35022 .46541 Mtetra
.085 .561 .904 r
.35022 .46541 .35754 .4697 .36886 .47213 .36155 .46806 Mtetra
0 .507 .859 r
.36155 .46806 .36886 .47213 .38025 .47512 .37296 .47128 Mtetra
0 .45 .806 r
.37296 .47128 .38025 .47512 .39171 .47865 .38444 .47505 Mtetra
0 .393 .749 r
.38444 .47505 .39171 .47865 .40326 .48268 .396 .47934 Mtetra
0 .341 .694 r
.396 .47934 .40326 .48268 .41491 .48716 .40766 .48408 Mtetra
.284 0 0 r
.40766 .48408 .41491 .48716 .42665 .49198 .41943 .48916 Mtetra
.321 0 0 r
.41943 .48916 .42665 .49198 .43851 .49705 .43131 .49446 Mtetra
.34 0 0 r
.43131 .49446 .43851 .49705 .45048 .5022 .4433 .49984 Mtetra
.341 0 0 r
.4433 .49984 .45048 .5022 .46257 .50729 .45543 .50511 Mtetra
.322 0 0 r
.45543 .50511 .46257 .50729 .47479 .51213 .46768 .51008 Mtetra
.282 0 0 r
.46768 .51008 .47479 .51213 .48713 .51653 .48006 .51455 Mtetra
.216 0 0 r
.48006 .51455 .48713 .51653 .4996 .52029 .49257 .51831 Mtetra
0 .461 .731 r
.49257 .51831 .4996 .52029 .51219 .52323 .5052 .52116 Mtetra
.005 .563 .813 r
.5052 .52116 .51219 .52323 .52489 .52516 .51794 .52292 Mtetra
.157 .67 .895 r
.51794 .52292 .52489 .52516 .53768 .52594 .53079 .52342 Mtetra
.318 .766 .959 r
.53079 .52342 .53768 .52594 .55057 .52542 .54372 .52254 Mtetra
.467 .835 .992 r
.54372 .52254 .55057 .52542 .56352 .52353 .55672 .52019 Mtetra
.587 .871 .994 r
.55672 .52019 .56352 .52353 .57653 .5202 .56978 .51633 Mtetra
.674 .881 .975 r
.56978 .51633 .57653 .5202 .58957 .51543 .58287 .51094 Mtetra
.733 .874 .946 r
.58287 .51094 .58957 .51543 .60264 .50923 .59598 .50408 Mtetra
.771 .86 .915 r
.59598 .50408 .60264 .50923 .61572 .50168 .6091 .49582 Mtetra
.796 .842 .886 r
.6091 .49582 .61572 .50168 .62879 .49286 .62221 .48627 Mtetra
.81 .824 .861 r
.62221 .48627 .62879 .49286 .64185 .48291 .6353 .47559 Mtetra
.818 .807 .84 r
.6353 .47559 .64185 .48291 .65488 .47196 .64837 .46393 Mtetra
.822 .791 .823 r
.64837 .46393 .65488 .47196 .66789 .46017 .6614 .45147 Mtetra
.824 .778 .809 r
.6614 .45147 .66789 .46017 .68086 .44769 .6744 .43838 Mtetra
.823 .766 .799 r
.6744 .43838 .68086 .44769 .6938 .4347 .68737 .42484 Mtetra
.821 .756 .791 r
.68737 .42484 .6938 .4347 .70672 .42135 .70031 .41101 Mtetra
.818 .747 .785 r
.70031 .41101 .70672 .42135 .7196 .40779 .71323 .39704 Mtetra
.814 .74 .782 r
.71323 .39704 .7196 .40779 .73247 .39414 .72613 .38309 Mtetra
.81 .734 .78 r
.72613 .38309 .73247 .39414 .74533 .38054 .73902 .36926 Mtetra
.806 .73 .78 r
.73902 .36926 .74533 .38054 .75818 .36709 .75191 .35565 Mtetra
.802 .727 .782 r
.75191 .35565 .75818 .36709 .77104 .35388 .76481 .34237 Mtetra
.797 .725 .784 r
.76481 .34237 .77104 .35388 .78391 .34098 .77773 .32946 Mtetra
.792 .723 .788 r
.77773 .32946 .78391 .34098 .79681 .32846 .79067 .31698 Mtetra
.787 .723 .793 r
.79067 .31698 .79681 .32846 .80973 .31636 .80366 .30498 Mtetra
.781 .724 .799 r
.80366 .30498 .80973 .31636 .8227 .30472 .81669 .29347 Mtetra
.776 .725 .805 r
.81669 .29347 .8227 .30472 .83572 .29357 .82977 .28247 Mtetra
.77 .726 .812 r
.82977 .28247 .83572 .29357 .8488 .2829 .84291 .27199 Mtetra
.545 .745 .969 r
.2214 .45997 .22896 .46571 .23975 .46425 .23221 .45857 Mtetra
.532 .743 .973 r
.23221 .45857 .23975 .46425 .25059 .46295 .24307 .45734 Mtetra
.516 .741 .976 r
.24307 .45734 .25059 .46295 .26147 .46185 .25397 .45632 Mtetra
.496 .736 .98 r
.25397 .45632 .26147 .46185 .2724 .46099 .26491 .45554 Mtetra
.471 .73 .983 r
.26491 .45554 .2724 .46099 .28338 .4604 .2759 .45505 Mtetra
.44 .721 .985 r
.2759 .45505 .28338 .4604 .2944 .46014 .28694 .4549 Mtetra
.401 .708 .985 r
.28694 .4549 .2944 .46014 .30546 .46025 .29802 .45514 Mtetra
.354 .691 .981 r
.29802 .45514 .30546 .46025 .31657 .46079 .30914 .45582 Mtetra
.298 .667 .973 r
.30914 .45582 .31657 .46079 .32773 .4618 .32032 .45699 Mtetra
.23 .635 .957 r
.32032 .45699 .32773 .4618 .33895 .46333 .33155 .45869 Mtetra
.153 .595 .932 r
.33155 .45869 .33895 .46333 .35022 .46541 .34283 .46097 Mtetra
.068 .546 .896 r
.34283 .46097 .35022 .46541 .36155 .46806 .35418 .46384 Mtetra
0 .49 .85 r
.35418 .46384 .36155 .46806 .37296 .47128 .36559 .4673 Mtetra
0 .431 .795 r
.36559 .4673 .37296 .47128 .38444 .47505 .37709 .47133 Mtetra
0 .373 .737 r
.37709 .47133 .38444 .47505 .396 .47934 .38867 .47588 Mtetra
0 .321 .68 r
.38867 .47588 .396 .47934 .40766 .48408 .40035 .48089 Mtetra
.304 0 0 r
.40035 .48089 .40766 .48408 .41943 .48916 .41213 .48625 Mtetra
.339 0 0 r
.41213 .48625 .41943 .48916 .43131 .49446 .42403 .49182 Mtetra
.357 0 0 r
.42403 .49182 .43131 .49446 .4433 .49984 .43605 .49743 Mtetra
.356 0 0 r
.43605 .49743 .4433 .49984 .45543 .50511 .4482 .50291 Mtetra
.335 0 0 r
.4482 .50291 .45543 .50511 .46768 .51008 .46048 .50804 Mtetra
.292 0 0 r
.46048 .50804 .46768 .51008 .48006 .51455 .4729 .51261 Mtetra
.223 0 0 r
.4729 .51261 .48006 .51455 .49257 .51831 .48545 .5164 Mtetra
0 .461 .725 r
.48545 .5164 .49257 .51831 .5052 .52116 .49812 .5192 Mtetra
.009 .568 .811 r
.49812 .5192 .5052 .52116 .51794 .52292 .51091 .52081 Mtetra
.167 .681 .894 r
.51091 .52081 .51794 .52292 .53079 .52342 .52381 .52108 Mtetra
.334 .78 .959 r
.52381 .52108 .53079 .52342 .54372 .52254 .53679 .51986 Mtetra
.486 .85 .99 r
.53679 .51986 .54372 .52254 .55672 .52019 .54985 .51707 Mtetra
.607 .886 .99 r
.54985 .51707 .55672 .52019 .56978 .51633 .56295 .51268 Mtetra
.694 .894 .97 r
.56295 .51268 .56978 .51633 .58287 .51094 .5761 .5067 Mtetra
.751 .886 .94 r
.5761 .5067 .58287 .51094 .59598 .50408 .58926 .49917 Mtetra
.788 .871 .909 r
.58926 .49917 .59598 .50408 .6091 .49582 .60242 .49021 Mtetra
.81 .852 .881 r
.60242 .49021 .6091 .49582 .62221 .48627 .61557 .47993 Mtetra
.823 .833 .856 r
.61557 .47993 .62221 .48627 .6353 .47559 .6287 .46852 Mtetra
.83 .815 .835 r
.6287 .46852 .6353 .47559 .64837 .46393 .6418 .45614 Mtetra
.833 .799 .819 r
.6418 .45614 .64837 .46393 .6614 .45147 .65487 .44299 Mtetra
.833 .785 .806 r
.65487 .44299 .6614 .45147 .6744 .43838 .6679 .42926 Mtetra
.831 .773 .796 r
.6679 .42926 .6744 .43838 .68737 .42484 .6809 .41514 Mtetra
.828 .762 .789 r
.6809 .41514 .68737 .42484 .70031 .41101 .69387 .40081 Mtetra
.824 .753 .784 r
.69387 .40081 .70031 .41101 .71323 .39704 .70682 .38642 Mtetra
.82 .745 .781 r
.70682 .38642 .71323 .39704 .72613 .38309 .71975 .37213 Mtetra
.815 .738 .78 r
.71975 .37213 .72613 .38309 .73902 .36926 .73268 .35804 Mtetra
.809 .733 .781 r
.73268 .35804 .73902 .36926 .75191 .35565 .74561 .34427 Mtetra
.803 .729 .782 r
.74561 .34427 .75191 .35565 .76481 .34237 .75855 .33088 Mtetra
.798 .727 .785 r
.75855 .33088 .76481 .34237 .77773 .32946 .77151 .31794 Mtetra
.792 .725 .79 r
.77151 .31794 .77773 .32946 .79067 .31698 .78451 .30549 Mtetra
.786 .724 .795 r
.78451 .30549 .79067 .31698 .80366 .30498 .79755 .29357 Mtetra
.78 .724 .8 r
.79755 .29357 .80366 .30498 .81669 .29347 .81063 .28218 Mtetra
.773 .724 .807 r
.81063 .28218 .81669 .29347 .82977 .28247 .82378 .27132 Mtetra
.767 .725 .814 r
.82378 .27132 .82977 .28247 .84291 .27199 .83698 .261 Mtetra
.542 .741 .968 r
.21379 .45409 .2214 .45997 .23221 .45857 .22462 .45275 Mtetra
.528 .739 .971 r
.22462 .45275 .23221 .45857 .24307 .45734 .23549 .45159 Mtetra
.512 .736 .975 r
.23549 .45159 .24307 .45734 .25397 .45632 .24641 .45063 Mtetra
.492 .731 .978 r
.24641 .45063 .25397 .45632 .26491 .45554 .25737 .44993 Mtetra
.466 .724 .981 r
.25737 .44993 .26491 .45554 .2759 .45505 .26837 .44954 Mtetra
.435 .714 .983 r
.26837 .44954 .2759 .45505 .28694 .4549 .27942 .44949 Mtetra
.396 .701 .983 r
.27942 .44949 .28694 .4549 .29802 .45514 .29052 .44984 Mtetra
.348 .682 .979 r
.29052 .44984 .29802 .45514 .30914 .45582 .30166 .45065 Mtetra
.29 .657 .97 r
.30166 .45065 .30914 .45582 .32032 .45699 .31285 .45198 Mtetra
.221 .624 .954 r
.31285 .45198 .32032 .45699 .33155 .45869 .32409 .45385 Mtetra
.142 .582 .928 r
.32409 .45385 .33155 .45869 .34283 .46097 .33538 .45633 Mtetra
.056 .532 .892 r
.33538 .45633 .34283 .46097 .35418 .46384 .34674 .45941 Mtetra
0 .475 .844 r
.34674 .45941 .35418 .46384 .36559 .4673 .35817 .46311 Mtetra
0 .415 .789 r
.35817 .46311 .36559 .4673 .37709 .47133 .36967 .46739 Mtetra
0 .357 .73 r
.36967 .46739 .37709 .47133 .38867 .47588 .38126 .47222 Mtetra
0 .305 .673 r
.38126 .47222 .38867 .47588 .40035 .48089 .39295 .47751 Mtetra
.317 0 0 r
.39295 .47751 .40035 .48089 .41213 .48625 .40475 .48315 Mtetra
.351 0 0 r
.40475 .48315 .41213 .48625 .42403 .49182 .41667 .489 Mtetra
.367 0 0 r
.41667 .489 .42403 .49182 .43605 .49743 .42871 .49487 Mtetra
.365 0 0 r
.42871 .49487 .43605 .49743 .4482 .50291 .44089 .50058 Mtetra
.342 0 0 r
.44089 .50058 .4482 .50291 .46048 .50804 .4532 .5059 Mtetra
.296 0 0 r
.4532 .5059 .46048 .50804 .4729 .51261 .46566 .5106 Mtetra
.223 0 0 r
.46566 .5106 .4729 .51261 .48545 .5164 .47825 .51445 Mtetra
0 .465 .73 r
.47825 .51445 .48545 .5164 .49812 .5192 .49096 .51722 Mtetra
.02 .577 .817 r
.49096 .51722 .49812 .5192 .51091 .52081 .5038 .51873 Mtetra
.185 .693 .9 r
.5038 .51873 .51091 .52081 .52381 .52108 .51675 .51878 Mtetra
.355 .794 .962 r
.51675 .51878 .52381 .52108 .53679 .51986 .52979 .51726 Mtetra
.508 .863 .99 r
.52979 .51726 .53679 .51986 .54985 .51707 .54289 .51407 Mtetra
.628 .897 .986 r
.54289 .51407 .54985 .51707 .56295 .51268 .55606 .50919 Mtetra
.712 .904 .964 r
.55606 .50919 .56295 .51268 .5761 .5067 .56926 .50263 Mtetra
.767 .895 .933 r
.56926 .50263 .5761 .5067 .58926 .49917 .58247 .49446 Mtetra
.802 .879 .902 r
.58247 .49446 .58926 .49917 .60242 .49021 .59568 .48481 Mtetra
.824 .86 .874 r
.59568 .48481 .60242 .49021 .61557 .47993 .60888 .47382 Mtetra
.836 .841 .85 r
.60888 .47382 .61557 .47993 .6287 .46852 .62205 .46167 Mtetra
.842 .823 .83 r
.62205 .46167 .6287 .46852 .6418 .45614 .6352 .44857 Mtetra
.844 .807 .815 r
.6352 .44857 .6418 .45614 .65487 .44299 .6483 .43473 Mtetra
.843 .793 .803 r
.6483 .43473 .65487 .44299 .6679 .42926 .66137 .42035 Mtetra
.84 .78 .794 r
.66137 .42035 .6679 .42926 .6809 .41514 .6744 .40565 Mtetra
.836 .769 .787 r
.6744 .40565 .6809 .41514 .69387 .40081 .6874 .3908 Mtetra
.831 .759 .783 r
.6874 .3908 .69387 .40081 .70682 .38642 .70038 .37598 Mtetra
.826 .751 .781 r
.70038 .37598 .70682 .38642 .71975 .37213 .71335 .36133 Mtetra
.819 .744 .78 r
.71335 .36133 .71975 .37213 .73268 .35804 .72631 .34697 Mtetra
.813 .738 .781 r
.72631 .34697 .73268 .35804 .74561 .34427 .73927 .33299 Mtetra
.806 .733 .784 r
.73927 .33299 .74561 .34427 .75855 .33088 .75226 .31949 Mtetra
.8 .73 .787 r
.75226 .31949 .75855 .33088 .77151 .31794 .76527 .3065 Mtetra
.793 .728 .792 r
.76527 .3065 .77151 .31794 .78451 .30549 .77831 .29406 Mtetra
.786 .726 .797 r
.77831 .29406 .78451 .30549 .79755 .29357 .7914 .28219 Mtetra
.779 .725 .803 r
.7914 .28219 .79755 .29357 .81063 .28218 .80454 .2709 Mtetra
.772 .725 .81 r
.80454 .2709 .81063 .28218 .82378 .27132 .81775 .26018 Mtetra
.765 .726 .817 r
.81775 .26018 .82378 .27132 .83698 .261 .83102 .25001 Mtetra
.539 .736 .966 r
.20612 .44806 .21379 .45409 .22462 .45275 .21697 .44676 Mtetra
.526 .734 .969 r
.21697 .44676 .22462 .45275 .23549 .45159 .22785 .44565 Mtetra
.509 .73 .973 r
.22785 .44565 .23549 .45159 .24641 .45063 .23879 .44476 Mtetra
.489 .725 .976 r
.23879 .44476 .24641 .45063 .25737 .44993 .24977 .44413 Mtetra
.463 .718 .979 r
.24977 .44413 .25737 .44993 .26837 .44954 .26079 .44381 Mtetra
.431 .708 .981 r
.26079 .44381 .26837 .44954 .27942 .44949 .27185 .44386 Mtetra
.392 .693 .98 r
.27185 .44386 .27942 .44949 .29052 .44984 .28296 .44432 Mtetra
.344 .674 .977 r
.28296 .44432 .29052 .44984 .30166 .45065 .29412 .44525 Mtetra
.285 .648 .968 r
.29412 .44525 .30166 .45065 .31285 .45198 .30532 .44672 Mtetra
.216 .614 .952 r
.30532 .44672 .31285 .45198 .32409 .45385 .31657 .44876 Mtetra
.137 .572 .926 r
.31657 .44876 .32409 .45385 .33538 .45633 .32787 .45141 Mtetra
.05 .521 .89 r
.32787 .45141 .33538 .45633 .34674 .45941 .33924 .4547 Mtetra
0 .464 .843 r
.33924 .4547 .34674 .45941 .35817 .46311 .35068 .45863 Mtetra
0 .404 .789 r
.35068 .45863 .35817 .46311 .36967 .46739 .36219 .46316 Mtetra
0 .346 .731 r
.36219 .46316 .36967 .46739 .38126 .47222 .37379 .46826 Mtetra
0 .295 .675 r
.37379 .46826 .38126 .47222 .39295 .47751 .3855 .47383 Mtetra
.321 0 0 r
.3855 .47383 .39295 .47751 .40475 .48315 .39731 .47975 Mtetra
.354 0 0 r
.39731 .47975 .40475 .48315 .41667 .489 .40924 .48588 Mtetra
.369 0 0 r
.40924 .48588 .41667 .489 .42871 .49487 .4213 .49202 Mtetra
.365 0 0 r
.4213 .49202 .42871 .49487 .44089 .50058 .4335 .49797 Mtetra
.34 0 0 r
.4335 .49797 .44089 .50058 .4532 .5059 .44585 .50349 Mtetra
.291 0 0 r
.44585 .50349 .4532 .5059 .46566 .5106 .45833 .50835 Mtetra
.213 0 0 r
.45833 .50835 .46566 .5106 .47825 .51445 .47096 .51229 Mtetra
0 .475 .748 r
.47096 .51229 .47825 .51445 .49096 .51722 .48372 .51507 Mtetra
.042 .591 .834 r
.48372 .51507 .49096 .51722 .5038 .51873 .49661 .5165 Mtetra
.211 .708 .914 r
.49661 .5165 .5038 .51873 .51675 .51878 .50961 .51639 Mtetra
.382 .807 .97 r
.50961 .51639 .51675 .51878 .52979 .51726 .5227 .5146 Mtetra
.533 .873 .991 r
.5227 .5146 .52979 .51726 .54289 .51407 .53586 .51105 Mtetra
.649 .903 .982 r
.53586 .51105 .54289 .51407 .55606 .50919 .54908 .50572 Mtetra
.729 .909 .957 r
.54908 .50572 .55606 .50919 .56926 .50263 .56234 .49862 Mtetra
.782 .899 .925 r
.56234 .49862 .56926 .50263 .58247 .49446 .57561 .48985 Mtetra
.815 .883 .894 r
.57561 .48985 .58247 .49446 .59568 .48481 .58888 .47954 Mtetra
.835 .865 .867 r
.58888 .47954 .59568 .48481 .60888 .47382 .60213 .46786 Mtetra
.846 .847 .843 r
.60213 .46786 .60888 .47382 .62205 .46167 .61535 .45501 Mtetra
.852 .829 .825 r
.61535 .45501 .62205 .46167 .6352 .44857 .62853 .4412 Mtetra
.853 .813 .81 r
.62853 .4412 .6352 .44857 .6483 .43473 .64168 .42668 Mtetra
.852 .799 .799 r
.64168 .42668 .6483 .43473 .66137 .42035 .65479 .41167 Mtetra
.849 .786 .791 r
.65479 .41167 .66137 .42035 .6744 .40565 .66785 .39638 Mtetra
.844 .775 .785 r
.66785 .39638 .6744 .40565 .6874 .3908 .68089 .38101 Mtetra
.838 .765 .782 r
.68089 .38101 .6874 .3908 .70038 .37598 .69391 .36574 Mtetra
.832 .757 .78 r
.69391 .36574 .70038 .37598 .71335 .36133 .70691 .35072 Mtetra
.825 .75 .781 r
.70691 .35072 .71335 .36133 .72631 .34697 .71991 .33607 Mtetra
.818 .744 .782 r
.71991 .33607 .72631 .34697 .73927 .33299 .73291 .32188 Mtetra
.81 .739 .785 r
.73291 .32188 .73927 .33299 .75226 .31949 .74594 .30823 Mtetra
.802 .735 .789 r
.74594 .30823 .75226 .31949 .76527 .3065 .75899 .29517 Mtetra
.794 .732 .794 r
.75899 .29517 .76527 .3065 .77831 .29406 .77209 .28272 Mtetra
.786 .729 .8 r
.77209 .28272 .77831 .29406 .7914 .28219 .78523 .27089 Mtetra
.779 .728 .806 r
.78523 .27089 .7914 .28219 .80454 .2709 .79843 .25968 Mtetra
.771 .728 .813 r
.79843 .25968 .80454 .2709 .81775 .26018 .81169 .24907 Mtetra
.763 .728 .82 r
.81169 .24907 .81775 .26018 .83102 .25001 .82502 .23904 Mtetra
.538 .731 .964 r
.1984 .44185 .20612 .44806 .21697 .44676 .20926 .44059 Mtetra
.524 .729 .967 r
.20926 .44059 .21697 .44676 .22785 .44565 .22017 .43953 Mtetra
.508 .725 .97 r
.22017 .43953 .22785 .44565 .23879 .44476 .23112 .43869 Mtetra
.487 .719 .974 r
.23112 .43869 .23879 .44476 .24977 .44413 .24211 .43812 Mtetra
.462 .711 .976 r
.24211 .43812 .24977 .44413 .26079 .44381 .25315 .43786 Mtetra
.43 .701 .978 r
.25315 .43786 .26079 .44381 .27185 .44386 .26423 .43798 Mtetra
.391 .686 .978 r
.26423 .43798 .27185 .44386 .28296 .44432 .27535 .43853 Mtetra
.343 .666 .974 r
.27535 .43853 .28296 .44432 .29412 .44525 .28652 .43958 Mtetra
.285 .64 .966 r
.28652 .43958 .29412 .44525 .30532 .44672 .29773 .44117 Mtetra
.216 .606 .95 r
.29773 .44117 .30532 .44672 .31657 .44876 .30899 .44335 Mtetra
.137 .563 .926 r
.30899 .44335 .31657 .44876 .32787 .45141 .32031 .44617 Mtetra
.052 .513 .891 r
.32031 .44617 .32787 .45141 .33924 .4547 .33169 .44965 Mtetra
0 .456 .846 r
.33169 .44965 .33924 .4547 .35068 .45863 .34313 .45378 Mtetra
0 .397 .794 r
.34313 .45378 .35068 .45863 .36219 .46316 .35465 .45855 Mtetra
0 .34 .738 r
.35465 .45855 .36219 .46316 .37379 .46826 .36626 .4639 Mtetra
0 .29 .685 r
.36626 .4639 .37379 .46826 .3855 .47383 .37798 .46973 Mtetra
0 .251 .64 r
.37798 .46973 .3855 .47383 .39731 .47975 .3898 .47593 Mtetra
.349 0 0 r
.3898 .47593 .39731 .47975 .40924 .48588 .40174 .48233 Mtetra
.362 0 0 r
.40174 .48233 .40924 .48588 .4213 .49202 .41382 .48874 Mtetra
.356 0 0 r
.41382 .48874 .4213 .49202 .4335 .49797 .42604 .49493 Mtetra
.329 0 0 r
.42604 .49493 .4335 .49797 .44585 .50349 .43841 .50067 Mtetra
.275 0 0 r
.43841 .50067 .44585 .50349 .45833 .50835 .45093 .50569 Mtetra
0 .39 .701 r
.45093 .50569 .45833 .50835 .47096 .51229 .46359 .50974 Mtetra
0 .492 .778 r
.46359 .50974 .47096 .51229 .48372 .51507 .4764 .51257 Mtetra
.075 .609 .862 r
.4764 .51257 .48372 .51507 .49661 .5165 .48933 .51396 Mtetra
.246 .724 .935 r
.48933 .51396 .49661 .5165 .50961 .51639 .50238 .51372 Mtetra
.415 .818 .981 r
.50238 .51372 .50961 .51639 .5227 .5146 .51553 .51171 Mtetra
.56 .878 .992 r
.51553 .51171 .5227 .5146 .53586 .51105 .52875 .50785 Mtetra
.67 .905 .978 r
.52875 .50785 .53586 .51105 .54908 .50572 .54203 .50211 Mtetra
.745 .908 .949 r
.54203 .50211 .54908 .50572 .56234 .49862 .55535 .49453 Mtetra
.794 .899 .916 r
.55535 .49453 .56234 .49862 .57561 .48985 .56868 .48521 Mtetra
.825 .883 .885 r
.56868 .48521 .57561 .48985 .58888 .47954 .582 .47429 Mtetra
.844 .866 .859 r
.582 .47429 .58888 .47954 .60213 .46786 .59531 .46196 Mtetra
.855 .849 .836 r
.59531 .46196 .60213 .46786 .61535 .45501 .60858 .44844 Mtetra
.86 .833 .819 r
.60858 .44844 .61535 .45501 .62853 .4412 .62182 .43397 Mtetra
.861 .818 .805 r
.62182 .43397 .62853 .4412 .64168 .42668 .63501 .41879 Mtetra
.86 .804 .795 r
.63501 .41879 .64168 .42668 .65479 .41167 .64816 .40316 Mtetra
.856 .792 .788 r
.64816 .40316 .65479 .41167 .66785 .39638 .66127 .3873 Mtetra
.851 .781 .783 r
.66127 .3873 .66785 .39638 .68089 .38101 .67435 .37142 Mtetra
.845 .772 .78 r
.67435 .37142 .68089 .38101 .69391 .36574 .6874 .3557 Mtetra
.838 .763 .78 r
.6874 .3557 .69391 .36574 .70691 .35072 .70044 .34031 Mtetra
.83 .756 .781 r
.70044 .34031 .70691 .35072 .71991 .33607 .71348 .32536 Mtetra
.822 .75 .783 r
.71348 .32536 .71991 .33607 .73291 .32188 .72652 .31095 Mtetra
.814 .744 .787 r
.72652 .31095 .73291 .32188 .74594 .30823 .73959 .29715 Mtetra
.805 .74 .791 r
.73959 .29715 .74594 .30823 .75899 .29517 .75269 .284 Mtetra
.796 .736 .797 r
.75269 .284 .75899 .29517 .77209 .28272 .76583 .27152 Mtetra
.788 .734 .803 r
.76583 .27152 .77209 .28272 .78523 .27089 .77903 .25971 Mtetra
.779 .732 .809 r
.77903 .25971 .78523 .27089 .79843 .25968 .79228 .24856 Mtetra
.77 .731 .816 r
.79228 .24856 .79843 .25968 .81169 .24907 .8056 .23804 Mtetra
.762 .73 .824 r
.8056 .23804 .81169 .24907 .82502 .23904 .81899 .22813 Mtetra
.537 .727 .962 r
.19063 .43546 .1984 .44185 .20926 .44059 .20151 .43423 Mtetra
.524 .724 .964 r
.20151 .43423 .20926 .44059 .22017 .43953 .21243 .43319 Mtetra
.507 .719 .968 r
.21243 .43319 .22017 .43953 .23112 .43869 .2234 .43239 Mtetra
.487 .713 .97 r
.2234 .43239 .23112 .43869 .24211 .43812 .23441 .43186 Mtetra
.462 .705 .973 r
.23441 .43186 .24211 .43812 .25315 .43786 .24546 .43165 Mtetra
.431 .694 .975 r
.24546 .43165 .25315 .43786 .26423 .43798 .25656 .43183 Mtetra
.392 .679 .974 r
.25656 .43183 .26423 .43798 .27535 .43853 .2677 .43246 Mtetra
.345 .658 .971 r
.2677 .43246 .27535 .43853 .28652 .43958 .27888 .43358 Mtetra
.288 .632 .963 r
.27888 .43358 .28652 .43958 .29773 .44117 .2901 .43527 Mtetra
.221 .598 .949 r
.2901 .43527 .29773 .44117 .30899 .44335 .30137 .43758 Mtetra
.144 .556 .926 r
.30137 .43758 .30899 .44335 .32031 .44617 .3127 .44054 Mtetra
.06 .507 .894 r
.3127 .44054 .32031 .44617 .33169 .44965 .32408 .44418 Mtetra
0 .452 .853 r
.32408 .44418 .33169 .44965 .34313 .45378 .33553 .44849 Mtetra
0 .395 .804 r
.33553 .44849 .34313 .45378 .35465 .45855 .34706 .45346 Mtetra
0 .34 .753 r
.34706 .45346 .35465 .45855 .36626 .4639 .35868 .45903 Mtetra
0 .292 .704 r
.35868 .45903 .36626 .4639 .37798 .46973 .3704 .46511 Mtetra
0 .254 .662 r
.3704 .46511 .37798 .46973 .3898 .47593 .38223 .47155 Mtetra
0 .232 .631 r
.38223 .47155 .3898 .47593 .40174 .48233 .39419 .47821 Mtetra
.344 0 0 r
.39419 .47821 .40174 .48233 .41382 .48874 .40628 .48487 Mtetra
.336 0 0 r
.40628 .48487 .41382 .48874 .42604 .49493 .41852 .4913 Mtetra
0 .271 .639 r
.41852 .4913 .42604 .49493 .43841 .50067 .43091 .49725 Mtetra
0 .328 .681 r
.43091 .49725 .43841 .50067 .45093 .50569 .44345 .50245 Mtetra
0 .41 .742 r
.44345 .50245 .45093 .50569 .46359 .50974 .45615 .50663 Mtetra
0 .513 .818 r
.45615 .50663 .46359 .50974 .4764 .51257 .46899 .50952 Mtetra
.119 .629 .896 r
.46899 .50952 .4764 .51257 .48933 .51396 .48197 .5109 Mtetra
.289 .739 .959 r
.48197 .5109 .48933 .51396 .50238 .51372 .49507 .51057 Mtetra
.452 .824 .992 r
.49507 .51057 .50238 .51372 .51553 .51171 .50827 .50839 Mtetra
.588 .877 .993 r
.50827 .50839 .51553 .51171 .52875 .50785 .52156 .50427 Mtetra
.689 .899 .972 r
.52156 .50427 .52875 .50785 .54203 .50211 .5349 .49819 Mtetra
.758 .901 .94 r
.5349 .49819 .54203 .50211 .55535 .49453 .54828 .49019 Mtetra
.804 .892 .907 r
.54828 .49019 .55535 .49453 .56868 .48521 .56167 .48037 Mtetra
.833 .879 .876 r
.56167 .48037 .56868 .48521 .582 .47429 .57506 .4689 Mtetra
.851 .863 .85 r
.57506 .4689 .582 .47429 .59531 .46196 .58842 .45598 Mtetra
.861 .848 .829 r
.58842 .45598 .59531 .46196 .60858 .44844 .60175 .44185 Mtetra
.866 .833 .812 r
.60175 .44185 .60858 .44844 .62182 .43397 .61504 .42676 Mtetra
.867 .82 .8 r
.61504 .42676 .62182 .43397 .63501 .41879 .62829 .41098 Mtetra
.866 .807 .79 r
.62829 .41098 .63501 .41879 .64816 .40316 .64148 .39476 Mtetra
.862 .796 .784 r
.64148 .39476 .64816 .40316 .66127 .3873 .65464 .37836 Mtetra
.857 .786 .78 r
.65464 .37836 .66127 .3873 .67435 .37142 .66776 .36199 Mtetra
.851 .777 .779 r
.66776 .36199 .67435 .37142 .6874 .3557 .68085 .34584 Mtetra
.844 .769 .779 r
.68085 .34584 .6874 .3557 .70044 .34031 .69393 .33008 Mtetra
.836 .762 .781 r
.69393 .33008 .70044 .34031 .71348 .32536 .70701 .31484 Mtetra
.827 .755 .784 r
.70701 .31484 .71348 .32536 .72652 .31095 .7201 .3002 Mtetra
.818 .75 .788 r
.7201 .3002 .72652 .31095 .73959 .29715 .73321 .28624 Mtetra
.809 .745 .793 r
.73321 .28624 .73959 .29715 .75269 .284 .74636 .27299 Mtetra
.799 .741 .799 r
.74636 .27299 .75269 .284 .76583 .27152 .75955 .26046 Mtetra
.789 .738 .806 r
.75955 .26046 .76583 .27152 .77903 .25971 .7728 .24866 Mtetra
.78 .736 .813 r
.7728 .24866 .77903 .25971 .79228 .24856 .78611 .23755 Mtetra
.77 .734 .82 r
.78611 .23755 .79228 .24856 .8056 .23804 .79948 .22711 Mtetra
.761 .733 .827 r
.79948 .22711 .8056 .23804 .81899 .22813 .81294 .21729 Mtetra
.537 .722 .959 r
.18281 .42886 .19063 .43546 .20151 .43423 .19371 .42764 Mtetra
.524 .718 .961 r
.19371 .42764 .20151 .43423 .21243 .43319 .20465 .42662 Mtetra
.508 .714 .964 r
.20465 .42662 .21243 .43319 .2234 .43239 .21563 .42584 Mtetra
.489 .707 .967 r
.21563 .42584 .2234 .43239 .23441 .43186 .22666 .42533 Mtetra
.464 .699 .969 r
.22666 .42533 .23441 .43186 .24546 .43165 .23773 .42516 Mtetra
.434 .687 .971 r
.23773 .42516 .24546 .43165 .25656 .43183 .24884 .42538 Mtetra
.396 .672 .971 r
.24884 .42538 .25656 .43183 .2677 .43246 .25999 .42605 Mtetra
.351 .652 .968 r
.25999 .42605 .2677 .43246 .27888 .43358 .27119 .42724 Mtetra
.296 .626 .961 r
.27119 .42724 .27888 .43358 .2901 .43527 .28242 .429 Mtetra
.231 .592 .948 r
.28242 .429 .2901 .43527 .30137 .43758 .29371 .43139 Mtetra
.157 .552 .928 r
.29371 .43139 .30137 .43758 .3127 .44054 .30504 .43446 Mtetra
.076 .504 .899 r
.30504 .43446 .3127 .44054 .32408 .44418 .31643 .43822 Mtetra
0 .452 .862 r
.31643 .43822 .32408 .44418 .33553 .44849 .32789 .44268 Mtetra
0 .397 .818 r
.32789 .44268 .33553 .44849 .34706 .45346 .33943 .44782 Mtetra
0 .344 .772 r
.33943 .44782 .34706 .45346 .35868 .45903 .35105 .45357 Mtetra
0 .299 .728 r
.35105 .45357 .35868 .45903 .3704 .46511 .36277 .45984 Mtetra
0 .264 .691 r
.36277 .45984 .3704 .46511 .38223 .47155 .37461 .4665 Mtetra
0 .243 .665 r
.37461 .4665 .38223 .47155 .39419 .47821 .38658 .47338 Mtetra
0 .239 .654 r
.38658 .47338 .39419 .47821 .40628 .48487 .39868 .48027 Mtetra
0 .254 .66 r
.39868 .48027 .40628 .48487 .41852 .4913 .41094 .48691 Mtetra
0 .291 .685 r
.41094 .48691 .41852 .4913 .43091 .49725 .42334 .49306 Mtetra
0 .35 .729 r
.42334 .49306 .43091 .49725 .44345 .50245 .43591 .49843 Mtetra
0 .433 .791 r
.43591 .49843 .44345 .50245 .45615 .50663 .44864 .50274 Mtetra
.018 .536 .863 r
.44864 .50274 .45615 .50663 .46899 .50952 .46152 .50572 Mtetra
.173 .646 .931 r
.46152 .50572 .46899 .50952 .48197 .5109 .47454 .50712 Mtetra
.337 .747 .98 r
.47454 .50712 .48197 .5109 .49507 .51057 .48769 .50674 Mtetra
.49 .822 .999 r
.48769 .50674 .49507 .51057 .50827 .50839 .50094 .50443 Mtetra
.614 .867 .99 r
.50094 .50443 .50827 .50839 .52156 .50427 .51428 .50011 Mtetra
.705 .886 .964 r
.51428 .50011 .52156 .50427 .5349 .49819 .52768 .49375 Mtetra
.768 .888 .93 r
.52768 .49375 .5349 .49819 .54828 .49019 .54112 .48539 Mtetra
.81 .881 .897 r
.54112 .48539 .54828 .49019 .56167 .48037 .55458 .47515 Mtetra
.837 .869 .867 r
.55458 .47515 .56167 .48037 .57506 .4689 .56803 .46321 Mtetra
.854 .856 .842 r
.56803 .46321 .57506 .4689 .58842 .45598 .58146 .44977 Mtetra
.865 .843 .821 r
.58146 .44977 .58842 .45598 .60175 .44185 .59485 .43509 Mtetra
.87 .83 .806 r
.59485 .43509 .60175 .44185 .61504 .42676 .6082 .41945 Mtetra
.871 .819 .794 r
.6082 .41945 .61504 .42676 .62829 .41098 .6215 .40312 Mtetra
.87 .808 .786 r
.6215 .40312 .62829 .41098 .64148 .39476 .63475 .38637 Mtetra
.867 .798 .78 r
.63475 .38637 .64148 .39476 .65464 .37836 .64795 .36947 Mtetra
.862 .789 .777 r
.64795 .36947 .65464 .37836 .66776 .36199 .66112 .35265 Mtetra
.856 .781 .777 r
.66112 .35265 .66776 .36199 .68085 .34584 .67426 .3361 Mtetra
.849 .773 .778 r
.67426 .3361 .68085 .34584 .69393 .33008 .68739 .32 Mtetra
.84 .767 .781 r
.68739 .32 .69393 .33008 .70701 .31484 .70051 .30447 Mtetra
.831 .761 .784 r
.70051 .30447 .70701 .31484 .7201 .3002 .71365 .28962 Mtetra
.822 .755 .789 r
.71365 .28962 .7201 .3002 .73321 .28624 .72681 .27549 Mtetra
.812 .751 .795 r
.72681 .27549 .73321 .28624 .74636 .27299 .74 .26214 Mtetra
.802 .747 .802 r
.74 .26214 .74636 .27299 .75955 .26046 .75324 .24956 Mtetra
.791 .743 .809 r
.75324 .24956 .75955 .26046 .7728 .24866 .76654 .23774 Mtetra
.781 .741 .816 r
.76654 .23774 .7728 .24866 .78611 .23755 .7799 .22666 Mtetra
.77 .738 .824 r
.7799 .22666 .78611 .23755 .79948 .22711 .79334 .21628 Mtetra
.76 .737 .831 r
.79334 .21628 .79948 .22711 .81294 .21729 .80685 .20654 Mtetra
.538 .717 .955 r
.17494 .42205 .18281 .42886 .19371 .42764 .18586 .42084 Mtetra
.526 .713 .958 r
.18586 .42084 .19371 .42764 .20465 .42662 .19681 .41982 Mtetra
.51 .708 .96 r
.19681 .41982 .20465 .42662 .21563 .42584 .20782 .41903 Mtetra
.491 .702 .963 r
.20782 .41903 .21563 .42584 .22666 .42533 .21886 .41853 Mtetra
.468 .693 .965 r
.21886 .41853 .22666 .42533 .23773 .42516 .22995 .41837 Mtetra
.439 .681 .966 r
.22995 .41837 .23773 .42516 .24884 .42538 .24108 .4186 Mtetra
.403 .666 .966 r
.24108 .4186 .24884 .42538 .25999 .42605 .25225 .41929 Mtetra
.359 .646 .964 r
.25225 .41929 .25999 .42605 .27119 .42724 .26345 .4205 Mtetra
.307 .62 .958 r
.26345 .4205 .27119 .42724 .28242 .429 .2747 .42231 Mtetra
.245 .588 .947 r
.2747 .42231 .28242 .429 .29371 .43139 .286 .42475 Mtetra
.175 .549 .929 r
.286 .42475 .29371 .43139 .30504 .43446 .29734 .42788 Mtetra
.099 .504 .904 r
.29734 .42788 .30504 .43446 .31643 .43822 .30874 .43172 Mtetra
.02 .454 .872 r
.30874 .43172 .31643 .43822 .32789 .44268 .32021 .43628 Mtetra
0 .403 .834 r
.32021 .43628 .32789 .44268 .33943 .44782 .33175 .44153 Mtetra
0 .353 .794 r
.33175 .44153 .33943 .44782 .35105 .45357 .34338 .44742 Mtetra
0 .311 .756 r
.34338 .44742 .35105 .45357 .36277 .45984 .35511 .45384 Mtetra
0 .279 .725 r
.35511 .45384 .36277 .45984 .37461 .4665 .36695 .46067 Mtetra
0 .261 .704 r
.36695 .46067 .37461 .4665 .38658 .47338 .37892 .46773 Mtetra
0 .259 .697 r
.37892 .46773 .38658 .47338 .39868 .48027 .39104 .47479 Mtetra
0 .276 .707 r
.39104 .47479 .39868 .48027 .41094 .48691 .4033 .48162 Mtetra
0 .314 .735 r
.4033 .48162 .41094 .48691 .42334 .49306 .41573 .48794 Mtetra
0 .375 .78 r
.41573 .48794 .42334 .49306 .43591 .49843 .42832 .49346 Mtetra
0 .457 .839 r
.42832 .49346 .43591 .49843 .44864 .50274 .44107 .4979 Mtetra
.081 .555 .902 r
.44107 .4979 .44864 .50274 .46152 .50572 .45398 .50096 Mtetra
.232 .656 .958 r
.45398 .50096 .46152 .50572 .47454 .50712 .46704 .5024 Mtetra
.385 .744 .992 r
.46704 .5024 .47454 .50712 .48769 .50674 .48023 .502 Mtetra
.524 .809 .998 r
.48023 .502 .48769 .50674 .50094 .50443 .49353 .49962 Mtetra
.634 .848 .981 r
.49353 .49962 .50094 .50443 .51428 .50011 .50693 .49514 Mtetra
.716 .865 .952 r
.50693 .49514 .51428 .50011 .52768 .49375 .52039 .48857 Mtetra
.773 .868 .918 r
.52039 .48857 .52768 .49375 .54112 .48539 .53389 .47993 Mtetra
.812 .863 .886 r
.53389 .47993 .54112 .48539 .55458 .47515 .54741 .46935 Mtetra
.838 .854 .857 r
.54741 .46935 .55458 .47515 .56803 .46321 .56093 .45702 Mtetra
.855 .844 .833 r
.56093 .45702 .56803 .46321 .58146 .44977 .57442 .44315 Mtetra
.865 .834 .814 r
.57442 .44315 .58146 .44977 .59485 .43509 .58788 .42801 Mtetra
.871 .824 .799 r
.58788 .42801 .59485 .43509 .6082 .41945 .60129 .41189 Mtetra
.873 .814 .788 r
.60129 .41189 .6082 .41945 .6215 .40312 .61465 .39509 Mtetra
.872 .805 .781 r
.61465 .39509 .6215 .40312 .63475 .38637 .62796 .37788 Mtetra
.87 .797 .776 r
.62796 .37788 .63475 .38637 .64795 .36947 .64122 .36054 Mtetra
.865 .79 .774 r
.64122 .36054 .64795 .36947 .66112 .35265 .65444 .34332 Mtetra
.86 .783 .775 r
.65444 .34332 .66112 .35265 .67426 .3361 .66763 .32641 Mtetra
.852 .776 .776 r
.66763 .32641 .67426 .3361 .68739 .32 .6808 .31 Mtetra
.844 .77 .78 r
.6808 .31 .68739 .32 .70051 .30447 .69398 .29422 Mtetra
.835 .765 .785 r
.69398 .29422 .70051 .30447 .71365 .28962 .70716 .27916 Mtetra
.825 .76 .79 r
.70716 .27916 .71365 .28962 .72681 .27549 .72037 .26488 Mtetra
.815 .755 .797 r
.72037 .26488 .72681 .27549 .74 .26214 .73361 .25142 Mtetra
.804 .751 .804 r
.73361 .25142 .74 .26214 .75324 .24956 .7469 .23878 Mtetra
.793 .748 .812 r
.7469 .23878 .75324 .24956 .76654 .23774 .76025 .22695 Mtetra
.782 .745 .819 r
.76025 .22695 .76654 .23774 .7799 .22666 .77367 .21588 Mtetra
.771 .743 .827 r
.77367 .21588 .7799 .22666 .79334 .21628 .78716 .20555 Mtetra
.76 .741 .835 r
.78716 .20555 .79334 .21628 .80685 .20654 .80073 .19588 Mtetra
.54 .713 .952 r
.16702 .41503 .17494 .42205 .18586 .42084 .17796 .41379 Mtetra
.528 .708 .954 r
.17796 .41379 .18586 .42084 .19681 .41982 .18894 .41275 Mtetra
.514 .703 .956 r
.18894 .41275 .19681 .41982 .20782 .41903 .19996 .41195 Mtetra
.495 .696 .958 r
.19996 .41195 .20782 .41903 .21886 .41853 .21103 .41143 Mtetra
.473 .687 .96 r
.21103 .41143 .21886 .41853 .22995 .41837 .22213 .41125 Mtetra
.445 .675 .962 r
.22213 .41125 .22995 .41837 .24108 .4186 .23328 .41147 Mtetra
.411 .66 .962 r
.23328 .41147 .24108 .4186 .25225 .41929 .24446 .41215 Mtetra
.37 .64 .96 r
.24446 .41215 .25225 .41929 .26345 .4205 .25569 .41336 Mtetra
.321 .616 .955 r
.25569 .41336 .26345 .4205 .2747 .42231 .26695 .41516 Mtetra
.263 .585 .945 r
.26695 .41516 .2747 .42231 .286 .42475 .27826 .41762 Mtetra
.198 .548 .93 r
.27826 .41762 .286 .42475 .29734 .42788 .28961 .42077 Mtetra
.127 .506 .909 r
.28961 .42077 .29734 .42788 .30874 .43172 .30102 .42464 Mtetra
.053 .459 .882 r
.30102 .42464 .30874 .43172 .32021 .43628 .3125 .42924 Mtetra
0 .411 .85 r
.3125 .42924 .32021 .43628 .33175 .44153 .32404 .43455 Mtetra
0 .366 .816 r
.32404 .43455 .33175 .44153 .34338 .44742 .33568 .44051 Mtetra
0 .327 .784 r
.33568 .44051 .34338 .44742 .35511 .45384 .34741 .44703 Mtetra
0 .298 .759 r
.34741 .44703 .35511 .45384 .36695 .46067 .35926 .45396 Mtetra
0 .282 .744 r
.35926 .45396 .36695 .46067 .37892 .46773 .37124 .46113 Mtetra
0 .282 .741 r
.37124 .46113 .37892 .46773 .39104 .47479 .38336 .46832 Mtetra
0 .301 .754 r
.38336 .46832 .39104 .47479 .4033 .48162 .39563 .47528 Mtetra
0 .34 .782 r
.39563 .47528 .4033 .48162 .41573 .48794 .40807 .48173 Mtetra
0 .399 .825 r
.40807 .48173 .41573 .48794 .42832 .49346 .42067 .48738 Mtetra
.023 .476 .877 r
.42067 .48738 .42832 .49346 .44107 .4979 .43345 .49192 Mtetra
.149 .565 .929 r
.43345 .49192 .44107 .4979 .45398 .50096 .44638 .49506 Mtetra
.289 .654 .97 r
.44638 .49506 .45398 .50096 .46704 .5024 .45948 .49655 Mtetra
.428 .73 .989 r
.45948 .49655 .46704 .5024 .48023 .502 .47271 .49616 Mtetra
.55 .786 .986 r
.47271 .49616 .48023 .502 .49353 .49962 .48606 .49373 Mtetra
.648 .82 .966 r
.48606 .49373 .49353 .49962 .50693 .49514 .4995 .48917 Mtetra
.721 .837 .936 r
.4995 .48917 .50693 .49514 .52039 .48857 .51302 .48244 Mtetra
.774 .842 .903 r
.51302 .48244 .52039 .48857 .53389 .47993 .52658 .4736 Mtetra
.81 .841 .873 r
.52658 .4736 .53389 .47993 .54741 .46935 .54017 .46277 Mtetra
.835 .835 .846 r
.54017 .46277 .54741 .46935 .56093 .45702 .55375 .45013 Mtetra
.852 .829 .824 r
.55375 .45013 .56093 .45702 .57442 .44315 .56731 .43593 Mtetra
.863 .821 .806 r
.56731 .43593 .57442 .44315 .58788 .42801 .58083 .42043 Mtetra
.869 .814 .793 r
.58083 .42043 .58788 .42801 .60129 .41189 .59431 .40393 Mtetra
.872 .807 .783 r
.59431 .40393 .60129 .41189 .61465 .39509 .60773 .38674 Mtetra
.872 .8 .776 r
.60773 .38674 .61465 .39509 .62796 .37788 .6211 .36915 Mtetra
.871 .794 .772 r
.6211 .36915 .62796 .37788 .64122 .36054 .63441 .35145 Mtetra
.867 .788 .771 r
.63441 .35145 .64122 .36054 .65444 .34332 .64769 .33389 Mtetra
.861 .782 .772 r
.64769 .33389 .65444 .34332 .66763 .32641 .66094 .31669 Mtetra
.855 .777 .775 r
.66094 .31669 .66763 .32641 .6808 .31 .67417 .30001 Mtetra
.847 .772 .779 r
.67417 .30001 .6808 .31 .69398 .29422 .68739 .28401 Mtetra
.838 .768 .785 r
.68739 .28401 .69398 .29422 .70716 .27916 .70063 .26877 Mtetra
.828 .763 .791 r
.70063 .26877 .70716 .27916 .72037 .26488 .71389 .25436 Mtetra
.817 .759 .798 r
.71389 .25436 .72037 .26488 .73361 .25142 .72718 .24081 Mtetra
.806 .755 .806 r
.72718 .24081 .73361 .25142 .7469 .23878 .74053 .22811 Mtetra
.794 .752 .814 r
.74053 .22811 .7469 .23878 .76025 .22695 .75393 .21626 Mtetra
.783 .749 .822 r
.75393 .21626 .76025 .22695 .77367 .21588 .7674 .20521 Mtetra
.771 .746 .83 r
.7674 .20521 .77367 .21588 .78716 .20555 .78095 .19491 Mtetra
.76 .744 .838 r
.78095 .19491 .78716 .20555 .80073 .19588 .79457 .18529 Mtetra
.543 .708 .948 r
.15906 .40777 .16702 .41503 .17796 .41379 .17002 .4065 Mtetra
.531 .704 .95 r
.17002 .4065 .17796 .41379 .18894 .41275 .18102 .40543 Mtetra
.518 .698 .951 r
.18102 .40543 .18894 .41275 .19996 .41195 .19206 .40459 Mtetra
.5 .691 .953 r
.19206 .40459 .19996 .41195 .21103 .41143 .20315 .40403 Mtetra
.479 .682 .955 r
.20315 .40403 .21103 .41143 .22213 .41125 .21427 .40381 Mtetra
.453 .67 .956 r
.21427 .40381 .22213 .41125 .23328 .41147 .22544 .40399 Mtetra
.422 .655 .956 r
.22544 .40399 .23328 .41147 .24446 .41215 .23664 .40463 Mtetra
.383 .636 .955 r
.23664 .40463 .24446 .41215 .25569 .41336 .24788 .40579 Mtetra
.338 .612 .951 r
.24788 .40579 .25569 .41336 .26695 .41516 .25916 .40756 Mtetra
.284 .583 .943 r
.25916 .40756 .26695 .41516 .27826 .41762 .27049 .40997 Mtetra
.224 .549 .93 r
.27049 .40997 .27826 .41762 .28961 .42077 .28185 .41309 Mtetra
.159 .509 .912 r
.28185 .41309 .28961 .42077 .30102 .42464 .29328 .41693 Mtetra
.091 .466 .89 r
.29328 .41693 .30102 .42464 .3125 .42924 .30476 .42152 Mtetra
.025 .422 .863 r
.30476 .42152 .3125 .42924 .32404 .43455 .31631 .42682 Mtetra
0 .38 .836 r
.31631 .42682 .32404 .43455 .33568 .44051 .32795 .43279 Mtetra
0 .345 .81 r
.32795 .43279 .33568 .44051 .34741 .44703 .33969 .43932 Mtetra
0 .319 .79 r
.33969 .43932 .34741 .44703 .35926 .45396 .35154 .44629 Mtetra
0 .305 .779 r
.35154 .44629 .35926 .45396 .37124 .46113 .36353 .4535 Mtetra
0 .307 .78 r
.36353 .4535 .37124 .46113 .38336 .46832 .37565 .46076 Mtetra
0 .326 .793 r
.37565 .46076 .38336 .46832 .39563 .47528 .38793 .46779 Mtetra
0 .364 .82 r
.38793 .46779 .39563 .47528 .40807 .48173 .40038 .47432 Mtetra
0 .419 .857 r
.40038 .47432 .40807 .48173 .42067 .48738 .41299 .48004 Mtetra
.097 .488 .899 r
.41299 .48004 .42067 .48738 .43345 .49192 .42579 .48466 Mtetra
.214 .566 .938 r
.42579 .48466 .43345 .49192 .44638 .49506 .43875 .48786 Mtetra
.34 .642 .965 r
.43875 .48786 .44638 .49506 .45948 .49655 .45186 .4894 Mtetra
.462 .706 .974 r
.45186 .4894 .45948 .49655 .47271 .49616 .46513 .48903 Mtetra
.569 .754 .965 r
.46513 .48903 .47271 .49616 .48606 .49373 .47852 .48659 Mtetra
.655 .786 .944 r
.47852 .48659 .48606 .49373 .4995 .48917 .49201 .48198 Mtetra
.721 .804 .916 r
.49201 .48198 .4995 .48917 .51302 .48244 .50558 .47517 Mtetra
.769 .812 .887 r
.50558 .47517 .51302 .48244 .52658 .4736 .5192 .46621 Mtetra
.804 .814 .859 r
.5192 .46621 .52658 .4736 .54017 .46277 .53285 .45521 Mtetra
.829 .813 .835 r
.53285 .45521 .54017 .46277 .55375 .45013 .54649 .44237 Mtetra
.846 .81 .815 r
.54649 .44237 .55375 .45013 .56731 .43593 .56012 .42793 Mtetra
.858 .806 .798 r
.56012 .42793 .56731 .43593 .58083 .42043 .57371 .41217 Mtetra
.865 .801 .786 r
.57371 .41217 .58083 .42043 .59431 .40393 .58725 .3954 Mtetra
.869 .797 .777 r
.58725 .3954 .59431 .40393 .60773 .38674 .60073 .37792 Mtetra
.87 .793 .771 r
.60073 .37792 .60773 .38674 .6211 .36915 .61417 .36005 Mtetra
.869 .788 .768 r
.61417 .36005 .6211 .36915 .63441 .35145 .62755 .34208 Mtetra
.866 .784 .768 r
.62755 .34208 .63441 .35145 .64769 .33389 .64089 .32426 Mtetra
.862 .78 .77 r
.64089 .32426 .64769 .33389 .66094 .31669 .65419 .30682 Mtetra
.855 .776 .773 r
.65419 .30682 .66094 .31669 .67417 .30001 .66748 .28994 Mtetra
.848 .773 .778 r
.66748 .28994 .67417 .30001 .68739 .28401 .68076 .27376 Mtetra
.839 .769 .784 r
.68076 .27376 .68739 .28401 .70063 .26877 .69405 .25839 Mtetra
.829 .765 .791 r
.69405 .25839 .70063 .26877 .71389 .25436 .70736 .24387 Mtetra
.819 .762 .799 r
.70736 .24387 .71389 .25436 .72718 .24081 .72071 .23025 Mtetra
.807 .759 .808 r
.72071 .23025 .72718 .24081 .74053 .22811 .73411 .21752 Mtetra
.795 .755 .816 r
.73411 .21752 .74053 .22811 .75393 .21626 .74757 .20565 Mtetra
.783 .752 .825 r
.74757 .20565 .75393 .21626 .7674 .20521 .7611 .19461 Mtetra
.771 .75 .833 r
.7611 .19461 .7674 .20521 .78095 .19491 .7747 .18434 Mtetra
.759 .747 .842 r
.7747 .18434 .78095 .19491 .79457 .18529 .78838 .17477 Mtetra
.546 .704 .944 r
.15106 .40029 .15906 .40777 .17002 .4065 .16203 .39897 Mtetra
.535 .7 .945 r
.16203 .39897 .17002 .4065 .18102 .40543 .17306 .39784 Mtetra
.522 .694 .947 r
.17306 .39784 .18102 .40543 .19206 .40459 .18412 .39695 Mtetra
.507 .686 .948 r
.18412 .39695 .19206 .40459 .20315 .40403 .19523 .39633 Mtetra
.487 .677 .949 r
.19523 .39633 .20315 .40403 .21427 .40381 .20638 .39604 Mtetra
.463 .666 .95 r
.20638 .39604 .21427 .40381 .22544 .40399 .21756 .39614 Mtetra
.433 .651 .95 r
.21756 .39614 .22544 .40399 .23664 .40463 .22879 .3967 Mtetra
.398 .632 .949 r
.22879 .3967 .23664 .40463 .24788 .40579 .24005 .39779 Mtetra
.356 .61 .945 r
.24005 .39779 .24788 .40579 .25916 .40756 .25135 .39947 Mtetra
.307 .582 .939 r
.25135 .39947 .25916 .40756 .27049 .40997 .26269 .4018 Mtetra
.253 .55 .929 r
.26269 .4018 .27049 .40997 .28185 .41309 .27407 .40483 Mtetra
.194 .513 .914 r
.27407 .40483 .28185 .41309 .29328 .41693 .28551 .40859 Mtetra
.133 .474 .895 r
.28551 .40859 .29328 .41693 .30476 .42152 .297 .41309 Mtetra
.073 .434 .874 r
.297 .41309 .30476 .42152 .31631 .42682 .30856 .41832 Mtetra
.019 .396 .851 r
.30856 .41832 .31631 .42682 .32795 .43279 .32021 .42422 Mtetra
0 .364 .831 r
.32021 .42422 .32795 .43279 .33969 .43932 .33196 .43069 Mtetra
0 .34 .815 r
.33196 .43069 .33969 .43932 .35154 .44629 .34381 .43761 Mtetra
0 .329 .807 r
.34381 .43761 .35154 .44629 .36353 .4535 .3558 .44479 Mtetra
0 .331 .809 r
.3558 .44479 .36353 .4535 .37565 .46076 .36793 .45203 Mtetra
0 .349 .822 r
.36793 .45203 .37565 .46076 .38793 .46779 .38021 .45906 Mtetra
.004 .383 .844 r
.38021 .45906 .38793 .46779 .40038 .47432 .39267 .4656 Mtetra
.075 .432 .873 r
.39267 .4656 .40038 .47432 .41299 .48004 .40529 .47135 Mtetra
.166 .493 .904 r
.40529 .47135 .41299 .48004 .42579 .48466 .4181 .47599 Mtetra
.271 .558 .931 r
.4181 .47599 .42579 .48466 .43875 .48786 .43107 .47924 Mtetra
.382 .622 .947 r
.43107 .47924 .43875 .48786 .45186 .4894 .44422 .4808 Mtetra
.487 .676 .949 r
.44422 .4808 .45186 .4894 .46513 .48903 .45751 .48047 Mtetra
.58 .719 .938 r
.45751 .48047 .46513 .48903 .47852 .48659 .47093 .47804 Mtetra
.656 .749 .918 r
.47093 .47804 .47852 .48659 .49201 .48198 .48447 .47343 Mtetra
.716 .768 .894 r
.48447 .47343 .49201 .48198 .50558 .47517 .49808 .46659 Mtetra
.761 .78 .868 r
.49808 .46659 .50558 .47517 .5192 .46621 .51176 .45758 Mtetra
.795 .786 .844 r
.51176 .45758 .5192 .46621 .53285 .45521 .52546 .44651 Mtetra
.819 .788 .823 r
.52546 .44651 .53285 .45521 .54649 .44237 .53916 .43357 Mtetra
.837 .789 .805 r
.53916 .43357 .54649 .44237 .56012 .42793 .55285 .419 Mtetra
.85 .788 .791 r
.55285 .419 .56012 .42793 .57371 .41217 .56651 .40309 Mtetra
.858 .786 .78 r
.56651 .40309 .57371 .41217 .58725 .3954 .58011 .38615 Mtetra
.863 .784 .772 r
.58011 .38615 .58725 .3954 .60073 .37792 .59367 .3685 Mtetra
.866 .782 .767 r
.59367 .3685 .60073 .37792 .61417 .36005 .60717 .35045 Mtetra
.866 .78 .765 r
.60717 .35045 .61417 .36005 .62755 .34208 .62061 .3323 Mtetra
.864 .778 .765 r
.62061 .3323 .62755 .34208 .64089 .32426 .63402 .31432 Mtetra
.86 .776 .767 r
.63402 .31432 .64089 .32426 .65419 .30682 .64738 .29672 Mtetra
.855 .773 .771 r
.64738 .29672 .65419 .30682 .66748 .28994 .66073 .27971 Mtetra
.848 .771 .777 r
.66073 .27971 .66748 .28994 .68076 .27376 .67407 .26341 Mtetra
.839 .768 .784 r
.67407 .26341 .68076 .27376 .69405 .25839 .68742 .24795 Mtetra
.83 .766 .792 r
.68742 .24795 .69405 .25839 .70736 .24387 .70079 .23336 Mtetra
.819 .763 .8 r
.70079 .23336 .70736 .24387 .72071 .23025 .71419 .2197 Mtetra
.808 .76 .809 r
.71419 .2197 .72071 .23025 .73411 .21752 .72765 .20695 Mtetra
.796 .758 .818 r
.72765 .20695 .73411 .21752 .74757 .20565 .74117 .19508 Mtetra
.783 .755 .827 r
.74117 .19508 .74757 .20565 .7611 .19461 .75475 .18406 Mtetra
.771 .752 .836 r
.75475 .18406 .7611 .19461 .7747 .18434 .76841 .17382 Mtetra
.759 .75 .844 r
.76841 .17382 .7747 .18434 .78838 .17477 .78215 .1643 Mtetra
.55 .701 .939 r
.143 .39258 .15106 .40029 .16203 .39897 .154 .39119 Mtetra
.54 .696 .94 r
.154 .39119 .16203 .39897 .17306 .39784 .16505 .38999 Mtetra
.528 .69 .942 r
.16505 .38999 .17306 .39784 .18412 .39695 .17614 .38902 Mtetra
.513 .682 .943 r
.17614 .38902 .18412 .39695 .19523 .39633 .18727 .38831 Mtetra
.495 .673 .944 r
.18727 .38831 .19523 .39633 .20638 .39604 .19844 .38793 Mtetra
.473 .662 .944 r
.19844 .38793 .20638 .39604 .21756 .39614 .20965 .38793 Mtetra
.446 .647 .944 r
.20965 .38793 .21756 .39614 .22879 .3967 .2209 .38838 Mtetra
.414 .63 .943 r
.2209 .38838 .22879 .3967 .24005 .39779 .23218 .38935 Mtetra
.376 .608 .94 r
.23218 .38935 .24005 .39779 .25135 .39947 .2435 .3909 Mtetra
.332 .582 .934 r
.2435 .3909 .25135 .39947 .26269 .4018 .25486 .39309 Mtetra
.283 .552 .925 r
.25486 .39309 .26269 .4018 .27407 .40483 .26627 .39598 Mtetra
.23 .518 .913 r
.26627 .39598 .27407 .40483 .28551 .40859 .27772 .3996 Mtetra
.175 .482 .898 r
.27772 .3996 .28551 .40859 .297 .41309 .28923 .40395 Mtetra
.123 .446 .88 r
.28923 .40395 .297 .41309 .30856 .41832 .3008 .40903 Mtetra
.075 .411 .862 r
.3008 .40903 .30856 .41832 .32021 .42422 .31246 .41478 Mtetra
.036 .382 .845 r
.31246 .41478 .32021 .42422 .33196 .43069 .32421 .42111 Mtetra
.01 .361 .833 r
.32421 .42111 .33196 .43069 .34381 .43761 .33608 .4279 Mtetra
0 .351 .827 r
.33608 .4279 .34381 .43761 .3558 .44479 .34807 .43497 Mtetra
.006 .353 .828 r
.34807 .43497 .3558 .44479 .36793 .45203 .3602 .4421 Mtetra
.032 .369 .838 r
.3602 .4421 .36793 .45203 .38021 .45906 .37249 .44905 Mtetra
.079 .398 .854 r
.37249 .44905 .38021 .45906 .39267 .4656 .38494 .45552 Mtetra
.144 .44 .875 r
.38494 .45552 .39267 .4656 .40529 .47135 .39758 .46123 Mtetra
.226 .491 .896 r
.39758 .46123 .40529 .47135 .4181 .47599 .41039 .46585 Mtetra
.319 .545 .913 r
.41039 .46585 .4181 .47599 .43107 .47924 .42338 .46909 Mtetra
.414 .598 .921 r
.42338 .46909 .43107 .47924 .44422 .4808 .43654 .47067 Mtetra
.504 .645 .919 r
.43654 .47067 .44422 .4808 .45751 .48047 .44985 .47036 Mtetra
.585 .683 .909 r
.44985 .47036 .45751 .48047 .47093 .47804 .46331 .46796 Mtetra
.652 .712 .891 r
.46331 .46796 .47093 .47804 .48447 .47343 .47688 .46338 Mtetra
.707 .732 .871 r
.47688 .46338 .48447 .47343 .49808 .46659 .49053 .45657 Mtetra
.75 .747 .849 r
.49053 .45657 .49808 .46659 .51176 .45758 .50425 .44758 Mtetra
.782 .756 .829 r
.50425 .44758 .51176 .45758 .52546 .44651 .51801 .43652 Mtetra
.807 .762 .811 r
.51801 .43652 .52546 .44651 .53916 .43357 .53177 .42357 Mtetra
.826 .766 .795 r
.53177 .42357 .53916 .43357 .55285 .419 .54552 .40898 Mtetra
.84 .768 .783 r
.54552 .40898 .55285 .419 .56651 .40309 .55923 .39303 Mtetra
.849 .769 .773 r
.55923 .39303 .56651 .40309 .58011 .38615 .57291 .37605 Mtetra
.856 .77 .767 r
.57291 .37605 .58011 .38615 .59367 .3685 .58653 .35834 Mtetra
.859 .77 .763 r
.58653 .35834 .59367 .3685 .60717 .35045 .6001 .34022 Mtetra
.86 .77 .761 r
.6001 .34022 .60717 .35045 .62061 .3323 .61361 .32201 Mtetra
.859 .77 .762 r
.61361 .32201 .62061 .3323 .63402 .31432 .62708 .30395 Mtetra
.857 .769 .765 r
.62708 .30395 .63402 .31432 .64738 .29672 .64051 .28629 Mtetra
.852 .769 .769 r
.64051 .28629 .64738 .29672 .66073 .27971 .65392 .26922 Mtetra
.846 .768 .775 r
.65392 .26922 .66073 .27971 .67407 .26341 .66732 .25288 Mtetra
.838 .766 .783 r
.66732 .25288 .67407 .26341 .68742 .24795 .68073 .23738 Mtetra
.829 .765 .791 r
.68073 .23738 .68742 .24795 .70079 .23336 .69416 .22277 Mtetra
.819 .763 .801 r
.69416 .22277 .70079 .23336 .71419 .2197 .70763 .2091 Mtetra
.807 .761 .81 r
.70763 .2091 .71419 .2197 .72765 .20695 .72114 .19636 Mtetra
.795 .759 .82 r
.72114 .19636 .72765 .20695 .74117 .19508 .73472 .18451 Mtetra
.783 .757 .829 r
.73472 .18451 .74117 .19508 .75475 .18406 .74836 .17352 Mtetra
.77 .754 .838 r
.74836 .17352 .75475 .18406 .76841 .17382 .76208 .16332 Mtetra
.758 .752 .847 r
.76208 .16332 .76841 .17382 .78215 .1643 .77588 .15384 Mtetra
.554 .697 .935 r
.13491 .38464 .143 .39258 .154 .39119 .14593 .38317 Mtetra
.545 .692 .936 r
.14593 .38317 .154 .39119 .16505 .38999 .15701 .38188 Mtetra
.534 .686 .936 r
.15701 .38188 .16505 .38999 .17614 .38902 .16812 .38081 Mtetra
.521 .679 .937 r
.16812 .38081 .17614 .38902 .18727 .38831 .17928 .37999 Mtetra
.504 .67 .938 r
.17928 .37999 .18727 .38831 .19844 .38793 .19048 .37949 Mtetra
.484 .659 .938 r
.19048 .37949 .19844 .38793 .20965 .38793 .20171 .37936 Mtetra
.459 .645 .938 r
.20171 .37936 .20965 .38793 .2209 .38838 .21298 .37967 Mtetra
.43 .628 .936 r
.21298 .37967 .2209 .38838 .23218 .38935 .22429 .38048 Mtetra
.396 .607 .934 r
.22429 .38048 .23218 .38935 .2435 .3909 .23564 .38186 Mtetra
.356 .583 .929 r
.23564 .38186 .2435 .3909 .25486 .39309 .24702 .38388 Mtetra
.313 .555 .921 r
.24702 .38388 .25486 .39309 .26627 .39598 .25844 .38657 Mtetra
.266 .524 .911 r
.25844 .38657 .26627 .39598 .27772 .3996 .26991 .38997 Mtetra
.218 .491 .898 r
.26991 .38997 .27772 .3996 .28923 .40395 .28144 .39411 Mtetra
.171 .457 .883 r
.28144 .39411 .28923 .40395 .3008 .40903 .29303 .39897 Mtetra
.13 .426 .868 r
.29303 .39897 .3008 .40903 .31246 .41478 .3047 .40449 Mtetra
.097 .399 .854 r
.3047 .40449 .31246 .41478 .32421 .42111 .31647 .4106 Mtetra
.075 .38 .843 r
.31647 .4106 .32421 .42111 .33608 .4279 .32834 .41717 Mtetra
.068 .37 .837 r
.32834 .41717 .33608 .4279 .34807 .43497 .34033 .42403 Mtetra
.076 .372 .837 r
.34033 .42403 .34807 .43497 .3602 .4421 .35247 .43097 Mtetra
.102 .385 .843 r
.35247 .43097 .3602 .4421 .37249 .44905 .36476 .43775 Mtetra
.146 .409 .854 r
.36476 .43775 .37249 .44905 .38494 .45552 .37722 .44408 Mtetra
.205 .444 .868 r
.37722 .44408 .38494 .45552 .39758 .46123 .38986 .44967 Mtetra
.277 .485 .881 r
.38986 .44967 .39758 .46123 .41039 .46585 .40268 .4542 Mtetra
.357 .531 .89 r
.40268 .4542 .41039 .46585 .42338 .46909 .41568 .45739 Mtetra
.438 .575 .893 r
.41568 .45739 .42338 .46909 .43654 .47067 .42885 .45895 Mtetra
.516 .615 .889 r
.42885 .45895 .43654 .47067 .44985 .47036 .44218 .45864 Mtetra
.586 .649 .88 r
.44218 .45864 .44985 .47036 .46331 .46796 .45565 .45628 Mtetra
.646 .677 .865 r
.45565 .45628 .46331 .46796 .47688 .46338 .46925 .45176 Mtetra
.696 .699 .848 r
.46925 .45176 .47688 .46338 .49053 .45657 .48294 .44502 Mtetra
.737 .715 .831 r
.48294 .44502 .49053 .45657 .50425 .44758 .4967 .43611 Mtetra
.769 .727 .814 r
.4967 .43611 .50425 .44758 .51801 .43652 .5105 .42513 Mtetra
.794 .736 .799 r
.5105 .42513 .51801 .43652 .53177 .42357 .52431 .41227 Mtetra
.813 .742 .786 r
.52431 .41227 .53177 .42357 .54552 .40898 .53812 .39777 Mtetra
.828 .747 .775 r
.53812 .39777 .54552 .40898 .55923 .39303 .55189 .3819 Mtetra
.839 .751 .767 r
.55189 .3819 .55923 .39303 .57291 .37605 .56563 .36498 Mtetra
.846 .754 .762 r
.56563 .36498 .57291 .37605 .58653 .35834 .57932 .34733 Mtetra
.851 .757 .758 r
.57932 .34733 .58653 .35834 .6001 .34022 .59295 .32927 Mtetra
.853 .759 .758 r
.59295 .32927 .6001 .34022 .61361 .32201 .60653 .31109 Mtetra
.853 .76 .759 r
.60653 .31109 .61361 .32201 .62708 .30395 .62007 .29307 Mtetra
.852 .761 .762 r
.62007 .29307 .62708 .30395 .64051 .28629 .63357 .27544 Mtetra
.848 .762 .768 r
.63357 .27544 .64051 .28629 .65392 .26922 .64705 .2584 Mtetra
.842 .763 .774 r
.64705 .2584 .65392 .26922 .66732 .25288 .66051 .24208 Mtetra
.835 .763 .782 r
.66051 .24208 .66732 .25288 .68073 .23738 .67399 .22661 Mtetra
.827 .762 .791 r
.67399 .22661 .68073 .23738 .69416 .22277 .68748 .21204 Mtetra
.817 .762 .801 r
.68748 .21204 .69416 .22277 .70763 .2091 .70101 .19841 Mtetra
.806 .761 .811 r
.70101 .19841 .70763 .2091 .72114 .19636 .71458 .18571 Mtetra
.794 .759 .821 r
.71458 .18571 .72114 .19636 .73472 .18451 .72822 .17391 Mtetra
.782 .757 .831 r
.72822 .17391 .73472 .18451 .74836 .17352 .74192 .16296 Mtetra
.769 .755 .84 r
.74192 .16296 .74836 .17352 .76208 .16332 .7557 .15281 Mtetra
.757 .753 .849 r
.7557 .15281 .76208 .16332 .77588 .15384 .76956 .14338 Mtetra
.559 .695 .931 r
.12677 .37649 .13491 .38464 .14593 .38317 .13782 .37492 Mtetra
.551 .69 .931 r
.13782 .37492 .14593 .38317 .15701 .38188 .14892 .37352 Mtetra
.541 .684 .931 r
.14892 .37352 .15701 .38188 .16812 .38081 .16006 .37233 Mtetra
.528 .676 .932 r
.16006 .37233 .16812 .38081 .17928 .37999 .17125 .37139 Mtetra
.513 .667 .932 r
.17125 .37139 .17928 .37999 .19048 .37949 .18247 .37074 Mtetra
.495 .656 .932 r
.18247 .37074 .19048 .37949 .20171 .37936 .19374 .37046 Mtetra
.473 .643 .931 r
.19374 .37046 .20171 .37936 .21298 .37967 .20504 .37059 Mtetra
.446 .627 .93 r
.20504 .37059 .21298 .37967 .22429 .38048 .21637 .37121 Mtetra
.416 .607 .927 r
.21637 .37121 .22429 .38048 .23564 .38186 .22774 .37238 Mtetra
.381 .584 .922 r
.22774 .37238 .23564 .38186 .24702 .38388 .23915 .37416 Mtetra
.342 .558 .916 r
.23915 .37416 .24702 .38388 .25844 .38657 .2506 .3766 Mtetra
.3 .53 .907 r
.2506 .3766 .25844 .38657 .26991 .38997 .2621 .37975 Mtetra
.258 .499 .896 r
.2621 .37975 .26991 .38997 .28144 .39411 .27364 .3836 Mtetra
.218 .469 .883 r
.27364 .3836 .28144 .39411 .29303 .39897 .28525 .38816 Mtetra
.182 .44 .87 r
.28525 .38816 .29303 .39897 .3047 .40449 .29694 .39338 Mtetra
.154 .416 .858 r
.29694 .39338 .3047 .40449 .31647 .4106 .30872 .39919 Mtetra
.136 .398 .848 r
.30872 .39919 .31647 .4106 .32834 .41717 .3206 .40545 Mtetra
.131 .388 .841 r
.3206 .40545 .32834 .41717 .34033 .42403 .33261 .41201 Mtetra
.141 .388 .839 r
.33261 .41201 .34033 .42403 .35247 .43097 .34475 .41867 Mtetra
.165 .398 .842 r
.34475 .41867 .35247 .43097 .36476 .43775 .35705 .42519 Mtetra
.204 .417 .848 r
.35705 .42519 .36476 .43775 .37722 .44408 .36951 .43129 Mtetra
.257 .445 .855 r
.36951 .43129 .37722 .44408 .38986 .44967 .38215 .43668 Mtetra
.319 .479 .862 r
.38215 .43668 .38986 .44967 .40268 .4542 .39497 .44106 Mtetra
.387 .517 .866 r
.39497 .44106 .40268 .4542 .41568 .45739 .40797 .44414 Mtetra
.457 .554 .866 r
.40797 .44414 .41568 .45739 .42885 .45895 .42115 .44564 Mtetra
.524 .589 .862 r
.42115 .44564 .42885 .45895 .44218 .45864 .43449 .44531 Mtetra
.585 .62 .853 r
.43449 .44531 .44218 .45864 .45565 .45628 .44798 .44298 Mtetra
.639 .646 .841 r
.44798 .44298 .45565 .45628 .46925 .45176 .4616 .43853 Mtetra
.685 .668 .827 r
.4616 .43853 .46925 .45176 .48294 .44502 .47531 .4319 Mtetra
.723 .685 .813 r
.47531 .4319 .48294 .44502 .4967 .43611 .4891 .42312 Mtetra
.754 .699 .799 r
.4891 .42312 .4967 .43611 .5105 .42513 .50294 .41231 Mtetra
.779 .71 .787 r
.50294 .41231 .5105 .42513 .52431 .41227 .5168 .39962 Mtetra
.799 .719 .776 r
.5168 .39962 .52431 .41227 .53812 .39777 .53066 .3853 Mtetra
.815 .727 .768 r
.53066 .3853 .53812 .39777 .55189 .3819 .54449 .36962 Mtetra
.826 .733 .761 r
.54449 .36962 .55189 .3819 .56563 .36498 .55829 .35288 Mtetra
.835 .738 .757 r
.55829 .35288 .56563 .36498 .57932 .34733 .57204 .3354 Mtetra
.841 .742 .755 r
.57204 .3354 .57932 .34733 .59295 .32927 .58574 .3175 Mtetra
.845 .746 .755 r
.58574 .3175 .59295 .32927 .60653 .31109 .59939 .29948 Mtetra
.846 .749 .757 r
.59939 .29948 .60653 .31109 .62007 .29307 .61299 .2816 Mtetra
.845 .752 .76 r
.61299 .2816 .62007 .29307 .63357 .27544 .62656 .2641 Mtetra
.842 .754 .766 r
.62656 .2641 .63357 .27544 .64705 .2584 .6401 .24717 Mtetra
.838 .756 .773 r
.6401 .24717 .64705 .2584 .66051 .24208 .65364 .23097 Mtetra
.831 .758 .782 r
.65364 .23097 .66051 .24208 .67399 .22661 .66718 .2156 Mtetra
.824 .759 .791 r
.66718 .2156 .67399 .22661 .68748 .21204 .68074 .20112 Mtetra
.814 .759 .801 r
.68074 .20112 .68748 .21204 .70101 .19841 .69433 .18757 Mtetra
.804 .759 .811 r
.69433 .18757 .70101 .19841 .71458 .18571 .70797 .17495 Mtetra
.792 .758 .822 r
.70797 .17495 .71458 .18571 .72822 .17391 .72167 .16322 Mtetra
.78 .757 .832 r
.72167 .16322 .72822 .17391 .74192 .16296 .73543 .15235 Mtetra
.768 .755 .842 r
.73543 .15235 .74192 .16296 .7557 .15281 .74927 .14226 Mtetra
.755 .754 .851 r
.74927 .14226 .7557 .15281 .76956 .14338 .7632 .13289 Mtetra
.564 .692 .927 r
.11858 .36812 .12677 .37649 .13782 .37492 .12966 .36644 Mtetra
.557 .687 .927 r
.12966 .36644 .13782 .37492 .14892 .37352 .14079 .36492 Mtetra
.547 .681 .927 r
.14079 .36492 .14892 .37352 .16006 .37233 .15196 .36359 Mtetra
.536 .674 .926 r
.15196 .36359 .16006 .37233 .17125 .37139 .16318 .3625 Mtetra
.523 .665 .926 r
.16318 .3625 .17125 .37139 .18247 .37074 .17443 .36169 Mtetra
.506 .655 .926 r
.17443 .36169 .18247 .37074 .19374 .37046 .18573 .36122 Mtetra
.486 .642 .925 r
.18573 .36122 .19374 .37046 .20504 .37059 .19706 .36116 Mtetra
.463 .626 .923 r
.19706 .36116 .20504 .37059 .21637 .37121 .20842 .36155 Mtetra
.435 .608 .92 r
.20842 .36155 .21637 .37121 .22774 .37238 .21983 .36247 Mtetra
.404 .587 .916 r
.21983 .36247 .22774 .37238 .23915 .37416 .23126 .36398 Mtetra
.37 .563 .91 r
.23126 .36398 .23915 .37416 .2506 .3766 .24274 .36613 Mtetra
.334 .536 .902 r
.24274 .36613 .2506 .3766 .2621 .37975 .25426 .36895 Mtetra
.297 .508 .892 r
.25426 .36895 .2621 .37975 .27364 .3836 .26584 .37246 Mtetra
.262 .48 .881 r
.26584 .37246 .27364 .3836 .28525 .38816 .27747 .37666 Mtetra
.231 .454 .869 r
.27747 .37666 .28525 .38816 .29694 .39338 .28918 .38151 Mtetra
.207 .431 .858 r
.28918 .38151 .29694 .39338 .30872 .39919 .30098 .38692 Mtetra
.192 .414 .848 r
.30098 .38692 .30872 .39919 .3206 .40545 .31287 .3928 Mtetra
.189 .404 .841 r
.31287 .3928 .3206 .40545 .33261 .41201 .32489 .39898 Mtetra
.198 .402 .837 r
.32489 .39898 .33261 .41201 .34475 .41867 .33704 .40526 Mtetra
.22 .409 .836 r
.33704 .40526 .34475 .41867 .35705 .42519 .34934 .41143 Mtetra
.254 .424 .838 r
.34934 .41143 .35705 .42519 .36951 .43129 .36181 .41722 Mtetra
.3 .446 .841 r
.36181 .41722 .36951 .43129 .38215 .43668 .37445 .42234 Mtetra
.353 .474 .843 r
.37445 .42234 .38215 .43668 .39497 .44106 .38727 .42649 Mtetra
.411 .504 .844 r
.38727 .42649 .39497 .44106 .40797 .44414 .40028 .4294 Mtetra
.471 .536 .842 r
.40028 .4294 .40797 .44414 .42115 .44564 .41346 .43078 Mtetra
.529 .566 .837 r
.41346 .43078 .42115 .44564 .43449 .44531 .4268 .43041 Mtetra
.583 .594 .829 r
.4268 .43041 .43449 .44531 .44798 .44298 .4403 .4281 Mtetra
.632 .619 .819 r
.4403 .4281 .44798 .44298 .4616 .43853 .45393 .42372 Mtetra
.674 .64 .808 r
.45393 .42372 .4616 .43853 .47531 .4319 .46767 .41722 Mtetra
.71 .658 .797 r
.46767 .41722 .47531 .4319 .4891 .42312 .48148 .40862 Mtetra
.74 .673 .786 r
.48148 .40862 .4891 .42312 .50294 .41231 .49535 .39803 Mtetra
.764 .686 .776 r
.49535 .39803 .50294 .41231 .5168 .39962 .50925 .38559 Mtetra
.785 .697 .768 r
.50925 .38559 .5168 .39962 .53066 .3853 .52315 .37154 Mtetra
.801 .706 .761 r
.52315 .37154 .53066 .3853 .54449 .36962 .53703 .35614 Mtetra
.814 .714 .755 r
.53703 .35614 .54449 .36962 .55829 .35288 .55089 .33969 Mtetra
.823 .721 .752 r
.55089 .33969 .55829 .35288 .57204 .3354 .5647 .3225 Mtetra
.83 .727 .751 r
.5647 .3225 .57204 .3354 .58574 .3175 .57846 .30488 Mtetra
.835 .733 .752 r
.57846 .30488 .58574 .3175 .59939 .29948 .59217 .28712 Mtetra
.837 .738 .754 r
.59217 .28712 .59939 .29948 .61299 .2816 .60584 .26949 Mtetra
.837 .742 .759 r
.60584 .26949 .61299 .2816 .62656 .2641 .61948 .25221 Mtetra
.835 .746 .765 r
.61948 .25221 .62656 .2641 .6401 .24717 .6331 .2355 Mtetra
.832 .749 .772 r
.6331 .2355 .6401 .24717 .65364 .23097 .6467 .21948 Mtetra
.826 .752 .781 r
.6467 .21948 .65364 .23097 .66718 .2156 .66031 .20428 Mtetra
.819 .754 .791 r
.66031 .20428 .66718 .2156 .68074 .20112 .67393 .18996 Mtetra
.81 .755 .801 r
.67393 .18996 .68074 .20112 .69433 .18757 .68759 .17654 Mtetra
.8 .756 .812 r
.68759 .17654 .69433 .18757 .70797 .17495 .7013 .16404 Mtetra
.789 .756 .823 r
.7013 .16404 .70797 .17495 .72167 .16322 .71506 .15243 Mtetra
.777 .756 .833 r
.71506 .15243 .72167 .16322 .73543 .15235 .72889 .14165 Mtetra
.765 .755 .843 r
.72889 .14165 .73543 .15235 .74927 .14226 .74279 .13165 Mtetra
.753 .753 .853 r
.74279 .13165 .74927 .14226 .7632 .13289 .75678 .12235 Mtetra
.569 .69 .923 r
.11035 .35955 .11858 .36812 .12966 .36644 .12146 .35775 Mtetra
.563 .685 .922 r
.12146 .35775 .12966 .36644 .14079 .36492 .13262 .35609 Mtetra
.554 .679 .922 r
.13262 .35609 .14079 .36492 .15196 .36359 .14382 .35461 Mtetra
.544 .672 .921 r
.14382 .35461 .15196 .36359 .16318 .3625 .15507 .35336 Mtetra
.532 .664 .921 r
.15507 .35336 .16318 .3625 .17443 .36169 .16636 .35237 Mtetra
.517 .654 .92 r
.16636 .35237 .17443 .36169 .18573 .36122 .17768 .35169 Mtetra
.499 .641 .919 r
.17768 .35169 .18573 .36122 .19706 .36116 .18905 .3514 Mtetra
.479 .627 .917 r
.18905 .3514 .19706 .36116 .20842 .36155 .20045 .35154 Mtetra
.454 .61 .914 r
.20045 .35154 .20842 .36155 .21983 .36247 .21188 .35218 Mtetra
.427 .59 .91 r
.21188 .35218 .21983 .36247 .23126 .36398 .22335 .35338 Mtetra
.397 .567 .904 r
.22335 .35338 .23126 .36398 .24274 .36613 .23486 .35519 Mtetra
.365 .543 .897 r
.23486 .35519 .24274 .36613 .25426 .36895 .24642 .35764 Mtetra
.333 .517 .888 r
.24642 .35764 .25426 .36895 .26584 .37246 .25802 .36076 Mtetra
.302 .491 .877 r
.25802 .36076 .26584 .37246 .27747 .37666 .26968 .36453 Mtetra
.275 .466 .866 r
.26968 .36453 .27747 .37666 .28918 .38151 .28142 .36893 Mtetra
.255 .445 .855 r
.28142 .36893 .28918 .38151 .30098 .38692 .29323 .37389 Mtetra
.242 .428 .846 r
.29323 .37389 .30098 .38692 .31287 .3928 .30515 .3793 Mtetra
.24 .418 .838 r
.30515 .3793 .31287 .3928 .32489 .39898 .31718 .38501 Mtetra
.248 .415 .832 r
.31718 .38501 .32489 .39898 .33704 .40526 .32935 .39085 Mtetra
.267 .419 .829 r
.32935 .39085 .33704 .40526 .34934 .41143 .34166 .39658 Mtetra
.297 .43 .827 r
.34166 .39658 .34934 .41143 .36181 .41722 .35413 .40197 Mtetra
.336 .448 .827 r
.35413 .40197 .36181 .41722 .37445 .42234 .36677 .40673 Mtetra
.382 .47 .826 r
.36677 .40673 .37445 .42234 .38727 .42649 .37959 .41059 Mtetra
.432 .495 .824 r
.37959 .41059 .38727 .42649 .40028 .4294 .39259 .41326 Mtetra
.483 .522 .821 r
.39259 .41326 .40028 .4294 .41346 .43078 .40577 .41449 Mtetra
.533 .548 .816 r
.40577 .41449 .41346 .43078 .4268 .43041 .41912 .41403 Mtetra
.581 .573 .809 r
.41912 .41403 .4268 .43041 .4403 .4281 .43262 .41171 Mtetra
.625 .596 .801 r
.43262 .41171 .4403 .4281 .45393 .42372 .44626 .4074 Mtetra
.663 .616 .792 r
.44626 .4074 .45393 .42372 .46767 .41722 .46 .40105 Mtetra
.697 .635 .783 r
.46 .40105 .46767 .41722 .48148 .40862 .47384 .39266 Mtetra
.726 .65 .774 r
.47384 .39266 .48148 .40862 .49535 .39803 .48773 .38234 Mtetra
.75 .664 .766 r
.48773 .38234 .49535 .39803 .50925 .38559 .50166 .37022 Mtetra
.77 .676 .76 r
.50166 .37022 .50925 .38559 .52315 .37154 .5156 .35652 Mtetra
.787 .687 .754 r
.5156 .35652 .52315 .37154 .53703 .35614 .52953 .34149 Mtetra
.8 .696 .75 r
.52953 .34149 .53703 .35614 .55089 .33969 .54343 .32543 Mtetra
.811 .705 .748 r
.54343 .32543 .55089 .33969 .5647 .3225 .55729 .30863 Mtetra
.819 .712 .748 r
.55729 .30863 .5647 .3225 .57846 .30488 .57112 .29139 Mtetra
.824 .719 .749 r
.57112 .29139 .57846 .30488 .59217 .28712 .58489 .27399 Mtetra
.827 .726 .753 r
.58489 .27399 .59217 .28712 .60584 .26949 .59863 .25671 Mtetra
.829 .731 .757 r
.59863 .25671 .60584 .26949 .61948 .25221 .61234 .23976 Mtetra
.828 .736 .764 r
.61234 .23976 .61948 .25221 .6331 .2355 .62602 .22334 Mtetra
.825 .741 .772 r
.62602 .22334 .6331 .2355 .6467 .21948 .63969 .20759 Mtetra
.82 .745 .781 r
.63969 .20759 .6467 .21948 .66031 .20428 .65337 .19263 Mtetra
.814 .748 .791 r
.65337 .19263 .66031 .20428 .67393 .18996 .66707 .17852 Mtetra
.806 .751 .802 r
.66707 .17852 .67393 .18996 .68759 .17654 .68079 .1653 Mtetra
.796 .752 .813 r
.68079 .1653 .68759 .17654 .7013 .16404 .69457 .15297 Mtetra
.786 .753 .824 r
.69457 .15297 .7013 .16404 .71506 .15243 .70839 .1415 Mtetra
.774 .754 .834 r
.70839 .1415 .71506 .15243 .72889 .14165 .72229 .13084 Mtetra
.762 .753 .845 r
.72229 .13084 .72889 .14165 .74279 .13165 .73626 .12094 Mtetra
.75 .753 .854 r
.73626 .12094 .74279 .13165 .75678 .12235 .7503 .11174 Mtetra
.575 .689 .919 r
.10207 .3508 .11035 .35955 .12146 .35775 .11321 .34886 Mtetra
.569 .684 .918 r
.11321 .34886 .12146 .35775 .13262 .35609 .1244 .34705 Mtetra
.561 .678 .917 r
.1244 .34705 .13262 .35609 .14382 .35461 .13564 .34541 Mtetra
.552 .671 .917 r
.13564 .34541 .14382 .35461 .15507 .35336 .14692 .34398 Mtetra
.541 .663 .916 r
.14692 .34398 .15507 .35336 .16636 .35237 .15824 .34279 Mtetra
.528 .653 .915 r
.15824 .34279 .16636 .35237 .17768 .35169 .1696 .34189 Mtetra
.512 .642 .913 r
.1696 .34189 .17768 .35169 .18905 .3514 .181 .34134 Mtetra
.494 .628 .911 r
.181 .34134 .18905 .3514 .20045 .35154 .19244 .34121 Mtetra
.472 .612 .908 r
.19244 .34121 .20045 .35154 .21188 .35218 .20391 .34154 Mtetra
.448 .593 .904 r
.20391 .34154 .21188 .35218 .22335 .35338 .21542 .3424 Mtetra
.422 .573 .898 r
.21542 .3424 .22335 .35338 .23486 .35519 .22696 .34383 Mtetra
.394 .55 .891 r
.22696 .34383 .23486 .35519 .24642 .35764 .23855 .34587 Mtetra
.366 .526 .883 r
.23855 .34587 .24642 .35764 .25802 .36076 .25019 .34855 Mtetra
.339 .502 .873 r
.25019 .34855 .25802 .36076 .26968 .36453 .26189 .35185 Mtetra
.316 .479 .863 r
.26189 .35185 .26968 .36453 .28142 .36893 .27365 .35575 Mtetra
.298 .459 .852 r
.27365 .35575 .28142 .36893 .29323 .37389 .28549 .36018 Mtetra
.287 .442 .842 r
.28549 .36018 .29323 .37389 .30515 .3793 .29743 .36506 Mtetra
.285 .432 .833 r
.29743 .36506 .30515 .3793 .31718 .38501 .30949 .37023 Mtetra
.292 .427 .826 r
.30949 .37023 .31718 .38501 .32935 .39085 .32166 .37554 Mtetra
.308 .428 .821 r
.32166 .37554 .32935 .39085 .34166 .39658 .33399 .38076 Mtetra
.334 .436 .817 r
.33399 .38076 .34166 .39658 .35413 .40197 .34646 .38567 Mtetra
.367 .45 .814 r
.34646 .38567 .35413 .40197 .36677 .40673 .35911 .39001 Mtetra
.406 .467 .811 r
.35911 .39001 .36677 .40673 .37959 .41059 .37193 .3935 Mtetra
.449 .488 .808 r
.37193 .3935 .37959 .41059 .39259 .41326 .38493 .39588 Mtetra
.493 .511 .804 r
.38493 .39588 .39259 .41326 .40577 .41449 .39811 .39688 Mtetra
.537 .534 .799 r
.39811 .39688 .40577 .41449 .41912 .41403 .41145 .3963 Mtetra
.579 .556 .792 r
.41145 .3963 .41912 .41403 .43262 .41171 .42495 .39395 Mtetra
.618 .577 .786 r
.42495 .39395 .43262 .41171 .44626 .4074 .43859 .3897 Mtetra
.654 .597 .778 r
.43859 .3897 .44626 .4074 .46 .40105 .45234 .3835 Mtetra
.685 .614 .771 r
.45234 .3835 .46 .40105 .47384 .39266 .46618 .37535 Mtetra
.713 .63 .764 r
.46618 .37535 .47384 .39266 .48773 .38234 .48009 .36533 Mtetra
.736 .645 .758 r
.48009 .36533 .48773 .38234 .50166 .37022 .49405 .35358 Mtetra
.756 .658 .753 r
.49405 .35358 .50166 .37022 .5156 .35652 .50801 .34029 Mtetra
.773 .669 .749 r
.50801 .34029 .5156 .35652 .52953 .34149 .52198 .32572 Mtetra
.787 .68 .746 r
.52198 .32572 .52953 .34149 .54343 .32543 .53593 .31013 Mtetra
.798 .689 .745 r
.53593 .31013 .54343 .32543 .55729 .30863 .54984 .29381 Mtetra
.807 .698 .745 r
.54984 .29381 .55729 .30863 .57112 .29139 .56372 .27704 Mtetra
.813 .706 .747 r
.56372 .27704 .57112 .29139 .58489 .27399 .57756 .26011 Mtetra
.817 .714 .751 r
.57756 .26011 .58489 .27399 .59863 .25671 .59136 .24326 Mtetra
.819 .721 .757 r
.59136 .24326 .59863 .25671 .61234 .23976 .60513 .22672 Mtetra
.819 .727 .763 r
.60513 .22672 .61234 .23976 .62602 .22334 .61888 .21068 Mtetra
.817 .733 .772 r
.61888 .21068 .62602 .22334 .63969 .20759 .63262 .19528 Mtetra
.813 .738 .781 r
.63262 .19528 .63969 .20759 .65337 .19263 .64637 .18063 Mtetra
.807 .742 .791 r
.64637 .18063 .65337 .19263 .66707 .17852 .66014 .1668 Mtetra
.8 .745 .802 r
.66014 .1668 .66707 .17852 .68079 .1653 .67393 .15382 Mtetra
.791 .748 .814 r
.67393 .15382 .68079 .1653 .69457 .15297 .68777 .1417 Mtetra
.781 .75 .825 r
.68777 .1417 .69457 .15297 .70839 .1415 .70167 .13041 Mtetra
.77 .751 .836 r
.70167 .13041 .70839 .1415 .72229 .13084 .71563 .1199 Mtetra
.759 .751 .846 r
.71563 .1199 .72229 .13084 .73626 .12094 .72966 .11014 Mtetra
.747 .751 .855 r
.72966 .11014 .73626 .12094 .7503 .11174 .74378 .10103 Mtetra
.58 .688 .915 r
.09374 .34187 .10207 .3508 .11321 .34886 .10492 .33979 Mtetra
.575 .683 .914 r
.10492 .33979 .11321 .34886 .1244 .34705 .11614 .33782 Mtetra
.568 .678 .913 r
.11614 .33782 .1244 .34705 .13564 .34541 .12741 .33601 Mtetra
.56 .671 .912 r
.12741 .33601 .13564 .34541 .14692 .34398 .13872 .33438 Mtetra
.551 .663 .911 r
.13872 .33438 .14692 .34398 .15824 .34279 .15008 .33298 Mtetra
.539 .654 .91 r
.15008 .33298 .15824 .34279 .1696 .34189 .16148 .33184 Mtetra
.525 .643 .908 r
.16148 .33184 .1696 .34189 .181 .34134 .17292 .33103 Mtetra
.509 .63 .905 r
.17292 .33103 .181 .34134 .19244 .34121 .18439 .3306 Mtetra
.49 .615 .902 r
.18439 .3306 .19244 .34121 .20391 .34154 .19591 .33061 Mtetra
.468 .598 .898 r
.19591 .33061 .20391 .34154 .21542 .3424 .20745 .3311 Mtetra
.445 .578 .893 r
.20745 .3311 .21542 .3424 .22696 .34383 .21904 .33212 Mtetra
.421 .557 .886 r
.21904 .33212 .22696 .34383 .23855 .34587 .23067 .33372 Mtetra
.396 .535 .878 r
.23067 .33372 .23855 .34587 .25019 .34855 .24235 .33591 Mtetra
.373 .513 .869 r
.24235 .33591 .25019 .34855 .26189 .35185 .25408 .3387 Mtetra
.352 .491 .859 r
.25408 .3387 .26189 .35185 .27365 .35575 .26588 .34205 Mtetra
.337 .472 .849 r
.26588 .34205 .27365 .35575 .28549 .36018 .27775 .34591 Mtetra
.327 .456 .838 r
.27775 .34591 .28549 .36018 .29743 .36506 .28972 .35019 Mtetra
.324 .445 .829 r
.28972 .35019 .29743 .36506 .30949 .37023 .30179 .35476 Mtetra
.33 .439 .821 r
.30179 .35476 .30949 .37023 .32166 .37554 .31399 .35947 Mtetra
.344 .438 .814 r
.31399 .35947 .32166 .37554 .33399 .38076 .32633 .36412 Mtetra
.365 .443 .808 r
.32633 .36412 .33399 .38076 .34646 .38567 .33882 .36849 Mtetra
.393 .453 .804 r
.33882 .36849 .34646 .38567 .35911 .39001 .35147 .37233 Mtetra
.427 .467 .799 r
.35147 .37233 .35911 .39001 .37193 .3935 .36429 .37539 Mtetra
.463 .484 .795 r
.36429 .37539 .37193 .3935 .38493 .39588 .37729 .37741 Mtetra
.502 .503 .79 r
.37729 .37741 .38493 .39588 .39811 .39688 .39046 .37815 Mtetra
.54 .523 .785 r
.39046 .37815 .39811 .39688 .41145 .3963 .40379 .3774 Mtetra
.578 .543 .779 r
.40379 .3774 .41145 .3963 .42495 .39395 .41729 .37499 Mtetra
.613 .562 .773 r
.41729 .37499 .42495 .39395 .43859 .3897 .43092 .37078 Mtetra
.645 .58 .767 r
.43092 .37078 .43859 .3897 .45234 .3835 .44467 .36472 Mtetra
.675 .597 .761 r
.44467 .36472 .45234 .3835 .46618 .37535 .45852 .35682 Mtetra
.701 .613 .755 r
.45852 .35682 .46618 .37535 .48009 .36533 .47244 .34713 Mtetra
.723 .628 .751 r
.47244 .34713 .48009 .36533 .49405 .35358 .48641 .33579 Mtetra
.743 .641 .747 r
.48641 .33579 .49405 .35358 .50801 .34029 .5004 .32297 Mtetra
.76 .653 .744 r
.5004 .32297 .50801 .34029 .52198 .32572 .5144 .30891 Mtetra
.774 .664 .742 r
.5144 .30891 .52198 .32572 .53593 .31013 .52838 .29386 Mtetra
.785 .675 .742 r
.52838 .29386 .53593 .31013 .54984 .29381 .54234 .2781 Mtetra
.795 .685 .743 r
.54234 .2781 .54984 .29381 .56372 .27704 .55627 .26189 Mtetra
.802 .694 .746 r
.55627 .26189 .56372 .27704 .57756 .26011 .57016 .2455 Mtetra
.806 .702 .75 r
.57016 .2455 .57756 .26011 .59136 .24326 .58403 .22918 Mtetra
.809 .71 .756 r
.58403 .22918 .59136 .24326 .60513 .22672 .59786 .21313 Mtetra
.81 .718 .763 r
.59786 .21313 .60513 .22672 .61888 .21068 .61168 .19754 Mtetra
.808 .724 .772 r
.61168 .19754 .61888 .21068 .63262 .19528 .62549 .18256 Mtetra
.805 .73 .782 r
.62549 .18256 .63262 .19528 .64637 .18063 .63931 .16829 Mtetra
.8 .736 .792 r
.63931 .16829 .64637 .18063 .66014 .1668 .65314 .15479 Mtetra
.793 .74 .803 r
.65314 .15479 .66014 .1668 .67393 .15382 .66701 .1421 Mtetra
.785 .743 .815 r
.66701 .1421 .67393 .15382 .68777 .1417 .68092 .13023 Mtetra
.776 .746 .826 r
.68092 .13023 .68777 .1417 .70167 .13041 .69488 .11915 Mtetra
.766 .748 .837 r
.69488 .11915 .70167 .13041 .71563 .1199 .70891 .10883 Mtetra
.755 .749 .847 r
.70891 .10883 .71563 .1199 .72966 .11014 .72301 .09921 Mtetra
.744 .749 .857 r
.72301 .09921 .72966 .11014 .74378 .10103 .73719 .09023 Mtetra
.586 .688 .912 r
.08536 .33279 .09374 .34187 .10492 .33979 .09657 .33055 Mtetra
.581 .683 .911 r
.09657 .33055 .10492 .33979 .11614 .33782 .10783 .32842 Mtetra
.575 .678 .91 r
.10783 .32842 .11614 .33782 .12741 .33601 .11913 .32643 Mtetra
.568 .671 .908 r
.11913 .32643 .12741 .33601 .13872 .33438 .13049 .3246 Mtetra
.56 .664 .907 r
.13049 .3246 .13872 .33438 .15008 .33298 .14188 .32297 Mtetra
.549 .655 .905 r
.14188 .32297 .15008 .33298 .16148 .33184 .15332 .32159 Mtetra
.537 .645 .903 r
.15332 .32159 .16148 .33184 .17292 .33103 .1648 .3205 Mtetra
.523 .633 .901 r
.1648 .3205 .17292 .33103 .18439 .3306 .17631 .31976 Mtetra
.506 .619 .897 r
.17631 .31976 .18439 .3306 .19591 .33061 .18787 .31942 Mtetra
.487 .603 .893 r
.18787 .31942 .19591 .33061 .20745 .3311 .19946 .31952 Mtetra
.467 .585 .888 r
.19946 .31952 .20745 .3311 .21904 .33212 .21109 .32012 Mtetra
.446 .565 .882 r
.21109 .32012 .21904 .33212 .23067 .33372 .22276 .32125 Mtetra
.424 .545 .874 r
.22276 .32125 .23067 .33372 .24235 .33591 .23448 .32293 Mtetra
.404 .524 .865 r
.23448 .32293 .24235 .33591 .25408 .3387 .24625 .32517 Mtetra
.385 .504 .855 r
.24625 .32517 .25408 .3387 .26588 .34205 .25809 .32793 Mtetra
.371 .485 .845 r
.25809 .32793 .26588 .34205 .27775 .34591 .27 .33117 Mtetra
.362 .47 .835 r
.27 .33117 .27775 .34591 .28972 .35019 .282 .33481 Mtetra
.36 .458 .825 r
.282 .33481 .28972 .35019 .30179 .35476 .2941 .33874 Mtetra
.364 .451 .816 r
.2941 .33874 .30179 .35476 .31399 .35947 .30633 .3428 Mtetra
.375 .448 .809 r
.30633 .3428 .31399 .35947 .32633 .36412 .31868 .34682 Mtetra
.393 .451 .802 r
.31868 .34682 .32633 .36412 .33882 .36849 .33118 .35059 Mtetra
.417 .458 .795 r
.33118 .35059 .33882 .36849 .35147 .37233 .34384 .35387 Mtetra
.445 .469 .79 r
.34384 .35387 .35147 .37233 .36429 .37539 .35666 .35645 Mtetra
.477 .482 .785 r
.35666 .35645 .36429 .37539 .37729 .37741 .36966 .35806 Mtetra
.51 .498 .779 r
.36966 .35806 .37729 .37741 .39046 .37815 .38282 .35849 Mtetra
.544 .515 .774 r
.38282 .35849 .39046 .37815 .40379 .3774 .39615 .35753 Mtetra
.577 .533 .769 r
.39615 .35753 .40379 .3774 .41729 .37499 .40964 .35502 Mtetra
.609 .55 .763 r
.40964 .35502 .41729 .37499 .43092 .37078 .42326 .35084 Mtetra
.638 .567 .758 r
.42326 .35084 .43092 .37078 .44467 .36472 .43701 .34492 Mtetra
.666 .583 .753 r
.43701 .34492 .44467 .36472 .45852 .35682 .45086 .33726 Mtetra
.69 .599 .749 r
.45086 .33726 .45852 .35682 .47244 .34713 .46478 .32791 Mtetra
.712 .613 .745 r
.46478 .32791 .47244 .34713 .48641 .33579 .47876 .317 Mtetra
.731 .626 .742 r
.47876 .317 .48641 .33579 .5004 .32297 .49277 .3047 Mtetra
.747 .639 .74 r
.49277 .3047 .5004 .32297 .5144 .30891 .50679 .2912 Mtetra
.761 .651 .74 r
.50679 .2912 .5144 .30891 .52838 .29386 .5208 .27675 Mtetra
.773 .662 .74 r
.5208 .27675 .52838 .29386 .54234 .2781 .5348 .2616 Mtetra
.783 .672 .742 r
.5348 .2616 .54234 .2781 .55627 .26189 .54877 .24601 Mtetra
.79 .682 .745 r
.54877 .24601 .55627 .26189 .57016 .2455 .56272 .23024 Mtetra
.795 .692 .75 r
.56272 .23024 .57016 .2455 .58403 .22918 .57664 .2145 Mtetra
.799 .7 .756 r
.57664 .2145 .58403 .22918 .59786 .21313 .59054 .19902 Mtetra
.8 .709 .764 r
.59054 .19902 .59786 .21313 .61168 .19754 .60442 .18395 Mtetra
.799 .716 .773 r
.60442 .18395 .61168 .19754 .62549 .18256 .6183 .16945 Mtetra
.797 .723 .783 r
.6183 .16945 .62549 .18256 .63931 .16829 .63218 .1556 Mtetra
.792 .729 .793 r
.63218 .1556 .63931 .16829 .65314 .15479 .64609 .14249 Mtetra
.786 .734 .805 r
.64609 .14249 .65314 .15479 .66701 .1421 .66003 .13013 Mtetra
.779 .739 .816 r
.66003 .13013 .66701 .1421 .68092 .13023 .67401 .11855 Mtetra
.77 .742 .827 r
.67401 .11855 .68092 .13023 .69488 .11915 .68804 .10772 Mtetra
.76 .745 .838 r
.68804 .10772 .69488 .11915 .70891 .10883 .70213 .09761 Mtetra
.75 .746 .849 r
.70213 .09761 .70891 .10883 .72301 .09921 .7163 .08816 Mtetra
.74 .747 .858 r
.7163 .08816 .72301 .09921 .73719 .09023 .73054 .07931 Mtetra
.591 .688 .909 r
.07693 .32357 .08536 .33279 .09657 .33055 .08817 .32117 Mtetra
.587 .683 .908 r
.08817 .32117 .09657 .33055 .10783 .32842 .09947 .31887 Mtetra
.582 .678 .906 r
.09947 .31887 .10783 .32842 .11913 .32643 .11081 .31669 Mtetra
.576 .672 .905 r
.11081 .31669 .11913 .32643 .13049 .3246 .1222 .31465 Mtetra
.568 .665 .903 r
.1222 .31465 .13049 .3246 .14188 .32297 .13363 .3128 Mtetra
.559 .657 .901 r
.13363 .3128 .14188 .32297 .15332 .32159 .14511 .31116 Mtetra
.548 .647 .899 r
.14511 .31116 .15332 .32159 .1648 .3205 .15663 .30979 Mtetra
.536 .636 .896 r
.15663 .30979 .1648 .3205 .17631 .31976 .16819 .30873 Mtetra
.521 .623 .893 r
.16819 .30873 .17631 .31976 .18787 .31942 .17979 .30803 Mtetra
.505 .608 .889 r
.17979 .30803 .18787 .31942 .19946 .31952 .19142 .30773 Mtetra
.487 .591 .884 r
.19142 .30773 .19946 .31952 .21109 .32012 .2031 .30789 Mtetra
.468 .573 .878 r
.2031 .30789 .21109 .32012 .22276 .32125 .21482 .30854 Mtetra
.45 .554 .87 r
.21482 .30854 .22276 .32125 .23448 .32293 .22658 .30969 Mtetra
.431 .535 .862 r
.22658 .30969 .23448 .32293 .24625 .32517 .2384 .31135 Mtetra
.415 .516 .852 r
.2384 .31135 .24625 .32517 .25809 .32793 .25028 .3135 Mtetra
.403 .498 .843 r
.25028 .3135 .25809 .32793 .27 .33117 .26223 .3161 Mtetra
.394 .483 .832 r
.26223 .3161 .27 .33117 .282 .33481 .27427 .31907 Mtetra
.391 .471 .822 r
.27427 .31907 .282 .33481 .2941 .33874 .28641 .32231 Mtetra
.394 .463 .813 r
.28641 .32231 .2941 .33874 .30633 .3428 .29866 .32568 Mtetra
.403 .459 .804 r
.29866 .32568 .30633 .3428 .31868 .34682 .31104 .32902 Mtetra
.418 .46 .797 r
.31104 .32902 .31868 .34682 .33118 .35059 .32355 .33215 Mtetra
.438 .464 .79 r
.32355 .33215 .33118 .35059 .34384 .35387 .33622 .33484 Mtetra
.462 .472 .783 r
.33622 .33484 .34384 .35387 .35666 .35645 .34905 .33687 Mtetra
.489 .483 .777 r
.34905 .33687 .35666 .35645 .36966 .35806 .36205 .33804 Mtetra
.518 .496 .772 r
.36205 .33804 .36966 .35806 .38282 .35849 .37521 .33811 Mtetra
.548 .511 .766 r
.37521 .33811 .38282 .35849 .39615 .35753 .38853 .33691 Mtetra
.577 .526 .761 r
.38853 .33691 .39615 .35753 .40964 .35502 .402 .33428 Mtetra
.606 .542 .756 r
.402 .33428 .40964 .35502 .42326 .35084 .41562 .33009 Mtetra
.633 .557 .752 r
.41562 .33009 .42326 .35084 .43701 .34492 .42935 .32429 Mtetra
.658 .572 .747 r
.42935 .32429 .43701 .34492 .45086 .33726 .44319 .31687 Mtetra
.681 .587 .744 r
.44319 .31687 .45086 .33726 .46478 .32791 .45712 .30787 Mtetra
.701 .601 .741 r
.45712 .30787 .46478 .32791 .47876 .317 .4711 .29741 Mtetra
.72 .614 .739 r
.4711 .29741 .47876 .317 .49277 .3047 .48511 .28563 Mtetra
.736 .627 .738 r
.48511 .28563 .49277 .3047 .50679 .2912 .49915 .27272 Mtetra
.75 .639 .738 r
.49915 .27272 .50679 .2912 .5208 .27675 .51319 .25891 Mtetra
.761 .651 .739 r
.51319 .25891 .5208 .27675 .5348 .2616 .52722 .24443 Mtetra
.771 .662 .742 r
.52722 .24443 .5348 .2616 .54877 .24601 .54124 .22951 Mtetra
.779 .672 .746 r
.54124 .22951 .54877 .24601 .56272 .23024 .55523 .21441 Mtetra
.785 .682 .751 r
.55523 .21441 .56272 .23024 .57664 .2145 .5692 .19932 Mtetra
.788 .691 .757 r
.5692 .19932 .57664 .2145 .59054 .19902 .58316 .18445 Mtetra
.79 .7 .765 r
.58316 .18445 .59054 .19902 .60442 .18395 .5971 .16996 Mtetra
.79 .709 .774 r
.5971 .16996 .60442 .18395 .6183 .16945 .61105 .15598 Mtetra
.788 .716 .784 r
.61105 .15598 .6183 .16945 .63218 .1556 .625 .14261 Mtetra
.784 .723 .795 r
.625 .14261 .63218 .1556 .64609 .14249 .63897 .12992 Mtetra
.779 .729 .806 r
.63897 .12992 .64609 .14249 .66003 .13013 .65298 .11794 Mtetra
.772 .734 .818 r
.65298 .11794 .66003 .13013 .67401 .11855 .66703 .10668 Mtetra
.764 .738 .829 r
.66703 .10668 .67401 .11855 .68804 .10772 .68113 .09612 Mtetra
.755 .741 .84 r
.68113 .09612 .68804 .10772 .70213 .09761 .6953 .08624 Mtetra
.745 .743 .85 r
.6953 .08624 .70213 .09761 .7163 .08816 .70953 .07698 Mtetra
.735 .745 .86 r
.70953 .07698 .7163 .08816 .73054 .07931 .72384 .06829 Mtetra
.596 .688 .907 r
.06844 .31422 .07693 .32357 .08817 .32117 .07972 .31166 Mtetra
.592 .684 .905 r
.07972 .31166 .08817 .32117 .09947 .31887 .09105 .30919 Mtetra
.588 .679 .903 r
.09105 .30919 .09947 .31887 .11081 .31669 .10243 .30681 Mtetra
.583 .673 .902 r
.10243 .30681 .11081 .31669 .1222 .31465 .11386 .30457 Mtetra
.576 .667 .9 r
.11386 .30457 .1222 .31465 .13363 .3128 .12533 .30248 Mtetra
.569 .659 .898 r
.12533 .30248 .13363 .3128 .14511 .31116 .13685 .30058 Mtetra
.559 .65 .895 r
.13685 .30058 .14511 .31116 .15663 .30979 .14842 .29892 Mtetra
.548 .639 .893 r
.14842 .29892 .15663 .30979 .16819 .30873 .16002 .29754 Mtetra
.536 .627 .889 r
.16002 .29754 .16819 .30873 .17979 .30803 .17167 .29648 Mtetra
.521 .614 .885 r
.17167 .29648 .17979 .30803 .19142 .30773 .18335 .29578 Mtetra
.506 .599 .88 r
.18335 .29578 .19142 .30773 .2031 .30789 .19507 .2955 Mtetra
.489 .582 .874 r
.19507 .2955 .2031 .30789 .21482 .30854 .20684 .29565 Mtetra
.473 .564 .867 r
.20684 .29565 .21482 .30854 .22658 .30969 .21866 .29626 Mtetra
.457 .546 .859 r
.21866 .29626 .22658 .30969 .2384 .31135 .23052 .29734 Mtetra
.442 .528 .85 r
.23052 .29734 .2384 .31135 .25028 .3135 .24245 .29886 Mtetra
.431 .512 .841 r
.24245 .29886 .25028 .3135 .26223 .3161 .25445 .3008 Mtetra
.423 .497 .831 r
.25445 .3008 .26223 .3161 .27427 .31907 .26653 .30308 Mtetra
.42 .485 .821 r
.26653 .30308 .27427 .31907 .28641 .32231 .2787 .30561 Mtetra
.421 .476 .811 r
.2787 .30561 .28641 .32231 .29866 .32568 .29098 .30827 Mtetra
.428 .471 .802 r
.29098 .30827 .29866 .32568 .31104 .32902 .30338 .31091 Mtetra
.44 .469 .793 r
.30338 .31091 .31104 .32902 .32355 .33215 .31592 .31335 Mtetra
.457 .472 .786 r
.31592 .31335 .32355 .33215 .33622 .33484 .32861 .31541 Mtetra
.477 .477 .779 r
.32861 .31541 .33622 .33484 .34905 .33687 .34144 .31688 Mtetra
.501 .486 .772 r
.34144 .31688 .34905 .33687 .36205 .33804 .35444 .31756 Mtetra
.526 .496 .766 r
.35444 .31756 .36205 .33804 .37521 .33811 .3676 .31725 Mtetra
.552 .509 .761 r
.3676 .31725 .37521 .33811 .38853 .33691 .38091 .31577 Mtetra
.578 .522 .756 r
.38091 .31577 .38853 .33691 .402 .33428 .39437 .31298 Mtetra
.604 .536 .751 r
.39437 .31298 .402 .33428 .41562 .33009 .40798 .30876 Mtetra
.628 .55 .747 r
.40798 .30876 .41562 .33009 .42935 .32429 .4217 .30306 Mtetra
.651 .564 .744 r
.4217 .30306 .42935 .32429 .44319 .31687 .43553 .29587 Mtetra
.673 .578 .741 r
.43553 .29587 .44319 .31687 .45712 .30787 .44945 .28722 Mtetra
.692 .591 .738 r
.44945 .28722 .45712 .30787 .4711 .29741 .46343 .2772 Mtetra
.71 .604 .737 r
.46343 .2772 .4711 .29741 .48511 .28563 .47745 .26596 Mtetra
.725 .617 .737 r
.47745 .26596 .48511 .28563 .49915 .27272 .4915 .25366 Mtetra
.739 .629 .737 r
.4915 .25366 .49915 .27272 .51319 .25891 .50556 .24051 Mtetra
.75 .641 .739 r
.50556 .24051 .51319 .25891 .52722 .24443 .51962 .22672 Mtetra
.76 .652 .742 r
.51962 .22672 .52722 .24443 .54124 .22951 .53367 .21252 Mtetra
.768 .663 .747 r
.53367 .21252 .54124 .22951 .55523 .21441 .5477 .19811 Mtetra
.774 .673 .752 r
.5477 .19811 .55523 .21441 .5692 .19932 .56172 .18371 Mtetra
.778 .683 .759 r
.56172 .18371 .5692 .19932 .58316 .18445 .57573 .16949 Mtetra
.78 .693 .767 r
.57573 .16949 .58316 .18445 .5971 .16996 .58974 .15562 Mtetra
.781 .702 .776 r
.58974 .15562 .5971 .16996 .61105 .15598 .60374 .1422 Mtetra
.779 .71 .787 r
.60374 .1422 .61105 .15598 .625 .14261 .61776 .12935 Mtetra
.776 .717 .797 r
.61776 .12935 .625 .14261 .63897 .12992 .6318 .11711 Mtetra
.771 .724 .809 r
.6318 .11711 .63897 .12992 .65298 .11794 .64588 .10554 Mtetra
.765 .73 .82 r
.64588 .10554 .65298 .11794 .66703 .10668 .65999 .09462 Mtetra
.757 .734 .831 r
.65999 .09462 .66703 .10668 .68113 .09612 .67416 .08436 Mtetra
.749 .738 .842 r
.67416 .08436 .68113 .09612 .6953 .08624 .6884 .07473 Mtetra
.74 .741 .852 r
.6884 .07473 .6953 .08624 .70953 .07698 .7027 .06567 Mtetra
.731 .743 .861 r
.7027 .06567 .70953 .07698 .72384 .06829 .71707 .05715 Mtetra
.601 .689 .904 r
.0599 .30476 .06844 .31422 .07972 .31166 .07121 .30204 Mtetra
.598 .685 .903 r
.07121 .30204 .07972 .31166 .09105 .30919 .08258 .29939 Mtetra
.594 .68 .901 r
.08258 .29939 .09105 .30919 .10243 .30681 .094 .29683 Mtetra
.59 .675 .899 r
.094 .29683 .10243 .30681 .11386 .30457 .10546 .29437 Mtetra
.584 .669 .897 r
.10546 .29437 .11386 .30457 .12533 .30248 .11698 .29205 Mtetra
.577 .661 .895 r
.11698 .29205 .12533 .30248 .13685 .30058 .12854 .2899 Mtetra
.569 .653 .893 r
.12854 .2899 .13685 .30058 .14842 .29892 .14015 .28795 Mtetra
.56 .643 .89 r
.14015 .28795 .14842 .29892 .16002 .29754 .1518 .28624 Mtetra
.549 .632 .886 r
.1518 .28624 .16002 .29754 .17167 .29648 .16349 .28482 Mtetra
.537 .62 .882 r
.16349 .28482 .17167 .29648 .18335 .29578 .17523 .28373 Mtetra
.523 .606 .878 r
.17523 .28373 .18335 .29578 .19507 .2955 .187 .28299 Mtetra
.509 .591 .872 r
.187 .28299 .19507 .2955 .20684 .29565 .19882 .28265 Mtetra
.494 .574 .865 r
.19882 .28265 .20684 .29565 .21866 .29626 .21069 .28272 Mtetra
.48 .558 .858 r
.21069 .28272 .21866 .29626 .23052 .29734 .2226 .28321 Mtetra
.467 .541 .849 r
.2226 .28321 .23052 .29734 .24245 .29886 .23458 .28411 Mtetra
.457 .525 .84 r
.23458 .28411 .24245 .29886 .25445 .3008 .24663 .28538 Mtetra
.449 .511 .83 r
.24663 .28538 .25445 .3008 .26653 .30308 .25875 .28696 Mtetra
.446 .498 .82 r
.25875 .28696 .26653 .30308 .2787 .30561 .27097 .28877 Mtetra
.446 .489 .81 r
.27097 .28877 .2787 .30561 .29098 .30827 .28328 .29071 Mtetra
.451 .483 .801 r
.28328 .29071 .29098 .30827 .30338 .31091 .29572 .29263 Mtetra
.461 .48 .792 r
.29572 .29263 .30338 .31091 .31592 .31335 .30828 .29438 Mtetra
.475 .481 .784 r
.30828 .29438 .31592 .31335 .32861 .31541 .32098 .29579 Mtetra
.492 .484 .776 r
.32098 .29579 .32861 .31541 .34144 .31688 .33383 .29667 Mtetra
.512 .491 .77 r
.33383 .29667 .34144 .31688 .35444 .31756 .34683 .29684 Mtetra
.534 .499 .764 r
.34683 .29684 .35444 .31756 .3676 .31725 .35999 .29611 Mtetra
.557 .509 .758 r
.35999 .29611 .3676 .31725 .38091 .31577 .37329 .29433 Mtetra
.58 .521 .753 r
.37329 .29433 .38091 .31577 .39437 .31298 .38675 .29136 Mtetra
.603 .533 .749 r
.38675 .29136 .39437 .31298 .40798 .30876 .40034 .28709 Mtetra
.625 .546 .745 r
.40034 .28709 .40798 .30876 .4217 .30306 .41405 .28147 Mtetra
.646 .558 .742 r
.41405 .28147 .4217 .30306 .43553 .29587 .42787 .27449 Mtetra
.666 .571 .739 r
.42787 .27449 .43553 .29587 .44945 .28722 .44177 .26617 Mtetra
.684 .584 .737 r
.44177 .26617 .44945 .28722 .46343 .2772 .45575 .25659 Mtetra
.701 .597 .737 r
.45575 .25659 .46343 .2772 .47745 .26596 .46977 .24589 Mtetra
.716 .609 .737 r
.46977 .24589 .47745 .26596 .4915 .25366 .48383 .2342 Mtetra
.729 .621 .738 r
.48383 .2342 .4915 .25366 .50556 .24051 .4979 .22172 Mtetra
.74 .633 .74 r
.4979 .22172 .50556 .24051 .51962 .22672 .51198 .20864 Mtetra
.75 .644 .744 r
.51198 .20864 .51962 .22672 .53367 .21252 .52606 .19515 Mtetra
.758 .656 .749 r
.52606 .19515 .53367 .21252 .5477 .19811 .54013 .18147 Mtetra
.764 .666 .755 r
.54013 .18147 .5477 .19811 .56172 .18371 .5542 .16778 Mtetra
.768 .677 .762 r
.5542 .16778 .56172 .18371 .57573 .16949 .56826 .15424 Mtetra
.771 .686 .77 r
.56826 .15424 .57573 .16949 .58974 .15562 .58232 .14101 Mtetra
.771 .696 .779 r
.58232 .14101 .58974 .15562 .60374 .1422 .59638 .12818 Mtetra
.77 .704 .79 r
.59638 .12818 .60374 .1422 .61776 .12935 .61047 .11587 Mtetra
.768 .712 .8 r
.61047 .11587 .61776 .12935 .6318 .11711 .62457 .10411 Mtetra
.763 .719 .812 r
.62457 .10411 .6318 .11711 .64588 .10554 .63871 .09296 Mtetra
.757 .725 .823 r
.63871 .09296 .64588 .10554 .65999 .09462 .6529 .08241 Mtetra
.751 .731 .834 r
.6529 .08241 .65999 .09462 .67416 .08436 .66714 .07247 Mtetra
.743 .735 .844 r
.66714 .07247 .67416 .08436 .6884 .07473 .68144 .06309 Mtetra
.734 .738 .854 r
.68144 .06309 .6884 .07473 .7027 .06567 .69581 .05425 Mtetra
.726 .74 .863 r
.69581 .05425 .7027 .06567 .71707 .05715 .71025 .0459 Mtetra
.606 .69 .902 r
.05129 .29521 .0599 .30476 .07121 .30204 .06264 .29233 Mtetra
.603 .686 .901 r
.06264 .29233 .07121 .30204 .08258 .29939 .07404 .2895 Mtetra
.6 .682 .899 r
.07404 .2895 .08258 .29939 .094 .29683 .0855 .28675 Mtetra
.596 .677 .897 r
.0855 .28675 .094 .29683 .10546 .29437 .09701 .28408 Mtetra
.591 .671 .895 r
.09701 .28408 .10546 .29437 .11698 .29205 .10857 .28153 Mtetra
.586 .664 .893 r
.10857 .28153 .11698 .29205 .12854 .2899 .12017 .27913 Mtetra
.579 .657 .89 r
.12017 .27913 .12854 .2899 .14015 .28795 .13183 .27689 Mtetra
.571 .648 .887 r
.13183 .27689 .14015 .28795 .1518 .28624 .14352 .27487 Mtetra
.561 .638 .884 r
.14352 .27487 .1518 .28624 .16349 .28482 .15527 .2731 Mtetra
.55 .626 .88 r
.15527 .2731 .16349 .28482 .17523 .28373 .16705 .27161 Mtetra
.539 .614 .876 r
.16705 .27161 .17523 .28373 .187 .28299 .17888 .27044 Mtetra
.526 .6 .87 r
.17888 .27044 .187 .28299 .19882 .28265 .19075 .26961 Mtetra
.513 .585 .864 r
.19075 .26961 .19882 .28265 .21069 .28272 .20267 .26915 Mtetra
.501 .569 .857 r
.20267 .26915 .21069 .28272 .2226 .28321 .21464 .26906 Mtetra
.49 .554 .848 r
.21464 .26906 .2226 .28321 .23458 .28411 .22667 .26934 Mtetra
.48 .539 .839 r
.22667 .26934 .23458 .28411 .24663 .28538 .23877 .26994 Mtetra
.473 .525 .83 r
.23877 .26994 .24663 .28538 .25875 .28696 .25094 .27083 Mtetra
.469 .513 .82 r
.25094 .27083 .25875 .28696 .27097 .28877 .2632 .27193 Mtetra
.469 .503 .811 r
.2632 .27193 .27097 .28877 .28328 .29071 .27556 .27314 Mtetra
.473 .496 .801 r
.27556 .27314 .28328 .29071 .29572 .29263 .28803 .27434 Mtetra
.48 .492 .792 r
.28803 .27434 .29572 .29263 .30828 .29438 .30062 .27539 Mtetra
.492 .491 .784 r
.30062 .27539 .30828 .29438 .32098 .29579 .31334 .27614 Mtetra
.506 .493 .776 r
.31334 .27614 .32098 .29579 .33383 .29667 .3262 .27643 Mtetra
.523 .497 .769 r
.3262 .27643 .33383 .29667 .34683 .29684 .33921 .27607 Mtetra
.542 .504 .763 r
.33921 .27607 .34683 .29684 .35999 .29611 .35237 .27492 Mtetra
.562 .512 .757 r
.35237 .27492 .35999 .29611 .37329 .29433 .36567 .27281 Mtetra
.582 .521 .752 r
.36567 .27281 .37329 .29433 .38675 .29136 .37912 .26964 Mtetra
.603 .532 .748 r
.37912 .26964 .38675 .29136 .40034 .28709 .39269 .2653 Mtetra
.623 .544 .744 r
.39269 .2653 .40034 .28709 .41405 .28147 .40639 .25974 Mtetra
.642 .555 .741 r
.40639 .25974 .41405 .28147 .42787 .27449 .42019 .25294 Mtetra
.66 .567 .739 r
.42019 .25294 .42787 .27449 .44177 .26617 .43409 .24494 Mtetra
.678 .579 .738 r
.43409 .24494 .44177 .26617 .45575 .25659 .44805 .23579 Mtetra
.693 .592 .738 r
.44805 .23579 .45575 .25659 .46977 .24589 .46207 .2256 Mtetra
.707 .604 .738 r
.46207 .2256 .46977 .24589 .48383 .2342 .47613 .21452 Mtetra
.72 .615 .74 r
.47613 .21452 .48383 .2342 .4979 .22172 .49022 .2027 Mtetra
.731 .627 .743 r
.49022 .2027 .4979 .22172 .51198 .20864 .50432 .19032 Mtetra
.74 .638 .747 r
.50432 .19032 .51198 .20864 .52606 .19515 .51842 .17756 Mtetra
.748 .65 .752 r
.51842 .17756 .52606 .19515 .54013 .18147 .53253 .16461 Mtetra
.754 .661 .758 r
.53253 .16461 .54013 .18147 .5542 .16778 .54663 .15164 Mtetra
.759 .671 .765 r
.54663 .15164 .5542 .16778 .56826 .15424 .56074 .13879 Mtetra
.761 .681 .774 r
.56074 .13879 .56826 .15424 .58232 .14101 .57485 .1262 Mtetra
.762 .691 .783 r
.57485 .1262 .58232 .14101 .59638 .12818 .58897 .11399 Mtetra
.761 .7 .793 r
.58897 .11399 .59638 .12818 .61047 .11587 .60312 .10222 Mtetra
.759 .708 .804 r
.60312 .10222 .61047 .11587 .62457 .10411 .61729 .09096 Mtetra
.755 .715 .815 r
.61729 .09096 .62457 .10411 .63871 .09296 .63149 .08024 Mtetra
.75 .722 .826 r
.63149 .08024 .63871 .09296 .6529 .08241 .64575 .07007 Mtetra
.744 .727 .837 r
.64575 .07007 .6529 .08241 .66714 .07247 .66005 .06045 Mtetra
.736 .732 .847 r
.66005 .06045 .66714 .07247 .68144 .06309 .67442 .05134 Mtetra
.729 .736 .857 r
.67442 .05134 .68144 .06309 .69581 .05425 .68885 .04272 Mtetra
.721 .738 .865 r
.68885 .04272 .69581 .05425 .71025 .0459 .70336 .03455 Mtetra
.611 .692 .901 r
.04261 .28559 .05129 .29521 .06264 .29233 .054 .28254 Mtetra
.609 .688 .899 r
.054 .28254 .06264 .29233 .07404 .2895 .06545 .27954 Mtetra
.606 .684 .897 r
.06545 .27954 .07404 .2895 .0855 .28675 .07694 .2766 Mtetra
.602 .679 .895 r
.07694 .2766 .0855 .28675 .09701 .28408 .08849 .27373 Mtetra
.598 .674 .893 r
.08849 .27373 .09701 .28408 .10857 .28153 .10009 .27095 Mtetra
.593 .668 .891 r
.10009 .27095 .10857 .28153 .12017 .27913 .11174 .2683 Mtetra
.588 .661 .888 r
.11174 .2683 .12017 .27913 .13183 .27689 .12344 .26579 Mtetra
.581 .653 .886 r
.12344 .26579 .13183 .27689 .14352 .27487 .13519 .26346 Mtetra
.573 .644 .882 r
.13519 .26346 .14352 .27487 .15527 .2731 .14698 .26134 Mtetra
.563 .633 .879 r
.14698 .26134 .15527 .2731 .16705 .27161 .15881 .25947 Mtetra
.553 .622 .874 r
.15881 .25947 .16705 .27161 .17888 .27044 .17069 .25788 Mtetra
.542 .609 .869 r
.17069 .25788 .17888 .27044 .19075 .26961 .18262 .25658 Mtetra
.531 .595 .863 r
.18262 .25658 .19075 .26961 .20267 .26915 .19459 .2556 Mtetra
.52 .581 .856 r
.19459 .2556 .20267 .26915 .21464 .26906 .20662 .25495 Mtetra
.51 .566 .849 r
.20662 .25495 .21464 .26906 .22667 .26934 .21871 .25462 Mtetra
.501 .552 .84 r
.21871 .25462 .22667 .26934 .23877 .26994 .23086 .25458 Mtetra
.495 .539 .831 r
.23086 .25458 .23877 .26994 .25094 .27083 .24308 .25479 Mtetra
.491 .527 .822 r
.24308 .25479 .25094 .27083 .2632 .27193 .25539 .25519 Mtetra
.49 .517 .812 r
.25539 .25519 .2632 .27193 .27556 .27314 .26779 .25569 Mtetra
.492 .51 .803 r
.26779 .25569 .27556 .27314 .28803 .27434 .2803 .25618 Mtetra
.498 .505 .794 r
.2803 .25618 .28803 .27434 .30062 .27539 .29292 .25655 Mtetra
.507 .502 .785 r
.29292 .25655 .30062 .27539 .31334 .27614 .30567 .25664 Mtetra
.519 .503 .778 r
.30567 .25664 .31334 .27614 .3262 .27643 .31855 .25632 Mtetra
.534 .505 .77 r
.31855 .25632 .3262 .27643 .33921 .27607 .33157 .25544 Mtetra
.55 .51 .764 r
.33157 .25544 .33921 .27607 .35237 .27492 .34473 .25385 Mtetra
.567 .517 .758 r
.34473 .25385 .35237 .27492 .36567 .27281 .35803 .25142 Mtetra
.585 .525 .753 r
.35803 .25142 .36567 .27281 .37912 .26964 .37147 .24803 Mtetra
.604 .534 .749 r
.37147 .24803 .37912 .26964 .39269 .2653 .38503 .2436 Mtetra
.622 .544 .746 r
.38503 .2436 .39269 .2653 .40639 .25974 .39872 .23808 Mtetra
.639 .555 .743 r
.39872 .23808 .40639 .25974 .42019 .25294 .41251 .23145 Mtetra
.656 .566 .741 r
.41251 .23145 .42019 .25294 .43409 .24494 .42639 .22373 Mtetra
.672 .577 .74 r
.42639 .22373 .43409 .24494 .44805 .23579 .44034 .21498 Mtetra
.687 .588 .74 r
.44034 .21498 .44805 .23579 .46207 .2256 .45436 .20529 Mtetra
.7 .6 .741 r
.45436 .20529 .46207 .2256 .47613 .21452 .46842 .19479 Mtetra
.712 .611 .743 r
.46842 .19479 .47613 .21452 .49022 .2027 .48251 .18361 Mtetra
.722 .623 .746 r
.48251 .18361 .49022 .2027 .50432 .19032 .49662 .17193 Mtetra
.732 .634 .75 r
.49662 .17193 .50432 .19032 .51842 .17756 .51075 .15988 Mtetra
.739 .645 .756 r
.51075 .15988 .51842 .17756 .53253 .16461 .52489 .14765 Mtetra
.745 .656 .762 r
.52489 .14765 .53253 .16461 .54663 .15164 .53903 .13539 Mtetra
.749 .667 .77 r
.53903 .13539 .54663 .15164 .56074 .13879 .55318 .12323 Mtetra
.752 .677 .778 r
.55318 .12323 .56074 .13879 .57485 .1262 .56734 .11129 Mtetra
.753 .687 .788 r
.56734 .11129 .57485 .1262 .58897 .11399 .58152 .09968 Mtetra
.753 .696 .798 r
.58152 .09968 .58897 .11399 .60312 .10222 .59572 .08846 Mtetra
.751 .705 .808 r
.59572 .08846 .60312 .10222 .61729 .09096 .60995 .0777 Mtetra
.747 .712 .819 r
.60995 .0777 .61729 .09096 .63149 .08024 .62422 .06742 Mtetra
.742 .719 .83 r
.62422 .06742 .63149 .08024 .64575 .07007 .63853 .05763 Mtetra
.737 .725 .84 r
.63853 .05763 .64575 .07007 .66005 .06045 .65291 .04833 Mtetra
.73 .73 .85 r
.65291 .04833 .66005 .06045 .67442 .05134 .66734 .0395 Mtetra
.723 .733 .859 r
.66734 .0395 .67442 .05134 .68885 .04272 .68184 .0311 Mtetra
.716 .736 .867 r
.68184 .0311 .68885 .04272 .70336 .03455 .69642 .0231 Mtetra
.615 .694 .9 r
.03387 .2759 .04261 .28559 .054 .28254 .0453 .27269 Mtetra
.613 .69 .898 r
.0453 .27269 .054 .28254 .06545 .27954 .05678 .26952 Mtetra
.611 .686 .896 r
.05678 .26952 .06545 .27954 .07694 .2766 .06832 .26639 Mtetra
.608 .682 .894 r
.06832 .26639 .07694 .2766 .08849 .27373 .07991 .26333 Mtetra
.605 .677 .892 r
.07991 .26333 .08849 .27373 .10009 .27095 .09155 .26033 Mtetra
.601 .671 .89 r
.09155 .26033 .10009 .27095 .11174 .2683 .10325 .25744 Mtetra
.596 .665 .887 r
.10325 .25744 .11174 .2683 .12344 .26579 .11499 .25466 Mtetra
.59 .658 .884 r
.11499 .25466 .12344 .26579 .13519 .26346 .12678 .25204 Mtetra
.583 .649 .881 r
.12678 .25204 .13519 .26346 .14698 .26134 .13862 .24959 Mtetra
.575 .64 .878 r
.13862 .24959 .14698 .26134 .15881 .25947 .15051 .24736 Mtetra
.566 .629 .874 r
.15051 .24736 .15881 .25947 .17069 .25788 .16245 .24535 Mtetra
.557 .618 .869 r
.16245 .24535 .17069 .25788 .18262 .25658 .17443 .24361 Mtetra
.547 .606 .863 r
.17443 .24361 .18262 .25658 .19459 .2556 .18646 .24214 Mtetra
.538 .592 .857 r
.18646 .24214 .19459 .2556 .20662 .25495 .19854 .24095 Mtetra
.529 .579 .85 r
.19854 .24095 .20662 .25495 .21871 .25462 .21068 .24003 Mtetra
.521 .566 .842 r
.21068 .24003 .21871 .25462 .23086 .25458 .22289 .23937 Mtetra
.515 .553 .833 r
.22289 .23937 .23086 .25458 .24308 .25479 .23516 .23893 Mtetra
.511 .542 .824 r
.23516 .23893 .24308 .25479 .25539 .25519 .24752 .23865 Mtetra
.509 .532 .815 r
.24752 .23865 .25539 .25519 .26779 .25569 .25997 .23846 Mtetra
.511 .524 .806 r
.25997 .23846 .26779 .25569 .2803 .25618 .27252 .23827 Mtetra
.515 .518 .797 r
.27252 .23827 .2803 .25618 .29292 .25655 .28518 .23796 Mtetra
.523 .515 .789 r
.28518 .23796 .29292 .25655 .30567 .25664 .29795 .23742 Mtetra
.532 .514 .781 r
.29795 .23742 .30567 .25664 .31855 .25632 .31085 .23652 Mtetra
.544 .515 .773 r
.31085 .23652 .31855 .25632 .33157 .25544 .32389 .23511 Mtetra
.558 .518 .767 r
.32389 .23511 .33157 .25544 .34473 .25385 .33706 .23309 Mtetra
.573 .523 .761 r
.33706 .23309 .34473 .25385 .35803 .25142 .35036 .23032 Mtetra
.589 .53 .756 r
.35036 .23032 .35803 .25142 .37147 .24803 .36379 .22671 Mtetra
.605 .538 .752 r
.36379 .22671 .37147 .24803 .38503 .2436 .37735 .22217 Mtetra
.622 .546 .749 r
.37735 .22217 .38503 .2436 .39872 .23808 .39102 .21667 Mtetra
.638 .556 .746 r
.39102 .21667 .39872 .23808 .41251 .23145 .4048 .21018 Mtetra
.653 .566 .744 r
.4048 .21018 .41251 .23145 .42639 .22373 .41867 .20272 Mtetra
.667 .577 .744 r
.41867 .20272 .42639 .22373 .44034 .21498 .43261 .19435 Mtetra
.681 .587 .744 r
.43261 .19435 .44034 .21498 .45436 .20529 .44662 .18513 Mtetra
.693 .598 .745 r
.44662 .18513 .45436 .20529 .46842 .19479 .46068 .17518 Mtetra
.705 .609 .748 r
.46068 .17518 .46842 .19479 .48251 .18361 .47478 .16462 Mtetra
.715 .621 .751 r
.47478 .16462 .48251 .18361 .49662 .17193 .4889 .15359 Mtetra
.723 .632 .755 r
.4889 .15359 .49662 .17193 .51075 .15988 .50305 .14224 Mtetra
.731 .643 .761 r
.50305 .14224 .51075 .15988 .52489 .14765 .51721 .13071 Mtetra
.737 .654 .768 r
.51721 .13071 .52489 .14765 .53903 .13539 .53139 .11914 Mtetra
.741 .664 .775 r
.53139 .11914 .53903 .13539 .55318 .12323 .54558 .10765 Mtetra
.744 .675 .784 r
.54558 .10765 .55318 .12323 .56734 .11129 .55978 .09635 Mtetra
.745 .684 .793 r
.55978 .09635 .56734 .11129 .58152 .09968 .57401 .08532 Mtetra
.744 .694 .803 r
.57401 .08532 .58152 .09968 .59572 .08846 .58827 .07465 Mtetra
.743 .702 .813 r
.58827 .07465 .59572 .08846 .60995 .0777 .60256 .06438 Mtetra
.739 .71 .824 r
.60256 .06438 .60995 .0777 .62422 .06742 .61689 .05453 Mtetra
.735 .717 .834 r
.61689 .05453 .62422 .06742 .63853 .05763 .63127 .04512 Mtetra
.73 .723 .844 r
.63127 .04512 .63853 .05763 .65291 .04833 .6457 .03614 Mtetra
.724 .728 .853 r
.6457 .03614 .65291 .04833 .66734 .0395 .6602 .02757 Mtetra
.717 .732 .862 r
.6602 .02757 .66734 .0395 .68184 .0311 .67477 .0194 Mtetra
.711 .735 .87 r
.67477 .0194 .68184 .0311 .69642 .0231 .68941 .01158 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.5 .1603 m
.5258 .15954 L
.5516 .16246 L
.56369 .1646 L
.5774 .16923 L
.6032 .18034 L
.62017 .1904 L
.629 .1968 L
.6506 .2162 L
.6548 .22076 L
.67102 .242 L
.6806 .25833 L
.68503 .2678 L
.69425 .2936 L
.69936 .3194 L
.70071 .3452 L
.69841 .371 L
.69229 .3968 L
.6819 .4226 L
.6806 .42524 L
.66644 .4484 L
.6548 .46301 L
.64397 .4742 L
.629 .48694 L
.60943 .5 L
.6032 .50338 L
.5774 .51452 L
.5516 .52129 L
.5258 .52419 L
.5 .52344 L
.4742 .51897 L
.4484 .51047 L
.42701 .5 L
.4226 .49728 L
.3968 .47808 L
.39258 .4742 L
.371 .44965 L
.3701 .4484 L
.35457 .4226 L
.3452 .39996 L
.34424 .3968 L
.3381 .371 L
.33579 .3452 L
.33715 .3194 L
.34227 .2936 L
.3452 .28322 L
.35146 .2678 L
.36551 .242 L
.371 .23401 L
.38588 .2162 L
Mistroke
.3968 .20562 L
.41641 .1904 L
.4226 .18646 L
.4484 .17326 L
.4742 .16479 L
.47497 .1646 L
.5 .1603 L
Mfstroke
.5 .54431 m
.5258 .53575 L
.5516 .53086 L
.5774 .52936 L
.6032 .53118 L
.629 .53641 L
.6548 .54535 L
.66834 .5516 L
.6806 .55855 L
.7064 .57717 L
.70667 .5774 L
.73197 .6032 L
.7322 .60348 L
.74994 .629 L
.758 .64405 L
.76264 .6548 L
.77117 .6806 L
.77603 .7064 L
.7775 .7322 L
.77565 .758 L
.77038 .7838 L
.76139 .8096 L
.758 .81728 L
.74815 .8354 L
.7322 .85796 L
.72949 .8612 L
.7064 .88425 L
.70311 .887 L
.6806 .90285 L
.6622 .9128 L
.6548 .91604 L
.629 .92499 L
.6032 .93022 L
.5774 .93204 L
.5516 .93054 L
.5258 .92565 L
.5 .91708 L
.49006 .9128 L
.4742 .90433 L
.44924 .887 L
.4484 .88631 L
.42284 .8612 L
.4226 .86091 L
.40416 .8354 L
.3968 .82238 L
.39092 .8096 L
.38193 .7838 L
.37667 .758 L
.37482 .7322 L
.37628 .7064 L
Mistroke
.38114 .6806 L
.38966 .6548 L
.3968 .639 L
.40238 .629 L
.42033 .6032 L
.4226 .60047 L
.44563 .5774 L
.4484 .57509 L
.4742 .55707 L
.48396 .5516 L
.5 .54431 L
Mfstroke
.66965 .0098 m
.6806 .01515 L
.7064 .03062 L
.71313 .0356 L
.7322 .05307 L
.7396 .0614 L
.75763 .0872 L
.758 .08782 L
.76999 .113 L
.77778 .1388 L
.78162 .1646 L
.78177 .1904 L
.77824 .2162 L
.77079 .242 L
.75884 .2678 L
.758 .26931 L
.74136 .2936 L
.7322 .30407 L
.71578 .3194 L
.7064 .32661 L
.6806 .34213 L
.67449 .3452 L
.6548 .35253 L
.629 .3587 L
.6032 .36103 L
.5774 .3597 L
.5516 .35462 L
.5258 .34542 L
.52529 .3452 L
.5 .33146 L
.48353 .3194 L
.4742 .31113 L
.45797 .2936 L
.4484 .28077 L
.44048 .2678 L
.42855 .242 L
.4226 .22378 L
.42112 .2162 L
.41757 .1904 L
.41772 .1646 L
.42158 .1388 L
.4226 .1338 L
.42935 .113 L
.44169 .0872 L
.4484 .07638 L
.45972 .0614 L
.4742 .046 L
.48616 .0356 L
.5 .02583 L
.5258 .01177 L
Mistroke
.52977 .0098 L
Mfstroke
.7064 .47313 m
.7322 .46688 L
.758 .4641 L
.7838 .46466 L
.8096 .46858 L
.83082 .4742 L
.8354 .47607 L
.8612 .48754 L
.88163 .5 L
.887 .50391 L
.91176 .5258 L
.9128 .52688 L
.93276 .5516 L
.9386 .56054 L
.94772 .5774 L
.9581 .6032 L
.9644 .62772 L
.96459 .629 L
.9676 .6548 L
.96729 .6806 L
.9644 .70259 L
.96364 .7064 L
.95646 .7322 L
.94528 .758 L
.9386 .76998 L
.92933 .7838 L
.9128 .80369 L
.90697 .8096 L
.887 .82663 L
.87434 .8354 L
.8612 .84299 L
.8354 .85448 L
.8133 .8612 L
.8096 .86194 L
.7838 .86587 L
.758 .86642 L
.7322 .86365 L
.7181 .8612 L
.7064 .85741 L
.6806 .84735 L
.65881 .8354 L
.6548 .83274 L
.629 .81229 L
.62618 .8096 L
.60381 .7838 L
.6032 .78296 L
.58783 .758 L
.5774 .73429 L
.57668 .7322 L
.56946 .7064 L
Mistroke
.56579 .6806 L
.56548 .6548 L
.5685 .629 L
.57503 .6032 L
.5774 .59601 L
.58539 .5774 L
.60037 .5516 L
.6032 .54755 L
.62132 .5258 L
.629 .51822 L
.65154 .5 L
.6548 .4978 L
.6806 .48318 L
.70292 .4742 L
.7064 .47313 L
Mfstroke
.0098 .44683 m
.01077 .4484 L
.02858 .4742 L
.0356 .48291 L
.05133 .5 L
.0614 .50956 L
.08117 .5258 L
.0872 .53017 L
.113 .5463 L
.12304 .5516 L
.1388 .5588 L
.1646 .5682 L
.1904 .5748 L
.20182 .5774 L
.2162 .57883 L
.242 .58039 L
.2678 .57952 L
.28626 .5774 L
.2936 .5762 L
.3194 .57035 L
.3452 .56178 L
.36826 .5516 L
.371 .55019 L
.3968 .53517 L
.41019 .5258 L
.4226 .51595 L
.44001 .5 L
.4484 .49125 L
.4628 .4742 L
.4742 .45842 L
.48059 .4484 L
.49446 .4226 L
.5 .41017 L
.50505 .3968 L
.51275 .371 L
.51779 .3452 L
.52033 .3194 L
.52043 .2936 L
.5181 .2678 L
.51328 .242 L
.50582 .2162 L
.5 .20062 L
.49549 .1904 L
.48191 .1646 L
.4742 .15237 L
.46449 .1388 L
.4484 .11956 L
.44219 .113 L
.4226 .09485 L
.41309 .0872 L
Mistroke
.3968 .07563 L
.37255 .0614 L
.371 .06061 L
.3452 .04903 L
.3194 .04046 L
.29946 .0356 L
.2936 .0346 L
.2678 .03129 L
.242 .03042 L
.2162 .03198 L
.19134 .0356 L
.1904 .036 L
.1646 .04261 L
.1388 .052 L
.11874 .0614 L
.113 .0645 L
.0872 .08063 L
.07825 .0872 L
.0614 .10124 L
.04915 .113 L
.0356 .12789 L
.02689 .1388 L
.0098 .16399 L
Mfstroke
0 g
.03 w
.51825 .34187 Mdot
.57616 .7307 Mdot
.59967 .17857 Mdot
.76656 .66527 Mdot
.24567 .3054 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.51961 .21512 m
.53922 .20907 L
.55882 .20878 L
.57843 .21464 L
.59507 .22549 L
.59804 .22897 L
.61021 .2451 L
.61765 .26185 L
.61853 .26471 L
.62304 .28431 L
.6245 .30392 L
.62343 .32353 L
.61998 .34314 L
.61765 .35221 L
.61416 .36275 L
.6051 .38235 L
.59804 .39278 L
.59149 .40196 L
.57843 .41089 L
.55882 .41732 L
.53922 .41539 L
.51961 .40644 L
.51243 .40196 L
.5 .39021 L
.49297 .38235 L
.48039 .3628 L
.48037 .36275 L
.47195 .34314 L
.46729 .32353 L
.46602 .30392 L
.46812 .28431 L
.47403 .26471 L
.48039 .25147 L
.48458 .2451 L
.5 .22798 L
.50248 .22549 L
.51961 .21512 L
s
.51961 .16284 m
.53922 .15855 L
.55882 .15778 L
.57843 .16068 L
.59648 .16667 L
.59804 .16774 L
.61765 .18002 L
.62493 .18627 L
.63725 .20009 L
.64143 .20588 L
.65243 .22549 L
.65686 .23608 L
.65988 .2451 L
.6648 .26471 L
.66771 .28431 L
.669 .30392 L
.66892 .32353 L
.6677 .34314 L
.66548 .36275 L
.6624 .38235 L
.65856 .40196 L
.65686 .40965 L
.65407 .42157 L
.64892 .44118 L
.64299 .46078 L
.63725 .47709 L
.63607 .48039 L
.62775 .5 L
.61765 .51517 L
.61366 .51961 L
.59804 .52893 L
.57843 .52845 L
.55882 .52052 L
.55673 .51961 L
.53922 .50833 L
.52747 .5 L
.51961 .49318 L
.50502 .48039 L
.5 .47541 L
.48576 .46078 L
.48039 .45466 L
.46922 .44118 L
.46078 .42975 L
.4552 .42157 L
.44355 .40196 L
.44118 .39742 L
.43418 .38235 L
.42706 .36275 L
.42214 .34314 L
.42157 .34005 L
Mistroke
.4194 .32353 L
.41888 .30392 L
.42066 .28431 L
.42157 .27747 L
.42487 .26471 L
.43178 .2451 L
.44118 .22662 L
.44187 .22549 L
.45596 .20588 L
.46078 .20045 L
.47602 .18627 L
.48039 .18293 L
.5 .17079 L
.50824 .16667 L
.51961 .16284 L
Mfstroke
.51961 .12281 m
.53922 .11923 L
.55882 .11831 L
.57843 .12013 L
.59804 .12494 L
.60539 .12745 L
.61765 .13316 L
.63725 .14561 L
.63914 .14706 L
.65686 .16382 L
.65934 .16667 L
.67347 .18627 L
.67647 .19138 L
.68379 .20588 L
.69139 .22549 L
.69608 .24168 L
.69689 .2451 L
.70075 .26471 L
.70325 .28431 L
.70466 .30392 L
.70518 .32353 L
.70503 .34314 L
.70438 .36275 L
.70344 .38235 L
.70239 .40196 L
.70143 .42157 L
.70077 .44118 L
.70063 .46078 L
.70118 .48039 L
.70259 .5 L
.70491 .51961 L
.70809 .53922 L
.71187 .55882 L
.71569 .57788 L
.71579 .57843 L
.71933 .59804 L
.72172 .61765 L
.72218 .63725 L
.7198 .65686 L
.71569 .67227 L
.71341 .67647 L
.70058 .69608 L
.69608 .70057 L
.67647 .7135 L
.67084 .71569 L
.65686 .71908 L
.63725 .71927 L
.62104 .71569 L
.61765 .71452 L
.59804 .70458 L
Mistroke
.5863 .69608 L
.57843 .6886 L
.56722 .67647 L
.55882 .66546 L
.55276 .65686 L
.54046 .63725 L
.53922 .63513 L
.52901 .61765 L
.51961 .6012 L
.51777 .59804 L
.50606 .57843 L
.5 .5686 L
.49375 .55882 L
.4808 .53922 L
.48039 .53861 L
.46737 .51961 L
.46078 .51002 L
.45389 .5 L
.44118 .48102 L
.44076 .48039 L
.42833 .46078 L
.42157 .44937 L
.41695 .44118 L
.40685 .42157 L
.40196 .41092 L
.39821 .40196 L
.39113 .38235 L
.3857 .36275 L
.38235 .346 L
.38197 .34314 L
.37999 .32353 L
.37981 .30392 L
.3815 .28431 L
.38235 .27752 L
.38516 .26471 L
.3909 .2451 L
.39896 .22549 L
.40196 .21938 L
.40963 .20588 L
.42157 .18869 L
.42348 .18627 L
.44118 .16697 L
.4415 .16667 L
.46078 .15062 L
.46583 .14706 L
.48039 .13822 L
.5 .12908 L
.50392 .12745 L
.51961 .12281 L
Mfstroke
.51961 .08702 m
.53922 .08389 L
.55882 .08292 L
.57843 .08418 L
.59804 .0878 L
.59987 .08824 L
.61765 .09402 L
.63725 .10325 L
.64505 .10784 L
.65686 .11611 L
.67016 .12745 L
.67647 .13378 L
.68787 .14706 L
.69608 .15852 L
.70117 .16667 L
.71141 .18627 L
.71569 .19621 L
.71932 .20588 L
.72539 .22549 L
.72997 .2451 L
.73335 .26471 L
.73529 .27995 L
.73574 .28431 L
.73736 .30392 L
.73841 .32353 L
.73907 .34314 L
.73955 .36275 L
.74003 .38235 L
.74072 .40196 L
.74181 .42157 L
.74351 .44118 L
.74596 .46078 L
.74927 .48039 L
.75348 .5 L
.7549 .50587 L
.75849 .51961 L
.76409 .53922 L
.76991 .55882 L
.77451 .57477 L
.77551 .57843 L
.78044 .59804 L
.78424 .61765 L
.78647 .63725 L
.78677 .65686 L
.78476 .67647 L
.78002 .69608 L
.77451 .71068 L
.77199 .71569 L
.75978 .73529 L
.7549 .74141 L
Mistroke
.74161 .7549 L
.73529 .76011 L
.71569 .77279 L
.71251 .77451 L
.69608 .78136 L
.67647 .78665 L
.65686 .78905 L
.63725 .78872 L
.61765 .78566 L
.59804 .77969 L
.5859 .77451 L
.57843 .77049 L
.55882 .75747 L
.55557 .7549 L
.53922 .73977 L
.53504 .73529 L
.51961 .71608 L
.51932 .71569 L
.50643 .69608 L
.5 .68497 L
.49535 .67647 L
.48534 .65686 L
.48039 .64668 L
.47587 .63725 L
.46653 .61765 L
.46078 .60575 L
.45699 .59804 L
.44706 .57843 L
.44118 .56722 L
.43667 .55882 L
.42584 .53922 L
.42157 .53161 L
.41477 .51961 L
.40369 .5 L
.40196 .49691 L
.39288 .48039 L
.38265 .46078 L
.38235 .4602 L
.37322 .44118 L
.36481 .42157 L
.36275 .41631 L
.35759 .40196 L
.35167 .38235 L
.34715 .36275 L
.3441 .34314 L
.34314 .3333 L
.34257 .32353 L
.34261 .30392 L
.34314 .29529 L
.34427 .28431 L
Mistroke
.34764 .26471 L
.35279 .2451 L
.35984 .22549 L
.36275 .21867 L
.36896 .20588 L
.38041 .18627 L
.38235 .18333 L
.39459 .16667 L
.40196 .15791 L
.41216 .14706 L
.42157 .13815 L
.43439 .12745 L
.44118 .12239 L
.46078 .10977 L
.4642 .10784 L
.48039 .09984 L
.5 .09231 L
.5139 .08824 L
.51961 .08702 L
Mfstroke
.55882 .04881 m
.56831 .04902 L
.57843 .04973 L
.59804 .0526 L
.61765 .05759 L
.63725 .06492 L
.64525 .06863 L
.65686 .07495 L
.67647 .08821 L
.67651 .08824 L
.69608 .1056 L
.69825 .10784 L
.71473 .12745 L
.71569 .12876 L
.72765 .14706 L
.73529 .16117 L
.73794 .16667 L
.74617 .18627 L
.75273 .20588 L
.7549 .21349 L
.75792 .22549 L
.76198 .2451 L
.76514 .26471 L
.76758 .28431 L
.76949 .30392 L
.77106 .32353 L
.77248 .34314 L
.77392 .36275 L
.77451 .36998 L
.7756 .38235 L
.77769 .40196 L
.78037 .42157 L
.78379 .44118 L
.78804 .46078 L
.79314 .48039 L
.79412 .48383 L
.79901 .5 L
.80545 .51961 L
.81215 .53922 L
.81373 .54379 L
.81877 .55882 L
.82491 .57843 L
.83018 .59804 L
.83333 .61216 L
.83429 .61765 L
.83694 .63725 L
.83791 .65686 L
.83701 .67647 L
.83402 .69608 L
.83333 .6995 L
Mistroke
.82872 .71569 L
.8208 .73529 L
.81373 .74862 L
.80979 .7549 L
.79499 .77451 L
.79412 .77551 L
.77508 .79412 L
.77451 .7946 L
.7549 .80899 L
.74713 .81373 L
.73529 .81997 L
.71569 .82824 L
.69948 .83333 L
.69608 .83417 L
.67647 .83799 L
.65686 .8398 L
.63725 .83966 L
.61765 .83752 L
.5981 .83333 L
.59804 .83331 L
.57843 .82687 L
.55882 .81792 L
.55121 .81373 L
.53922 .80611 L
.52341 .79412 L
.51961 .79085 L
.50288 .77451 L
.5 .77132 L
.48658 .7549 L
.48039 .74634 L
.47306 .73529 L
.46147 .71569 L
.46078 .71443 L
.45122 .69608 L
.44186 .67647 L
.44118 .67499 L
.433 .65686 L
.42434 .63725 L
.42157 .63098 L
.41563 .61765 L
.40669 .59804 L
.40196 .58795 L
.39742 .57843 L
.38779 .55882 L
.38235 .54799 L
.3779 .53922 L
.36788 .51961 L
.36275 .50951 L
.35795 .5 L
.34833 .48039 L
Mistroke
.34314 .46937 L
.33924 .46078 L
.33089 .44118 L
.32353 .42177 L
.32346 .42157 L
.31709 .40196 L
.31188 .38235 L
.30794 .36275 L
.30532 .34314 L
.30408 .32353 L
.30427 .30392 L
.30594 .28431 L
.30914 .26471 L
.31393 .2451 L
.32038 .22549 L
.32353 .2174 L
.3286 .20588 L
.33874 .18627 L
.34314 .1788 L
.351 .16667 L
.36275 .1507 L
.36568 .14706 L
.38235 .12841 L
.38329 .12745 L
.40196 .1101 L
.40465 .10784 L
.42157 .09489 L
.43142 .08824 L
.44118 .08225 L
.46078 .07187 L
.46782 .06863 L
.48039 .06353 L
.5 .05711 L
.51961 .05253 L
.53922 .04976 L
.5499 .04902 L
.55882 .04881 L
Mfstroke
.48039 .02701 m
.5 .02147 L
.51961 .01748 L
.53922 .01503 L
.55882 .01414 L
.57843 .01484 L
.59804 .01721 L
.61765 .02134 L
.63725 .02739 L
.64269 .02941 L
.65686 .03556 L
.67647 .04617 L
.68103 .04902 L
.69608 .05965 L
.70697 .06863 L
.71569 .07673 L
.72663 .08824 L
.73529 .0986 L
.74222 .10784 L
.75486 .12745 L
.7549 .12752 L
.7652 .14706 L
.77368 .16667 L
.77451 .16881 L
.78063 .18627 L
.78632 .20588 L
.79095 .22549 L
.79412 .24163 L
.79473 .2451 L
.79783 .26471 L
.80044 .28431 L
.80272 .30392 L
.80486 .32353 L
.80705 .34314 L
.80945 .36275 L
.81226 .38235 L
.81373 .39128 L
.81565 .40196 L
.81973 .42157 L
.82462 .44118 L
.83032 .46078 L
.83333 .4702 L
.83677 .48039 L
.84378 .5 L
.8511 .51961 L
.85294 .52451 L
.8584 .53922 L
.86534 .55882 L
.8716 .57843 L
.87255 .58161 L
Mistroke
.8769 .59804 L
.881 .61765 L
.88374 .63725 L
.88496 .65686 L
.88456 .67647 L
.8824 .69608 L
.87836 .71569 L
.87255 .73462 L
.87229 .73529 L
.86399 .7549 L
.85315 .77451 L
.85294 .77484 L
.83935 .79412 L
.83333 .80143 L
.82192 .81373 L
.81373 .82153 L
.79965 .83333 L
.79412 .83749 L
.77451 .85038 L
.77008 .85294 L
.7549 .86081 L
.73529 .86915 L
.72579 .87255 L
.71569 .87564 L
.69608 .88042 L
.67647 .88358 L
.65686 .88519 L
.63725 .88524 L
.61765 .88371 L
.59804 .88056 L
.57843 .87568 L
.5685 .87255 L
.55882 .86895 L
.53922 .86016 L
.52598 .85294 L
.51961 .84904 L
.5 .83522 L
.49762 .83333 L
.48039 .81816 L
.4759 .81373 L
.46078 .7971 L
.45832 .79412 L
.44359 .77451 L
.44118 .77097 L
.43095 .7549 L
.42157 .73848 L
.41985 .73529 L
.40988 .71569 L
.40196 .69885 L
.4007 .69608 L
Mistroke
.39202 .67647 L
.38359 .65686 L
.38235 .65398 L
.37519 .63725 L
.36667 .61765 L
.36275 .60879 L
.35791 .59804 L
.34887 .57843 L
.34314 .5663 L
.33957 .55882 L
.3301 .53922 L
.32353 .52566 L
.32061 .51961 L
.31127 .5 L
.30392 .48404 L
.30229 .48039 L
.29384 .46078 L
.28612 .44118 L
.28431 .43629 L
.27926 .42157 L
.2734 .40196 L
.26864 .38235 L
.26505 .36275 L
.26471 .36114 L
.26271 .34314 L
.26167 .32353 L
.26196 .30392 L
.26364 .28431 L
.26471 .27568 L
.26674 .26471 L
.2713 .2451 L
.27738 .22549 L
.28431 .20758 L
.28505 .20588 L
.29439 .18627 L
.30392 .16928 L
.30551 .16667 L
.3186 .14706 L
.32353 .14038 L
.33387 .12745 L
.34314 .11687 L
.3517 .10784 L
.36275 .09711 L
.37268 .08824 L
.38235 .08024 L
.39784 .06863 L
.40196 .06577 L
.42157 .05339 L
.42932 .04902 L
.44118 .04289 L
Mistroke
.46078 .03413 L
.47321 .02941 L
.48039 .02701 L
Mfstroke
.68771 .0098 m
.69608 .01477 L
.71569 .02824 L
.71722 .02941 L
.73529 .0448 L
.7397 .04902 L
.7549 .06531 L
.75769 .06863 L
.77247 .08824 L
.77451 .09125 L
.78476 .10784 L
.79412 .12554 L
.79504 .12745 L
.80367 .14706 L
.81091 .16667 L
.81373 .17533 L
.81698 .18627 L
.82207 .20588 L
.82637 .22549 L
.83003 .2451 L
.83323 .26471 L
.83333 .26541 L
.83612 .28431 L
.83888 .30392 L
.8417 .32353 L
.84473 .34314 L
.84817 .36275 L
.85216 .38235 L
.85294 .38587 L
.85683 .40196 L
.86227 .42157 L
.86849 .44118 L
.87255 .45285 L
.87544 .46078 L
.88293 .48039 L
.89075 .5 L
.89216 .5035 L
.89859 .51961 L
.90614 .53922 L
.91176 .55484 L
.91312 .55882 L
.91927 .57843 L
.9244 .59804 L
.92835 .61765 L
.93102 .63725 L
.93137 .64095 L
.93232 .65686 L
.93216 .67647 L
.93137 .68798 L
.9305 .69608 L
Mistroke
.92724 .71569 L
.9223 .73529 L
.91556 .7549 L
.91176 .7641 L
.90689 .77451 L
.89606 .79412 L
.89216 .80031 L
.88279 .81373 L
.87255 .82662 L
.86667 .83333 L
.85294 .84746 L
.84705 .85294 L
.83333 .86457 L
.82283 .87255 L
.81373 .87888 L
.79412 .89091 L
.79189 .89216 L
.77451 .90102 L
.7549 .90943 L
.74874 .91176 L
.73529 .91631 L
.71569 .92176 L
.69608 .92585 L
.67647 .92864 L
.65686 .93015 L
.63725 .93037 L
.61765 .9293 L
.59804 .92689 L
.57843 .92308 L
.55882 .9178 L
.54133 .91176 L
.53922 .91094 L
.51961 .90234 L
.50058 .89216 L
.5 .89181 L
.48039 .8791 L
.47153 .87255 L
.46078 .86385 L
.44865 .85294 L
.44118 .84559 L
.42977 .83333 L
.42157 .82366 L
.41376 .81373 L
.40196 .7972 L
.3999 .79412 L
.3877 .77451 L
.38235 .76516 L
.37678 .7549 L
.36682 .73529 L
.36275 .72681 L
Mistroke
.35756 .71569 L
.34878 .69608 L
.34314 .68316 L
.34024 .67647 L
.33179 .65686 L
.32353 .63786 L
.32326 .63725 L
.31456 .61765 L
.30561 .59804 L
.30392 .59441 L
.29642 .57843 L
.28703 .55882 L
.28431 .55319 L
.27757 .53922 L
.26815 .51961 L
.26471 .51233 L
.25896 .5 L
.25018 .48039 L
.2451 .46846 L
.24196 .46078 L
.23448 .44118 L
.22786 .42157 L
.22549 .41383 L
.22221 .40196 L
.21764 .38235 L
.21422 .36275 L
.212 .34314 L
.21104 .32353 L
.21137 .30392 L
.21304 .28431 L
.21608 .26471 L
.22052 .2451 L
.22549 .22816 L
.22639 .22549 L
.23375 .20588 L
.24264 .18627 L
.2451 .18137 L
.25312 .16667 L
.26471 .14795 L
.2653 .14706 L
.27929 .12745 L
.28431 .121 L
.29527 .10784 L
.30392 .09821 L
.3135 .08824 L
.32353 .07847 L
.33438 .06863 L
.34314 .06118 L
.35858 .04902 L
.36275 .04594 L
Mistroke
.38235 .03252 L
.38728 .02941 L
.40196 .02075 L
.42157 .0105 L
.423 .0098 L
Mfstroke
.75855 .0098 m
.77451 .02545 L
.77818 .02941 L
.79412 .04845 L
.79456 .04902 L
.80839 .06863 L
.81373 .07712 L
.82017 .08824 L
.83023 .10784 L
.83333 .11455 L
.83884 .12745 L
.84622 .14706 L
.85255 .16667 L
.85294 .16799 L
.85798 .18627 L
.8627 .20588 L
.86683 .22549 L
.87055 .2451 L
.87255 .25629 L
.87401 .26471 L
.87736 .28431 L
.88079 .30392 L
.88445 .32353 L
.88852 .34314 L
.89216 .35876 L
.89314 .36275 L
.89844 .38235 L
.90448 .40196 L
.91128 .42157 L
.91176 .4229 L
.91875 .44118 L
.92674 .46078 L
.93137 .4718 L
.93502 .48039 L
.94332 .5 L
.95098 .51867 L
.95135 .51961 L
.95886 .53922 L
.96564 .55882 L
.97059 .57512 L
.9715 .57843 L
.97633 .59804 L
.98003 .61765 L
.98254 .63725 L
.9838 .65686 L
.98378 .67647 L
.98244 .69608 L
.97974 .71569 L
.97561 .73529 L
.97059 .75309 L
Mistroke
.96999 .7549 L
.96281 .77451 L
.95394 .79412 L
.95098 .79992 L
.94324 .81373 L
.93137 .83211 L
.93051 .83333 L
.91548 .85294 L
.91176 .85733 L
.89777 .87255 L
.89216 .87814 L
.8768 .89216 L
.87255 .89574 L
.85294 .91085 L
.85166 .91176 L
.83333 .92391 L
.82073 .93137 L
.81373 .93522 L
.79412 .94498 L
.78039 .95098 L
.77451 .95335 L
.7549 .96043 L
.73529 .9663 L
.71777 .97059 L
.71569 .97103 L
.69608 .97465 L
.67647 .97719 L
.65686 .97864 L
.63725 .97902 L
.61765 .97831 L
.59804 .97648 L
.57843 .97349 L
.56415 .97059 L
.55882 .9693 L
.53922 .96384 L
.51961 .95703 L
.50492 .95098 L
.5 .94875 L
.48039 .93887 L
.46741 .93137 L
.46078 .92722 L
.44118 .91358 L
.43879 .91176 L
.42157 .89764 L
.41546 .89216 L
.40196 .87905 L
.39577 .87255 L
.38235 .85731 L
.37876 .85294 L
.36383 .83333 L
Mistroke
.36275 .83181 L
.35054 .81373 L
.34314 .80184 L
.33856 .79412 L
.32759 .77451 L
.32353 .76684 L
.31742 .7549 L
.30781 .73529 L
.30392 .72709 L
.29859 .71569 L
.28958 .69608 L
.28431 .68456 L
.28061 .67647 L
.27156 .65686 L
.26471 .64227 L
.26232 .63725 L
.25284 .61765 L
.2451 .60204 L
.24309 .59804 L
.23313 .57843 L
.22549 .56361 L
.22302 .55882 L
.2129 .53922 L
.20588 .52548 L
.20292 .51961 L
.19325 .5 L
.18627 .48523 L
.18406 .48039 L
.17553 .46078 L
.16777 .44118 L
.16667 .4382 L
.16094 .42157 L
.15512 .40196 L
.1504 .38235 L
.14706 .36416 L
.14685 .36275 L
.14453 .34314 L
.14348 .32353 L
.14373 .30392 L
.14532 .28431 L
.14706 .27095 L
.14828 .26471 L
.15263 .2451 L
.15841 .22549 L
.16565 .20588 L
.16667 .2034 L
.17438 .18627 L
.18464 .16667 L
.18627 .16379 L
.19648 .14706 L
Mistroke
.20588 .13311 L
.20995 .12745 L
.22513 .10784 L
.22549 .10741 L
.24215 .08824 L
.2451 .08505 L
.26115 .06863 L
.26471 .06519 L
.28239 .04902 L
.28431 .04735 L
.30392 .03122 L
.30625 .02941 L
.32353 .01661 L
.33337 .0098 L
Mfstroke
.9902 .8525 m
.98991 .85294 L
.97614 .87255 L
.97059 .87975 L
.96032 .89216 L
.95098 .90258 L
.94215 .91176 L
.93137 .92221 L
.9212 .93137 L
.91176 .93933 L
.89683 .95098 L
.89216 .95441 L
.87255 .96775 L
.86805 .97059 L
.85294 .97958 L
.83333 .99005 L
.83304 .9902 L
s
.9902 .45982 m
.98187 .44118 L
.97329 .42157 L
.97059 .41522 L
.96513 .40196 L
.95759 .38235 L
.95098 .36345 L
.95075 .36275 L
.94462 .34314 L
.93919 .32353 L
.93433 .30392 L
.93137 .29092 L
.92992 .28431 L
.9258 .26471 L
.9218 .2451 L
.91778 .22549 L
.91358 .20588 L
.91176 .19785 L
.90903 .18627 L
.90399 .16667 L
.89834 .14706 L
.89216 .12808 L
.89194 .12745 L
.88462 .10784 L
.87626 .08824 L
.87255 .08031 L
.86668 .06863 L
.8557 .04902 L
.85294 .04448 L
.84308 .02941 L
.83333 .01595 L
.82854 .0098 L
s
.44766 .9902 m
.44118 .98658 L
.42157 .9746 L
.41555 .97059 L
.40196 .96091 L
.38917 .95098 L
.38235 .94533 L
.3667 .93137 L
.36275 .92761 L
.34712 .91176 L
.34314 .90745 L
.32978 .89216 L
.32353 .88453 L
.31421 .87255 L
.30392 .85846 L
.30007 .85294 L
.28708 .83333 L
.28431 .82897 L
.275 .81373 L
.26471 .79602 L
.26363 .79412 L
.25278 .77451 L
.2451 .76023 L
.24227 .7549 L
.23193 .73529 L
.22549 .72304 L
.22162 .71569 L
.21118 .69608 L
.20588 .68629 L
.20051 .67647 L
.18951 .65686 L
.18627 .65122 L
.17814 .63725 L
.16667 .61807 L
.16641 .61765 L
.15437 .59804 L
.14706 .5863 L
.14214 .57843 L
.12986 .55882 L
.12745 .55496 L
.11773 .53922 L
.10784 .5228 L
.10596 .51961 L
.09473 .5 L
.08824 .48806 L
.08423 .48039 L
.07461 .46078 L
.06863 .44744 L
.066 .44118 L
.05847 .42157 L
Mistroke
.0521 .40196 L
.04902 .39094 L
.04693 .38235 L
.043 .36275 L
.04033 .34314 L
.03894 .32353 L
.03885 .30392 L
.04008 .28431 L
.04266 .26471 L
.04661 .2451 L
.04902 .23555 L
.05199 .22549 L
.05882 .20588 L
.06717 .18627 L
.06863 .18318 L
.07709 .16667 L
.08824 .1477 L
.08864 .14706 L
.10189 .12745 L
.10784 .1194 L
.11691 .10784 L
.12745 .09532 L
.13375 .08824 L
.14706 .0741 L
.15248 .06863 L
.16667 .05498 L
.17317 .04902 L
.18627 .0375 L
.1959 .02941 L
.20588 .02134 L
.22081 .0098 L
Mfstroke
.9902 .98553 m
.98495 .9902 L
s
.0098 .63361 m
.01299 .63725 L
.02941 .65591 L
.03025 .65686 L
.0475 .67647 L
.04902 .67821 L
.06443 .69608 L
.06863 .70103 L
.08084 .71569 L
.08824 .72479 L
.0966 .73529 L
.10784 .74983 L
.11169 .7549 L
.12619 .77451 L
.12745 .77625 L
.14023 .79412 L
.14706 .80385 L
.15395 .81373 L
.16667 .83207 L
.16754 .83333 L
.18119 .85294 L
.18627 .86018 L
.19508 .87255 L
.20588 .88741 L
.20941 .89216 L
.22437 .91176 L
.22549 .9132 L
.24019 .93137 L
.2451 .93721 L
.2571 .95098 L
.26471 .95934 L
.27538 .97059 L
.28431 .97959 L
.29538 .9902 L
s
.9902 .1985 m
.9872 .18627 L
.98222 .16667 L
.97693 .14706 L
.97121 .12745 L
.97059 .12544 L
.96493 .10784 L
.958 .08824 L
.95098 .07028 L
.95029 .06863 L
.94166 .04902 L
.93202 .02941 L
.93137 .02817 L
.92119 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
o`000=7ooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0coooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`3?ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo0<oooooo0009ooooo`03o`000?oooooooooo02Gooooo0P00
000Booooo`8000003_ooool00`00003o0000ooooo`0Dooooo`D000005?ooool00ol0003ooooooooo
o`09ooooo`8000002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo8olI6AT00`000000<c<c03<c
<`0@03<c<`8000003P1<C4`200000100IVIV1`00000507moO`L000003P1VIVH2000000/0C4a<00<0
000003<c<`0c<c<02@0c<c<00ol0003o6ATIoaTI6@0<oaTI6@co00001?ooool00ol0003ooooooooo
o`3?ooooo`002Oooool01?l0003ooooooooooooooolRoaTI6@030000000c<c<0<c<c0100<c<c00<0
000004a<C01<C4`0301<C4`2000000l0IVIV0`00000C07moO`<000003@1VIVH2000000X0C4a<00?o
000003<c<`0c<c<0200c<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00001?ooool00ol0003ooooooooo
o`3?ooooo`002Oooool01?l0003ooooooooooooooolQoaTI6@03o`00000c<c<0<c<c00l0<c<c0P00
000=04a<C08000003@1VIVH01000003o0000o`000000000I07moO`0400000?l000000000000000/0
IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0803<c<`03o`000?lI6AWo6ATI00go
6ATI2_l00004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooob3o
6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00<04a<C00300000?l00000IVIV00X0
IVIV0`00000Q07moO`8000002P1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00L0
<c<c00?o0000oaTI6OlI6AT03OlI6AT:o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo
00Co0000oooooooooooooooo7olI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00/0
C4a<0P00000;06IVIP8000009P1oOgl2000000T0IVIV00<0000004a<C01<C4`0201<C4`00`000000
<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00go6ATI2Ol00004ooooo`03o`000?oooooooooo0<oo
oooo0009ooooo`04o`000?oooooooooooooooako6ATI00<0000003<c<`0c<c<03`0c<c<00`000000
C4a<04a<C00;04a<C0030000001VIVH0IVIV00X0IVIV00<0000007moO`1oOgl0:01oOgl00ol00000
IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00P0C4a<00?o000003<c<`0c<c<01`0c<c<00ol0003o
6ATIoaTI6@0<oaTI6@Wo00001?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooo
oooooooooolLoaTI6@8000004@0c<c<00`00003o000004a<C00;04a<C003o`00001VIVH0IVIV00P0
IVIV00<00000o`00000000003@1oOgl;00000003o`0000000000000000D00000301oOgl2000000P0
IVIV0P00000804a<C0030000000c<c<0<c<c00P0<c<c00?o0000oaTI6OlI6AT03?lI6AT8o`0000Co
oooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo6olI6AT00`000000
<c<c03<c<`0@03<c<`030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH0201VIVH00`000000
Ogmo07moO`0;07moO`<000004`2IVIT3000000/0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000
C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00?o0000oaTI6OlI6AT03?lI6AT8o`0000Co
oooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo6_lI6AT00`000000
<c<c03<c<`0@03<c<`030000001<C4`0C4a<00X0C4a<0P00000:06IVIP030000001oOgl0Ogmo00T0
Ogmo0`00000I09VIV@0300000?l00000Ogmo00T0Ogmo00<0000006IVIP1VIVH01`1VIVH00ol00000
C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00?o0000oaTI6OlI6AT03?lI6AT7o`0000Co
oooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo6OlI6AT00`000000
<c<c03<c<`0@03<c<`03o`00001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH0201VIVH00ol00000
000007moO`0:07moO`030000002IVIT0VIVI01`0VIVI0P00000907moO`8000001`1VIVH00`000000
C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00?o0000oaTI6OlI6AT03?lI6AT7o`0000Co
oooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo6?lI6AT00ol00000
<c<c03<c<`0@03<c<`030000001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH0201VIVH00`000000
Ogmo07moO`0807moO`80000000?o000009VIV@2IVIT07`2IVIT2000000T0Ogmo00<0000006IVIP1V
IVH0101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00?o0000oaTI6OlI
6AT03?lI6AT7o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooo
oooo6?lI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00X0C4a<00<0000006IVIP1V
IVH0201VIVH00`000000Ogmo07moO`0707moO`8000009P2IVIT00`000000Ogmo07moO`0607moO`03
0000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`03
o`000?lI6AWo6ATI00co6ATI1_l00004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`00
0?oooooooooooooooaOo6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00:04a<C003
0000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0<09VIV@03
o`0000000000000000/0000000?o000009VIV@2IVIT02P2IVIT00`00003o000007moO`0607moO`03
0000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`03
o`000?lI6AWo6ATI00co6ATI1_l00004ooooo`03o`000?oooooooooo08_ooooo0_l00012ooooo`00
2Oooool01?l0003ooooooooooooooolEoaTI6@8000004P0c<c<00ol00000C4a<04a<C00904a<C003
0000001VIVH0IVIV00L0IVIV0P00000907moO`030000002IVIT0VIVI00P0VIVI100000000ol00000
/k>c0;>c/`0<0;>c/`<000002`2IVIT00`000000Ogmo07moO`0607moO`03o`00001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00co
6ATI1Ol00004ooooo`03o`000?oooooooooo08Sooooo0ol000000ooooooo0000ooooo`11ooooo`00
2Oooool01?l0003ooooooooooooooolDoaTI6@030000000c<c<0<c<c0140<c<c00<0000004a<C01<
C4`02@1<C4`00ol00000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<00000o`00002I
VIT02@2IVIT00`000000/k>c0;>c/`0D0;>c/`<000002@2IVIT00`000000Ogmo07moO`0607moO`03
0000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`03
o`000?lI6AWo6ATI00co6ATI1Ol00004ooooo`03o`000?oooooooooo08Kooooo0_l00004ooooo`;o
0000@Oooool000Wooooo00Co0000oooooooooooooooo5?lI6AT00`000000<c<c03<c<`0@03<c<`03
0000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`03
0000002IVIT0VIVI00P0VIVI0P00000J0;>c/`0300000?l00000VIVI00L0VIVI00<0000007moO`1o
Ogl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c
<c<01`0c<c<00ol0003o6ATIoaTI6@0<oaTI6@Co00001?ooool00ol0003oooooooooo`23ooooo`?o
00001Oooool01?nf_=ko0000ooooool00010ooooo`002Oooool01?l0003ooooooooooooooolCoaTI
6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0706IV
IP030000001oOgl0Ogmo00H0Ogmo00?o00000000002IVIT01`2IVIT3000001h0/k>c0P00000709VI
V@03o`0000000000Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<
C003o`00000c<c<0<c<c00L0<c<c00?o0000oaTI6OlI6AT02olI6AT4o`0000Cooooo00?o0000oooo
ooooool0P?ooool3o`0000Oooooo0_nf_=h00ol0003oooooo`000010ooooo`002Oooool01?l0003o
oooooooooooooolBoaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`00
0000IVIV06IVIP0806IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01`2IVIT00`00
0000/k>c0;>c/`0Q0;>c/`8000001`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI
00_o6ATI1?l00004ooooo`03o`000?oooooooooo07kooooo0_l00008ooooo`05okNkg?nf_=ko][cN
okJlg_l000000_ooool00ol0003oooooooooo`0mooooo`002Oooool01?l0003ooooooooooooooolA
oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP07
06IVIP8000001`1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00`0/k>c2`00000=
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c<c<00ol0003o6ATIoaTI6@0;
oaTI6@?o00001?ooool00ol0003oooooooooo`1kooooo`?o00002?ooool02?ni^][o]k_LokNkg?ng
^mco][cNokNlgOl0003o]kcM0_ooool00ol0003oooooooooo`0looooo`002Oooool01?l0003ooooo
ooooooooool@oaTI6@03o`00000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00ol00000
IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00ol00000
00000;>c/`090;>c/`D000002`3<c<`01000003o000000000000000:0;>c/`030000002IVIT0VIVI
00D0VIVI00?o000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<
00D0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@0;oaTI6@?o00001?ooool00ol0
003oooooooooo`1iooooo`;o00002_ooool3okVjfP09okNkg?ni^m_o^K_KokNlgOl0003o]kcMokRl
gOoooooo000003kooooo0009ooooo`04o`000?oooooooooooooooa3o6ATI00<0000003<c<`0c<c<0
3`0c<c<00ol00000C4a<04a<C00:04a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0
1P1oOgl00ol00000VIVI09VIV@0509VIV@030000002c/k<0/k>c00P0/k>c00<00000o`00003<c<`0
4`3<c<`2000000P0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000
001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`03o`00
0?lI6AWo6ATI00_o6ATI0ol00004ooooo`03o`000?oooooooooo07Kooooo0ol0000:ooooo`05okZi
f?ni^][o^K[JokVjf_nj^]T01?ni^m/01_l0003o^;cMokRlgOnh_=goooooo`0003gooooo0009oooo
o`04o`000?ooooooooooooooo`oo6ATI00<0000003<c<`0c<c<0400c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@05
09VIV@030000002c/k<0/k>c00H0/k>c0`00000H0<c<c0030000002c/k<0/k>c00H0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00_o6ATI0ol00004
ooooo`03o`000?oooooooooo07Cooooo0_l0000;ooooo`Co^[WH00Co^K[JokZjfOnj^]Wo^[[I0_ni
^m/01onj_=_o0000okRlgOnh_=go^KgLooooool00000?Oooool000Wooooo00Co0000oooooooooooo
oooo3olI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00X0C4a<00<0000006IVIP1V
IVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c
/k<01P2c/k<00`000000c<c<0<c<c00J0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00_o6ATI0_l00004ooooo`03
o`000?oooooooooo077ooooo0ol0000<ooooo`;o_;OE0onj^MP3okZjf@06okbkf?nj_=_o^[cKokZl
fol0003o^;cM0oni_M`00ooooooo0000ooooo`0kooooo`002Oooool01?l0003oooooooooooooool>
oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP06
06IVIP03o`00001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`06
0;>c/`030000003<c<`0c<c<01`0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@04
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C005
04a<C0030000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI6AT02olI6AT2o`0000Cooooo00?o0000
ooooooooool0K_ooool3o`0000gooooo00?o_KGBokbgeOnl]mD00_nl]mD01?nj^MSo_;WGokbieonj
^]T3okbkf0;o^[cK00Go0000okVmg?ni_Mco^KgLok^ng002ooooo`03o`000?oooooooooo03Wooooo
0009ooooo`04o`000?ooooooooooooooo`ko6ATI00<0000003<c<`0c<c<0400c<c<00`000000C4a<
04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00ol00000VIVI
09VIV@0509VIV@030000002c/k<0/k>c00H0/k>c00<00000o`00003<c<`07P3<c<`00`000000/k>c
0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0003o6ATI
oaTI6@0;oaTI6@;o00001?ooool00ol0003oooooooooo`1/ooooo`;o00003oooool3okfedP;o_;OE
00Go_KSDokbieonl^MOo_;WGokjjeP03okbkf005okZlfonk_=[o^kcJo`000?ni_M`00onk_]`00ooo
oooo0000ooooo`0jooooo`002Oooool01?l0003oooooooooooooool=oaTI6@030000000c<c<0<c<c
0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo
00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`8000003@3<c<`;0000
00X0c<c<00<000000;>c/`2c/k<01@2c/k<00ol00000VIVI09VIV@0409VIV@03o`00001oOgl0Ogmo
00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c
00H0<c<c00?o0000oaTI6OlI6AT02olI6AT00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
06Wooooo0ol0000?ooooo`05okjcd?nm]M;o_KGBokfed_no]]401?nm^=@01Onl^MOo_[[Fokjje_nn
^]Ko_;_H00;o_[cH0_nk_=X01Ol0003o^kkLok^ng?nk_]co_;kL00;ooooo00?o0000ooooooooool0
>?ooool000Wooooo00Co0000oooooooooooooooo3?lI6AT00`000000<c<c03<c<`0@03<c<`030000
001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00D0VIVI00?o00000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0080<c<c0Co0000
00<000000>KViP3Vi^H02@3Vi^H00`00003o00000<c<c0080<c<c003o`0000000000/k>c00D0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`03o`00001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00_o6ATI
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Wooooo`;o00004Oooool3okjcd004okfe
d_no]]7o_kKAoknfd@;o_KSD00Go_kSCokjje_nn^]Ko_[[Fol2ke@04okjlf004ok^lf_l0003o_KgJ
ok^ng0?o_;kL0_ooool00ol0003oooooooooo`0gooooo`002Oooool01?l0003oooooooooooooool<
oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP06
06IVIP03o`00001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`05
0;>c/`030000003<c<`0c<c<00H0c<c<0_l0000A0>KViP8000002@3<c<`00`000000/k>c0;>c/`04
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@0;
oaTI6@03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool3o`0001;ooooo00Co_[7=
okjcd?nn/m3o_[?@1?no]]401Onm^=Co_kSCoknhdono^=?o_[[F00?o`;_E0_nn_=P01Ono_=Oo_KgJ
o`000?nm_M[o_[kI00?o_;kL0_ooool00ol0003oooooooooo`0gooooo`002Oooool01?l0003ooooo
ooooooooool;oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000
IVIV06IVIP0706IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000
/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00?o00000>KViP3Vi^H04`3Vi^H00`000000
c<c<0<c<c0070<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00_o6ATI00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Rooooo`;o00005?ooool3okjac@03okjcd?o0]<ko`;C>00?o_kKA00Co`KO@oknhdono
^=?o_kSC0oo0^mD00oo1^mCo_kcGoknle`02oknle`05o`000?nn_]Wo_[kIokjnfOnl_]`00_nm_m/2
ooooo`03o`000?oooooooooo03Kooooo0009ooooo`04o`000?ooooooooooooooo`[o6ATI00<00000
03<c<`0c<c<04@0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<00000
0<c<c03<c<`01P3<c<`00ol00000i^KV0>KViP0E0>KViP8000001`3<c<`00`000000/k>c0;>c/`04
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@0;
oaTI6@05o`000?ooooooooooooooool00000HOooool3o`0001Cooooo00Go_Zo;okjacOnn/Lgo_[7=
ol2bc004ol2dcP05oknfdOo1]m3o`KO@ol6gd?no^=<00_o1^M801?o0^mGo`K_Dol6ke?o1^m@2oknl
e`05ol6meol0003o_[kIokjnfOno_]T00onm_m/01?nn_m_oooooooooool0000gooooo`002Oooool0
1?l0003oooooooooooooool:oaTI6@03o`00000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<
C4`00ol00000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0102I
VIT00ol00000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<00?o00000>KViP3Vi^H0603V
i^H00`000000c<c<0<c<c0050<c<c003o`00002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2I
VIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<
C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00_o6ATI00Go0000oooooooooooooooo
o`00001Oooooo`;o00005_ooool3okj_b`04okjacOo0//co`;;<ol2bc0;o`;C>00Go`[G=ol6gd?o1
]m3o`KO@ol>hc`03ol6idP05ol>jdOo1^mCo`K_Dol6ke?no_=L00_o1_ML00ol0003o_[kIoknnf@02
oknnf@06okfofonn_m_o_[oKokjofooooooo0000=oooool000Wooooo00Co0000oooooooooooooooo
2_lI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c0060<c<c003o`00003Vi^H0i^KV01X0i^KV00<000000<c<c03<c<`0
1@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0
0`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0
1P0c<c<00ol0003o6ATIoaTI6@0;oaTI6@05o`000?ooooooooooooooool00000G?ooool3o`0001Oo
oooo00Co_Zc8okj_bonn[l_o_Zo;1?o0//`01Oo0]<ko`[G=ol:ecOo2]Lgo`KO@00?o`kS?00Ko`KWB
ol>jdOo3^]7o`k[Aol6ke?o3_=@3ol6me`05o`000?no_]Wo_kkIoknnfOo1_mP00onn_m/01?no`=[o
ooooooooool0000fooooo`002Oooool01?l0003oooooooooooooool9oaTI6@030000000c<c<0<c<c
0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo
00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<
00H0c<c<00?o00000>KViP3Vi^H0703Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c
00@0/k>c00?o000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`03o`000?lI6AWo6ATI
00_o6ATI00Go0000ooooooooooooooooo`00001Iooooo`?o00006Oooool3okj/b003okj_boo0[lWo
`:o900?o`;;<0oo2]Ld01Oo4]/co`kS?ol>hcoo3^<ooaKW?00?o`k[A00WoaK_Aol>le?o3_=Co`kcD
ol6meoo2_]Ko0000ol:ne_no_]T00oo1_mP01?nn_m_o_l3Joko0f_no`=X2ooooo`03o`000?oooooo
oooo03?ooooo0009ooooo`04o`000?ooooooooooooooo`So6ATI00<0000003<c<`0c<c<0400c<c<0
0`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`0
0ol00000i^KV0>KViP0N0>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00`2c/k<0
0`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI6AT02_lI6AT4
ooooo`03o`000?oooooooooo05Gooooo0_l0000Jooooo`05okfYa_nn[<So_Zc8okj/b?o0[LL01?o0
[lT01?o0//co`[?;ol:cboo2]Ld3olBfc005ol>hcoo5^LooaKW?olFicoo3^]400oo5^m42ol>le004
olFmdoo2_]Ko0000ol:neP?o`KoH00?o`/3Hoko0f_no`=X00_no`=X2ooooo`03o`000?oooooooooo
03?ooooo0009ooooo`04o`000?ooooooooooooooo`So6ATI00<0000003<c<`0c<c<0400c<c<00`00
0000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00?o000007moO`1oOgl01@1oOgl00`00
0000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`00ol0
0000i^KV0>KViP0:0>KViPP00000303Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c
00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI
00[o6ATI1?ooool00ol0003oooooooooo`1Booooo`?o00006oooool3okfYaP04okj/b?o0[LOo`:g7
ol2]a`;o`:o900Co`k38ol:cboo2/l_o`[?;1?o4]/`4olFic`CoaK_A00Go`kcDolFmdoo5_M?oaKgC
o`000002olBoeP04ol6of?o2`=So`/3Hol;0f0Co_l3J0_ooool00ol0003oooooooooo`0booooo`00
2Oooool01?l0003oooooooooooooool8oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<
C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2I
VIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<00?o00000>KViP3V
i^H0203Vi^H3000000Sooooo0P00000:0>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c
/k<00`2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI
6AT02_lI6AT4ooooo`03o`000?oooooooooo053ooooo0_l0000Mooooo`Co_JW61?o0[LL01Oo0[lWo
`k38ol>`b?o3/<So`[?;00;oaKC:0oo4]/`01Oo6]lcoaKW?olFicoo5^Looak[>00;oaK_A00Koakg@
olFmdoo5_M?oaKgColJndol00002olBoeP04olG0e_o2`=So`/3Hol;0f0?o_l3J00Co`<3Joooooooo
oooo0000=?ooool000Wooooo00Co0000oooooooooooooooo1olI6AT00`000000<c<c03<c<`0@03<c
<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<
c003o`00003Vi^H0i^KV00P0i^KV00<00000ooooooooool02oooool00`000000i^KV0>KViP080>KV
iP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00L0<c<c00?o0000oaTI6OlI6AT02OlI6AT4ooooo`03o`000?oooooooooo
04gooooo0ol0000Nooooo`;o_:O40onmZLH01?noZ/Go`:g7ol2]aoo2[/H4ol>`b0CoaKC:00Goa;K<
olJgc?o6]lcoa[O<olFic`02olNjcP05olFkdOo7_M3oakg@olNmd?o5_M<00_o6_]<00ol0003oa;oF
olG0eP02olG0eP04ol;0f?o3`=So`l3Hoko0fP?o`<3J0_ooool00ol0003oooooooooo`0aooooo`00
2Oooool01?l0003oooooooooooooool7oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<
C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2I
VIT0102IVIT00ol00000/k>c0;>c/`040;>c/`03o`00003<c<`0c<c<00@0c<c<00?o00000>KViP3V
i^H01`3Vi^H00ol000000000ooooo`0>ooooo`03o`0000000000i^KV00L0i^KV00<000000<c<c03<
c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01`0c<c<00ol0003o6ATIoaTI6@09oaTI6@Cooooo00?o0000ooooooooool0Boooool2o`0001oo
oooo00?o^jC2okbWa?nlYl@00_nlYl@01?nmZLKo_j[5oknZaOo0[LL3ol:^aP;o`k380_o5//L2olFd
bP05olNebOo6]lcoa[O<olJgc?o8^L/00oo7^/h01?o9^lkoakg@olNmd?o7_M03olJnd`05o`000?o5
`=KoaL3FolG0e_o6`MD00oo3`=P01?o3`MOo`<3Jol30f_o0`=X3ooooo`03o`000?oooooooooo033o
oooo0009ooooo`04o`000?ooooooooooooooo`Oo6ATI00<0000003<c<`0c<c<0400c<c<00`000000
C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000
VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`00ol00000
i^KV0>KViP070>KViP0300000?oooooooooo00oooooo00<000000>KViP3Vi^H01P3Vi^H00`000000
c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00Wo6ATI1?ooool00ol0003oooooooooo`18ooooo`?o
00008?ooool3ok^T`P;o_:O400Co_ZO3oknZaOnoZ/Go_j[51?o2[/H01Oo3/<SoaK;7olFbaoo5//Oo
aKC:00?oakG900Goa[O<olRiboo8^L_ob;W;olNjcP03olVkcP08olNmd?o8_]3ob;k@olJndoo7_m?o
0000olNodoo5`=H3olK1e@05ol?0f?o3`MOo`l7Gol?1eoo0`=X00_o1`MT2ooooo`03o`000?oooooo
oooo033ooooo0009ooooo`04o`000?ooooooooooooooo`Oo6ATI00<0000003<c<`0c<c<03`0c<c<0
0`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl0
0`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`0
0ol00000i^KV0>KViP070>KViP0300000?oooooooooo017ooooo00<000000>KViP3Vi^H01P3Vi^H0
0ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT0
0`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00Wo6ATI1?ooool00ol0003oooooooooo`15
ooooo`?o00008Oooool00oniXL7o^jC2ok^T`P02ok^T`P04okbWa?nnYl?o_ZO3okjW``;o_j[500Go
`Z_3ol:^a_o2[/Ko`Zk6olF_a@03olFba`04olNca_o7]LWoakG9olNeb@?ob;W;00Gob[[;olVkc_o9
^lkobK_>ol^mc@03olRnd004olZod?o7_m?o0000olNod`Coa/7E0oo3`ML01?o4`MOo`L7Iol71fOo1
`MT3ooooo`03o`000?oooooooooo02oooooo0009ooooo`04o`000?ooooooooooooooo`Ko6ATI00?o
000003<c<`0c<c<0400c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<0
00000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP070>KViP0300000?oooooooooo01?ooooo00<0
00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0
000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00Wo6ATI1?oo
ool00ol0003oooooooooo`13ooooo`;o00008oooool3okVQ`@;o^jC200?o_JG1okjW`onnYl<00_nn
Yl<01OnoZ/Go`Z_3ol:[`oo2Zl?o`Zk600?oaJo500GoaK;7olNca_o7/lKoak?6olNeb@02olVgb005
olRiboo:^/_ob[[;olZjboo9^lh00oo;_Ld01Oo8_]3ob[o@olZod?o:_m3o000000;obL3B1?o6`MD0
1Oo3`MOoa<7GolC1eoo4`MOo`L7I00;o`L3I0oooool00ol0003oooooooooo`0^ooooo`002Oooool0
1?l0003oooooooooooooool6oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<
C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102I
VIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H01P3V
i^H00ol0003oooooooooo`0Dooooo`030000003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`00`3<
c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1o
Ogl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c
<c<00ol0003o6ATIoaTI6@09oaTI6@Cooooo00?o0000ooooooooool0@?ooool3o`0002Cooooo1?ni
XL401?nkY<;o_JG1okfU`OnmYL42okjW``05ol6Y`_o2Zl?o`Z_3ol:[`oo4[L<01?o5[lD4olNcaP?o
bKO81?o:^//3ol^mc@06olbncOo:_m3ob[o@olZod?o;`=3o00000_o9`=801?o9`M;oa/7EolK1eOo6
`MD4olC1e`?o`L3I00Co`/3Hoooooooooooo0000<?ooool000Wooooo00Co0000oooooooooooooooo
1_lI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00H0i^KV00<00000ooooooooool0
5Oooool00`000000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI6AT0
2OlI6AT4ooooo`03o`000?oooooooooo03kooooo0_l0000Vooooo`;o]ik00oniXL44okfU`@05okjW
`oo1ZL;o`JW2ol6Y`_o2Zl<00oo4[L<2olF_a@;oak740_o7/lH2olZeaP;obKO800Koc;W8olZjboo:
^/_ob[[;olblb_o;_Ld3olbnc@05olZod?o;`=3obl3@o`000?o9`=800oo9`M800oo6`MGoal7DolO1
e004olC1e`04ol70fOo2`=So`/3Hol;0f0;ooooo00?o0000ooooooooool0;Oooool000Wooooo00Co
0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00H0i^KV
00<00000ooooooooool05_ooool00ol00000i^KV0>KViP060>KViP030000003<c<`0c<c<00<0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00L0<c<c
00?o0000oaTI6OlI6AT02?lI6AT4ooooo`03o`000?oooooooooo03_ooooo0ol0000Vooooo`03okBK
_ongW/3o]ik000;o]ik000?o^J71ok^R_onkX[l00onmYL44ol6Y`PCoa:g300GoaJo5olNaa?o7/LCo
ak74olNcaP03olZeaP05olVgb?o<^LSoc;W8olbib?o:^//00_o<_<X01?o>_L[oc;k=olbncOo<_/d3
ol_0d005o`000?o9`M;obL7BolW1d_o:`]800oo7`M@3olC1e`05olG1e_o2`=So`/3Hol;0f?o2_mP0
0oooool00ol0003oooooooooo`0/ooooo`002Oooool01?l0003oooooooooooooool5oaTI6@030000
000c<c<0<c<c0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000
001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000
003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H01P3Vi^H00`00003oooooooooo`0Fooooo`030000
003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000
002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@08oaTI6@Cooooo
00?o0000ooooooooool0>Oooool2o`0002Sooooo0ondVkl2okNN`003okRO__nkX[oo^j:o00;o^j:o
00?o_JG1oknV`?noY/000oo1ZL801Oo3Z/7oa:g3olB]`oo4[L?oajk200?oak740oo:]LH01Oo<]lGo
c;W8olbib?o<^LSoc[[800?oc;c:0_o>_LX02?o<_/goc/3=olk0cOo;`=3oc<7?o`000?o<`LoobL7B
0oo:`]801?o7`MCob<7DolS1e?o4`ML3olG1eP04ol;0f?o2_mSo`[oHol:of0;ooooo00?o0000oooo
ooooool0;?ooool000Wooooo00Co0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0@03<c
<`03o`00001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507mo
O`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<
c003o`00003Vi^H0i^KV00H0i^KV00<00000ooooooooool05_ooool00`000000i^KV0>KViP060>KV
iP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI6AT02?lI6AT4ooooo`03o`000?oooooooooo
03Kooooo0ol0000Yooooo`Co]9^o00?o]ik0okRO__nhWkh01?nkX[l4oknV`005ol6Y`_o3Z/7o`j[1
ol>Z`Oo4[L<00oo7[/801?o7/LCob[?3olZc`oo:]LH3olbga@05olbib?o>^/Soc[[8oljjb?o<_<X0
0oo>_LX3olk0c@04olo1cOo<`Loo0000olc1c`?ob/;B00?obl;BolS1e?o8`M@00oo8`M@00oo5`MKo
aL3FolG0eP02ol:of005ol:oeoooooooooooooooool00000;Oooool000Wooooo00Co0000oooooooo
oooooooo1OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00D0i^KV00<00000oooo
ooooool06?ooool00`000000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IV
IP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00?o0000oaTI
6OlI6AT01olI6AT4ooooo`03o`000?oooooooooo03?ooooo0ol0000[ooooo`;o/IVn0ondVkl4okRO
_P;o^j:o0_nmXkl2oknV`003ol:W_oo3Z/7o`j[100;o`j[11?o7[/83olZc``Coc;O50oo>^/P01?o@
_<Ooc[g:oljmb_o>_LX2om2obP05olk0cOo?`Lgocl7=olo1cOl000000_o=`/l01?o:`];obl;Bol_2
d_o;`]83olS1e004olS1doo5`=KoaL3FolG0ePCo`[oG0_ooool00ol0003oooooooooo`0[ooooo`00
2Oooool01?l0003oooooooooooooool5oaTI6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<
C4`02@1<C4`00`000000IVIV06IVIP0606IVIP03o`00001oOgl0Ogmo00@0Ogmo00<0000009VIV@2I
VIT0102IVIT00`000000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00@0c<c<00?o00000>KViP3V
i^H01P3Vi^H00`00003oooooooooo`0Hooooo`030000003Vi^H0i^KV00D0i^KV00<000000<c<c03<
c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01`0c<c<00ol0003o6ATIoaTI6@07oaTI6@Cooooo00?o0000ooooooooool0<Oooool2o`0002co
oooo00?o[YJnok6I__naVKh00_naVKh00ondVkoo]YbnokJL_P03okRO_P05ok^R_onmXkoo_J>ookfS
_onoY/000oo2Ykl2ol>Z`@;oaZc00_o7[/82olV``@;ob[?300Koc;G3olbgaOo<]lGoc;O5oljiaOo>
^/P3om2la`04oljmb_o@_l[od;o:om2obPCocl7=00?ocL;?o`000?o=`/l00oo;`]82ol_2d@05olS1
e?o8`M?ob<7ColS1doo5`=H00_o5_mD2ol:oe`05ol:ne_ooooooooooooooool00000;?ooool000Wo
oooo00Co0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<
00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI
00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV
00H0i^KV00<00000ooooooooool06?ooool00`000000i^KV0>KViP050>KViP030000003<c<`0c<c<
00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo
00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00L0<c<c00?o0000oaTI6OlI6AT01olI6AT4ooooo`03o`000?oooooooooo02kooooo0ol0000/oooo
o`Co[YJn0_naVKh01?ncVKgo]YbnokJL__nfW;h3okRO_PCo_J>o1?o2Ykl01Oo3Z/7oaZc0olJ/`?o6
[<3oajk200?obK3100Gob[?3olbe`oo<]L?oc;G3olbga@02oljia@Cod;c70oo@_lX2om71bP;ocl7=
0_o@`/d01?l0003oc/;?olk2coo;`]83ol_2d@?ob<7C00Cob<3ColFoeOo5_mGoaKoE1?o2_]H3oooo
o`03o`000?oooooooooo02Wooooo0009ooooo`04o`000?ooooooooooooooo`Go6ATI00<0000003<c
<`0c<c<0400c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007mo
O`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<
c03<c<`0103<c<`00ol00000i^KV0>KViP060>KViP0300000?oooooooooo01Sooooo00<000000>KV
iP3Vi^H01@3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VI
V@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<
C01<C4`0101<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00Oo6ATI1?ooool00ol0
003oooooooooo`0/ooooo`;o0000;_ooool2ojZC_P?o[YJn00?o/IVnok>I_OncVKd01?nfW;h00onh
Wkko^j2nok^P_P03okfS_`04oknT__o2Ykoo`ZNool:W_`CoaZc01?o9/<44olbe``?oc[W500KodK_5
om2laoo@_<Ood;c7om6naoo@_lX3om71bP05olo1cOo@`/god<;=om73cOl000000oo>`/l4ol_2d@05
olS1doo8`=?ob<3ColS0doo5_mD00_o5_]@2ol:neP;o`[gE0_ooool00ol0003oooooooooo`0Yoooo
o`002Oooool01?l0003oooooooooooooool5oaTI6@030000000c<c<0<c<c00l0<c<c00<0000004a<
C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VI
V@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KV
iP3Vi^H01@3Vi^H00`00003oooooooooo`0Jooooo`030000003Vi^H0i^KV00@0i^KV00<000000<c<
c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007mo
O`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@07oaTI6@Cooooo00?o0000ooooooooool0:Oooool3o`00
02kooooo00CoYi2nojZC__nZTkkoZY>n0on^U[h4ok>I_@;o]Ybn00?o^9fmok^P__nkX;h00_nkX;h0
0onmXkoo_jBnoknT_P03ol:W_`03olBY_oo6[<3oaZc000;ob:k00_o9/<42olbc`@;oc;G30_o?]l<0
1Oo>^LGodK_5om6kaOoA^lGod;c700;odKk700Kodl37om71b_oA`L[odL7:om;2b_o@`/d2om73c@03
o`000?o>`/ooc/;?00;oc/;?0oo;`]43olS0d`05olRod_o5_]CoaKkDolFne?o5_]<00oo2_MD3oooo
o`03o`000?oooooooooo02Sooooo0009ooooo`04o`000?ooooooooooooooo`Go6ATI00<0000003<c
<`0c<c<03`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007mo
O`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<
c03<c<`0103<c<`00ol00000i^KV0>KViP050>KViP0300000?oooooooooo01[ooooo00<000000>KV
iP3Vi^H0103Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VI
V@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<
C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03o`000?lI6AWo6ATI00Oo6ATI1?ooool00ol0
003oooooooooo`0Wooooo`;o0000;_ooool01?nSS[koYi2nojN@__nWT;h4ojZC_P03ojjF__n_U[go
[iJm00?o/iVm00Co]YbnokRM_OnhWKgo^9fm0_nkX;h00onmX[go_jBnoknT_P02oknT_P04ol:W_oo4
ZKooa:VoolJ/`0?ob:k000GobK31olbc`Oo</l7oc;?1olbe``03olng``CodK_50ooA_/L2om?0a`04
om71b_oB`/[od/;:om?3bP;odL?=00?o0000olk2coo>`/l00oo>`/l01?o;`]7obl7@ol_1d?o8`=<3
olRodP05olFne?o5_]?oaKkColFndoo2_MD00_o2_=@3ooooo`03o`000?oooooooooo02Oooooo0009
ooooo`04o`000?ooooooooooooooo`Go6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<
C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KV
iP050>KViP0300000?oooooooooo01[ooooo00<000000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<
c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c
<`0603<c<`03o`000?lI6AWo6ATI00Oo6ATI1?ooool00ol0003oooooooooo`0Tooooo`?o0000;_oo
ool01?nORkooXhjnoj>>__nSS[h3ojN@_P;oZY>n00Co[9>mojnF_On_U[go[iJm0oncVKd4okRM_@04
ok^P__nmX[go_J:mokfR_@;o_jBn00Co`ZJmolBY_oo4ZKooa:Vo1?o8[/04olbc`@?ockO30_oA^/<2
om6ka@;odkg500CodKk7om?0aooC`<Oodl370ooB`/X2om?3bP03om73cOl0003odL?=00Coc/;?0oo;
`M001?o;`=3ob;oBolRod_o8_m83olFnd`04olFld_o2_=Co`[cDol:le0?ooooo00?o0000oooooooo
ool09oooool000Wooooo00Co0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0?03<c<`03
0000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003
o`00003Vi^H0i^KV00H0i^KV00<00000ooooooooool06?ooool00`000000i^KV0>KViP050>KViP03
0000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C003
0000000c<c<0<c<c00H0<c<c00?o0000oaTI6OlI6AT01_lI6AT4ooooo`03o`000?oooooooooo02;o
oooo0_l0000^ooooo`04oiZ9`?nORkooWh^ooin;_`?oXhjn0onWT;h00onZTkko[9>mojbC_@04ojnF
_@03ok>I_OndV[co]9Zl00?o^9fm1?nmX[d01?noY;ko`ZJmol:V_Oo2Y[d2olBY_`05olN/__o8[/3o
b:k0olR^`?o;/Kl00oo</l400oo?]L7ockO3om6j``02om6j``04om6kaOoC_LGodkg5om>ma@?odl37
0_oD`/P01ooB`/[odl?:om?3b_oC`l[odL?=o`000?oA`ld00oo>`/l2olk2cP05ol_1d?o;`=3obl3@
ol_0d?o8_m800_o8_]401Oo5_]?oaKcBolFld_o5_=;o`[cD00;o`[_C0oooool00ol0003ooooooooo
o`0Vooooo`002Oooool01?l0003oooooooooooooool5oaTI6@030000000c<c<0<c<c00l0<c<c00<0
000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0
000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00?o
00000>KViP3Vi^H01P3Vi^H00`00003oooooooooo`0Hooooo`030000003Vi^H0i^KV00D0i^KV00<0
00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0
000003<c<`0c<c<01P0c<c<00ol0003o6ATIoaTI6@06oaTI6@Cooooo00?o0000ooooooooool07ooo
ool3o`0002kooooo00CoUXO1oiZ9`?nJRL3oVXW00onORkl3oj>>_P03ojN@__nWT;go[9>m00?o[9>m
0_n_U[d00onaUkco]9ZlokBJ_002okBJ_003okRM_OnjW[co_J:m00?o_J:m1?o2Y[d01Oo4ZKooajbn
olN/__o7[;kob:k000?obk6o00Coc;?1olne`Oo?]L7odKS10ooA^/<01_oC_<?odkg5om>maOoC_LGo
e;o5om?0a`?oe<;80ooC`lX2omC3bP04o`000?oA`lcodL?<olk2c`?oc/;>0oo;`=001?o;_loob;kA
olRndOo8_]43olFldP04olFkdOo2^m?o`[_Col:kd`Cooooo00?o0000ooooooooool09Oooool000Wo
oooo00Co0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<
00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI
00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV
00H0i^KV00<00000ooooooooool06?ooool00`000000i^KV0>KViP050>KViP030000003<c<`0c<c<
00@0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c
00H0<c<c00?o0000oaTI6OlI6AT01_lI6AT4ooooo`03o`000?oooooooooo01cooooo0ol0000/oooo
o`03ohj4a?nBQL;oTXG200?oUXO10onJRL03oin;_`?oXhjn0onWT;d3ojbC_@03ojnF_OnaUkco/INl
00Co]9Zl0onjW[`2okfR_@;o_jBm0_o2Y[d00oo5ZKgoajbnolN/_P02olN/_PCobk6o0oo?]L42om6h
`@05om6j`ooC_<?odkc3om>l`ooC_LD00_oD_lD01_oF`LGoe<;8omC2b?oD`/SoeL?8om?3bP?oe<?:
00Co0000om73c?oA`lcodL?<0oo>`/h00oo>`Lkobl3@ol^oc`02ol^oc`04olRndOo7_M3oakg@olFl
dP?oaK_A00?o`[_Col>jd_o3^]800oooool00ol0003oooooooooo`0Uooooo`002Oooool01?l0003o
ooooooooooooool5oaTI6@030000000c<c<0<c<c00l0<c<c00<0000004a<C01<C4`02@1<C4`00`00
0000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`00
0000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H01@3Vi^H00`00
003oooooooooo`0Hooooo`030000003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`0103<c<`00`00
0000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`00
0000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00ol0
003o6ATIoaTI6@06oaTI6@Cooooo00?o0000ooooooooool06_ooool2o`0001[ooooo00CoQI3Goh>=
eOn3SMGoPhgE0_n2R]82oh:8d0;oPXK>0on3Q<`2ohF3b@;oR8?70on;PlD2ohj4a0?oTXG20onFQl43
oiZ9`003oin;_onORkkoXhjn00;oXhjn1?nWT;d00on/Tkgo[IBlok6G_003ok6G_0;o]9Zl00Go]i^l
okZN_?njW[co^YjlokfR_@03oknT_@04ol:V_Oo5ZKgoaJVmolFY_@;oajbn0_o:[[h2ol^a_`;oc[>o
00CockG1om6h`OoA^<7odKS11?oC_<<3omBoa@;oe/7500?oe<;8omG3b?oE`lP00ooD`lX00ooDa<[o
0000om73c003om73c003olk2c_o>`Lkoc/7>00?obko?00Cob[k?olNmd?o7_M3oakg@0oo5^m401?o5
^m3o`k[Bol>jd_o3^]84ooooo`03o`000?oooooooooo02Cooooo0009ooooo`04o`000?oooooooooo
ooooo`Go6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0
IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0
/k>c00@0/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP060>KViP0300000?oooooo
oooo01Oooooo00<000000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0
/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0
IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo
6ATI00Go6ATI1?ooool00ol0003oooooooooo`0Gooooo`?o00005?ooool00on>W]koS9_LohbKg002
ohVGf`?oQiCI0_n5T=L3oh>=e@;oPX[B0_n2R=02oh:6cP;oPhC<0_n5PlT3ohR3a`?oRh?50_n>Q<@2
oi:5`P?oUXO10_nJRL001?nJR;ooWh^noin;__nORkh3oj>>_P;oYi2m00?oZ96mojfD_?n]U;`01?na
Uk`01?ndV[co]i^lokNK_?ngVk`2okZN_0Co_jBm1?o5ZKd01Oo7[;kobZjnolZ^__o:[[kobk6o00?o
c[>o1?oA^<400ooD^l7odkc3om>l``02omFn``04omBoaOoF`LGoe/75omK1a@?oeL?800?oe/C8omC3
b_oDa<X00_l00003om73c006om72c?o>`Lkoc/7>olk1c_o=`<gobko?0oo:_/l01?o7_M3oakc@olNl
d?o5^m43olFkd003ol>jd_o3^]7o`k[A00Cooooo00?o0000ooooooooool08oooool000Wooooo00Co
0000oooooooooooooooo1OlI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00T0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00H0i^KV
00<00000ooooooooool05oooool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c
00?o0000oaTI6OlI6AT01OlI6AT4ooooo`03o`000?oooooooooo01Kooooo0_l0000?ooooo`;oUJKQ
0_nCXn02oi2Qg`?oSYkN0_n<Vm`2ohVGf`?oQiCI0_n5T=L2oh>=e@;oPX[B0_n2R=03oh:6cP;oPhC<
0_n5PlT3ohR3a`;oRh?50_n>Q<@3oi:5`P03oiJ7`OnEQ/3oVXRo00;oVXRo0onORkh3oj>>_P03ojN@
_OnXTKgoZ96m00?o[IBl0_naUk`00oncV;co]i^lokNK_002okNK_003okZN_?nmXKco_J6l00?o_jBm
00Co`ZJmolFY_Oo5ZKgoaJVm1?o:[[h01Oo=/Kkoc[>ooljc_oo>/koodKK000;odKS10_oD^l401?oC
_<?oeKk3omFn`ooE_/<3omK1a@;oel?600?oeL?8omK4b?l000000_l000001?oDa<[o0000omC3b_oA
`l`3om72c003olk1c_o=`<gocL3=00?ob[k?00CobKc>olNld?o7_=3oakc@0oo5^m001?o5^]3o`k[A
ol>jdOo3^]44ooooo`03o`000?oooooooooo02?ooooo0009ooooo`04o`000?ooooooooooooooo`Go
6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0
IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0
/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP060>KViP0300000?oooooooooo01Ko
oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0
/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0
IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00Go
6ATI1?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000[ooooo00?oV:[SoiNXh_nG
Z>801?nEY^42oi>Sh0;oT:7O0_n>W]h01?n<VmcoQiSLohFDfon5U=/3oh:@f@;oP8gG0_mnRM@2ogf6
dP;oOHC?0ommP/d2ogn1b`;oQH?90_n8PlL00on4P<OoR875ohR1a@02ohb2``?oTHC20onEQ/03oiZ8
_`?oWh^n00?oXhjnojB>_OnXTKd00onXTKd2ojfD_004ok6G_?ncV;co/iRlok>H_0;o]i^l00?o^Ifl
okfQ_?nmXK`00_nmXK`01OnoY;go`ZJmol:V_Oo2Y[goaJVm00;ob:bm0oo:[[h2olfa_P04oljc_ooA
]/3odKK0om6h`@?oe;_10ooE_/<2omO1a003omK1aOoG`lKoel?600?o00000ooFa<P00ooDa<[oe<?:
o`000003om72c006om31c?o=`<gocL3=olg0cOo=_lgob[k?0oo9_<h01?o7_=3oak_?olNkcoo5^m03
olFjd003ol>jdOo3^M7o`kWA00Cooooo00?o0000ooooooooool08_ooool000Wooooo00Co0000oooo
oooooooooooo1OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<00<00000
06IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00H0i^KV00<00000
ooooooooool05Oooool00`000000i^KV0>KViP060>KViP030000003<c<`0c<c<00@0c<c<00<00000
0;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C003o`00000c<c<0<c<c00L0<c<c00?o0000
oaTI6OlI6AT01?lI6AT4ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo00001Ooo
ool00onJ[NCoVJ_SoiV[h`03oiRZh`;oUjSR0_nEY^400onBY>7oT:;Qoi2Rh@02ohfOg`?oRY_N0_n7
V=`2ohFDf`?oPY3I0_n0SML2ogj9e0;oOHKB0_mmQ<l2ogf2c@;oOh7;0_n1P<P3ohB0a`;oR8750on<
P/<3oi64`P;oUHK00onJR;l3oin;_P;oY8jm1?nXTKd00on]U;co[iFlok>H_003ok>H_004okNK_?ni
WKco^IflokVM_0;o_J6l00?o_j>lol:V_Oo2Y[d00_o2Y[d4olR/_@04olZ^__o=/KkocK6nolfa_P?o
dKK000KodkW0omBk`OoD^l7oe;_1omJm`_oE_/<3omO1a0?o00000_oHa<H4omK4b0?oe<?:00?o0000
om72c?o@`L`00_o@`L`01?o=`<gocKo=olfocOo<_L`3olVlcP?oak_?00Coak[>olFjd?o5^]3oaK[@
0oo3^M401Oo4^M3ooooooooooooooooo000002Cooooo0009ooooo`04o`000?ooooooooooooooo`Go
6ATI00<0000003<c<`0c<c<0400c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0
/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KViP0300000?oooooooooo01Go
oooo00<000000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0
/k>c00<0000009VIV@2IVIT00`2IVIT00ol00000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0
IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00Co
6ATI1?ooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooooooo`;oW:oU0_nK[^@3oiZ]
i0;oVJ_S00?oV:[SoiJYhonFZN<00_nDYn83oi:Th@;oT:;Q0_n=Wml3ohZKgP;oQiSL0_n5U=/2oh:@
f@;oP8gG0_mnRM@3ogf6dP04ogf4commP/goOH;=ogf2c@;oOh7;0_n1P<P3ohB0a`;oR8750_n<P/<3
oi64`P?oUHK00_nJR;l3oin;_P?oY8jm0_nXTKd01?nZT[go[iFlojnE_?n_UK`3ok>H_0Co^Ifl00Co
_J6loknS_?noXkco_j>l0_o2Y[d2olFY_@;ob:bm00Cobjnnolfa__o=/KkocK6n0_o@];l2om6f`0;o
dkW000Coe;_1omJm`_oF_L;of<320ol000000ooI`lCoel?6omS4aP02omS4aPGoe/C800Coe<?:om?3
b_oC`l[o00000oo@`L`3olfoc@;oc;g<00CobKc>olVkcOo9^lgoak_?0oo7^/h01?o5^]3oaKW?olFi
coo3^M43olBid0?ooooo00?o0000ooooooooool08Oooool000Wooooo00Co0000oooooooooooooooo
1OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0
102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00H0i^KV00<00000ooooooooool0
5Oooool00`000000i^KV0>KViP060>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0
0`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0
101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00?o0000oaTI6OlI6AT0
1?lI6AT4ooooo`03o`000?oooooooooo01Gooooo00?o0000oifai_nM/NH00_nL/>D3oib_i@;oVjkT
00?oVZgToiV/i?nI[>@00_nGZn@3oiJYh`;oU:OR0_nBY>400on@X^7oS:3QohbPh@02ohVMh0;oQYWN
0_n3UMd2oh2Af`;oOHgI0_mjRMH2ogV6e0?oN8?A0_mhP<l2ogf2c@;oOh7;0on1P<P2ohB0a`;oR875
0on<P/<00onAQ<;oSh?1oiB5`002oiB5`0;oVXRo1?nORkh2ojB>_@03ojRA_OnZT[goZY:m00Co[iFl
00?o/iRlokFJ_?neV[`00oniWK`4oknS_005ol:V_Oo5ZKgoaJVmolFY_Oo8[;d00oo;[kh01Oo=/Kko
d;Boom2d_oo@];oodKK000?odkW000Koe[g2o`000?l0003o0000omS0`_oG`L@2omW3a005om[4a?oH
a<Kof<C6omS4a_oIaLH01?oFa<P3om?3bP03o`000?oC`/[od<7<00;ocl3;00CocKo=olbmc?o<_Lco
c;g<0oo9^ld3olNjcP04olNicOo5^LooaKW?olFic`?oa;W@00?oaKW?ooooooooool00_ooool00ol0
003oooooooooo`0Pooooo`002Oooool01?l0003oooooooooooooool5oaTI6@030000000c<c<0<c<c
0100<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`00003oooooooooo`0Cooooo`030000003Vi^H0i^KV
00L0i^KV00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI
00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<
00D0C4a<00<0000003<c<`0c<c<0200c<c<00ol0003o6ATIoaTI6@03oaTI6@Cooooo00?o0000oooo
ooooool05Oooool01?l0003oWK7Voifai_nM/NH2oib`i@03oib_iOnK[nGoVZgU00;oVZgU0onI[>@2
oiN[i004oiJYhonDZ>?oTZGSoi:Uh`?oSj?R0on<X>42ohVMh0;oQYWN0_n3UMd2oh2Af`;oOHgI0_mj
RMH2ogV6e0?oN8?A00?oN83?ogUncOmiO/d00_mjOLX3ogemb0;oPGk60_n5Ol@3ohZ1``?oSh?10_nD
QL03oiZ8_`?oWh^n00?oY8jmojF>_OnZT[d00onZT[d2ojnE_004ok6G_?neV[co]IZlokFJ_0?o^Ifl
00Co_:2loknS_?noXkco_j>l1?o5ZKd4ol^__PCod;Bo0_oC^L03o`000004omJm`_oH`<;of<32omS0
`P?ofL?40_oJa<@00ooHa<KofLG6omW5aP05omK4b004om?3b_oC`/[odl;:o`0000?ocl3;0oo<_L`2
ol^lc004olVkcOo9^/cobK[<olNjcP?oakW=00CoaKW?olFic_o5^Lkoa;W@0oo5^Ll3ooooo`03o`00
0?oooooooooo023ooooo0009ooooo`04o`000?ooooooooooooooo`Ko6ATI00<0000003<c<`0c<c<0
400c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0
1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP060>KViP0300000?oooooooooo01?ooooo00<000000>KViP3Vi^H0
1P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT0
0`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0
1@1<C4`00`000000<c<c03<c<`0703<c<`03o`000?lI6AWo6ATI00?o6ATI1?ooool00ol0003ooooo
ooooo`0Eooooo`04o`000?ooooooWK7VoibaiP?oVk3V0_nK[nD3oiZ]i@04oiV/i?nGZnGoUZWToiJY
i0?oU:SS0_nBYN<3ohnShP04ohbPhOn9W^7oQI_PohFKh0;oPYOO0_mnT]d2ogZ>f`;oMh[I0omjRMH2
ogV6e0;oN8?A0_mhP<l2ogUnc@;oNWg:0_mmOLP2oh5naP?oQGo40_n:PL<3ohn3`@?oU8G00_nJR;l3
oin;_P?oYHjm0onZT[d00on_UKco/INlok6G_004okFJ_003okVM_?nlX;co_:2l00?o_j>l00Go`ZJm
olFY_Oo5ZKgoaJVmolR/_@02ol^__P;oc[:n0_o@];l3o`0000?oe[c10ooH`<82om[2``04omW3a?oJ
a<Cof/C4om[4a0?ofLG600?ofLG7omK4b?oFa<P00_oFa<P3om?2bP03om;1bOl0003ocl3;00;ockk;
00Coc;g<ol^lc?o;_<cobkc<0oo9^/`3olNic@04olNic?o5^LkoaKW>olFicP?oaKW?00?oa[[?oooo
ooooool00_ooool00ol0003oooooooooo`0Oooooo`002Oooool01?l0003oooooooooooooool6oaTI
6@030000000c<c<0<c<c0100<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IV
IP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c
/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00`00003oooooooooo`0Aoooo
o`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`030;>c
/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00ol00000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<00ol0003o6ATIoaTI6@02oaTI
6@Cooooo00?o0000ooooooooool05Oooool00ol0003ooooooibaiP02oibaiP03oi^`i_nJ[nKoVZoV
00;oVJkV0onH[ND2oiN[i@;oUZWT00?oU:SSoi6Wi?nAYn@00_n?Y><2ohbQhP?oRIkQ0_n5Vn02oh:G
g`;oOY;M0_mjS]/2ogN:f@;oM8KG0_mbP]@2og9od@;oLWg?0omiO/d2ogYmbP;oOGg80_n1O/H2ohEo
a0?oRX730on?Pl42oiB5`0;oVXRo0onORkh3ojF>_@?oZY:m1?naUk`2okFJ_003okRM_OnlX;co_:2l
00;o_:2l00Go_j>lol:V_Oo2Y[go`ZJmolFY_@02olR/_@03ol^___o>/[koc[:n00?o00000_oB^;l3
omJl`@;of;o100Cof<32om[2`ooJ`/?of/;30ooJa<@2om[5a@03omW5a_oIaLOofLG700;of<G700Co
e/C8omG3b?oE`lSodl;:0_oB`LT01?oA_lWo0000olnnboo?_//3ol^lc0;obk_;00CobK[<olVic?o9
^LcoakW=0oo7^L`01?o5^Lkoa[W>olJic_o5^Ll3olJjc`Cooooo00?o0000ooooooooool07_ooool0
00Wooooo00Co0000oooooooooooooooo1olI6AT00ol00000<c<c03<c<`0?03<c<`030000001<C4`0
C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0
i^KV00P0i^KV00?o000000000?ooool03oooool00`000000i^KV0>KViP080>KViP030000003<c<`0
c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00P0<c<c00?o0000oaTI6OlI6AT00_lI6AT4ooooo`03o`000?oooooooooo01Gooooo00Co0000
ooooooooooooW;7V0_nK/>H3oiZ_iP;oVJkV00?oV:gUoiN/i_nG[>H00_nEZnD2oi>Yi@?oTJOT0_n?
Y><2ohbQhP;oRIkQ0_n5Vn02oh:Gg`?oOY;M0_mjS]/2ogN:f@;oM8KG0_mbP]@2og9od@04og9mcomc
NlgoLg_=og=kc@;oMW[:0_miNlP2oh5naP?oQGo40_n:PL<2ohn3`@03ohj2`_nDQL3oU8G000?oVXRo
0onORkh3ojF>_@03ojZB_On/Tkgo[9>m00?o/INl00Co]IZlokRM_OnhWKgo^9fm0_nlX;`00onoXkgo
`ZJmol:V_@02ol:V_@?ob:bm00Goc[:no`000?l0003oc[:nom6f_`03om:h_`03omFk`?oF_<7of;o1
00;of;o10ooJ`/<2om_4``06om[4a?oJaLGof/G5om[5aOoJa/GofLG70ooHaLL3omG3b006omC2b?oB
`LWodKo9om6obOl0003ockk;0_o>_LX01?o;_<cobk_;ol^kboo;^l/3olVic0CoakW<0oo6^Lh3olJj
c`03olNkcooooooooooo00;ooooo00?o0000ooooooooool07_ooool000Wooooo00Co0000oooooooo
oooooooo1olI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00T0i^KV00<00000oooo
ooooool03Oooool00`000000i^KV0>KViP080>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c
/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00Co0000oaTI
6OlI6AWo6ATI1?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo0_nK/>H0
0onJ[nKoVJoWoiR^iP02oiR^iP?oUjcV0_nEZnD2oi>Yi@04oi6Wi?n?Y^GoS:?TohbSi0?oRJ3S0_n5
WN82oh6Ih@;oOICO0_miT=d2ogB;f`;oLHOI0_m^PmL2og:2e0;oLWoA0_mbOLl3og=kc@03ogIjb_mi
NlSoNG_800;oOG_60on3OLD2ohQo``?oSX;20_nDQL03oiZ8_`?oWh^n0_nUS[d01?nVT;ko[9>mojbC
_On/Tkd3ok6G_0Co^9fm00Co_:2loknS_OnoXkgo_j>m0_o2Y[d2olJY_@?o00000oo>/[h2om6f_`04
om:h_ooE^l3oeK_0omRn`@?of;o100?of/;2om[2`ooKa<<00_oKa<<3om[5a@;of/K51OoHaLL00ooE
`lSoe<;8omC2b003om6ob@04om2nbOl0003oc[g:oljmbP?obk_;0_o;^/X00oo9^LcobKW;olVib`04
olNic004olJic_o7^LgoakW=olJjc`?oak_?1?ooool00ol0003oooooooooo`0Mooooo`002Oooool0
1?l0003oooooooooooooool7oaTI6@030000000c<c<0<c<c00l0<c<c00<0000004a<C01<C4`02@1<
C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102I
VIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H02P3V
i^H00`00003oooooooooo`0:ooooo`8000002`3Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c
/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001V
IVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0803<c<`04o`000?lI
6AWo6ATIoaTI6@Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`;oVK3W
0onI[nL3oiR^iP04oiN/i_nE[>KoTj[Voi>ZiP?oTJSU0_n?Y^D2ohbSi0?oRJ3S0_n5WN82oh6Ih@;o
OICO0_miT=d2ogB;f`;oLHOI00?oKX?Gofaoe?m/Om@00_m[O=83of]ic`;oLg_=0_mfN/X2ogUkb0;o
OG_60_n3OLD3ohQo``?oSX;20_nDQL03oiZ8_`03oin;__nPS;ooYY2n00?oYY2n0on/Tkd00onaUkco
/iVmok>I_@03okRM_@Co_j>m00Go`ZJmo`000?l0003o0000olR/_@03olb`_P04oljb__oA][oodKJo
om6f_`?oeK_00_oH_/401?oH_l7of/;2om[2`_oKaL<3om_4``03omc6a?oJaLGof/K500;of/K500?o
f/K6omS5aooHaLL00_oHaLL3omC2b003om?1b?oA_lWod;k900;od;k900Co0000olflbOo=_<Wobk_;
0oo;^/X4olVib`?oakW<0oo7^Ld3olNkc`03olRlcooooooooooo00?ooooo00?o0000ooooooooool0
7?ooool000Wooooo00Co0000oooooooooooooooo1olI6AT00`000000<c<c03<c<`0?03<c<`030000
001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000
003Vi^H0i^KV00/0i^KV00?o000000000?ooool02?ooool00`000000i^KV0>KViP0:0>KViP030000
003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000
001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000
000c<c<0<c<c00P0<c<c00Co0000oaTI6OlI6AWo6ATI1?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo0_nI/>L00onI[nOoUjoWoiN_i`03oiJ]i`;oUJcV0_nCZ^H00onAZ>Go
SjSVohnXiP02ohbUiP;oRJ;U0_n5Wn@2oh6Kh`;oO9OR0_mgT^02og>=gP;oKXSL0_mZQ=X2ofj3e`;o
K7oD0_m[O=82of]ic`;oKGS=0_m`N</2ogUkb0?oOG_60_n3OLD2ohQo``?oSX;20_nDQL02oiZ8_`04
oiZ9`?nPS;ooX8booj2<_`?oYY2n0_n/Tkd00on^U[ko/iVmok>I_@02ok>I_@04okRM_OnkX;go^j2m
oknS_@?o00000oo6ZKd4olb`_P?odKJo0_oD^/001?oE^l3of;k1omRn`OoH_/43om[2`P;oflG300?o
flC3omc6a?oLa/@00_oLalD00ooJa/Gof/K6om[6aP03omS5a`;oelC700Coe<;8om?1b?oC`LSod[o8
0oo@_/T01?o=_<Wo0000olflbOo<^/T3ol^jbP03olZib_o9^L_obKW;00;obKW;00CoakW<olRic?o8
^LcoakW=0_o8^/d01?o7^loob;c?olRlcoo8_<l4ooooo`03o`000?oooooooooo01cooooo0009oooo
o`04o`000?ooooooooooooooo`Oo6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00:
04a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@05
09VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0<
0>KViP0300000?oooooooooo00Cooooo0P00000=0>KViP030000003<c<`0c<c<00D0c<c<00<00000
0;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00T0<c<c00?o0000
oaTI6OlI6AT01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo0onH/>P2
oiN_i`03oiJ]ionD[NOoU:gW00;oTjcW0_nAZ^L3ohnXiP;oS:GV0_n9X^D2ohFOi0;oPI_S0_mlUn82
ogNBh0;oLhgN0_m^R=`2ofZ4fP04ofMoeomTNmCoI7_DofAke0;oJgcB0_m[NLl00om]N<goL7S;og1h
b`02ogAhb@?oNW[70_n0O<D3ohQo``04ohj2`_n=P/;oThG1oi>5`@?oVXW00onPS;l3ojJ@_PCo[YJn
0_ncVKd00onfW;ko^j2mo`000002o`0000;o_j>m00?o`ZNnolJY_Oo6ZKd00_o9[[h2olb`_P;ockBo
00GodKJoomBj`?oD^/3oe;[0omFk`003omRn`@;of/;20ooKaL<3omc6a0;og<O51?oJa/H01?oHaLOo
elC7omO4aooGa<L3om?1b0;od[o800Cod;k9olnmb?o?_LSo00000oo<^/T00oo;^/[ob[W:olZibP04
olVib`?ob;W<0oo8^/d3olRlc`03olVncooooooooooo00?ooooo00?o0000ooooooooool06oooool0
00Wooooo00Co0000oooooooooooooooo2?lI6AT00`000000<c<c03<c<`0?03<c<`030000001<C4`0
C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0
VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0
i^KV00`0i^KV1P00000?0>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH0
0`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00?o0000oaTI6OlI6AT01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?oV;3XoiN`j?nF[^P00_nF[^P3
oiB]i`;oTjcW0_nAZ^L01?n?Z>KoS:OWohVUion9YNL2ohFRiP;oPIkU0omlV^@2ogNEh`;oLY3Q00Co
K8_Oofj8g?m^R=coKXSL0_mZQ=X00omWOmOoI7_DofAke002ofAhdP;oI7K@0_m]N<d2og1hb`;oM7S9
0_mjN/L2oh1la@?oQWk40_n=P/83oi>5`@?oVXW00onPS;l00onVT;koZ9:oojRB_`03ojjF_P04ok>I
_Ol0003o0000o`0000?o^j2m00Co_j>mol:W__o2YkkoaZVm0oo9[[h01?o</;kockBoolnd_oo?];l4
omBj`0?of;k10_oJ`/83om_5``;ogLO300Gog<K4omc7aOoLalGog<O5omc8a@03om[6aP06omW5aooG
a<OoelC7omO4aooF`lOodl780ooB_lP3olnmb004olbjbOl0003oc;[9olbjb0?ob[W:00?ob[W9olVi
boo9^L/00_o9^LX01?o8^LcobK[<olVjc?o8^/d2olVlc@04olRlcoo9_/oobKk?olVnc`Gooooo00?o
0000ooooooooool06_ooool000Wooooo00Co0000oooooooooooooooo2?lI6AT00`000000<c<c03<c
<`0?03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07mo
O`0507moO`030000002IVIT0VIVI00D0VIVI00?o00000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0060<c<c0030000003Vi^H0i^KV0200i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c
/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IV
IP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<00ol0003o6ATIoaTI
6@04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool2oiN`j0?oUZkX00Co
U:gWoi>]j?nAZnSoTJ_X0on?ZNP2ohbWi`;oRJGW0_n5X^H2oh6Ni@?oO9[T0_mgUN<2og:@h@03ofb;
gomWQ]goIhKM00;oHX7J0_mNO=P2ofAke0;oI7SB00?oI7K@ofMecOmWMLd00om`N</01?mdN<WoNW[7
ogYjaomjN/L2oh1la@?oQWk40_n=P/82oi>5`@?oVXW00_nPS;l01OnRS/3oZ9:oojRB_onXT[oo[YJn
00?o00000onfW;h2ok^P_@04okjT_oo2Ykko`ZNnol:W_PCobJjn1?o?];l01_oB^<3oe;[0omBj`?oD
^/3oekg1omRn`@?of/;200?og<G2om_5`ooMal<00_oMal<3omc7a@;og<S50ooJa/H2omW5a`03omO4
aooF`lOoe/?700?od[o80_oA_/P01Oo?_LSoc[_8oljkb?o<^/Wo000000;oc;[800Cob[W:olZibOo:
^LWobKW;0oo9^LX3olVjc0?obKc=0oo9_/l00oo;`=3oooooooooo`03ooooo`03o`000?oooooooooo
01[ooooo0009ooooo`04o`000?ooooooooooooooo`So6ATI00<0000003<c<`0c<c<03`0c<c<00`00
0000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`00
0000VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01`3<c<`00ol0
0000i^KV0>KViP0O0>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`00
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00?o0000oaTI6OlI6AT01?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0_nF/>T3oiB^j@;oTjgX0_nAZnP00on?
ZNSoSJWYohfYj@02ohVWj0;oQZCX0_n2XNL2ogfMiP;oMiWU0_maTn@2of^>hP;oIHSP0_mWQ]d2of:1
fP03oeilf?mLN=GoG7SE00;oI7SB0_mTM]001?mWMLgoJgG<of]ec?m[ML`2og1fbP;oNW[70on0O<D2
ohIna0;oSH;20onCQL400onJRL3oVh[1oj:>`002oj:>`006ojRB_ol0003o0000o`000?n^U[ko/9Vo
1?nfW;h01?nkX;go_ZBookjT_onnY;l2ol:W_P05olF[_oo9[[kobJjnolV^__o</[l00_o?];l3om:h
`004omBj`?oG_L7oekg1omW1`P;of/;20_oLaL84omg7``04omg8a?oLalGog<S5omc8a@;og<S600Co
f/K6omW5aooIaLOofLG70ooF`lL00ooD`LOod[o8om6nb002om6nb0?oc[_800Coc;[8o`000?o<^/So
c;W80oo:^LT3olVibP;ob[[:00CobK[<olZkc?o:^lcobKc=0_o;_Lh01?o9_/oobl3@ol_0d?o;`=05
ooooo`03o`000?oooooooooo01Wooooo0009ooooo`04o`000?ooooooooooooooo`Wo6ATI00<00000
03<c<`0c<c<03`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<00000
07moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<00000
0<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0N0>KViP030000003<c<`0c<c<00H0c<c<00<00000
0;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00P0<c<c00?o0000
oaTI6Oooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo0_nF/>T0
0onD[^WoTjkYoi>^j@02oi6]j@?oSj_Y0_n=ZNT2ohVWj0;oQZCX0_n2XNL2ogfMiP;oMiWU0_maTn@2
of^>hP03ofF8h?mOPmkoGh?N00;oFWgK0_mNO=P00omLN=GoG7GCoeaed`02oeecd0;oIgG=0_m[ML`2
og1fbP;oMWS80ommNlH2ohAna@;oS8;40onCQ/83oi^:`@?o00000_nXT[l01?nZUL3o/9Vook2I_on`
VKl2okJL_P03okVP`?nnY;oo_ZBo00;o_ZBo00Go`ZNnolF[_oo5ZkooaJ^oolV^_P03olbb_`04olnd
_ooB^<3od[S0om:h`0?oekg10_oI`L800ooJ`/;og<G2omc5`P03omg7``;ogLS400?ogLW5omc8aOoL
b<H00_oLb<H3omW5a`;of<C700?oe/?7omC1aooD`LL00ooA_/P2om2la`05oljkb?o=^/SocK[8olbj
b?l000000_o<^LP01?o:^LWobkW9ol^ibOo9^LX3olZjbP?ob[_<0oo;_Lh3ol_0d0;ocL?A1?ooool0
0ol0003oooooooooo`0Iooooo`002Oooool01?l0003oooooooooooooool:oaTI6@030000000c<c<0
<c<c00h0<c<c00<00000o`00001<C4`02@1<C4`00`000000IVIV06IVIP0706IVIP03o`00001oOgl0
Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0
c<c<00H0c<c<00<000000>KViP3Vi^H07@3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0
/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0803<c<`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0:ooooo`?oU;3Z0onC[^T2
oi6]j@04ohn[jOn=Zn[oRZWZohZYjP;oQjOZ0_n3Y>T2ogjPj@;oN9cX0_mbUnL2ofbBi@;oI8cT0_mU
R>02oen3gP;oFWgK00?oEWSIoeaheOmLN=D00_mLMM<01?mMLm3oGg;?oembcomOL/l2of]ec0;oL7K:
0_mfN<P2ogekaP;oQ7k50on<P/@3oi>6`P;o00000onRS/000onXT[ooZYG0ojZE`003ok2I_`04okJL
__niX<3o^J30okVP`0;o_ZBo00?o`JS0olF[_oo5Zkl00_o5Zkl4olbb_`?od[S00_oE_<401?oG_L7o
fL72omW1`_oI`L82omc5`P?ogLO30ooMb<@00ooMbLGogL[6omc8aP02omc8aP05om_7a_oIaLOof<C7
omS4aooF`lL00ooD`LL00ooC_lOodKk8om2la`02om2la`CocK[800?oc;W8o`000?o<^LP00oo;^LT3
olZjbP;obk_;00Cob[_<olbmc?o<_Lcobkg>0_o<_lh01?o;`=3ocL?Aolg3dOo>a]85ooooo`03o`00
0?oooooooooo01Sooooo0009ooooo`04o`000?ooooooooooooooo`[o6ATI00?o000003<c<`0c<c<0
3`0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0
1@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0
1`3<c<`00`000000i^KV0>KViP0L0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
1@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?oU;3Zoi>`jonC/>/0
0_nA[n/3ohn]jP;oSJ_Z0_n:ZNX2ohNWjP;oPjCY0_mnX>T2ogRLj0;oLYOW0_m/T^D2ofB<i0;oGHKR
00KoEX3OoeYmfomJOM_oFWgKoeIhfOmCM=H3oe9ae003oeecd?mOL/ooGg;?00;oI7?=0_m`M/X2ogIh
b0?oOG_60_n4O/D2ohb2a0?o00000onKR/400onRS/3oXi72ojZE`003ojZE`0;o/9Vo1?niX<001?nn
Y;oo`JS0ol6X`?o1Z<02olF[_`;obJo10_o</[l2om2f`@04om:h`?oE_<7oeKc1omFl`@?ofL720_oK
aL<00ooLaL;ogLO3omg7``02omk9a003omg8a?oMbLGogLW500;ogL[600Gog<S6om_7a_oKalKofLK7
omS4a`03omK3a`04omC1aooC_lOodko7om6na`?od;c700?ock_7olfjb?o=^/P00_o=^/P00oo<^LSo
0000olbib003ol^ib@04olZjb_o;^l_obk_;ol^kb`?oc;g<0oo<_lh00oo>`/oocL?Aolk6dP02olk6
dPGooooo00?o0000ooooooooool05oooool000Wooooo00Co0000oooooooooooooooo2_lI6AT00`00
0000<c<c03<c<`0?03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`00
0000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`00
0000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV01/0i^KV00<000000<c<c03<c<`01P3<c<`00`00
0000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<02@0c<c<01Ol0
003ooooooooooooooooo000001Gooooo00?o0000ooooooooool03Oooool2oi>`j`;oTJo[00?oSjgZ
ohf]k?n;[>/00_n;[>/2ohRYj`?oQ:O[0_moY>/00omjX>[oM9cYogBLj@02offGj0;oII7W0_mMRnD2
oef6hP03oeJ0gom@N]coD7[L00;oC7GJ00?oDgCFoe9ae?mBLM@00_mDL=82oembc`03ofAccOmZML_o
JWG;00?oLGS:0_mmNlH01on4O/Go0000o`000?l0003oS8;4oi>6`_nCR<@00onKS<<3oj>A`P?oZYG0
00?o/9Vook>L`OncW<400oniX<04ol6X`005olF[_oo9[l7obJo1olV_`Oo</[l00oo@]/43omFl`@;o
f<7300KofL72om_5`ooKaL?oflG3omg8a?oMal<3omk9a003omk;aOoMbLGogL[600;ogL[60ooKalH0
0ooIa/Oof<G7omK3a`02omK3a`03omC1aooC_lOodKk700;odKk700?od;c7olnkaoo?^lL01?o=^/P0
0oo<^LSo0000olbib003ol^ib@?obk_;0_o<_</01?o<_LcocKo=olfocOo<_lh2olk2c`?oc/KB0_o@
bM<4ooooo`03o`000?oooooooooo01Oooooo0009ooooo`04o`000?ooooooooooooooo`_o6ATI00<0
000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00L0IVIV00<0
000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00@0/k>c00<0
00000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0J0>KViP030000003<c<`0c<c<00L0c<c<00<0
00000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00Go
0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00gooooo0onA/>`2oi2_k0;oSJg/
0on;[>/2ohRYj`04ohBWjon1YngoO:C/ogbTk0;oMZ3/0_mdW>T2offGj0;oII7W00?oGH_UoeF4homE
Q><00_m=ON02oe1jg003odaef_m9LMOoBG7G00;oDW7D00?oE73BoeQ`d?mHL=000_mTLld2ofYeb`;o
LGS:0ol000001?n2OlOoRh?6oh^3a_n;PlH3oi>8a0?oVhc30_nSTL82ojZE`003ojbH`_ncW<7o/ic1
00;o/ic100?o^J30okbU`_nlYL800oo1Z<001Oo5[L;obJo1olV_`Oo9[l7ocKC200?od;K100?odk_2
omFl`OoH`L<00_oH`L<3om_5``;ogLS40ooNbL@2omk;a@?ogL[60_oLbLH00ooKalKofLK7omW6a`02
omS5a`03omK3aooD`LOoe<7700?odKk700God;c7olnkaoo?^lOock_7oljja`02olfjb0;ocKW800Co
c;W8o`000?o<^LSobkW90_o<^lT01?o;^l_oc;c;olblboo<_</3olfoc@?oc/;?00?od<G@olk6d_o@
bM<00_o@bM<5ooooo`03o`000?oooooooooo01Kooooo0009ooooo`04o`000?ooooooooooooooo`_o
6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00H0
IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@03o`00002c/k<0/k>c00D0
/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0I0>KViP030000003<c<`0c<c<00L0
c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0
Ogmo00?o000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0
<c<c1?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?oTK3/oi2akOn@
/Nd00_n>[nd3ohb^k@;oRJc]0_n5Z^d2oh6Wk@;oO:C/0_mfX>`2ofnKj`03ofNFj_mNT>SoGY3X00;o
EHWV0_mEQ><00om=ON3oAWOModIgg@02odaefP03odUaeom8K]GoB6kE00;oE73B00CoF73@oeeac_mM
LLkoJWG;0ol000000omaN<[oNW_8ogYkb002oh9oa`?oRh?60_nCR<@3oi^<``03oj>A`_nUU<Co[9S2
00?o[9S20_ncW<400onfXL?o_:G2okbU`P02okbU`P05ol6X`?o5[L;oaJg2olF]`_o9[l400oo=]<80
1?o@]/7odk_2om>k`_oF`<@3omS1``03om_5a?oKaL?ogLS400;ogLS400?og/_5omk9a?oNblD00_oN
blD00ooNc<KogL[6omc9aP02omc9aP03om_9aooIa/Oof<G700;of<G70ooD`LL00ooC`<OodKk7om2l
a`02om2la`04olnkaoo>^/Ooc[[7olfjb0?ocKW80_o<^LP01Ol0003oc;_9olbkbOo<^lWocKc:00?o
c;c;00Goc[o<olfocOo?`/kocl;>olk2c`02om35d0?od<WC0_oAcMD5ooooo`03o`000?oooooooooo
01Gooooo0009ooooo`04o`000?ooooooooooooooo`_o6ATI00<0000003<c<`0c<c<03`0c<c<00`00
0000C4a<04a<C00904a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00ol0
0000VIVI09VIV@0409VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0203<c<`00`00
0000i^KV0>KViP0H0>KViP030000003<c<`0c<c<00L0c<c<00<000000;>c/`2c/k<01@2c/k<00`00
0000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00`00
0000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c1?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo0_n@/Nd2ohj_k@04ohb^kOn:[nkoQjg^ohN]kP;oPj[^0_mnYnh3
ogVTkP;oLZ3^0_mZVnd01?mQUNcoGY3Xoej@j?mERNH2odb2i0;oCGgP00?oAWOMod5af_m1LMX00_m9
LML01?m8K]GoBVgCodY]domHL=03o`0000;oI7?=0_m]Ml`2ogYkb0;oPWo70on;PlH3oi>8a003oi^<
`onLSlGoYIC400;oYIC40on/V<801?ncW<7o]Z73okJQ`onfXL<2okbU`P03oknYa?o5[L;oaJg200;o
aJg21?o=]<83om>k`P;oe/3400?of<73om_5a?oKaL@00_oLb<D00ooMb<Cog/_5omk;a@02omo<aP03
omk;aOoNc<Kog/c600?og<W60_oKbLL3omS5a`;oe/?800?oe<77om?0aooC`<L00oo@_<L01?o?^lOo
c[[7oljjaoo>^/L3olfib0;ocK[800Coc;W8olfjbOl0003oc;_90oo=_<X00oo<_<_oc[o<oljoc003
olo2cP05om75coo@aM3odLWBom79d_o@bM<00_oAcMD2om?@e`Cooooo00?o0000ooooooooool05Ooo
ool000Wooooo00Co0000oooooooooooooooo3?lI6AT00`000000<c<c03<c<`0?03<c<`030000001<
C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0507moO`030000002I
VIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0080<c<c0030000003V
i^H0i^KV01H0i^KV00?o00000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`060;>c/`030000002I
VIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<
C4`0C4a<00H0C4a<00?o000003<c<`0c<c<01`0c<c<4ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool3ohnakP;oSK3^0_n:[nh2ohN]kP;oPj[^0_mnYnh3ogVTkP;oLZ3^0_mZ
Vnd01?mQUNcoEhkZoeN>j_m<QnP2odb2i0;o@g[Q00Go>gCNod5af_lmKMSo?FgHodQ^e@03o`000003
odi]d_mMLLkoGG7>00;oI7?=0_m]Ml`2ogIkb`?oP83:00?oRh?6ohZ5b?nCRlL00_nCRlL2oib?a@?o
YIC40on/V<84okJQ``04okbU`_noZLCo_jW4oknYa0;oaJg20_o8//@2olfd`P;od;[400Codk_2omK0
a?oF`<Coe/340ooKaL@2omc8a@?og/_50_oOc<H3omk<aP03omg<aooLbLKoflW700;oflW700?ofLO8
omS5aooF`lP00_oF`lP3om?0a`03om6naoo@_<Oock_700;ock_700Coc[[7olfjaoo=^/OocKW80oo=
^/P2olfjb@04o`000?o=_<[ocKc:olflbP;ocko;00Coc[o<om32cOo@`/gocl;>0_oAaLl3om79dP05
om?=dooAcMGodm3Gom?@eooDe=T01Oooool00ol0003oooooooooo`0Dooooo`002Oooool01?l0003o
ooooooooooooool=oaTI6@030000000c<c<0<c<c00h0<c<c00<0000004a<C01<C4`02@1<C4`00`00
0000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0102IVIT00`00
0000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00?o00000000003Vi^H05@3Vi^H00`00
0000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT0102IVIT00ol0
0000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`00
0000<c<c03<c<`0603<c<`Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03ohnak_n=/^ooSK;_00;oRk7_0_n8[nl3ohF]k`;oPJ_`0_mkZ?02ogFUl003ofjPkomUVnooII__
00;oFiG]0_mGS^X00om<QnSo@WoUod9oi@02od=jh@05oc]dg_l0003o0000o`000?lmJmH00_m:KM<0
1?m>KM;oEFoAoeE_dOmEKm42ofAcc@;oKGO<0_mfNl/2oh20bP;oRXG81?nCRlL2oib?a@?oYIC400?o
[9S2ojnMaOn_WLD00onfXL<4oknYa005olF]`_o8//Cob;;4olRba?o=]<800oo@^/@3omK0a0;ofLC5
00KoflG4omc8aOoLb<Gog<S5omk<a_oNblD3omo<aP04omo>aooNc<KogLc7omg<a`;og<_800?oflW7
omW7b?oIalP00ooF`lP2omC2b004om?0aooA_/OodKk7om2mb0?ock_70oo=^/L3olfjb0;ocK_800Co
cK[9oljlbOl0003ocKc:0oo?_l/3om32c@05om75c_oAaLoodlWAom?9dOoAbM800_oCcM<01OoEdMKo
dm3GomCDfOoDe=WoeMSK00Gooooo00?o0000ooooooooool04oooool000Wooooo00Co0000oooooooo
oooooooo3_lI6AT00ol00000<c<c03<c<`0>03<c<`03o`00001<C4`0C4a<00P0C4a<00<0000006IV
IP1VIVH01`1VIVH00ol00000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI00<000000;>c
/`2c/k<01P2c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV01<0i^KV00<000000<c<
c03<c<`0203<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007mo
O`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c
<`0c<c<01P0c<c<4ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool2ohfb
k`;oRk7_0_n8[nl01?n5[NooPjkaogj/lOmn[?42ogVYl@;oLZGa0_mYXO42ofFKk`;oFiG]00?oD8k[
odB6jOm4Q^T00_m2OnD2o`000005obi`g_ldK]_o<FWIoc5YfOlmJmH00_loJ]@00om>KM;oEFoAoeE_
d@02oeecd0;oKGO<0_mfNl/3oh20bP;oRXG80onCRlL2oib?a@;oYIC400?oYiS7ojnMaOn_WLD00_n_
WLD00onfXL?o^JK6okVVaP03oknYa004ol>_a_o8//Cob;;4olRba0?od;[40_oC_lH01?oF`<CofLC5
omW4aOoIa<D3omc8a@;og/c60ooOc<H2omo>a`?ogLc70_oLblP3omW7b003omS6b?oF`lSoe<;800;o
e<;80ooA_/L2om2mb004olnkaoo>^lOoc[_7olfja`?ocK[80oo=^lP3oljlb@03o`000?o?_l_ocko;
00;od<;<00?od<;=om75c_oAaLh00ooCbM401_oDcM?odlgComGAe_oEdMKoe]KHomCDf@;oeMSK1Ooo
ool00ol0003oooooooooo`0Cooooo`002Oooool01?l0003oooooooooooooool>oaTI6@030000000c
<c<0<c<c00h0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`060;>c/`030000003<
c<`0c<c<00X0c<c<00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c
/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001V
IVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0503<c<`Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`?oS;?`0_n:/_02ohN`l@;oPjka0_mn
[?42ogVYl@;oLZGa0_mYXO42of2Kl0;oE9C_00CoB8g/o`000?l0003o00000_l[M>801?l^L=ko9f[K
obMZfolaJMT2oc1We`03ocmZe?m4JmCoA6_D00;oEFoA00?oGG?@ofMgcomWMll00ombO<h2oh20bP;o
RXG80_nCRlL00onDS/[oWY?9oijCb@04ojNHa`;o[ig500?o/Z;8okVVa_niY/H00_niY/H01OnoZLCo
`jo6ol>_a_o3[lKob;;400;oc;S600God;[4om>oa_oC_lKodko6omO4b003omW4a@03om_9aooLb<Go
g/c600;og/c600Coglk8omo<a_oOc/Ooglk70_oNc/T00ooMc<Oog<_8omc;b002om_:b@04omW7b?oH
a/Sof<K8omK4b@?oe<;800?od/38om6naoo@_LP00_o@_LP3oljka`?ocK[800Coc[_8olfkb?o=^lSo
cK_80_o>_<T2olnnbP04o`000?o@`/cod<;<om;5cP?odLG>00KodlW@om?9dOoDcM?oe<gComKBeOoE
dMH2omKFf004omOJf_oEf=_oeMcMomGLg@Gooooo00?o0000ooooooooool04_ooool000Wooooo00Co
0000oooooooooooooooo3olI6AT00`000000<c<c03<c<`0>03<c<`030000001<C4`0C4a<00T0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI
00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00:0<c<c003o`00003Vi^H0i^KV00l0i^KV
00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<00H0C4a<
00<0000003<c<`0c<c<01@0c<c<4ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
5Oooool00on</o3oRkCaoh^dl@03ohRcl@;oQK7b0_n1[o82ogb]lP;oMZ[c0_m^Y_<00omUXO;oFica
o`000002o`0000;oB8g/00?o>XCYobakiOl[M>800_lQKMh01?lWJ]_o8VGIob9UfOl`ImL2oc9VeP03
odA[e?m<K]?oC6kC00;oGG?@0_mWMll2og9lcP;oOX;=0_n9R<`3oiB>bP?oWY?90onWV<L01?n_WLGo
/Z;8ok:Rb?nbX/P2okVVaP03okf/bOo3[lKo`jo600;o`jo60oo<^<H01?o@_LWodko6om>oa_oC_lH2
omO4b003omW4aOoKbLOoflW700;ogLg900Gog/c6omo>b?oOc/Sogm39omo>a`03omk>b@03omg>b_oL
blSofl[900;ofl[90ooHa/P2omK4b@03omC2b?oB`<Sod/3800?od;g80_o?_<P01?o>^lOoc[_8oljk
b?o=^/P3oljkb003olfkb?o>_<Woc[c900?ockk:00?o0000om32c?oBaLh00_oBaLh01OoAaLkodlW@
om?9d?oFc];oe<gC00;oe];E00Kof=OGomKFf?oGf][oem[JomSNg?oEg=d2omGPg`Cooooo00?o0000
ooooooooool04_ooool000Wooooo00Co0000oooooooooooooooo3olI6AT00`000000<c<c03<c<`0>
03<c<`030000001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`05
07moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00:
0<c<c0030000003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`06
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP06
06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01@0c<c<4ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05oooool2oh^dl@04ohRclOn7]??oQ;;cohBbl`;oOk3c0_mj
[_@2og>[m004ofbWm?l0003o0000o`0000;oFica0_m>U?001Om0S>go<H?Yoc63jOl/NnGo7g;Q00;o
8FgN00So66KJob9UfOlQHmOo<6OGoc9Ve_lhJ=KoA6_Doda^d`;oEW;C0omWMll2og9lcP;oOX;=0_n9
R<`3oiB>bP?oWY?900?oYiS7ojVMb_nbX/P00onbX/P01?niY/Ko_Jc9okf/bOnm[<T2ol>_aP;oakG9
0_o<^<H2om2mb@04om>oa_oGa<SoelC8omO4b0?oflW70_oMcLT3omo>b004omo@bOoNdL_og]7;omk>
b@;ogLk:0ooKb/T2omW9bP03omS6b?oFa<Woe/C900;odl?900Cod/38om6ob?oA_lSod;g80oo?_<P6
oljkb0Coc[c90_o?_/X2om72c003o`000?oBaLkod/G>00;oe<W?00?odlW@omK>d_oFc]800ooFd]D0
1ooHemOoem[JomOJf_oGf][of=kLomSSg_oEh=l00_oDhn401OoCi^Cooooooooooooooooo000001?o
oooo0009ooooo`04o`000?oooooooooooooooa3o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000
C4a<04a<C00904a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000
VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02P3<c<`2000000d0
i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00D0
VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0
C4a<00<0000003<c<`0c<c<01@0c<c<4ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool06Oooool2oh^elP;oQkCc0_n4/_<2ogn`l`04ogZ^m?l0003o0000o`0000;oK:Od0_mRX_@2oeJL
l`04odRElOliS>ko>Hc^oc63j@;o8WWU00Ko7g;Qoa=Yg?lCJMco66KJob9UfOlQHmL2oc9VeP04ocQX
e_m<K]?oC6kCoeIbd`?oHGSC0_m^O]82ogj2c@?oRHS<0_nDS/X2oijCb@04oinHcOnYWL[oZIg:ojVM
bP?o/Z;81?nm[<T01Oo3[lKoakG9olNebOo7]LWoc;S600?od;g90ooGa<P2omW9bP03om_9aooMcLWo
gLg900;og]3;00?oglk8omo@bOoOd<T00_oNdL/3omg>bP03omc=booKb/WofLW:00;ofLW:00?oelO;
omK4bOoC`lT00_oC`lT3om6ob0?ockc80_o>_<P01?o>^lSoc[c8oljlb?o>^lP4oljlb@;ockk:0ooA
`/`01OoBaLgo0000omC9cooDbLooe/kA00?oe/kB00Ooem?DomKBeOoHemOof=OGomWLfOoGf][of=kL
00;of>?N00GoenKQomCShOoCi^CodnKTom;XiP03ooooo`03o`000?oooooooooo013ooooo0009oooo
o`04o`000?oooooooooooooooa3o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@05
09VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0303<c<`2000000X0i^KV00?o0000
0<c<c03<c<`03@3<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0VIVI00D0VIVI00<00000
07moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00H0C4a<00<00000
03<c<`0c<c<0100c<c<4ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool2
ohZfl`;oQkGd0ol000000omn/_GoNJoeogV_m@02og6/mP;oJJSf0_mNXoD01OmBWOCo@iGaocV<k_li
S>ko:8;Y00;o8WWU00Co4VoOoa=Yg?l9HMSo2F7H0_lQHmL01?lTHmKo>6SFocQXe_m1K=H2oeIbd`?o
HGSC00?oKWkBog^5d_mkQM800on8S=02oiBBc`CoWiS=0onYWLX00onbX/So]JS<okFXc002okf/b@05
ol6bc?o7]LWoakG9olNebOo;_<`00oo@_LT2om?4b`06omO4b?oIbL[ofLW:omW9b_oKc/cogLg90ooN
d</01?oNd/cogm39omkAbooNdL/2omgAc003omg>b_oLcL_og<g;00;of/c<00?ofLW:omO7booGal/0
0ooC`lT2om;1bP04om6ob?o@_/Wod;k9olnlb0Koc[c80oo>_<T2olnobP04olnnb_oA`/codL;<om72
c0;od/G=00?oe<[?o`000?oFc]400_oFc]401OoFc];oem?DomOCe?oIf=Kof=OG00;ofMcI00?ofN7K
omWUg_oHhmh00_oGi^401?oFjN?odnKTom;Xi_o?jNP3ooooo`03o`000?oooooooooo013ooooo0009
ooooo`04o`000?oooooooooooooooa7o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000C4a<04a<
C00804a<C003o`00001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`03@3<c<`2000000L0i^KV0P00
000?0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07mo
O`0507moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0403<c<`Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`05ohVgm?l0
003o0000o`000?n6]_D00_n2]OD2ogfcmP;oMk7g0_m`[_L2ofNZm`;oFjGf00GoCYkeod>ElOm3UO7o
<Xc^ob21j002oaMgh`04o`I/g?l4IMWo2F7Ho`9Le@;o4EkF00Co96?FobYUeolZIMOo@FcF0_m<L]L2
of5hd`;oKWkB0_mkQM83ohR<d0;oU9;?0onOV<d2ojVMbP05ojbSc_neZ<co]JS<okFXc?nm[<T00oo1
//`01Oo7]LWobkc<ol^lc?o;_<cod;g900?odlC;0ooIbLX2om_>c0?og]3;0_oNd/`00ooNe<kog]7;
omgAc002omgAc003omcAc_oLcL_of/c<00;of/c<0ooGal/00ooDaL_odl?9om;1bP02om;1bP?od;k9
0oo>_<P2oljlb@04oljlb?o>_LWoc[g9oljlb@?ocko:0ooA`/`2om;5c@;oe<[?00?o0000omK>dOoF
c]400_oHe=@01OoGdmCofMSFomWHe_oJgMWofMcI00;ofN7K0_oIjN001OoGi^7oe^WSom?/iOoBj>Ko
cnWX00;ocNWZ0oooool00ol0003oooooooooo`0?ooooo`002Oooool01?l0003ooooooooooooooolA
oaTI6@03o`00000c<c<0<c<c00h0<c<c00?o000004a<C01<C4`0201<C4`00`000000IVIV06IVIP07
06IVIP03o`00001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`06
0;>c/`030000003<c<`0c<c<00l0c<c<00<000000>KViP3Vi^H00`3Vi^H00`000000c<c<0<c<c00?
0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`05
07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`04
03<c<`Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`?o000000?oRKOd
ohVhmOn6]oH00_n6]oH2oh:fmP;oOKCg0_mf/_P2ofn_n0;oIJch00?oFJKgod^Pm_m;X?H00_lnU_80
2Ol/S>go887Xob21j?l=MN7o1VcLo`1Qe_l0GMCo0UcEoa5NeP02oa=OeP04obYUeoldJ]Wo=6[Iodab
e`;oFWWG0_mYPMP3og^5dP;oR8c@0onDT/l00onOV<goXIkAoj6Nd@03ojbScP03okFXc?ni[m3o^Jo@
00?o`K;<00Goa;[@ol^lc?o;_<cobkc<olk3c`03om?4b`03omK9c_oIbL[oflk<00;oflk<00?og=;>
omk@booNd/`00_oNd/`00ooNe<kogMG?omgAc002omgAc004omcAc_oJc<cof/c<om[<c0;oel_=00Co
elO;omC5booDaL_od/C<0ooB`LX01Oo@`<_od;k9olnmb_o?_L[oc[c800?oc[c90oo>_LT3olnobP?o
dL;<0_oBaLd3omC:c`04omO?dOl0003of=CDomSDe0;of]WF00GofMSFom[MfOoKhm_ofn?KomWQf`02
omWYh003omO]h_oFjN?odncU00;odNgW00Goc^kYolgYj_o:jNcob^W/olOXk@03o`00013ooooo0009
ooooo`04o`000?oooooooooooooooa;o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000C4a<04a<
C00804a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VI
V@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`03`3<c<`500000180c<c<00<0
00000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00<0<c<c1?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo0ol00004ooooo`;oRKSe00?o
Q[OfohJim_n6^OH00on1^?L2ogbfn0;oM[Ci0_m^/OT2ofB]n@;oBj3f0olkUo82oaV1i`03o`Edgol0
JMWo067F00;o05O@00Go05WCoa=Oe_lJH]Oo6V;GocAZf@02od5afP;oFWWG0_mYPMP2ogR9e`;oQi3F
0onEV=@4oj6Nd@03ojbSc_n_Zm?o^Jo@00?o^Jo@00Go`K;<olBjd?o4^]3oa;[@ol^lc003olk3c`03
om?4booFbLkoe/W>00;of<o@00?oflk<omcBc_oLd/h00_oMeM000ooNd/cog]C>omkDcP02omgEc`05
omgAc?oLdLkog=7>om[@cooJc<`00_oGbld2omG8cP05omC5booBa<cod/C<om;4c?oB`LX00_o@`</3
olnmbP06oljnboo>_<Woc[c9oljlbOo>_/_oc[g90_o?_l/01?o?_l[odL;<om72c?oA`/`3om;5c@;o
e<[?0_oGcm401_oIe=Co0000om[Ie_oJfMKofmoIom[Mf@;ofn?K00?ofnSMom[/h?oIjN000_oGkN80
0ooEknGod_7Wom7]i`02olk^j@03olc^k?o:jNcoanS]00;oa>O_00?oooooo`000?ooool03oooool0
00Wooooo00Co0000oooooooooooooooo4olI6AT00`000000<c<c03<c<`0>03<c<`030000001<C4`0
C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0
VIVI00D0VIVI00?o00000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00U0<c<c0030000002c/k<0
/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00ol00000Ogmo07moO`0507moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0203<c<`Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o00002Oooool2ohVjmP;oQ[Wf00?oPKSg
oh:in?ml^?T00_ml^?T2ogJfn@;oK[?j00?oI:ojoeNZnOmGZ_T00_m9XOH2ocRIlP05obB>kOlCPNKo
4h7Vo`1WeOl0GM000_l0Em02o`5Jd`03oaYReolUJ=[o9FSJ00;o@G7J00CoDG[LofV1f?mYPMSoJH7H
0_mhRML2ohN@eP?oUISD0_nQW]401?nSYMOo[j_Cojn[don_Zm<2okV_d005okbge?o4^]3oa;[@olBj
d?o8`M@00oo>`ll2om79dP06omK9c_oHcm3of<o@omS?d?oJe=;og=;>0_oMeM02omgGdP03omkDc_oM
eLoogMG?00;og=GA00Gog=7>om[@cooJd<oof<k@omO;c@03omG8cP?od/C<00Kod<;=om30boo@`<_o
d<3;olnoboo?_LX3oljnb`03oljlbOo>_/_oc[k;00?ocko;0_o@`/d01?oA`/cod/K>om;6c_oBaLd2
omC:c`06omO?d_oGcm7ofMCDomWDe?oKfmOo00000_oKgmT00ooLiM_ofn?Kom_Xg@02om[/h003omS`
h_oGkN;oeNoU00;od_7W00Goco;Yolk^jOo<k^cob>g]olG[k`02olCWk`03ol7Ul?oooooo0000013o
oooo0009ooooo`04o`000?oooooooooooooooa?o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000
C4a<04a<C00804a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000
VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`09@3<c<`00`000000
/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<00P0c<c<4ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3o`0000cooooo0_n9^oH2ohJjm`;o
P[Wh00?oO;SiogfinOmm^OT00omf]oX2ofjen`;oEj[i0_m8XoL2ocNKl`07ob>@kOl?PNCo3h7To`1c
f_l0F/_o05?8o`1AbP02o`5Jd`03o`QNe_lUJ=[o=77N00;o=77N00?oDG[Lof>4gOmSQ=d00_mdSMd3
ohN@eP03oiFHe?nEW][oXjGG00?oXjGG0_n_Zm<01Oni[m3o_;ODokbge?nl]mCoa;[@00?ob<7D00Co
c/??om79d_oAbM;oe=3E0ooHcm02om[DdP03om[HeOoMeM3ogMOB00;ogMOB00Cog=WDomgEcooLeM7o
g=GA0_oJe=<01?oJd<oof<k@omS>d?oEc=43omG8cP03om;7cooBa<cod<;=00;od<;=00?od<3;olno
boo?_l/00oo>_//01_o>_lcoc[k;oljnboo>_/_ocl3<olnob`?od<;=0ooBa/h01_oDbm3oe<[?omO?
d_oGcm;ofMGDomWDe0;ofm_G00Oo0000om_OfOoLiM_og>GKomcZgOoKkmoof^cP00;of?3R00Soe_?T
om?di_oBlNOoco;Yolcbjoo9lNgob>g]olG[k`;o`^W`00Co`NG`okkRlOnlgo7o00004?ooool000Wo
oooo00Co0000oooooooooooooooo5?lI6AT00`000000<c<c03<c<`0=03<c<`030000001<C4`0C4a<
00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00D0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00T0<c<c0030000002c/k<0/k>c
00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0203<c<`Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`?o00004Oooool2ohVlm`;oQ[_h0_n2^_T2ogfi
n@03ogJgn_mg^O_oMkWk00;oKkKk00?oIK?koeR/n_mH[?X00_m8YOL2ocNMl`;o3H?T00So07CHo`1U
cOl0F<Go04c2o`1>aol0E<oo25kFoaAUfP;o=77N0_m6O>42of>4g@;oM8gM0_n6U]`3oiFNfP?oXjGG
00?o[j_Cok:bfOnb/]T00onl]m@01_no_mWob<7DolS1e?o8`MCoblWHom79dP?oe=3E00?of<o@om[D
d_oJe=800_oJf=D3omgGdP;og=WD00?of]WFomcEdOoJe=<00_oJe=<3omS>d0;oeLcA00?oeLS>om;7
cooBall00oo@`/d2olk1cP04olnoboo>_lcoc[o<oljnb`?oc[o<00?oc[k;olo0c?o?`<`00oo@`/d2
om;6c`05om;6c_oDbm3oe<_@omO@dooGcm800_oIeM@01ooKg=Oofm_GomcQfOoLhMWo0000omcUfooL
j]d00_oKkml02?oIln7of?3RomKci?oCm>KocoKXolcfj_o<l^_obO7]0_o6knl02?o3kO7o`^W`okoV
lOnoi_7o_N?bokcOlOoooooo00003oooool000Wooooo00Co0000oooooooooooooooo5?lI6AT00`00
0000<c<c03<c<`0>03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`00
0000Ogmo07moO`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01`2c/k<00`00
0000c<c<0<c<c00U0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`00
0000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00?o000004a<C01<C4`01`1<C4`01000
0000<c<c03<c<`0c<c<4ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool3
o`0001Gooooo0_n:_OL2ohNmn0;oPkci0_mm^oX00omg^O_oN;[kogRjn`02og2ho0;oI[Gl00?oF[3k
odZXn?m:Z?P00_lhWo@01_lTU>go38GSo`b5hol0IL_o05O0o`1<^P;o04k700Go05WBoaAUf_ldLMko
=77NodIlh@02oe^7h`?oM8gM0_n6U]`2oiFNfP;oXjGG00?oYJgMok:bfOnb/]T00_nb/]T01Onl]mCo
_koIoknofOno_mWob<7D00;oblWH00KocM3KomC@eOoDd=Goe=3EomGEf?oJe=83om[He@03om[KeooM
em;og=WD00;og=WD00?of]WFomSHeooJe=<00_oJe=<01?oGd]Cof<k@omG<dOoEc=42om;:dP04om;7
coo@aM3od<G@om32c@?oc/7>1_o>_l`2olk1c@04olo0c?o@`lkod<?>om32c@;od/K?0_oDbm400ooD
bm3oem3ComO@d`03omWEe003om_LeooLhm[og>7I00;ogNOL00Co0000om_bgooKkmoofO?Q0_oFm^<0
0oo>nNKocoKXolcfjP02olSek003olGck_o6knoo`nga00;o`>[b00?o_nKaokgSl_ooool00_ooool0
0ol0003oooooooooo`0=ooooo`002Oooool01?l0003ooooooooooooooolEoaTI6@03o`00000c<c<0
<c<c00d0<c<c00<0000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0606IVIP030000001oOgl0
Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0
c<c<02@0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0
Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0040000000c<c<0
<c<c03<c<`Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00006Ooo
ool2oh^nn0;oR;ki0_n4_OT2ogjlnP04ogRjnomi_?_oNKckogVln`;oL[[l0_mX]o`2oefbn`;o>Z;d
00So9iS^o`j8i?l>R>Co07WHo`1WbOl0B[Co04k7o`1Cb`;o0F;H00?o973OodIlhOm6O>400_mKQn<2
og2Ci0;oQ9gS0onFY^43ojF]g@;o/[;I00Co];_NoknofOno_mWo_koI0_o2amh01Oo;bMSocM3Kolg@
foo=d=_oe=3E00;oeMGH0_oFf]/00ooJf=Gof]_Gom[Ke`02omWLf@03omcIe?oJfMKof]WF00;of=SG
00Gof]CComOBe?oGd]Coe=3EomG<d@03om;:dP?od<G@00Koc/CAolk1c_o>`Lkoc/7>olg1coo>_l`2
olg0cP04oljoc?o>`Lgoc/7=olk1c@?od<?>00?odLO@om;6cooDbm400_oDbm43omO@d`0>omWFe_oI
eMCofmcGom_LeooLhm[ogNWLomgWg?oLkMko0000om_bgooHm^7oe?WRomKfhoo>nNH2ol[ij003olOh
joo8mNcoaO?^00;o`_7`0_o0j_86ooooo`03o`000?oooooooooo00gooooo0009ooooo`04o`000?oo
oooooooooooooaGo6ATI00<0000003<c<`0c<c<03P0c<c<00ol00000C4a<04a<C00804a<C0030000
001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@03o`00
002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0903<c<`00`000000/k>c0;>c/`070;>c/`030000
002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000
001<C4`0C4a<00H0C4a<00@0000003<c<`0c<c<0<c<c1?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo0ol0000Nooooo`;oS;oh0_n9_oT2ohFnnP03oh2mnon1___oPKkk00;o
Nkgl0_md^o`2of^io0;oGkCl00?oDZojocjUm_lnYOH00_l[Vo001_l0OMWo06[9o`1H^ol0@[Co05?;
o`5Rf0;o4fkO0_liOND2oe6;j@;oL9?T0_n4WN<3oiJVh@03ojF]gOnV]^CoY[KT00?o];_N00Co_koI
ol;7g_o2amkoa<oS0oo=d=/2oloGg`03omGEf?oFf]_oe][K00;oe]kM00?of]_GomWLfOoIg=T00_oH
gM/00ooJfMKof=SGomSHe`02omKGf@03omOBe?oDd=Goe=3E00?od/[B0_o?b=<01Oo@aM3oc/CAolk4
dOo>a=7oc/7>00;ocL7?0oo=`<h2olg2c`04olk1cOo?a<ooclC?om33cP;odLO@0ooDbm42omKAe006
omO@dooIe]KofMKFom[MfOoKg=Oog>?J0_oMjM`02ooLkmkof_GPom_bgol0003oe?WRom3khoo<nnGo
ao_Vol[ij?o7n>_o`oO]00;o`OG`00?o`_7`okg[lonmjo<01oooool00ol0003oooooooooo`0=oooo
o`002Oooool01?l0003ooooooooooooooolFoaTI6@030000000c<c<0<c<c00d0<c<c00<0000004a<
C01<C4`02@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`8000009@3<c<`00`000000/k>c0;>c/`070;>c
/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0606IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo0ol0000Rooooo`;oSL3h0_n:`?T2ohJonP03oh6nnon3_o_oPkok
00;oOKkl0_mf_O`2offjo@;oHkOl0_mF/O/01?m6ZoSo;ioaobnOlOlKTnT2o`21f`03o`1;[?l0@[;o
04g100;o4fkO0_lZO^L00omARnWoJIW[ofVIj`03oh6Uj`;oUJkX1?nV]^@01?nd^mko]lCTokO4i?o2
amh3olC?h`06olg@foo?emoocmOOoloGgoo?g>;oe][K0ooFg]d00ooEhN3ofMcIomSMf`02omSMf`04
omGMgOoHf=Ooe]OIomKGf@;od]GK00Coe=3Eom7>eooAc]Ood/[B0oo?b=<3olk4d@;oc<?B00CocL7?
olc2d?o<`]3ocL3>0oo=`/l3olo4c`05om37d_oAam3odlcCom?<dooDbm400_oFdM@2omSHe`06omWF
e_oJgMWof]gIomcTfooLk=kogNWL0_oLkmh01_oGnN7od__QomCih_l0003oc?_UolOkiP;oa?_X00?o
_OS^ol7el?o1mO000_nlko@00onmjo?oooooooooo`06ooooo`03o`000?oooooooooo00gooooo0009
ooooo`04o`000?oooooooooooooooaOo6ATI00<0000003<c<`0c<c<03@0c<c<00`000000C4a<04a<
C00804a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`08P3<c<`00`000000/k>c0;>c
/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00ol00000IVIV06IV
IP0606IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooo`?o00009_ooool2ohk1n0;oRl7i0_n7`?X01?n3_o_oQL7k
ohG1non5`O/2ognoo0;oN;kl0_m`^od2ofJho@;oF[?k0_m;[OT2ob6Hk007o`b;h_l0N=;o03fWo`16
]?l0ElSo06_KobYni`02odF>kP;oJIW[0on1YN/2oiF^j0;oY[KT0_nW_n/01Onga>Co^<gZokS=j_nh
cN[oa<oS00?oa]OW00?ocmOOoloLh_o?g>800_o?hND00ooFg]goeN7PomGQh002om?RhP05omSMfooE
gMgoeMgMom;LgooFemT00ooBeM/00oo?d]codLkGolk<f002olk<f004olo8doo=amCocLODolk4d@;o
c<?B00CoblCColc2d?o<`]3oc<;@0oo=`/l2olg5dP03olo4coo@am;od<OB00?odlcC00CoeM;FomKA
e?oHf=Oof=SG0_oJgmX00ooJgMWog>CKomc/gP02om_bg`03omc_g_oGnN7od__Q00;ocOgQ00Kob?gR
o`000?noo>Goa?_Xokghk_nkmO42ok[bl`03okc_m?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool000Wooooo00Co0000oooooooooooooooo5olI6AT00`000000<c<c03<c<`0=03<c<`030000
001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00R0<c<c0030000
002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000
001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`04ooooo`03o`00
0?oooooooooo00oooooo1?l0000[ooooo`;oT<;h0_n=`_T00on9`O[oRl;ioh_2n@02ohO1nP;oPL3k
0_mk_o`2og>mo@;oJK[m0_mN]_`2oe2`nP;o@:Sf00Oo;YoaoaB@i_lDT>KoFP00o`1@_?l0I]?o67cV
00;oAHk^0_mQWo82ogb]lPCoU;S`00?oYko[ojO9lOnhcNX00_nhcNX01?nhe^ooa]OWolKGioo6enL2
olGNj`03oloLh_o?hNGocn7U00;ocNCX00?oeN7Pom?Rh_oCh^800_o@h^@00ooEgMgod]cOom;Lg`02
oloJh@03om;Efoo?d]cocm;L00?oc/cH0_o;b]T01?o=amCoblKFol_6e_o<`m83ol_4d`04olc2d?o<
`m;oc<?Bolg2c`;ocLGB00Koc/SDom37d_o@am;od<OBom7=eOoCc=<2omGBeP04omOIfOoHf=Oof]oJ
om[OfP;ofnKM00cog>cNom_bgooKl]oof?OPomCkh?o>oN3ob?kOolgmhOo8oN;o`ogSo`000?ninN`2
okSgk`03okKdl_njl_?ooooo00_ooooo00?o0000ooooooooool03Oooool000Wooooo00Co0000oooo
oooooooooooo6?lI6AT00`000000<c<c03<c<`0=03<c<`030000001<C4`0C4a<00P0C4a<00<00000
06IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<00000
0;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00Q0<c<c0030000002c/k<0/k>c00L0/k>c00<00000
09VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<00000
04a<C01<C4`01P1<C4`00`000000<c<c03<c<`04ooooo`03o`000?oooooooooo00oooooo0_l0000^
ooooo`;oTL;g0_n>`_P00on;`_WoSL;iohg2n@02ohS2nP;oQ<7k0_mm`?`2ogJno@;oKK_m0_mR]o`2
oeFbn`;oAZ_h0_leXo<01OlRV>co1hSOoeH00?l0BZoo05o700;o=Y3`0_mGY?L2ogb]lP;oU;S`0_nA
`OL2ojO9l@05okS=j_nhe^oo^=K_okSFkoo6enL00_o5g^/2olCSkP03oloQiOo=i>SocNCX00;obnKZ
00?odn;Rom3Ri?o@h^@00_o=hNH00ooBg=oocm[QoloJh@02ol_GhP04oloBg?o;d=gobm3Molk<f0;o
bl[I00Cob<WJol_6e_o;a]KoblKF0oo;a=<2ol[5eP04olc3d_o<a]Coc<KDolg5dP?oc/SD00God<OB
om7=eOoAcMGodm?HomGBeP02omOIf@0=omSPgOoJgm[ofnKMom_VgOoKk]oofOCQom_bgooHmn3oe?_P
olkmh?o8o]oo`_kOokcmg`02okCki004ok?jj?l0003o^?O_okKdlPoooooo00?o0000ooooooooool0
3?ooool000Wooooo00Co0000oooooooooooooooo6?lI6AT00`000000<c<c03<c<`0=03<c<`030000
001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`030000
002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00Q0<c<c0030000
002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000
001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<cooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0;?ooool2oi;3m`;oT<?h00GoSL;iohk3nOn>`oWo
S/?ioh[2nP02ohK2n`;oP<3l00CoNKkmog^oo?mk_ocoNkol0_mc_Od2ofVjo@;oGKGl0_lkYOD01olY
W>oo3hgTo`n=i?l0AJ?o05Vjo`1de_lVT>d00_mGY?L3ogJdn@03oi71mon<bOcoYM7g00?oYM7g00?o
^=K_okOMlonggO<00_ndh_H01?o4hnko`^K`ol;Vl?o=i>P2ol_VjP;ob>K/00?od>;TolgQi_o=hNH0
0_o9g^P01?o?f^7obmORol_Gh_o7e>@3ol_@g@03olS>goo;b]Wob<WJ00;ob<WJ00CoblKFolW6f?o9
a]SoblCC0oo:aMH3olc6e0?oc/SD0_o?c]P01OoAcMGodm?Hom?Cf?oEf]coemWI00;of>3M00CofNSO
om_VgOoKk]oofOCQ0_oEn^402oo@oN3obOkNol7ng?ncnm[o[_[LojcigondnnCo/o[Xok;hkOnbm_7o
0000013ooooo00?o0000ooooooooool03?ooool000Wooooo00Co0000oooooooooooooooo6OlI6AT0
0`000000<c<c03<c<`0=03<c<`030000001<C4`0C4a<00P0C4a<00?o000006IVIP1VIVH01P1VIVH0
0`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<0
0`000000c<c<0<c<c00P0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`0
0`000000<c<cooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;Oooool2
oiC3m`;oTL?h00?oS/?ioi33n?n@`oP00_n<`oT2ohS2nP03oh;1non4`O_oQ<7k00;oO/3l0_mf__d2
offko@;oH[Ol0_mD/O/01om6Z_So<9oaoc2OlOl5Q]ko05>^o`1^b_lDS^H00om9YoP2offjo@;oS<Wl
0_nUdOL2oj;In`03okOMlondh_Ko]>;f00;o/>Kh00?o`^K`okkXl_nnj?800_njj?@00oo8i^coa>G^
olCUkP02ol3Rl004olWNj?o5g>[oaMcZol_GhP?oamCT00Cobm3MolS>goo8c]ooa<cP0oo8bMX00oo6
b=cobLKHolO7fP02olO7fP04ol[5e_o9amSobLOHolc6e0;oc<[H00?oc/SDolo>f?o?c]P00_oAe=/0
1OoCdmSoeM[LomGJg?oFh]oof>3M00;ofNSO00cof?3RomKghooAnn;oeO[Qom3mh?o9o]ko`OkLok?k
f_n^n]co[?WOoj_ii?n[n>T4ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool000Wooooo00Co0000oooooooooooooooo6OlI6AT00`000000<c<c03<c<`0=03<c<`03o`00001<
C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002I
VIT0VIVI00L0VIVI00?o00000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00P0<c<c0030000002c
/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001V
IVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<cooooo`03ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0;Oooool2oiK3mP03oi?3monD`oOoU<?g00;oTL?h0_n>
`oT00on:`_[oS<;johc2nP02ohO2n`;oPL3l0_mi__`2og2ko@;oIKSl0_mI/_/2od^/n@06oc^TmOlT
V>go99S]oa:>iOl0J;go18WL0_lkYoD2of:no@;oQ/oo0_mmd_l01OnMgOgoU^3noiKPo_nFh?ko/>Kh
00;oZnOj00?o_^Sbok[Xm?njj?@00_nfioH00oo4iNko`>;`ol3Rl002ok_OlP05olGLj_o1fN_o`MW[
ol7Ijoo7e>@00_o3d^D01Oo8c]ooa<cPolC<h?o4c>3ob<WJ00;oa/SL0oo7amX01_o6bMcobLOHolW7
f?o9amSobL_Kolc:f0;ocLoK00KoclkHom7DfooAe=_odMCKom;KgooEf]`2omKRg`04omKZhooIj=oo
f?3RomKgh`;odO_R00Oob_kPol7ng?nXn=CoXoKEoj3ffOnPm]koY?K[00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01?l0003ooooooooooooooolJoaTI6@03
0000000c<c<0<c<c00d0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP03
0000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`03
0000003<c<`0c<c<0200c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@03
o`00001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C003
00000?oooooooooo00;ooooo00?o0000ooooooooool05?ooool2o`0002kooooo0_nG`oH00onD`oOo
U/?foiK3mP02oi?3m`;oT<?h00?oS<;johk3nOn>`oT00_n9`_X2oh?1n`;oO;ol0_mc_?d2ofVio@;o
GKCl0_m?[_X2ocnWmP06obnNlOlHTNSo0X?MocH00?l0OLOo7Z7U0_mF_oX2odVmm@;oLm;m0_nFh?h2
ohoPo@03oj_Wn_nVio_oY^Ok00;oX>Gl00Co]^Ofok7Tn?nai?So`>;`0_nkgo82okKLl`;o`MW[0_nl
eNd00oo3d^Go_m3Woko@i`02olC<h0;o`L_R00Coa/SLolC9g_o4bMkoalOJ0oo6bM`00oo9amSobL_K
olW;f`03olg?f`;oc]GO00KodMCKom;KgooBfmoodnCSomKRgooFj^<2omGbi@09om7hiOo;o>?odO_R
ol[nh?o1o]coV_;=oiG`c_nGl]koVo?V00Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`002Oooool01?l0003ooooooooooooooolKoaTI6@030000000c<c<0<c<c00d0<c<c
00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP03o`00001oOgl0Ogmo00H0Ogmo
00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<01l0c<c<
00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C00300000?oooooooooo00;ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03oiS3mOnF`oKoUl?f00;oUl?f
0_nD`oL00onA`oSoS/?ioho3n002oho3n0;oRl;j0_n5`O/00omn_ocoM[glogVmo002ogVmo0;oKk_l
0_mC/?X2odBYm`?o=:7c00Go3H[So`1leol0L<co07Njo`ZGe@02ocjik`;oJ]7k0_mQc_P00on8gogo
P]cmoh;Lo@02oj3Uo0;oVn;m00?o/NChojcQnOn/hOT00_nWgOX00onfg??o/MSdok7Hm002okcEk@;o
]m;^00?o_m3Wok_>j?nkc^P00_o1bn82okk<i003olC9g_o2bn7o`/_Q00;oa/WL0_o5cN001?o9bm_o
bM3OolW@goo=cm/2olkEg`;ocmgS00kod]_Oom?ThooCi>?od^cVom3dj?oEl^GodOSUol_lhoo2o]oo
]ocJoj;fconJl/goUO3>oi3_h@cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`002Oooool01?l0003ooooooooooooooolKoaTI6@030000000c<c<0<c<c00d0<c<c00<00000
04a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<00000
09VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<01l0c<c<00<00000
0;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00704a<C00300000?oooooooooo00;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0]ooooo`;oVL?d00?oUl?foiW3mOnI`oD00_nF`oH0
0onC`oOoU<?goiC3m`02oi73n0;oSL;i0_n7`OX00on1_o_oPl3koh?0n`02ogbno0;oLk_l0_mX^?`2
oe^cn`04odf]nOlhXoCo>:?dobNJkP;o4HgU00Go0H?Lo`1R_Ol0Gk?o07Nno`6@d002obZ^i0;oELOe
0_mlfOd2ogOEo@05oiKNo_n@f_ooT=[ooi3JoonWgOX00_nQfO/01Onaf?Co[=CeojcDmOn/e?Go]m;^
00;o/m3_00?o^lkXokS>jonhc^/00onnc>@3ol;;h@?oaLgP0_o5dN@01?o9d=oob]OSol[Ghoo>eMl2
oloMh`;ocnGW00_odnCSom;/i_o@m>Sod?CXol;mi?ngo=koZ_WFoigdc_n:j/GoQNS5ohCZf`0?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool000Wooooo00Co0000oooooooo
oooooooo7?lI6AT00`000000<c<c03<c<`0<03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<02@2c/k<00`000000c<c<0<c<c00N0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<
C01<C4`01`1<C4`00`00003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0;Oooool00onK`oCoW<?coic3l`02oi[3m0;oV<?e00?oU<?goiK3m_nF`oH00_nC`oL2ohk2
n003ohW1n_n<`OWoS<7i00;oQ/3j0_mn_o/2ogJlo0;oK;Wl0_mO]O`2oe:`nP0:od:Ymol/WO3o;9g`
oaZCj?l4Q]ko07WCo`1^bOl0I;co07W7o`:>e@?o9ZWV0_m>`?H00ombdOkoK/cnofk<oP03oh_Eo`03
oj7InonLe?_oW=Ck00;o[=Ce0_nWdOH00oncd>oo[/oaokS>j`03okS>j`04okk<i?nlcNOo_<gWol;;
h@;o`<kU00KoaLgPolGAi?o5dNCoaM7TolCHj?o:en<2ol[Nj004oloMhoo?iNOocnGWolg^jP;obOG/
00Ood?CXol;mi?ngo=koZ_WFoigdc_mcg[_oMnCE017ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`002Oooool01Ol0003ooooooooooooooooo000001_o6ATI00<0000003<c
<`0c<c<03@0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00H0IVIV00<0000007mo
O`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<
c03<c<`07P3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00H0VIVI00<0000007mo
O`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00H0C4a<00<00000oooo
ooooool00_ooool00ol0003oooooooooo`0Iooooo`;o0000;_ooool00onL`o?oWL?coig3l`02oi_3
l`;oVL?e00?oU/?foiO3mOnG`oD00_nD`_H2oi32n003ohc1nOn>`_SoS/;h00;oR<7j0_n1_o/2ogVm
o0;oKk_m0_mT]o`2oeNbn`;oAjch00[o=ZCcoanGjolOUn_o3HgRo`1ne_l0L/co06C0o`1U`?l0NLgo
18cJ0_lTXnT2odNhm`?oJLOn0_n5d?l00onLe?_oU]3loiK@o002ojOAmP;oXLoh0_n^co42okS>j`;o
]<k]00Co_<gWokW?jonicn_o`<kU0onodnT01Oo5dNCoa=SXolCHj?o3gngob]kX00;obNK/00Woa^o_
olg^j_o9mNcobOG/okOki?nYnMcoVo?Aohc/aon0iL005Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo0009ooooo`05o`000?ooooooooooooooool000007?lI6AT00`000000
<c<c03<c<`0<03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000
Ogmo07moO`0607moO`03o`00002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<02@2c/k<00ol00000
c<c<0<c<c00M0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000
Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`00003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool01_nM`o?o
W/;boik2l_nN`_;oW<?coi[3m0?oVl;c00CoVL;doiK2m_nF`_KoT/;g0_nD`_H2oi32n0;oR/7i0_n4
`?/00oml__coP;okoh2on`02ogNmo0;oKK_m0_mQ]o`01?mC/__o?:SeocbXmOl[X>l2oa:Ai007o`26
f_l0JlCo06Foo`1[aOl0Mlko0XSKob2Mj@02od>cmP?oHl;m00?oOlcoogW7oomiaol00on?cOd00onQ
coSoVlkioi_>n@02ojW?l`;o]<k]0_n`d?400onicn_o]m?_okOCk`02okoCj@;o_MW^00Koa=SXol?O
kOo1io7o`NOaolWVk?o6knl2ol3ek`05okOik?nYn>CoVO?IogWR`?m]f[L06?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`06o`000?ooooooooooooooo`00003o
00007?lI6AT00`000000<c<c03<c<`0<03<c<`03o`00001<C4`0C4a<00L0C4a<00<0000006IVIP1V
IVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0VIVI00?o00000;>c/`2c
/k<0202c/k<00`000000c<c<0<c<c00M0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2I
VIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0IVIV00<0000004a<C01<
C4`01P1<C4`00`00003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;Oooool00onN`_;oWl;aoio2l@02oig2lP03oi_2lonL`_;oW<;b00;oV/;d0_nG`_D00onD`_Ko
U/;foiK2mP02oi;2m`;oSL7i00?oQl3joh[1nOn:`OT00_n3`?/2og^oo003og:moOmW^_goIk[m00;o
F[Kl0_m;/?T02OljZ_Co7i_Yo`J<g?l6S=co06o3o`1W^ol0J<3o07;9o`21e`02oaNEiP;o>J[d00Co
E[WkogW7oomaa?ooLLCo0on9bod00onKc_WoULkkoiG>n`03ojC@m`04ok3@lOn]doCo[M?dokOCk`;o
]=Wc0_nmfNh01Onkgo;o]nOfokOWm_o1io7o_>oc00;o]?Cb00Go`?G_okOik?nYn>CoVO?Io`00000K
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00Co0000oooo
oooooooooooo0P0000000ol0003o6ATIoaTI6@0JoaTI6@030000000c<c<0<c<c00/0<c<c00<00000
04a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<00000
09VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<01/0c<c<00<00000
0;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C00300000?oooooooooo00;ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0]ooooo`03oio2lOnP`_7oX<;a00;oW/;a00?oW<;b
oik2l_nN`_800_nK`_<2oiW2m003oiK2m_nG`_GoUl;e00;oTl;f00?oSl;hoi72monA`_L00_n=`OT2
ohO1nP;oOl3l0_mg__d2offlo@;oHKWm0_mC]O/2od>_m`05oc:XlOlFV>?o5YSSo`1[^?l0I;L00_l0
OM800ol@T>;o<ZGaoc:Ul@02odjdnP?oJL7n0_n1bOh00onEc__oS/kmohk>o@03oioBnP04ojgCm?nX
f?SoZ=ShokCIl`;o/=og00Co^mobokOWm_ngioKo/>gg0_nUlOD01?ndm?;oZ?K]oiSchon6jm@Noooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00Co0000oooooooo
oooooooo0`0000000ol0003o6ATIoaTI6@0IoaTI6@03o`00000c<c<0<c<c00`0<c<c00<0000004a<
C01<C4`0201<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01P2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<01X0c<c<00<000000;>c
/`2c/k<02@2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C00300000?oooooooooo00;ooooo00?o0000oooo
ooooool07_ooool2o`0002kooooo00?oX<;aoj72l?nQ`_000_nO`_400onN`_;oWl;aoio2l@02oig2
lP03oi[2lonL`_?oW<;c00;oVL;d0_nF`_H00onA`_OoU<;foiC2mP02oho2n0;oR/7j0_n4`O/00oml
`?coPL7loh71o002ogW0o@;oKkon0_mT_?d2oeNio0;oB;Ch00Oo>JoboaZNholJW^?o2YGGo`1daOl0
Q]Oo7YcY00;oA;3g0omO__d2ogS8o`03ohk>oOn5coooQLoo00?oV=Gm00GoZ=Shoj;Lo?nIhOgoVN7m
ojWUnP02oj3ZnP06ok3]monUlOGoYO7eoiO`kOn4j]ooL=o>8Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`04o`000?ooooooooooooooo`<0000000?o0000oaTI
6OlI6AT06OlI6AT00`000000<c<c03<c<`0<03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c
/`2c/k<02@2c/k<00`000000c<c<0<c<c00J0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<
C01<C4`01P1<C4`00`00003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0;?ooool00onQ`_3oX/7_oj;1k`02oj32l003oio2lOnP`O3oX<7`00;oW/;a00?oW<;coig2
l_nM`_800_nK`_<2oiS2m003oiC2m_nF`_GoU/;e00;oT/;g0_n=`_T00on8`_[oS<;johc2nP02ohK2
n`;oO/;m0_mf`Oh00om/_okoM<;nogC2oP02of_1oP;oH;om0_mD_?X01Om7^?Ko::[WobRZiol0N/Co
1XoH00?o:jO]00CoA[Ofofk7oomQaOcoHLGl0_mjd?l2oi3Ho`;oQ=[n00OoVN7mohgSnomlh_CoO>;d
oi?[m_n1in_oKMkJ02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`00
2Oooool01?l0003oooooooooooooool400000003o`000?lI6AWo6ATI01Wo6ATI00<0000003<c<`0c
<c<0300c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<
c<`06@3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1o
Ogl01P1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<00000oooooooo
ool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02cooooo0onR`Nl2oj71k`03
oj31l?nQ`O3oXL7`00;oWl7a00?oWL;boik1lOnN`O400_nL`_800onI`_CoVl;coi_2l`02oiS2m0;o
UL;f00?oTL;hoi?3monC`oL00_n?`oP2oh[3nP03ohC3o?n9a?_oRLCk00;oPlCl0_mla?h2ogC4oP03
of_3o_mea_ooMLKo00;oKLKo0_mTaOd2oe[3n`06oe31molN003o3ISHo`fHf?lUZ^?oD/;g0_m0_>d3
oe_<m@05ogGJn_mSeNooC/cOocVob_lW/KD0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo0009ooooo`04o`000?ooooooooooooooo`D0000000?o0000oaTI6OlI6AT06?lI
6AT00`000000<c<c03<c<`0<03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1V
IVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<02@2c
/k<00`000000c<c<0<c<c00I0<c<c003o`00002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01P2I
VIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<
C4`00`00003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;Ooo
ool01OnR`NooXl7^oj?1k_nR`NooXL7`00;oX/7_0_nP`O000onN`O7oWl7`oio1l002oig1l@03oi_2
lonM`_;oWL;b00;oV/;c00?oUl;eoi[2m?nJ`_@00_nF`oH2oi?3m`03ohk4nOnBa?SoT/Ch00;oS/Cj
0_n9aO/00on3aOgoooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2_ooool000Wooooo00Co0000oooooooooooooooo1P000002o`0001Wo6ATI00<0000003<c<`0c<c<0
300c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0
1P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0
5`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0
1P1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<00000ooooooooool0
0_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02gooooo00?oXl7^ojC0k_nT`>h0
0_nS`Nh01OnR`NooXl7^oj?1k_nQ`NooWl7`00;oXL7`0_nO`O400onM`_;oW/7aoik1l@02oic2lP03
oi[2m?nL`_?oW<;c00;oVL?d0_nF`oH00onBa?Soooooooooo`1:ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool000Wooooo00Co0000oooooooooooooooo1`0000000ol0003o
6ATIoaTI6@0GoaTI6@030000000c<c<0<c<c00`0<c<c00?o000004a<C01<C4`0201<C4`00ol00000
IVIV06IVIP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00ol00000
/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<01H0c<c<00<000000;>c/`2c/k<02P2c/k<00`000000
VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000
C4a<04a<C00604a<C00300000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool2o`0002oo
oooo0_nT`>d00onT`>koY<3]ojC0k@02oj?0kP03oj;1konS`>koXl3^00;oX/7_00CoX<7`oik1lOnP
`O3oX<7`0_nN`_400onL`_?oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool000Wooooo00Co0000oooooooooooooooo200000000ol0003o6ATIoaTI6@0GoaTI
6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0606IV
IP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`0:0;>c
/`8000005@3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI00L0VIVI00<0000007mo
O`1oOgl01@1oOgl00`000000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<00H0C4a<00<00000oooo
ooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo0_nU`>`00onT
`>goYL3]ojG0k@02ojC0k@03oj?0k_nT`>goY<3]00;oXl3^00?oXL7_ooooooooool0E_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04o`000?oooooooooooooo
o`T0000000?o0000oaTI6OlI6AT05olI6AT00ol00000<c<c03<c<`0;03<c<`030000001<C4`0C4a<
00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00L0VIVI00<000000;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00A0<c<c003o`00002c/k<0/k>c
00/0/k>c00<0000009VIV@2IVIT01`2IVIT00ol00000Ogmo07moO`0507moO`030000001VIVH0IVIV
00H0IVIV00<0000004a<C01<C4`01P1<C4`00`00003oooooooooo`02ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0;Oooool2ojJok003ojG0kOnU_ncoYKo/00;oYL3]00?oY<3]oooo
ooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04
o`000?ooooooooooooooo`X0000000?o0000oaTI6OlI6AT05_lI6AT00`000000<c<c03<c<`0;03<c
<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00ol00000Ogmo07moO`0607mo
O`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0302c/k<00`000000c<c<0<c<c00>0<c<
c08000003P2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C00300000?oooooooooo00;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0]ooooo`;oY[o/00?oYKo/ooooooooool0H?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?oooooooooooooo
o`X0000000?o0000oaTI6OlI6AT05olI6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0C4a<
00L0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI
00L0VIVI00<000000;>c/`2c/k<0302c/k<2000000d0c<c<00<000000;>c/`2c/k<03@2c/k<00`00
0000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH00`00
0000C4a<04a<C00604a<C00300000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool2o`00
02gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo0009ooooo`04o`000?ooooooooooooooo`/0000000?o0000oaTI6OlI6AT05_lI6AT00`00
0000<c<c03<c<`0;03<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`00
0000Ogmo07moO`0707moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<03P2c/k<00`00
0000c<c<0<c<c0090<c<c003o`00002c/k<0/k>c00h0/k>c00?o000009VIV@2IVIT01`2IVIT00`00
0000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`00
0000<c<cooooo`03ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wo
oooo00Co0000oooooooooooooooo30000002o`0001Oo6ATI00<0000003<c<`0c<c<02`0c<c<00`00
0000C4a<04a<C00704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00ol0
0000VIVI09VIV@0709VIV@030000002c/k<0/k>c00h0/k>c00<00000o`00000000002000000A0;>c
/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0506IV
IP030000001<C4`0C4a<00H0C4a<00<0000003<c<oooool00oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo
000000_ooooo0009ooooo`04o`000?ooooooooooooooo`h0000000?o0000oaTI6OlI6AT05OlI6AT0
0ol00000<c<c03<c<`0:03<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH01P1VIVH0
0`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<0:@2c/k<0
0`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01@1VIVH0
0`000000C4a<04a<C00604a<C0030000000c<c?ooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00002ooo
ool000Wooooo00Co0000oooooooooooooooo3P0000000ol0003o6ATIoaTI6@0EoaTI6@030000000c
<c<0<c<c00/0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`0W0;>c/`030000002I
VIT0VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0506IVIP030000001<
C4`0C4a<00L0C4a<00<0000003<c<oooool00oooool00ol0003oooooooooo`0^ooooo`;o0000:?oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009ooooo`04o`000?oooooo
ooooooooo`l0000000?o0000oaTI6OlI6AT05OlI6AT00`000000<c<c03<c<`0:03<c<`03o`00001<
C4`0C4a<00P0C4a<00?o000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707moO`030000002I
VIT0VIVI00P0VIVI00<000000;>c/`2c/k<09@2c/k<00ol00000VIVI09VIV@0709VIV@030000001o
Ogl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00704a<C0030000000c
<c?ooooo00?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooool000002oooool000Wooooo00Co0000oooooooooooooooo3`00
00000ol0003o6ATIoaTI6@0EoaTI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0201<
C4`00`000000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0202I
VIT00ol00000/k>c0;>c/`0T0;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01P1o
Ogl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c<oooool00ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Iooo
ool00ol0003oooooo`00000:ooooo`002Oooool01?l0003oooooooooooooool@00000003o`000?lI
6AWo6ATI01Go6ATI00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C00804a<C0030000001V
IVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VIV@030000002c
/k<0/k>c0280/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`030000001V
IVH0IVIV00H0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`04ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Xooooo`;o00002_oo
ool000Wooooo00Co0000oooooooooooooooo4@0000000ol0003o6ATIoaTI6@0DoaTI6@030000000c
<c<0<c<c00X0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0706IVIP030000001o
Ogl0Ogmo00H0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0P0;>c/`030000002I
VIT0VIVI00T0VIVI00?o000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0606IVIP030000001<
C4`0C4a<00L0C4a<00?o000003<c<`0c<c<01?ooool00ol0003oooooooooo`0cooooo`;o00008ooo
ool00ol0003oooooooooo`1Wooooo`?o00002_ooool000Wooooo00Co0000oooooooooooooooo4P00
00000ol0003o6ATIoaTI6@0DoaTI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0201<
C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT02@2I
VIT00`00003o00000000000N0;>c/`03o`00002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl01`1o
Ogl00`000000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<00L0C4a<00<0000003<c<`0c<c<01?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hooo
ool4o`0000gooooo0009ooooo`04o`000?oooooooooooooooa80000000?o0000oaTI6OlI6AT05?lI
6AT00ol00000<c<c03<c<`0:03<c<`030000001<C4`0C4a<00T0C4a<00?o000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00`0VIVI00<000000;>c/`2c/k<06@2c
/k<2000000`0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0506IVIP030000001<
C4`0C4a<00P0C4a<00<0000003<c<`0c<c<01?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`04o`000?oooooo
oooooooooa<0000000?o0000oaTI6OlI6AT05?lI6AT00`000000<c<c03<c<`0:03<c<`030000001<
C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707moO`030000002I
VIT0VIVI00`0VIVI0P00000H0;>c/`030000002IVIT0VIVI00/0VIVI00<0000007moO`1oOgl01`1o
Ogl00`000000IVIV06IVIP0606IVIP030000001<C4`0C4a<00L0C4a<00@0000003<c<`0c<c<0<c<c
1?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
G?ooool4o`0001Cooooo0009ooooo`04o`000?oooooooooooooooa@0000000?o0000oaTI6OlI6AT0
5?lI6AT00`000000<c<c03<c<`0:03<c<`03o`00001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0707moO`0300000?l00000VIVI00d0VIVI0P00000C0;>c/`800000
00?o000009VIV@2IVIT02`2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV
00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0203<c<`Cooooo00?o0000ooooooooool0
>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo0009ooooo`04o`000?oo
oooooooooooooa@0000000?o0000oaTI6OlI6AT05?lI6AT00`000000<c<c03<c<`0:03<c<`030000
001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0907moO`030000
002IVIT0VIVI00d0VIVI0`00000=0;>c/`<000003`2IVIT00`000000Ogmo07moO`0807moO`030000
001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0203<c<`Cooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo
1?l0000Looooo`002Oooool01?l0003ooooooooooooooolE00000003o`000?lI6AWo6ATI01Co6ATI
00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl02@1oOgl00`000000VIVI09VIV@0?09VIV@<000001P2c/k<400000140VIVI
00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00L0C4a<
00<0000003<c<`0c<c<00P0c<c<4ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo00Co0000oooooooooooooooo
5P0000000ol0003o6ATIoaTI6@0CoaTI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0
201<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT0
4@2IVIT6000001@0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<00`0c<c<4ooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008oooool000Wooooo00Co
0000oooooooooooooooo5`0000000ol0003o6ATIoaTI6@0CoaTI6@030000000c<c<0<c<c00X0<c<c
00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0706IVIP0300000?l00000Ogmo00T0Ogmo
00?o000009VIV@2IVIT0:02IVIT2000000/0Ogmo00?o000006IVIP1VIVH01`1VIVH00ol00000C4a<
04a<C00704a<C003o`00000c<c<0<c<c00<0<c<c1?ooool00ol0003oooooooooo`0mooooo`;o0000
6Oooool00ol0003oooooooooo`19ooooo`Co00009oooool000Wooooo00Co0000oooooooooooooooo
600000000ol0003o6ATIoaTI6@0BoaTI6@030000000c<c<0<c<c00/0<c<c00?o000004a<C01<C4`0
1`1<C4`00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT0
9P2IVIT00`000000Ogmo07moO`0:07moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0
1`1<C4`00`000000<c<c03<c<`0403<c<`Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0000[ooooo`002Oooool01?l0003ooooooooo
oooooolH00000003o`000?lI6AWo6ATI01?o6ATI00<0000003<c<`0c<c<02P0c<c<00`000000C4a<
04a<C00804a<C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02@1oOgl3000002<0VIVI
0P00000<07moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c
03<c<`0403<c<`Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04?ooooo0ol0000_ooooo`002Oooool01?l0003ooooooooooooooolI00000003o`00
0?lI6AWo6ATI01?o6ATI00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C00804a<C0030000
001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0N09VIV@800000
301oOgl2000000T0IVIV00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0503<c<`Cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo
1?l0000booooo`002Oooool01?l0003ooooooooooooooolI00000003o`000?lI6AWo6ATI01?o6ATI
00<0000003<c<`0c<c<02P0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00P0IVIV
00?o000007moO`1oOgl02`1oOgl00ol0000000000000000K09VIV@8000003@1oOgl00`000000IVIV
06IVIP0806IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<01@0c<c<4ooooo`03o`00
0?oooooooooo04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Ooo
ool01?l0003ooooooooooooooolJ00000003o`000?lI6AWo6ATI01?o6ATI00<0000003<c<`0c<c<0
2P0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0
3@1oOgl2000001P0VIVI00<0000007moO`1oOgl03@1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<01P0c<c<4ooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool000Wooooo00Co
0000oooooooooooooooo6`0000000ol0003o6ATIoaTI6@0BoaTI6@030000000c<c<0<c<c00/0<c<c
00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00h0Ogmo
0P0000000ol00000VIVI09VIV@0A09VIV@8000003`1oOgl00`000000IVIV06IVIP0806IVIP030000
001<C4`0C4a<00P0C4a<00?o000003<c<`0c<c<01`0c<c<4ooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00Co
0000oooooooooooooooo700000000ol0003o6ATIoaTI6@0BoaTI6@03o`00000c<c<0<c<c00X0<c<c
00?o000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0906IVIP800000401oOgl6000000H0VIVI
1P0000000ol00000000007moO`0=07moO`80000000?o000006IVIP1VIVH0201VIVH00`000000C4a<
04a<C00904a<C0030000000c<c<0<c<c00L0<c<c1?ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009ooooo`04o`000?oo
oooooooooooooa`0000000?o0000oaTI6OlI6AT04_lI6AT00`000000<c<c03<c<`0;03<c<`030000
001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH02P1VIVH2000001@0Ogmo1P00000E07moO`030000
001VIVH0IVIV00X0IVIV00<0000004a<C01<C4`02@1<C4`00`000000<c<c03<c<`0803<c<`Cooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo
1?l00015ooooo`002Oooool01?l0003ooooooooooooooolM00000003o`000?lI6AWo6ATI01;o6ATI
00<0000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00/0IVIV
00<0000007moO`1oOgl0:`1oOgl00`000000IVIV06IVIP0:06IVIP03o`00001<C4`0C4a<00T0C4a<
00<0000003<c<`0c<c<02@0c<c<4ooooo`03o`000?oooooooooo04Sooooo0_l0000=ooooo`03o`00
0?oooooooooo02Sooooo1?l00019ooooo`002Oooool01?l0003ooooooooooooooolN00000003o`00
0?lI6AWo6ATI01;o6ATI00<0000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00904a<C003o`00
00000000IVIV00/0IVIV00?o00000000001oOgl09`1oOgl200000003o`00001VIVH0IVIV00X0IVIV
00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0:03<c<`05o`000?ooooooooooooooool0
0000C?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`00
2Oooool01?l0003ooooooooooooooolO00000003o`000?lI6AWo6ATI01;o6ATI00?o000003<c<`0c
<c<02`0c<c<00ol00000C4a<04a<C00:04a<C0030000001VIVH0IVIV00/0IVIV0P00000T07moO`80
00003P1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00/0<c<c00Go0000oooooooo
ooooooooo`00001=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00
057ooooo0009ooooo`04o`000?oooooooooooooooal0000000?o0000oaTI6OlI6AT04_lI6AT00`00
0000<c<c03<c<`0;03<c<`030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH0301VIVH20000
0200Ogmo0P00000?06IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02P0c<c<00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Mooooo`Co0000E?ooool000Wooooo00Co0000oooooooooooooooo800000000ol0
003o6ATIoaTI6@0BoaTI6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`02P1<C4`00`00
0000IVIV06IVIP0>06IVIP800000701oOgl200000100IVIV00<0000004a<C01<C4`02P1<C4`00`00
0000<c<c03<c<`0;03<c<`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool2o`00
00Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`04o`000?oooooooooooooo
ob00000000?o0000oaTI6OlI6AT04olI6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0C4a<
00X0C4a<0P00000@06IVIP0400000?l000000000000001@0Ogmo0`0000000ol00000IVIV06IVIP0>
06IVIP800000301<C4`00ol00000<c<c03<c<`0;03<c<`03o`000?lI6AWooooo00?ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001L
ooooo`002Oooool01?l0003ooooooooooooooolQ00000003o`000?lI6AWo6ATI01;o6ATI00<00000
03<c<`0c<c<0300c<c<00ol00000C4a<04a<C00;04a<C08000004P1VIVH7000000H0Ogmo1`00000B
06IVIP800000301<C4`2000000d0<c<c00?o0000oaTI6OlI6AT01?ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009oooo
o`04o`000?ooooooooooooooob80000000?o0000oaTI6OlI6AT04_lI6AT00`000000<c<c03<c<`0<
03<c<`030000001<C4`0C4a<00`0C4a<00<0000006IVIP1VIVH05P1VIVH6000001P0IVIV00<00000
04a<C01<C4`02`1<C4`00`000000<c<c03<c<`0<03<c<`04o`000?lI6AWo6ATIoaTI6@Cooooo00?o
0000ooooooooool0DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0
001Sooooo`002Oooool01?l0003ooooooooooooooolS00000003o`000?lI6AWo6ATI01;o6ATI00?o
000003<c<`0c<c<0300c<c<2000000d0C4a<00<00000o`0000000000<01VIVH200000003o`00001<
C4`0C4a<00/0C4a<00?o000003<c<`0c<c<0300c<c<00ol0003o6ATIoaTI6@02oaTI6@Cooooo00?o
0000ooooooooool0D_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009
ooooo`04o`000?ooooooooooooooob@0000000?o0000oaTI6OlI6AT04_lI6AT00`000000<c<c03<c
<`0=03<c<`8000003P1<C4`00`000000IVIV06IVIP0/06IVIP030000001<C4`0C4a<00`0C4a<0P00
000>03<c<`03o`000?lI6AWo6ATI00?o6ATI1?ooool00ol0003oooooooooo`1Dooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01?l0003ooooooooooooooolU00000003o`00
0?lI6AWo6ATI01;o6ATI00<0000003<c<`0c<c<03P0c<c<00`000000C4a<04a<C00<04a<C0<00000
:@1VIVH2000000h0C4a<00<0000003<c<`0c<c<03@0c<c<00ol0003o6ATIoaTI6@04oaTI6@Cooooo
00?o0000ooooooooool0EOooool00ol0003oooooo`000005ooooo`?o0000Koooool000Wooooo00Co
0000oooooooooooooooo9P0000000ol0003o6ATIoaTI6@0BoaTI6@030000000c<c<0<c<c00h0<c<c
00<0000004a<C01<C4`03P1<C4`00`00003o00000000000R06IVIP80000000?o00000000001<C4`0
3P1<C4`00`000000<c<c03<c<`0=03<c<`03o`000?lI6AWo6ATI00Go6ATI1?ooool00ol0003ooooo
ooooo`1Fooooo`;o000000?oooooo`000?l000000_l0001booooo`002Oooool01?l0003ooooooooo
oooooolV00000003o`000?lI6AWo6ATI01?o6ATI00<0000003<c<`0c<c<03@0c<c<00ol000000000
04a<C00A04a<C0030000001VIVH0IVIV01`0IVIV0`00000B04a<C0030000000c<c<0<c<c00d0<c<c
00?o0000oaTI6OlI6AT01_lI6AT4ooooo`03o`000?oooooooooo05Oooooo0_l0001fooooo`002Ooo
ool01?l0003ooooooooooooooolV00000003o`000?lI6AWo6ATI01Co6ATI00<0000003<c<`0c<c<0
3P0c<c<200000140C4a<1P00000D06IVIP@00000501<C4`00`000000<c<c03<c<`0=03<c<`03o`00
0?lI6AWo6ATI00Oo6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooo
oooooolW00000003o`000?lI6AWo6ATI01Co6ATI00<0000003<c<`0c<c<03`0c<c<00`000000C4a<
04a<C00D04a<C0@000002@1VIVH7000001H0C4a<0P00000?03<c<`03o`000?lI6AWo6ATI00So6ATI
1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooooooooolX00000003o`00
0?lI6AWo6ATI01Co6ATI00?o00000000000c<c<03`0c<c<00ol00000000004a<C00G04a<C0T00000
6`1<C4`00ol00000000003<c<`0>03<c<`;o00002olI6AT4ooooo`03o`000?oooooooooo0<oooooo
0009ooooo`04o`000?ooooooooooooooobT0000000?o0000oaTI6OlI6AT05OlI6AT00`000000<c<c
03<c<`0?03<c<`800000>01<C4`200000100<c<c00?o0000oaTI6OlI6AT02olI6AT4ooooo`03o`00
0?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooobX0000000?o0000oaTI6OlI6AT0
5OlI6AT00`000000<c<c03<c<`0@03<c<`030000001<C4`0C4a<0380C4a<0`00000A03<c<`03o`00
0?lI6AWo6ATI00co6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooo
ooooool[00000003o`000?lI6AWo6ATI01Go6ATI00?o000003<c<`0c<c<0400c<c<01000003o0000
00000000000^04a<C003o`0000000000<c<c0180<c<c00?o0000oaTI6OlI6AT03OlI6AT4ooooo`03
o`000?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooob`0000000?o0000oaTI6OlI
6AT05OlI6AT00`000000<c<c03<c<`0C03<c<`800000:P1<C4`2000001<0<c<c0_l0000@oaTI6@Co
oooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo;@0000000ol0003o
6ATIoaTI6@0EoaTI6@8000005@0c<c<00`000000C4a<04a<C00S04a<C0@000004`0c<c<2o`0001;o
6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003oooooooooooooool^00000003
o`000?lI6AWo6ATI01Ko6ATI00<0000003<c<`0c<c<04`0c<c<3000001l0C4a<0`00000F03<c<`03
o`000?lI6AWo6ATI01;o6ATI1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooo
ooooooooool_00000003o`000?lI6AWo6ATI01Ko6ATI00<0000003<c<`0c<c<05@0c<c<200000003
o`0000000000000000800000501<C4`4000001P0<c<c0_l0000DoaTI6@Cooooo00?o0000oooooooo
ool0coooool000Wooooo00Co0000oooooooooooooooo<00000000ol0003o6ATIoaTI6@0FoaTI6@03
o`0000000000<c<c01/0<c<c5000000I03<c<`?o00005_lI6AT4ooooo`03o`000?oooooooooo0<oo
oooo0009ooooo`04o`000?oooooooooooooooc40000000?o0000oaTI6OlI6AT05olI6AT00`000000
<c<c03<c<`1503<c<`03o`000?lI6AWo6ATI01Oo6ATI1?ooool00ol0003oooooooooo`3?ooooo`00
2Oooool01?l0003ooooooooooooooolb00000003o`000?lI6AWo6ATI01Oo6ATI00<00000o`00000c
<c<0@P0c<c<2o`0001Wo6ATI0_l00003ooooo`03o`000?oooooooooo0<oooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool0coooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`3?ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo0<oooooo0009oooookKo0000dOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]_l0
000AoooookKo00002_ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0Foooool00`000?oo003oo`00o`0Hooooo`80003o>_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo0P00000Cooooo`03o`000?oooooooooo00cooooo00<00000o`00
0?l00000;_ooool2000000_ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`0300000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0FOooool20000oagooooo0P000?lhooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08oooool00`00003oooooooooo`0Aooooo`0300000?l0003ooooo00gooooo00<00000oooooooo
ool03ooooolC000000oooooo0P00000:ooooo`0300000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo05Sooooo00<0003oooooooooool07oooool20000ocKooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Rooooo`0300000?oooooooooo017ooooo00<00000ooooooooool0
3?ooool2000000oooooo0`00000Cooooo`@000003Oooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Oooooo00<0003oooooooooool08_oo
ool00`000?ooooooooooo`0cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_oo
ool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool03Ooo
ool00ol000000000ooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Roooooa40003o8oooool0
0`000?ooooooooooo`0Tooooo`03o`00oooooooooooo03;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Pooooo`8000004Oooool2000000cooooo00<00000o`00000000002oooool4
00000003o`000?oooooooooo01_ooooo0`00000;ooooo`8000002Oooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Nooooo`@0003o4Oooool00ol00?l0003o0000o`030000
oa_ooooo0P000?lXooooo`030000oooooooooooo037ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Nooooo`8000004_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo
00_ooooo00<00000ooooooooool08oooool2000000_ooooo00<00000ooooooooool01oooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`@0003o6oooool30000oaOo
oooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`0`ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool02_ooool2000002Sooooo00<00000ooooooooool02Oooool00ol0003o
ooooooooo`07ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool03Oooool00`00003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo
0`000?lRooooo`80003o5?ooool00`000?ooooooooooo`0[ooooo`030000oooooooooooo02oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`0300000?oooooooooo017ooooo
00<00000ooooooooool02_ooool00`00003o0000ooooo`0:ooooo`8000004Oooool200000004o`00
000000000000000000Ko00003_ooool00ol00000000000000009ooooo`0300000?oooooooooo00Oo
oooo00<00000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`0300000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05Oooool20000obOooooo
0P000?lAooooo`030000oooooooooooo02gooooo0P000?l_ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool02Oooool2000000oooooo1000000<ooooo`?o00003_ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool04oooool00ol00?l0003oooooo`0Zooooo`80003o3_ooool00`000?oooooooooo
o`0`ooooo`030000oooooooooooo02cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Kooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo00cooooo0`00000Cooooo`Co00002oooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool04Oooool20000oboooooo0P000?l<ooooo`030000oooooooooooo033ooooo00<0003o
ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00<00000
ooooooooool04?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool02_ooool3000001[ooooo0_l0000:ooooo`0300000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0?oooo
o`80003o<oooool00`000?ooooooooooo`08ooooo`030000oooooooooooo03;ooooo00<0003ooooo
ooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00<00000oooo
ooooool04?ooool00ol0003oooooooooo`0:ooooo`8000002Oooool00`00003o0000ooooo`08oooo
o`@000007oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo00<00000ooooooooool03?ooool00`00003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00kooooo00<0003ooooooooo
ool0=?ooool20000o`Oooooo00<0003oooooooooool0=?ooool00`000?ooooooooooo`0Zooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00`00003o0000ooooo`0Aooooo`03
00000?oooooooooo00[ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo02?ooooo0_l00008ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0<ooooo`80003o
>Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo03Cooooo00<0003oooooooooool0
:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00<00000ooooooooool0
4Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Oooooo0P000009ooooo`800000
3oooool<o`0000gooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02_oo
ool20000occooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`0fooooo`030000oooo
oooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`0300000?oo
oooooooo017ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Oooooo0P00000=ooooo`0400000?l0003o0000o`0000cooooo1?l0000:ooooo`;o0000
1oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool0
1oooool00ol0003oooooooooo`0<ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`0mooooo`05o`00oooo
ooooooooooooo`000?l0>?ooool00`000?ooooooooooo`0Yooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool02?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo
0`00000Dooooo`;o00002_ooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`08ooooo`030000oooooooooooo03oooooo00<0003oooooo`000?l0>_ooool00`000?oooooooooo
o`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00`00003ooooooooo
o`0Aooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo00Sooooo0`00000Iooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00`000?ooooooooooo`10
ooooo`80003o>_ooool00`000?ooooooooooo`0Xooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool06oooool2o`0000Wooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0<
ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool01oooool00`000?ooooooooooo`12ooooo`030000oooooooooooo03Sooooo00<0003ooooo
ooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000oooo
ooooool04Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Oooooo0P000007oooo
o`8000002?ooool00`00003o00000000000Pooooo`;o00001oooool00ol0003oooooooooo`05oooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`0300000?oooooooooo00_ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo04;ooooo00<0003oooooo`00
0?l0>_ooool00`000?ooooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00Gooooo00<0003oooooooooool0@oooool010000?ooooooooooool00?liooooo`03
0000oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03
00000?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo00Kooooo00<00000ooooooooool01oooool00`00003oooooooooo`0:ooooo`80
00003Ol0000<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01?ooool00`000?ooooooooooo`13ooooo`030000oooooooooooo00;ooooo
00<0003oooooooooool0=oooool00`000?ooooooooooo`0Vooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`0300000?oooooooooo00[ooooo
00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo
00<00000o`000?ooool02_ooool2000000oooooo1?l00009ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0;ooooo`0300000?l0003ooooo00?ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00`000?oooooooooo
o`13ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool0=_ooool00`000?oooooooooo
o`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo00_ooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02Oooool00`00003o0000oooo
o`0Dooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00<0
0000ooooooooool01?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool03?ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo00;ooooo00<0003oooooooooool0A?ooool00ol00?ooooooooooo`05
ooooo`030000oooooooooooo03Kooooo00<0003oooooooooool09Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00Oooooo0`00000Iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000
ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`02oooo
o`030000oooooooooooo04Cooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0foooo
o`030000oooooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>oooo
o`0300000?oooooooooo013ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06oooo
o`0300000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool03?ooool01@00003ooooooooooooooooo
000000[ooooo0009ooooo`05o`000?ooooooooooooooo`000?l0Aoooool00`000?ooooooooooo`06
ooooo`030000oooooooooooo03Gooooo00<0003oooooooooool09Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Gooooo00?o000000000?ooool07_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0<
ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00Co0000ooooooooool0003oB?oo
ool00`000?ooooooooooo`07ooooo`030000oooooooooooo03Cooooo00<0003oooooooooool09Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00<00000ooooooooool04Ooo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool08?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`0<ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00Co
0000ooooooooool0003oB?ooool00`000?ooooooooooo`07ooooo`030000ooooool0003o00X0003o
:_ooool00`000?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Cooooo0P000007ooooo`030000
0?oooooooooo00cooooo3?l0000:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00cooooo00@00000oooooooooooo
00002_ooool000Wooooo00?o0000ooooo`000?l0BOooool00`000?ooooooooooo`05oonf`@@0003o
2ooo]/450000obGooooo00<0003oooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00_ooooo00<00000ooooooooool04?ooool00ol000000000ooooo`0:ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Gooooo00<0okK10000003o]/402@3o]/4400000003o`00003o]/40okK100H0okK1
1?ooool2o`0000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00<00000ooooooooool03?ooool01000003oooooooooool0000:ooooo`00
2Oooool00ol0003oooooooooo`19ooooo`040000oooo]/7ookK1oonf`@@0003o0ooo]/400`000?oo
okK1oonf`@0>oonf`@80003o00CookK100000000000000007oooool00`000?ooooooooooo`0Uoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0@oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool00_ooool40?nf`@030000003o]/40okK1
00H0okK10P00000@0?nf`@?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0<oooo
o`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo04Kooooo0ooo]/401000
0?oookK10000o`000?l8oonf`@030000oooo]/7ookK100oookK11@00000Nooooo`030000oooooooo
oooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooo
oooo017ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`060?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/404`3o]/400ooooooo0000ooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool01?ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00cooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool0@oooool6
oonf`@80003o2ooo]/400`000?oookK1oonf`@0>oonf`@D000000_oo]/4Looooo`030000oooooooo
oooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooo
oooo013ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo00Gooooo00<00000ooooooooool01?ooool00`000000okK10?nf`@060?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/405P3o]/400ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00cooooo00<00000ooooool000002_ooool000Wooooo00?o0000ooooooooool0@?ooool9oonf
`@030000oooo]/7ookK100[ookK100<0003ooonf`Ooo]/403_oo]/45000000030000oooo]/7ookK1
00;ookK16Oooool00`000?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00?ooooo0P3o]/400ol0
0000okK10?nf`@040?nf`@03o`0000000000okK100H0okK100<00000o`00003o]/406@3o]/400ol0
0000okK10?nf`@06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo00cooooo00<00000ooooool000002_ooool000Wo
oooo00?o0000ooooooooool0?Oooool:oonf`@030000ool00?l0003o00gookK100<0003ooonf`Ooo
]/403_oo]/43000000;ookK10P000?l5oonf`AKooooo00<0003oooooooooool09Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool04Oooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01Oooool00`00003o
ooooooooo`050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000
okK10?nf`@0K0?nf`@03o`00003o]/40okK10080okK10oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0<ooooo`03
00000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo03[ooooo3?oo]/4010000?oookK1
oonf`@000?l=oonf`@03o`00oooo]/7ookK101GookK10P000?l4oonf`AGooooo00<0003ooooooooo
ool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<00000oooooooo
ool04Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool01Oooool00`000000okK10?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/401@3o]/400`000000okK10?nf`@0M0?nf`@03o`00003o]/40okK10080okK10oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`0;ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo03Wooooo
3?oo]/401@000?oookK1oonf`Ooo]/40003o00gookK100<0003ooonf`Ooo]/405ooo]/400`000?oo
okK1oonf`@02oonf`ACooooo00<0003oooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Sooooo00<00000ooooooooool04?ooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo00Oooooo00<00000ooooooooool01Oooool00`000000okK10?nf`@040?nf`@03
0000003o]/40okK100@0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@0N0?nf`@03
o`00003o]/40okK10080okK10oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo03Oooooo3Ooo]/400`000?oookK1oonf`@02oonf`@030000
oooo]/7ookK100cookK100<0003ooonf`Ooo]/405ooo]/400`000?oookK1oonf`@04oonf`A7ooooo
00<0003oooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo
00<00000ooooooooool04?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool20?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100X0okK12000000<0?nf`@03o`00
003o]/40okK100D0okK100?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0eooooo`kookK100<0003ooonf`Ooo]/400ooo]/400`000?oookK1oonf
`@0=oonf`@030000oooo]/7ookK101OookK100?o003ooonf`Ooo]/401Ooo]/4?ooooo`030000oooo
oooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00;ooooo0`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@080?nf`@<00000203o]/43000000X0okK100?o
00000?nf`@3o]/40103o]/400ol00000okK1ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo03Cooooo3_oo]/400`000?oookK1oonf`@04oonf`@030000oooo]/7o
okK100gookK100<0003ooonf`Ooo]/405ooo]/400`000?oookK1oonf`@06oonf`@kooooo00<0003o
ooooooooool09Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000
ooooooooool04?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000
ooooooooool00_ooool40?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@050?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o]/40
0`000000okK10?nf`@070?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`Oooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool0
0`00003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool03?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0cooooo`kookK100<0003ooonf
`Ooo]/401Ooo]/400`000?oookK1oonf`@0=oonf`@030000oooo]/7ookK101OookK100<0003ooonf
`Ooo]/401ooo]/4<ooooo`030000oooooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`07ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`06ooooo`0400000?ooooooooooooooo`@0okK100<000000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100D0okK100<000000?nf`@3o]/401`3o]/40
0ol0000000000?nf`@0?0?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
03;ooooo3_oo]/400`000?oookK1oonf`@06oonf`@030000oooo]/7ookK100kookK100<0003ooonf
`Ooo]/405ooo]/400`000?oookK1oonf`@07oonf`@_ooooo00<0003oooooooooool09_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool04?ooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01@3o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`00
0000okK10?nf`@070?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/400ol0
0000okK10?nf`@040?nf`@04o`00003o]/40okK10?nf`@;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0<?ooool@oonf`@030000oooo]/7ookK100OookK100<0003ooonf
`Ooo]/403Ooo]/400`000?oookK1oonf`@0Hoonf`@030000oooo]/7ookK100SookK12Oooool00`00
0?ooooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00
003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01_ooool00`00
003ooooo0?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@050?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/404@3o]/400`00
0000okK10?nf`@070?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400P3o]/400ooo
oooo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0_oooooa3ookK100<0003ooonf`Ooo
]/402Ooo]/400`000?oookK1oonf`@0<oonf`@030000oooo]/7ookK101WookK100<0003ooonf`Ooo
]/402?oo]/47ooooo`030000oooooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00003o
ooooooooo`06ooooo`030000003o]/40okK100D0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401`3o]/400`000000
okK10?nf`@0C0?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/40103o]/400ol00000
okK10?nf`@030?nf`@03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`03ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01oooool00`00003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02kooooo
4Ooo]/400`000?oookK1oonf`@09oonf`@030000oooo]/7ookK100cookK100<0003ooonf`Ooo]/40
6Ooo]/400`000?oookK1oonf`@09oonf`@Kooooo00<0003oooooooooool09oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool04?ooool00`00003ooooo
ooooo`09ooooo`0300000?oooooooooo00Kooooo00<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK101<0okK100<000000?nf`@3o]/401P3o]/400ol00000okK1
0?nf`@040?nf`@03o`00003o]/40okK100<0okK100?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0;OoooolAoonf`@030000oooo]/7ookK100_ookK100<0003ooonf`Ooo]/402ooo
]/400`000?oookK1oonf`@0Joonf`@030000oooo]/7ookK100WookK11?ooool00`000?oooooooooo
o`0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003ooooooooo
o`0@ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01Oooool00`3o]/4000000?nf
`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/405@3o]/400`000000okK10?nf
`@050?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK1oooo
o`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0/oooooa;ookK100<0003ooonf`Ooo]/402ooo]/40
0`000?oookK1oonf`@0<oonf`@030000oooo]/7ookK101[ookK100<0003ooonf`Ooo]/402Ooo]/43
ooooo`030000oooooooooooo02Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`05
ooooo`030?nf`@000000okK100H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@0F
0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@03
0?nf`@03o`00003o]/7ooooo00;ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`04
ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0;
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo4ooo]/400`00
0?oookK1oonf`@0;oonf`@030000oooo]/7ookK100cookK100<0003ooonf`Ooo]/406_oo]/400`00
0?oookK1oonf`@0:oonf`@;ooooo00<0003oooooooooool0:?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`09oooo
o`0300000?oooooooooo00Cooooo0P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/405`3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK1
00@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@02ooooo`03o`000?oooooooooo
00?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo
00Kooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Zoooooa?ookK100<0003ooonf`Ooo]/403Ooo]/400`000?oookK1oonf`@0;oonf`@03
0000oooo]/7ookK101_ookK100<0003ooonf`Ooo]/402Ooo]/400oooool0003oooooo`0Zooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0@ooooo`03
o`000?oooooooooo00Wooooo00<00000ooooooooool00oooool30?nf`@030000003o]/40okK100D0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@0G0?nf`@030000003o]/40okK100D0
okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK100;o
oooo00?o0000ooooooooool00oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo02[ooooo4ooo]/400`000?oookK1oonf`@0=oonf`@030000
oooo]/7ookK100_ookK100<0003ooonf`Ooo]/406ooo]/400`000?oookK1oonf`@0:oonf`@030000
oooooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`030000
0?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`03ooooo`<0okK1
00<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK101L0okK1
00<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK1
00Ko00000?nf`@3o]/40okK1ooooool00005ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool01?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0:OoooolCoonf`@030000oooo]/7ookK100oo
okK100<0003ooonf`Ooo]/402_oo]/400`000?oookK1oonf`@0Loonf`@030000oooo]/7ookK100So
okK100<0003ooonf`Oooool0:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo00<00000ooooooooool04?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00;o
oooo103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o
]/406@3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o
]/400`3o]/400ol00000okK10?nf`@020?nf`@03ooooool0003ooooo00Cooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0XoooooaCookK1
00<0003ooonf`Ooo]/404?oo]/400`000?oookK1oonf`@09oonf`@030000oooo]/7ookK101cookK1
00<0003ooonf`Ooo]/401ooo]/4010000?oookK1oonf`Ooo]/4Zooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00[o
oooo00@00000oooooooooooooooo1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00H0okK100<000000?nf`@3o]/406@3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK1
00<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`000?oooooooooo
00?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo
00Kooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0WoooooaCookK100<0003ooonf`Ooo]/404_oo]/400`000?oookK1oonf`@08oonf`@03
0000oooo]/7ookK101gookK100<0003ooonf`Ooo]/401Ooo]/400`000?oookK1oonf`@03oonf`BWo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo013o
oooo00<00000ooooooooool02_ooool00`00003oooooooooo`060?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@0I0?nf`@030000003o]/40okK100D0
okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK100<0
okK100?o0000ooooooooool00oooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo02Kooooo0_oo]/430000013ookK100<0003ooonf`Ooo]/40
4ooo]/400`000?oookK1oonf`@07oonf`@030000oooo]/7ookK101gookK100<0003ooonf`Ooo]/40
1?oo]/400`000?oookK1oonf`@04oonf`BWooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`04ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`060?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40103o]/400ol00000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@0J0?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK1
0?nf`@030?nf`@03o`00003o]/40okK100<0okK100?o0000ooooooooool00oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo00?o
okK10000000000000`00000?oonf`@030000oooo]/7ookK101CookK100<0003ooonf`Ooo]/401_oo
]/400`000?oookK1oonf`@0Moonf`@030000oooo]/7ookK100?ookK100<0003ooonf`Ooo]/401_oo
]/4Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00`00003ooooooooo
o`0@ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01P3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/406P3o]/400`000000okK10?nf
`@050?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf
`@030?nf`@03o`00003o]/7ooooo00?ooooo00<00000ooooooooool01?ooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Uooooo`;ookK11@00000>oonf`@030000oooo]/7o
okK101KookK100<0003ooonf`Ooo]/401Ooo]/400`000?oookK1oonf`@0Moonf`@030000oooo]/7o
okK100;ookK100<0003ooonf`Ooo]/402?oo]/4Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo00<00000
ooooo`3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100@0okK100?o0000
0?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/406P3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100<0okK100?o0000
0?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK100?ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Toooo
o`?ookK11@00000>oonf`@030000oooo]/7ookK101KookK100<0003ooonf`Ooo]/401Ooo]/400`00
0?oookK1oonf`@0Moonf`@050000oooo]/7ookK1oonf`@000?l02ooo]/4Wooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo00Wooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK100@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100D0okK100<000000?nf`@3o]/406P3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40
okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40
okK100?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Tooooo`CookK10`00000?oonf`@030000oooo]/7ookK101OookK10P000?l5oonf
`@030000oooo]/7ookK101gookK100@0003ooonf`Ooo]/7o003o3Ooo]/4Vooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oooooo
oooo00Wooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK100@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100H0okK100<000000?nf`@3o]/406@3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40
okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40
okK10?nf`@?ooooo00<00000ooooooooool00oooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0SoooooaOookK100<0003ooonf`Ooo]/406Ooo]/400`000?oookK1oonf`@02
oonf`@030000oooo]/7ookK101gookK10`000?l>oonf`BKooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool02Oooool0
0`000000okK10?nf`@060?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401P3o]/40
0`000000okK10?nf`@0I0?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK100Co00000?nf`@3o]/40okK10ooo
ool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02?ooooo5ooo]/400`000?oookK1oonf`@0Joonf`@80003o00CookK100000000000000007Ooo
]/420000oa7ookK19Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool04?ooool00`00003oooooooooo`09ooooo`030000003o]/40okK100H0okK100<0
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK101T0okK100<0
00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK100?o
00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@;ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0RoooooaSookK100<0003o
oonf`Ooo]/407?oo]/45000001_ookK100@0003ooonf`Ooo]/40003o4Ooo]/4Tooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0@ooooo`0300000?oo
oooooooo00Sooooo00<0okK10000003o]/40203o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/40603o]/400`000000okK10?nf`@060?nf`@03o`00003o
]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@03o`00003o
]/40okK10080okK100?ooooo00000?ooool01Oooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0QoooooaWookK100<0003ooonf`Ooo]/407?oo]/45000001[ookK100Go003o
oonf`Ooo]/7ookK10000o`0Aoonf`BCooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`04ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool01oooool20?nf`@030000003o
]/40okK100L0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@03o`00003o
]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@030000003o
]/40okK101P0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o
]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@03ooooo`00
003ooooo00Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08OoooolI
oonf`@030000oooo]/7ookK101cookK11@0000020000oaGookK10`000?l4oonf`@030000oooo]/7o
okK1013ookK18oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000
ooooooooool04?ooool00`00003oooooooooo`07ooooo`80okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100H0okK100<000000?nf`@3o]/40603o]/40
0`000000okK10?nf`@060?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/40
0ol00000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100<00000ooooooooool01?ooool0
0`00003oooooooooo`05ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Poooooa[ookK100<0003ooonf
`Ooo]/407Ooo]/43000000?ookK110000?l=oonf`@@0003o1ooo]/400`000?oookK1oonf`@0@oonf
`B?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo
013ooooo00<00000ooooooooool01_ooool30?nf`@030000003o]/40okK100L0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100<000000?nf
`@3o]/40103o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK101L0okK100<000000?nf
`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK100?o00000?nf
`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@0300000?oooooooooo00Cooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08?oooolJoonf`@030000oooo]/7ookK101ko
okK100<0003ooonf`Ooo]/401_oo]/4=0000o`_ookK100<0003ooonf`Ooo]/404Ooo]/4Rooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0@ooooo`03
00000?oooooooooo00Gooooo103o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100D0
okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100?o00000?nf`@3o]/401P3o]/42000001P0okK100<000000?nf`@3o]/401@3o]/400ol00000
okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000
okK10?nf`@030?nf`@0300000?oooooooooo00Cooooo00<00000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07ooooolKoonf`@030000oooo]/7ookK101gookK100<0003ooonf`Ooo]/40
7_oo]/400`000?oookK1oonf`@0Coonf`B7ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`05ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool01?ooool50?nf`@030000
003o]/40okK100H0okK100?o00000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@03o`00
003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@070?nf`@030000
003o]/40okK101D0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00
003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@030000
003o]/7ooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oo
oolLoonf`@030000oooo]/7ookK101gookK100<0003ooonf`Ooo]/407_oo]/400`000?oookK1oonf
`@0Coonf`B7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool00oooool60?nf`@030000003o]/40okK100H0okK100<0
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100<0
00000?nf`@3o]/40103o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK101D0okK100<0
00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o
00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@030000003o]/7ooooo00Cooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oooolLoonf`@030000oooo]/7o
okK101gookK100<0003ooonf`Ooo]/407_oo]/400`000?oookK1oonf`@0Doonf`B3ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00oooooo00<00000
ooooooooool00oooool60?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@070?nf`@030000003o]/40okK101<0okK100<000000?nf`@3o]/401`3o]/40
0ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/40
0ol00000okK10?nf`@040?nf`@030000003o]/7ooooo00Cooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool07OoooolMoonf`@030000oooo]/7ookK101cookK100<0003ooonf
`Ooo]/407ooo]/400`000?oookK1oonf`@0Doonf`B3ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`06ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool00_ooool70?nf
`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@050?nf
`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@070?nf
`@030000003o]/40okK10140okK100<000000?nf`@3o]/40203o]/400ol00000okK10?nf`@040?nf
`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@040?nf
`@030000003o]/7ooooo00Cooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool07OoooolNoonf`@030000oooo]/7ookK101KookK11Oooool00`000?oooooooonf`@0Noonf`@03
0000oooo]/7ookK101GookK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo00<00000ooooooooool03oooool00`00003oooooooooo`02ooooo`L0okK100<000000?nf`@3o
]/401`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o
]/40103o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100D0okK10P3oool00`000000
oooo0?ooo`020?ooo`l0okK100<000000?nf`@3o]/40203o]/400ol00000okK10?nf`@040?nf`@03
o`00003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@040?nf`@03
0000003o]/7ooooo00Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
7OoooolNoonf`@030000oooo]/7ookK101;ookK12Oooool00`000?ooooooooooo`03oooooa_ookK1
00<0003ooonf`Ooo]/405_oo]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00;ooooo1`3o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK1
0?nf`@040?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401`3oool2000000H0oooo
2P3o]/400`000000okK10?nf`@090?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40
103o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/40
1?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0LoooooaoookK100<0
003oo`00oooo]/404?oo]/4:ooooo`030000oooooooooooo00Kooooo6Ooo]/400`000?oookK1oonf
`@0Foonf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`0300000?oo
oooooooo013ooooo00<00000ooooooooool02@3o]/400`000000okK10?nf`@070?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@030000003o
]/40okK100D0okK100?o00000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`P0okK100<0
00000?nf`@3o]/40203o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100?o
00000?nf`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100Gooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07?oooolPoonf`@030000oooo]/7o
okK100gookK13?ooool00`000?ooooooooooo`08oooooaOookK100<0003ooonf`Ooo]/405_oo]/4O
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo00T0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@04
0?nf`@030?ooool00000oooo00/0oooo00<000000?ooo`3oool01P3oool40?nf`@8000002`3o]/40
0ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@030000003o]/7ooooo00Cooooo00<00000ooooooooool01_ooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool07?oooolPoonf`@030000oooo]/7ookK100cookK13?ooool00`00
0?ooooooooooo`0;oooooaCookK100<0003ooonf`Ooo]/406?oo]/4Nooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
00T0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00D0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@020?nf`@80oooo00?o00000?oo
o`3oool02`3oool00ol000000000000000070?ooo`8000003@3o]/400ol00000okK10?nf`@050?nf
`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@040?nf
`@030000003o]/40okK100Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool06ooooolRoonf`@030000oooo]/7ookK100[ookK13Oooool00`000?ooooooooooo`0<oooooa?o
okK100<0003ooonf`Ooo]/406?oo]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02?ooool00`00003oooooooooo`0?ooooo`030000003o]/40okK100T0okK100<000000?nf`@3o
]/401`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100?o00000?nf`@3o
]/40103o]/4010000000okK10?nf`@3o]/440?ooo`03o`00003oool0oooo00d0oooo10000000103o
ool000000000003oool>0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/40
0ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100<000000?nf`@3o]/401Oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooob;ookK100<0003ooonf
`Ooo]/402Ooo]/4=ooooo`030000oooooooooooo00kooooo4_oo]/400`000?oookK1oonf`@0Hoonf
`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo
00oooooo00<000000?nf`@3o]/402@3o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK1
00D0okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@050?nf`@030000003o]/40oooo
00D0oooo00?o00000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo``0okK100?o00000?nf
`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0okK100?o00000?nf
`@3o]/40103o]/400`000000okK10?nf`@05ooooo`0300000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01_ooooo8_oo]/400`000?oookK1oonf`@08oonf`@kooooo00<0003ooooooooo
ool03oooool@oonf`@030000oooo]/7ookK101WookK17_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Sooooo00<00000ooooooooool03oooool00`000000okK10?nf`@090?nf`@03
0000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@03
o`00003o]/40okK100D0okK100<000000?ooo`3oool01@3oool00ol00000oooo0?ooo`0F0?ooo`/0
okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100@0
okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@05ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01_ooooo8_oo]/400`000?oookK1oonf`@08oonf`@kooooo
00<0003oooooooooool03oooool@oonf`@030000oooo]/7ookK101WookK17_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool04?ooool00`000000okK1
0?nf`@080?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@050?nf`@03o`00003o]/40okK100@0okK100<000000?ooo`3oool01P3oool00ol00000oooo
0?ooo`0E0?ooo`/0okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00
003o]/40okK100@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@05ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool02Oooool01@00003ooooooooooooooooo000000[o
oooo0009ooooo`03o`000?oooooooooo01_ooooo8ooo]/400`000?oookK1oonf`@05oonf`@oooooo
00<0003oooooooooool04Oooool>oonf`@030000oooo]/7ookK101[ookK17_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool03oooool00`000000okK1
0?nf`@090?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@040?nf`@03o`00003o]/40okK100<0okK10P3oool00`000000oooo0?ooo`060?ooo`03o`00
003oool0oooo01D0oooo2@3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100@0okK1
00?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@030000003o]/7ooooo00Gooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`08ooooo`0500000?ooooooooooooooool0
00002_ooool000Wooooo00?o0000ooooooooool06ooooolToonf`@030000oooo]/7ookK100?ookK1
4?ooool00`000?ooooooooooo`0Booooo`gookK100<0003ooonf`Ooo]/406ooo]/4Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0?ooooo`03o`00
003o]/40okK100T0okK100<000000?nf`@3o]/401`3o]/400ol00000okK10?nf`@050?nf`@030000
003o]/40okK100D0okK100Co00000?nf`@3o]/40okK10`3oool00`000000oooo0?ooo`070?ooo`03
o`00003oool0oooo01D0oooo203o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100@0
okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK100Go
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`09ooooo`0400000?ooooooooooo`00
00[ooooo0009ooooo`03o`000?ooool0003o01[ooooo9_oo]/400`000?oookK1oonf`@02oonf`@oo
oooo00<0003oooooooooool04oooool<oonf`@030000oooo]/7ookK101cookK17Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00`3o]/40
00000?nf`@0:0?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000
okK10?nf`@050?nf`@04o`00003o]/40okK10?nf`@@0oooo00?o00000?ooo`3oool01`3oool00ol0
0000oooo0?ooo`0D0?ooo`P0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@040?nf
`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@05oooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool02Oooool01000003oooooooooool0000:
ooooo`002Oooool00ol0003ooooo0000o`0JooooobKookK100@0003ooonf`Ooo]/7ookK14?ooool0
0`000?ooooooooooo`0Dooooo`[ookK100<0003ooonf`Ooo]/407Ooo]/4Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`0=ooooo`80okK100<00000
0?nf`@3o]/402@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/401@3o]/400ol00000okK10?ooo`050?ooo`030000003oool0oooo00L0oooo00?o0000
0?ooo`3oool0503oool60?nf`@03o`00003o]/40okK100P0okK100?o00000?nf`@3o]/401@3o]/40
0ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100<000000?nf`Oooool01Oooool0
0ol0003oooooooooo`06ooooo`0300000?oooooooooo00Wooooo00<00000ooooool000002_ooool0
00Wooooo00Co0000ooooooooool0003o6OoooolWoonf`@030000oooo]/7ookK100oooooo00<0003o
ooooooooool05Oooool9oonf`@030000oooo]/7ookK101kookK17Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00_ooooo00<00000ooooooooool03?ooool30?nf`@030000003o]/40
okK100T0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40
okK100D0okK100?o00000?nf`@3oool01P3oool00`000000oooo0?ooo`070?ooo`03o`00003oool0
oooo01<0oooo1P3o]/400ol00000okK10?nf`@080?nf`@03o`00003o]/40okK100D0okK100?o0000
0?nf`@3o]/401@3o]/400ol00000okK10?nf`@040?nf`@030000003o]/7ooooo00Gooooo00<00000
ooooooooool01oooool00`00003oooooooooo`08ooooo`0300000?oooooo000000[ooooo0009oooo
o`05o`000?ooooooooooooooo`000?l06?oooolXoonf`@030000oooooooooooo00kooooo00<0003o
ooooooooool05_ooool7oonf`@030000oooo]/7ookK100kookK12P000?l7oonf`Agooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo0`3o]/40
0`000000okK10?nf`@090?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@050?nf`@03o`00003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool0
0ol00000oooo0?ooo`0D0?ooo`D0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@05
0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/40103o]/400`000000okK1ooooo`05
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`002Oooool01Ol0003oooooooooooooool0003o01Sooooo:Ooo]/400`000?ooooooooooo`0<
ooooo`030000oooooooooooo01Oooooo1_oo]/400`000?oookK1oonf`@0:oonf`@D0003o2_oo]/44
0000o`?ookK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00<00000
ooooooooool03?ooool30?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@050?nf`@030000003o]/40okK100D0okK100?o00000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`03o`00003oool0oooo01<0oooo103o]/400ol00000okK10?nf`@09
0?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@05
0?nf`@0300000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo0P000?lFoooo
obWookK100?ooooo0000ooooool02oooool00`000?ooooooooooo`0Hooooo`GookK100<0003ooonf
`Ooo]/401_oo]/420000o`;o003o00<0003ooonf`Ooo]/404Ooo]/4010000?oo003o0000o`000?lL
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0;
ooooo`@0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@030000003o]/40
okK100D0okK100<000000?nf`@3o]/401@3o]/400ol00000oooo0?ooo`060?ooo`030000003oool0
oooo00P0oooo00?o00000?ooo`3oool04P3oool40?nf`@03o`00003o]/40okK100T0okK100?o0000
0?nf`@3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100D0okK100<00000
ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00`000?ooooooooooo`0Coooo
obWookK10_ooool00ol00?l0003oooooo`08ooooo`030000oooooooooooo01Wooooo1?oo]/400`00
0?oookK1oonf`@04oonf`@<0003o6ooo]/401?ooool0003o0000o`000?lIooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0;ooooo`@0okK100<00000
0?nf`@3o]/402@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100D0okK100<00000
0?nf`@3o]/40103o]/400`3ooooo00000?ooo`070?ooo`030000003oool0oooo00P0oooo0_l0000B
0?ooo`@0okK100?o00000?nf`@3o]/402@3o]/400ol00000okK10?nf`@060?nf`@03o`00003o]/40
okK100@0okK100?o00000?nf`@3o]/401@3o]/400`00003oooooooooo`06ooooo`0300000?oooooo
oooo00Kooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`04ooooo`030000oooooooooooo01?ooooo:?oo]/45ooooo`030000oooooooooooo
00Gooooo00<0003oooooooooool06oooool00ooo]/40003o0000o`05oonf`@80003o7_oo]/44oooo
o`030000oooooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00[ooooo1@3o]/400ol00000okK10?nf`@080?nf`@030000003o]/40okK1
00L0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@030?nf`@80oooo00?o00000?oo
o`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`03o`00003oool0oooo0100oooo0`3o]/400ol0
0000okK10?nf`@090?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/401@3o]/400ol0
0000okK10?nf`@040?nf`@0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Go
oooo00<0003oooooooooool04_oooolXoonf`@Kooooo00<0003oooooooooool00oooool00`000?oo
ooooooooo`0Looooo`030000oooo]/7ookK100CookK100<0003ooonf`Ooo]/407_oo]/45ooooo`03
0000oooooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03
00000?oooooooooo00[ooooo1@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100H0
okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@020?nf`@<0oooo00?o00000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00l0oooo0`3o]/400ol00000
okK10?nf`@090?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/401@3o]/400ol00000
okK10?nf`@050?nf`@0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool00`00003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo
00<0003oooooooooool04OoooolYoonf`@Oooooo00<0003oooooooooool00_ooool00`000?oooooo
ooooo`0Kooooo`030000oooo]/7ookK100CookK100<0003ooonf`Ooo]/407ooo]/46ooooo`030000
oooooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`030000
0?oooooooooo00Sooooo1`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100L0okK1
00<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@020?nf`@@0oooo00?o00000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0:0?ooo`03o`00003oool0oooo00l0oooo0P3o]/400ol00000okK1
0?nf`@0:0?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK1
0?nf`@050?nf`@0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo0P00
0?lAooooobWookK12?ooool01?l00?l0003o0000o`000?lKooooo`80003o00?o003ooooooooo]/40
1?oo]/400`000?oo003ooonf`@0Poonf`@Oooooo00?o003o0000o`000?l04oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool02?ooool70?nf`@030000
003o]/40okK100T0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@04o`00
003o]/40okK10?nf`@@0oooo00?o00000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`?o
00003P3oool20?nf`@03o`00003o]/40okK100X0okK100?o00000?nf`@3o]/401P3o]/400ol00000
okK10?nf`@050?nf`@03o`00003o]/40okK100D0okK100?ooooo00000?ooool01_ooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool02?ooool20000o`oooooo:Ooo]/48ooooo`80003o00Cooooo0000o`000?l0
003o5_ooool30000o`Cooooo1?oo]/400`000?oookK1oonf`@0Qoonf`@[ooooo00<0003ooooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00<00000oooooooo
ool02?ooool70?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401P3o]/400`000000
okK10?nf`@070?nf`@03o`00003o]/40okK100@0oooo00?o00000?ooo`3oool01`3oool00ol00000
oooo0?ooo`0<0?ooo`;o0000303oool00`3o]/7o00000?nf`@0<0?nf`@03o`00003o]/40okK100L0
okK100?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@050?nf`@03ooooo`00003ooooo00Ko
oooo00<00000ooooooooool01oooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool03?oooolYoonf`@Oooooo
00<0003oooooooooool01?ooool30000oa3ooooo0`000?l7ooooo`?ookK100<0003ooonf`Ooo]/40
8_oo]/4;ooooo`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo00Oooooo203o]/400`000000okK10?nf`@090?nf`@030000
003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@050?ooo`03o`00
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00ol00000oooo0?ooo`090?ooo`03o`00
003o]/40okK100`0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@050?nf`@03o`00
003o]/40okK100@0okK10_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0;ooooo`030000oooooooooooo00cooooo:?oo]/46ooooo`030000oooooooooooo00Sooooo0`00
0?l9ooooo`@0003o2_ooool00ooo]/40003o0000o`0Uoonf`@cooooo00<0003oooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00<00000ooooooooool01ooo
ool80?nf`@030000003o]/40okK100T0okK100?o00000?nf`@3o]/401P3o]/400`000000okK10?nf
`@060?nf`@03o`00003o]/40oooo00D0oooo00?o00000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`;o00001`3oool2o`0000l0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf
`@060?nf`@03o`00003o]/40okK100<0okK10_ooool00ol0003oooooooooo`05ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00_ooooo:?oo]/45ooooo`030000oooooooo
oooo00cooooo2@000?l>ooooo`030000oooo]/7ookK102GookK13Oooool00`000?ooooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`P0okK100?o00000?nf`@3o]/402@3o]/400`000000okK10?nf`@070?nf`@03o`00003o]/40
okK100D0okK100?o00000?nf`@3oool01@3oool00ol00000oooo0?ooo`070?ooo`030000003oool0
oooo00l0oooo0_l000040?ooo`03o`00003oool0oooo00l0okK100?o00000?nf`@3o]/401`3o]/40
0ol00000okK10?nf`@060?nf`@03o`00003o]/40okK100<0okK10_ooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0=ooooo`80003o2ooooolYoonf`@?ooooo00<0003ooooo
ooooool05_ooool?0000obOookK13Oooool00`000?ooooooooooo`0=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04Oooool00`00003oooooooooo`06ooooo`P0okK100<000000?nf
`@3o]/402@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100D0okK100?o00000?nf
`@3o]/401P3oool00ol00000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo1?l000020?oo
oa00okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@060?nf`@03o`00003o]/40okK1
00<0okK10_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0?ooooo`80
003o2OoooolYoonf`@03ooooo`000?l0003o01Gooooo10000?l=ooooo`030000oooo]/40003o0080
003o9?oo]/4>ooooo`030000oooooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Booooo`0300000?oooooooooo00Gooooo2@3o]/400`000000okK10?nf`@090?nf`@03
0000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?ooo`050?ooo`03
o`00003oool0oooo00L0oooo00<000000?ooo`3oool05P3ooolA0?nf`@03o`00003o]/40okK100L0
okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@020?nf`@?ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool04Oooool00`000?ooooooooooo`06ooooobSookK1
0P000?lDooooo`<0003o4?ooool00`000?oookK1oonf`@03oonf`@80003o8_oo]/4?ooooo`030000
oooooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`030000
0?oooooooooo00Gooooo2P3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100L0okK1
00<000000?nf`@3o]/401@3o]/400ol00000okK10?ooo`060?ooo`03o`00003oool0oooo00L0oooo
00<000000?ooo`3oool05@3ooolA0?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/40
1P3o]/400ol00000okK10?nf`@020?nf`@?ooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`06ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool04_ooool00ol00?ooooooooooo`05ooooobOookK100<0003ooonf`Oooool04_oo
ool20000oa;ooooo00<0003ooooooooo]/401_oo]/430000oaoookK14?ooool00`000?oooooooooo
o`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00`00003ooooooooo
o`04ooooo`X0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@030000003o
]/40okK100H0okK100?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`070?ooo`030000003o
ool0oooo01D0oooo4@3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100H0okK100?o
00000?nf`@3o]/400P3o]/43ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01?ooooo0`000?l4ooooobGookK10P000?l3oonf`A3ooooo0P000?lDooooo`03o`00oooo]/7o
okK100WookK10P000?lMoonf`A7ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool00oooool;0?nf`@030000003o]/40
okK100P0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40
oooo00H0oooo00?o00000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?oooa<0okK100?o0000
0?nf`@3o]/401`3o]/400ol00000okK10?nf`@060?nf`@04o`00003o]/40okK10?nf`@Cooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05_ooool20000o`;ooooo8ooo]/42
0000o`GookK13_ooool20000oaKooooo00<0003ooonf`Ooo]/402ooo]/420000oa_ookK14_ooool0
0`000?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`02ooooo`/0okK100<000000?nf`@3o]/402@3o]/400ol00000okK10?nf`@06
0?nf`@030000003o]/40okK100H0okK100?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`07
0?ooo`030000003oool0oooo0180oooo4`3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40
okK100H0okK100Co00000?nf`@3o]/40okK11?ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Hooooo`<0003o7ooo]/430000o`SookK12oooool20000oaOooooo00<0003o
oonf`Ooo]/403_oo]/420000oaWookK14_ooool00`000?ooooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05Oooool00`00003oooooooooo`02ooooo``0okK100?o0000
0?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100H0okK100?o0000
0?nf`@3oool01P3oool00ol00000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo503o]/40
0ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100H0okK100Co00000?nf`@3o]/40okK11?oo
ool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`@0003o5_oo]/45
0000o`gookK12?ooool00`000?ooooooooooo`0Fooooo`030000oooooooookK1017ookK100<0003o
oonf`Ooo]/405_oo]/4Booooo`030000oooooooooooo00Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Fooooo`0300000?oooooooooo00;ooooo2`3o]/400`000000okK10?nf`@09
0?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@06
0?ooo`03o`00003oool0oooo00L0oooo00<000000?ooo`3oool0403ooolD0?nf`@03o`00003o]/40
okK100P0okK100?o00000?nf`@3o]/401@3o]/401?l00000okK10?nf`@3o]/45ooooo`0300000?oo
oooooooo00Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo1?oo]/430000oa3ookK10`000?lB
oonf`@Oooooo00<0003oooooooooool05oooool00`000?oookK1oonf`@0Boonf`@03o`00oooo]/7o
okK101CookK15?ooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05_ooool00`00003oooooooooo`02ooooo``0okK100<000000?nf`@3o]/40203o]/40
0`000000okK10?nf`@060?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401P3oool0
0ol00000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo5@3o]/400ol00000okK10?nf`@08
0?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`Oooool01Oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Kooooo`OookK13`000?l00ol00?oookK1oonf`@0Doonf
`@Gooooo00<0003oo`00ooooool05oooool00`000?oookK1oonf`@0Coonf`@030000oooo]/7ookK1
01CookK15?ooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05oooool01000003oooooooooooooool<0?nf`@030000003o]/40okK100T0okK100<00000
0?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100H0oooo00?o0000
0?ooo`3oool0203oool00`000000oooo0?ooo`0<0?oooaH0okK100?o00000?nf`@3o]/40203o]/40
0ol00000okK10?nf`@060?nf`@03o`00003o]/7ooooo00Kooooo00<00000ooooooooool01Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool06oooool^oonf`@?ooooo00<0003oooooooooool06?ooool00`00
0?oookK1oonf`@0Doonf`@030000oooo]/7ookK101?ookK15?ooool00`000?ooooooooooo`07oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<0?nf
`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@070?nf
`@03o`00003o]/40okK100D0oooo00?o00000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
oaL0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@060?nf`@03o`00003o]/7ooooo
00Kooooo00<00000ooooooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool_oonf`@03
ooooo`000?oooooo01Wooooo00<0003ooonf`Ooo]/405_oo]/400`000?oookK1oonf`@0Boonf`AGo
oooo00<0003oooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01So
oooo00<00000ooooooooool03@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100H0
okK100<000000?nf`@3o]/401P3o]/401?l00000okK10?nf`@3o]/450?ooo`03o`00003oool0oooo
00P0oooo00<000000?ooo`3oool02@3ooolI0?nf`@03o`00003o]/40okK100P0okK100?o00000?nf
`@3o]/401P3o]/400ol0003oooooooooo`06ooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool01oooool01@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo
01cooooo;_oo]/400`000?ooooooooooo`0Gooooo`03oonf`@000?oookK101WookK100<0003ooonf
`Ooo]/404Ooo]/4Eooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Iooooo`0300000?oooooooooo00d0okK100<000000?nf`@3o]/40203o]/400`00
0000okK10?nf`@070?nf`@030000003o]/40okK100H0okK100Co00000?nf`@3o]/40okK11@3oool0
0ol00000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo6`3o]/400ol00000okK10?nf`@08
0?nf`@03o`00003o]/40okK100H0okK100?o0000ooooooooool01_ooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00Oooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool0
0ol0003oooooooooo`0LooooobgookK100@0003ooonf`Ooo]/7ookK15Oooool3oonf`@03o`00oooo
]/7ookK101WookK100<0003ooonf`Ooo]/403ooo]/4Gooooo`030000oooooooooooo00Gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`0300000?oooooooooo00d0okK100?o
00000?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100H0okK100?o
00000?nf`@3o]/400`3o]/430?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0103o
oolM0?nf`@03o`00003o]/40okK100P0okK100?o00000?nf`@3o]/401P3o]/400ol0003ooooooooo
o`06ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool01@00003ooooooooo
oooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01cooooo;Ooo]/400`000?oookK1oonf
`@03oonf`A7ooooo1Ooo]/400`000?oookK1oonf`@0Ioonf`@030000oooo]/7ookK100oookK15ooo
ool00`000?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_oo
ool00`00003ooooo0?nf`@0<0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401`3o
]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100D0okK100<0ooooo`00003oool02@3o
ool00`000000oooo0?ooo`020?oooal0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf
`@060?nf`@03ooooool0003ooooo00Kooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`07ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool07Ooo
ool[oonf`@030000oooo]/7ookK100KookK13Oooool7oonf`@030000oooo]/7ookK101[ookK100<0
003ooonf`Ooo]/403_oo]/4Gooooo`030000oooooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Jooooo`0300000?oooooooooo00d0okK100<000000?nf`@3o]/40203o
]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401@3o
]/400ol00000oooo0?ooo`090?ooo`030000003oool0okK10240okK100?o00000?nf`@3o]/40203o
]/400ol00000okK10?nf`@050?nf`@03ooooool0003ooooo00Kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`06ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o
0000ooooooooool07OoooolZoonf`@030000oooo]/7ookK100_ookK11Oooool:oonf`@030000oooo
]/7ookK101cookK100<0003ooonf`Ooo]/403?oo]/4Iooooo`030000oooooooooooo00Cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`0300000?ooool0okK100d0okK100<0
00000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100H0okK100?o
00000?nf`@3o]/401P3o]/401?l00000okK10?nf`@3o]/450?ooo`<0okK100<000000?nf`@3o]/40
803o]/400ol00000okK10?nf`@080?nf`@03o`00003o]/40okK100@0okK10_ooool00ol0003ooooo
ooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool01@00003ooooo
oooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo01gooooo:_oo]/400`000?oookK1
oonf`@0Joonf`@030000oooo]/7ookK101gookK100<0003ooonf`Ooo]/402ooo]/4Iooooo`030000
oooooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`030000
0?ooool0okK100d0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@030000
003o]/40okK100H0okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@090?nf`@030000
003o]/40okK10200okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@040?nf`@;ooooo
00?o0000ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo
00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0NooooobSookK1
00<0003ooonf`Ooo]/406ooo]/400`000?oookK1oonf`@0Noonf`@030000oooo]/7ookK100[ookK1
6Oooool00`000?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7?ooool00`00003ooooo0?nf`@0=0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
1P3o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/40
2@3o]/400`000000okK10?nf`@0O0?nf`@03o`00003o]/40okK100P0okK100?o00000?nf`@3o]/40
103o]/42ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01Oooool00`00003ooooo
ooooo`07ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo01kooooo
:?oo]/400`000?oookK1oonf`@0Koonf`@030000oooo]/7ookK101kookK100<0003ooonf`Ooo]/40
2Ooo]/4Jooooo`030000oooooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
0000000Mooooo`030000003o]/40okK100d0okK100<000000?nf`@3o]/40203o]/400`000000okK1
0?nf`@060?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401P3o]/400ol00000okK1
0?nf`@090?nf`@030000003o]/40okK101h0okK100?o00000?nf`@3o]/40203o]/400ol00000okK1
0?nf`@030?nf`@?ooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`05ooooo`03o`00
0?oooooooooo00Oooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool0
7ooooolVoonf`@030000oooo]/7ookK101cookK100<0003ooonf`Ooo]/407ooo]/400`000?oookK1
oonf`@08oonf`A[ooooo00<0003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?ooool0000001gooooo00<00000ooooo`3o]/403@3o]/400ol00000okK10?nf`@080?nf`@030000
003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@060?nf`@03o`00
003o]/40okK100T0okK100<000000?nf`@3o]/407P3o]/400ol00000okK10?nf`@080?nf`@03o`00
003o]/40okK100<0okK10oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool01oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003ooooo
ooooo`0PooooobGookK100<0003ooonf`Ooo]/406ooo]/400`000?oookK1oonf`@0Poonf`@03o`00
oooo]/7ookK100OookK17?ooool00`000?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo
00Co0000ooooooooool000007Oooool00`00003ooooo0?nf`@0<0?nf`@030000003o]/40okK100P0
okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100L0
okK100?o00000?nf`@3o]/402@3o]/400`000000okK10?nf`@0M0?nf`@03o`00003o]/40okK100P0
okK100?o00000?nf`@3o]/400P3o]/44ooooo`03o`000?oooooooooo00Kooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`07ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03
o`000?oooooooooo023ooooo9?oo]/400`000?oookK1oonf`@0Loonf`@030000oooo]/7ookK1027o
okK100<0003ooonf`Ooo]/401Ooo]/4Mooooo`030000oooooooooooo00?ooooo00?o0000oooooooo
ool03oooool01Ol0003oooooooooooooool0000001gooooo00<000000?nf`@3o]/40303o]/400`00
0000okK10?nf`@080?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400ol0
0000okK10?nf`@060?nf`@03o`00003o]/40okK100T0okK100<000000?nf`@3o]/40703o]/400ol0
0000okK10?nf`@090?nf`@04o`00003o]/40okK10?nf`@Kooooo00?o0000ooooooooool01Oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00@00000oooooooooooo00002_oo
ool000Wooooo00?o0000ooooooooool08OoooolSoonf`@030000oooo]/7ookK101cookK100<0003o
oonf`Ooo]/408?oo]/43000000KookK17Oooool00`000?ooooooooooo`03ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool00ol000000000ooooo`0Jooooo`03o`000?ooool0
okK100`0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40
okK100H0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@090?nf`@030000003o]/40
okK101/0okK100?o00000?nf`@3o]/402@3o]/401?l00000okK10?nf`@3o]/46ooooo`03o`000?oo
oooooooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0400000?oo
ooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo027ooooo8_oo]/400`000?oookK1oonf
`@0Moonf`@030000oooo]/7ookK101oookK11@000004oonf`Akooooo00<0003oooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool06?oo
ool00`00003ooooo0?nf`@0<0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/402P3o
]/400ol00000okK10?nf`@0J0?nf`@03o`00003o]/40okK100T0okK100?o00000?nf`@3o]/401ooo
ool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_oo
ool01000003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`0Qooooob;ookK100<0
003ooonf`Ooo]/407Ooo]/400`000?oookK1oonf`@0Ooonf`@D000001?oo]/4Nooooo`030000oooo
oooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`0300000?oo
oooooooo01Sooooo00<000000?nf`@3o]/40303o]/400`000000okK10?nf`@080?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@070?nf`@03o`00003o
]/40okK100X0okK100<000000?nf`@3o]/40603o]/400ol00000okK10?nf`@0:0?nf`@03o`00003o
]/40okK100Kooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00Kooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool08_oo
oolQoonf`@030000oooo]/7ookK101gookK100<0003ooonf`Ooo]/407ooo]/45000000CookK17_oo
ool00`000?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Hooooo`030000003o]/40okK100`0okK100<000000?nf`@3o]/40203o
]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401`3o
]/400ol00000okK10?nf`@0:0?nf`@030000003o]/40okK101L0okK100?o00000?nf`@3o]/402P3o
]/400ol00000okK10?nf`@06ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`06ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oo
oooooooo02?ooooo7ooo]/400`000?oookK1oonf`@0Noonf`@030000oooo]/7ookK1023ookK10`00
0004oonf`Aoooooo00<0003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00<00000ooooooooool06?ooool00`00003ooooo0?nf`@0<0?nf`@030000003o
]/40okK100P0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@060?nf`@03o`00003o
]/40okK100L0okK100?o00000?nf`@3o]/402P3o]/400`000000okK10?nf`@0G0?nf`@03o`00003o
]/40okK100X0okK100?o00000?nf`Oooool01_ooool00ol0003oooooooooo`06ooooo`0300000?oo
oooooooo00Kooooo00<00000ooooooooool01_ooool01000003oooooooooool0000:ooooo`002Ooo
ool00ol0003oooooooooo`0SoooooaoookK100<0003ooonf`Ooo]/407_oo]/400`000?oookK1oonf
`@0Roonf`@040000oooo]/7ookK1oonf`B3ooooo00<0003oooooooooool00oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool06?ooool00`000000okK1
0?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@060?nf`@03o`00003o]/40okK100H0okK100?o00000?nf`@3o]/402`3o]/400`000000okK1
0?nf`@0E0?nf`@03o`00003o]/40okK100/0okK100?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool01oooool01000003ooooo
ooooool0000:ooooo`002Oooool00ol0003oooooooooo`0ToooooakookK100<0003ooonf`Ooo]/40
7_oo]/400`000?oookK1oonf`@0Roonf`@040000oooo]/7ookK1oonf`B3ooooo00<0003ooooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<00000oooooooo
ool05oooool00`00003ooooo0?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o
]/401`3o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o
]/402`3o]/400`000000okK10?nf`@0D0?nf`@03o`00003o]/40okK100X0okK100?o00000?nf`Ooo
ool01oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool01oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`0Toooooago
okK100<0003ooonf`Ooo]/408?oo]/400`000?oookK1oonf`@0Roonf`@030000oooo]/7ooooo01oo
oooo00<0003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05oooool00`000000okK10?nf`@0;0?nf`@030000003o]/40okK100P0
okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK100L0
okK100?o00000?nf`@3o]/402`3o]/400ol0000000000?nf`@0B0?nf`@03o`00003o]/40okK100/0
okK100?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool01oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003o
ooooooooo`0UoooooacookK100<0003ooonf`Ooo]/408?oo]/400`000?oookK1oonf`@0Roonf`@03
0000oooo]/7ooooo01oooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo00<00000ooooooooool05_ooool00`00003ooooo0?nf`@0;0?nf`@03
0000003o]/40okK100P0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@060?nf`@03
o`00003o]/40okK100L0okK100?o00000?nf`@3o]/403@3o]/400`00003o00000?nf`@0>0?nf`@;o
00003P3o]/400ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`07ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03
o`000?oooooooooo02Kooooo6ooo]/400`000?oookK1oonf`@0Poonf`@030000oooo]/7ookK102;o
okK100<0003oooooooooool07oooool00`000?ooooooooooo`04ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02_ooool00`00003oooooooooo`0Gooooo`0300000?ooool0okK100/0
okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100L0
okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@0>0?nf`@;o00002`3o]/42o`0000l0
okK100?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool01oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003o
ooooooooo`0Woooooa[ookK100<0003ooonf`Ooo]/408?oo]/400`000?oookK1oonf`@0Roonf`@03
0000oooooooooooo01oooooo00<0003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00_ooooo00<00000ooooooooool05_ooool00`00003oooooooooo`0;0?nf`@03
0000003o]/40okK100P0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@060?nf`@03
o`00003o]/40okK100L0okK100?o00000?nf`@3o]/40403o]/400ol00000okK10?nf`@070?nf`@03
o`00003o]/40okK100l0okK100?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
00000?oooooooooo00Kooooo00<00000ooooooooool01_ooool01@00003ooooooooooooooooo0000
00[ooooo0009ooooo`03o`000?oooooooooo02Sooooo6Ooo]/400`000?oookK1oonf`@0Poonf`@<0
00008Ooo]/400oooool0003oooooo`0Pooooo`030000oooooooooooo00Cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00<00000oooooooo
ool02`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o
]/401`3o]/400ol00000okK10?nf`@070?nf`@03o`00003o]/40okK100l0okK12_l0000A0?nf`@03
ooooool0003ooooo00Sooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Kooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003o
ooooooooo`0XoooooaWookK100<0003ooonf`Ooo]/407ooo]/45000001oookK10oooool00`000?oo
ooooooooo`0Mooooo`030000oooooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0=ooooo`0300000?oooooooooo01Kooooo00?o0000ooooo`3o]/402P3o]/400`000000
okK10?nf`@080?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/401`3o]/400ol00000
okK10?nf`@080?nf`@03o`00003o]/40okK102P0okK100?oooooo`000?ooool02Oooool00ol0003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool01@00003o
oooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo02Wooooo6?oo]/400`000?oo
okK1oonf`@0Ooonf`@D000007ooo]/43ooooo`030000oooooooooooo01gooooo00<0003ooooooooo
ool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00<00000oooooooo
ool05Oooool00`00003oooooooooo`0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o
]/401P3o]/400`000000okK10?nf`@070?nf`@03o`00003o]/40okK100P0okK100?o00000?nf`@3o
]/409`3o]/400ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0:_oooolGoonf`@030000oooo]/7ookK101oookK1
1@00000Noonf`@Cooooo00<0003oooooooooool07Oooool00`000?ooooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0Eooooo`030000
0?oooooooooo00/0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@070?nf`@030000
003o]/40okK100L0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@0U0?nf`@03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00Kooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0[oooooaKookK100<0003ooonf`Ooo]/408?oo]/43000001kookK11Ooo
ool00`000?ooooooooooo`0Looooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0?ooooo`0300000?oooooooooo01Gooooo00@00000oooooooooooooooo
2P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100L0okK100?o00000?nf`@3o]/40
1`3o]/400ol00000okK10?nf`@090?nf`@03o`00003o]/40okK102<0okK100?oooooo`000?ooool0
2Oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02cooooo5Ooo]/400`000?oookK1oonf`@0Roonf`@030000oooo]/7ookK101_ookK11Ooo
ool00`000?ooooooooooo`0Mooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`0300000?oooooooooo01Gooooo00@00000oooooooooooooooo
2@3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40
203o]/400ol00000okK10?nf`@090?nf`@03o`00003o]/40okK10240okK100?oooooo`000?ooool0
2Oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02gooooo5?oo]/400`000?oookK1oonf`@0Roonf`@030000oooo]/7ookK101WookK11ooo
ool00`000?ooooooooooo`0Mooooo`030000oooooooooooo00Kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool00_oo
ool90?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf
`@070?nf`@03o`00003o]/40okK100X0okK100?o00000?nf`@3o]/407P3o]/42ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0^oooooa?ookK100<0003ooonf`Ooo]/408ooo]/400`000?oookK1oonf`@0G
oonf`@Sooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`07ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04Oooool00`00003oooooooooo`0Eooooo`0300000?oooooo
oooo00;ooooo203o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100L0okK100<00000
0?nf`@3o]/401`3o]/400ol00000okK10?nf`@0:0?nf`@;o00007@3o]/42ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool00`00003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0`oooooa7ookK100<0003ooonf`Ooo]/408ooo]/400`000?oookK1oonf`@0Foonf
`@Wooooo00<0003oooooooooool07?ooool00`000?ooooooooooo`07ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo1`3o]/400`000000okK10?nf`@080?nf`@03o`00003o]/40okK100L0okK100<000000?nf
`@3o]/401P3o]/400ol00000okK10?nf`@0<0?nf`@;o00006P3o]/400ooooooo0000o`00000<oooo
o`03o`000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0<Oooool@oonf`@030000oooo]/7ookK102CookK100<0003ooonf`Ooo]/405?oo]/4:ooooo`03
0000oooooooooooo01_ooooo00<0003oooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01?ooooo00<00000ooooooooool05?ooool00`00003oooooooooo`04ooooo`L0
okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100H0
okK100?o00000?nf`@3o]/403@3o]/400ol00000okK10?nf`@0F0?nf`@;o00003Oooool00ol0003o
ooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03;ooooo
4?oo]/400`000?oookK1oonf`@0Toonf`@030000oooo]/7ookK101;ookK12_ooool00`000?oooooo
ooooo`0Looooo`030000oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Dooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool01?ooool60?nf`@03o`00
003o]/40okK100P0okK100<000000?nf`@3o]/401`3o]/400ol00000okK10?nf`@070?nf`@;o0000
3P3o]/42o`0001@0okK10_l0000>ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0<oooool?oonf`@030000oooo]/7ookK102CookK100<0
003ooonf`Ooo]/404Ooo]/4;ooooo`030000oooooooooooo01_ooooo00<0003oooooooooool02Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool05?oo
ool00`00003oooooooooo`05ooooo`D0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf
`@070?nf`@030000003o]/40okK100T0okK100?o00000?nf`@3o]/403@3o]/43o`0000d0okK11?l0
000?ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0=Oooool=oonf`@030000oooo]/7ookK102GookK100<0003ooonf`Ooo]/403_oo]/4=
ooooo`030000oooooooooooo01[ooooo00<0003oooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Gooooo00<00000ooooooooool05?ooool00`00003oooooooooo`06
ooooo`@0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@030000003o]/40
okK100T0okK100?o00000?nf`@3o]/403`3o]/44o`0000H0okK10ol000020?nf`A3ooooo00?o0000
ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0foooo
o`cookK100<0003ooonf`Ooo]/409_oo]/400`000?oookK1oonf`@0<oonf`@kooooo00<0003ooooo
ooooool06Oooool00`000?ooooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05Oooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo00Oooooo0`3o]/400`00
0000okK10?nf`@080?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/402@3o]/400ol0
0000okK10?nf`@0B0?nf`@Ko0000103o]/4@ooooo`03o`000?oooooooooo00Wooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0>?ooool;oonf`@030000oooo]/7ookK102Ko
okK100<0003ooonf`Ooo]/402Ooo]/4@ooooo`030000oooooooooooo01Sooooo00<0003ooooooooo
ool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo0P00000Eooooo`03
00000?oooooooooo00Sooooo0P3o]/400`000000okK10?nf`@080?nf`@0300000?l00000okK100P0
okK100<000000?nf`@3o]/402@3o]/42o`0001X0okK14?ooool2o`0000_ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0>_ooool9oonf`@030000oooo]/7ookK102OookK1
00<0003ooonf`Ooo]/401_oo]/4Aooooo`030000oooooooooooo01Sooooo00?o003oooooooooool0
3Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00<00000ooooooooool0
4_ooool00`00003oooooooooo`0:ooooo`030?nf`Ol00000okK100T0okK100<000000?nf`@3o]/40
203o]/400`000000okK10?nf`@0:0?nf`@03o`00003o]/40okK101D0okK14Oooool00ol0003ooooo
ooooo`0:ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03_ooooo2Ooo
]/400`000?oookK1oonf`@0Woonf`@030000oooo]/7ookK100CookK14_ooool00`000?oooooooooo
o`0Gooooo`030000oooooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Hooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool02_ooool00`000000okK10?nf
`@090?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/402P3o]/42o`0001@0okK14?oo
ool2o`0000cooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0?_ooool6
oonf`@030000oooo]/7ookK102SookK100Co003ooonf`Ooo]/7ookK15?ooool00`000?oooooooooo
o`0Fooooo`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Iooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool02_ooool00`00003ooooo0?nf
`@090?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/402`3o]/400ol00000okK10?nf
`@0?0?nf`A3ooooo0_l0000=ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo047ooooo1?oo]/400`000?oookK1oonf`@0Xoonf`@030000oooooooooooo01?ooooo00<0003o
ooooooooool05_ooool00`000?ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00_ooooo00@00000
oooooooooooooooo1`3o]/400`000000okK10?nf`@090?nf`@03o`00003o]/40okK100/0okK10_l0
000<0?nf`A7ooooo0_l0000>ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo04Cooooo00?ookK10000oooo]/409_oo]/44ooooo`030000oooooooooooo01;ooooo00<0003o
ooooooooool05Oooool00`000?ooooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00_ooooo00<00000
ooooooooool00oooool50?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/40303o]/42
o`0000L0okK14_ooool2o`0000oooooo00<00000ooooooooool02Oooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0AOooool00`000?oooooooonf`@0Roonf`@Sooooo00<0003oooooooooool04?ooool00`00
0?ooooooooooo`0Dooooo`80003o5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo
00Gooooo0`3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100d0okK10ol000000`3o
]/7oooooooooo`0Aooooo`;o00004?ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`16ooooo`040000oooooooooooooooooagookK13?ooool00`000?oo003o0000o`0>oooo
o`030000oooooooooooo01Cooooo00<0003oooooooooool05?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01_ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00<0okK10000003o]/402P3o]/42000000h0okK10_ooool3o`00
00gooooo1?l0000Aooooo`03o`000?oooooooooo00Sooooo0P00000:ooooo`0300000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00`000?oo
ooooooooo`04oooooaOookK14_ooool20000o`cooooo00<0003oooooooooool04oooool00`000?oo
ooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00`00003o
ooooooooo`0Booooo`0300000?oooooooooo00cooooo00<00000ooooooooool02Oooool00`000000
okK10?nf`@0:0?nf`@030000003o]/40okK100P0okK12?ooool=o`0001?ooooo0P00000:ooooo`03
00000?oooooooooo00[ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`17ooooo`030000oooooooooooo00cooooo1?oo]/4Nooooo`80003o
2Oooool00`000?ooooooooooo`0Booooo`80003o6?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01gooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool01_ooool40?nf`@0300000?oooooooooo02gooooo
0P00000;ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`18ooooo`030000oooooooooooo02oooooo0`00
0?l5ooooo`030000oooooooooooo013ooooo0`000?lJooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool07_ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo00cooooo00<0
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`0300000?l00000000002[ooooo00<0
0000o`000?ooool02oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00<0
0000ooooool000002_ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?ooooooooooo`0b
ooooo`80003o0_ooool00ol00?ooooooooooo`0>ooooo`<0003o7Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01kooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0V
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0;
ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo04Wooooo00<0003oo`00
ooooool0<oooool60000o`Sooooo0`000?l00ol00?l0003oooooo`0Oooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07oooool00`00003oooooooooo`0Booooo`0300000?oooooooooo
00cooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0<ooooo`<000008_ooool30000
00gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0;ooooo`0400000?oooooooooo
o`0000[ooooo0009ooooo`03o`000?oooooooooo04_ooooo00<0003oooooooooool0<_ooool00`00
0?ooooooooooo`02ooooo`P0003o9Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01oooooo00<00000ooooooooool04oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo
00[ooooo00<00000ooooooooool03_ooool2000001gooooo0`00000?ooooo`0300000?oooooooooo
00[ooooo00<00000ooooooooool03?ooool01000003oooooooooool0000:ooooo`002Oooool00ol0
003oooooooooo`1<ooooo`030000oooooooooooo033ooooo00<0003oooooooooool0<?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00<00000ooooooooool04oooool00`00
003oooooooooo`0<ooooo`0300000?oooooooooo00[ooooo0P00000@ooooo`D000005?ooool40000
013ooooo0P00000<ooooo`03o`000?oooooooooo00_ooooo0P000003ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo04gooooo00<0003oooooooooool0;_ooool00`000?oo
ooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00`00003o
ooooooooo`0Dooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02oooool2000001?o
oooo0`00000=ooooo`@000004_ooool2000000gooooo00<00000ooooooooool02oooool00`00003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04kooooo
0P000?l[ooooo`80003o00?o003oooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo027ooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0<ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool04oooool=000001Gooooo00<00000ooooooooool0
3?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0D?ooool00`000?ooooooooooo`0Wooooo`030000oooo
oooooooo03Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000000
003ooooo01Cooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0<ooooo`0300000?l0
00000000037ooooo0P0000000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00<0
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1A
ooooo`030000oooooooooooo02Gooooo00<0003oooooooooool0=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02?ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0=
ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0=
ooooo`8000003_ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo05;ooooo00<0003oooooooooool08_ooool20000ocWooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Tooooo`0300000?oooooooooo01?ooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0>ooooo`800000:oooool2000000oooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo05?ooooo0`000?lPooooo`030000oooooooooooo03Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Uooooo`0300000?oooooooooo01?ooooo00<00000oooooooo
ool03Oooool00`00003oooooooooo`0?ooooo`800000:?ooool00`00003oooooooooo`0>ooooo`03
00000?oooooooooo00gooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Fooooo`030000oooooooooooo01_ooooo0P000?llooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool09_ooool00`00003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo00<00000o`000?ooool04?ooool30000027ooooo1000000?ooooo`800000
3oooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo05Oooooo00Co003o0000o`000?l0003o5_ooool30000ockooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Wooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0
3_ooool00`00003oooooooooo`0Aooooo`<000006oooool3000001;ooooo00<00000ooooooooool0
3_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo05_ooooo1@000?l=ooooo`@0003o@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Sooooo00<00000ooooooooool04oooool00`00003oooooooooo`0>ooooo`0300000?oo
oooooooo01?ooooo1000000@ooooo`L000004oooool20000013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Pooooo`@0003o1?ooool5
0000odGooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`0300000?oooooo
oooo01?ooooo00<00000ooooooooool03_ooool3000001Kooooo4000000Hooooo`03o`000000003o
oooo013ooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`1Tooooo`@0003oB_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02Wooooo00<00000ooooooooool05?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo
03Wooooo0P00000Booooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wo
oooo0P00000Fooooo`0300000?oooooooooo013ooooo0P00000hooooo`0300000?oooooooooo013o
oooo0P00000?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`0300000?oooooooooo01Cooooo
00<00000ooooooooool04Oooool00`00003oooooooooo`0cooooo`8000004_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`0300000?oooooooooo01Cooooo00?o
000000000?ooool04Oooool01000003o000000000000000]ooooo`80000000?o000000000?ooool0
4_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`0300000?oo
oooooooo01Kooooo00<00000ooooooooool04oooool3000002Wooooo00<00000ooooooooool04ooo
ool2000001?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00<00000ooooooooool05_ooool0
0`00003oooooooooo`0Eooooo`@000008_ooool3000001Gooooo00<00000ooooooooool04oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0;_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo
01Sooooo00<00000ooooooooool07?ooool3000001Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Fooooo`0300000?l00000000001So
oooo00?o00000000000000000`00000@ooooo`H0000000?o000000000?ooool05oooool2000001Oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo00<00000ooooooooool06?ooool2000001cooooo
4000000Mooooo`<000006Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Oooool00`00003ooooooooo
o`0Iooooo`0300000?oooooooooo04Gooooo00<00000ooooooooool06?ooool00ol0003oooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0<_ooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06?ooool01?l0003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.48077 .13461 m
.5 .13291 L
.51923 .13197 L
.53846 .13202 L
.55769 .13319 L
.57124 .13462 L
.57692 .13574 L
.59615 .14011 L
.61538 .14604 L
.63462 .15322 L
.6362 .15385 L
.65385 .16266 L
.6728 .17308 L
.67308 .17325 L
.69231 .18609 L
.70138 .19231 L
.71154 .20018 L
.72578 .21154 L
.73077 .21589 L
.74713 .23077 L
.75 .23358 L
.76586 .25 L
.76923 .25369 L
.78233 .26923 L
.78846 .27678 L
.79691 .28846 L
.80769 .30355 L
.81019 .30769 L
.82197 .32692 L
.82692 .33533 L
.83229 .34615 L
.84168 .36538 L
.84615 .37536 L
.8495 .38462 L
.85593 .40385 L
.86116 .42308 L
.8649 .44231 L
.86538 .44344 L
.86687 .46154 L
.86751 .48077 L
.86691 .5 L
.86538 .5188 L
.8652 .51923 L
.86212 .53846 L
.85805 .55769 L
.8532 .57692 L
.84792 .59615 L
.84615 .60256 L
.84161 .61538 L
.83421 .63462 L
.82692 .65321 L
.82663 .65385 L
.81707 .67308 L
.80769 .69149 L
.80721 .69231 L
.79527 .71154 L
.78846 .72236 L
.78244 .73077 L
.76923 .74854 L
.76805 .75 L
.75166 .76923 L
.75 .77109 L
.73324 .78846 L
.73077 .79084 L
.71213 .80769 L
.71154 .80818 L
.69231 .82294 L
.68665 .82692 L
.67308 .83524 L
.65385 .84548 L
.65243 .84615 L
.63462 .85301 L
.61538 .85863 L
.59615 .86229 L
.57692 .8641 L
.55769 .86436 L
.53846 .86346 L
.51923 .86178 L
.5 .85965 L
.48077 .85723 L
.46154 .85456 L
.44231 .85161 L
.42308 .84842 L
.4098 .84615 L
.40385 .84476 L
.38462 .83979 L
.36538 .83429 L
.34615 .82865 L
.34011 .82692 L
.32692 .82196 L
.30769 .81422 L
.2918 .80769 L
.28846 .80604 L
.26923 .79578 L
.25639 .78846 L
.25 .78419 L
.23077 .77005 L
.22974 .76923 L
.21154 .75251 L
.20913 .75 L
.1927 .73077 L
.19231 .73025 L
.17996 .71154 L
.17308 .69934 L
.1699 .69231 L
.16235 .67308 L
.15657 .65385 L
.15385 .64206 L
.15258 .63462 L
.14987 .61538 L
.14763 .59615 L
.14557 .57692 L
.14354 .55769 L
.14161 .53846 L
.13995 .51923 L
.13874 .5 L
.13814 .48077 L
.13824 .46154 L
.13909 .44231 L
.14074 .42308 L
.1432 .40385 L
.14651 .38462 L
.15066 .36538 L
.15385 .35274 L
.15598 .34615 L
.16321 .32692 L
.17188 .30769 L
.17308 .30529 L
.1832 .28846 L
.19231 .27551 L
.19743 .26923 L
.21154 .25419 L
.21603 .25 L
.23077 .23797 L
.2407 .23077 L
.25 .22485 L
.26923 .21329 L
.27228 .21154 L
.28846 .20302 L
.30769 .19264 L
.30831 .19231 L
.32692 .18338 L
.34615 .17385 L
.34778 .17308 L
.36538 .16605 L
.38462 .15828 L
.39648 .15385 L
.40385 .15185 L
.42308 .1466 L
.44231 .14176 L
.46154 .13772 L
.48074 .13462 L
F
0 g
.48077 .13461 m
.5 .13291 L
.51923 .13197 L
.53846 .13202 L
.55769 .13319 L
.57124 .13462 L
.57692 .13574 L
.59615 .14011 L
.61538 .14604 L
.63462 .15322 L
.6362 .15385 L
.65385 .16266 L
.6728 .17308 L
.67308 .17325 L
.69231 .18609 L
.70138 .19231 L
.71154 .20018 L
.72578 .21154 L
.73077 .21589 L
.74713 .23077 L
.75 .23358 L
.76586 .25 L
.76923 .25369 L
.78233 .26923 L
.78846 .27678 L
.79691 .28846 L
.80769 .30355 L
.81019 .30769 L
.82197 .32692 L
.82692 .33533 L
.83229 .34615 L
.84168 .36538 L
.84615 .37536 L
.8495 .38462 L
.85593 .40385 L
.86116 .42308 L
.8649 .44231 L
.86538 .44344 L
.86687 .46154 L
.86751 .48077 L
.86691 .5 L
.86538 .5188 L
.8652 .51923 L
.86212 .53846 L
.85805 .55769 L
.8532 .57692 L
.84792 .59615 L
.84615 .60256 L
.84161 .61538 L
.83421 .63462 L
Mistroke
.82692 .65321 L
.82663 .65385 L
.81707 .67308 L
.80769 .69149 L
.80721 .69231 L
.79527 .71154 L
.78846 .72236 L
.78244 .73077 L
.76923 .74854 L
.76805 .75 L
.75166 .76923 L
.75 .77109 L
.73324 .78846 L
.73077 .79084 L
.71213 .80769 L
.71154 .80818 L
.69231 .82294 L
.68665 .82692 L
.67308 .83524 L
.65385 .84548 L
.65243 .84615 L
.63462 .85301 L
.61538 .85863 L
.59615 .86229 L
.57692 .8641 L
.55769 .86436 L
.53846 .86346 L
.51923 .86178 L
.5 .85965 L
.48077 .85723 L
.46154 .85456 L
.44231 .85161 L
.42308 .84842 L
.4098 .84615 L
.40385 .84476 L
.38462 .83979 L
.36538 .83429 L
.34615 .82865 L
.34011 .82692 L
.32692 .82196 L
.30769 .81422 L
.2918 .80769 L
.28846 .80604 L
.26923 .79578 L
.25639 .78846 L
.25 .78419 L
.23077 .77005 L
.22974 .76923 L
.21154 .75251 L
.20913 .75 L
Mistroke
.1927 .73077 L
.19231 .73025 L
.17996 .71154 L
.17308 .69934 L
.1699 .69231 L
.16235 .67308 L
.15657 .65385 L
.15385 .64206 L
.15258 .63462 L
.14987 .61538 L
.14763 .59615 L
.14557 .57692 L
.14354 .55769 L
.14161 .53846 L
.13995 .51923 L
.13874 .5 L
.13814 .48077 L
.13824 .46154 L
.13909 .44231 L
.14074 .42308 L
.1432 .40385 L
.14651 .38462 L
.15066 .36538 L
.15385 .35274 L
.15598 .34615 L
.16321 .32692 L
.17188 .30769 L
.17308 .30529 L
.1832 .28846 L
.19231 .27551 L
.19743 .26923 L
.21154 .25419 L
.21603 .25 L
.23077 .23797 L
.2407 .23077 L
.25 .22485 L
.26923 .21329 L
.27228 .21154 L
.28846 .20302 L
.30769 .19264 L
.30831 .19231 L
.32692 .18338 L
.34615 .17385 L
.34778 .17308 L
.36538 .16605 L
.38462 .15828 L
.39648 .15385 L
.40385 .15185 L
.42308 .1466 L
.44231 .14176 L
Mistroke
.46154 .13772 L
.48074 .13462 L
.48077 .13461 L
Mfstroke
.2 g
.42308 .17214 m
.44231 .16785 L
.46154 .16444 L
.48077 .16201 L
.5 .16062 L
.51923 .16031 L
.53846 .16113 L
.55769 .1632 L
.57692 .16659 L
.59615 .17134 L
.60213 .17308 L
.61538 .17775 L
.63462 .18579 L
.6484 .19231 L
.65385 .19523 L
.67308 .20642 L
.68131 .21154 L
.69231 .21916 L
.70798 .23077 L
.71154 .23366 L
.73033 .25 L
.73077 .25041 L
.74926 .26923 L
.75 .27004 L
.76538 .28846 L
.76923 .29343 L
.77919 .30769 L
.78846 .32197 L
.79127 .32692 L
.80164 .34615 L
.80769 .35852 L
.81057 .36538 L
.81805 .38462 L
.82435 .40385 L
.82692 .41305 L
.82913 .42308 L
.8325 .44231 L
.83457 .46154 L
.83535 .48077 L
.83494 .5 L
.83346 .51923 L
.83108 .53846 L
.82791 .55769 L
.82692 .56301 L
.82377 .57692 L
.81863 .59615 L
.81263 .61538 L
.80769 .62973 L
.80572 .63462 L
.79724 .65385 L
.78846 .67185 L
.78779 .67308 L
.77641 .69231 L
.76923 .70355 L
.76356 .71154 L
.75 .72921 L
.7487 .73077 L
.73139 .75 L
.73077 .75064 L
.71154 .76886 L
.71112 .76923 L
.69231 .7843 L
.6866 .78846 L
.67308 .79723 L
.65428 .80769 L
.65385 .8079 L
.63462 .81604 L
.61538 .82209 L
.59615 .82615 L
.59179 .82692 L
.57692 .82847 L
.55769 .82956 L
.53846 .82988 L
.51923 .82974 L
.5 .82927 L
.48077 .82843 L
.46154 .8271 L
.45934 .82692 L
.44231 .82495 L
.42308 .82192 L
.40385 .81799 L
.38462 .81323 L
.36538 .80785 L
.36485 .80769 L
.34615 .80107 L
.32692 .79345 L
.31515 .78846 L
.30769 .78485 L
.28846 .77463 L
.2792 .76923 L
.26923 .76263 L
.2524 .75 L
.25 .74798 L
.23212 .73077 L
.23077 .72929 L
.21668 .71154 L
.21154 .70389 L
.20494 .69231 L
.19602 .67308 L
.19231 .66314 L
.18945 .65385 L
.18457 .63462 L
.18062 .61538 L
.17717 .59615 L
.17397 .57692 L
.17308 .57131 L
.17119 .55769 L
.16878 .53846 L
.16682 .51923 L
.16551 .5 L
.16498 .48077 L
.16531 .46154 L
.16655 .44231 L
.16871 .42308 L
.1718 .40385 L
.17308 .39727 L
.17616 .38462 L
.18191 .36538 L
.18913 .34615 L
.19231 .33887 L
.19841 .32692 L
.2103 .30769 L
.21154 .30593 L
.22571 .28846 L
.23077 .28308 L
.24549 .26923 L
.25 .26544 L
.26923 .25058 L
.27002 .25 L
.28846 .2373 L
.2983 .23077 L
.30769 .22489 L
.32692 .21313 L
.32963 .21154 L
.34615 .20265 L
.36538 .19294 L
.36672 .19231 L
.38462 .18501 L
.40385 .17793 L
.41924 .17308 L
F
0 g
.42308 .17214 m
.44231 .16785 L
.46154 .16444 L
.48077 .16201 L
.5 .16062 L
.51923 .16031 L
.53846 .16113 L
.55769 .1632 L
.57692 .16659 L
.59615 .17134 L
.60213 .17308 L
.61538 .17775 L
.63462 .18579 L
.6484 .19231 L
.65385 .19523 L
.67308 .20642 L
.68131 .21154 L
.69231 .21916 L
.70798 .23077 L
.71154 .23366 L
.73033 .25 L
.73077 .25041 L
.74926 .26923 L
.75 .27004 L
.76538 .28846 L
.76923 .29343 L
.77919 .30769 L
.78846 .32197 L
.79127 .32692 L
.80164 .34615 L
.80769 .35852 L
.81057 .36538 L
.81805 .38462 L
.82435 .40385 L
.82692 .41305 L
.82913 .42308 L
.8325 .44231 L
.83457 .46154 L
.83535 .48077 L
.83494 .5 L
.83346 .51923 L
.83108 .53846 L
.82791 .55769 L
.82692 .56301 L
.82377 .57692 L
.81863 .59615 L
.81263 .61538 L
.80769 .62973 L
.80572 .63462 L
.79724 .65385 L
Mistroke
.78846 .67185 L
.78779 .67308 L
.77641 .69231 L
.76923 .70355 L
.76356 .71154 L
.75 .72921 L
.7487 .73077 L
.73139 .75 L
.73077 .75064 L
.71154 .76886 L
.71112 .76923 L
.69231 .7843 L
.6866 .78846 L
.67308 .79723 L
.65428 .80769 L
.65385 .8079 L
.63462 .81604 L
.61538 .82209 L
.59615 .82615 L
.59179 .82692 L
.57692 .82847 L
.55769 .82956 L
.53846 .82988 L
.51923 .82974 L
.5 .82927 L
.48077 .82843 L
.46154 .8271 L
.45934 .82692 L
.44231 .82495 L
.42308 .82192 L
.40385 .81799 L
.38462 .81323 L
.36538 .80785 L
.36485 .80769 L
.34615 .80107 L
.32692 .79345 L
.31515 .78846 L
.30769 .78485 L
.28846 .77463 L
.2792 .76923 L
.26923 .76263 L
.2524 .75 L
.25 .74798 L
.23212 .73077 L
.23077 .72929 L
.21668 .71154 L
.21154 .70389 L
.20494 .69231 L
.19602 .67308 L
.19231 .66314 L
Mistroke
.18945 .65385 L
.18457 .63462 L
.18062 .61538 L
.17717 .59615 L
.17397 .57692 L
.17308 .57131 L
.17119 .55769 L
.16878 .53846 L
.16682 .51923 L
.16551 .5 L
.16498 .48077 L
.16531 .46154 L
.16655 .44231 L
.16871 .42308 L
.1718 .40385 L
.17308 .39727 L
.17616 .38462 L
.18191 .36538 L
.18913 .34615 L
.19231 .33887 L
.19841 .32692 L
.2103 .30769 L
.21154 .30593 L
.22571 .28846 L
.23077 .28308 L
.24549 .26923 L
.25 .26544 L
.26923 .25058 L
.27002 .25 L
.28846 .2373 L
.2983 .23077 L
.30769 .22489 L
.32692 .21313 L
.32963 .21154 L
.34615 .20265 L
.36538 .19294 L
.36672 .19231 L
.38462 .18501 L
.40385 .17793 L
.41924 .17308 L
.42308 .17214 L
Mfstroke
.3 g
.42308 .18863 m
.44231 .18421 L
.46154 .18101 L
.48077 .17903 L
.5 .17824 L
.51923 .1786 L
.53846 .18013 L
.55769 .18284 L
.57692 .18678 L
.59615 .19195 L
.59734 .19231 L
.61538 .19859 L
.63462 .20658 L
.64528 .21154 L
.65385 .21598 L
.67308 .22702 L
.67912 .23077 L
.69231 .23989 L
.70565 .25 L
.71154 .25493 L
.72717 .26923 L
.73077 .27285 L
.74491 .28846 L
.75 .29463 L
.75969 .30769 L
.76923 .32196 L
.77216 .32692 L
.78258 .34615 L
.78846 .35851 L
.79128 .36538 L
.79837 .38462 L
.8041 .40385 L
.80769 .41915 L
.80842 .42308 L
.81137 .44231 L
.81317 .46154 L
.81391 .48077 L
.81372 .5 L
.81272 .51923 L
.81094 .53846 L
.80838 .55769 L
.80769 .56214 L
.80483 .57692 L
.80019 .59615 L
.79441 .61538 L
.78846 .63215 L
.78745 .63462 L
.77878 .65385 L
.76923 .67215 L
.76869 .67308 L
.7565 .69231 L
.75 .70153 L
.74221 .71154 L
.73077 .72485 L
.72521 .73077 L
.71154 .74393 L
.70463 .75 L
.69231 .7597 L
.67871 .76923 L
.67308 .7727 L
.65385 .78312 L
.64193 .78846 L
.63462 .79117 L
.61538 .79701 L
.59615 .80102 L
.57692 .80366 L
.55769 .80549 L
.53846 .80696 L
.52792 .80769 L
.51923 .80821 L
.5 .80911 L
.48077 .80942 L
.46154 .80893 L
.44438 .80769 L
.44231 .80748 L
.42308 .80486 L
.40385 .80109 L
.38462 .7962 L
.36538 .79032 L
.35985 .78846 L
.34615 .78319 L
.32692 .77481 L
.31537 .76923 L
.30769 .7651 L
.28846 .75349 L
.28328 .75 L
.26923 .73933 L
.25946 .73077 L
.25 .72127 L
.24166 .71154 L
.23077 .69633 L
.22833 .69231 L
.21843 .67308 L
.21154 .65546 L
.211 .65385 L
.2054 .63462 L
.20075 .61538 L
.19658 .59615 L
.19269 .57692 L
.19231 .57498 L
.18925 .55769 L
.18628 .53846 L
.18397 .51923 L
.18252 .5 L
.18204 .48077 L
.18262 .46154 L
.18428 .44231 L
.18707 .42308 L
.19103 .40385 L
.19231 .39867 L
.19644 .38462 L
.20346 .36538 L
.21154 .34778 L
.21239 .34615 L
.22391 .32692 L
.23077 .31733 L
.23858 .30769 L
.25 .29528 L
.25694 .28846 L
.26923 .27733 L
.27879 .26923 L
.28846 .26144 L
.30331 .25 L
.30769 .24678 L
.32692 .23328 L
.33072 .23077 L
.34615 .22128 L
.36361 .21154 L
.36538 .21066 L
.38462 .20186 L
.40385 .19438 L
.40991 .19231 L
F
0 g
.42308 .18863 m
.44231 .18421 L
.46154 .18101 L
.48077 .17903 L
.5 .17824 L
.51923 .1786 L
.53846 .18013 L
.55769 .18284 L
.57692 .18678 L
.59615 .19195 L
.59734 .19231 L
.61538 .19859 L
.63462 .20658 L
.64528 .21154 L
.65385 .21598 L
.67308 .22702 L
.67912 .23077 L
.69231 .23989 L
.70565 .25 L
.71154 .25493 L
.72717 .26923 L
.73077 .27285 L
.74491 .28846 L
.75 .29463 L
.75969 .30769 L
.76923 .32196 L
.77216 .32692 L
.78258 .34615 L
.78846 .35851 L
.79128 .36538 L
.79837 .38462 L
.8041 .40385 L
.80769 .41915 L
.80842 .42308 L
.81137 .44231 L
.81317 .46154 L
.81391 .48077 L
.81372 .5 L
.81272 .51923 L
.81094 .53846 L
.80838 .55769 L
.80769 .56214 L
.80483 .57692 L
.80019 .59615 L
.79441 .61538 L
.78846 .63215 L
.78745 .63462 L
.77878 .65385 L
.76923 .67215 L
.76869 .67308 L
Mistroke
.7565 .69231 L
.75 .70153 L
.74221 .71154 L
.73077 .72485 L
.72521 .73077 L
.71154 .74393 L
.70463 .75 L
.69231 .7597 L
.67871 .76923 L
.67308 .7727 L
.65385 .78312 L
.64193 .78846 L
.63462 .79117 L
.61538 .79701 L
.59615 .80102 L
.57692 .80366 L
.55769 .80549 L
.53846 .80696 L
.52792 .80769 L
.51923 .80821 L
.5 .80911 L
.48077 .80942 L
.46154 .80893 L
.44438 .80769 L
.44231 .80748 L
.42308 .80486 L
.40385 .80109 L
.38462 .7962 L
.36538 .79032 L
.35985 .78846 L
.34615 .78319 L
.32692 .77481 L
.31537 .76923 L
.30769 .7651 L
.28846 .75349 L
.28328 .75 L
.26923 .73933 L
.25946 .73077 L
.25 .72127 L
.24166 .71154 L
.23077 .69633 L
.22833 .69231 L
.21843 .67308 L
.21154 .65546 L
.211 .65385 L
.2054 .63462 L
.20075 .61538 L
.19658 .59615 L
.19269 .57692 L
.19231 .57498 L
Mistroke
.18925 .55769 L
.18628 .53846 L
.18397 .51923 L
.18252 .5 L
.18204 .48077 L
.18262 .46154 L
.18428 .44231 L
.18707 .42308 L
.19103 .40385 L
.19231 .39867 L
.19644 .38462 L
.20346 .36538 L
.21154 .34778 L
.21239 .34615 L
.22391 .32692 L
.23077 .31733 L
.23858 .30769 L
.25 .29528 L
.25694 .28846 L
.26923 .27733 L
.27879 .26923 L
.28846 .26144 L
.30331 .25 L
.30769 .24678 L
.32692 .23328 L
.33072 .23077 L
.34615 .22128 L
.36361 .21154 L
.36538 .21066 L
.38462 .20186 L
.40385 .19438 L
.40991 .19231 L
.42308 .18863 L
Mfstroke
.4 g
.40385 .20753 m
.42308 .2015 L
.44231 .19702 L
.46154 .19406 L
.48077 .19254 L
.5 .19237 L
.51923 .19346 L
.53846 .19573 L
.55769 .19913 L
.57692 .20356 L
.59615 .20899 L
.60417 .21154 L
.61538 .21547 L
.63462 .22319 L
.65095 .23077 L
.65385 .23226 L
.67308 .24316 L
.68376 .25 L
.69231 .25613 L
.70864 .26923 L
.71154 .27182 L
.72832 .28846 L
.73077 .29117 L
.74419 .30769 L
.75 .31575 L
.75713 .32692 L
.76775 .34615 L
.76923 .34912 L
.77619 .36538 L
.78291 .38462 L
.78799 .40385 L
.78846 .40572 L
.79153 .42308 L
.79383 .44231 L
.79513 .46154 L
.79571 .48077 L
.79579 .5 L
.7954 .51923 L
.7944 .53846 L
.79257 .55769 L
.78971 .57692 L
.78846 .58381 L
.78558 .59615 L
.77999 .61538 L
.7729 .63462 L
.76923 .64327 L
.76408 .65385 L
.75326 .67308 L
.75 .67826 L
.74012 .69231 L
.73077 .70404 L
.72415 .71154 L
.71154 .72422 L
.70433 .73077 L
.69231 .74034 L
.67839 .75 L
.67308 .75316 L
.65385 .76307 L
.63835 .76923 L
.63462 .77037 L
.61538 .77536 L
.59615 .77862 L
.57692 .78098 L
.55769 .78339 L
.53846 .78623 L
.52405 .78846 L
.51923 .78923 L
.5 .79188 L
.48077 .79357 L
.46154 .79405 L
.44231 .7932 L
.42308 .791 L
.40802 .78846 L
.40385 .78746 L
.38462 .78247 L
.36538 .77615 L
.3477 .76923 L
.34615 .76855 L
.32692 .75937 L
.31017 .75 L
.30769 .74848 L
.28846 .73516 L
.28296 .73077 L
.26923 .71829 L
.2629 .71154 L
.25 .69517 L
.24809 .69231 L
.23721 .67308 L
.23077 .65826 L
.22911 .65385 L
.22283 .63462 L
.2175 .61538 L
.21263 .59615 L
.21154 .59168 L
.20809 .57692 L
.20394 .55769 L
.20042 .53846 L
.19778 .51923 L
.1962 .5 L
.19579 .48077 L
.19663 .46154 L
.19877 .44231 L
.20227 .42308 L
.20723 .40385 L
.21154 .39068 L
.21382 .38462 L
.2224 .36538 L
.23077 .3503 L
.23335 .34615 L
.24713 .32692 L
.25 .32337 L
.26386 .30769 L
.26923 .30207 L
.28298 .28846 L
.28846 .28327 L
.30398 .26923 L
.30769 .26601 L
.32692 .25036 L
.3274 .25 L
.34615 .23665 L
.35539 .23077 L
.36538 .22501 L
.38462 .21528 L
.39314 .21154 L
F
0 g
.40385 .20753 m
.42308 .2015 L
.44231 .19702 L
.46154 .19406 L
.48077 .19254 L
.5 .19237 L
.51923 .19346 L
.53846 .19573 L
.55769 .19913 L
.57692 .20356 L
.59615 .20899 L
.60417 .21154 L
.61538 .21547 L
.63462 .22319 L
.65095 .23077 L
.65385 .23226 L
.67308 .24316 L
.68376 .25 L
.69231 .25613 L
.70864 .26923 L
.71154 .27182 L
.72832 .28846 L
.73077 .29117 L
.74419 .30769 L
.75 .31575 L
.75713 .32692 L
.76775 .34615 L
.76923 .34912 L
.77619 .36538 L
.78291 .38462 L
.78799 .40385 L
.78846 .40572 L
.79153 .42308 L
.79383 .44231 L
.79513 .46154 L
.79571 .48077 L
.79579 .5 L
.7954 .51923 L
.7944 .53846 L
.79257 .55769 L
.78971 .57692 L
.78846 .58381 L
.78558 .59615 L
.77999 .61538 L
.7729 .63462 L
.76923 .64327 L
.76408 .65385 L
.75326 .67308 L
.75 .67826 L
.74012 .69231 L
Mistroke
.73077 .70404 L
.72415 .71154 L
.71154 .72422 L
.70433 .73077 L
.69231 .74034 L
.67839 .75 L
.67308 .75316 L
.65385 .76307 L
.63835 .76923 L
.63462 .77037 L
.61538 .77536 L
.59615 .77862 L
.57692 .78098 L
.55769 .78339 L
.53846 .78623 L
.52405 .78846 L
.51923 .78923 L
.5 .79188 L
.48077 .79357 L
.46154 .79405 L
.44231 .7932 L
.42308 .791 L
.40802 .78846 L
.40385 .78746 L
.38462 .78247 L
.36538 .77615 L
.3477 .76923 L
.34615 .76855 L
.32692 .75937 L
.31017 .75 L
.30769 .74848 L
.28846 .73516 L
.28296 .73077 L
.26923 .71829 L
.2629 .71154 L
.25 .69517 L
.24809 .69231 L
.23721 .67308 L
.23077 .65826 L
.22911 .65385 L
.22283 .63462 L
.2175 .61538 L
.21263 .59615 L
.21154 .59168 L
.20809 .57692 L
.20394 .55769 L
.20042 .53846 L
.19778 .51923 L
.1962 .5 L
.19579 .48077 L
Mistroke
.19663 .46154 L
.19877 .44231 L
.20227 .42308 L
.20723 .40385 L
.21154 .39068 L
.21382 .38462 L
.2224 .36538 L
.23077 .3503 L
.23335 .34615 L
.24713 .32692 L
.25 .32337 L
.26386 .30769 L
.26923 .30207 L
.28298 .28846 L
.28846 .28327 L
.30398 .26923 L
.30769 .26601 L
.32692 .25036 L
.3274 .25 L
.34615 .23665 L
.35539 .23077 L
.36538 .22501 L
.38462 .21528 L
.39314 .21154 L
.40385 .20753 L
Mfstroke
.5 g
.44231 .20824 m
.46154 .20558 L
.48077 .20455 L
.5 .20505 L
.51923 .20698 L
.53846 .21017 L
.54525 .21154 L
.55769 .2143 L
.57692 .21916 L
.59615 .22457 L
.61538 .23062 L
.61583 .23077 L
.63462 .23776 L
.65385 .24641 L
.66092 .25 L
.67308 .25706 L
.69099 .26923 L
.69231 .27025 L
.71154 .28681 L
.71323 .28846 L
.7305 .30769 L
.73077 .30802 L
.74412 .32692 L
.75 .33672 L
.75486 .34615 L
.76322 .36538 L
.76923 .38376 L
.76945 .38462 L
.77371 .40385 L
.7763 .42308 L
.77753 .44231 L
.77791 .46154 L
.77812 .48077 L
.77857 .5 L
.77912 .51923 L
.77925 .53846 L
.77843 .55769 L
.77631 .57692 L
.77269 .59615 L
.76923 .60985 L
.76741 .61538 L
.76023 .63462 L
.75106 .65385 L
.75 .65583 L
.7395 .67308 L
.73077 .68522 L
.72508 .69231 L
.71154 .7069 L
.70676 .71154 L
.69231 .72348 L
.68221 .73077 L
.67308 .73608 L
.65385 .74523 L
.64098 .75 L
.63462 .7512 L
.61538 .75426 L
.59615 .75501 L
.57692 .75503 L
.55769 .75779 L
.53846 .76482 L
.51923 .76916 L
.51878 .76923 L
.5 .77492 L
.48077 .77867 L
.46154 .78046 L
.44231 .78041 L
.42308 .77862 L
.40385 .77515 L
.38462 .7701 L
.38175 .76923 L
.36538 .76346 L
.34615 .75513 L
.33593 .75 L
.32692 .74505 L
.30769 .73259 L
.30521 .73077 L
.28846 .71696 L
.28294 .71154 L
.26923 .69576 L
.26672 .69231 L
.25492 .67308 L
.25 .66282 L
.24621 .65385 L
.23931 .63462 L
.23332 .61538 L
.23077 .60668 L
.22768 .59615 L
.2222 .57692 L
.21725 .55769 L
.21318 .53846 L
.21154 .52937 L
.21022 .51923 L
.20853 .5 L
.20821 .48077 L
.20936 .46154 L
.21154 .44446 L
.21205 .44231 L
.21635 .42308 L
.22255 .40385 L
.23077 .38499 L
.23094 .38462 L
.24161 .36538 L
.25 .35312 L
.25512 .34615 L
.26923 .32877 L
.27079 .32692 L
.2875 .30769 L
.28846 .30659 L
.30499 .28846 L
.30769 .28558 L
.32434 .26923 L
.32692 .26684 L
.34615 .25092 L
.3474 .25 L
.36538 .23778 L
.37761 .23077 L
.38462 .22723 L
.40385 .2189 L
.42308 .21259 L
.42659 .21154 L
F
0 g
.44231 .20824 m
.46154 .20558 L
.48077 .20455 L
.5 .20505 L
.51923 .20698 L
.53846 .21017 L
.54525 .21154 L
.55769 .2143 L
.57692 .21916 L
.59615 .22457 L
.61538 .23062 L
.61583 .23077 L
.63462 .23776 L
.65385 .24641 L
.66092 .25 L
.67308 .25706 L
.69099 .26923 L
.69231 .27025 L
.71154 .28681 L
.71323 .28846 L
.7305 .30769 L
.73077 .30802 L
.74412 .32692 L
.75 .33672 L
.75486 .34615 L
.76322 .36538 L
.76923 .38376 L
.76945 .38462 L
.77371 .40385 L
.7763 .42308 L
.77753 .44231 L
.77791 .46154 L
.77812 .48077 L
.77857 .5 L
.77912 .51923 L
.77925 .53846 L
.77843 .55769 L
.77631 .57692 L
.77269 .59615 L
.76923 .60985 L
.76741 .61538 L
.76023 .63462 L
.75106 .65385 L
.75 .65583 L
.7395 .67308 L
.73077 .68522 L
.72508 .69231 L
.71154 .7069 L
.70676 .71154 L
.69231 .72348 L
Mistroke
.68221 .73077 L
.67308 .73608 L
.65385 .74523 L
.64098 .75 L
.63462 .7512 L
.61538 .75426 L
.59615 .75501 L
.57692 .75503 L
.55769 .75779 L
.53846 .76482 L
.51923 .76916 L
.51878 .76923 L
.5 .77492 L
.48077 .77867 L
.46154 .78046 L
.44231 .78041 L
.42308 .77862 L
.40385 .77515 L
.38462 .7701 L
.38175 .76923 L
.36538 .76346 L
.34615 .75513 L
.33593 .75 L
.32692 .74505 L
.30769 .73259 L
.30521 .73077 L
.28846 .71696 L
.28294 .71154 L
.26923 .69576 L
.26672 .69231 L
.25492 .67308 L
.25 .66282 L
.24621 .65385 L
.23931 .63462 L
.23332 .61538 L
.23077 .60668 L
.22768 .59615 L
.2222 .57692 L
.21725 .55769 L
.21318 .53846 L
.21154 .52937 L
.21022 .51923 L
.20853 .5 L
.20821 .48077 L
.20936 .46154 L
.21154 .44446 L
.21205 .44231 L
.21635 .42308 L
.22255 .40385 L
.23077 .38499 L
Mistroke
.23094 .38462 L
.24161 .36538 L
.25 .35312 L
.25512 .34615 L
.26923 .32877 L
.27079 .32692 L
.2875 .30769 L
.28846 .30659 L
.30499 .28846 L
.30769 .28558 L
.32434 .26923 L
.32692 .26684 L
.34615 .25092 L
.3474 .25 L
.36538 .23778 L
.37761 .23077 L
.38462 .22723 L
.40385 .2189 L
.42308 .21259 L
.42659 .21154 L
.44231 .20824 L
Mfstroke
.6 g
.40385 .22949 m
.42308 .22295 L
.44231 .21855 L
.46154 .21617 L
.48077 .2157 L
.5 .21706 L
.51923 .22012 L
.53846 .22466 L
.55769 .23002 L
.56037 .23077 L
.57692 .23503 L
.59615 .23998 L
.61538 .24515 L
.63094 .25 L
.63462 .25136 L
.65385 .2594 L
.67215 .26923 L
.67308 .26984 L
.69231 .28339 L
.69844 .28846 L
.71154 .30105 L
.71753 .30769 L
.73077 .32502 L
.73202 .32692 L
.74308 .34615 L
.75 .36175 L
.75126 .36538 L
.75691 .38462 L
.76025 .40385 L
.76142 .42308 L
.76084 .44231 L
.75943 .46154 L
.75874 .48077 L
.75992 .5 L
.76217 .51923 L
.76408 .53846 L
.76474 .55769 L
.76367 .57692 L
.76066 .59615 L
.75561 .61538 L
.75 .63106 L
.74841 .63462 L
.73876 .65385 L
.73077 .66668 L
.72627 .67308 L
.71154 .69052 L
.7099 .69231 L
.69231 .70782 L
.68793 .71154 L
.67308 .72022 L
.65385 .72834 L
.64426 .73077 L
.63462 .73221 L
.61538 .73122 L
.61344 .73077 L
.59615 .72467 L
.58984 .71154 L
.58849 .69231 L
.59176 .67308 L
.59615 .65503 L
.59648 .65385 L
.60238 .63462 L
.60955 .61538 L
.61538 .60204 L
.61833 .59615 L
.62921 .57692 L
.63462 .56859 L
.64218 .55769 L
.65385 .54256 L
.65683 .53846 L
.67144 .51923 L
.67308 .51688 L
.68108 .5 L
.68295 .48077 L
.67433 .46154 L
.67308 .45877 L
.6574 .44231 L
.65385 .43847 L
.63764 .42308 L
.63462 .42001 L
.61899 .40385 L
.61538 .39981 L
.60263 .38462 L
.59615 .37651 L
.5877 .36538 L
.57692 .35245 L
.57204 .34615 L
.55769 .3353 L
.53846 .32871 L
.51923 .33047 L
.5 .33673 L
.48077 .3445 L
.47663 .34615 L
.46154 .35205 L
.44231 .35853 L
.42308 .36365 L
.41547 .36538 L
.40385 .36766 L
.38462 .37125 L
.36538 .37574 L
.34615 .38446 L
.34595 .38462 L
.33226 .40385 L
.32938 .42308 L
.3301 .44231 L
.332 .46154 L
.33387 .48077 L
.33504 .5 L
.33523 .51923 L
.33461 .53846 L
.33384 .55769 L
.3343 .57692 L
.33837 .59615 L
.34615 .61161 L
.34965 .61538 L
.36538 .62876 L
.37554 .63462 L
.38462 .63911 L
.40385 .64737 L
.41973 .65385 L
.42308 .65519 L
.44231 .66369 L
.45998 .67308 L
.46154 .67384 L
.48077 .68586 L
.48857 .69231 L
.5 .70191 L
.50826 .71154 L
.51697 .73077 L
.50525 .75 L
.5 .7549 L
.48077 .76339 L
.46154 .7668 L
.44231 .76781 L
.42308 .76666 L
.40385 .76343 L
.38462 .75818 L
.36538 .75096 L
.36313 .75 L
.34615 .74195 L
.3277 .73077 L
.32692 .73029 L
.30769 .71567 L
.30324 .71154 L
.28846 .69584 L
.28578 .69231 L
.27328 .67308 L
.26923 .66506 L
.26419 .65385 L
.25669 .63462 L
.25021 .61538 L
.25 .61464 L
.24316 .59615 L
.23633 .57692 L
.23077 .55818 L
.23063 .55769 L
.22567 .53846 L
.22217 .51923 L
.22029 .5 L
.22008 .48077 L
.22167 .46154 L
.22521 .44231 L
.23077 .42369 L
.23096 .42308 L
.23867 .40385 L
.25 .38551 L
.25034 .38462 L
.26516 .36538 L
.26923 .36089 L
.28161 .34615 L
.28846 .33739 L
.29598 .32692 L
.30769 .30951 L
.30931 .30769 L
.32404 .28846 L
.32692 .28491 L
.34208 .26923 L
.34615 .2654 L
.36538 .25025 L
.36576 .25 L
.38462 .23842 L
.40068 .23077 L
F
0 g
.40385 .22949 m
.42308 .22295 L
.44231 .21855 L
.46154 .21617 L
.48077 .2157 L
.5 .21706 L
.51923 .22012 L
.53846 .22466 L
.55769 .23002 L
.56037 .23077 L
.57692 .23503 L
.59615 .23998 L
.61538 .24515 L
.63094 .25 L
.63462 .25136 L
.65385 .2594 L
.67215 .26923 L
.67308 .26984 L
.69231 .28339 L
.69844 .28846 L
.71154 .30105 L
.71753 .30769 L
.73077 .32502 L
.73202 .32692 L
.74308 .34615 L
.75 .36175 L
.75126 .36538 L
.75691 .38462 L
.76025 .40385 L
.76142 .42308 L
.76084 .44231 L
.75943 .46154 L
.75874 .48077 L
.75992 .5 L
.76217 .51923 L
.76408 .53846 L
.76474 .55769 L
.76367 .57692 L
.76066 .59615 L
.75561 .61538 L
.75 .63106 L
.74841 .63462 L
.73876 .65385 L
.73077 .66668 L
.72627 .67308 L
.71154 .69052 L
.7099 .69231 L
.69231 .70782 L
.68793 .71154 L
.67308 .72022 L
Mistroke
.65385 .72834 L
.64426 .73077 L
.63462 .73221 L
.61538 .73122 L
.61344 .73077 L
.59615 .72467 L
.58984 .71154 L
.58849 .69231 L
.59176 .67308 L
.59615 .65503 L
.59648 .65385 L
.60238 .63462 L
.60955 .61538 L
.61538 .60204 L
.61833 .59615 L
.62921 .57692 L
.63462 .56859 L
.64218 .55769 L
.65385 .54256 L
.65683 .53846 L
.67144 .51923 L
.67308 .51688 L
.68108 .5 L
.68295 .48077 L
.67433 .46154 L
.67308 .45877 L
.6574 .44231 L
.65385 .43847 L
.63764 .42308 L
.63462 .42001 L
.61899 .40385 L
.61538 .39981 L
.60263 .38462 L
.59615 .37651 L
.5877 .36538 L
.57692 .35245 L
.57204 .34615 L
.55769 .3353 L
.53846 .32871 L
.51923 .33047 L
.5 .33673 L
.48077 .3445 L
.47663 .34615 L
.46154 .35205 L
.44231 .35853 L
.42308 .36365 L
.41547 .36538 L
.40385 .36766 L
.38462 .37125 L
.36538 .37574 L
Mistroke
.34615 .38446 L
.34595 .38462 L
.33226 .40385 L
.32938 .42308 L
.3301 .44231 L
.332 .46154 L
.33387 .48077 L
.33504 .5 L
.33523 .51923 L
.33461 .53846 L
.33384 .55769 L
.3343 .57692 L
.33837 .59615 L
.34615 .61161 L
.34965 .61538 L
.36538 .62876 L
.37554 .63462 L
.38462 .63911 L
.40385 .64737 L
.41973 .65385 L
.42308 .65519 L
.44231 .66369 L
.45998 .67308 L
.46154 .67384 L
.48077 .68586 L
.48857 .69231 L
.5 .70191 L
.50826 .71154 L
.51697 .73077 L
.50525 .75 L
.5 .7549 L
.48077 .76339 L
.46154 .7668 L
.44231 .76781 L
.42308 .76666 L
.40385 .76343 L
.38462 .75818 L
.36538 .75096 L
.36313 .75 L
.34615 .74195 L
.3277 .73077 L
.32692 .73029 L
.30769 .71567 L
.30324 .71154 L
.28846 .69584 L
.28578 .69231 L
.27328 .67308 L
.26923 .66506 L
.26419 .65385 L
.25669 .63462 L
Mistroke
.25021 .61538 L
.25 .61464 L
.24316 .59615 L
.23633 .57692 L
.23077 .55818 L
.23063 .55769 L
.22567 .53846 L
.22217 .51923 L
.22029 .5 L
.22008 .48077 L
.22167 .46154 L
.22521 .44231 L
.23077 .42369 L
.23096 .42308 L
.23867 .40385 L
.25 .38551 L
.25034 .38462 L
.26516 .36538 L
.26923 .36089 L
.28161 .34615 L
.28846 .33739 L
.29598 .32692 L
.30769 .30951 L
.30931 .30769 L
.32404 .28846 L
.32692 .28491 L
.34208 .26923 L
.34615 .2654 L
.36538 .25025 L
.36576 .25 L
.38462 .23842 L
.40068 .23077 L
.40385 .22949 L
Mfstroke
.7 g
.26923 .39767 m
.28846 .38857 L
.3048 .40385 L
.30769 .41496 L
.31048 .42308 L
.31515 .44231 L
.31895 .46154 L
.32165 .48077 L
.32302 .5 L
.323 .51923 L
.32175 .53846 L
.31971 .55769 L
.31799 .57692 L
.31992 .59615 L
.32286 .61538 L
.32692 .62113 L
.34542 .63462 L
.34615 .63643 L
.36538 .64596 L
.38462 .6536 L
.38529 .65385 L
.40385 .66027 L
.42308 .66816 L
.43342 .67308 L
.44231 .67667 L
.46154 .69 L
.46407 .69231 L
.48077 .71048 L
.4814 .71154 L
.48475 .73077 L
.48077 .73807 L
.46225 .75 L
.46154 .75024 L
.44231 .75421 L
.42308 .75403 L
.40385 .75099 L
.39894 .75 L
.38462 .74603 L
.36538 .738 L
.35215 .73077 L
.34615 .7279 L
.32692 .71311 L
.32523 .71154 L
.30769 .69326 L
.30703 .69231 L
.29462 .67308 L
.28846 .65916 L
.2866 .65385 L
.27774 .63462 L
.27293 .61538 L
.26923 .60782 L
.26108 .59615 L
.25369 .57692 L
.25 .56893 L
.24502 .55769 L
.23844 .53846 L
.23435 .51923 L
.2324 .5 L
.23237 .48077 L
.23431 .46154 L
.23897 .44231 L
.24818 .42308 L
.25 .42029 L
.26255 .40385 L
F
0 g
.26923 .39767 m
.28846 .38857 L
.3048 .40385 L
.30769 .41496 L
.31048 .42308 L
.31515 .44231 L
.31895 .46154 L
.32165 .48077 L
.32302 .5 L
.323 .51923 L
.32175 .53846 L
.31971 .55769 L
.31799 .57692 L
.31992 .59615 L
.32286 .61538 L
.32692 .62113 L
.34542 .63462 L
.34615 .63643 L
.36538 .64596 L
.38462 .6536 L
.38529 .65385 L
.40385 .66027 L
.42308 .66816 L
.43342 .67308 L
.44231 .67667 L
.46154 .69 L
.46407 .69231 L
.48077 .71048 L
.4814 .71154 L
.48475 .73077 L
.48077 .73807 L
.46225 .75 L
.46154 .75024 L
.44231 .75421 L
.42308 .75403 L
.40385 .75099 L
.39894 .75 L
.38462 .74603 L
.36538 .738 L
.35215 .73077 L
.34615 .7279 L
.32692 .71311 L
.32523 .71154 L
.30769 .69326 L
.30703 .69231 L
.29462 .67308 L
.28846 .65916 L
.2866 .65385 L
.27774 .63462 L
.27293 .61538 L
Mistroke
.26923 .60782 L
.26108 .59615 L
.25369 .57692 L
.25 .56893 L
.24502 .55769 L
.23844 .53846 L
.23435 .51923 L
.2324 .5 L
.23237 .48077 L
.23431 .46154 L
.23897 .44231 L
.24818 .42308 L
.25 .42029 L
.26255 .40385 L
.26923 .39767 L
Mfstroke
.8 g
.26923 .43526 m
.28846 .43758 L
.29242 .44231 L
.30152 .46154 L
.30623 .48077 L
.30769 .49243 L
.30821 .5 L
.30769 .51687 L
.30747 .51923 L
.30395 .53846 L
.29624 .55769 L
.28846 .56607 L
.26923 .55979 L
.26742 .55769 L
.25607 .53846 L
.25 .52015 L
.2498 .51923 L
.24665 .5 L
.2471 .48077 L
.25 .46695 L
.25159 .46154 L
.26165 .44231 L
F
0 g
.26923 .43526 m
.28846 .43758 L
.29242 .44231 L
.30152 .46154 L
.30623 .48077 L
.30769 .49243 L
.30821 .5 L
.30769 .51687 L
.30747 .51923 L
.30395 .53846 L
.29624 .55769 L
.28846 .56607 L
.26923 .55979 L
.26742 .55769 L
.25607 .53846 L
.25 .52015 L
.2498 .51923 L
.24665 .5 L
.2471 .48077 L
.25 .46695 L
.25159 .46154 L
.26165 .44231 L
.26923 .43526 L
s
.7 g
.44231 .2286 m
.46154 .2266 L
.48077 .22692 L
.5 .22963 L
.50533 .23077 L
.51923 .23386 L
.53846 .2405 L
.55769 .24875 L
.56134 .25 L
.57692 .25264 L
.59615 .25658 L
.61538 .25994 L
.63462 .26476 L
.64878 .26923 L
.65385 .27194 L
.67308 .28218 L
.68267 .28846 L
.69231 .29619 L
.70456 .30769 L
.71154 .3155 L
.72023 .32692 L
.73077 .34435 L
.73165 .34615 L
.73972 .36538 L
.7447 .38462 L
.74665 .40385 L
.74564 .42308 L
.74214 .44231 L
.73077 .4579 L
.72807 .46154 L
.71154 .46464 L
.70576 .46154 L
.69231 .45118 L
.67834 .44231 L
.67308 .43825 L
.65385 .42314 L
.65376 .42308 L
.63462 .40578 L
.63265 .40385 L
.61538 .38468 L
.61533 .38462 L
.60077 .36538 L
.59615 .35909 L
.58758 .34615 L
.57692 .33239 L
.57395 .32692 L
.55769 .31595 L
.53846 .31142 L
.51923 .31624 L
.5 .32438 L
.49381 .32692 L
.48077 .33336 L
.46154 .34173 L
.44942 .34615 L
.44231 .34838 L
.42308 .35335 L
.40385 .35665 L
.38462 .35857 L
.36538 .35952 L
.34615 .35976 L
.32692 .35546 L
.32068 .34615 L
.32207 .32692 L
.32692 .31308 L
.32938 .30769 L
.34131 .28846 L
.34615 .28166 L
.35866 .26923 L
.36538 .26314 L
.38423 .25 L
.38462 .24977 L
.40385 .2398 L
.42308 .23291 L
.42919 .23077 L
F
0 g
.44231 .2286 m
.46154 .2266 L
.48077 .22692 L
.5 .22963 L
.50533 .23077 L
.51923 .23386 L
.53846 .2405 L
.55769 .24875 L
.56134 .25 L
.57692 .25264 L
.59615 .25658 L
.61538 .25994 L
.63462 .26476 L
.64878 .26923 L
.65385 .27194 L
.67308 .28218 L
.68267 .28846 L
.69231 .29619 L
.70456 .30769 L
.71154 .3155 L
.72023 .32692 L
.73077 .34435 L
.73165 .34615 L
.73972 .36538 L
.7447 .38462 L
.74665 .40385 L
.74564 .42308 L
.74214 .44231 L
.73077 .4579 L
.72807 .46154 L
.71154 .46464 L
.70576 .46154 L
.69231 .45118 L
.67834 .44231 L
.67308 .43825 L
.65385 .42314 L
.65376 .42308 L
.63462 .40578 L
.63265 .40385 L
.61538 .38468 L
.61533 .38462 L
.60077 .36538 L
.59615 .35909 L
.58758 .34615 L
.57692 .33239 L
.57395 .32692 L
.55769 .31595 L
.53846 .31142 L
.51923 .31624 L
.5 .32438 L
Mistroke
.49381 .32692 L
.48077 .33336 L
.46154 .34173 L
.44942 .34615 L
.44231 .34838 L
.42308 .35335 L
.40385 .35665 L
.38462 .35857 L
.36538 .35952 L
.34615 .35976 L
.32692 .35546 L
.32068 .34615 L
.32207 .32692 L
.32692 .31308 L
.32938 .30769 L
.34131 .28846 L
.34615 .28166 L
.35866 .26923 L
.36538 .26314 L
.38423 .25 L
.38462 .24977 L
.40385 .2398 L
.42308 .23291 L
.42919 .23077 L
.44231 .2286 L
Mfstroke
.8 g
.34615 .6627 m
.36538 .66332 L
.38462 .6694 L
.39764 .67308 L
.40385 .67585 L
.42308 .68094 L
.43742 .69231 L
.44231 .69648 L
.45489 .71154 L
.45197 .73077 L
.44231 .73536 L
.42308 .74137 L
.40385 .73756 L
.38493 .73077 L
.38462 .73065 L
.36538 .72109 L
.35136 .71154 L
.34615 .70658 L
.33374 .69231 L
.32796 .67308 L
F
0 g
.34615 .6627 m
.36538 .66332 L
.38462 .6694 L
.39764 .67308 L
.40385 .67585 L
.42308 .68094 L
.43742 .69231 L
.44231 .69648 L
.45489 .71154 L
.45197 .73077 L
.44231 .73536 L
.42308 .74137 L
.40385 .73756 L
.38493 .73077 L
.38462 .73065 L
.36538 .72109 L
.35136 .71154 L
.34615 .70658 L
.33374 .69231 L
.32796 .67308 L
.34615 .6627 L
s
.4 g
.51923 .34408 m
.53846 .3442 L
.5455 .34615 L
.55769 .35249 L
.57293 .36538 L
.57692 .37023 L
.58934 .38462 L
.59615 .39295 L
.60547 .40385 L
.61538 .41496 L
.62282 .42308 L
.63462 .43544 L
.64066 .44231 L
.65385 .45809 L
.65569 .46154 L
.66356 .48077 L
.66254 .5 L
.65418 .51923 L
.65385 .5199 L
.6417 .53846 L
.63462 .54891 L
.62859 .55769 L
.61653 .57692 L
.61538 .5789 L
.60619 .59615 L
.59725 .61538 L
.59615 .61787 L
.58942 .63462 L
.58154 .65385 L
.57692 .66356 L
.57327 .67308 L
.55769 .69086 L
.55575 .69231 L
.53846 .69386 L
.52332 .69231 L
.51923 .69051 L
.5 .68041 L
.48582 .67308 L
.48077 .67004 L
.46154 .65993 L
.4487 .65385 L
.44231 .65094 L
.42308 .64261 L
.40476 .63462 L
.40385 .6342 L
.38462 .62429 L
.37221 .61538 L
.36538 .60923 L
.35635 .59615 L
.34965 .57692 L
.3475 .55769 L
.34722 .53846 L
.34727 .51923 L
.34692 .5 L
.34615 .4822 L
.34599 .48077 L
.34484 .46154 L
.34437 .44231 L
.34615 .42405 L
.34636 .42308 L
.3549 .40385 L
.36538 .3938 L
.38462 .38494 L
.38561 .38462 L
.40385 .37929 L
.42308 .37434 L
.44231 .36897 L
.45383 .36538 L
.46154 .36273 L
.48077 .35567 L
.5 .34884 L
.50925 .34615 L
F
0 g
.51923 .34408 m
.53846 .3442 L
.5455 .34615 L
.55769 .35249 L
.57293 .36538 L
.57692 .37023 L
.58934 .38462 L
.59615 .39295 L
.60547 .40385 L
.61538 .41496 L
.62282 .42308 L
.63462 .43544 L
.64066 .44231 L
.65385 .45809 L
.65569 .46154 L
.66356 .48077 L
.66254 .5 L
.65418 .51923 L
.65385 .5199 L
.6417 .53846 L
.63462 .54891 L
.62859 .55769 L
.61653 .57692 L
.61538 .5789 L
.60619 .59615 L
.59725 .61538 L
.59615 .61787 L
.58942 .63462 L
.58154 .65385 L
.57692 .66356 L
.57327 .67308 L
.55769 .69086 L
.55575 .69231 L
.53846 .69386 L
.52332 .69231 L
.51923 .69051 L
.5 .68041 L
.48582 .67308 L
.48077 .67004 L
.46154 .65993 L
.4487 .65385 L
.44231 .65094 L
.42308 .64261 L
.40476 .63462 L
.40385 .6342 L
.38462 .62429 L
.37221 .61538 L
.36538 .60923 L
.35635 .59615 L
.34965 .57692 L
Mistroke
.3475 .55769 L
.34722 .53846 L
.34727 .51923 L
.34692 .5 L
.34615 .4822 L
.34599 .48077 L
.34484 .46154 L
.34437 .44231 L
.34615 .42405 L
.34636 .42308 L
.3549 .40385 L
.36538 .3938 L
.38462 .38494 L
.38561 .38462 L
.40385 .37929 L
.42308 .37434 L
.44231 .36897 L
.45383 .36538 L
.46154 .36273 L
.48077 .35567 L
.5 .34884 L
.50925 .34615 L
.51923 .34408 L
Mfstroke
.8 g
.42308 .24306 m
.44231 .23862 L
.46154 .23706 L
.48077 .23834 L
.5 .2432 L
.51297 .25 L
.51923 .25401 L
.5331 .26923 L
.52854 .28846 L
.51923 .29619 L
.50225 .30769 L
.5 .30987 L
.48077 .322 L
.46998 .32692 L
.46154 .33092 L
.44231 .3383 L
.42308 .34308 L
.40385 .34539 L
.38462 .34542 L
.36538 .34451 L
.34852 .32692 L
.34854 .30769 L
.35793 .28846 L
.36538 .27658 L
.3753 .26923 L
.38462 .26154 L
.40385 .25058 L
.40506 .25 L
F
0 g
.42308 .24306 m
.44231 .23862 L
.46154 .23706 L
.48077 .23834 L
.5 .2432 L
.51297 .25 L
.51923 .25401 L
.5331 .26923 L
.52854 .28846 L
.51923 .29619 L
.50225 .30769 L
.5 .30987 L
.48077 .322 L
.46998 .32692 L
.46154 .33092 L
.44231 .3383 L
.42308 .34308 L
.40385 .34539 L
.38462 .34542 L
.36538 .34451 L
.34852 .32692 L
.34854 .30769 L
.35793 .28846 L
.36538 .27658 L
.3753 .26923 L
.38462 .26154 L
.40385 .25058 L
.40506 .25 L
.42308 .24306 L
s
.3 g
.5 .36158 m
.51923 .35798 L
.53846 .35974 L
.55124 .36538 L
.55769 .36971 L
.57403 .38462 L
.57692 .38804 L
.5909 .40385 L
.59615 .40997 L
.60764 .42308 L
.61538 .43169 L
.62431 .44231 L
.63462 .45484 L
.63828 .46154 L
.64589 .48077 L
.64534 .5 L
.63788 .51923 L
.63462 .52588 L
.62666 .53846 L
.61538 .55629 L
.61451 .55769 L
.6032 .57692 L
.59615 .58991 L
.59306 .59615 L
.58381 .61538 L
.57692 .62937 L
.57451 .63462 L
.56292 .65385 L
.55769 .65921 L
.53846 .67035 L
.51923 .66973 L
.5 .66342 L
.48077 .65497 L
.47823 .65385 L
.46154 .64623 L
.44231 .6377 L
.43525 .63462 L
.42308 .62933 L
.40385 .61981 L
.39651 .61538 L
.38462 .60681 L
.37503 .59615 L
.3654 .57692 L
.36538 .5769 L
.36154 .55769 L
.36027 .53846 L
.35983 .51923 L
.35933 .5 L
.35862 .48077 L
.35815 .46154 L
.35915 .44231 L
.36425 .42308 L
.36538 .42044 L
.38038 .40385 L
.38462 .40102 L
.40385 .39227 L
.42308 .38624 L
.42873 .38462 L
.44231 .38044 L
.46154 .37415 L
.48077 .36761 L
.48603 .36538 L
F
0 g
.5 .36158 m
.51923 .35798 L
.53846 .35974 L
.55124 .36538 L
.55769 .36971 L
.57403 .38462 L
.57692 .38804 L
.5909 .40385 L
.59615 .40997 L
.60764 .42308 L
.61538 .43169 L
.62431 .44231 L
.63462 .45484 L
.63828 .46154 L
.64589 .48077 L
.64534 .5 L
.63788 .51923 L
.63462 .52588 L
.62666 .53846 L
.61538 .55629 L
.61451 .55769 L
.6032 .57692 L
.59615 .58991 L
.59306 .59615 L
.58381 .61538 L
.57692 .62937 L
.57451 .63462 L
.56292 .65385 L
.55769 .65921 L
.53846 .67035 L
.51923 .66973 L
.5 .66342 L
.48077 .65497 L
.47823 .65385 L
.46154 .64623 L
.44231 .6377 L
.43525 .63462 L
.42308 .62933 L
.40385 .61981 L
.39651 .61538 L
.38462 .60681 L
.37503 .59615 L
.3654 .57692 L
.36538 .5769 L
.36154 .55769 L
.36027 .53846 L
.35983 .51923 L
.35933 .5 L
.35862 .48077 L
.35815 .46154 L
Mistroke
.35915 .44231 L
.36425 .42308 L
.36538 .42044 L
.38038 .40385 L
.38462 .40102 L
.40385 .39227 L
.42308 .38624 L
.42873 .38462 L
.44231 .38044 L
.46154 .37415 L
.48077 .36761 L
.48603 .36538 L
.5 .36158 L
Mfstroke
.9 g
.46154 .24957 m
.46523 .25 L
.48077 .25378 L
.5 .26879 L
.50022 .26923 L
.5 .28473 L
.49815 .28846 L
.48077 .3065 L
.47927 .30769 L
.46154 .32019 L
.44231 .32687 L
.44189 .32692 L
.42308 .33182 L
.40385 .33334 L
.38462 .32968 L
.37917 .32692 L
.36833 .30769 L
.37516 .28846 L
.38462 .27727 L
.39361 .26923 L
.40385 .26212 L
.42308 .25332 L
.44231 .25003 L
.44303 .25 L
F
0 g
.46154 .24957 m
.46523 .25 L
.48077 .25378 L
.5 .26879 L
.50022 .26923 L
.5 .28473 L
.49815 .28846 L
.48077 .3065 L
.47927 .30769 L
.46154 .32019 L
.44231 .32687 L
.44189 .32692 L
.42308 .33182 L
.40385 .33334 L
.38462 .32968 L
.37917 .32692 L
.36833 .30769 L
.37516 .28846 L
.38462 .27727 L
.39361 .26923 L
.40385 .26212 L
.42308 .25332 L
.44231 .25003 L
.44303 .25 L
.46154 .24957 L
s
.2 g
.48077 .38122 m
.5 .37582 L
.51923 .37344 L
.53846 .37691 L
.55492 .38462 L
.55769 .38867 L
.57361 .40385 L
.57692 .40767 L
.5906 .42308 L
.59615 .42948 L
.60663 .44231 L
.61538 .45315 L
.62002 .46154 L
.62758 .48077 L
.62741 .5 L
.62063 .51923 L
.61538 .53019 L
.61026 .53846 L
.59883 .55769 L
.59615 .56227 L
.58805 .57692 L
.57763 .59615 L
.57692 .59747 L
.56757 .61538 L
.55769 .6299 L
.55594 .63462 L
.53846 .64644 L
.51923 .6497 L
.5 .64597 L
.48077 .63907 L
.46961 .63462 L
.46154 .6312 L
.44231 .62295 L
.42639 .61538 L
.42308 .61379 L
.40385 .60203 L
.39714 .59615 L
.38462 .57987 L
.38326 .57692 L
.37719 .55769 L
.3748 .53846 L
.37382 .51923 L
.37321 .5 L
.37279 .48077 L
.37319 .46154 L
.37615 .44231 L
.38462 .4242 L
.38588 .42308 L
.40385 .40852 L
.41456 .40385 L
.42308 .4004 L
.44231 .39366 L
.46154 .38742 L
.47016 .38462 L
F
0 g
.48077 .38122 m
.5 .37582 L
.51923 .37344 L
.53846 .37691 L
.55492 .38462 L
.55769 .38867 L
.57361 .40385 L
.57692 .40767 L
.5906 .42308 L
.59615 .42948 L
.60663 .44231 L
.61538 .45315 L
.62002 .46154 L
.62758 .48077 L
.62741 .5 L
.62063 .51923 L
.61538 .53019 L
.61026 .53846 L
.59883 .55769 L
.59615 .56227 L
.58805 .57692 L
.57763 .59615 L
.57692 .59747 L
.56757 .61538 L
.55769 .6299 L
.55594 .63462 L
.53846 .64644 L
.51923 .6497 L
.5 .64597 L
.48077 .63907 L
.46961 .63462 L
.46154 .6312 L
.44231 .62295 L
.42639 .61538 L
.42308 .61379 L
.40385 .60203 L
.39714 .59615 L
.38462 .57987 L
.38326 .57692 L
.37719 .55769 L
.3748 .53846 L
.37382 .51923 L
.37321 .5 L
.37279 .48077 L
.37319 .46154 L
.37615 .44231 L
.38462 .4242 L
.38588 .42308 L
.40385 .40852 L
.41456 .40385 L
Mistroke
.42308 .4004 L
.44231 .39366 L
.46154 .38742 L
.47016 .38462 L
.48077 .38122 L
Mfstroke
1 g
.42308 .26816 m
.44231 .2618 L
.46154 .26652 L
.46977 .26923 L
.47341 .28846 L
.46154 .30168 L
.45611 .30769 L
.44231 .31496 L
.42308 .31736 L
.40385 .31549 L
.39035 .30769 L
.39527 .28846 L
.40385 .27983 L
.41996 .26923 L
F
0 g
.42308 .26816 m
.44231 .2618 L
.46154 .26652 L
.46977 .26923 L
.47341 .28846 L
.46154 .30168 L
.45611 .30769 L
.44231 .31496 L
.42308 .31736 L
.40385 .31549 L
.39035 .30769 L
.39527 .28846 L
.40385 .27983 L
.41996 .26923 L
.42308 .26816 L
s
.1 g
.48077 .39831 m
.5 .39367 L
.51923 .39272 L
.53846 .39838 L
.54901 .40385 L
.55769 .41222 L
.56875 .42308 L
.57692 .43241 L
.58499 .44231 L
.59615 .45769 L
.59815 .46154 L
.60594 .48077 L
.60618 .5 L
.59992 .51923 L
.59615 .52798 L
.59028 .53846 L
.57932 .55769 L
.57692 .56186 L
.56873 .57692 L
.55769 .595 L
.55712 .59615 L
.54217 .61538 L
.53846 .61797 L
.51923 .62623 L
.5 .62531 L
.48077 .6199 L
.46805 .61538 L
.46154 .61266 L
.44231 .6041 L
.4284 .59615 L
.42308 .59291 L
.40675 .57692 L
.40385 .57317 L
.39711 .55769 L
.393 .53846 L
.3913 .51923 L
.39057 .5 L
.39062 .48077 L
.39243 .46154 L
.39896 .44231 L
.40385 .43439 L
.41787 .42308 L
.42308 .41987 L
.44231 .41101 L
.46154 .4045 L
.4635 .40385 L
F
0 g
.48077 .39831 m
.5 .39367 L
.51923 .39272 L
.53846 .39838 L
.54901 .40385 L
.55769 .41222 L
.56875 .42308 L
.57692 .43241 L
.58499 .44231 L
.59615 .45769 L
.59815 .46154 L
.60594 .48077 L
.60618 .5 L
.59992 .51923 L
.59615 .52798 L
.59028 .53846 L
.57932 .55769 L
.57692 .56186 L
.56873 .57692 L
.55769 .595 L
.55712 .59615 L
.54217 .61538 L
.53846 .61797 L
.51923 .62623 L
.5 .62531 L
.48077 .6199 L
.46805 .61538 L
.46154 .61266 L
.44231 .6041 L
.4284 .59615 L
.42308 .59291 L
.40675 .57692 L
.40385 .57317 L
.39711 .55769 L
.393 .53846 L
.3913 .51923 L
.39057 .5 L
.39062 .48077 L
.39243 .46154 L
.39896 .44231 L
.40385 .43439 L
.41787 .42308 L
.42308 .41987 L
.44231 .41101 L
.46154 .4045 L
.4635 .40385 L
.48077 .39831 L
s
.5 .42239 m
.51598 .42308 L
.51923 .42369 L
.53846 .43268 L
.5501 .44231 L
.55769 .45092 L
.56481 .46154 L
.57336 .48077 L
.57423 .5 L
.56879 .51923 L
.55908 .53846 L
.55769 .54098 L
.54859 .55769 L
.53846 .57161 L
.53396 .57692 L
.51923 .58911 L
.5 .59335 L
.48077 .59041 L
.46154 .58286 L
.45083 .57692 L
.44231 .57114 L
.4306 .55769 L
.42308 .53967 L
.42278 .53846 L
.41922 .51923 L
.41825 .5 L
.41964 .48077 L
.42308 .46731 L
.42527 .46154 L
.44231 .44261 L
.44293 .44231 L
.46154 .43187 L
.48077 .42558 L
.49448 .42308 L
F
.5 .42239 m
.51598 .42308 L
.51923 .42369 L
.53846 .43268 L
.5501 .44231 L
.55769 .45092 L
.56481 .46154 L
.57336 .48077 L
.57423 .5 L
.56879 .51923 L
.55908 .53846 L
.55769 .54098 L
.54859 .55769 L
.53846 .57161 L
.53396 .57692 L
.51923 .58911 L
.5 .59335 L
.48077 .59041 L
.46154 .58286 L
.45083 .57692 L
.44231 .57114 L
.4306 .55769 L
.42308 .53967 L
.42278 .53846 L
.41922 .51923 L
.41825 .5 L
.41964 .48077 L
.42308 .46731 L
.42527 .46154 L
.44231 .44261 L
.44293 .44231 L
.46154 .43187 L
.48077 .42558 L
.49448 .42308 L
.5 .42239 L
s
.8 g
.59615 .27546 m
.61538 .27617 L
.63462 .27863 L
.65385 .28472 L
.66356 .28846 L
.67308 .29463 L
.69048 .30769 L
.69231 .30953 L
.7081 .32692 L
.71154 .33136 L
.72015 .34615 L
.728 .36538 L
.73077 .37738 L
.73183 .38462 L
.73139 .40385 L
.73077 .40692 L
.72384 .42308 L
.71154 .43196 L
.69231 .43075 L
.67493 .42308 L
.67308 .42204 L
.65385 .40888 L
.64737 .40385 L
.63462 .39156 L
.62822 .38462 L
.61538 .36815 L
.61353 .36538 L
.6016 .34615 L
.59615 .33912 L
.59176 .32692 L
.5836 .30769 L
.58266 .28846 L
F
0 g
.59615 .27546 m
.61538 .27617 L
.63462 .27863 L
.65385 .28472 L
.66356 .28846 L
.67308 .29463 L
.69048 .30769 L
.69231 .30953 L
.7081 .32692 L
.71154 .33136 L
.72015 .34615 L
.728 .36538 L
.73077 .37738 L
.73183 .38462 L
.73139 .40385 L
.73077 .40692 L
.72384 .42308 L
.71154 .43196 L
.69231 .43075 L
.67493 .42308 L
.67308 .42204 L
.65385 .40888 L
.64737 .40385 L
.63462 .39156 L
.62822 .38462 L
.61538 .36815 L
.61353 .36538 L
.6016 .34615 L
.59615 .33912 L
.59176 .32692 L
.5836 .30769 L
.58266 .28846 L
.59615 .27546 L
s
.7 g
.71154 .50624 m
.73077 .50893 L
.73821 .51923 L
.74797 .53846 L
.75 .55701 L
.75008 .55769 L
.75074 .57692 L
.75 .58661 L
.74871 .59615 L
.74409 .61538 L
.73672 .63462 L
.73077 .64658 L
.72651 .65385 L
.71233 .67308 L
.71154 .67398 L
.69243 .69231 L
.69231 .6924 L
.67308 .70467 L
.65385 .71138 L
.65297 .71154 L
.63462 .71183 L
.63328 .71154 L
.61538 .7014 L
.61125 .69231 L
.60854 .67308 L
.61041 .65385 L
.61484 .63462 L
.61538 .6325 L
.62136 .61538 L
.63036 .59615 L
.63462 .58853 L
.64188 .57692 L
.65385 .56119 L
.65642 .55769 L
.67308 .53994 L
.67338 .53846 L
.69231 .52172 L
.69491 .51923 L
F
0 g
.71154 .50624 m
.73077 .50893 L
.73821 .51923 L
.74797 .53846 L
.75 .55701 L
.75008 .55769 L
.75074 .57692 L
.75 .58661 L
.74871 .59615 L
.74409 .61538 L
.73672 .63462 L
.73077 .64658 L
.72651 .65385 L
.71233 .67308 L
.71154 .67398 L
.69243 .69231 L
.69231 .6924 L
.67308 .70467 L
.65385 .71138 L
.65297 .71154 L
.63462 .71183 L
.63328 .71154 L
.61538 .7014 L
.61125 .69231 L
.60854 .67308 L
.61041 .65385 L
.61484 .63462 L
.61538 .6325 L
.62136 .61538 L
.63036 .59615 L
.63462 .58853 L
.64188 .57692 L
.65385 .56119 L
.65642 .55769 L
.67308 .53994 L
.67338 .53846 L
.69231 .52172 L
.69491 .51923 L
.71154 .50624 L
s
.9 g
.61538 .29989 m
.63462 .29391 L
.65385 .29834 L
.67199 .30769 L
.67308 .30828 L
.69231 .32476 L
.69424 .32692 L
.70793 .34615 L
.71154 .35507 L
.71515 .36538 L
.71764 .38462 L
.71154 .40253 L
.71053 .40385 L
.69231 .41173 L
.67308 .40626 L
.66846 .40385 L
.65385 .39441 L
.64199 .38462 L
.63462 .3761 L
.62671 .36538 L
.61584 .34615 L
.61538 .34499 L
.60891 .32692 L
.60883 .30769 L
F
0 g
.61538 .29989 m
.63462 .29391 L
.65385 .29834 L
.67199 .30769 L
.67308 .30828 L
.69231 .32476 L
.69424 .32692 L
.70793 .34615 L
.71154 .35507 L
.71515 .36538 L
.71764 .38462 L
.71154 .40253 L
.71053 .40385 L
.69231 .41173 L
.67308 .40626 L
.66846 .40385 L
.65385 .39441 L
.64199 .38462 L
.63462 .3761 L
.62671 .36538 L
.61584 .34615 L
.61538 .34499 L
.60891 .32692 L
.60883 .30769 L
.61538 .29989 L
s
.8 g
.69231 .54511 m
.71154 .53985 L
.73077 .55439 L
.73239 .55769 L
.73683 .57692 L
.73611 .59615 L
.73185 .61538 L
.73077 .61938 L
.72468 .63462 L
.71299 .65385 L
.71154 .65581 L
.69639 .67308 L
.69231 .67628 L
.67308 .68848 L
.66044 .69231 L
.65385 .69304 L
.64657 .69231 L
.63462 .68784 L
.626 .67308 L
.62447 .65385 L
.62748 .63462 L
.63378 .61538 L
.63462 .61319 L
.64277 .59615 L
.65385 .57991 L
.65555 .57692 L
.67308 .55903 L
.67463 .55769 L
F
0 g
.69231 .54511 m
.71154 .53985 L
.73077 .55439 L
.73239 .55769 L
.73683 .57692 L
.73611 .59615 L
.73185 .61538 L
.73077 .61938 L
.72468 .63462 L
.71299 .65385 L
.71154 .65581 L
.69639 .67308 L
.69231 .67628 L
.67308 .68848 L
.66044 .69231 L
.65385 .69304 L
.64657 .69231 L
.63462 .68784 L
.626 .67308 L
.62447 .65385 L
.62748 .63462 L
.63378 .61538 L
.63462 .61319 L
.64277 .59615 L
.65385 .57991 L
.65555 .57692 L
.67308 .55903 L
.67463 .55769 L
.69231 .54511 L
s
1 g
.63462 .31941 m
.65385 .3126 L
.67308 .32501 L
.67628 .32692 L
.69183 .34615 L
.69231 .347 L
.70098 .36538 L
.6947 .38462 L
.69231 .38814 L
.67308 .38844 L
.66565 .38462 L
.65385 .37948 L
.64362 .36538 L
.63462 .35088 L
.6323 .34615 L
.62823 .32692 L
F
0 g
.63462 .31941 m
.65385 .3126 L
.67308 .32501 L
.67628 .32692 L
.69183 .34615 L
.69231 .347 L
.70098 .36538 L
.6947 .38462 L
.69231 .38814 L
.67308 .38844 L
.66565 .38462 L
.65385 .37948 L
.64362 .36538 L
.63462 .35088 L
.6323 .34615 L
.62823 .32692 L
.63462 .31941 L
s
.9 g
.69231 .56693 m
.71154 .56864 L
.71695 .57692 L
.72281 .59615 L
.71853 .61538 L
.71154 .63144 L
.70988 .63462 L
.69699 .65385 L
.69231 .65764 L
.67308 .67019 L
.65385 .66974 L
.64258 .65385 L
.64058 .63462 L
.64728 .61538 L
.65385 .60089 L
.65839 .59615 L
.67308 .57883 L
.67575 .57692 L
F
0 g
.69231 .56693 m
.71154 .56864 L
.71695 .57692 L
.72281 .59615 L
.71853 .61538 L
.71154 .63144 L
.70988 .63462 L
.69699 .65385 L
.69231 .65764 L
.67308 .67019 L
.65385 .66974 L
.64258 .65385 L
.64058 .63462 L
.64728 .61538 L
.65385 .60089 L
.65839 .59615 L
.67308 .57883 L
.67575 .57692 L
.69231 .56693 L
s
1 g
.67308 .61027 m
.69231 .60134 L
.69584 .61538 L
.69231 .62527 L
.68491 .63462 L
.67308 .6393 L
.66759 .63462 L
.66998 .61538 L
F
0 g
.67308 .61027 m
.69231 .60134 L
.69584 .61538 L
.69231 .62527 L
.68491 .63462 L
.67308 .6393 L
.66759 .63462 L
.66998 .61538 L
.67308 .61027 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57612 Mtetra
.47173 .57612 .47766 .58195 .48818 .5788 .48228 .57294 Mtetra
.663 .741 .908 r
.48228 .57294 .48818 .5788 .49874 .57563 .49287 .56975 Mtetra
.49287 .56975 .49874 .57563 .50935 .57245 .5035 .56655 Mtetra
.5035 .56655 .50935 .57245 .51999 .56926 .51417 .56333 Mtetra
.51417 .56333 .51999 .56926 .53068 .56605 .52489 .56011 Mtetra
.663 .742 .908 r
.52489 .56011 .53068 .56605 .54141 .56284 .53564 .55687 Mtetra
.53564 .55687 .54141 .56284 .55218 .55961 .54644 .55362 Mtetra
.54644 .55362 .55218 .55961 .56299 .55636 .55728 .55036 Mtetra
.55728 .55036 .56299 .55636 .57385 .55311 .56816 .54708 Mtetra
.56816 .54708 .57385 .55311 .58474 .54984 .57909 .54379 Mtetra
.57909 .54379 .58474 .54984 .59568 .54656 .59006 .54049 Mtetra
.663 .742 .909 r
.59006 .54049 .59568 .54656 .60667 .54327 .60107 .53718 Mtetra
.60107 .53718 .60667 .54327 .61769 .53997 .61213 .53386 Mtetra
.61213 .53386 .61769 .53997 .62877 .53666 .62323 .53054 Mtetra
.662 .743 .91 r
.62323 .53054 .62877 .53666 .63988 .53334 .63437 .52722 Mtetra
.63437 .52722 .63988 .53334 .65104 .53002 .64557 .52391 Mtetra
.661 .744 .911 r
.64557 .52391 .65104 .53002 .66224 .5267 .6568 .52059 Mtetra
.661 .745 .912 r
.6568 .52059 .66224 .5267 .67349 .52336 .66808 .51727 Mtetra
.661 .746 .913 r
.66808 .51727 .67349 .52336 .68479 .52001 .67941 .51393 Mtetra
.661 .748 .914 r
.67941 .51393 .68479 .52001 .69613 .51663 .69079 .51056 Mtetra
.662 .749 .915 r
.69079 .51056 .69613 .51663 .70751 .51323 .7022 .50715 Mtetra
.663 .75 .915 r
.7022 .50715 .70751 .51323 .71894 .5098 .71367 .5037 Mtetra
.664 .751 .915 r
.71367 .5037 .71894 .5098 .73042 .50634 .72517 .5002 Mtetra
.665 .75 .914 r
.72517 .5002 .73042 .50634 .74194 .50285 .73673 .49666 Mtetra
.666 .75 .913 r
.73673 .49666 .74194 .50285 .75351 .49934 .74832 .49308 Mtetra
.666 .748 .912 r
.74832 .49308 .75351 .49934 .76512 .49582 .75997 .48949 Mtetra
.666 .747 .911 r
.75997 .48949 .76512 .49582 .77678 .49229 .77166 .48589 Mtetra
.665 .745 .91 r
.77166 .48589 .77678 .49229 .78849 .48875 .7834 .4823 Mtetra
.665 .744 .909 r
.7834 .4823 .78849 .48875 .80024 .48521 .79519 .4787 Mtetra
.664 .743 .909 r
.79519 .4787 .80024 .48521 .81205 .48165 .80702 .4751 Mtetra
.664 .742 .908 r
.80702 .4751 .81205 .48165 .8239 .47809 .81891 .4715 Mtetra
.81891 .4715 .8239 .47809 .8358 .47451 .83085 .46789 Mtetra
.83085 .46789 .8358 .47451 .84775 .47093 .84283 .46427 Mtetra
.664 .741 .908 r
.84283 .46427 .84775 .47093 .85976 .46732 .85487 .46064 Mtetra
.85487 .46064 .85976 .46732 .87181 .46371 .86696 .457 Mtetra
.86696 .457 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.663 .741 .908 r
.45523 .57343 .46122 .57928 .47173 .57612 .46576 .57024 Mtetra
.46576 .57024 .47173 .57612 .48228 .57294 .47634 .56704 Mtetra
.47634 .56704 .48228 .57294 .49287 .56975 .48695 .56383 Mtetra
.48695 .56383 .49287 .56975 .5035 .56655 .49761 .56061 Mtetra
.663 .742 .908 r
.49761 .56061 .5035 .56655 .51417 .56333 .50831 .55738 Mtetra
.50831 .55738 .51417 .56333 .52489 .56011 .51905 .55413 Mtetra
.663 .742 .909 r
.51905 .55413 .52489 .56011 .53564 .55687 .52983 .55088 Mtetra
.52983 .55088 .53564 .55687 .54644 .55362 .54066 .54761 Mtetra
.54066 .54761 .54644 .55362 .55728 .55036 .55153 .54433 Mtetra
.55153 .54433 .55728 .55036 .56816 .54708 .56244 .54103 Mtetra
.663 .743 .909 r
.56244 .54103 .56816 .54708 .57909 .54379 .57339 .53772 Mtetra
.57339 .53772 .57909 .54379 .59006 .54049 .58439 .53441 Mtetra
.663 .743 .91 r
.58439 .53441 .59006 .54049 .60107 .53718 .59544 .53109 Mtetra
.662 .743 .91 r
.59544 .53109 .60107 .53718 .61213 .53386 .60652 .52777 Mtetra
.661 .744 .911 r
.60652 .52777 .61213 .53386 .62323 .53054 .61765 .52446 Mtetra
.661 .745 .912 r
.61765 .52446 .62323 .53054 .63437 .52722 .62883 .52116 Mtetra
.66 .746 .914 r
.62883 .52116 .63437 .52722 .64557 .52391 .64006 .51787 Mtetra
.659 .747 .916 r
.64006 .51787 .64557 .52391 .6568 .52059 .65133 .5146 Mtetra
.658 .749 .917 r
.65133 .5146 .6568 .52059 .66808 .51727 .66264 .51132 Mtetra
.658 .752 .919 r
.66264 .51132 .66808 .51727 .67941 .51393 .67401 .50803 Mtetra
.658 .754 .921 r
.67401 .50803 .67941 .51393 .69079 .51056 .68542 .5047 Mtetra
.66 .757 .922 r
.68542 .5047 .69079 .51056 .7022 .50715 .69687 .50131 Mtetra
.662 .759 .922 r
.69687 .50131 .7022 .50715 .71367 .5037 .70837 .49784 Mtetra
.664 .76 .922 r
.70837 .49784 .71367 .5037 .72517 .5002 .71991 .49429 Mtetra
.667 .76 .92 r
.71991 .49429 .72517 .5002 .73673 .49666 .73149 .49066 Mtetra
.668 .759 .918 r
.73149 .49066 .73673 .49666 .74832 .49308 .74312 .48699 Mtetra
.669 .756 .916 r
.74312 .48699 .74832 .49308 .75997 .48949 .75479 .48328 Mtetra
.668 .753 .914 r
.75479 .48328 .75997 .48949 .77166 .48589 .76651 .47957 Mtetra
.668 .75 .912 r
.76651 .47957 .77166 .48589 .7834 .4823 .77828 .47588 Mtetra
.667 .747 .911 r
.77828 .47588 .7834 .4823 .79519 .4787 .7901 .47219 Mtetra
.666 .745 .91 r
.7901 .47219 .79519 .4787 .80702 .4751 .80197 .46853 Mtetra
.665 .744 .909 r
.80197 .46853 .80702 .4751 .81891 .4715 .81389 .46488 Mtetra
.664 .743 .908 r
.81389 .46488 .81891 .4715 .83085 .46789 .82586 .46123 Mtetra
.664 .742 .908 r
.82586 .46123 .83085 .46789 .84283 .46427 .83788 .45757 Mtetra
.83788 .45757 .84283 .46427 .85487 .46064 .84995 .45391 Mtetra
.664 .741 .908 r
.84995 .45391 .85487 .46064 .86696 .457 .86207 .45023 Mtetra
.86207 .45023 .86696 .457 .87909 .45334 .87424 .44655 Mtetra
.87424 .44655 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57392 Mtetra
.42819 .57392 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.663 .741 .908 r
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56432 Mtetra
.45975 .56432 .46576 .57024 .47634 .56704 .47035 .5611 Mtetra
.47035 .5611 .47634 .56704 .48695 .56383 .48099 .55787 Mtetra
.663 .742 .908 r
.48099 .55787 .48695 .56383 .49761 .56061 .49168 .55464 Mtetra
.663 .742 .909 r
.49168 .55464 .49761 .56061 .50831 .55738 .5024 .55139 Mtetra
.5024 .55139 .50831 .55738 .51905 .55413 .51317 .54814 Mtetra
.51317 .54814 .51905 .55413 .52983 .55088 .52398 .54487 Mtetra
.663 .743 .91 r
.52398 .54487 .52983 .55088 .54066 .54761 .53484 .54159 Mtetra
.53484 .54159 .54066 .54761 .55153 .54433 .54573 .5383 Mtetra
.662 .744 .911 r
.54573 .5383 .55153 .54433 .56244 .54103 .55668 .535 Mtetra
.662 .745 .911 r
.55668 .535 .56244 .54103 .57339 .53772 .56766 .5317 Mtetra
.662 .745 .912 r
.56766 .5317 .57339 .53772 .58439 .53441 .57869 .52839 Mtetra
.661 .746 .913 r
.57869 .52839 .58439 .53441 .59544 .53109 .58976 .5251 Mtetra
.66 .747 .915 r
.58976 .5251 .59544 .53109 .60652 .52777 .60088 .52181 Mtetra
.659 .749 .917 r
.60088 .52181 .60652 .52777 .61765 .52446 .61204 .51855 Mtetra
.657 .751 .919 r
.61204 .51855 .61765 .52446 .62883 .52116 .62325 .51531 Mtetra
.655 .753 .922 r
.62325 .51531 .62883 .52116 .64006 .51787 .63451 .51209 Mtetra
.654 .756 .925 r
.63451 .51209 .64006 .51787 .65133 .5146 .64582 .50891 Mtetra
.652 .76 .928 r
.64582 .50891 .65133 .5146 .66264 .51132 .65717 .50573 Mtetra
.652 .764 .932 r
.65717 .50573 .66264 .51132 .67401 .50803 .66858 .50253 Mtetra
.653 .769 .934 r
.66858 .50253 .67401 .50803 .68542 .5047 .68003 .49928 Mtetra
.655 .774 .936 r
.68003 .49928 .68542 .5047 .69687 .50131 .69152 .49594 Mtetra
.659 .777 .936 r
.69152 .49594 .69687 .50131 .70837 .49784 .70305 .49246 Mtetra
.664 .78 .935 r
.70305 .49246 .70837 .49784 .71991 .49429 .71463 .48884 Mtetra
.669 .779 .932 r
.71463 .48884 .71991 .49429 .73149 .49066 .72624 .48509 Mtetra
.672 .777 .929 r
.72624 .48509 .73149 .49066 .74312 .48699 .73789 .48124 Mtetra
.673 .772 .924 r
.73789 .48124 .74312 .48699 .75479 .48328 .74959 .47734 Mtetra
.673 .766 .92 r
.74959 .47734 .75479 .48328 .76651 .47957 .76134 .47344 Mtetra
.672 .76 .917 r
.76134 .47344 .76651 .47957 .77828 .47588 .77313 .46957 Mtetra
.67 .754 .914 r
.77313 .46957 .77828 .47588 .7901 .47219 .78498 .46575 Mtetra
.668 .75 .911 r
.78498 .46575 .7901 .47219 .80197 .46853 .79687 .46198 Mtetra
.667 .746 .91 r
.79687 .46198 .80197 .46853 .81389 .46488 .80882 .45824 Mtetra
.665 .744 .909 r
.80882 .45824 .81389 .46488 .82586 .46123 .82083 .45453 Mtetra
.665 .743 .908 r
.82083 .45453 .82586 .46123 .83788 .45757 .83288 .45083 Mtetra
.664 .742 .908 r
.83288 .45083 .83788 .45757 .84995 .45391 .84499 .44713 Mtetra
.84499 .44713 .84995 .45391 .86207 .45023 .85715 .44342 Mtetra
.664 .741 .908 r
.85715 .44342 .86207 .45023 .87424 .44655 .86936 .4397 Mtetra
.86936 .4397 .87424 .44655 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57392 .42206 .56802 Mtetra
.663 .741 .908 r
.42206 .56802 .42819 .57392 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56432 .45369 .55836 Mtetra
.45369 .55836 .45975 .56432 .47035 .5611 .46432 .55513 Mtetra
.663 .742 .909 r
.46432 .55513 .47035 .5611 .48099 .55787 .47499 .55189 Mtetra
.662 .742 .909 r
.47499 .55189 .48099 .55787 .49168 .55464 .4857 .54864 Mtetra
.662 .742 .91 r
.4857 .54864 .49168 .55464 .5024 .55139 .49646 .5454 Mtetra
.662 .743 .91 r
.49646 .5454 .5024 .55139 .51317 .54814 .50725 .54215 Mtetra
.661 .744 .911 r
.50725 .54215 .51317 .54814 .52398 .54487 .51809 .53889 Mtetra
.661 .745 .912 r
.51809 .53889 .52398 .54487 .53484 .54159 .52897 .53563 Mtetra
.661 .746 .913 r
.52897 .53563 .53484 .54159 .54573 .5383 .5399 .53237 Mtetra
.66 .748 .915 r
.5399 .53237 .54573 .5383 .55668 .535 .55087 .5291 Mtetra
.659 .749 .917 r
.55087 .5291 .55668 .535 .56766 .5317 .56188 .52585 Mtetra
.658 .751 .919 r
.56188 .52585 .56766 .5317 .57869 .52839 .57294 .52261 Mtetra
.656 .754 .922 r
.57294 .52261 .57869 .52839 .58976 .5251 .58405 .5194 Mtetra
.654 .757 .926 r
.58405 .5194 .58976 .5251 .60088 .52181 .5952 .51623 Mtetra
.651 .762 .93 r
.5952 .51623 .60088 .52181 .61204 .51855 .6064 .51309 Mtetra
.649 .766 .935 r
.6064 .51309 .61204 .51855 .62325 .51531 .61765 .51 Mtetra
.645 .771 .94 r
.61765 .51 .62325 .51531 .63451 .51209 .62895 .50694 Mtetra
.642 .777 .945 r
.62895 .50694 .63451 .51209 .64582 .50891 .6403 .50392 Mtetra
.639 .784 .951 r
.6403 .50392 .64582 .50891 .65717 .50573 .65169 .5009 Mtetra
.638 .79 .955 r
.65169 .5009 .65717 .50573 .66858 .50253 .66314 .49786 Mtetra
.639 .798 .959 r
.66314 .49786 .66858 .50253 .68003 .49928 .67463 .49474 Mtetra
.643 .805 .961 r
.67463 .49474 .68003 .49928 .69152 .49594 .68617 .49147 Mtetra
.651 .812 .961 r
.68617 .49147 .69152 .49594 .70305 .49246 .69774 .48798 Mtetra
.66 .815 .958 r
.69774 .48798 .70305 .49246 .71463 .48884 .70935 .48425 Mtetra
.67 .815 .953 r
.70935 .48425 .71463 .48884 .72624 .48509 .721 .48029 Mtetra
.678 .81 .946 r
.721 .48029 .72624 .48509 .73789 .48124 .73268 .47616 Mtetra
.682 .801 .938 r
.73268 .47616 .73789 .48124 .74959 .47734 .74439 .47193 Mtetra
.682 .79 .931 r
.74439 .47193 .74959 .47734 .76134 .47344 .75615 .4677 Mtetra
.68 .778 .924 r
.75615 .4677 .76134 .47344 .77313 .46957 .76797 .46353 Mtetra
.677 .767 .919 r
.76797 .46353 .77313 .46957 .78498 .46575 .77983 .45946 Mtetra
.673 .758 .915 r
.77983 .45946 .78498 .46575 .79687 .46198 .79175 .4555 Mtetra
.67 .752 .912 r
.79175 .4555 .79687 .46198 .80882 .45824 .80373 .45163 Mtetra
.667 .747 .91 r
.80373 .45163 .80882 .45824 .82083 .45453 .81576 .44782 Mtetra
.666 .745 .909 r
.81576 .44782 .82083 .45453 .83288 .45083 .82785 .44405 Mtetra
.665 .743 .908 r
.82785 .44405 .83288 .45083 .84499 .44713 .83999 .4403 Mtetra
.664 .742 .908 r
.83999 .4403 .84499 .44713 .85715 .44342 .85219 .43656 Mtetra
.85219 .43656 .85715 .44342 .86936 .4397 .86443 .43281 Mtetra
.664 .741 .908 r
.86443 .43281 .86936 .4397 .88162 .43597 .87673 .42904 Mtetra
.87673 .42904 .88162 .43597 .89393 .43222 .88908 .42527 Mtetra
.88908 .42527 .89393 .43222 .9063 .42846 .90149 .42147 Mtetra
.90149 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.663 .741 .908 r
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .55561 Mtetra
.43698 .55561 .44311 .56159 .45369 .55836 .44759 .55237 Mtetra
.663 .742 .909 r
.44759 .55237 .45369 .55836 .46432 .55513 .45825 .54913 Mtetra
.662 .742 .909 r
.45825 .54913 .46432 .55513 .47499 .55189 .46894 .54589 Mtetra
.661 .742 .91 r
.46894 .54589 .47499 .55189 .4857 .54864 .47968 .54265 Mtetra
.66 .743 .912 r
.47968 .54265 .4857 .54864 .49646 .5454 .49046 .53944 Mtetra
.659 .745 .913 r
.49046 .53944 .49646 .5454 .50725 .54215 .50129 .53623 Mtetra
.658 .747 .915 r
.50129 .53623 .50725 .54215 .51809 .53889 .51215 .53304 Mtetra
.657 .749 .918 r
.51215 .53304 .51809 .53889 .52897 .53563 .52306 .52985 Mtetra
.656 .752 .921 r
.52306 .52985 .52897 .53563 .5399 .53237 .53402 .52669 Mtetra
.654 .756 .925 r
.53402 .52669 .5399 .53237 .55087 .5291 .54502 .52355 Mtetra
.651 .761 .93 r
.54502 .52355 .55087 .5291 .56188 .52585 .55607 .52046 Mtetra
.647 .766 .936 r
.55607 .52046 .56188 .52585 .57294 .52261 .56716 .51743 Mtetra
.642 .773 .943 r
.56716 .51743 .57294 .52261 .58405 .5194 .57831 .51446 Mtetra
.637 .782 .951 r
.57831 .51446 .58405 .5194 .5952 .51623 .5895 .51156 Mtetra
.63 .791 .96 r
.5895 .51156 .5952 .51623 .6064 .51309 .60074 .50871 Mtetra
.623 .802 .968 r
.60074 .50871 .6064 .51309 .61765 .51 .61203 .50589 Mtetra
.616 .812 .976 r
.61203 .50589 .61765 .51 .62895 .50694 .62338 .5031 Mtetra
.608 .822 .982 r
.62338 .5031 .62895 .50694 .6403 .50392 .63477 .50033 Mtetra
.601 .831 .987 r
.63477 .50033 .6403 .50392 .65169 .5009 .64622 .49754 Mtetra
.596 .84 .991 r
.64622 .49754 .65169 .5009 .66314 .49786 .65772 .4947 Mtetra
.596 .849 .992 r
.65772 .4947 .66314 .49786 .67463 .49474 .66926 .49172 Mtetra
.603 .858 .992 r
.66926 .49172 .67463 .49474 .68617 .49147 .68085 .48852 Mtetra
.618 .867 .989 r
.68085 .48852 .68617 .49147 .69774 .48798 .69247 .48499 Mtetra
.64 .873 .985 r
.69247 .48499 .69774 .48798 .70935 .48425 .70411 .48108 Mtetra
.663 .873 .978 r
.70411 .48108 .70935 .48425 .721 .48029 .71579 .47679 Mtetra
.682 .865 .969 r
.71579 .47679 .721 .48029 .73268 .47616 .72748 .47219 Mtetra
.693 .85 .958 r
.72748 .47219 .73268 .47616 .74439 .47193 .73921 .46743 Mtetra
.697 .831 .947 r
.73921 .46743 .74439 .47193 .75615 .4677 .75098 .46265 Mtetra
.695 .81 .936 r
.75098 .46265 .75615 .4677 .76797 .46353 .7628 .45798 Mtetra
.689 .79 .927 r
.7628 .45798 .76797 .46353 .77983 .45946 .77467 .45348 Mtetra
.682 .774 .92 r
.77467 .45348 .77983 .45946 .79175 .4555 .78661 .4492 Mtetra
.676 .762 .915 r
.78661 .4492 .79175 .4555 .80373 .45163 .79861 .44509 Mtetra
.671 .753 .912 r
.79861 .44509 .80373 .45163 .81576 .44782 .81067 .44113 Mtetra
.668 .748 .91 r
.81067 .44113 .81576 .44782 .82785 .44405 .82279 .43726 Mtetra
.666 .745 .909 r
.82279 .43726 .82785 .44405 .83999 .4403 .83496 .43344 Mtetra
.665 .743 .908 r
.83496 .43344 .83999 .4403 .85219 .43656 .84719 .42965 Mtetra
.664 .742 .908 r
.84719 .42965 .85219 .43656 .86443 .43281 .85947 .42586 Mtetra
.85947 .42586 .86443 .43281 .87673 .42904 .87181 .42206 Mtetra
.664 .741 .908 r
.87181 .42206 .87673 .42904 .88908 .42527 .88419 .41826 Mtetra
.88419 .41826 .88908 .42527 .90149 .42147 .89664 .41443 Mtetra
.89664 .41443 .90149 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.663 .741 .908 r
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .55611 Mtetra
.40966 .55611 .41588 .56208 .42641 .55885 .42021 .55286 Mtetra
.42021 .55286 .42641 .55885 .43698 .55561 .43081 .5496 Mtetra
.662 .742 .909 r
.43081 .5496 .43698 .55561 .44759 .55237 .44145 .54635 Mtetra
.661 .742 .91 r
.44145 .54635 .44759 .55237 .45825 .54913 .45213 .54311 Mtetra
.66 .742 .911 r
.45213 .54311 .45825 .54913 .46894 .54589 .46285 .5399 Mtetra
.658 .744 .913 r
.46285 .5399 .46894 .54589 .47968 .54265 .47362 .53672 Mtetra
.656 .746 .916 r
.47362 .53672 .47968 .54265 .49046 .53944 .48442 .53359 Mtetra
.653 .749 .92 r
.48442 .53359 .49046 .53944 .50129 .53623 .49527 .53051 Mtetra
.65 .753 .925 r
.49527 .53051 .50129 .53623 .51215 .53304 .50617 .52748 Mtetra
.647 .759 .931 r
.50617 .52748 .51215 .53304 .52306 .52985 .51711 .52452 Mtetra
.642 .766 .938 r
.51711 .52452 .52306 .52985 .53402 .52669 .5281 .52162 Mtetra
.635 .775 .947 r
.5281 .52162 .53402 .52669 .54502 .52355 .53913 .51882 Mtetra
.625 .785 .958 r
.53913 .51882 .54502 .52355 .55607 .52046 .55022 .51613 Mtetra
.612 .798 .971 r
.55022 .51613 .55607 .52046 .56716 .51743 .56135 .51356 Mtetra
.594 .813 .984 r
.56135 .51356 .56716 .51743 .57831 .51446 .57254 .51112 Mtetra
.571 .828 .994 r
.57254 .51112 .57831 .51446 .5895 .51156 .58378 .50876 Mtetra
.544 .842 .999 r
.58378 .50876 .5895 .51156 .60074 .50871 .59508 .50644 Mtetra
.514 .851 .996 r
.59508 .50644 .60074 .50871 .61203 .50589 .60643 .5041 Mtetra
.483 .856 .985 r
.60643 .5041 .61203 .50589 .62338 .5031 .61783 .50171 Mtetra
.456 .856 .97 r
.61783 .50171 .62338 .5031 .63477 .50033 .62928 .49924 Mtetra
.434 .854 .954 r
.62928 .49924 .63477 .50033 .64622 .49754 .64079 .49668 Mtetra
.422 .853 .941 r
.64079 .49668 .64622 .49754 .65772 .4947 .65234 .49399 Mtetra
.424 .858 .932 r
.65234 .49399 .65772 .4947 .66926 .49172 .66394 .49109 Mtetra
.444 .87 .931 r
.66394 .49109 .66926 .49172 .68085 .48852 .67558 .48789 Mtetra
.484 .89 .937 r
.67558 .48789 .68085 .48852 .69247 .48499 .68725 .48422 Mtetra
.541 .913 .949 r
.68725 .48422 .69247 .48499 .70411 .48108 .69894 .48 Mtetra
.604 .931 .961 r
.69894 .48 .70411 .48108 .71579 .47679 .71063 .47521 Mtetra
.66 .935 .968 r
.71063 .47521 .71579 .47679 .72748 .47219 .72235 .46992 Mtetra
.698 .921 .968 r
.72235 .46992 .72748 .47219 .73921 .46743 .73408 .46435 Mtetra
.716 .894 .961 r
.73408 .46435 .73921 .46743 .75098 .46265 .74584 .45871 Mtetra
.717 .861 .95 r
.74584 .45871 .75098 .46265 .7628 .45798 .75765 .45323 Mtetra
.71 .828 .938 r
.75765 .45323 .7628 .45798 .77467 .45348 .76952 .44805 Mtetra
.698 .8 .928 r
.76952 .44805 .77467 .45348 .78661 .4492 .78146 .44323 Mtetra
.687 .779 .92 r
.78146 .44323 .78661 .4492 .79861 .44509 .79346 .43874 Mtetra
.678 .763 .915 r
.79346 .43874 .79861 .44509 .81067 .44113 .80554 .43452 Mtetra
.672 .753 .912 r
.80554 .43452 .81067 .44113 .82279 .43726 .81769 .43048 Mtetra
.668 .748 .91 r
.81769 .43048 .82279 .43726 .83496 .43344 .82989 .42656 Mtetra
.666 .744 .909 r
.82989 .42656 .83496 .43344 .84719 .42965 .84215 .4227 Mtetra
.665 .743 .908 r
.84215 .4227 .84719 .42965 .85947 .42586 .85447 .41886 Mtetra
.664 .742 .908 r
.85447 .41886 .85947 .42586 .87181 .42206 .86684 .41503 Mtetra
.86684 .41503 .87181 .42206 .88419 .41826 .87927 .41119 Mtetra
.664 .741 .908 r
.87927 .41119 .88419 .41826 .89664 .41443 .89175 .40734 Mtetra
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.663 .741 .908 r
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .55611 .40339 .55009 Mtetra
.40339 .55009 .40966 .55611 .42021 .55286 .41397 .54683 Mtetra
.662 .741 .909 r
.41397 .54683 .42021 .55286 .43081 .5496 .4246 .54357 Mtetra
.661 .742 .91 r
.4246 .54357 .43081 .5496 .44145 .54635 .43526 .54033 Mtetra
.659 .742 .911 r
.43526 .54033 .44145 .54635 .45213 .54311 .44596 .53713 Mtetra
.656 .744 .914 r
.44596 .53713 .45213 .54311 .46285 .5399 .45671 .53399 Mtetra
.652 .746 .918 r
.45671 .53399 .46285 .5399 .47362 .53672 .4675 .53096 Mtetra
.647 .75 .925 r
.4675 .53096 .47362 .53672 .48442 .53359 .47833 .52803 Mtetra
.64 .756 .933 r
.47833 .52803 .48442 .53359 .49527 .53051 .48921 .52524 Mtetra
.631 .765 .943 r
.48921 .52524 .49527 .53051 .50617 .52748 .50013 .52259 Mtetra
.619 .776 .956 r
.50013 .52259 .50617 .52748 .51711 .52452 .5111 .52009 Mtetra
.601 .791 .972 r
.5111 .52009 .51711 .52452 .5281 .52162 .52212 .51778 Mtetra
.573 .806 .987 r
.52212 .51778 .5281 .52162 .53913 .51882 .5332 .51568 Mtetra
.529 .821 .999 r
.5332 .51568 .53913 .51882 .55022 .51613 .54432 .51382 Mtetra
.459 .825 .994 r
.54432 .51382 .55022 .51613 .56135 .51356 .55551 .51217 Mtetra
.359 .805 .952 r
.55551 .51217 .56135 .51356 .57254 .51112 .56676 .5107 Mtetra
.236 .749 .859 r
.56676 .5107 .57254 .51112 .58378 .50876 .57806 .5093 Mtetra
.117 .668 .732 r
.57806 .5093 .58378 .50876 .59508 .50644 .58943 .50783 Mtetra
0 0 0 r
.58943 .50783 .59508 .50644 .60643 .5041 .60085 .50618 Mtetra
.024 0 0 r
.60085 .50618 .60643 .5041 .61783 .50171 .61232 .50425 Mtetra
.045 0 0 r
.61232 .50425 .61783 .50171 .62928 .49924 .62384 .50203 Mtetra
.044 0 0 r
.62384 .50203 .62928 .49924 .64079 .49668 .63542 .49953 Mtetra
.027 0 0 r
.63542 .49953 .64079 .49668 .65234 .49399 .64703 .49677 Mtetra
0 0 0 r
.64703 .49677 .65234 .49399 .66394 .49109 .65869 .49374 Mtetra
.65869 .49374 .66394 .49109 .67558 .48789 .67039 .49033 Mtetra
.67039 .49033 .67558 .48789 .68725 .48422 .68211 .48637 Mtetra
.68211 .48637 .68725 .48422 .69894 .48 .69384 .48169 Mtetra
.388 .837 .735 r
.69384 .48169 .69894 .48 .71063 .47521 .70557 .4762 Mtetra
.531 .921 .828 r
.70557 .4762 .71063 .47521 .72235 .46992 .71729 .46998 Mtetra
.647 .966 .9 r
.71729 .46998 .72235 .46992 .73408 .46435 .72902 .46327 Mtetra
.717 .965 .939 r
.72902 .46327 .73408 .46435 .74584 .45871 .74076 .4564 Mtetra
.742 .931 .951 r
.74076 .4564 .74584 .45871 .75765 .45323 .75254 .44972 Mtetra
.739 .886 .947 r
.75254 .44972 .75765 .45323 .76952 .44805 .76438 .44348 Mtetra
.724 .842 .937 r
.76438 .44348 .76952 .44805 .78146 .44323 .77631 .43781 Mtetra
.706 .806 .927 r
.77631 .43781 .78146 .44323 .79346 .43874 .78831 .4327 Mtetra
.691 .78 .919 r
.78831 .4327 .79346 .43874 .80554 .43452 .80039 .42806 Mtetra
.68 .763 .914 r
.80039 .42806 .80554 .43452 .81769 .43048 .81255 .42376 Mtetra
.672 .753 .911 r
.81255 .42376 .81769 .43048 .82989 .42656 .82479 .41968 Mtetra
.668 .747 .909 r
.82479 .41968 .82989 .42656 .84215 .4227 .83708 .41572 Mtetra
.666 .744 .909 r
.83708 .41572 .84215 .4227 .85447 .41886 .84943 .41182 Mtetra
.664 .742 .908 r
.84943 .41182 .85447 .41886 .86684 .41503 .86184 .40795 Mtetra
.86184 .40795 .86684 .41503 .87927 .41119 .8743 .40407 Mtetra
.664 .741 .908 r
.8743 .40407 .87927 .41119 .89175 .40734 .88682 .40019 Mtetra
.88682 .40019 .89175 .40734 .90428 .40347 .89939 .39629 Mtetra
.89939 .39629 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.663 .741 .908 r
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55059 Mtetra
.37599 .55059 .38235 .5566 .39285 .55335 .38651 .54731 Mtetra
.38651 .54731 .39285 .55335 .40339 .55009 .39708 .54404 Mtetra
.662 .741 .909 r
.39708 .54404 .40339 .55009 .41397 .54683 .40768 .54077 Mtetra
.661 .742 .91 r
.40768 .54077 .41397 .54683 .4246 .54357 .41833 .53752 Mtetra
.659 .742 .912 r
.41833 .53752 .4246 .54357 .43526 .54033 .42902 .53433 Mtetra
.655 .743 .915 r
.42902 .53433 .43526 .54033 .44596 .53713 .43975 .53123 Mtetra
.648 .746 .921 r
.43975 .53123 .44596 .53713 .45671 .53399 .45052 .52828 Mtetra
.639 .75 .929 r
.45052 .52828 .45671 .53399 .4675 .53096 .46133 .52553 Mtetra
.626 .758 .941 r
.46133 .52553 .4675 .53096 .47833 .52803 .47219 .52303 Mtetra
.607 .768 .957 r
.47219 .52303 .47833 .52803 .48921 .52524 .48309 .52081 Mtetra
.578 .783 .976 r
.48309 .52081 .48921 .52524 .50013 .52259 .49403 .51891 Mtetra
.531 .798 .995 r
.49403 .51891 .50013 .52259 .5111 .52009 .50504 .51734 Mtetra
.45 .804 .997 r
.50504 .51734 .5111 .52009 .52212 .51778 .51609 .51614 Mtetra
.309 .77 .947 r
.51609 .51614 .52212 .51778 .5332 .51568 .52721 .51534 Mtetra
.098 .653 .789 r
.52721 .51534 .5332 .51568 .54432 .51382 .53839 .51494 Mtetra
.123 0 0 r
.53839 .51494 .54432 .51382 .55551 .51217 .54964 .51486 Mtetra
.279 0 0 r
.54964 .51486 .55551 .51217 .56676 .5107 .56096 .51496 Mtetra
.361 0 0 r
.56096 .51496 .56676 .5107 .57806 .5093 .57235 .515 Mtetra
.394 0 0 r
.57235 .515 .57806 .5093 .58943 .50783 .5838 .51471 Mtetra
.398 0 .046 r
.5838 .51471 .58943 .50783 .60085 .50618 .59532 .51385 Mtetra
.385 0 .071 r
.59532 .51385 .60085 .50618 .61232 .50425 .60688 .51227 Mtetra
.361 0 .071 r
.60688 .51227 .61232 .50425 .62384 .50203 .61848 .50998 Mtetra
.331 0 .052 r
.61848 .50998 .62384 .50203 .63542 .49953 .63012 .5071 Mtetra
.297 0 .017 r
.63012 .5071 .63542 .49953 .64703 .49677 .6418 .5038 Mtetra
.259 0 0 r
.6418 .5038 .64703 .49677 .65869 .49374 .65352 .50019 Mtetra
.212 0 0 r
.65352 .50019 .65869 .49374 .67039 .49033 .66527 .49625 Mtetra
.146 0 0 r
.66527 .49625 .67039 .49033 .68211 .48637 .67705 .49178 Mtetra
.051 0 0 r
.67705 .49178 .68211 .48637 .69384 .48169 .68884 .48652 Mtetra
0 0 0 r
.68884 .48652 .69384 .48169 .70557 .4762 .7006 .48024 Mtetra
.7006 .48024 .70557 .4762 .71729 .46998 .71234 .47292 Mtetra
.462 .85 .642 r
.71234 .47292 .71729 .46998 .72902 .46327 .72406 .46479 Mtetra
.635 .959 .793 r
.72406 .46479 .72902 .46327 .74076 .4564 .73577 .45631 Mtetra
.738 .988 .891 r
.73577 .45631 .74076 .4564 .75254 .44972 .74751 .44798 Mtetra
.769 .956 .933 r
.74751 .44798 .75254 .44972 .76438 .44348 .7593 .44022 Mtetra
.759 .901 .94 r
.7593 .44022 .76438 .44348 .77631 .43781 .77118 .43328 Mtetra
.735 .848 .934 r
.77118 .43328 .77631 .43781 .78831 .4327 .78316 .42721 Mtetra
.711 .807 .925 r
.78316 .42721 .78831 .4327 .80039 .42806 .79523 .4219 Mtetra
.692 .779 .918 r
.79523 .4219 .80039 .42806 .81255 .42376 .8074 .41718 Mtetra
.679 .761 .913 r
.8074 .41718 .81255 .42376 .82479 .41968 .81965 .41284 Mtetra
.672 .751 .91 r
.81965 .41284 .82479 .41968 .83708 .41572 .83197 .40873 Mtetra
.667 .746 .909 r
.83197 .40873 .83708 .41572 .84943 .41182 .84436 .40475 Mtetra
.665 .743 .908 r
.84436 .40475 .84943 .41182 .86184 .40795 .8568 .40082 Mtetra
.664 .742 .908 r
.8568 .40082 .86184 .40795 .8743 .40407 .8693 .3969 Mtetra
.8693 .3969 .8743 .40407 .88682 .40019 .88186 .39298 Mtetra
.664 .741 .908 r
.88186 .39298 .88682 .40019 .89939 .39629 .89447 .38905 Mtetra
.89447 .38905 .89939 .39629 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.663 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55059 .36958 .54453 Mtetra
.36958 .54453 .37599 .55059 .38651 .54731 .38013 .54124 Mtetra
.662 .741 .909 r
.38013 .54124 .38651 .54731 .39708 .54404 .39072 .53796 Mtetra
.661 .742 .91 r
.39072 .53796 .39708 .54404 .40768 .54077 .40135 .5347 Mtetra
.658 .742 .912 r
.40135 .5347 .40768 .54077 .41833 .53752 .41202 .5315 Mtetra
.654 .743 .915 r
.41202 .5315 .41833 .53752 .42902 .53433 .42273 .52841 Mtetra
.645 .745 .922 r
.42273 .52841 .42902 .53433 .43975 .53123 .43348 .52553 Mtetra
.632 .749 .932 r
.43348 .52553 .43975 .53123 .45052 .52828 .44427 .52293 Mtetra
.611 .757 .948 r
.44427 .52293 .45052 .52828 .46133 .52553 .4551 .52072 Mtetra
.576 .767 .969 r
.4551 .52072 .46133 .52553 .47219 .52303 .46597 .51899 Mtetra
.516 .778 .991 r
.46597 .51899 .47219 .52303 .48309 .52081 .47689 .51781 Mtetra
.407 .774 .994 r
.47689 .51781 .48309 .52081 .49403 .51891 .48786 .51723 Mtetra
.208 .707 .913 r
.48786 .51723 .49403 .51891 .50504 .51734 .49889 .51725 Mtetra
.077 0 0 r
.49889 .51725 .50504 .51734 .51609 .51614 .50998 .51792 Mtetra
.322 0 0 r
.50998 .51792 .51609 .51614 .52721 .51534 .52115 .51921 Mtetra
.457 0 0 r
.52115 .51921 .52721 .51534 .53839 .51494 .53239 .52107 Mtetra
.517 .054 .093 r
.53239 .52107 .53839 .51494 .54964 .51486 .54372 .52331 Mtetra
.539 .117 .188 r
.54372 .52331 .54964 .51486 .56096 .51496 .55514 .5256 Mtetra
.539 .146 .244 r
.55514 .5256 .56096 .51496 .57235 .515 .56663 .52749 Mtetra
.526 .152 .274 r
.56663 .52749 .57235 .515 .5838 .51471 .5782 .52851 Mtetra
.503 .141 .285 r
.5782 .52851 .5838 .51471 .59532 .51385 .58982 .52826 Mtetra
.473 .117 .281 r
.58982 .52826 .59532 .51385 .60688 .51227 .60148 .52657 Mtetra
.438 .083 .264 r
.60148 .52657 .60688 .51227 .61848 .50998 .61317 .52353 Mtetra
.401 .041 .235 r
.61317 .52353 .61848 .50998 .63012 .5071 .62488 .51947 Mtetra
.364 0 .196 r
.62488 .51947 .63012 .5071 .6418 .5038 .63662 .51486 Mtetra
.331 0 .149 r
.63662 .51486 .6418 .5038 .65352 .50019 .64839 .51006 Mtetra
.298 0 .1 r
.64839 .51006 .65352 .50019 .66527 .49625 .6602 .50521 Mtetra
.257 0 .049 r
.6602 .50521 .66527 .49625 .67705 .49178 .67204 .50011 Mtetra
.196 0 0 r
.67204 .50011 .67705 .49178 .68884 .48652 .6839 .49432 Mtetra
.101 0 0 r
.6839 .49432 .68884 .48652 .7006 .48024 .69572 .48737 Mtetra
0 0 0 r
.69572 .48737 .7006 .48024 .71234 .47292 .7075 .47902 Mtetra
.7075 .47902 .71234 .47292 .72406 .46479 .71922 .4694 Mtetra
.71922 .4694 .72406 .46479 .73577 .45631 .7309 .45903 Mtetra
.639 .937 .694 r
.7309 .45903 .73577 .45631 .74751 .44798 .74257 .44859 Mtetra
.762 .996 .843 r
.74257 .44859 .74751 .44798 .7593 .44022 .7543 .43878 Mtetra
.794 .969 .914 r
.7543 .43878 .7593 .44022 .77118 .43328 .76611 .43005 Mtetra
.774 .907 .932 r
.76611 .43005 .77118 .43328 .78316 .42721 .77803 .42257 Mtetra
.741 .849 .93 r
.77803 .42257 .78316 .42721 .79523 .4219 .79007 .41625 Mtetra
.712 .805 .923 r
.79007 .41625 .79523 .4219 .8074 .41718 .80223 .41085 Mtetra
.691 .776 .916 r
.80223 .41085 .8074 .41718 .81965 .41284 .81449 .40611 Mtetra
.678 .759 .912 r
.81449 .40611 .81965 .41284 .83197 .40873 .82683 .40177 Mtetra
.67 .75 .91 r
.82683 .40177 .83197 .40873 .84436 .40475 .83924 .39765 Mtetra
.667 .745 .909 r
.83924 .39765 .84436 .40475 .8568 .40082 .85172 .39364 Mtetra
.665 .743 .908 r
.85172 .39364 .8568 .40082 .8693 .3969 .86426 .38967 Mtetra
.664 .742 .908 r
.86426 .38967 .8693 .3969 .88186 .39298 .87685 .38571 Mtetra
.664 .741 .908 r
.87685 .38571 .88186 .39298 .89447 .38905 .8895 .38175 Mtetra
.8895 .38175 .89447 .38905 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35258 .54173 Mtetra
.35258 .54173 .35907 .54781 .36958 .54453 .36312 .53843 Mtetra
.663 .741 .909 r
.36312 .53843 .36958 .54453 .38013 .54124 .37369 .53513 Mtetra
.661 .742 .91 r
.37369 .53513 .38013 .54124 .39072 .53796 .38431 .53186 Mtetra
.659 .742 .911 r
.38431 .53186 .39072 .53796 .40135 .5347 .39496 .52864 Mtetra
.654 .743 .915 r
.39496 .52864 .40135 .5347 .41202 .5315 .40566 .52554 Mtetra
.644 .744 .922 r
.40566 .52554 .41202 .5315 .42273 .52841 .41639 .52267 Mtetra
.628 .748 .933 r
.41639 .52267 .42273 .52841 .43348 .52553 .42716 .52016 Mtetra
.599 .753 .952 r
.42716 .52016 .43348 .52553 .44427 .52293 .43796 .51817 Mtetra
.547 .76 .976 r
.43796 .51817 .44427 .52293 .4551 .52072 .44879 .51688 Mtetra
.446 .758 .995 r
.44879 .51688 .4551 .52072 .46597 .51899 .45967 .51644 Mtetra
.243 .703 .95 r
.45967 .51644 .46597 .51899 .47689 .51781 .4706 .51693 Mtetra
0 .499 .706 r
.4706 .51693 .47689 .51781 .48786 .51723 .48158 .51841 Mtetra
.385 0 0 r
.48158 .51841 .48786 .51723 .49889 .51725 .49264 .52087 Mtetra
.529 .016 0 r
.49264 .52087 .49889 .51725 .50998 .51792 .50377 .52426 Mtetra
.586 .137 .152 r
.50377 .52426 .50998 .51792 .52115 .51921 .51499 .52851 Mtetra
.606 .202 .251 r
.51499 .52851 .52115 .51921 .53239 .52107 .52631 .5334 Mtetra
.609 .236 .311 r
.52631 .5334 .53239 .52107 .54372 .52331 .53773 .53855 Mtetra
.6 .249 .346 r
.53773 .53855 .54372 .52331 .55514 .5256 .54926 .54339 Mtetra
.583 .247 .365 r
.54926 .54339 .55514 .5256 .56663 .52749 .56088 .54719 Mtetra
.558 .232 .372 r
.56088 .54719 .56663 .52749 .5782 .52851 .57258 .54921 Mtetra
.525 .205 .368 r
.57258 .54921 .5782 .52851 .58982 .52826 .58432 .54895 Mtetra
.485 .168 .354 r
.58432 .54895 .58982 .52826 .60148 .52657 .59609 .54623 Mtetra
.439 .121 .328 r
.59609 .54623 .60148 .52657 .61317 .52353 .60785 .54138 Mtetra
.391 .066 .291 r
.60785 .54138 .61317 .52353 .62488 .51947 .61962 .53509 Mtetra
.347 .01 .243 r
.61962 .53509 .62488 .51947 .63662 .51486 .6314 .52826 Mtetra
.314 0 .191 r
.6314 .52826 .63662 .51486 .64839 .51006 .64322 .52167 Mtetra
.294 0 .142 r
.64322 .52167 .64839 .51006 .6602 .50521 .65509 .51567 Mtetra
.28 0 .105 r
.65509 .51567 .6602 .50521 .67204 .50011 .66701 .51006 Mtetra
.252 0 .077 r
.66701 .51006 .67204 .50011 .6839 .49432 .67896 .50417 Mtetra
.195 0 .048 r
.67896 .50417 .6839 .49432 .69572 .48737 .69089 .49711 Mtetra
.097 0 .002 r
.69089 .49711 .69572 .48737 .7075 .47902 .70274 .48822 Mtetra
0 0 0 r
.70274 .48822 .7075 .47902 .71922 .4694 .71449 .47737 Mtetra
.71449 .47737 .71922 .4694 .7309 .45903 .72616 .46506 Mtetra
.72616 .46506 .7309 .45903 .74257 .44859 .73777 .45219 Mtetra
.66 .923 .625 r
.73777 .45219 .74257 .44859 .7543 .43878 .74941 .43979 Mtetra
.789 .998 .808 r
.74941 .43979 .7543 .43878 .76611 .43005 .76112 .42865 Mtetra
.813 .972 .9 r
.76112 .42865 .76611 .43005 .77803 .42257 .77296 .41918 Mtetra
.783 .905 .926 r
.77296 .41918 .77803 .42257 .79007 .41625 .78494 .41137 Mtetra
.742 .843 .926 r
.78494 .41137 .79007 .41625 .80223 .41085 .79706 .40496 Mtetra
.71 .799 .92 r
.79706 .40496 .80223 .41085 .81449 .40611 .8093 .39958 Mtetra
.688 .771 .915 r
.8093 .39958 .81449 .40611 .82683 .40177 .82166 .39488 Mtetra
.676 .756 .911 r
.82166 .39488 .82683 .40177 .83924 .39765 .83409 .39056 Mtetra
.669 .748 .909 r
.83409 .39056 .83924 .39765 .85172 .39364 .8466 .38643 Mtetra
.666 .744 .908 r
.8466 .38643 .85172 .39364 .86426 .38967 .85918 .3824 Mtetra
.664 .742 .908 r
.85918 .3824 .86426 .38967 .87685 .38571 .87181 .3784 Mtetra
.87181 .3784 .87685 .38571 .8895 .38175 .8845 .37439 Mtetra
.664 .741 .908 r
.8845 .37439 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.663 .741 .908 r
.33554 .53893 .34209 .54503 .35258 .54173 .34605 .53561 Mtetra
.34605 .53561 .35258 .54173 .36312 .53843 .35661 .5323 Mtetra
.662 .741 .909 r
.35661 .5323 .36312 .53843 .37369 .53513 .36721 .529 Mtetra
.659 .742 .911 r
.36721 .529 .37369 .53513 .38431 .53186 .37785 .52576 Mtetra
.655 .742 .914 r
.37785 .52576 .38431 .53186 .39496 .52864 .38853 .52263 Mtetra
.645 .743 .921 r
.38853 .52263 .39496 .52864 .40566 .52554 .39924 .51972 Mtetra
.628 .746 .932 r
.39924 .51972 .40566 .52554 .41639 .52267 .40999 .5172 Mtetra
.596 .749 .951 r
.40999 .5172 .41639 .52267 .42716 .52016 .42076 .51529 Mtetra
.532 .751 .976 r
.42076 .51529 .42716 .52016 .43796 .51817 .43156 .51426 Mtetra
.396 .733 .991 r
.43156 .51426 .43796 .51817 .44879 .51688 .4424 .51438 Mtetra
.107 .618 .893 r
.4424 .51438 .44879 .51688 .45967 .51644 .45327 .51584 Mtetra
.297 0 0 r
.45327 .51584 .45967 .51644 .4706 .51693 .46419 .51875 Mtetra
.539 0 0 r
.46419 .51875 .4706 .51693 .48158 .51841 .47518 .52311 Mtetra
.623 .154 .118 r
.47518 .52311 .48158 .51841 .49264 .52087 .48625 .52881 Mtetra
.649 .235 .246 r
.48625 .52881 .49264 .52087 .50377 .52426 .49742 .53568 Mtetra
.653 .277 .319 r
.49742 .53568 .50377 .52426 .51499 .52851 .5087 .54348 Mtetra
.648 .297 .363 r
.5087 .54348 .51499 .52851 .52631 .5334 .5201 .55178 Mtetra
.637 .303 .389 r
.5201 .55178 .52631 .5334 .53773 .53855 .53163 .55994 Mtetra
.619 .298 .404 r
.53163 .55994 .53773 .53855 .54926 .54339 .54328 .56709 Mtetra
.594 .282 .409 r
.54328 .56709 .54926 .54339 .56088 .54719 .55504 .57221 Mtetra
.561 .254 .405 r
.55504 .57221 .56088 .54719 .57258 .54921 .56687 .57434 Mtetra
.516 .213 .391 r
.56687 .57434 .57258 .54921 .58432 .54895 .57873 .5729 Mtetra
.459 .157 .365 r
.57873 .5729 .58432 .54895 .59609 .54623 .59059 .5679 Mtetra
.39 .085 .324 r
.59059 .5679 .59609 .54623 .60785 .54138 .60242 .56002 Mtetra
.313 .001 .265 r
.60242 .56002 .60785 .54138 .61962 .53509 .61424 .55047 Mtetra
.242 0 .19 r
.61424 .55047 .61962 .53509 .6314 .52826 .62605 .54072 Mtetra
.2 0 .114 r
.62605 .54072 .6314 .52826 .64322 .52167 .63791 .53203 Mtetra
.206 0 .06 r
.63791 .53203 .64322 .52167 .65509 .51567 .64984 .52505 Mtetra
.244 0 .046 r
.64984 .52505 .65509 .51567 .66701 .51006 .66187 .51955 Mtetra
.271 0 .064 r
.66187 .51955 .66701 .51006 .67896 .50417 .67395 .51449 Mtetra
.254 0 .085 r
.67395 .51449 .67896 .50417 .69089 .49711 .68603 .50842 Mtetra
.187 0 .086 r
.68603 .50842 .69089 .49711 .70274 .48822 .69802 .50001 Mtetra
.074 0 .054 r
.69802 .50001 .70274 .48822 .71449 .47737 .70987 .48867 Mtetra
0 0 0 r
.70987 .48867 .71449 .47737 .72616 .46506 .72155 .47473 Mtetra
.72155 .47473 .72616 .46506 .73777 .45219 .73312 .4593 Mtetra
.73312 .4593 .73777 .45219 .74941 .43979 .74466 .44385 Mtetra
.7 .923 .593 r
.74466 .44385 .74941 .43979 .76112 .42865 .75624 .42966 Mtetra
.819 .999 .795 r
.75624 .42966 .76112 .42865 .77296 .41918 .76796 .41751 Mtetra
.827 .966 .895 r
.76796 .41751 .77296 .41918 .78494 .41137 .77984 .40761 Mtetra
.783 .894 .922 r
.77984 .40761 .78494 .41137 .79706 .40496 .7919 .39973 Mtetra
.738 .832 .923 r
.7919 .39973 .79706 .40496 .8093 .39958 .80411 .3934 Mtetra
.705 .79 .918 r
.80411 .3934 .8093 .39958 .82166 .39488 .81646 .38813 Mtetra
.684 .766 .913 r
.81646 .38813 .82166 .39488 .83409 .39056 .82891 .3835 Mtetra
.673 .752 .91 r
.82891 .3835 .83409 .39056 .8466 .38643 .84145 .37921 Mtetra
.668 .746 .909 r
.84145 .37921 .8466 .38643 .85918 .3824 .85406 .37509 Mtetra
.665 .743 .908 r
.85406 .37509 .85918 .3824 .87181 .3784 .86673 .37103 Mtetra
.664 .742 .908 r
.86673 .37103 .87181 .3784 .8845 .37439 .87945 .36698 Mtetra
.87945 .36698 .8845 .37439 .89724 .37038 .89224 .36293 Mtetra
.664 .741 .908 r
.89224 .36293 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.663 .741 .908 r
.32893 .53279 .33554 .53893 .34605 .53561 .33947 .52946 Mtetra
.662 .741 .909 r
.33947 .52946 .34605 .53561 .35661 .5323 .35006 .52614 Mtetra
.66 .742 .91 r
.35006 .52614 .35661 .5323 .36721 .529 .36068 .52286 Mtetra
.656 .742 .913 r
.36068 .52286 .36721 .529 .37785 .52576 .37134 .51967 Mtetra
.648 .743 .918 r
.37134 .51967 .37785 .52576 .38853 .52263 .38204 .51669 Mtetra
.632 .744 .928 r
.38204 .51669 .38853 .52263 .39924 .51972 .39277 .51407 Mtetra
.601 .745 .946 r
.39277 .51407 .39924 .51972 .40999 .5172 .40352 .51208 Mtetra
.537 .744 .971 r
.40352 .51208 .40999 .5172 .42076 .51529 .41429 .51105 Mtetra
.393 .719 .988 r
.41429 .51105 .42076 .51529 .43156 .51426 .42508 .51138 Mtetra
.067 .579 .882 r
.42508 .51138 .43156 .51426 .4424 .51438 .4359 .51343 Mtetra
.382 0 0 r
.4359 .51343 .4424 .51438 .45327 .51584 .44675 .51743 Mtetra
.613 .08 0 r
.44675 .51743 .45327 .51584 .46419 .51875 .45765 .52344 Mtetra
.678 .225 .168 r
.45765 .52344 .46419 .51875 .47518 .52311 .46863 .53132 Mtetra
.691 .29 .282 r
.46863 .53132 .47518 .52311 .48625 .52881 .47971 .54077 Mtetra
.687 .32 .345 r
.47971 .54077 .48625 .52881 .49742 .53568 .49091 .55139 Mtetra
.678 .333 .382 r
.49091 .55139 .49742 .53568 .5087 .54348 .50225 .56267 Mtetra
.665 .335 .404 r
.50225 .56267 .5087 .54348 .5201 .55178 .51374 .57396 Mtetra
.648 .328 .416 r
.51374 .57396 .5201 .55178 .53163 .55994 .52537 .58435 Mtetra
.625 .312 .42 r
.52537 .58435 .53163 .55994 .54328 .56709 .53715 .59271 Mtetra
.591 .283 .415 r
.53715 .59271 .54328 .56709 .55504 .57221 .54904 .59778 Mtetra
.543 .237 .399 r
.54904 .59778 .55504 .57221 .56687 .57434 .56099 .59854 Mtetra
.473 .168 .367 r
.56099 .59854 .56687 .57434 .57873 .5729 .57295 .59451 Mtetra
.371 .065 .311 r
.57295 .59451 .57873 .5729 .59059 .5679 .58488 .58598 Mtetra
.226 0 .216 r
.58488 .58598 .59059 .5679 .60242 .56002 .59677 .57415 Mtetra
.04 0 .069 r
.59677 .57415 .60242 .56002 .61424 .55047 .6086 .56082 Mtetra
0 0 0 r
.6086 .56082 .61424 .55047 .62605 .54072 .62044 .54806 Mtetra
.62044 .54806 .62605 .54072 .63791 .53203 .63234 .53763 Mtetra
.63234 .53763 .63791 .53203 .64984 .52505 .64435 .53042 Mtetra
.104 0 0 r
.64435 .53042 .64984 .52505 .66187 .51955 .65651 .52614 Mtetra
.275 0 0 r
.65651 .52614 .66187 .51955 .67395 .51449 .66878 .52335 Mtetra
.32 0 .061 r
.66878 .52335 .67395 .51449 .68603 .50842 .68107 .51985 Mtetra
.273 0 .121 r
.68107 .51985 .68603 .50842 .69802 .50001 .69328 .51347 Mtetra
.169 0 .129 r
.69328 .51347 .69802 .50001 .70987 .48867 .7053 .50287 Mtetra
.028 0 .091 r
.7053 .50287 .70987 .48867 .72155 .47473 .71707 .48804 Mtetra
0 0 .005 r
.71707 .48804 .72155 .47473 .73312 .4593 .72863 .47026 Mtetra
0 0 0 r
.72863 .47026 .73312 .4593 .74466 .44385 .74007 .45146 Mtetra
.74007 .45146 .74466 .44385 .75624 .42966 .75151 .43361 Mtetra
.757 .94 .603 r
.75151 .43361 .75624 .42966 .76796 .41751 .76307 .41804 Mtetra
.849 .998 .805 r
.76307 .41804 .76796 .41751 .77984 .40761 .77482 .40536 Mtetra
.831 .95 .897 r
.77482 .40536 .77984 .40761 .7919 .39973 .78677 .39543 Mtetra
.776 .876 .92 r
.78677 .39543 .7919 .39973 .80411 .3934 .79893 .38774 Mtetra
.729 .817 .92 r
.79893 .38774 .80411 .3934 .81646 .38813 .81125 .38164 Mtetra
.698 .78 .915 r
.81125 .38164 .81646 .38813 .82891 .3835 .8237 .37654 Mtetra
.68 .76 .912 r
.8237 .37654 .82891 .3835 .84145 .37921 .83626 .372 Mtetra
.671 .749 .91 r
.83626 .372 .84145 .37921 .85406 .37509 .8489 .36774 Mtetra
.666 .745 .909 r
.8489 .36774 .85406 .37509 .86673 .37103 .8616 .36361 Mtetra
.665 .743 .908 r
.8616 .36361 .86673 .37103 .87945 .36698 .87437 .35952 Mtetra
.664 .742 .908 r
.87437 .35952 .87945 .36698 .89224 .36293 .88719 .35543 Mtetra
.664 .741 .908 r
.88719 .35543 .89224 .36293 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.662 .741 .909 r
.32228 .5266 .32893 .53279 .33947 .52946 .33285 .52326 Mtetra
.661 .741 .91 r
.33285 .52326 .33947 .52946 .35006 .52614 .34345 .51994 Mtetra
.658 .742 .912 r
.34345 .51994 .35006 .52614 .36068 .52286 .3541 .5167 Mtetra
.652 .742 .916 r
.3541 .5167 .36068 .52286 .37134 .51967 .36478 .51361 Mtetra
.639 .742 .924 r
.36478 .51361 .37134 .51967 .38204 .51669 .37549 .51084 Mtetra
.613 .743 .938 r
.37549 .51084 .38204 .51669 .39277 .51407 .38623 .50862 Mtetra
.558 .74 .961 r
.38623 .50862 .39277 .51407 .40352 .51208 .39698 .50734 Mtetra
.435 .719 .985 r
.39698 .50734 .40352 .51208 .41429 .51105 .40774 .50747 Mtetra
.138 .603 .924 r
.40774 .50747 .41429 .51105 .42508 .51138 .41851 .50953 Mtetra
.353 0 0 r
.41851 .50953 .42508 .51138 .4359 .51343 .42928 .51396 Mtetra
.638 .097 0 r
.42928 .51396 .4359 .51343 .44675 .51743 .44009 .52098 Mtetra
.715 .257 .162 r
.44009 .52098 .44675 .51743 .45765 .52344 .45096 .5305 Mtetra
.727 .322 .282 r
.45096 .5305 .45765 .52344 .46863 .53132 .46192 .54211 Mtetra
.72 .349 .346 r
.46192 .54211 .46863 .53132 .47971 .54077 .47301 .55517 Mtetra
.707 .357 .381 r
.47301 .55517 .47971 .54077 .49091 .55139 .48424 .56895 Mtetra
.692 .356 .401 r
.48424 .56895 .49091 .55139 .50225 .56267 .49565 .58268 Mtetra
.675 .346 .41 r
.49565 .58268 .50225 .56267 .51374 .57396 .50722 .59548 Mtetra
.653 .328 .411 r
.50722 .59548 .51374 .57396 .52537 .58435 .51896 .60629 Mtetra
.62 .297 .401 r
.51896 .60629 .52537 .58435 .53715 .59271 .53084 .61388 Mtetra
.569 .243 .376 r
.53084 .61388 .53715 .59271 .54904 .59778 .54283 .61701 Mtetra
.479 .147 .325 r
.54283 .61701 .54904 .59778 .56099 .59854 .55487 .61476 Mtetra
.308 0 .217 r
.55487 .61476 .56099 .59854 .57295 .59451 .56691 .60693 Mtetra
0 0 0 r
.56691 .60693 .57295 .59451 .58488 .58598 .57889 .59424 Mtetra
.57889 .59424 .58488 .58598 .59677 .57415 .59079 .57838 Mtetra
.853 .979 .68 r
.59079 .57838 .59677 .57415 .6086 .56082 .60265 .5617 Mtetra
.906 .977 .796 r
.60265 .5617 .6086 .56082 .62044 .54806 .6145 .54675 Mtetra
.855 .953 .876 r
.6145 .54675 .62044 .54806 .63234 .53763 .62645 .53565 Mtetra
.707 .933 .963 r
.62645 .53565 .63234 .53763 .64435 .53042 .63856 .52947 Mtetra
.285 .776 .9 r
.63856 .52947 .64435 .53042 .65651 .52614 .65087 .52788 Mtetra
.27 0 0 r
.65087 .52788 .65651 .52614 .66878 .52335 .66337 .52899 Mtetra
.426 0 0 r
.66337 .52899 .66878 .52335 .68107 .51985 .67595 .52986 Mtetra
.382 0 .124 r
.67595 .52986 .68107 .51985 .69328 .51347 .68845 .5273 Mtetra
.264 0 .169 r
.68845 .5273 .69328 .51347 .7053 .50287 .70072 .51905 Mtetra
.111 0 .155 r
.70072 .51905 .7053 .50287 .71707 .48804 .71265 .5045 Mtetra
0 0 .095 r
.71265 .5045 .71707 .48804 .72863 .47026 .72425 .48493 Mtetra
0 0 0 r
.72425 .48493 .72863 .47026 .74007 .45146 .73563 .46279 Mtetra
.73563 .46279 .74007 .45146 .75151 .43361 .74693 .44082 Mtetra
.662 .826 .399 r
.74693 .44082 .75151 .43361 .76307 .41804 .75831 .42117 Mtetra
.824 .968 .652 r
.75831 .42117 .76307 .41804 .77482 .40536 .76988 .40495 Mtetra
.868 .989 .83 r
.76988 .40495 .77482 .40536 .78677 .39543 .78169 .39233 Mtetra
.823 .925 .902 r
.78169 .39233 .78677 .39543 .79893 .38774 .79376 .38278 Mtetra
.762 .852 .918 r
.79376 .38278 .79893 .38774 .81125 .38164 .80603 .37552 Mtetra
.717 .801 .916 r
.80603 .37552 .81125 .38164 .8237 .37654 .81847 .36974 Mtetra
.69 .77 .913 r
.81847 .36974 .8237 .37654 .83626 .372 .83104 .36483 Mtetra
.676 .754 .91 r
.83104 .36483 .83626 .372 .8489 .36774 .8437 .36039 Mtetra
.669 .747 .909 r
.8437 .36039 .8489 .36774 .8616 .36361 .85644 .35615 Mtetra
.665 .743 .908 r
.85644 .35615 .8616 .36361 .87437 .35952 .86924 .35199 Mtetra
.664 .742 .908 r
.86924 .35199 .87437 .35952 .88719 .35543 .88211 .34786 Mtetra
.88211 .34786 .88719 .35543 .90008 .35133 .89503 .34373 Mtetra
.664 .741 .908 r
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.662 .741 .909 r
.31558 .52038 .32228 .5266 .33285 .52326 .32617 .51703 Mtetra
.66 .741 .91 r
.32617 .51703 .33285 .52326 .34345 .51994 .3368 .51372 Mtetra
.655 .741 .913 r
.3368 .51372 .34345 .51994 .3541 .5167 .34747 .51053 Mtetra
.646 .741 .919 r
.34747 .51053 .3541 .5167 .36478 .51361 .35817 .50757 Mtetra
.627 .741 .93 r
.35817 .50757 .36478 .51361 .37549 .51084 .36889 .50506 Mtetra
.586 .738 .948 r
.36889 .50506 .37549 .51084 .38623 .50862 .37963 .50335 Mtetra
.497 .725 .974 r
.37963 .50335 .38623 .50862 .39698 .50734 .39038 .50292 Mtetra
.278 .656 .969 r
.39038 .50292 .39698 .50734 .40774 .50747 .40111 .50442 Mtetra
0 .377 .727 r
.40111 .50442 .40774 .50747 .41851 .50953 .41183 .50846 Mtetra
.603 .034 0 r
.41183 .50846 .41851 .50953 .42928 .51396 .42256 .51553 Mtetra
.734 .252 .098 r
.42256 .51553 .42928 .51396 .44009 .52098 .43331 .52573 Mtetra
.759 .338 .25 r
.43331 .52573 .44009 .52098 .45096 .5305 .44414 .5387 Mtetra
.754 .369 .325 r
.44414 .5387 .45096 .5305 .46192 .54211 .45508 .55358 Mtetra
.74 .377 .364 r
.45508 .55358 .46192 .54211 .47301 .55517 .46618 .56929 Mtetra
.722 .371 .383 r
.46618 .56929 .47301 .55517 .48424 .56895 .47746 .58471 Mtetra
.702 .356 .387 r
.47746 .58471 .48424 .56895 .49565 .58268 .48893 .59881 Mtetra
.68 .332 .378 r
.48893 .59881 .49565 .58268 .50722 .59548 .50059 .61069 Mtetra
.648 .291 .352 r
.50059 .61069 .50722 .59548 .51896 .60629 .51242 .61939 Mtetra
.588 .211 .294 r
.51242 .61939 .51896 .60629 .53084 .61388 .52439 .62388 Mtetra
.442 .024 .149 r
.52439 .62388 .53084 .61388 .54283 .61701 .53644 .6232 Mtetra
0 0 0 r
.53644 .6232 .54283 .61701 .55487 .61476 .54853 .61678 Mtetra
.816 1 .812 r
.54853 .61678 .55487 .61476 .56691 .60693 .56059 .60479 Mtetra
.914 .89 .793 r
.56059 .60479 .56691 .60693 .57889 .59424 .57259 .58836 Mtetra
.89 .797 .752 r
.57259 .58836 .57889 .59424 .59079 .57838 .5845 .56953 Mtetra
.857 .744 .738 r
.5845 .56953 .59079 .57838 .60265 .5617 .59637 .55096 Mtetra
.817 .71 .747 r
.59637 .55096 .60265 .5617 .6145 .54675 .60825 .53539 Mtetra
.759 .684 .779 r
.60825 .53539 .6145 .54675 .62645 .53565 .62025 .52514 Mtetra
.652 .657 .841 r
.62025 .52514 .62645 .53565 .63856 .52947 .63247 .52141 Mtetra
.4 .596 .924 r
.63247 .52141 .63856 .52947 .65087 .52788 .64496 .52382 Mtetra
0 .324 .738 r
.64496 .52382 .65087 .52788 .66337 .52899 .65771 .53021 Mtetra
.572 .008 0 r
.65771 .53021 .66337 .52899 .67595 .52986 .6706 .53698 Mtetra
.525 .061 .094 r
.6706 .53698 .67595 .52986 .68845 .5273 .68345 .53994 Mtetra
.37 0 .181 r
.68345 .53994 .68845 .5273 .70072 .51905 .69605 .53573 Mtetra
.181 0 .185 r
.69605 .53573 .70072 .51905 .71265 .5045 .70822 .52293 Mtetra
0 0 .138 r
.70822 .52293 .71265 .5045 .72425 .48493 .71994 .50254 Mtetra
0 0 .052 r
.71994 .50254 .72425 .48493 .73563 .46279 .7313 .47745 Mtetra
0 0 0 r
.7313 .47745 .73563 .46279 .74693 .44082 .74247 .45124 Mtetra
.74247 .45124 .74693 .44082 .75831 .42117 .75366 .427 Mtetra
.777 .897 .492 r
.75366 .427 .75831 .42117 .76988 .40495 .76503 .40661 Mtetra
.879 .987 .722 r
.76503 .40661 .76988 .40495 .78169 .39233 .77668 .39065 Mtetra
.868 .965 .859 r
.77668 .39065 .78169 .39233 .79376 .38278 .78861 .3787 Mtetra
.804 .892 .907 r
.78861 .3787 .79376 .38278 .80603 .37552 .80081 .36987 Mtetra
.744 .827 .915 r
.80081 .36987 .80603 .37552 .81847 .36974 .81322 .36317 Mtetra
.705 .785 .914 r
.81322 .36317 .81847 .36974 .83104 .36483 .82579 .35775 Mtetra
.683 .762 .911 r
.82579 .35775 .83104 .36483 .8437 .36039 .83847 .35303 Mtetra
.672 .75 .909 r
.83847 .35303 .8437 .36039 .85644 .35615 .85124 .34865 Mtetra
.667 .745 .909 r
.85124 .34865 .85644 .35615 .86924 .35199 .86408 .34442 Mtetra
.665 .743 .908 r
.86408 .34442 .86924 .35199 .88211 .34786 .87698 .34024 Mtetra
.664 .742 .908 r
.87698 .34024 .88211 .34786 .89503 .34373 .88994 .33607 Mtetra
.664 .741 .908 r
.88994 .33607 .89503 .34373 .90801 .33958 .90297 .33189 Mtetra
.661 .741 .909 r
.30882 .51411 .31558 .52038 .32617 .51703 .31944 .51075 Mtetra
.658 .741 .911 r
.31944 .51075 .32617 .51703 .3368 .51372 .33009 .50747 Mtetra
.652 .741 .915 r
.33009 .50747 .3368 .51372 .34747 .51053 .34078 .50434 Mtetra
.639 .74 .922 r
.34078 .50434 .34747 .51053 .35817 .50757 .3515 .50153 Mtetra
.612 .738 .935 r
.3515 .50153 .35817 .50757 .36889 .50506 .36224 .49931 Mtetra
.554 .73 .957 r
.36224 .49931 .36889 .50506 .37963 .50335 .37298 .49815 Mtetra
.419 .696 .978 r
.37298 .49815 .37963 .50335 .39038 .50292 .3837 .49866 Mtetra
.085 .546 .905 r
.3837 .49866 .39038 .50292 .40111 .50442 .3944 .5016 Mtetra
.441 0 0 r
.3944 .5016 .40111 .50442 .41183 .50846 .40508 .5077 Mtetra
.714 .189 0 r
.40508 .5077 .41183 .50846 .42256 .51553 .41574 .5174 Mtetra
.78 .329 .176 r
.41574 .5174 .42256 .51553 .43331 .52573 .42644 .53057 Mtetra
.787 .38 .281 r
.42644 .53057 .43331 .52573 .44414 .5387 .43722 .5464 Mtetra
.775 .393 .331 r
.43722 .5464 .44414 .5387 .45508 .55358 .44815 .56349 Mtetra
.757 .385 .35 r
.44815 .56349 .45508 .55358 .46618 .56929 .45928 .58018 Mtetra
.734 .362 .347 r
.45928 .58018 .46618 .56929 .47746 .58471 .47063 .59498 Mtetra
.706 .321 .317 r
.47063 .59498 .47746 .58471 .48893 .59881 .48218 .6068 Mtetra
.663 .243 .237 r
.48218 .6068 .48893 .59881 .50059 .61069 .49393 .61499 Mtetra
.544 .039 .004 r
.49393 .61499 .50059 .61069 .51242 .61939 .50583 .61904 Mtetra
.107 .66 .791 r
.50583 .61904 .51242 .61939 .52439 .62388 .51784 .61848 Mtetra
.716 .809 .923 r
.51784 .61848 .52439 .62388 .53644 .6232 .52993 .61288 Mtetra
.773 .703 .786 r
.52993 .61288 .53644 .6232 .54853 .61678 .54202 .60214 Mtetra
.78 .654 .724 r
.54202 .60214 .54853 .61678 .56059 .60479 .55408 .58676 Mtetra
.779 .629 .694 r
.55408 .58676 .56059 .60479 .57259 .58836 .56606 .56809 Mtetra
.773 .614 .682 r
.56606 .56809 .57259 .58836 .5845 .56953 .57798 .5482 Mtetra
.759 .601 .682 r
.57798 .5482 .5845 .56953 .59637 .55096 .58985 .52973 Mtetra
.731 .585 .693 r
.58985 .52973 .59637 .55096 .60825 .53539 .60177 .51537 Mtetra
.678 .562 .718 r
.60177 .51537 .60825 .53539 .62025 .52514 .61383 .50741 Mtetra
.571 .519 .758 r
.61383 .50741 .62025 .52514 .63247 .52141 .62615 .50713 Mtetra
.337 .422 .802 r
.62615 .50713 .63247 .52141 .64496 .52382 .6388 .51423 Mtetra
0 .184 .716 r
.6388 .51423 .64496 .52382 .65771 .53021 .65178 .52651 Mtetra
.648 .111 0 r
.65178 .52651 .65771 .53021 .6706 .53698 .66498 .53995 Mtetra
.676 .166 .023 r
.66498 .53995 .6706 .53698 .68345 .53994 .6782 .54957 Mtetra
.495 .066 .155 r
.6782 .54957 .68345 .53994 .69605 .53573 .69117 .55087 Mtetra
.247 0 .177 r
.69117 .55087 .69605 .53573 .70822 .52293 .70367 .54136 Mtetra
0 0 .137 r
.70367 .54136 .70822 .52293 .71994 .50254 .71558 .5215 Mtetra
0 0 .059 r
.71558 .5215 .71994 .50254 .7313 .47745 .72699 .49434 Mtetra
0 0 0 r
.72699 .49434 .7313 .47745 .74247 .45124 .73808 .46422 Mtetra
.73808 .46422 .74247 .45124 .75366 .427 .7491 .43527 Mtetra
.752 .838 .383 r
.7491 .43527 .75366 .427 .76503 .40661 .76026 .41028 Mtetra
.874 .954 .607 r
.76026 .41028 .76503 .40661 .77668 .39065 .77171 .39044 Mtetra
.902 .982 .79 r
.77171 .39044 .77668 .39065 .78861 .3787 .7835 .3756 Mtetra
.848 .928 .882 r
.7835 .3756 .78861 .3787 .80081 .36987 .7956 .36481 Mtetra
.777 .856 .91 r
.7956 .36481 .80081 .36987 .81322 .36317 .80796 .35689 Mtetra
.724 .803 .913 r
.80796 .35689 .81322 .36317 .82579 .35775 .82051 .35079 Mtetra
.693 .771 .912 r
.82051 .35079 .82579 .35775 .83847 .35303 .8332 .3457 Mtetra
.676 .755 .91 r
.8332 .3457 .83847 .35303 .85124 .34865 .84599 .34114 Mtetra
.669 .747 .909 r
.84599 .34114 .85124 .34865 .86408 .34442 .85887 .33681 Mtetra
.666 .743 .908 r
.85887 .33681 .86408 .34442 .87698 .34024 .87181 .33256 Mtetra
.664 .742 .908 r
.87181 .33256 .87698 .34024 .88994 .33607 .88482 .32835 Mtetra
.88482 .32835 .88994 .33607 .90297 .33189 .89788 .32412 Mtetra
.66 .741 .91 r
.30202 .50779 .30882 .51411 .31944 .51075 .31266 .50444 Mtetra
.657 .741 .912 r
.31266 .50444 .31944 .51075 .33009 .50747 .32334 .50117 Mtetra
.649 .74 .916 r
.32334 .50117 .33009 .50747 .34078 .50434 .33405 .4981 Mtetra
.632 .738 .924 r
.33405 .4981 .34078 .50434 .3515 .50153 .34478 .49543 Mtetra
.598 .733 .939 r
.34478 .49543 .3515 .50153 .36224 .49931 .35553 .49351 Mtetra
.521 .717 .962 r
.35553 .49351 .36224 .49931 .37298 .49815 .36627 .49289 Mtetra
.335 .655 .97 r
.36627 .49289 .37298 .49815 .3837 .49866 .37697 .49431 Mtetra
0 .417 .813 r
.37697 .49431 .3837 .49866 .3944 .5016 .38764 .49867 Mtetra
.584 .013 0 r
.38764 .49867 .3944 .5016 .40508 .5077 .39825 .50672 Mtetra
.77 .273 .03 r
.39825 .50672 .40508 .5077 .41574 .5174 .40886 .5188 Mtetra
.81 .372 .202 r
.40886 .5188 .41574 .5174 .42644 .53057 .41949 .53443 Mtetra
.81 .403 .279 r
.41949 .53443 .42644 .53057 .43722 .5464 .43025 .55224 Mtetra
.794 .4 .308 r
.43025 .55224 .43722 .5464 .44815 .56349 .44119 .57013 Mtetra
.77 .371 .298 r
.44119 .57013 .44815 .56349 .45928 .58018 .45237 .58585 Mtetra
.732 .304 .234 r
.45237 .58585 .45928 .58018 .47063 .59498 .46381 .59768 Mtetra
.637 .127 .017 r
.46381 .59768 .47063 .59498 .48218 .6068 .47547 .60472 Mtetra
0 .524 .794 r
.47547 .60472 .48218 .6068 .49393 .61499 .4873 .60692 Mtetra
.614 .697 .904 r
.4873 .60692 .49393 .61499 .50583 .61904 .49927 .60459 Mtetra
.686 .614 .769 r
.49927 .60459 .50583 .61904 .51784 .61848 .5113 .59806 Mtetra
.702 .574 .709 r
.5113 .59806 .51784 .61848 .52993 .61288 .52338 .58757 Mtetra
.71 .557 .678 r
.52338 .58757 .52993 .61288 .54202 .60214 .53544 .57341 Mtetra
.716 .549 .662 r
.53544 .57341 .54202 .60214 .55408 .58676 .54747 .55625 Mtetra
.72 .547 .655 r
.54747 .55625 .55408 .58676 .56606 .56809 .55943 .53731 Mtetra
.719 .545 .654 r
.55943 .53731 .56606 .56809 .57798 .5482 .57133 .51845 Mtetra
.709 .541 .659 r
.57133 .51845 .57798 .5482 .58985 .52973 .58322 .50193 Mtetra
.683 .53 .672 r
.58322 .50193 .58985 .52973 .60177 .51537 .59517 .49017 Mtetra
.627 .505 .695 r
.59517 .49017 .60177 .51537 .61383 .50741 .60729 .48531 Mtetra
.509 .449 .724 r
.60729 .48531 .61383 .50741 .62615 .50713 .61968 .48868 Mtetra
.263 .323 .737 r
.61968 .48868 .62615 .50713 .6388 .51423 .63245 .50023 Mtetra
0 .081 .64 r
.63245 .50023 .6388 .51423 .65178 .52651 .64561 .51795 Mtetra
.618 .174 0 r
.64561 .51795 .65178 .52651 .66498 .53995 .65908 .53782 Mtetra
.762 .249 0 r
.65908 .53782 .66498 .53995 .6782 .54957 .67264 .55434 Mtetra
.632 .139 .061 r
.67264 .55434 .6782 .54957 .69117 .55087 .68599 .56203 Mtetra
.313 0 .109 r
.68599 .56203 .69117 .55087 .70367 .54136 .69884 .55721 Mtetra
0 0 .075 r
.69884 .55721 .70367 .54136 .71558 .5215 .71103 .53944 Mtetra
0 0 .004 r
.71103 .53944 .71558 .5215 .72699 .49434 .72257 .51156 Mtetra
0 0 0 r
.72257 .51156 .72699 .49434 .73808 .46422 .73365 .47844 Mtetra
.73365 .47844 .73808 .46422 .7491 .43527 .74455 .44517 Mtetra
.77 .816 .341 r
.74455 .44517 .7491 .43527 .76026 .41028 .75553 .41556 Mtetra
.876 .92 .525 r
.75553 .41556 .76026 .41028 .77171 .39044 .76679 .39158 Mtetra
.923 .975 .714 r
.76679 .39158 .77171 .39044 .7835 .3756 .77841 .37346 Mtetra
.888 .951 .842 r
.77841 .37346 .7835 .3756 .7956 .36481 .79039 .36036 Mtetra
.813 .884 .896 r
.79039 .36036 .7956 .36481 .80796 .35689 .80268 .35097 Mtetra
.748 .823 .91 r
.80268 .35097 .80796 .35689 .82051 .35079 .8152 .34399 Mtetra
.706 .783 .911 r
.8152 .34399 .82051 .35079 .8332 .3457 .8279 .33843 Mtetra
.683 .761 .91 r
.8279 .33843 .8332 .3457 .84599 .34114 .84072 .33361 Mtetra
.672 .75 .909 r
.84072 .33361 .84599 .34114 .85887 .33681 .85362 .32915 Mtetra
.667 .745 .908 r
.85362 .32915 .85887 .33681 .87181 .33256 .8666 .32483 Mtetra
.665 .743 .908 r
.8666 .32483 .87181 .33256 .88482 .32835 .87965 .32056 Mtetra
.664 .742 .908 r
.87965 .32056 .88482 .32835 .89788 .32412 .89275 .3163 Mtetra
.66 .741 .91 r
.29517 .50143 .30202 .50779 .31266 .50444 .30583 .49806 Mtetra
.655 .74 .912 r
.30583 .49806 .31266 .50444 .32334 .50117 .31653 .49481 Mtetra
.646 .739 .917 r
.31653 .49481 .32334 .50117 .33405 .4981 .32727 .49179 Mtetra
.626 .736 .926 r
.32727 .49179 .33405 .4981 .34478 .49543 .33802 .48924 Mtetra
.584 .727 .942 r
.33802 .48924 .34478 .49543 .35553 .49351 .34877 .48757 Mtetra
.49 .701 .963 r
.34877 .48757 .35553 .49351 .36627 .49289 .35951 .48744 Mtetra
.258 .608 .955 r
.35951 .48744 .36627 .49289 .37697 .49431 .37019 .4897 Mtetra
0 .301 .724 r
.37019 .4897 .37697 .49431 .38764 .49867 .38082 .49535 Mtetra
.663 .113 0 r
.38082 .49535 .38764 .49867 .39825 .50672 .39138 .50516 Mtetra
.804 .323 .064 r
.39138 .50516 .39825 .50672 .40886 .5188 .40192 .51928 Mtetra
.832 .398 .204 r
.40192 .51928 .40886 .5188 .41949 .53443 .41251 .5368 Mtetra
.828 .414 .259 r
.41251 .5368 .41949 .53443 .43025 .55224 .42324 .55567 Mtetra
.808 .392 .259 r
.42324 .55567 .43025 .55224 .44119 .57013 .43422 .57307 Mtetra
.765 .316 .183 r
.43422 .57307 .44119 .57013 .45237 .58585 .44549 .58621 Mtetra
.61 .054 0 r
.44549 .58621 .45237 .58585 .46381 .59768 .45704 .59329 Mtetra
.348 .707 .984 r
.45704 .59329 .46381 .59768 .47547 .60472 .46882 .5939 Mtetra
.679 .661 .825 r
.46882 .5939 .47547 .60472 .4873 .60692 .48076 .5889 Mtetra
.701 .589 .727 r
.48076 .5889 .4873 .60692 .49927 .60459 .49278 .57965 Mtetra
.697 .55 .683 r
.49278 .57965 .49927 .60459 .5113 .59806 .50483 .56741 Mtetra
.692 .529 .661 r
.50483 .56741 .5113 .59806 .52338 .58757 .51687 .55298 Mtetra
.691 .518 .649 r
.51687 .55298 .52338 .58757 .53544 .57341 .52889 .53687 Mtetra
.691 .515 .643 r
.52889 .53687 .53544 .57341 .54747 .55625 .54087 .51965 Mtetra
.692 .515 .643 r
.54087 .51965 .54747 .55625 .55943 .53731 .5528 .5022 Mtetra
.69 .516 .647 r
.5528 .5022 .55943 .53731 .57133 .51845 .56469 .48586 Mtetra
.68 .515 .655 r
.56469 .48586 .57133 .51845 .58322 .50193 .57659 .4724 Mtetra
.652 .505 .671 r
.57659 .4724 .58322 .50193 .59517 .49017 .58857 .4638 Mtetra
.589 .476 .692 r
.58857 .4638 .59517 .49017 .60729 .48531 .60072 .46199 Mtetra
.455 .406 .715 r
.60072 .46199 .60729 .48531 .61968 .48868 .61317 .46839 Mtetra
.19 .257 .703 r
.61317 .46839 .61968 .48868 .63245 .50023 .62599 .48323 Mtetra
0 .021 .589 r
.62599 .48323 .63245 .50023 .64561 .51795 .63926 .505 Mtetra
0 0 .397 r
.63926 .505 .64561 .51795 .65908 .53782 .6529 .53 Mtetra
.72 .266 0 r
.6529 .53 .65908 .53782 .67264 .55434 .66671 .55265 Mtetra
.715 .181 0 r
.66671 .55265 .67264 .55434 .68599 .56203 .6804 .56679 Mtetra
.381 0 0 r
.6804 .56679 .68599 .56203 .69884 .55721 .69363 .56761 Mtetra
0 0 0 r
.69363 .56761 .69884 .55721 .71103 .53944 .70615 .55349 Mtetra
.70615 .55349 .71103 .53944 .72257 .51156 .71791 .52661 Mtetra
.71791 .52661 .72257 .51156 .73365 .47844 .72908 .49197 Mtetra
.749 .767 .262 r
.72908 .49197 .73365 .47844 .74455 .44517 .73993 .45538 Mtetra
.83 .831 .358 r
.73993 .45538 .74455 .44517 .75553 .41556 .75078 .42165 Mtetra
.9 .902 .493 r
.75078 .42165 .75553 .41556 .76679 .39158 .76187 .39363 Mtetra
.94 .957 .654 r
.76187 .39363 .76679 .39158 .77841 .37346 .77333 .37213 Mtetra
.919 .957 .794 r
.77333 .37213 .77841 .37346 .79039 .36036 .78518 .3565 Mtetra
.849 .906 .874 r
.78518 .3565 .79039 .36036 .80268 .35097 .79739 .3454 Mtetra
.775 .843 .903 r
.79739 .3454 .80268 .35097 .8152 .34399 .80988 .33738 Mtetra
.722 .796 .91 r
.80988 .33738 .8152 .34399 .8279 .33843 .82257 .33122 Mtetra
.691 .768 .91 r
.82257 .33122 .8279 .33843 .84072 .33361 .8354 .32609 Mtetra
.676 .753 .909 r
.8354 .32609 .84072 .33361 .85362 .32915 .84833 .32146 Mtetra
.669 .746 .909 r
.84833 .32146 .85362 .32915 .8666 .32483 .86135 .31705 Mtetra
.665 .743 .908 r
.86135 .31705 .8666 .32483 .87965 .32056 .87444 .31272 Mtetra
.664 .742 .908 r
.87444 .31272 .87965 .32056 .89275 .3163 .88758 .30841 Mtetra
.659 .741 .91 r
.28826 .49501 .29517 .50143 .30583 .49806 .29895 .49163 Mtetra
.654 .74 .912 r
.29895 .49163 .30583 .49806 .31653 .49481 .30968 .48837 Mtetra
.644 .738 .917 r
.30968 .48837 .31653 .49481 .32727 .49179 .32043 .48537 Mtetra
.622 .733 .926 r
.32043 .48537 .32727 .49179 .33802 .48924 .3312 .48291 Mtetra
.574 .721 .942 r
.3312 .48291 .33802 .48924 .34877 .48757 .34197 .48145 Mtetra
.463 .685 .962 r
.34197 .48145 .34877 .48757 .35951 .48744 .3527 .48173 Mtetra
.191 .561 .935 r
.3527 .48173 .35951 .48744 .37019 .4897 .36337 .48474 Mtetra
0 .206 .648 r
.36337 .48474 .37019 .4897 .38082 .49535 .37395 .49156 Mtetra
.713 .182 0 r
.37395 .49156 .38082 .49535 .39138 .50516 .38446 .50296 Mtetra
.827 .358 .084 r
.38446 .50296 .39138 .50516 .40192 .51928 .39493 .51885 Mtetra
.848 .417 .2 r
.39493 .51885 .40192 .51928 .41251 .5368 .40547 .53787 Mtetra
.84 .418 .234 r
.40547 .53787 .41251 .5368 .42324 .55567 .4162 .55722 Mtetra
.809 .367 .195 r
.4162 .55722 .42324 .55567 .43422 .57307 .42723 .57335 Mtetra
.701 .179 0 r
.42723 .57335 .43422 .57307 .44549 .58621 .43861 .58302 Mtetra
.154 .636 .923 r
.43861 .58302 .44549 .58621 .45704 .59329 .4503 .58451 Mtetra
.718 .715 .847 r
.4503 .58451 .45704 .59329 .46882 .5939 .46223 .57818 Mtetra
.745 .629 .73 r
.46223 .57818 .46882 .5939 .48076 .5889 .47428 .56594 Mtetra
.731 .578 .683 r
.47428 .56594 .48076 .5889 .49278 .57965 .48636 .5503 Mtetra
.713 .545 .66 r
.48636 .5503 .49278 .57965 .50483 .56741 .49841 .53332 Mtetra
.698 .524 .649 r
.49841 .53332 .50483 .56741 .51687 .55298 .51043 .51623 Mtetra
.688 .512 .643 r
.51043 .51623 .51687 .55298 .52889 .53687 .5224 .49956 Mtetra
.682 .507 .642 r
.5224 .49956 .52889 .53687 .54087 .51965 .53433 .48353 Mtetra
.679 .507 .645 r
.53433 .48353 .54087 .51965 .5528 .5022 .54623 .46855 Mtetra
.675 .508 .653 r
.54623 .46855 .5528 .5022 .56469 .48586 .55812 .45535 Mtetra
.662 .508 .665 r
.55812 .45535 .56469 .48586 .57659 .4724 .57003 .44512 Mtetra
.63 .498 .683 r
.57003 .44512 .57659 .4724 .58857 .4638 .58203 .43941 Mtetra
.557 .465 .706 r
.58203 .43941 .58857 .4638 .60072 .46199 .5942 .43991 Mtetra
.404 .382 .721 r
.5942 .43991 .60072 .46199 .61317 .46839 .60665 .44808 Mtetra
.129 .216 .687 r
.60665 .44808 .61317 .46839 .62599 .48323 .61948 .46453 Mtetra
0 0 .569 r
.61948 .46453 .62599 .48323 .63926 .505 .63275 .48834 Mtetra
0 0 .435 r
.63275 .48834 .63926 .505 .6529 .53 .64645 .51642 Mtetra
0 0 .369 r
.64645 .51642 .6529 .53 .66671 .55265 .66042 .54355 Mtetra
0 0 .417 r
.66042 .54355 .66671 .55265 .6804 .56679 .67436 .56333 Mtetra
0 .288 .678 r
.67436 .56333 .6804 .56679 .69363 .56761 .68792 .57004 Mtetra
.568 .922 .734 r
.68792 .57004 .69363 .56761 .70615 .55349 .70079 .56082 Mtetra
.809 .896 .481 r
.70079 .56082 .70615 .55349 .71791 .52661 .71285 .53678 Mtetra
.857 .851 .392 r
.71285 .53678 .71791 .52661 .72908 .49197 .7242 .50252 Mtetra
.883 .843 .382 r
.7242 .50252 .72908 .49197 .73993 .45538 .73512 .4642 Mtetra
.91 .862 .42 r
.73512 .4642 .73993 .45538 .75078 .42165 .74592 .42744 Mtetra
.939 .898 .502 r
.74592 .42744 .75078 .42165 .76187 .39363 .75689 .39596 Mtetra
.959 .938 .623 r
.75689 .39596 .76187 .39363 .77333 .37213 .76822 .37126 Mtetra
.942 .95 .752 r
.76822 .37126 .77333 .37213 .78518 .3565 .77996 .35307 Mtetra
.881 .918 .846 r
.77996 .35307 .78518 .3565 .79739 .3454 .79208 .34015 Mtetra
.803 .86 .892 r
.79208 .34015 .79739 .3454 .80988 .33738 .80452 .33095 Mtetra
.741 .81 .906 r
.80452 .33095 .80988 .33738 .82257 .33122 .8172 .3241 Mtetra
.702 .776 .909 r
.8172 .3241 .82257 .33122 .8354 .32609 .83004 .31858 Mtetra
.681 .757 .909 r
.83004 .31858 .8354 .32609 .84833 .32146 .84301 .31374 Mtetra
.671 .748 .909 r
.84301 .31374 .84833 .32146 .86135 .31705 .85606 .30921 Mtetra
.666 .744 .908 r
.85606 .30921 .86135 .31705 .87444 .31272 .86918 .30482 Mtetra
.665 .742 .908 r
.86918 .30482 .87444 .31272 .88758 .30841 .88237 .30046 Mtetra
.659 .74 .91 r
.28131 .48854 .28826 .49501 .29895 .49163 .29202 .48513 Mtetra
.654 .739 .912 r
.29202 .48513 .29895 .49163 .30968 .48837 .30277 .48185 Mtetra
.643 .736 .917 r
.30277 .48185 .30968 .48837 .32043 .48537 .31355 .47886 Mtetra
.619 .73 .926 r
.31355 .47886 .32043 .48537 .3312 .48291 .32434 .47644 Mtetra
.566 .715 .942 r
.32434 .47644 .3312 .48291 .34197 .48145 .33512 .47514 Mtetra
.44 .67 .96 r
.33512 .47514 .34197 .48145 .3527 .48173 .34585 .47578 Mtetra
.128 .515 .912 r
.34585 .47578 .3527 .48173 .36337 .48474 .3565 .47949 Mtetra
0 .118 .572 r
.3565 .47949 .36337 .48474 .37395 .49156 .36704 .48742 Mtetra
.755 .241 0 r
.36704 .48742 .37395 .49156 .38446 .50296 .37748 .50035 Mtetra
.846 .389 .11 r
.37748 .50035 .38446 .50296 .39493 .51885 .38788 .51797 Mtetra
.86 .433 .207 r
.38788 .51797 .39493 .51885 .40547 .53787 .39837 .53838 Mtetra
.845 .421 .224 r
.39837 .53838 .40547 .53787 .4162 .55722 .4091 .55809 Mtetra
.796 .336 .147 r
.4091 .55809 .4162 .55722 .42723 .57335 .42018 .57279 Mtetra
.535 0 0 r
.42018 .57279 .42723 .57335 .43861 .58302 .43168 .57889 Mtetra
.651 .839 .972 r
.43168 .57889 .43861 .58302 .4503 .58451 .44354 .57491 Mtetra
.802 .72 .775 r
.44354 .57491 .4503 .58451 .46223 .57818 .45563 .56202 Mtetra
.791 .646 .701 r
.45563 .56202 .46223 .57818 .47428 .56594 .4678 .5433 Mtetra
.766 .599 .671 r
.4678 .5433 .47428 .56594 .48636 .5503 .47996 .5223 Mtetra
.739 .565 .658 r
.47996 .5223 .48636 .5503 .49841 .53332 .49203 .50175 Mtetra
.715 .54 .652 r
.49203 .50175 .49841 .53332 .51043 .51623 .50403 .4831 Mtetra
.696 .524 .65 r
.50403 .4831 .51043 .51623 .5224 .49956 .51596 .46671 Mtetra
.684 .516 .653 r
.51596 .46671 .5224 .49956 .53433 .48353 .52786 .4524 Mtetra
.676 .515 .66 r
.52786 .4524 .53433 .48353 .54623 .46855 .53974 .44003 Mtetra
.668 .517 .671 r
.53974 .44003 .54623 .46855 .55812 .45535 .55163 .42976 Mtetra
.652 .518 .687 r
.55163 .42976 .55812 .45535 .57003 .44512 .56355 .42225 Mtetra
.615 .508 .709 r
.56355 .42225 .57003 .44512 .58203 .43941 .57556 .41862 Mtetra
.532 .471 .733 r
.57556 .41862 .58203 .43941 .5942 .43991 .58773 .42034 Mtetra
.364 .376 .739 r
.58773 .42034 .5942 .43991 .60665 .44808 .60015 .42886 Mtetra
.096 .204 .688 r
.60015 .42886 .60665 .44808 .61948 .46453 .61293 .44513 Mtetra
0 .012 .577 r
.61293 .44513 .61948 .46453 .63275 .48834 .62615 .46883 Mtetra
0 0 .483 r
.62615 .46883 .63275 .48834 .64645 .51642 .63981 .49767 Mtetra
0 0 .463 r
.63981 .49767 .64645 .51642 .66042 .54355 .6538 .52711 Mtetra
0 0 .548 r
.6538 .52711 .66042 .54355 .67436 .56333 .66788 .55097 Mtetra
.028 .271 .769 r
.66788 .55097 .67436 .56333 .68792 .57004 .68169 .56307 Mtetra
.64 .762 .936 r
.68169 .56307 .68792 .57004 .70079 .56082 .69489 .5594 Mtetra
.944 .924 .757 r
.69489 .5594 .70079 .56082 .71285 .53678 .7073 .5398 Mtetra
.983 .904 .592 r
.7073 .5398 .71285 .53678 .7242 .50252 .71893 .50796 Mtetra
.979 .882 .517 r
.71893 .50796 .7242 .50252 .73512 .4642 .73001 .46988 Mtetra
.975 .879 .503 r
.73001 .46988 .73512 .4642 .74592 .42744 .74086 .43165 Mtetra
.976 .894 .538 r
.74086 .43165 .74592 .42744 .75689 .39596 .7518 .39774 Mtetra
.977 .919 .617 r
.7518 .39774 .75689 .39596 .76822 .37126 .76304 .37039 Mtetra
.958 .935 .722 r
.76304 .37039 .76822 .37126 .77996 .35307 .77469 .34986 Mtetra
.905 .918 .818 r
.77469 .34986 .77996 .35307 .79208 .34015 .78674 .33513 Mtetra
.829 .872 .876 r
.78674 .33513 .79208 .34015 .80452 .33095 .79914 .32469 Mtetra
.76 .822 .9 r
.79914 .32469 .80452 .33095 .8172 .3241 .8118 .31706 Mtetra
.714 .785 .908 r
.8118 .31706 .8172 .3241 .83004 .31858 .82465 .31109 Mtetra
.687 .762 .909 r
.82465 .31109 .83004 .31858 .84301 .31374 .83764 .306 Mtetra
.674 .751 .909 r
.83764 .306 .84301 .31374 .85606 .30921 .85072 .30134 Mtetra
.668 .745 .908 r
.85072 .30134 .85606 .30921 .86918 .30482 .86388 .29686 Mtetra
.665 .743 .908 r
.86388 .29686 .86918 .30482 .88237 .30046 .87711 .29245 Mtetra
.659 .74 .91 r
.2743 .48201 .28131 .48854 .29202 .48513 .28504 .47857 Mtetra
.654 .739 .912 r
.28504 .47857 .29202 .48513 .30277 .48185 .29582 .47526 Mtetra
.643 .735 .916 r
.29582 .47526 .30277 .48185 .31355 .47886 .30662 .47224 Mtetra
.617 .728 .925 r
.30662 .47224 .31355 .47886 .32434 .47644 .31743 .46986 Mtetra
.558 .71 .942 r
.31743 .46986 .32434 .47644 .33512 .47514 .32822 .46869 Mtetra
.415 .655 .958 r
.32822 .46869 .33512 .47514 .34585 .47578 .33895 .46968 Mtetra
.055 .464 .884 r
.33895 .46968 .34585 .47578 .3565 .47949 .34957 .47408 Mtetra
.509 0 0 r
.34957 .47408 .3565 .47949 .36704 .48742 .36006 .48317 Mtetra
.794 .298 0 r
.36006 .48317 .36704 .48742 .37748 .50035 .37043 .4977 Mtetra
.862 .42 .147 r
.37043 .4977 .37748 .50035 .38788 .51797 .38075 .51716 Mtetra
.867 .45 .228 r
.38075 .51716 .38788 .51797 .39837 .53838 .39117 .53914 Mtetra
.846 .426 .235 r
.39117 .53914 .39837 .53838 .4091 .55809 .40188 .55943 Mtetra
.778 .313 .138 r
.40188 .55943 .4091 .55809 .42018 .57279 .41303 .57303 Mtetra
.345 0 0 r
.41303 .57303 .42018 .57279 .43168 .57889 .42465 .57602 Mtetra
.805 .896 .908 r
.42465 .57602 .43168 .57889 .44354 .57491 .43668 .56723 Mtetra
.863 .758 .745 r
.43668 .56723 .44354 .57491 .45563 .56202 .44895 .54869 Mtetra
.84 .686 .691 r
.44895 .54869 .45563 .56202 .4678 .5433 .46126 .52455 Mtetra
.809 .639 .671 r
.46126 .52455 .4678 .5433 .47996 .5223 .47351 .49927 Mtetra
.776 .602 .665 r
.47351 .49927 .47996 .5223 .49203 .50175 .48562 .47608 Mtetra
.744 .574 .664 r
.48562 .47608 .49203 .50175 .50403 .4831 .49762 .45652 Mtetra
.716 .554 .668 r
.49762 .45652 .50403 .4831 .51596 .46671 .50954 .4407 Mtetra
.696 .543 .676 r
.50954 .4407 .51596 .46671 .52786 .4524 .52142 .42801 Mtetra
.682 .541 .687 r
.52142 .42801 .52786 .4524 .53974 .44003 .5333 .4178 Mtetra
.669 .543 .703 r
.5333 .4178 .53974 .44003 .55163 .42976 .54519 .40977 Mtetra
.649 .545 .724 r
.54519 .40977 .55163 .42976 .56355 .42225 .55713 .40413 Mtetra
.606 .535 .749 r
.55713 .40413 .56355 .42225 .57556 .41862 .56915 .40165 Mtetra
.516 .494 .771 r
.56915 .40165 .57556 .41862 .58773 .42034 .58131 .40353 Mtetra
.345 .394 .769 r
.58131 .40353 .58773 .42034 .60015 .42886 .59369 .41119 Mtetra
.103 .227 .708 r
.59369 .41119 .60015 .42886 .61293 .44513 .60638 .4258 Mtetra
0 .058 .608 r
.60638 .4258 .61293 .44513 .62615 .46883 .61948 .44757 Mtetra
0 0 .536 r
.61948 .44757 .62615 .46883 .63981 .49767 .63302 .47502 Mtetra
0 0 .528 r
.63302 .47502 .63981 .49767 .6538 .52711 .64694 .50451 Mtetra
0 .041 .589 r
.64694 .50451 .6538 .52711 .66788 .55097 .66104 .53048 Mtetra
.151 .24 .702 r
.66104 .53048 .66788 .55097 .68169 .56307 .67499 .54676 Mtetra
.514 .514 .794 r
.67499 .54676 .68169 .56307 .69489 .5594 .68847 .54858 Mtetra
.81 .728 .774 r
.68847 .54858 .69489 .5594 .7073 .5398 .70122 .53446 Mtetra
.946 .82 .688 r
.70122 .53446 .7073 .5398 .71893 .50796 .71319 .50685 Mtetra
.988 .85 .614 r
.71319 .50685 .71893 .50796 .73001 .46988 .72454 .47105 Mtetra
.996 .862 .577 r
.72454 .47105 .73001 .46988 .74086 .43165 .73555 .43315 Mtetra
.993 .877 .581 r
.73555 .43315 .74086 .43165 .7518 .39774 .74654 .39816 Mtetra
.986 .898 .627 r
.74654 .39816 .7518 .39774 .76304 .37039 .75777 .36902 Mtetra
.966 .914 .706 r
.75777 .36902 .76304 .37039 .77469 .34986 .76937 .34658 Mtetra
.92 .91 .794 r
.76937 .34658 .77469 .34986 .78674 .33513 .78136 .3302 Mtetra
.85 .877 .859 r
.78136 .3302 .78674 .33513 .79914 .32469 .79372 .31853 Mtetra
.779 .831 .892 r
.79372 .31853 .79914 .32469 .8118 .31706 .80637 .31008 Mtetra
.727 .793 .904 r
.80637 .31008 .8118 .31706 .82465 .31109 .81922 .30361 Mtetra
.695 .767 .908 r
.81922 .30361 .82465 .31109 .83764 .306 .83223 .29823 Mtetra
.678 .753 .908 r
.83223 .29823 .83764 .306 .85072 .30134 .84534 .29341 Mtetra
.669 .746 .908 r
.84534 .29341 .85072 .30134 .86388 .29686 .85854 .28884 Mtetra
.666 .743 .908 r
.85854 .28884 .86388 .29686 .87711 .29245 .87181 .28437 Mtetra
.66 .74 .909 r
.26724 .47542 .2743 .48201 .28504 .47857 .27801 .47195 Mtetra
.655 .738 .911 r
.27801 .47195 .28504 .47857 .29582 .47526 .28881 .4686 Mtetra
.643 .735 .916 r
.28881 .4686 .29582 .47526 .30662 .47224 .29964 .46556 Mtetra
.615 .727 .925 r
.29964 .46556 .30662 .47224 .31743 .46986 .31047 .4632 Mtetra
.55 .706 .943 r
.31047 .4632 .31743 .46986 .32822 .46869 .32127 .46217 Mtetra
.385 .64 .957 r
.32127 .46217 .32822 .46869 .33895 .46968 .332 .46353 Mtetra
0 .404 .844 r
.332 .46353 .33895 .46968 .34957 .47408 .34259 .46866 Mtetra
.598 .064 0 r
.34259 .46866 .34957 .47408 .36006 .48317 .35302 .47897 Mtetra
.826 .349 .012 r
.35302 .47897 .36006 .48317 .37043 .4977 .3633 .49523 Mtetra
.874 .447 .187 r
.3633 .49523 .37043 .4977 .38075 .51716 .37352 .51671 Mtetra
.873 .467 .254 r
.37352 .51671 .38075 .51716 .39117 .53914 .38386 .54051 Mtetra
.847 .435 .256 r
.38386 .54051 .39117 .53914 .40188 .55943 .39454 .56172 Mtetra
.764 .304 .155 r
.39454 .56172 .40188 .55943 .41303 .57303 .40573 .57471 Mtetra
.214 0 0 r
.40573 .57471 .41303 .57303 .42465 .57602 .41748 .57527 Mtetra
.879 .938 .852 r
.41748 .57527 .42465 .57602 .43668 .56723 .42968 .56253 Mtetra
.912 .8 .723 r
.42968 .56253 .43668 .56723 .44895 .54869 .44213 .53934 Mtetra
.887 .731 .683 r
.44213 .53934 .44895 .54869 .46126 .52455 .45461 .51081 Mtetra
.856 .687 .672 r
.45461 .51081 .46126 .52455 .47351 .49927 .46697 .48215 Mtetra
.82 .652 .675 r
.46697 .48215 .47351 .49927 .48562 .47608 .47915 .45697 Mtetra
.783 .623 .683 r
.47915 .45697 .48562 .47608 .49762 .45652 .49118 .43677 Mtetra
.747 .601 .695 r
.49118 .43677 .49762 .45652 .50954 .4407 .5031 .42141 Mtetra
.717 .588 .71 r
.5031 .42141 .50954 .4407 .52142 .42801 .51499 .4099 Mtetra
.695 .584 .727 r
.51499 .4099 .52142 .42801 .5333 .4178 .52687 .40119 Mtetra
.675 .586 .748 r
.52687 .40119 .5333 .4178 .54519 .40977 .53877 .3946 Mtetra
.65 .588 .772 r
.53877 .3946 .54519 .40977 .55713 .40413 .55073 .39001 Mtetra
.605 .578 .797 r
.55073 .39001 .55713 .40413 .56915 .40165 .56276 .38787 Mtetra
.515 .535 .815 r
.56276 .38787 .56915 .40165 .58131 .40353 .57491 .38916 Mtetra
.358 .436 .805 r
.57491 .38916 .58131 .40353 .59369 .41119 .58724 .39518 Mtetra
.151 .281 .744 r
.58724 .39518 .59369 .41119 .60638 .4258 .59985 .40719 Mtetra
0 .129 .653 r
.59985 .40719 .60638 .4258 .61948 .44757 .61281 .42579 Mtetra
0 .039 .588 r
.61281 .42579 .61948 .44757 .63302 .47502 .62618 .45024 Mtetra
0 .029 .573 r
.62618 .45024 .63302 .47502 .64694 .50451 .63994 .47786 Mtetra
.009 .094 .605 r
.63994 .47786 .64694 .50451 .66104 .53048 .65395 .50398 Mtetra
.202 .229 .666 r
.65395 .50398 .66104 .53048 .67499 .54676 .66796 .52288 Mtetra
.449 .409 .721 r
.66796 .52288 .67499 .54676 .68847 .54858 .68162 .52945 Mtetra
.684 .582 .735 r
.68162 .52945 .68847 .54858 .70122 .53446 .69468 .52111 Mtetra
.848 .706 .706 r
.69468 .52111 .70122 .53446 .71319 .50685 .70701 .49893 Mtetra
.936 .779 .661 r
.70701 .49893 .71319 .50685 .72454 .47105 .71868 .46709 Mtetra
.974 .819 .627 r
.71868 .46709 .72454 .47105 .73555 .43315 .72994 .43126 Mtetra
.986 .847 .618 r
.72994 .43126 .73555 .43315 .74654 .39816 .74108 .39662 Mtetra
.984 .871 .643 r
.74108 .39662 .74654 .39816 .75777 .36902 .75236 .36669 Mtetra
.967 .891 .7 r
.75236 .36669 .75777 .36902 .76937 .34658 .76396 .34293 Mtetra
.928 .896 .775 r
.76396 .34293 .76937 .34658 .78136 .3302 .77593 .32519 Mtetra
.866 .875 .842 r
.77593 .32519 .78136 .3302 .79372 .31853 .78826 .31239 Mtetra
.796 .837 .882 r
.78826 .31239 .79372 .31853 .80637 .31008 .80089 .30312 Mtetra
.739 .799 .9 r
.80089 .30312 .80637 .31008 .81922 .30361 .81375 .29612 Mtetra
.702 .772 .906 r
.81375 .29612 .81922 .30361 .83223 .29823 .82677 .29043 Mtetra
.682 .756 .908 r
.82677 .29043 .83223 .29823 .84534 .29341 .83992 .28543 Mtetra
.671 .748 .908 r
.83992 .28543 .84534 .29341 .85854 .28884 .85316 .28076 Mtetra
.667 .744 .908 r
.85316 .28076 .85854 .28884 .87181 .28437 .86647 .27623 Mtetra
.66 .74 .909 r
.26012 .46878 .26724 .47542 .27801 .47195 .27092 .46527 Mtetra
.655 .738 .911 r
.27092 .46527 .27801 .47195 .28881 .4686 .28175 .46189 Mtetra
.643 .735 .916 r
.28175 .46189 .28881 .4686 .29964 .46556 .2926 .45883 Mtetra
.613 .726 .926 r
.2926 .45883 .29964 .46556 .31047 .4632 .30346 .4565 Mtetra
.54 .703 .945 r
.30346 .4565 .31047 .4632 .32127 .46217 .31427 .45562 Mtetra
.349 .623 .955 r
.31427 .45562 .32127 .46217 .332 .46353 .32498 .45737 Mtetra
0 .335 .791 r
.32498 .45737 .332 .46353 .34259 .46866 .33554 .46328 Mtetra
.671 .145 0 r
.33554 .46328 .34259 .46866 .35302 .47897 .3459 .47486 Mtetra
.85 .39 .07 r
.3459 .47486 .35302 .47897 .3633 .49523 .35608 .49289 Mtetra
.884 .47 .219 r
.35608 .49289 .3633 .49523 .37352 .51671 .36619 .51644 Mtetra
.879 .482 .275 r
.36619 .51644 .37352 .51671 .38386 .54051 .37644 .54217 Mtetra
.85 .445 .27 r
.37644 .54217 .38386 .54051 .39454 .56172 .38708 .56453 Mtetra
.757 .299 .164 r
.38708 .56453 .39454 .56172 .40573 .57471 .39831 .57729 Mtetra
.093 0 0 r
.39831 .57729 .40573 .57471 .41748 .57527 .41017 .576 Mtetra
.916 .949 .804 r
.41017 .576 .41748 .57527 .42968 .56253 .42255 .56013 Mtetra
.941 .824 .701 r
.42255 .56013 .42968 .56253 .44213 .53934 .43519 .53322 Mtetra
.92 .765 .672 r
.43519 .53322 .44213 .53934 .45461 .51081 .44784 .50123 Mtetra
.894 .729 .67 r
.44784 .50123 .45461 .51081 .46697 .48215 .46032 .46993 Mtetra
.862 .701 .682 r
.46032 .46993 .46697 .48215 .47915 .45697 .47258 .44319 Mtetra
.824 .678 .702 r
.47258 .44319 .47915 .45697 .49118 .43677 .48466 .42245 Mtetra
.783 .658 .725 r
.48466 .42245 .49118 .43677 .5031 .42141 .49662 .40732 Mtetra
.744 .644 .749 r
.49662 .40732 .5031 .42141 .51499 .4099 .50852 .39652 Mtetra
.712 .638 .774 r
.50852 .39652 .51499 .4099 .52687 .40119 .52042 .38868 Mtetra
.684 .639 .798 r
.52042 .38868 .52687 .40119 .53877 .3946 .53235 .38287 Mtetra
.655 .639 .821 r
.53235 .38287 .53877 .3946 .55073 .39001 .54432 .37871 Mtetra
.61 .626 .842 r
.54432 .37871 .55073 .39001 .56276 .38787 .55637 .37642 Mtetra
.53 .585 .854 r
.55637 .37642 .56276 .38787 .57491 .38916 .56851 .37674 Mtetra
.398 .494 .841 r
.56851 .37674 .57491 .38916 .58724 .39518 .58081 .38081 Mtetra
.226 .355 .786 r
.58081 .38081 .58724 .39518 .59985 .40719 .59333 .38987 Mtetra
.07 .211 .704 r
.59333 .38987 .59985 .40719 .61281 .42579 .60616 .40478 Mtetra
0 .116 .637 r
.60616 .40478 .61281 .42579 .62618 .45024 .61935 .42537 Mtetra
0 .091 .608 r
.61935 .42537 .62618 .45024 .63994 .47786 .63292 .44985 Mtetra
.073 .131 .618 r
.63292 .44985 .63994 .47786 .65395 .50398 .64679 .47458 Mtetra
.219 .225 .653 r
.64679 .47458 .65395 .50398 .66796 .52288 .66074 .49454 Mtetra
.407 .357 .69 r
.66074 .49454 .66796 .52288 .68162 .52945 .67451 .50468 Mtetra
.6 .498 .71 r
.67451 .50468 .68162 .52945 .69468 .52111 .68782 .5017 Mtetra
.76 .621 .705 r
.68782 .5017 .69468 .52111 .70701 .49893 .70048 .48534 Mtetra
.87 .711 .681 r
.70048 .48534 .70701 .49893 .71868 .46709 .71251 .45849 Mtetra
.934 .771 .656 r
.71251 .45849 .71868 .46709 .72994 .43126 .72406 .42599 Mtetra
.963 .812 .645 r
.72406 .42599 .72994 .43126 .74108 .39662 .73541 .39292 Mtetra
.971 .843 .658 r
.73541 .39292 .74108 .39662 .75236 .36669 .74681 .36313 Mtetra
.961 .867 .7 r
.74681 .36313 .75236 .36669 .76396 .34293 .75844 .33867 Mtetra
.93 .878 .763 r
.75844 .33867 .76396 .34293 .77593 .32519 .77042 .31992 Mtetra
.876 .868 .827 r
.77042 .31992 .77593 .32519 .78826 .31239 .78274 .30614 Mtetra
.81 .838 .871 r
.78274 .30614 .78826 .31239 .80089 .30312 .79536 .29612 Mtetra
.751 .803 .894 r
.79536 .29612 .80089 .30312 .81375 .29612 .80823 .2886 Mtetra
.71 .776 .903 r
.80823 .2886 .81375 .29612 .82677 .29043 .82128 .28259 Mtetra
.686 .758 .907 r
.82128 .28259 .82677 .29043 .83992 .28543 .83445 .2774 Mtetra
.673 .749 .907 r
.83445 .2774 .83992 .28543 .85316 .28076 .84773 .27262 Mtetra
.668 .744 .908 r
.84773 .27262 .85316 .28076 .86647 .27623 .86108 .26802 Mtetra
.66 .74 .909 r
.25296 .46209 .26012 .46878 .27092 .46527 .26378 .45855 Mtetra
.655 .739 .911 r
.26378 .45855 .27092 .46527 .28175 .46189 .27464 .45514 Mtetra
.642 .735 .916 r
.27464 .45514 .28175 .46189 .2926 .45883 .28551 .45206 Mtetra
.61 .726 .928 r
.28551 .45206 .2926 .45883 .30346 .4565 .29639 .44977 Mtetra
.529 .699 .948 r
.29639 .44977 .30346 .4565 .31427 .45562 .30721 .44906 Mtetra
.311 .605 .951 r
.30721 .44906 .31427 .45562 .32498 .45737 .31791 .45121 Mtetra
0 .266 .733 r
.31791 .45121 .32498 .45737 .33554 .46328 .32843 .45786 Mtetra
.722 .208 0 r
.32843 .45786 .33554 .46328 .3459 .47486 .33872 .47064 Mtetra
.866 .419 .107 r
.33872 .47064 .3459 .47486 .35608 .49289 .3488 .49031 Mtetra
.892 .487 .236 r
.3488 .49031 .35608 .49289 .36619 .51644 .3588 .51576 Mtetra
.887 .495 .281 r
.3588 .51576 .36619 .51644 .37644 .54217 .36896 .54324 Mtetra
.859 .454 .268 r
.36896 .54324 .37644 .54217 .38708 .56453 .37955 .56665 Mtetra
.757 .289 .137 r
.37955 .56665 .38708 .56453 .39831 .57729 .39081 .5793 Mtetra
0 0 0 r
.39081 .5793 .39831 .57729 .41017 .576 .40278 .57659 Mtetra
.934 .926 .776 r
.40278 .57659 .41017 .576 .42255 .56013 .41532 .55828 Mtetra
.949 .822 .685 r
.41532 .55828 .42255 .56013 .43519 .53322 .42814 .52853 Mtetra
.935 .777 .661 r
.42814 .52853 .43519 .53322 .44784 .50123 .44096 .49394 Mtetra
.915 .752 .665 r
.44096 .49394 .44784 .50123 .46032 .46993 .45357 .46071 Mtetra
.889 .735 .684 r
.45357 .46071 .46032 .46993 .47258 .44319 .46593 .43283 Mtetra
.855 .721 .714 r
.46593 .43283 .47258 .44319 .48466 .42245 .47807 .41166 Mtetra
.813 .709 .749 r
.47807 .41166 .48466 .42245 .49662 .40732 .49007 .3966 Mtetra
.768 .698 .785 r
.49007 .3966 .49662 .40732 .50852 .39652 .502 .38615 Mtetra
.727 .691 .816 r
.502 .38615 .50852 .39652 .52042 .38868 .51393 .37875 Mtetra
.692 .688 .841 r
.51393 .37875 .52042 .38868 .53235 .38287 .52588 .37327 Mtetra
.661 .684 .861 r
.52588 .37327 .53235 .38287 .54432 .37871 .53789 .36918 Mtetra
.62 .67 .876 r
.53789 .36918 .54432 .37871 .55637 .37642 .54995 .36652 Mtetra
.554 .632 .883 r
.54995 .36652 .55637 .37642 .56851 .37674 .5621 .36582 Mtetra
.448 .555 .872 r
.5621 .36582 .56851 .37674 .58081 .38081 .57438 .36806 Mtetra
.303 .433 .828 r
.57438 .36806 .58081 .38081 .59333 .38987 .58684 .37436 Mtetra
.155 .294 .754 r
.58684 .37436 .59333 .38987 .60616 .40478 .59955 .38572 Mtetra
.059 .185 .682 r
.59955 .38572 .60616 .40478 .61935 .42537 .61258 .4024 Mtetra
.039 .137 .64 r
.61258 .4024 .61935 .42537 .63292 .44985 .62597 .42333 Mtetra
.092 .152 .633 r
.62597 .42333 .63292 .44985 .64679 .47458 .63967 .4458 Mtetra
.207 .22 .653 r
.63967 .4458 .64679 .47458 .66074 .49454 .65353 .46562 Mtetra
.366 .327 .682 r
.65353 .46562 .66074 .49454 .67451 .50468 .66733 .47808 Mtetra
.539 .451 .704 r
.66733 .47808 .67451 .50468 .68782 .5017 .68081 .47946 Mtetra
.697 .569 .707 r
.68081 .47946 .68782 .5017 .70048 .48534 .69375 .46846 Mtetra
.817 .665 .694 r
.69375 .46846 .70048 .48534 .71251 .45849 .70611 .44669 Mtetra
.895 .734 .675 r
.70611 .44669 .71251 .45849 .72406 .42599 .71797 .41806 Mtetra
.937 .783 .664 r
.71797 .41806 .72406 .42599 .73541 .39292 .72956 .38724 Mtetra
.954 .818 .671 r
.72956 .38724 .73541 .39292 .74681 .36313 .74111 .35827 Mtetra
.951 .845 .702 r
.74111 .35827 .74681 .36313 .75844 .33867 .75282 .33363 Mtetra
.927 .86 .755 r
.75282 .33363 .75844 .33867 .77042 .31992 .76482 .31422 Mtetra
.88 .856 .814 r
.76482 .31422 .77042 .31992 .78274 .30614 .77715 .29967 Mtetra
.819 .834 .86 r
.77715 .29967 .78274 .30614 .79536 .29612 .78978 .28898 Mtetra
.761 .804 .887 r
.78978 .28898 .79536 .29612 .80823 .2886 .80266 .28098 Mtetra
.717 .777 .9 r
.80266 .28098 .80823 .2886 .82128 .28259 .81573 .27467 Mtetra
.69 .76 .905 r
.81573 .27467 .82128 .28259 .83445 .2774 .82894 .2693 Mtetra
.676 .75 .907 r
.82894 .2693 .83445 .2774 .84773 .27262 .84225 .26441 Mtetra
.669 .745 .907 r
.84225 .26441 .84773 .27262 .86108 .26802 .85564 .25974 Mtetra
.661 .74 .909 r
.24573 .45536 .25296 .46209 .26378 .45855 .25658 .45178 Mtetra
.655 .739 .911 r
.25658 .45178 .26378 .45855 .27464 .45514 .26747 .44834 Mtetra
.641 .735 .917 r
.26747 .44834 .27464 .45514 .28551 .45206 .27837 .44526 Mtetra
.607 .725 .929 r
.27837 .44526 .28551 .45206 .29639 .44977 .28926 .44301 Mtetra
.518 .696 .95 r
.28926 .44301 .29639 .44977 .30721 .44906 .30009 .44246 Mtetra
.275 .586 .945 r
.30009 .44246 .30721 .44906 .31791 .45121 .31078 .44496 Mtetra
0 .21 .684 r
.31078 .44496 .31791 .45121 .32843 .45786 .32127 .45224 Mtetra
.751 .246 0 r
.32127 .45224 .32843 .45786 .33872 .47064 .33149 .46599 Mtetra
.876 .437 .121 r
.33149 .46599 .33872 .47064 .3488 .49031 .34149 .48696 Mtetra
.9 .499 .236 r
.34149 .48696 .3488 .49031 .3588 .51576 .35139 .51384 Mtetra
.897 .506 .271 r
.35139 .51384 .3588 .51576 .36896 .54324 .36146 .54256 Mtetra
.872 .461 .241 r
.36146 .54256 .36896 .54324 .37955 .56665 .37201 .56662 Mtetra
.756 .259 .043 r
.37201 .56662 .37955 .56665 .39081 .5793 .3833 .57902 Mtetra
.474 .887 .93 r
.3833 .57902 .39081 .5793 .40278 .57659 .39537 .57514 Mtetra
.93 .872 .759 r
.39537 .57514 .40278 .57659 .41532 .55828 .40806 .55502 Mtetra
.941 .8 .676 r
.40806 .55502 .41532 .55828 .42814 .52853 .42104 .52333 Mtetra
.933 .77 .655 r
.42104 .52333 .42814 .52853 .44096 .49394 .43401 .48706 Mtetra
.92 .756 .661 r
.43401 .48706 .44096 .49394 .45357 .46071 .44675 .45266 Mtetra
.901 .749 .683 r
.44675 .45266 .45357 .46071 .46593 .43283 .4592 .42415 Mtetra
.873 .746 .72 r
.4592 .42415 .46593 .43283 .47807 .41166 .47141 .40276 Mtetra
.832 .742 .765 r
.47141 .40276 .47807 .41166 .49007 .3966 .48345 .38775 Mtetra
.784 .737 .809 r
.48345 .38775 .49007 .3966 .502 .38615 .49543 .37746 Mtetra
.736 .73 .845 r
.49543 .37746 .502 .38615 .51393 .37875 .50739 .37024 Mtetra
.697 .723 .87 r
.50739 .37024 .51393 .37875 .52588 .37327 .51938 .36487 Mtetra
.665 .716 .886 r
.51938 .36487 .52588 .37327 .53789 .36918 .53141 .3607 Mtetra
.63 .702 .897 r
.53141 .3607 .53789 .36918 .54995 .36652 .5435 .35766 Mtetra
.577 .67 .903 r
.5435 .35766 .54995 .36652 .5621 .36582 .55567 .35615 Mtetra
.489 .608 .897 r
.55567 .35615 .5621 .36582 .57438 .36806 .56794 .35696 Mtetra
.359 .503 .867 r
.56794 .35696 .57438 .36806 .58684 .37436 .58037 .36114 Mtetra
.205 .365 .803 r
.58037 .36114 .58684 .37436 .59955 .38572 .593 .36969 Mtetra
.079 .237 .726 r
.593 .36969 .59955 .38572 .61258 .4024 .60592 .38313 Mtetra
.022 .16 .669 r
.60592 .38313 .61258 .4024 .62597 .42333 .61916 .40092 Mtetra
.047 .149 .649 r
.61916 .40092 .62597 .42333 .63967 .4458 .63271 .42108 Mtetra
.145 .201 .663 r
.63271 .42108 .63967 .4458 .65353 .46562 .64648 .44014 Mtetra
.301 .302 .693 r
.64648 .44014 .65353 .46562 .66733 .47808 .66027 .45379 Mtetra
.485 .429 .719 r
.66027 .45379 .66733 .47808 .68081 .47946 .67384 .4582 Mtetra
.656 .552 .725 r
.67384 .4582 .68081 .47946 .69375 .46846 .68699 .45133 Mtetra
.787 .65 .712 r
.68699 .45133 .69375 .46846 .70611 .44669 .69962 .43382 Mtetra
.871 .72 .691 r
.69962 .43382 .70611 .44669 .71797 .41806 .71175 .40869 Mtetra
.918 .767 .677 r
.71175 .40869 .71797 .41806 .72956 .38724 .72356 .38015 Mtetra
.939 .801 .68 r
.72356 .38015 .72956 .38724 .74111 .35827 .73527 .35223 Mtetra
.939 .825 .705 r
.73527 .35223 .74111 .35827 .75282 .33363 .74708 .32772 Mtetra
.92 .841 .75 r
.74708 .32772 .75282 .33363 .76482 .31422 .75913 .30793 Mtetra
.88 .842 .803 r
.75913 .30793 .76482 .31422 .77715 .29967 .77149 .29283 Mtetra
.824 .826 .85 r
.77149 .29283 .77715 .29967 .78978 .28898 .78414 .28162 Mtetra
.767 .801 .88 r
.78414 .28162 .78978 .28898 .80266 .28098 .79704 .27323 Mtetra
.722 .777 .896 r
.79704 .27323 .80266 .28098 .81573 .27467 .81013 .26665 Mtetra
.693 .76 .903 r
.81013 .26665 .81573 .27467 .82894 .2693 .82337 .26111 Mtetra
.677 .75 .906 r
.82337 .26111 .82894 .2693 .84225 .26441 .83672 .25612 Mtetra
.669 .745 .907 r
.83672 .25612 .84225 .26441 .85564 .25974 .85016 .25139 Mtetra
.661 .74 .909 r
.23845 .44857 .24573 .45536 .25658 .45178 .24933 .44497 Mtetra
.655 .739 .911 r
.24933 .44497 .25658 .45178 .26747 .44834 .26024 .4415 Mtetra
.641 .735 .917 r
.26024 .4415 .26747 .44834 .27837 .44526 .27117 .43842 Mtetra
.604 .725 .93 r
.27117 .43842 .27837 .44526 .28926 .44301 .28208 .43621 Mtetra
.51 .692 .951 r
.28208 .43621 .28926 .44301 .30009 .44246 .29291 .43577 Mtetra
.252 .571 .94 r
.29291 .43577 .30009 .44246 .31078 .44496 .30361 .43851 Mtetra
0 .178 .659 r
.30361 .43851 .31078 .44496 .32127 .45224 .31407 .44622 Mtetra
.76 .262 0 r
.31407 .44622 .32127 .45224 .33149 .46599 .32424 .46059 Mtetra
.88 .445 .112 r
.32424 .46059 .33149 .46599 .34149 .48696 .33417 .4823 Mtetra
.907 .505 .217 r
.33417 .4823 .34149 .48696 .35139 .51384 .344 .5099 Mtetra
.908 .512 .24 r
.344 .5099 .35139 .51384 .36146 .54256 .35401 .5391 Mtetra
.884 .461 .179 r
.35401 .5391 .36146 .54256 .37201 .56662 .36455 .56317 Mtetra
.707 .171 0 r
.36455 .56317 .37201 .56662 .3833 .57902 .37587 .57503 Mtetra
.677 .857 .968 r
.37587 .57503 .3833 .57902 .39537 .57514 .38802 .57019 Mtetra
.902 .804 .742 r
.38802 .57019 .39537 .57514 .40806 .55502 .40082 .54895 Mtetra
.921 .766 .672 r
.40082 .54895 .40806 .55502 .42104 .52333 .41394 .51628 Mtetra
.922 .751 .654 r
.41394 .51628 .42104 .52333 .43401 .48706 .42703 .47936 Mtetra
.915 .748 .66 r
.42703 .47936 .43401 .48706 .44675 .45266 .43987 .44468 Mtetra
.902 .751 .684 r
.43987 .44468 .44675 .45266 .4592 .42415 .4524 .41613 Mtetra
.879 .757 .724 r
.4524 .41613 .4592 .42415 .47141 .40276 .46468 .39484 Mtetra
.842 .762 .775 r
.46468 .39484 .47141 .40276 .48345 .38775 .47678 .37995 Mtetra
.793 .763 .825 r
.47678 .37995 .48345 .38775 .49543 .37746 .48879 .36977 Mtetra
.743 .757 .864 r
.48879 .36977 .49543 .37746 .50739 .37024 .5008 .3626 Mtetra
.702 .748 .888 r
.5008 .3626 .50739 .37024 .51938 .36487 .51282 .35719 Mtetra
.669 .739 .902 r
.51282 .35719 .51938 .36487 .53141 .3607 .52489 .35291 Mtetra
.637 .725 .912 r
.52489 .35291 .53141 .3607 .5435 .35766 .53701 .34961 Mtetra
.589 .7 .92 r
.53701 .34961 .5435 .35766 .55567 .35615 .5492 .34763 Mtetra
.506 .65 .922 r
.5492 .34763 .55567 .35615 .56794 .35696 .56149 .34765 Mtetra
.37 .557 .906 r
.56149 .34765 .56794 .35696 .58037 .36114 .57391 .35064 Mtetra
.18 .412 .849 r
.57391 .35064 .58037 .36114 .593 .36969 .58651 .35757 Mtetra
0 .247 .756 r
.58651 .35757 .593 .36969 .60592 .38313 .59937 .36906 Mtetra
0 .125 .672 r
.59937 .36906 .60592 .38313 .61916 .40092 .61253 .38485 Mtetra
0 .085 .638 r
.61253 .38485 .61916 .40092 .63271 .42108 .62599 .40336 Mtetra
0 .133 .664 r
.62599 .40336 .63271 .42108 .64648 .44014 .63968 .42158 Mtetra
.154 .262 .724 r
.63968 .42158 .64648 .44014 .66027 .45379 .65345 .43554 Mtetra
.411 .433 .772 r
.65345 .43554 .66027 .45379 .67384 .4582 .66707 .44144 Mtetra
.638 .581 .774 r
.66707 .44144 .67384 .4582 .68699 .45133 .68035 .43692 Mtetra
.787 .677 .743 r
.68035 .43692 .68699 .45133 .69962 .43382 .69315 .42203 Mtetra
.87 .733 .708 r
.69315 .42203 .69962 .43382 .71175 .40869 .70547 .39919 Mtetra
.912 .767 .688 r
.70547 .39919 .71175 .40869 .72356 .38015 .71746 .37226 Mtetra
.929 .791 .687 r
.71746 .37226 .72356 .38015 .73527 .35223 .72931 .34518 Mtetra
.929 .81 .707 r
.72931 .34518 .73527 .35223 .74708 .32772 .74122 .32089 Mtetra
.911 .822 .746 r
.74122 .32089 .74708 .32772 .75913 .30793 .75334 .30092 Mtetra
.875 .824 .795 r
.75334 .30092 .75913 .30793 .77149 .29283 .76574 .28548 Mtetra
.824 .814 .84 r
.76574 .28548 .77149 .29283 .78414 .28162 .77842 .27393 Mtetra
.77 .794 .873 r
.77842 .27393 .78414 .28162 .79704 .27323 .79135 .26526 Mtetra
.726 .774 .891 r
.79135 .26526 .79704 .27323 .81013 .26665 .80448 .25849 Mtetra
.696 .759 .901 r
.80448 .25849 .81013 .26665 .82337 .26111 .81776 .25283 Mtetra
.679 .75 .905 r
.81776 .25283 .82337 .26111 .83672 .25612 .83115 .24775 Mtetra
.67 .745 .907 r
.83115 .24775 .83672 .25612 .85016 .25139 .84463 .24296 Mtetra
.661 .74 .909 r
.23112 .44174 .23845 .44857 .24933 .44497 .24202 .43811 Mtetra
.655 .739 .912 r
.24202 .43811 .24933 .44497 .26024 .4415 .25296 .43462 Mtetra
.64 .735 .918 r
.25296 .43462 .26024 .4415 .27117 .43842 .26391 .43152 Mtetra
.602 .724 .931 r
.26391 .43152 .27117 .43842 .28208 .43621 .27484 .42932 Mtetra
.506 .69 .951 r
.27484 .42932 .28208 .43621 .29291 .43577 .28569 .42894 Mtetra
.245 .564 .937 r
.28569 .42894 .29291 .43577 .30361 .43851 .29639 .43179 Mtetra
0 .175 .662 r
.29639 .43179 .30361 .43851 .31407 .44622 .30684 .43965 Mtetra
.75 .256 0 r
.30684 .43965 .31407 .44622 .32424 .46059 .31699 .45418 Mtetra
.877 .441 .08 r
.31699 .45418 .32424 .46059 .33417 .4823 .32688 .47596 Mtetra
.91 .504 .178 r
.32688 .47596 .33417 .4823 .344 .5099 .33668 .50345 Mtetra
.912 .509 .183 r
.33668 .50345 .344 .5099 .35401 .5391 .34667 .53225 Mtetra
.876 .44 .067 r
.34667 .53225 .35401 .5391 .36455 .56317 .3572 .55564 Mtetra
0 .026 .532 r
.3572 .55564 .36455 .56317 .37587 .57503 .36855 .56669 Mtetra
.7 .732 .876 r
.36855 .56669 .37587 .57503 .38802 .57019 .38077 .56115 Mtetra
.865 .741 .724 r
.38077 .56115 .38802 .57019 .40082 .54895 .39365 .53958 Mtetra
.897 .733 .67 r
.39365 .53958 .40082 .54895 .41394 .51628 .40685 .50703 Mtetra
.906 .732 .655 r
.40685 .50703 .41394 .51628 .42703 .47936 .42002 .47061 Mtetra
.907 .739 .662 r
.42002 .47061 .42703 .47936 .43987 .44468 .43294 .43657 Mtetra
.9 .751 .687 r
.43294 .43657 .43987 .44468 .4524 .41613 .44554 .40864 Mtetra
.882 .767 .73 r
.44554 .40864 .4524 .41613 .46468 .39484 .45787 .3878 Mtetra
.85 .782 .785 r
.45787 .3878 .46468 .39484 .47678 .37995 .47003 .37315 Mtetra
.803 .789 .84 r
.47003 .37315 .47678 .37995 .48879 .36977 .48209 .36302 Mtetra
.751 .785 .881 r
.48209 .36302 .48879 .36977 .5008 .3626 .49414 .35577 Mtetra
.708 .775 .905 r
.49414 .35577 .5008 .3626 .51282 .35719 .5062 .35024 Mtetra
.673 .763 .918 r
.5062 .35024 .51282 .35719 .52489 .35291 .51831 .34582 Mtetra
.637 .748 .928 r
.51831 .34582 .52489 .35291 .53701 .34961 .53047 .34242 Mtetra
.583 .725 .941 r
.53047 .34242 .53701 .34961 .5492 .34763 .54269 .34038 Mtetra
.482 .68 .953 r
.54269 .34038 .5492 .34763 .56149 .34765 .55501 .34037 Mtetra
.293 .579 .94 r
.55501 .34037 .56149 .34765 .57391 .35064 .56745 .34332 Mtetra
0 .382 .841 r
.56745 .34332 .57391 .35064 .58651 .35757 .58007 .35014 Mtetra
0 .129 .646 r
.58007 .35014 .58651 .35757 .59937 .36906 .59293 .36138 Mtetra
0 0 .468 r
.59293 .36138 .59937 .36906 .61253 .38485 .60608 .37676 Mtetra
.596 .134 0 r
.60608 .37676 .61253 .38485 .62599 .40336 .61952 .39473 Mtetra
0 0 .448 r
.61952 .39473 .62599 .40336 .63968 .42158 .63319 .41238 Mtetra
0 .111 .651 r
.63319 .41238 .63968 .42158 .65345 .43554 .64694 .42592 Mtetra
.225 .475 .886 r
.64694 .42592 .65345 .43554 .66707 .44144 .66058 .43165 Mtetra
.657 .702 .88 r
.66058 .43165 .66707 .44144 .68035 .43692 .67389 .42729 Mtetra
.83 .76 .786 r
.67389 .42729 .68035 .43692 .69315 .42203 .68677 .41281 Mtetra
.893 .774 .722 r
.68677 .41281 .69315 .42203 .70547 .39919 .6992 .39049 Mtetra
.918 .78 .692 r
.6992 .39049 .70547 .39919 .71746 .37226 .7113 .36401 Mtetra
.925 .787 .689 r
.7113 .36401 .71746 .37226 .72931 .34518 .72325 .33723 Mtetra
.92 .796 .707 r
.72325 .33723 .72931 .34518 .74122 .32089 .73525 .31305 Mtetra
.901 .803 .743 r
.73525 .31305 .74122 .32089 .75334 .30092 .74744 .29306 Mtetra
.866 .806 .788 r
.74744 .29306 .75334 .30092 .76574 .28548 .75989 .27751 Mtetra
.819 .799 .832 r
.75989 .27751 .76574 .28548 .77842 .27393 .77262 .26583 Mtetra
.769 .785 .866 r
.77262 .26583 .77842 .27393 .79135 .26526 .7856 .25704 Mtetra
.726 .769 .887 r
.7856 .25704 .79135 .26526 .80448 .25849 .79877 .25017 Mtetra
.696 .757 .898 r
.79877 .25017 .80448 .25849 .81776 .25283 .81209 .24443 Mtetra
.679 .749 .904 r
.81209 .24443 .81776 .25283 .83115 .24775 .82553 .2393 Mtetra
.67 .745 .906 r
.82553 .2393 .83115 .24775 .84463 .24296 .83905 .23445 Mtetra
.661 .741 .909 r
.22373 .43486 .23112 .44174 .24202 .43811 .23465 .43119 Mtetra
.655 .739 .912 r
.23465 .43119 .24202 .43811 .25296 .43462 .24562 .42768 Mtetra
.64 .735 .918 r
.24562 .42768 .25296 .43462 .26391 .43152 .25659 .42456 Mtetra
.602 .724 .93 r
.25659 .42456 .26391 .43152 .27484 .42932 .26755 .42234 Mtetra
.507 .689 .95 r
.26755 .42234 .27484 .42932 .28569 .42894 .27842 .42193 Mtetra
.256 .566 .937 r
.27842 .42193 .28569 .42894 .29639 .43179 .28913 .42471 Mtetra
0 .2 .692 r
.28913 .42471 .29639 .43179 .30684 .43965 .29959 .43243 Mtetra
.717 .225 0 r
.29959 .43243 .30684 .43965 .31699 .45418 .30975 .44663 Mtetra
.863 .421 .023 r
.30975 .44663 .31699 .45418 .32688 .47596 .31965 .46781 Mtetra
.902 .49 .115 r
.31965 .46781 .32688 .47596 .33668 .50345 .32945 .49436 Mtetra
.899 .49 .095 r
.32945 .49436 .33668 .50345 .34667 .53225 .33945 .52195 Mtetra
.808 .377 0 r
.33945 .52195 .34667 .53225 .3572 .55564 .35001 .54409 Mtetra
0 .221 .743 r
.35001 .54409 .3572 .55564 .36855 .56669 .36139 .55422 Mtetra
.682 .647 .809 r
.36139 .55422 .36855 .56669 .38077 .56115 .37363 .54845 Mtetra
.832 .695 .712 r
.37363 .54845 .38077 .56115 .39365 .53958 .38654 .5275 Mtetra
.875 .708 .671 r
.38654 .5275 .39365 .53958 .40685 .50703 .39977 .49628 Mtetra
.894 .72 .659 r
.39977 .49628 .40685 .50703 .42002 .47061 .41297 .46155 Mtetra
.902 .737 .668 r
.41297 .46155 .42002 .47061 .43294 .43657 .42593 .42914 Mtetra
.903 .761 .695 r
.42593 .42914 .43294 .43657 .44554 .40864 .43859 .40248 Mtetra
.892 .791 .742 r
.43859 .40248 .44554 .40864 .45787 .3878 .45098 .3824 Mtetra
.865 .821 .803 r
.45098 .3824 .45787 .3878 .47003 .37315 .46319 .36804 Mtetra
.82 .838 .863 r
.46319 .36804 .47003 .37315 .48209 .36302 .47531 .35783 Mtetra
.766 .836 .906 r
.47531 .35783 .48209 .36302 .49414 .35577 .48741 .3503 Mtetra
.719 .822 .929 r
.48741 .3503 .49414 .35577 .5062 .35024 .49952 .34445 Mtetra
.678 .803 .942 r
.49952 .34445 .5062 .35024 .51831 .34582 .51167 .33981 Mtetra
.629 .782 .955 r
.51167 .33981 .51831 .34582 .53047 .34242 .52387 .33643 Mtetra
.546 .753 .973 r
.52387 .33643 .53047 .34242 .54269 .34038 .53613 .33475 Mtetra
.374 .685 .979 r
.53613 .33475 .54269 .34038 .55501 .34037 .54849 .33553 Mtetra
.02 .492 .876 r
.54849 .33553 .55501 .34037 .56745 .34332 .56098 .33967 Mtetra
.432 0 0 r
.56098 .33967 .56745 .34332 .58007 .35014 .57366 .348 Mtetra
.689 .145 0 r
.57366 .348 .58007 .35014 .59293 .36138 .58658 .36083 Mtetra
.779 .277 0 r
.58658 .36083 .59293 .36138 .60608 .37676 .59978 .37752 Mtetra
.801 .319 .066 r
.59978 .37752 .60608 .37676 .61952 .39473 .61327 .39615 Mtetra
.784 .296 .06 r
.61327 .39615 .61952 .39473 .63319 .41238 .62697 .41353 Mtetra
.699 .169 0 r
.62697 .41353 .63319 .41238 .64694 .42592 .64072 .42583 Mtetra
.309 0 0 r
.64072 .42583 .64694 .42592 .66058 .43165 .65434 .4296 Mtetra
.676 .943 .962 r
.65434 .4296 .66058 .43165 .67389 .42729 .66763 .423 Mtetra
.904 .885 .803 r
.66763 .423 .67389 .42729 .68677 .41281 .68049 .40651 Mtetra
.93 .823 .718 r
.68049 .40651 .68677 .41281 .6992 .39049 .69293 .38272 Mtetra
.93 .794 .688 r
.69293 .38272 .6992 .39049 .7113 .36401 .70506 .35541 Mtetra
.923 .783 .687 r
.70506 .35541 .7113 .36401 .72325 .33723 .71708 .3283 Mtetra
.91 .781 .706 r
.71708 .3283 .72325 .33723 .73525 .31305 .72916 .30413 Mtetra
.888 .784 .74 r
.72916 .30413 .73525 .31305 .74744 .29306 .74142 .28427 Mtetra
.854 .786 .783 r
.74142 .28427 .74744 .29306 .75989 .27751 .75395 .26886 Mtetra
.811 .782 .826 r
.75395 .26886 .75989 .27751 .77262 .26583 .76675 .25728 Mtetra
.764 .774 .861 r
.76675 .25728 .77262 .26583 .7856 .25704 .77978 .24854 Mtetra
.724 .763 .884 r
.77978 .24854 .7856 .25704 .79877 .25017 .793 .24167 Mtetra
.695 .753 .896 r
.793 .24167 .79877 .25017 .81209 .24443 .80637 .23591 Mtetra
.679 .747 .903 r
.80637 .23591 .81209 .24443 .82553 .2393 .81986 .23075 Mtetra
.67 .744 .906 r
.81986 .23075 .82553 .2393 .83905 .23445 .83343 .22586 Mtetra
.661 .741 .909 r
.21628 .42792 .22373 .43486 .23465 .43119 .22723 .42423 Mtetra
.655 .739 .912 r
.22723 .42423 .23465 .43119 .24562 .42768 .23822 .42068 Mtetra
.64 .735 .917 r
.23822 .42068 .24562 .42768 .25659 .42456 .24922 .41752 Mtetra
.604 .724 .929 r
.24922 .41752 .25659 .42456 .26755 .42234 .2602 .41524 Mtetra
.513 .69 .948 r
.2602 .41524 .26755 .42234 .27842 .42193 .2711 .41472 Mtetra
.284 .577 .939 r
.2711 .41472 .27842 .42193 .28913 .42471 .28184 .41728 Mtetra
0 .25 .74 r
.28184 .41728 .28913 .42471 .29959 .43243 .29233 .42455 Mtetra
.655 .167 0 r
.29233 .42455 .29959 .43243 .30975 .44663 .30252 .43797 Mtetra
.829 .382 0 r
.30252 .43797 .30975 .44663 .31965 .46781 .31246 .45794 Mtetra
.875 .458 .026 r
.31246 .45794 .31965 .46781 .32945 .49436 .32231 .48287 Mtetra
.853 .445 0 r
.32231 .48287 .32945 .49436 .33945 .52195 .33236 .50864 Mtetra
.65 .261 0 r
.33236 .50864 .33945 .52195 .35001 .54409 .34295 .52921 Mtetra
.134 .302 .769 r
.34295 .52921 .35001 .54409 .36139 .55422 .35434 .53857 Mtetra
.658 .596 .774 r
.35434 .53857 .36139 .55422 .37363 .54845 .36656 .53327 Mtetra
.804 .664 .71 r
.36656 .53327 .37363 .54845 .38654 .5275 .37944 .51408 Mtetra
.859 .695 .678 r
.37944 .51408 .38654 .5275 .39977 .49628 .39263 .48555 Mtetra
.888 .721 .67 r
.39263 .48555 .39977 .49628 .41297 .46155 .40582 .45378 Mtetra
.906 .754 .681 r
.40582 .45378 .41297 .46155 .42593 .42914 .41879 .42401 Mtetra
.918 .797 .712 r
.41879 .42401 .42593 .42914 .43859 .40248 .43149 .39926 Mtetra
.917 .852 .763 r
.43149 .39926 .43859 .40248 .45098 .3824 .44393 .38022 Mtetra
.892 .905 .828 r
.44393 .38022 .45098 .3824 .46319 .36804 .45621 .3661 Mtetra
.841 .934 .889 r
.45621 .3661 .46319 .36804 .47531 .35783 .46841 .35554 Mtetra
.782 .932 .931 r
.46841 .35554 .47531 .35783 .48741 .3503 .48058 .34735 Mtetra
.731 .91 .956 r
.48058 .34735 .48741 .3503 .49952 .34445 .49276 .3408 Mtetra
.678 .879 .973 r
.49276 .3408 .49952 .34445 .51167 .33981 .50496 .3357 Mtetra
.598 .841 .99 r
.50496 .3357 .51167 .33981 .52387 .33643 .5172 .33233 Mtetra
.436 .775 .997 r
.5172 .33233 .52387 .33643 .53613 .33475 .52951 .33134 Mtetra
.074 .579 .889 r
.52951 .33134 .53613 .33475 .54849 .33553 .54192 .33364 Mtetra
.431 0 0 r
.54192 .33364 .54849 .33553 .56098 .33967 .55448 .34015 Mtetra
.695 .161 0 r
.55448 .34015 .56098 .33967 .57366 .348 .56724 .35151 Mtetra
.771 .303 .132 r
.56724 .35151 .57366 .348 .58658 .36083 .58027 .36756 Mtetra
.784 .354 .229 r
.58027 .36756 .58658 .36083 .59978 .37752 .59359 .387 Mtetra
.772 .359 .269 r
.59359 .387 .59978 .37752 .61327 .39615 .60718 .40711 Mtetra
.736 .324 .268 r
.60718 .40711 .61327 .39615 .62697 .41353 .62094 .42414 Mtetra
.652 .222 .213 r
.62094 .42414 .62697 .41353 .64072 .42583 .63471 .43409 Mtetra
.392 0 .004 r
.63471 .43409 .64072 .42583 .65434 .4296 .64827 .43397 Mtetra
.519 .864 .604 r
.64827 .43397 .65434 .4296 .66763 .423 .66147 .42282 Mtetra
.949 .947 .736 r
.66147 .42282 .66763 .423 .68049 .40651 .67424 .40213 Mtetra
.957 .847 .692 r
.67424 .40213 .68049 .40651 .69293 .38272 .68661 .37519 Mtetra
.938 .795 .676 r
.68661 .37519 .69293 .38272 .70506 .35541 .69874 .34602 Mtetra
.919 .772 .682 r
.69874 .34602 .70506 .35541 .71708 .3283 .71079 .31818 Mtetra
.899 .763 .704 r
.71079 .31818 .71708 .3283 .72916 .30413 .72294 .29401 Mtetra
.873 .763 .738 r
.72294 .29401 .72916 .30413 .74142 .28427 .7353 .2745 Mtetra
.839 .765 .78 r
.7353 .2745 .74142 .28427 .75395 .26886 .74792 .25952 Mtetra
.798 .765 .823 r
.74792 .25952 .75395 .26886 .76675 .25728 .76079 .24828 Mtetra
.756 .762 .858 r
.76079 .24828 .76675 .25728 .77978 .24854 .7739 .23975 Mtetra
.719 .755 .881 r
.7739 .23975 .77978 .24854 .793 .24167 .78718 .23299 Mtetra
.693 .75 .895 r
.78718 .23299 .793 .24167 .80637 .23591 .8006 .22727 Mtetra
.678 .746 .902 r
.8006 .22727 .80637 .23591 .81986 .23075 .81413 .2221 Mtetra
.67 .743 .906 r
.81413 .2221 .81986 .23075 .83343 .22586 .82775 .21719 Mtetra
.661 .741 .909 r
.20877 .42093 .21628 .42792 .22723 .42423 .21975 .4172 Mtetra
.655 .739 .911 r
.21975 .4172 .22723 .42423 .23822 .42068 .23077 .41362 Mtetra
.641 .735 .917 r
.23077 .41362 .23822 .42068 .24922 .41752 .2418 .41041 Mtetra
.607 .724 .928 r
.2418 .41041 .24922 .41752 .2602 .41524 .25281 .40803 Mtetra
.524 .692 .945 r
.25281 .40803 .2602 .41524 .2711 .41472 .26374 .40732 Mtetra
.322 .593 .942 r
.26374 .40732 .2711 .41472 .28184 .41728 .27451 .40949 Mtetra
0 .315 .796 r
.27451 .40949 .28184 .41728 .29233 .42455 .28505 .41606 Mtetra
.556 .081 0 r
.28505 .41606 .29233 .42455 .30252 .43797 .29531 .42833 Mtetra
.765 .317 0 r
.29531 .42833 .30252 .43797 .31246 .45794 .30532 .44663 Mtetra
.817 .4 0 r
.30532 .44663 .31246 .45794 .32231 .48287 .31525 .46946 Mtetra
.761 .369 0 r
.31525 .46946 .32231 .48287 .33236 .50864 .32537 .49306 Mtetra
0 0 .46 r
.32537 .49306 .33236 .50864 .34295 .52921 .33599 .51203 Mtetra
.221 .322 .756 r
.33599 .51203 .34295 .52921 .35434 .53857 .34736 .52106 Mtetra
.626 .561 .761 r
.34736 .52106 .35434 .53857 .36656 .53327 .35952 .51717 Mtetra
.777 .647 .719 r
.35952 .51717 .36656 .53327 .37944 .51408 .37229 .50107 Mtetra
.847 .696 .695 r
.37229 .50107 .37944 .51408 .39263 .48555 .38538 .47668 Mtetra
.891 .744 .692 r
.38538 .47668 .39263 .48555 .40582 .45378 .39849 .44926 Mtetra
.925 .803 .707 r
.39849 .44926 .40582 .45378 .41879 .42401 .41143 .42323 Mtetra
.947 .881 .737 r
.41143 .42323 .41879 .42401 .43149 .39926 .42415 .40109 Mtetra
.93 .962 .768 r
.42415 .40109 .43149 .39926 .44393 .38022 .43666 .38337 Mtetra
.843 .997 .775 r
.43666 .38337 .44393 .38022 .45621 .3661 .44903 .36939 Mtetra
.731 .983 .77 r
.44903 .36939 .45621 .3661 .46841 .35554 .46133 .3581 Mtetra
.669 .97 .799 r
.46133 .3581 .46841 .35554 .48058 .34735 .4736 .34869 Mtetra
.644 .968 .859 r
.4736 .34869 .48058 .34735 .49276 .3408 .48587 .34085 Mtetra
.599 .947 .917 r
.48587 .34085 .49276 .3408 .50496 .3357 .49815 .3348 Mtetra
.464 .877 .941 r
.49815 .3348 .50496 .3357 .5172 .33233 .51045 .33119 Mtetra
.131 .671 .841 r
.51045 .33119 .5172 .33233 .52951 .33134 .52282 .33099 Mtetra
.37 0 0 r
.52282 .33099 .52951 .33134 .54192 .33364 .53529 .3353 Mtetra
.666 .134 0 r
.53529 .3353 .54192 .33364 .55448 .34015 .54792 .34504 Mtetra
.758 .302 .165 r
.54792 .34504 .55448 .34015 .56724 .35151 .56078 .3605 Mtetra
.778 .366 .271 r
.56078 .3605 .56724 .35151 .58027 .36756 .57394 .38083 Mtetra
.769 .382 .323 r
.57394 .38083 .58027 .36756 .59359 .387 .58741 .4037 Mtetra
.742 .367 .342 r
.58741 .4037 .59359 .387 .60718 .40711 .60113 .42535 Mtetra
.69 .316 .334 r
.60113 .42535 .60718 .40711 .62094 .42414 .61497 .44127 Mtetra
.581 .198 .281 r
.61497 .44127 .62094 .42414 .63471 .43409 .62873 .4474 Mtetra
.273 0 .09 r
.62873 .4474 .63471 .43409 .64827 .43397 .64221 .44149 Mtetra
.608 .839 .46 r
.64221 .44149 .64827 .43397 .66147 .42282 .65528 .42394 Mtetra
.973 .926 .665 r
.65528 .42394 .66147 .42282 .67424 .40213 .66791 .39755 Mtetra
.965 .832 .663 r
.66791 .39755 .67424 .40213 .68661 .37519 .68019 .36653 Mtetra
.935 .779 .663 r
.68019 .36653 .68661 .37519 .69874 .34602 .69228 .33512 Mtetra
.909 .753 .676 r
.69228 .33512 .69874 .34602 .71079 .31818 .70438 .30656 Mtetra
.883 .742 .701 r
.70438 .30656 .71079 .31818 .72294 .29401 .71661 .28265 Mtetra
.855 .742 .737 r
.71661 .28265 .72294 .29401 .7353 .2745 .72907 .26382 Mtetra
.822 .746 .78 r
.72907 .26382 .7353 .2745 .74792 .25952 .74179 .24956 Mtetra
.784 .75 .822 r
.74179 .24956 .74792 .25952 .76079 .24828 .75476 .23888 Mtetra
.745 .75 .857 r
.75476 .23888 .76079 .24828 .7739 .23975 .76795 .23072 Mtetra
.712 .749 .881 r
.76795 .23072 .7739 .23975 .78718 .23299 .78129 .22416 Mtetra
.689 .746 .895 r
.78129 .22416 .78718 .23299 .8006 .22727 .79477 .21852 Mtetra
.676 .744 .902 r
.79477 .21852 .8006 .22727 .81413 .2221 .80836 .21337 Mtetra
.669 .743 .905 r
.80836 .21337 .81413 .2221 .82775 .21719 .82202 .20844 Mtetra
.661 .741 .909 r
.2012 .41388 .20877 .42093 .21975 .4172 .21221 .41012 Mtetra
.656 .739 .911 r
.21221 .41012 .21975 .4172 .23077 .41362 .22325 .4065 Mtetra
.643 .735 .916 r
.22325 .4065 .23077 .41362 .2418 .41041 .23431 .40322 Mtetra
.611 .725 .926 r
.23431 .40322 .2418 .41041 .25281 .40803 .24536 .40071 Mtetra
.538 .696 .941 r
.24536 .40071 .25281 .40803 .26374 .40732 .25633 .39973 Mtetra
.368 .612 .944 r
.25633 .39973 .26374 .40732 .27451 .40949 .26715 .4014 Mtetra
.016 .388 .847 r
.26715 .4014 .27451 .40949 .28505 .41606 .27776 .40707 Mtetra
0 .032 .568 r
.27776 .40707 .28505 .41606 .29531 .42833 .2881 .41791 Mtetra
.66 .221 0 r
.2881 .41791 .29531 .42833 .30532 .44663 .29822 .43421 Mtetra
.72 .314 0 r
.29822 .43421 .30532 .44663 .31525 .46946 .30825 .45464 Mtetra
0 0 .311 r
.30825 .45464 .31525 .46946 .32537 .49306 .31845 .47597 Mtetra
0 0 .55 r
.31845 .47597 .32537 .49306 .33599 .51203 .32909 .49355 Mtetra
.233 .314 .742 r
.32909 .49355 .33599 .51203 .34736 .52106 .34041 .50289 Mtetra
.577 .528 .764 r
.34041 .50289 .34736 .52106 .35952 .51717 .35243 .50147 Mtetra
.741 .636 .743 r
.35243 .50147 .35952 .51717 .37229 .50107 .36501 .48983 Mtetra
.834 .714 .732 r
.36501 .48983 .37229 .50107 .38538 .47668 .37791 .47113 Mtetra
.901 .799 .738 r
.37791 .47113 .38538 .47668 .39849 .44926 .39088 .44954 Mtetra
.947 .907 .749 r
.39088 .44954 .39849 .44926 .41143 .42323 .40375 .42852 Mtetra
.891 .981 .698 r
.40375 .42852 .41143 .42323 .42415 .40109 .41647 .40991 Mtetra
.621 .861 .5 r
.41647 .40991 .42415 .40109 .43666 .38337 .42905 .39397 Mtetra
0 0 0 r
.42905 .39397 .43666 .38337 .44903 .36939 .44155 .38015 Mtetra
.44155 .38015 .44903 .36939 .46133 .3581 .45399 .36773 Mtetra
.45399 .36773 .46133 .3581 .4736 .34869 .46641 .35643 Mtetra
.46641 .35643 .4736 .34869 .48587 .34085 .47881 .3465 Mtetra
.47881 .3465 .48587 .34085 .49815 .3348 .4912 .33875 Mtetra
.4912 .33875 .49815 .3348 .51045 .33119 .50359 .33434 Mtetra
.259 0 0 r
.50359 .33434 .51045 .33119 .52282 .33099 .51602 .33467 Mtetra
.582 .055 0 r
.51602 .33467 .52282 .33099 .53529 .3353 .52856 .34103 Mtetra
.726 .268 .162 r
.52856 .34103 .53529 .3353 .54792 .34504 .54127 .35424 Mtetra
.773 .362 .273 r
.54127 .35424 .54792 .34504 .56078 .3605 .55424 .37406 Mtetra
.778 .396 .331 r
.55424 .37406 .56078 .3605 .57394 .38083 .56753 .39871 Mtetra
.762 .394 .36 r
.56753 .39871 .57394 .38083 .58741 .4037 .58114 .42462 Mtetra
.725 .364 .366 r
.58114 .42462 .58741 .4037 .60113 .42535 .59498 .44683 Mtetra
.654 .292 .345 r
.59498 .44683 .60113 .42535 .61497 .44127 .60888 .46015 Mtetra
.49 .12 .263 r
.60888 .46015 .61497 .44127 .62873 .4474 .62262 .46076 Mtetra
0 0 0 r
.62262 .46076 .62873 .4474 .64221 .44149 .63599 .44759 Mtetra
.883 .938 .567 r
.63599 .44759 .64221 .44149 .65528 .42394 .6489 .42265 Mtetra
.983 .868 .642 r
.6489 .42265 .65528 .42394 .66791 .39755 .66139 .3902 Mtetra
.951 .79 .645 r
.66139 .3902 .66791 .39755 .68019 .36653 .67359 .35525 Mtetra
.919 .747 .653 r
.67359 .35525 .68019 .36653 .69228 .33512 .68568 .32204 Mtetra
.891 .727 .672 r
.68568 .32204 .69228 .33512 .70438 .30656 .69783 .29331 Mtetra
.864 .72 .701 r
.69783 .29331 .70438 .30656 .71661 .28265 .71017 .27014 Mtetra
.836 .722 .739 r
.71017 .27014 .71661 .28265 .72907 .26382 .72275 .25238 Mtetra
.803 .729 .782 r
.72275 .25238 .72907 .26382 .74179 .24956 .7356 .23912 Mtetra
.767 .736 .824 r
.7356 .23912 .74179 .24956 .75476 .23888 .74867 .22919 Mtetra
.733 .741 .858 r
.74867 .22919 .75476 .23888 .76795 .23072 .76194 .2215 Mtetra
.704 .743 .881 r
.76194 .2215 .76795 .23072 .78129 .22416 .77536 .2152 Mtetra
.685 .743 .895 r
.77536 .2152 .78129 .22416 .79477 .21852 .78889 .20967 Mtetra
.674 .742 .902 r
.78889 .20967 .79477 .21852 .80836 .21337 .80253 .20455 Mtetra
.668 .742 .906 r
.80253 .20455 .80836 .21337 .82202 .20844 .81624 .19961 Mtetra
.661 .741 .909 r
.19357 .40678 .2012 .41388 .21221 .41012 .20461 .40298 Mtetra
.656 .739 .911 r
.20461 .40298 .21221 .41012 .22325 .4065 .21568 .39931 Mtetra
.644 .736 .915 r
.21568 .39931 .22325 .4065 .23431 .40322 .22677 .39594 Mtetra
.617 .726 .924 r
.22677 .39594 .23431 .40322 .24536 .40071 .23785 .39328 Mtetra
.554 .7 .937 r
.23785 .39328 .24536 .40071 .25633 .39973 .24887 .39198 Mtetra
.415 .631 .944 r
.24887 .39198 .25633 .39973 .26715 .4014 .25976 .39304 Mtetra
.136 .458 .887 r
.25976 .39304 .26715 .4014 .27776 .40707 .27044 .39767 Mtetra
0 .162 .691 r
.27044 .39767 .27776 .40707 .2881 .41791 .28089 .40688 Mtetra
0 0 .469 r
.28089 .40688 .2881 .41791 .29822 .43421 .29113 .42098 Mtetra
0 0 .378 r
.29113 .42098 .29822 .43421 .30825 .45464 .30128 .4389 Mtetra
0 0 .437 r
.30128 .4389 .30825 .45464 .31845 .47597 .31156 .45797 Mtetra
0 .032 .597 r
.31156 .45797 .31845 .47597 .32909 .49355 .32222 .47445 Mtetra
.202 .286 .728 r
.32222 .47445 .32909 .49355 .34041 .50289 .33344 .48469 Mtetra
.494 .48 .771 r
.33344 .48469 .34041 .50289 .35243 .50147 .34526 .48667 Mtetra
.672 .615 .783 r
.34526 .48667 .35243 .50147 .36501 .48983 .35758 .48071 Mtetra
.795 .742 .804 r
.35758 .48071 .36501 .48983 .37791 .47113 .37021 .46913 Mtetra
.888 .906 .834 r
.37021 .46913 .37791 .47113 .39088 .44954 .38295 .4549 Mtetra
.78 .978 .705 r
.38295 .4549 .39088 .44954 .40375 .42852 .39569 .44033 Mtetra
0 0 0 r
.39569 .44033 .40375 .42852 .41647 .40991 .40838 .42644 Mtetra
.40838 .42644 .41647 .40991 .42905 .39397 .42103 .41311 Mtetra
.082 0 .088 r
.42103 .41311 .42905 .39397 .44155 .38015 .43367 .39977 Mtetra
.087 0 .1 r
.43367 .39977 .44155 .38015 .45399 .36773 .4463 .38608 Mtetra
.051 0 .067 r
.4463 .38608 .45399 .36773 .46641 .35643 .45892 .37232 Mtetra
.011 0 .009 r
.45892 .37232 .46641 .35643 .47881 .3465 .47151 .35949 Mtetra
.021 0 0 r
.47151 .35949 .47881 .3465 .4912 .33875 .48405 .34912 Mtetra
.154 0 0 r
.48405 .34912 .4912 .33875 .50359 .33434 .49657 .34305 Mtetra
.408 0 .033 r
.49657 .34305 .50359 .33434 .51602 .33467 .5091 .34318 Mtetra
.626 .176 .163 r
.5091 .34318 .51602 .33467 .52856 .34103 .52171 .35097 Mtetra
.735 .32 .262 r
.52171 .35097 .52856 .34103 .54127 .35424 .5345 .36701 Mtetra
.775 .388 .322 r
.5345 .36701 .54127 .35424 .55424 .37406 .54757 .39036 Mtetra
.779 .409 .355 r
.54757 .39036 .55424 .37406 .56753 .39871 .56098 .4181 Mtetra
.761 .398 .367 r
.56098 .4181 .56753 .39871 .58114 .42462 .5747 .44536 Mtetra
.715 .351 .358 r
.5747 .44536 .58114 .42462 .59498 .44683 .58862 .46612 Mtetra
.61 .235 .307 r
.58862 .46612 .59498 .44683 .60888 .46015 .60253 .47488 Mtetra
.275 0 .108 r
.60253 .47488 .60888 .46015 .62262 .46076 .6162 .46853 Mtetra
.734 .893 .501 r
.6162 .46853 .62262 .46076 .63599 .44759 .62945 .4475 Mtetra
.985 .883 .642 r
.62945 .4475 .63599 .44759 .6489 .42265 .64223 .41548 Mtetra
.955 .788 .635 r
.64223 .41548 .6489 .42265 .66139 .3902 .65462 .37797 Mtetra
.921 .737 .636 r
.65462 .37797 .66139 .3902 .67359 .35525 .66679 .34032 Mtetra
.893 .711 .648 r
.66679 .34032 .67359 .35525 .68568 .32204 .67892 .30649 Mtetra
.868 .699 .67 r
.67892 .30649 .68568 .32204 .69783 .29331 .69117 .27851 Mtetra
.842 .698 .703 r
.69117 .27851 .69783 .29331 .71017 .27014 .70364 .25674 Mtetra
.815 .704 .743 r
.70364 .25674 .71017 .27014 .72275 .25238 .71637 .24044 Mtetra
.783 .715 .788 r
.71637 .24044 .72275 .25238 .7356 .23912 .72934 .22839 Mtetra
.75 .726 .83 r
.72934 .22839 .7356 .23912 .74867 .22919 .74252 .21932 Mtetra
.72 .734 .862 r
.74252 .21932 .74867 .22919 .76194 .2215 .75588 .21217 Mtetra
.696 .739 .884 r
.75588 .21217 .76194 .2215 .77536 .2152 .76937 .20614 Mtetra
.681 .741 .896 r
.76937 .20614 .77536 .2152 .78889 .20967 .78296 .20074 Mtetra
.672 .741 .903 r
.78296 .20074 .78889 .20967 .80253 .20455 .79665 .19565 Mtetra
.667 .741 .906 r
.79665 .19565 .80253 .20455 .81624 .19961 .81042 .19069 Mtetra
.661 .741 .909 r
.18589 .39962 .19357 .40678 .20461 .40298 .19695 .39578 Mtetra
.657 .739 .91 r
.19695 .39578 .20461 .40298 .21568 .39931 .20805 .39205 Mtetra
.647 .736 .914 r
.20805 .39205 .21568 .39931 .22677 .39594 .21918 .3886 Mtetra
.623 .727 .921 r
.21918 .3886 .22677 .39594 .23785 .39328 .23029 .38575 Mtetra
.571 .705 .933 r
.23029 .38575 .23785 .39328 .24887 .39198 .24136 .38409 Mtetra
.461 .65 .941 r
.24136 .38409 .24887 .39198 .25976 .39304 .25232 .38448 Mtetra
.249 .52 .912 r
.25232 .38448 .25976 .39304 .27044 .39767 .2631 .38795 Mtetra
0 .291 .789 r
.2631 .38795 .27044 .39767 .28089 .40688 .27367 .39543 Mtetra
0 .059 .618 r
.27367 .39543 .28089 .40688 .29113 .42098 .28405 .40722 Mtetra
0 0 .523 r
.28405 .40722 .29113 .42098 .30128 .4389 .29433 .42254 Mtetra
0 0 .541 r
.29433 .42254 .30128 .4389 .31156 .45797 .30471 .43939 Mtetra
0 .079 .627 r
.30471 .43939 .31156 .45797 .32222 .47445 .31537 .4549 Mtetra
.151 .247 .71 r
.31537 .4549 .32222 .47445 .33344 .48469 .32646 .46635 Mtetra
.367 .403 .766 r
.32646 .46635 .33344 .48469 .34526 .48667 .33804 .4722 Mtetra
.522 .545 .821 r
.33804 .4722 .34526 .48667 .35758 .48071 .35004 .47264 Mtetra
.636 .729 .916 r
.35004 .47264 .35758 .48071 .37021 .46913 .36231 .46914 Mtetra
.582 .937 .93 r
.36231 .46914 .37021 .46913 .38295 .4549 .37475 .4635 Mtetra
0 0 0 r
.37475 .4635 .38295 .4549 .39569 .44033 .38727 .45679 Mtetra
.225 0 .106 r
.38727 .45679 .39569 .44033 .40838 .42644 .39987 .44905 Mtetra
.275 0 .21 r
.39987 .44905 .40838 .42644 .42103 .41311 .41257 .43955 Mtetra
.261 0 .238 r
.41257 .43955 .42103 .41311 .43367 .39977 .42535 .42756 Mtetra
.216 0 .231 r
.42535 .42756 .43367 .39977 .4463 .38608 .4382 .41298 Mtetra
.159 0 .202 r
.4382 .41298 .4463 .38608 .45892 .37232 .45107 .39666 Mtetra
.115 0 .164 r
.45107 .39666 .45892 .37232 .47151 .35949 .4639 .38039 Mtetra
.122 0 .132 r
.4639 .38039 .47151 .35949 .48405 .34912 .47666 .36658 Mtetra
.227 0 .134 r
.47666 .36658 .48405 .34912 .49657 .34305 .48935 .35787 Mtetra
.427 .032 .184 r
.48935 .35787 .49657 .34305 .5091 .34318 .502 .35665 Mtetra
.617 .212 .253 r
.502 .35665 .5091 .34318 .52171 .35097 .51471 .36456 Mtetra
.725 .333 .307 r
.51471 .36456 .52171 .35097 .5345 .36701 .52759 .38181 Mtetra
.771 .393 .339 r
.52759 .38181 .5345 .36701 .54757 .39036 .54074 .40665 Mtetra
.781 .41 .352 r
.54074 .40665 .54757 .39036 .56098 .4181 .55422 .43499 Mtetra
.764 .39 .346 r
.55422 .43499 .56098 .4181 .5747 .44536 .568 .46084 Mtetra
.706 .314 .303 r
.568 .46084 .5747 .44536 .58862 .46612 .58194 .47755 Mtetra
.491 .051 .13 r
.58194 .47755 .58862 .46612 .60253 .47488 .59581 .4799 Mtetra
.641 .916 .624 r
.59581 .4799 .60253 .47488 .6162 .46853 .60939 .46594 Mtetra
.967 .87 .688 r
.60939 .46594 .6162 .46853 .62945 .4475 .62254 .43773 Mtetra
.936 .762 .641 r
.62254 .43773 .62945 .4475 .64223 .41548 .63523 .40033 Mtetra
.907 .712 .628 r
.63523 .40033 .64223 .41548 .65462 .37797 .64758 .35987 Mtetra
.884 .687 .631 r
.64758 .35987 .65462 .37797 .66679 .34032 .65979 .32156 Mtetra
.863 .675 .647 r
.65979 .32156 .66679 .34032 .67892 .30649 .67202 .28872 Mtetra
.842 .673 .673 r
.67202 .28872 .67892 .30649 .69117 .27851 .68442 .26258 Mtetra
.819 .679 .709 r
.68442 .26258 .69117 .27851 .70364 .25674 .69705 .24283 Mtetra
.793 .691 .752 r
.69705 .24283 .70364 .25674 .71637 .24044 .70993 .22831 Mtetra
.764 .706 .798 r
.70993 .22831 .71637 .24044 .72934 .22839 .72303 .21759 Mtetra
.734 .72 .838 r
.72303 .21759 .72934 .22839 .74252 .21932 .73633 .20941 Mtetra
.707 .73 .868 r
.73633 .20941 .74252 .21932 .75588 .21217 .74977 .20277 Mtetra
.688 .736 .887 r
.74977 .20277 .75588 .21217 .76937 .20614 .76332 .19702 Mtetra
.676 .739 .898 r
.76332 .19702 .76937 .20614 .78296 .20074 .77698 .19173 Mtetra
.67 .741 .903 r
.77698 .19173 .78296 .20074 .79665 .19565 .79072 .18667 Mtetra
.666 .741 .906 r
.79072 .18667 .79665 .19565 .81042 .19069 .80454 .1817 Mtetra
.662 .741 .909 r
.17814 .3924 .18589 .39962 .19695 .39578 .18923 .38852 Mtetra
.658 .74 .91 r
.18923 .38852 .19695 .39578 .20805 .39205 .20036 .38474 Mtetra
.649 .736 .913 r
.20036 .38474 .20805 .39205 .21918 .3886 .21152 .38118 Mtetra
.63 .729 .919 r
.21152 .38118 .21918 .3886 .23029 .38575 .22268 .37813 Mtetra
.588 .71 .928 r
.22268 .37813 .23029 .38575 .24136 .38409 .2338 .37608 Mtetra
.503 .667 .936 r
.2338 .37608 .24136 .38409 .25232 .38448 .24483 .37576 Mtetra
.348 .572 .924 r
.24483 .37576 .25232 .38448 .2631 .38795 .25572 .37805 Mtetra
.118 .404 .854 r
.25572 .37805 .2631 .38795 .27367 .39543 .26642 .38373 Mtetra
0 .211 .736 r
.26642 .38373 .27367 .39543 .28405 .40722 .27695 .39314 Mtetra
0 .087 .646 r
.27695 .39314 .28405 .40722 .29433 .42254 .28739 .40581 Mtetra
0 .067 .626 r
.28739 .40581 .29433 .42254 .30471 .43939 .29787 .42034 Mtetra
0 .125 .653 r
.29787 .42034 .30471 .43939 .31537 .4549 .30854 .43475 Mtetra
.114 .216 .693 r
.30854 .43475 .31537 .4549 .32646 .46635 .31952 .44719 Mtetra
.229 .305 .735 r
.31952 .44719 .32646 .46635 .33804 .4722 .33086 .45667 Mtetra
.28 .39 .796 r
.33086 .45667 .33804 .4722 .35004 .47264 .3425 .46331 Mtetra
.197 .481 .895 r
.3425 .46331 .35004 .47264 .36231 .46914 .35438 .46796 Mtetra
.268 0 0 r
.35438 .46796 .36231 .46914 .37475 .4635 .36644 .47135 Mtetra
.467 0 .035 r
.36644 .47135 .37475 .4635 .38727 .45679 .37867 .47339 Mtetra
.457 .072 .219 r
.37867 .47339 .38727 .45679 .39987 .44905 .39111 .47305 Mtetra
.411 .071 .276 r
.39111 .47305 .39987 .44905 .41257 .43955 .40377 .46884 Mtetra
.345 .034 .287 r
.40377 .46884 .41257 .43955 .42535 .42756 .41666 .4596 Mtetra
.267 0 .272 r
.41666 .4596 .42535 .42756 .4382 .41298 .42972 .44523 Mtetra
.188 0 .243 r
.42972 .44523 .4382 .41298 .45107 .39666 .44286 .42702 Mtetra
.131 0 .211 r
.44286 .42702 .45107 .39666 .4639 .38039 .45597 .40748 Mtetra
.13 0 .189 r
.45597 .40748 .4639 .38039 .47666 .36658 .46899 .38992 Mtetra
.219 0 .196 r
.46899 .38992 .47666 .36658 .48935 .35787 .4819 .37777 Mtetra
.397 .039 .235 r
.4819 .37777 .48935 .35787 .502 .35665 .49472 .37395 Mtetra
.582 .2 .283 r
.49472 .37395 .502 .35665 .51471 .36456 .50755 .38017 Mtetra
.703 .318 .316 r
.50755 .38017 .51471 .36456 .52759 .38181 .52051 .39625 Mtetra
.764 .38 .328 r
.52051 .39625 .52759 .38181 .54074 .40665 .53373 .41961 Mtetra
.784 .395 .318 r
.53373 .41961 .54074 .40665 .55422 .43499 .54725 .44524 Mtetra
.77 .357 .268 r
.54725 .44524 .55422 .43499 .568 .46084 .56103 .46646 Mtetra
.658 .166 .07 r
.56103 .46646 .568 .46084 .58194 .47755 .57493 .47668 Mtetra
.519 .908 .934 r
.57493 .47668 .58194 .47755 .59581 .4799 .58872 .47154 Mtetra
.892 .796 .747 r
.58872 .47154 .59581 .4799 .60939 .46594 .6022 .45056 Mtetra
.885 .707 .656 r
.6022 .45056 .60939 .46594 .62254 .43773 .61526 .41714 Mtetra
.872 .671 .628 r
.61526 .41714 .62254 .43773 .63523 .40033 .62793 .37709 Mtetra
.86 .654 .622 r
.62793 .37709 .63523 .40033 .64758 .35987 .64033 .33644 Mtetra
.847 .646 .63 r
.64033 .33644 .64758 .35987 .65979 .32156 .65265 .29978 Mtetra
.833 .646 .649 r
.65265 .29978 .65979 .32156 .67202 .28872 .66505 .26952 Mtetra
.817 .653 .679 r
.66505 .26952 .67202 .28872 .68442 .26258 .67763 .24617 Mtetra
.796 .666 .719 r
.67763 .24617 .68442 .26258 .69705 .24283 .69043 .22889 Mtetra
.772 .684 .766 r
.69043 .22889 .69705 .24283 .70993 .22831 .70346 .21629 Mtetra
.744 .702 .811 r
.70346 .21629 .70993 .22831 .72303 .21759 .7167 .2069 Mtetra
.718 .718 .849 r
.7167 .2069 .72303 .21759 .73633 .20941 .73009 .19954 Mtetra
.696 .729 .875 r
.73009 .19954 .73633 .20941 .74977 .20277 .74361 .19338 Mtetra
.681 .735 .891 r
.74361 .19338 .74977 .20277 .76332 .19702 .75723 .18785 Mtetra
.673 .739 .9 r
.75723 .18785 .76332 .19702 .77698 .19173 .77095 .18266 Mtetra
.668 .74 .904 r
.77095 .18266 .77698 .19173 .79072 .18667 .78474 .17762 Mtetra
.665 .741 .906 r
.78474 .17762 .79072 .18667 .80454 .1817 .7986 .17264 Mtetra
.662 .741 .909 r
.17033 .38512 .17814 .3924 .18923 .38852 .18145 .38121 Mtetra
.659 .74 .91 r
.18145 .38121 .18923 .38852 .20036 .38474 .19261 .37736 Mtetra
.652 .737 .912 r
.19261 .37736 .20036 .38474 .21152 .38118 .2038 .37369 Mtetra
.636 .731 .916 r
.2038 .37369 .21152 .38118 .22268 .37813 .215 .37044 Mtetra
.604 .716 .923 r
.215 .37044 .22268 .37813 .2338 .37608 .22618 .36801 Mtetra
.541 .682 .93 r
.22618 .36801 .2338 .37608 .24483 .37576 .23729 .36697 Mtetra
.43 .613 .926 r
.23729 .36697 .24483 .37576 .25572 .37805 .24828 .36806 Mtetra
.267 .493 .889 r
.24828 .36806 .25572 .37805 .26642 .38373 .25913 .37195 Mtetra
.1 .344 .814 r
.25913 .37195 .26642 .38373 .27695 .39314 .26983 .37898 Mtetra
.001 .227 .737 r
.26983 .37898 .27695 .39314 .28739 .40581 .28044 .38893 Mtetra
0 .177 .694 r
.28044 .38893 .28739 .40581 .29787 .42034 .29105 .40095 Mtetra
.053 .182 .681 r
.29105 .40095 .29787 .42034 .30854 .43475 .30177 .41383 Mtetra
.117 .21 .685 r
.30177 .41383 .30854 .43475 .31952 .44719 .31268 .42652 Mtetra
.145 .233 .697 r
.31268 .42652 .31952 .44719 .33086 .45667 .3238 .43854 Mtetra
.093 .231 .716 r
.3238 .43854 .33086 .45667 .3425 .46331 .33512 .45012 Mtetra
0 .164 .703 r
.33512 .45012 .3425 .46331 .35438 .46796 .34662 .4617 Mtetra
.575 .045 0 r
.34662 .4617 .35438 .46796 .36644 .47135 .35828 .47327 Mtetra
.696 .187 .022 r
.35828 .47327 .36644 .47135 .37867 .47339 .37018 .4838 Mtetra
.618 .188 .203 r
.37018 .4838 .37867 .47339 .39111 .47305 .38237 .49134 Mtetra
.514 .137 .263 r
.38237 .49134 .39111 .47305 .40377 .46884 .39492 .49353 Mtetra
.397 .059 .27 r
.39492 .49353 .40377 .46884 .41666 .4596 .40782 .48861 Mtetra
.272 0 .25 r
.40782 .48861 .41666 .4596 .42972 .44523 .42103 .47618 Mtetra
.155 0 .216 r
.42103 .47618 .42972 .44523 .44286 .42702 .43439 .45765 Mtetra
.075 0 .182 r
.43439 .45765 .44286 .42702 .45597 .40748 .44778 .43602 Mtetra
.062 0 .166 r
.44778 .43602 .45597 .40748 .46899 .38992 .46108 .41528 Mtetra
.147 0 .178 r
.46108 .41528 .46899 .38992 .4819 .37777 .47423 .39956 Mtetra
.324 0 .219 r
.47423 .39956 .4819 .37777 .49472 .37395 .48724 .3922 Mtetra
.522 .143 .263 r
.48724 .3922 .49472 .37395 .50755 .38017 .50022 .39493 Mtetra
.667 .27 .284 r
.50022 .39493 .50755 .38017 .52051 .39625 .51329 .40724 Mtetra
.748 .338 .272 r
.51329 .40724 .52051 .39625 .53373 .41961 .52656 .42594 Mtetra
.781 .34 .204 r
.52656 .42594 .53373 .41961 .54725 .44524 .54009 .44555 Mtetra
.719 .193 0 r
.54009 .44555 .54725 .44524 .56103 .46646 .55383 .45941 Mtetra
.292 .619 .959 r
.55383 .45941 .56103 .46646 .57493 .47668 .56764 .46166 Mtetra
.757 .669 .765 r
.56764 .46166 .57493 .47668 .58872 .47154 .58133 .44925 Mtetra
.808 .635 .667 r
.58133 .44925 .58872 .47154 .6022 .45056 .59472 .42304 Mtetra
.821 .62 .631 r
.59472 .42304 .6022 .45056 .61526 .41714 .60774 .38725 Mtetra
.823 .613 .619 r
.60774 .38725 .61526 .41714 .62793 .37709 .62045 .34762 Mtetra
.821 .612 .621 r
.62045 .34762 .62793 .37709 .64033 .33644 .63297 .30947 Mtetra
.815 .616 .633 r
.63297 .30947 .64033 .33644 .65265 .29978 .64546 .27641 Mtetra
.806 .625 .657 r
.64546 .27641 .65265 .29978 .66505 .26952 .65805 .24996 Mtetra
.793 .639 .692 r
.65805 .24996 .66505 .26952 .67763 .24617 .67082 .22998 Mtetra
.775 .659 .736 r
.67082 .22998 .67763 .24617 .69043 .22889 .6838 .21534 Mtetra
.752 .682 .784 r
.6838 .21534 .69043 .22889 .70346 .21629 .69698 .20461 Mtetra
.726 .703 .828 r
.69698 .20461 .70346 .21629 .7167 .2069 .71033 .19643 Mtetra
.704 .719 .861 r
.71033 .19643 .7167 .2069 .73009 .19954 .72381 .18979 Mtetra
.686 .729 .883 r
.72381 .18979 .73009 .19954 .74361 .19338 .73741 .184 Mtetra
.676 .735 .895 r
.73741 .184 .74361 .19338 .75723 .18785 .75109 .17866 Mtetra
.67 .739 .902 r
.75109 .17866 .75723 .18785 .77095 .18266 .76486 .17353 Mtetra
.666 .74 .905 r
.76486 .17353 .77095 .18266 .78474 .17762 .7787 .16849 Mtetra
.665 .741 .907 r
.7787 .16849 .78474 .17762 .7986 .17264 .79262 .16349 Mtetra
.662 .741 .908 r
.16246 .37779 .17033 .38512 .18145 .38121 .17361 .37383 Mtetra
.66 .74 .909 r
.17361 .37383 .18145 .38121 .19261 .37736 .1848 .36992 Mtetra
.655 .738 .911 r
.1848 .36992 .19261 .37736 .2038 .37369 .19603 .36615 Mtetra
.642 .732 .914 r
.19603 .36615 .2038 .37369 .215 .37044 .20727 .36271 Mtetra
.618 .72 .919 r
.20727 .36271 .215 .37044 .22618 .36801 .2185 .3599 Mtetra
.572 .695 .925 r
.2185 .3599 .22618 .36801 .23729 .36697 .22969 .35818 Mtetra
.495 .645 .923 r
.22969 .35818 .23729 .36697 .24828 .36806 .24079 .35813 Mtetra
.384 .56 .903 r
.24079 .35813 .24828 .36806 .25913 .37195 .25179 .36029 Mtetra
.263 .449 .856 r
.25179 .36029 .25913 .37195 .26983 .37898 .26266 .365 Mtetra
.177 .347 .796 r
.26266 .365 .26983 .37898 .28044 .38893 .27346 .37222 Mtetra
.147 .281 .745 r
.27346 .37222 .28044 .38893 .29105 .40095 .28423 .38152 Mtetra
.156 .251 .712 r
.28423 .38152 .29105 .40095 .30177 .41383 .29504 .3923 Mtetra
.166 .236 .692 r
.29504 .3923 .30177 .41383 .31268 .42652 .30594 .40412 Mtetra
.145 .215 .679 r
.30594 .40412 .31268 .42652 .3238 .43854 .31694 .417 Mtetra
.06 .168 .664 r
.31694 .417 .3238 .43854 .33512 .45012 .32804 .43134 Mtetra
0 .07 .623 r
.32804 .43134 .33512 .45012 .34662 .4617 .33923 .44743 Mtetra
0 0 .493 r
.33923 .44743 .34662 .4617 .35828 .47327 .35056 .46486 Mtetra
.714 .234 0 r
.35056 .46486 .35828 .47327 .37018 .4838 .36212 .4821 Mtetra
.762 .252 0 r
.36212 .4821 .37018 .4838 .38237 .49134 .37402 .49656 Mtetra
.646 .159 .081 r
.37402 .49656 .38237 .49134 .39492 .49353 .38637 .50525 Mtetra
.438 .001 .108 r
.38637 .50525 .39492 .49353 .40782 .48861 .39919 .50571 Mtetra
.193 0 .082 r
.39919 .50571 .40782 .48861 .42103 .47618 .41242 .49703 Mtetra
0 0 .04 r
.41242 .49703 .42103 .47618 .43439 .45765 .42591 .48035 Mtetra
0 0 .009 r
.42591 .48035 .43439 .45765 .44778 .43602 .4395 .45872 Mtetra
0 0 .005 r
.4395 .45872 .44778 .43602 .46108 .41528 .45303 .43643 Mtetra
0 0 .036 r
.45303 .43643 .46108 .41528 .47423 .39956 .46641 .41797 Mtetra
.149 0 .094 r
.46641 .41797 .47423 .39956 .48724 .3922 .47964 .40691 Mtetra
.395 0 .148 r
.47964 .40691 .48724 .3922 .50022 .39493 .49278 .40501 Mtetra
.587 .138 .154 r
.49278 .40501 .50022 .39493 .51329 .40724 .50596 .41152 Mtetra
.69 .194 .062 r
.50596 .41152 .51329 .40724 .52656 .42594 .51928 .4231 Mtetra
.603 .038 0 r
.51928 .4231 .52656 .42594 .54009 .44555 .5328 .43439 Mtetra
.264 .483 .883 r
.5328 .43439 .54009 .44555 .55383 .45941 .54647 .43948 Mtetra
.641 .563 .752 r
.54647 .43948 .55383 .45941 .56764 .46166 .56018 .43374 Mtetra
.729 .567 .671 r
.56018 .43374 .56764 .46166 .58133 .44925 .57376 .41555 Mtetra
.764 .569 .635 r
.57376 .41555 .58133 .44925 .59472 .42304 .58708 .38669 Mtetra
.78 .573 .619 r
.58708 .38669 .59472 .42304 .60774 .38725 .60011 .35147 Mtetra
.787 .578 .617 r
.60011 .35147 .60774 .38725 .62045 .34762 .6129 .31495 Mtetra
.79 .585 .624 r
.6129 .31495 .62045 .34762 .63297 .30947 .62558 .28134 Mtetra
.788 .596 .642 r
.62558 .28134 .63297 .30947 .64546 .27641 .63827 .25313 Mtetra
.782 .613 .67 r
.63827 .25313 .64546 .27641 .65805 .24996 .65106 .23107 Mtetra
.771 .634 .71 r
.65106 .23107 .65805 .24996 .67082 .22998 .66403 .21459 Mtetra
.754 .66 .757 r
.66403 .21459 .67082 .22998 .6838 .21534 .67717 .20248 Mtetra
.732 .685 .805 r
.67717 .20248 .6838 .21534 .69698 .20461 .69048 .1934 Mtetra
.71 .707 .845 r
.69048 .1934 .69698 .20461 .71033 .19643 .70393 .18623 Mtetra
.691 .722 .873 r
.70393 .18623 .71033 .19643 .72381 .18979 .7175 .18015 Mtetra
.679 .731 .89 r
.7175 .18015 .72381 .18979 .73741 .184 .73116 .17465 Mtetra
.671 .736 .899 r
.73116 .17465 .73741 .184 .75109 .17866 .7449 .16943 Mtetra
.667 .739 .904 r
.7449 .16943 .75109 .17866 .76486 .17353 .75872 .16434 Mtetra
.665 .74 .906 r
.75872 .16434 .76486 .17353 .7787 .16849 .77262 .1593 Mtetra
.664 .741 .907 r
.77262 .1593 .7787 .16849 .79262 .16349 .78658 .15426 Mtetra
.663 .741 .908 r
.15452 .37039 .16246 .37779 .17361 .37383 .1657 .36639 Mtetra
.661 .74 .909 r
.1657 .36639 .17361 .37383 .1848 .36992 .17692 .36243 Mtetra
.657 .738 .91 r
.17692 .36243 .1848 .36992 .19603 .36615 .18818 .35856 Mtetra
.648 .734 .912 r
.18818 .35856 .19603 .36615 .20727 .36271 .19947 .35494 Mtetra
.63 .725 .916 r
.19947 .35494 .20727 .36271 .2185 .3599 .21076 .35179 Mtetra
.597 .706 .919 r
.21076 .35179 .2185 .3599 .22969 .35818 .22202 .34945 Mtetra
.545 .669 .919 r
.22202 .34945 .22969 .35818 .24079 .35813 .23323 .34837 Mtetra
.47 .61 .907 r
.23323 .34837 .24079 .35813 .25179 .36029 .24437 .34896 Mtetra
.387 .529 .877 r
.24437 .34896 .25179 .36029 .26266 .365 .25542 .35151 Mtetra
.319 .444 .831 r
.25542 .35151 .26266 .365 .27346 .37222 .2664 .3561 Mtetra
.28 .376 .783 r
.2664 .3561 .27346 .37222 .28423 .38152 .27736 .36257 Mtetra
.262 .327 .742 r
.27736 .36257 .28423 .38152 .29504 .3923 .28831 .37072 Mtetra
.243 .287 .709 r
.28831 .37072 .29504 .3923 .30594 .40412 .29929 .38058 Mtetra
.203 .244 .682 r
.29929 .38058 .30594 .40412 .31694 .417 .31029 .3925 Mtetra
.125 .184 .654 r
.31029 .3925 .31694 .417 .32804 .43134 .32129 .40704 Mtetra
.002 .103 .617 r
.32129 .40704 .32804 .43134 .33923 .44743 .33232 .42454 Mtetra
0 .01 .568 r
.33232 .42454 .33923 .44743 .35056 .46486 .34343 .44451 Mtetra
0 0 .523 r
.34343 .44451 .35056 .46486 .36212 .4821 .35474 .46534 Mtetra
0 0 .519 r
.35474 .46534 .36212 .4821 .37402 .49656 .36638 .48428 Mtetra
0 .053 .613 r
.36638 .48428 .37402 .49656 .38637 .50525 .37849 .49805 Mtetra
0 .412 .848 r
.37849 .49805 .38637 .50525 .39919 .50571 .39113 .50376 Mtetra
.515 .883 .977 r
.39113 .50376 .39919 .50571 .41242 .49703 .40426 .49992 Mtetra
.785 .997 .803 r
.40426 .49992 .41242 .49703 .42591 .48035 .41774 .4871 Mtetra
.827 .967 .648 r
.41774 .4871 .42591 .48035 .4395 .45872 .4314 .46791 Mtetra
.785 .925 .553 r
.4314 .46791 .4395 .45872 .45303 .43643 .44506 .4464 Mtetra
.669 .869 .485 r
.44506 .4464 .45303 .43643 .46641 .41797 .4586 .42694 Mtetra
0 0 0 r
.4586 .42694 .46641 .41797 .47964 .40691 .472 .41307 Mtetra
.472 .41307 .47964 .40691 .49278 .40501 .48529 .40648 Mtetra
.107 0 0 r
.48529 .40648 .49278 .40501 .50596 .41152 .49857 .40646 Mtetra
.061 .535 .894 r
.49857 .40646 .50596 .41152 .51928 .4231 .51195 .40994 Mtetra
.431 .536 .863 r
.51195 .40994 .51928 .4231 .5328 .43439 .52545 .41234 Mtetra
.597 .521 .739 r
.52545 .41234 .5328 .43439 .54647 .43948 .53906 .40896 Mtetra
.673 .522 .672 r
.53906 .40896 .54647 .43948 .56018 .43374 .55266 .39667 Mtetra
.714 .529 .638 r
.55266 .39667 .56018 .43374 .57376 .41555 .56614 .375 Mtetra
.738 .538 .622 r
.56614 .375 .57376 .41555 .58708 .38669 .57943 .34614 Mtetra
.753 .547 .617 r
.57943 .34614 .58708 .38669 .60011 .35147 .59249 .31392 Mtetra
.761 .557 .621 r
.59249 .31392 .60011 .35147 .6129 .31495 .6054 .2823 Mtetra
.765 .57 .634 r
.6054 .2823 .6129 .31495 .62558 .28134 .61825 .25427 Mtetra
.765 .587 .657 r
.61825 .25427 .62558 .28134 .63827 .25313 .63113 .23133 Mtetra
.761 .61 .691 r
.63113 .23133 .63827 .25313 .65106 .23107 .64412 .21361 Mtetra
.751 .637 .735 r
.64412 .21361 .65106 .23107 .66403 .21459 .65726 .20036 Mtetra
.735 .667 .784 r
.65726 .20036 .66403 .21459 .67717 .20248 .67054 .19042 Mtetra
.715 .693 .828 r
.67054 .19042 .67717 .20248 .69048 .1934 .68396 .1827 Mtetra
.696 .713 .862 r
.68396 .1827 .69048 .1934 .70393 .18623 .6975 .1763 Mtetra
.682 .726 .884 r
.6975 .1763 .70393 .18623 .7175 .18015 .71114 .17062 Mtetra
.673 .733 .896 r
.71114 .17062 .7175 .18015 .73116 .17465 .72486 .16531 Mtetra
.668 .738 .902 r
.72486 .16531 .73116 .17465 .7449 .16943 .73866 .16017 Mtetra
.666 .74 .905 r
.73866 .16017 .7449 .16943 .75872 .16434 .75253 .15509 Mtetra
.665 .741 .907 r
.75253 .15509 .75872 .16434 .77262 .1593 .76648 .15002 Mtetra
.664 .741 .907 r
.76648 .15002 .77262 .1593 .78658 .15426 .78049 .14496 Mtetra
.663 .741 .908 r
.14652 .36294 .15452 .37039 .1657 .36639 .15773 .3589 Mtetra
.662 .74 .909 r
.15773 .3589 .1657 .36639 .17692 .36243 .16898 .35488 Mtetra
.659 .739 .909 r
.16898 .35488 .17692 .36243 .18818 .35856 .18028 .35093 Mtetra
.652 .736 .911 r
.18028 .35093 .18818 .35856 .19947 .35494 .1916 .34715 Mtetra
.64 .729 .913 r
.1916 .34715 .19947 .35494 .21076 .35179 .20294 .3437 Mtetra
.617 .715 .915 r
.20294 .3437 .21076 .35179 .22202 .34945 .21428 .34083 Mtetra
.582 .689 .915 r
.21428 .34083 .22202 .34945 .23323 .34837 .22559 .33886 Mtetra
.533 .647 .907 r
.22559 .33886 .23323 .34837 .24437 .34896 .23686 .33809 Mtetra
.478 .588 .886 r
.23686 .33809 .24437 .34896 .25542 .35151 .24807 .33876 Mtetra
.427 .522 .852 r
.24807 .33876 .25542 .35151 .2664 .3561 .25924 .34095 Mtetra
.389 .458 .811 r
.25924 .34095 .2664 .3561 .27736 .36257 .27039 .34468 Mtetra
.361 .403 .77 r
.27039 .34468 .27736 .36257 .28831 .37072 .28152 .34997 Mtetra
.33 .352 .733 r
.28152 .34997 .28831 .37072 .29929 .38058 .29265 .3571 Mtetra
.285 .299 .7 r
.29265 .3571 .29929 .38058 .31029 .3925 .30375 .36659 Mtetra
.221 .238 .667 r
.30375 .36659 .31029 .3925 .32129 .40704 .3148 .37913 Mtetra
.142 .173 .633 r
.3148 .37913 .32129 .40704 .33232 .42454 .32582 .39512 Mtetra
.072 .116 .602 r
.32582 .39512 .33232 .42454 .34343 .44451 .33687 .41422 Mtetra
.039 .09 .588 r
.33687 .41422 .34343 .44451 .35474 .46534 .34806 .43505 Mtetra
.069 .113 .6 r
.34806 .43505 .35474 .46534 .36638 .48428 .35954 .45512 Mtetra
.173 .194 .641 r
.35954 .45512 .36638 .48428 .37849 .49805 .37145 .47134 Mtetra
.338 .322 .694 r
.37145 .47134 .37849 .49805 .39113 .50376 .38387 .48078 Mtetra
.522 .467 .736 r
.38387 .48078 .39113 .50376 .40426 .49992 .39679 .48156 Mtetra
.68 .596 .754 r
.39679 .48156 .40426 .49992 .41774 .4871 .41012 .47359 Mtetra
.793 .695 .757 r
.41012 .47359 .41774 .4871 .4314 .46791 .4237 .4587 Mtetra
.86 .769 .76 r
.4237 .4587 .4314 .46791 .44506 .4464 .43736 .4402 Mtetra
.889 .825 .778 r
.43736 .4402 .44506 .4464 .4586 .42694 .45096 .42187 Mtetra
.874 .86 .823 r
.45096 .42187 .4586 .42694 .472 .41307 .46445 .40684 Mtetra
.801 .84 .881 r
.46445 .40684 .472 .41307 .48529 .40648 .47785 .39669 Mtetra
.687 .727 .881 r
.47785 .39669 .48529 .40648 .49857 .40646 .49122 .3909 Mtetra
.621 .598 .806 r
.49122 .3909 .49857 .40646 .51195 .40994 .50463 .38707 Mtetra
.624 .53 .727 r
.50463 .38707 .51195 .40994 .52545 .41234 .51812 .38177 Mtetra
.653 .509 .675 r
.51812 .38177 .52545 .41234 .53906 .40896 .53166 .37176 Mtetra
.682 .508 .644 r
.53166 .37176 .53906 .40896 .55266 .39667 .54517 .35528 Mtetra
.705 .514 .627 r
.54517 .35528 .55266 .39667 .56614 .375 .55859 .33262 Mtetra
.723 .523 .62 r
.55859 .33262 .56614 .375 .57943 .34614 .57186 .30591 Mtetra
.735 .534 .622 r
.57186 .30591 .57943 .34614 .59249 .31392 .58498 .27817 Mtetra
.742 .548 .631 r
.58498 .27817 .59249 .31392 .6054 .2823 .598 .25218 Mtetra
.747 .566 .65 r
.598 .25218 .6054 .2823 .61825 .25427 .61101 .22984 Mtetra
.747 .588 .679 r
.61101 .22984 .61825 .25427 .63113 .23133 .62407 .21184 Mtetra
.743 .617 .718 r
.62407 .21184 .63113 .23133 .64412 .21361 .63722 .19795 Mtetra
.733 .649 .766 r
.63722 .19795 .64412 .21361 .65726 .20036 .6505 .18738 Mtetra
.717 .679 .812 r
.6505 .18738 .65726 .20036 .67054 .19042 .66391 .17916 Mtetra
.699 .704 .851 r
.66391 .17916 .67054 .19042 .68396 .1827 .67742 .17244 Mtetra
.685 .721 .877 r
.67742 .17244 .68396 .1827 .6975 .1763 .69104 .16658 Mtetra
.675 .73 .892 r
.69104 .16658 .6975 .1763 .71114 .17062 .70474 .16117 Mtetra
.669 .736 .9 r
.70474 .16117 .71114 .17062 .72486 .16531 .71852 .15597 Mtetra
.666 .739 .904 r
.71852 .15597 .72486 .16531 .73866 .16017 .73237 .15085 Mtetra
.665 .74 .906 r
.73237 .15085 .73866 .16017 .75253 .15509 .74629 .14576 Mtetra
.664 .741 .907 r
.74629 .14576 .75253 .15509 .76648 .15002 .76028 .14067 Mtetra
.664 .741 .908 r
.76028 .14067 .76648 .15002 .78049 .14496 .77434 .13557 Mtetra
.663 .741 .908 r
.13846 .35543 .14652 .36294 .15773 .3589 .1497 .35135 Mtetra
.662 .741 .908 r
.1497 .35135 .15773 .3589 .16898 .35488 .16098 .34728 Mtetra
.66 .74 .909 r
.16098 .34728 .16898 .35488 .18028 .35093 .1723 .34325 Mtetra
.656 .737 .91 r
.1723 .34325 .18028 .35093 .1916 .34715 .18367 .33933 Mtetra
.647 .732 .911 r
.18367 .33933 .1916 .34715 .20294 .3437 .19506 .33564 Mtetra
.632 .722 .912 r
.19506 .33564 .20294 .3437 .21428 .34083 .20646 .33235 Mtetra
.609 .704 .911 r
.20646 .33235 .21428 .34083 .22559 .33886 .21786 .32966 Mtetra
.578 .674 .905 r
.21786 .32966 .22559 .33886 .23686 .33809 .22924 .32779 Mtetra
.542 .633 .891 r
.22924 .32779 .23686 .33809 .24807 .33876 .2406 .3269 Mtetra
.507 .582 .866 r
.2406 .3269 .24807 .33876 .25924 .34095 .25194 .32707 Mtetra
.476 .529 .832 r
.25194 .32707 .25924 .34095 .27039 .34468 .26327 .32836 Mtetra
.447 .476 .796 r
.26327 .32836 .27039 .34468 .28152 .34997 .2746 .33091 Mtetra
.414 .423 .76 r
.2746 .33091 .28152 .34997 .29265 .3571 .28591 .33504 Mtetra
.371 .367 .725 r
.28591 .33504 .29265 .3571 .30375 .36659 .29718 .34135 Mtetra
.316 .307 .69 r
.29718 .34135 .30375 .36659 .3148 .37913 .30839 .3505 Mtetra
.26 .249 .656 r
.30839 .3505 .3148 .37913 .32582 .39512 .31954 .36296 Mtetra
.219 .203 .626 r
.31954 .36296 .32582 .39512 .33687 .41422 .33068 .37861 Mtetra
.21 .183 .608 r
.33068 .37861 .33687 .41422 .34806 .43505 .3419 .39642 Mtetra
.241 .196 .604 r
.3419 .39642 .34806 .43505 .35954 .45512 .35335 .41447 Mtetra
.307 .238 .613 r
.35335 .41447 .35954 .45512 .37145 .47134 .36513 .43019 Mtetra
.395 .299 .628 r
.36513 .43019 .37145 .47134 .38387 .48078 .37736 .44096 Mtetra
.489 .369 .643 r
.37736 .44096 .38387 .48078 .39679 .48156 .39006 .44488 Mtetra
.576 .438 .656 r
.39006 .44488 .39679 .48156 .41012 .47359 .40316 .44135 Mtetra
.648 .5 .668 r
.40316 .44135 .41012 .47359 .4237 .4587 .41654 .43136 Mtetra
.702 .552 .68 r
.41654 .43136 .4237 .4587 .43736 .4402 .43007 .4172 Mtetra
.734 .591 .696 r
.43007 .4172 .43736 .4402 .45096 .42187 .44361 .40169 Mtetra
.741 .612 .715 r
.44361 .40169 .45096 .42187 .46445 .40684 .45711 .38734 Mtetra
.721 .607 .729 r
.45711 .38734 .46445 .40684 .47785 .39669 .47055 .37544 Mtetra
.687 .576 .725 r
.47055 .37544 .47785 .39669 .49122 .3909 .48396 .36576 Mtetra
.662 .538 .703 r
.48396 .36576 .49122 .3909 .50463 .38707 .49738 .35674 Mtetra
.658 .512 .674 r
.49738 .35674 .50463 .38707 .51812 .38177 .51085 .34616 Mtetra
.669 .503 .651 r
.51085 .34616 .51812 .38177 .53166 .37176 .52433 .33217 Mtetra
.685 .503 .635 r
.52433 .33217 .53166 .37176 .54517 .35528 .53777 .31405 Mtetra
.7 .51 .627 r
.53777 .31405 .54517 .35528 .55859 .33262 .55114 .2925 Mtetra
.712 .52 .627 r
.55114 .2925 .55859 .33262 .57186 .30591 .56441 .26929 Mtetra
.722 .533 .634 r
.56441 .26929 .57186 .30591 .58498 .27817 .57759 .24655 Mtetra
.729 .55 .649 r
.57759 .24655 .58498 .27817 .598 .25218 .59072 .22604 Mtetra
.732 .572 .674 r
.59072 .22604 .598 .25218 .61101 .22984 .60387 .20877 Mtetra
.732 .6 .709 r
.60387 .20877 .61101 .22984 .62407 .21184 .61707 .19492 Mtetra
.727 .632 .753 r
.61707 .19492 .62407 .21184 .63722 .19795 .63036 .18408 Mtetra
.716 .666 .799 r
.63036 .18408 .63722 .19795 .6505 .18738 .64376 .17554 Mtetra
.701 .694 .84 r
.64376 .17554 .6505 .18738 .66391 .17916 .65726 .16855 Mtetra
.687 .715 .87 r
.65726 .16855 .66391 .17916 .67742 .17244 .67085 .16252 Mtetra
.676 .727 .888 r
.67085 .16252 .67742 .17244 .69104 .16658 .68453 .15701 Mtetra
.67 .734 .898 r
.68453 .15701 .69104 .16658 .70474 .16117 .69829 .15175 Mtetra
.666 .738 .903 r
.69829 .15175 .70474 .16117 .71852 .15597 .71212 .1466 Mtetra
.665 .74 .906 r
.71212 .1466 .71852 .15597 .73237 .15085 .72602 .14148 Mtetra
.664 .741 .907 r
.72602 .14148 .73237 .15085 .74629 .14576 .73999 .13637 Mtetra
.73999 .13637 .74629 .14576 .76028 .14067 .75403 .13125 Mtetra
.664 .741 .908 r
.75403 .13125 .76028 .14067 .77434 .13557 .76814 .1261 Mtetra
.663 .741 .908 r
.13033 .34786 .13846 .35543 .1497 .35135 .14159 .34374 Mtetra
.14159 .34374 .1497 .35135 .16098 .34728 .15291 .33962 Mtetra
.661 .74 .908 r
.15291 .33962 .16098 .34728 .1723 .34325 .16426 .33553 Mtetra
.658 .739 .909 r
.16426 .33553 .1723 .34325 .18367 .33933 .17566 .3315 Mtetra
.653 .735 .91 r
.17566 .3315 .18367 .33933 .19506 .33564 .1871 .32762 Mtetra
.643 .728 .91 r
.1871 .32762 .19506 .33564 .20646 .33235 .19855 .32399 Mtetra
.629 .715 .909 r
.19855 .32399 .20646 .33235 .21786 .32966 .21003 .32075 Mtetra
.609 .695 .905 r
.21003 .32075 .21786 .32966 .22924 .32779 .22151 .31804 Mtetra
.586 .667 .894 r
.22151 .31804 .22924 .32779 .2406 .3269 .23299 .31595 Mtetra
.563 .63 .876 r
.23299 .31595 .2406 .3269 .25194 .32707 .24448 .31454 Mtetra
.541 .588 .851 r
.24448 .31454 .25194 .32707 .26327 .32836 .25598 .31386 Mtetra
.517 .542 .821 r
.25598 .31386 .26327 .32836 .2746 .33091 .26749 .31406 Mtetra
.488 .494 .789 r
.26749 .31406 .2746 .33091 .28591 .33504 .27898 .31543 Mtetra
.449 .44 .756 r
.27898 .31543 .28591 .33504 .29718 .34135 .29045 .3185 Mtetra
.403 .382 .722 r
.29045 .3185 .29718 .34135 .30839 .3505 .30187 .32386 Mtetra
.357 .326 .686 r
.30187 .32386 .30839 .3505 .31954 .36296 .31323 .33197 Mtetra
.324 .28 .654 r
.31323 .33197 .31954 .36296 .33068 .37861 .32456 .34288 Mtetra
.315 .255 .63 r
.32456 .34288 .33068 .37861 .3419 .39642 .33594 .35596 Mtetra
.332 .253 .615 r
.33594 .35596 .3419 .39642 .35335 .41447 .34746 .36988 Mtetra
.372 .272 .61 r
.34746 .36988 .35335 .41447 .36513 .43019 .35924 .38275 Mtetra
.425 .305 .612 r
.35924 .38275 .36513 .43019 .37736 .44096 .37136 .39254 Mtetra
.483 .345 .617 r
.37136 .39254 .37736 .44096 .39006 .44488 .38386 .39756 Mtetra
.538 .386 .623 r
.38386 .39756 .39006 .44488 .40316 .44135 .39672 .39701 Mtetra
.587 .427 .632 r
.39672 .39701 .40316 .44135 .41654 .43136 .40987 .39119 Mtetra
.626 .462 .641 r
.40987 .39119 .41654 .43136 .43007 .4172 .42319 .38139 Mtetra
.653 .492 .652 r
.42319 .38139 .43007 .4172 .44361 .40169 .43659 .36946 Mtetra
.668 .511 .663 r
.43659 .36946 .44361 .40169 .45711 .38734 .45 .35708 Mtetra
.67 .52 .672 r
.45 .35708 .45711 .38734 .47055 .37544 .46341 .34522 Mtetra
.665 .517 .673 r
.46341 .34522 .47055 .37544 .48396 .36576 .47681 .33389 Mtetra
.662 .509 .666 r
.47681 .33389 .48396 .36576 .49738 .35674 .49022 .32225 Mtetra
.666 .503 .654 r
.49022 .32225 .49738 .35674 .51085 .34616 .50364 .30917 Mtetra
.674 .502 .644 r
.50364 .30917 .51085 .34616 .52433 .33217 .51707 .29385 Mtetra
.685 .505 .638 r
.51707 .29385 .52433 .33217 .53777 .31405 .53046 .27626 Mtetra
.696 .513 .637 r
.53046 .27626 .53777 .31405 .55114 .2925 .5438 .2572 Mtetra
.706 .525 .642 r
.5438 .2572 .55114 .2925 .56441 .26929 .55708 .238 Mtetra
.713 .541 .655 r
.55708 .238 .56441 .26929 .57759 .24655 .57032 .22001 Mtetra
.719 .562 .676 r
.57032 .22001 .57759 .24655 .59072 .22604 .58354 .20422 Mtetra
.721 .589 .708 r
.58354 .20422 .59072 .22604 .60387 .20877 .5968 .19104 Mtetra
.719 .621 .747 r
.5968 .19104 .60387 .20877 .61707 .19492 .61012 .18036 Mtetra
.712 .655 .791 r
.61012 .18036 .61707 .19492 .63036 .18408 .62352 .17173 Mtetra
.701 .686 .832 r
.62352 .17173 .63036 .18408 .64376 .17554 .637 .1646 Mtetra
.688 .709 .864 r
.637 .1646 .64376 .17554 .65726 .16855 .65058 .15844 Mtetra
.678 .724 .884 r
.65058 .15844 .65726 .16855 .67085 .16252 .66424 .15283 Mtetra
.671 .732 .896 r
.66424 .15283 .67085 .16252 .68453 .15701 .67797 .14751 Mtetra
.667 .737 .902 r
.67797 .14751 .68453 .15701 .69829 .15175 .69178 .14232 Mtetra
.665 .739 .905 r
.69178 .14232 .69829 .15175 .71212 .1466 .70566 .13718 Mtetra
.664 .74 .907 r
.70566 .13718 .71212 .1466 .72602 .14148 .71961 .13205 Mtetra
.664 .741 .907 r
.71961 .13205 .72602 .14148 .73999 .13637 .73363 .1269 Mtetra
.664 .741 .908 r
.73363 .1269 .73999 .13637 .75403 .13125 .74772 .12173 Mtetra
.74772 .12173 .75403 .13125 .76814 .1261 .76188 .11654 Mtetra
.663 .741 .908 r
.12213 .34022 .13033 .34786 .14159 .34374 .13343 .33607 Mtetra
.13343 .33607 .14159 .34374 .15291 .33962 .14477 .33191 Mtetra
.662 .741 .908 r
.14477 .33191 .15291 .33962 .16426 .33553 .15616 .32776 Mtetra
.66 .739 .909 r
.15616 .32776 .16426 .33553 .17566 .3315 .16759 .32364 Mtetra
.657 .737 .909 r
.16759 .32364 .17566 .3315 .1871 .32762 .17906 .31961 Mtetra
.651 .732 .909 r
.17906 .31961 .1871 .32762 .19855 .32399 .19057 .31574 Mtetra
.642 .724 .908 r
.19057 .31574 .19855 .32399 .21003 .32075 .20211 .3121 Mtetra
.63 .711 .905 r
.20211 .3121 .21003 .32075 .22151 .31804 .21367 .30878 Mtetra
.616 .691 .897 r
.21367 .30878 .22151 .31804 .23299 .31595 .22525 .30582 Mtetra
.602 .666 .884 r
.22525 .30582 .23299 .31595 .24448 .31454 .23686 .30326 Mtetra
.588 .636 .866 r
.23686 .30326 .24448 .31454 .25598 .31386 .24849 .30113 Mtetra
.571 .601 .844 r
.24849 .30113 .25598 .31386 .26749 .31406 .26015 .29953 Mtetra
.549 .56 .818 r
.26015 .29953 .26749 .31406 .27898 .31543 .27182 .29869 Mtetra
.518 .513 .79 r
.27182 .29869 .27898 .31543 .29045 .3185 .28348 .29899 Mtetra
.48 .461 .759 r
.28348 .29899 .29045 .3185 .30187 .32386 .29511 .30093 Mtetra
.44 .406 .724 r
.29511 .30093 .30187 .32386 .31323 .33197 .3067 .30489 Mtetra
.408 .357 .69 r
.3067 .30489 .31323 .33197 .32456 .34288 .31827 .31102 Mtetra
.393 .324 .66 r
.31827 .31102 .32456 .34288 .33594 .35596 .32985 .319 Mtetra
.398 .309 .638 r
.32985 .319 .33594 .35596 .34746 .36988 .34154 .32803 Mtetra
.419 .31 .624 r
.34154 .32803 .34746 .36988 .35924 .38275 .35339 .33687 Mtetra
.451 .325 .617 r
.35339 .33687 .35924 .38275 .37136 .39254 .36549 .3441 Mtetra
.488 .347 .615 r
.36549 .3441 .37136 .39254 .38386 .39756 .37788 .34843 Mtetra
.525 .373 .617 r
.37788 .34843 .38386 .39756 .39672 .39701 .39055 .34908 Mtetra
.559 .399 .621 r
.39055 .34908 .39672 .39701 .40987 .39119 .40347 .34593 Mtetra
.589 .425 .628 r
.40347 .34593 .40987 .39119 .42319 .38139 .41658 .33955 Mtetra
.612 .449 .636 r
.41658 .33955 .42319 .38139 .43659 .36946 .4298 .33091 Mtetra
.629 .468 .644 r
.4298 .33091 .43659 .36946 .45 .35708 .44309 .32097 Mtetra
.641 .481 .651 r
.44309 .32097 .45 .35708 .46341 .34522 .45641 .31036 Mtetra
.649 .49 .655 r
.45641 .31036 .46341 .34522 .47681 .33389 .46975 .29919 Mtetra
.656 .495 .654 r
.46975 .29919 .47681 .33389 .49022 .32225 .48311 .28717 Mtetra
.665 .5 .651 r
.48311 .28717 .49022 .32225 .50364 .30917 .49649 .27391 Mtetra
.674 .505 .649 r
.49649 .27391 .50364 .30917 .51707 .29385 .50987 .25928 Mtetra
.684 .513 .649 r
.50987 .25928 .51707 .29385 .53046 .27626 .52322 .24362 Mtetra
.693 .525 .654 r
.52322 .24362 .53046 .27626 .5438 .2572 .53654 .22767 Mtetra
.701 .54 .666 r
.53654 .22767 .5438 .2572 .55708 .238 .54984 .21233 Mtetra
.707 .56 .685 r
.54984 .21233 .55708 .238 .57032 .22001 .56312 .19838 Mtetra
.711 .585 .713 r
.56312 .19838 .57032 .22001 .58354 .20422 .57643 .18629 Mtetra
.711 .616 .749 r
.57643 .18629 .58354 .20422 .5968 .19104 .58977 .17613 Mtetra
.707 .649 .789 r
.58977 .17613 .5968 .19104 .61012 .18036 .60318 .16767 Mtetra
.699 .679 .828 r
.60318 .16767 .61012 .18036 .62352 .17173 .61666 .16053 Mtetra
.688 .704 .86 r
.61666 .16053 .62352 .17173 .637 .1646 .63022 .1543 Mtetra
.678 .721 .881 r
.63022 .1543 .637 .1646 .65058 .15844 .64386 .14863 Mtetra
.671 .731 .895 r
.64386 .14863 .65058 .15844 .66424 .15283 .65758 .14326 Mtetra
.667 .736 .902 r
.65758 .14326 .66424 .15283 .67797 .14751 .67136 .13803 Mtetra
.665 .739 .905 r
.67136 .13803 .67797 .14751 .69178 .14232 .68522 .13286 Mtetra
.664 .74 .907 r
.68522 .13286 .69178 .14232 .70566 .13718 .69915 .1277 Mtetra
.664 .741 .907 r
.69915 .1277 .70566 .13718 .71961 .13205 .71315 .12253 Mtetra
.664 .741 .908 r
.71315 .12253 .71961 .13205 .73363 .1269 .72722 .11735 Mtetra
.72722 .11735 .73363 .1269 .74772 .12173 .74135 .11214 Mtetra
.74135 .11214 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.663 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33607 .12519 .32834 Mtetra
.12519 .32834 .13343 .33607 .14477 .33191 .13656 .32414 Mtetra
.13656 .32414 .14477 .33191 .15616 .32776 .14798 .31993 Mtetra
.661 .74 .908 r
.14798 .31993 .15616 .32776 .16759 .32364 .15945 .31575 Mtetra
.659 .738 .908 r
.15945 .31575 .16759 .32364 .17906 .31961 .17096 .31161 Mtetra
.656 .735 .908 r
.17096 .31161 .17906 .31961 .19057 .31574 .18251 .30755 Mtetra
.65 .73 .908 r
.18251 .30755 .19057 .31574 .20211 .3121 .1941 .30363 Mtetra
.643 .722 .905 r
.1941 .30363 .20211 .3121 .21367 .30878 .20573 .29989 Mtetra
.636 .709 .9 r
.20573 .29989 .21367 .30878 .22525 .30582 .21739 .29635 Mtetra
.628 .693 .891 r
.21739 .29635 .22525 .30582 .23686 .30326 .22908 .29301 Mtetra
.619 .673 .879 r
.22908 .29301 .23686 .30326 .24849 .30113 .24082 .28989 Mtetra
.609 .648 .864 r
.24082 .28989 .24849 .30113 .26015 .29953 .2526 .28704 Mtetra
.595 .618 .845 r
.2526 .28704 .26015 .29953 .27182 .29869 .2644 .28462 Mtetra
.573 .582 .824 r
.2644 .28462 .27182 .29869 .28348 .29899 .27622 .28288 Mtetra
.544 .538 .798 r
.27622 .28288 .28348 .29899 .29511 .30093 .28804 .28217 Mtetra
.511 .488 .768 r
.28804 .28217 .29511 .30093 .3067 .30489 .29984 .2828 Mtetra
.481 .439 .734 r
.29984 .2828 .3067 .30489 .31827 .31102 .31163 .28493 Mtetra
.461 .399 .701 r
.31163 .28493 .31827 .31102 .32985 .319 .32344 .28845 Mtetra
.455 .372 .673 r
.32344 .28845 .32985 .319 .34154 .32803 .3353 .29293 Mtetra
.462 .359 .652 r
.3353 .29293 .34154 .32803 .35339 .33687 .34729 .29765 Mtetra
.479 .359 .638 r
.34729 .29765 .35339 .33687 .36549 .3441 .35944 .30173 Mtetra
.501 .367 .631 r
.35944 .30173 .36549 .3441 .37788 .34843 .37179 .30429 Mtetra
.525 .381 .627 r
.37179 .30429 .37788 .34843 .39055 .34908 .38435 .3047 Mtetra
.55 .398 .628 r
.38435 .3047 .39055 .34908 .40347 .34593 .39711 .30269 Mtetra
.572 .416 .632 r
.39711 .30269 .40347 .34593 .41658 .33955 .41005 .29837 Mtetra
.592 .435 .637 r
.41005 .29837 .41658 .33955 .4298 .33091 .4231 .29211 Mtetra
.609 .452 .644 r
.4231 .29211 .4298 .33091 .44309 .32097 .43625 .28436 Mtetra
.624 .468 .65 r
.43625 .28436 .44309 .32097 .45641 .31036 .44947 .27544 Mtetra
.638 .482 .655 r
.44947 .27544 .45641 .31036 .46975 .29919 .46273 .26548 Mtetra
.65 .493 .658 r
.46273 .26548 .46975 .29919 .48311 .28717 .47603 .25449 Mtetra
.662 .504 .66 r
.47603 .25449 .48311 .28717 .49649 .27391 .48935 .24249 Mtetra
.673 .515 .664 r
.48935 .24249 .49649 .27391 .50987 .25928 .50268 .22971 Mtetra
.683 .528 .67 r
.50268 .22971 .50987 .25928 .52322 .24362 .51601 .21659 Mtetra
.691 .544 .681 r
.51601 .21659 .52322 .24362 .53654 .22767 .52933 .20371 Mtetra
.698 .564 .699 r
.52933 .20371 .53654 .22767 .54984 .21233 .54264 .19167 Mtetra
.702 .588 .724 r
.54264 .19167 .54984 .21233 .56312 .19838 .55597 .18086 Mtetra
.704 .616 .756 r
.55597 .18086 .56312 .19838 .57643 .18629 .56934 .17144 Mtetra
.702 .647 .793 r
.56934 .17144 .57643 .18629 .58977 .17613 .58275 .16334 Mtetra
.695 .677 .828 r
.58275 .16334 .58977 .17613 .60318 .16767 .59623 .15633 Mtetra
.687 .701 .858 r
.59623 .15633 .60318 .16767 .61666 .16053 .60978 .1501 Mtetra
.678 .719 .88 r
.60978 .1501 .61666 .16053 .63022 .1543 .6234 .14439 Mtetra
.672 .729 .893 r
.6234 .14439 .63022 .1543 .64386 .14863 .63709 .13898 Mtetra
.668 .735 .901 r
.63709 .13898 .64386 .14863 .65758 .14326 .65086 .13372 Mtetra
.665 .739 .905 r
.65086 .13372 .65758 .14326 .67136 .13803 .6647 .12852 Mtetra
.664 .74 .906 r
.6647 .12852 .67136 .13803 .68522 .13286 .6786 .12334 Mtetra
.664 .741 .907 r
.6786 .12334 .68522 .13286 .69915 .1277 .69258 .11815 Mtetra
.664 .741 .908 r
.69258 .11815 .69915 .1277 .71315 .12253 .70663 .11294 Mtetra
.70663 .11294 .71315 .12253 .72722 .11735 .72074 .10771 Mtetra
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
.663 .741 .908 r
.10554 .32477 .11387 .33253 .12519 .32834 .11689 .32054 Mtetra
.11689 .32054 .12519 .32834 .13656 .32414 .12829 .3163 Mtetra
.12829 .3163 .13656 .32414 .14798 .31993 .13974 .31206 Mtetra
.662 .74 .908 r
.13974 .31206 .14798 .31993 .15945 .31575 .15124 .30781 Mtetra
.661 .739 .908 r
.15124 .30781 .15945 .31575 .17096 .31161 .16278 .30358 Mtetra
.659 .738 .908 r
.16278 .30358 .17096 .31161 .18251 .30755 .17437 .2994 Mtetra
.656 .734 .907 r
.17437 .2994 .18251 .30755 .1941 .30363 .18601 .29528 Mtetra
.652 .729 .906 r
.18601 .29528 .1941 .30363 .20573 .29989 .19769 .29126 Mtetra
.648 .721 .902 r
.19769 .29126 .20573 .29989 .21739 .29635 .20941 .28734 Mtetra
.643 .711 .897 r
.20941 .28734 .21739 .29635 .22908 .29301 .22118 .28351 Mtetra
.639 .699 .889 r
.22118 .28351 .22908 .29301 .24082 .28989 .23299 .27976 Mtetra
.634 .683 .879 r
.23299 .27976 .24082 .28989 .2526 .28704 .24486 .27613 Mtetra
.626 .664 .867 r
.24486 .27613 .2526 .28704 .2644 .28462 .25676 .27269 Mtetra
.613 .639 .853 r
.25676 .27269 .2644 .28462 .27622 .28288 .2687 .26962 Mtetra
.594 .607 .835 r
.2687 .26962 .27622 .28288 .28804 .28217 .28066 .26712 Mtetra
.57 .568 .811 r
.28066 .26712 .28804 .28217 .29984 .2828 .29262 .26541 Mtetra
.545 .524 .783 r
.29262 .26541 .29984 .2828 .31163 .28493 .3046 .26463 Mtetra
.524 .482 .752 r
.3046 .26463 .31163 .28493 .32344 .28845 .3166 .26478 Mtetra
.511 .447 .721 r
.3166 .26478 .32344 .28845 .3353 .29293 .32865 .26566 Mtetra
.507 .423 .696 r
.32865 .26566 .3353 .29293 .34729 .29765 .34077 .26692 Mtetra
.512 .41 .676 r
.34077 .26692 .34729 .29765 .35944 .30173 .35301 .26804 Mtetra
.523 .406 .662 r
.35301 .26804 .35944 .30173 .37179 .30429 .36538 .26851 Mtetra
.537 .409 .654 r
.36538 .26851 .37179 .30429 .38435 .3047 .3779 .26789 Mtetra
.553 .418 .651 r
.3779 .26789 .38435 .3047 .39711 .30269 .39058 .26588 Mtetra
.57 .429 .651 r
.39058 .26588 .39711 .30269 .41005 .29837 .4034 .2624 Mtetra
.586 .443 .654 r
.4034 .2624 .41005 .29837 .4231 .29211 .41634 .25751 Mtetra
.602 .458 .658 r
.41634 .25751 .4231 .29211 .43625 .28436 .42938 .25131 Mtetra
.617 .473 .664 r
.42938 .25131 .43625 .28436 .44947 .27544 .4425 .24394 Mtetra
.632 .489 .669 r
.4425 .24394 .44947 .27544 .46273 .26548 .45569 .23549 Mtetra
.646 .504 .674 r
.45569 .23549 .46273 .26548 .47603 .25449 .46892 .22609 Mtetra
.66 .518 .681 r
.46892 .22609 .47603 .25449 .48935 .24249 .48219 .21593 Mtetra
.671 .534 .689 r
.48219 .21593 .48935 .24249 .50268 .22971 .49548 .20533 Mtetra
.681 .551 .701 r
.49548 .20533 .50268 .22971 .51601 .21659 .50879 .19469 Mtetra
.689 .572 .718 r
.50879 .19469 .51601 .21659 .52933 .20371 .52211 .18446 Mtetra
.694 .595 .741 r
.52211 .18446 .52933 .20371 .54264 .19167 .53545 .17496 Mtetra
.697 .622 .769 r
.53545 .17496 .54264 .19167 .55597 .18086 .54882 .16639 Mtetra
.696 .651 .801 r
.54882 .16639 .55597 .18086 .56934 .17144 .56224 .15876 Mtetra
.691 .678 .832 r
.56224 .15876 .56934 .17144 .58275 .16334 .57571 .15197 Mtetra
.684 .701 .859 r
.57571 .15197 .58275 .16334 .59623 .15633 .58925 .14582 Mtetra
.677 .718 .879 r
.58925 .14582 .59623 .15633 .60978 .1501 .60285 .14012 Mtetra
.672 .729 .893 r
.60285 .14012 .60978 .1501 .6234 .14439 .61653 .13468 Mtetra
.668 .735 .9 r
.61653 .13468 .6234 .14439 .63709 .13898 .63027 .12939 Mtetra
.665 .738 .904 r
.63027 .12939 .63709 .13898 .65086 .13372 .64409 .12417 Mtetra
.664 .74 .906 r
.64409 .12417 .65086 .13372 .6647 .12852 .65797 .11896 Mtetra
.664 .741 .907 r
.65797 .11896 .6647 .12852 .6786 .12334 .67193 .11375 Mtetra
.664 .741 .908 r
.67193 .11375 .6786 .12334 .69258 .11815 .68595 .10852 Mtetra
.68595 .10852 .69258 .11815 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09799 Mtetra
.71421 .09799 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.663 .741 .908 r
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31269 Mtetra
.10852 .31269 .11689 .32054 .12829 .3163 .11994 .30841 Mtetra
.11994 .30841 .12829 .3163 .13974 .31206 .13142 .30412 Mtetra
.13142 .30412 .13974 .31206 .15124 .30781 .14295 .29982 Mtetra
.662 .74 .908 r
.14295 .29982 .15124 .30781 .16278 .30358 .15453 .29552 Mtetra
.661 .739 .908 r
.15453 .29552 .16278 .30358 .17437 .2994 .16616 .29124 Mtetra
.659 .737 .907 r
.16616 .29124 .17437 .2994 .18601 .29528 .17783 .287 Mtetra
.657 .734 .906 r
.17783 .287 .18601 .29528 .19769 .29126 .18956 .28279 Mtetra
.655 .729 .904 r
.18956 .28279 .19769 .29126 .20941 .28734 .20133 .27862 Mtetra
.653 .723 .901 r
.20133 .27862 .20941 .28734 .22118 .28351 .21315 .27449 Mtetra
.651 .716 .896 r
.21315 .27449 .22118 .28351 .23299 .27976 .22503 .27037 Mtetra
.649 .707 .89 r
.22503 .27037 .23299 .27976 .24486 .27613 .23696 .26628 Mtetra
.645 .696 .883 r
.23696 .26628 .24486 .27613 .25676 .27269 .24893 .26226 Mtetra
.638 .682 .874 r
.24893 .26226 .25676 .27269 .2687 .26962 .26096 .2584 Mtetra
.628 .662 .864 r
.26096 .2584 .2687 .26962 .28066 .26712 .27301 .25481 Mtetra
.613 .635 .849 r
.27301 .25481 .28066 .26712 .29262 .26541 .2851 .25165 Mtetra
.596 .602 .829 r
.2851 .25165 .29262 .26541 .3046 .26463 .29722 .249 Mtetra
.578 .566 .804 r
.29722 .249 .3046 .26463 .3166 .26478 .30937 .24691 Mtetra
.564 .531 .777 r
.30937 .24691 .3166 .26478 .32865 .26566 .32156 .2453 Mtetra
.554 .501 .751 r
.32156 .2453 .32865 .26566 .34077 .26692 .33381 .24402 Mtetra
.551 .479 .728 r
.33381 .24402 .34077 .26692 .35301 .26804 .34614 .24282 Mtetra
.553 .465 .71 r
.34614 .24282 .35301 .26804 .36538 .26851 .35857 .24141 Mtetra
.559 .459 .697 r
.35857 .24141 .36538 .26851 .3779 .26789 .37111 .23953 Mtetra
.568 .459 .689 r
.37111 .23953 .3779 .26789 .39058 .26588 .38376 .23695 Mtetra
.579 .463 .686 r
.38376 .23695 .39058 .26588 .4034 .2624 .39653 .23352 Mtetra
.591 .472 .685 r
.39653 .23352 .4034 .2624 .41634 .25751 .4094 .22917 Mtetra
.605 .483 .688 r
.4094 .22917 .41634 .25751 .42938 .25131 .42237 .22386 Mtetra
.619 .497 .692 r
.42237 .22386 .42938 .25131 .4425 .24394 .43543 .21762 Mtetra
.633 .511 .697 r
.43543 .21762 .4425 .24394 .45569 .23549 .44855 .2105 Mtetra
.647 .527 .704 r
.44855 .2105 .45569 .23549 .46892 .22609 .46174 .20264 Mtetra
.659 .544 .713 r
.46174 .20264 .46892 .22609 .48219 .21593 .47497 .19424 Mtetra
.67 .563 .725 r
.47497 .19424 .48219 .21593 .49548 .20533 .48824 .18559 Mtetra
.679 .583 .741 r
.48824 .18559 .49548 .20533 .50879 .19469 .50154 .17701 Mtetra
.686 .606 .761 r
.50154 .17701 .50879 .19469 .52211 .18446 .51487 .16878 Mtetra
.689 .631 .786 r
.51487 .16878 .52211 .18446 .53545 .17496 .52823 .16108 Mtetra
.69 .657 .813 r
.52823 .16108 .53545 .17496 .54882 .16639 .54164 .15399 Mtetra
.687 .682 .84 r
.54164 .15399 .54882 .16639 .56224 .15876 .55511 .14749 Mtetra
.682 .703 .863 r
.55511 .14749 .56224 .15876 .57571 .15197 .56863 .14147 Mtetra
.676 .718 .881 r
.56863 .14147 .57571 .15197 .58925 .14582 .58222 .1358 Mtetra
.671 .728 .893 r
.58222 .1358 .58925 .14582 .60285 .14012 .59587 .13036 Mtetra
.668 .735 .9 r
.59587 .13036 .60285 .14012 .61653 .13468 .6096 .12505 Mtetra
.666 .738 .904 r
.6096 .12505 .61653 .13468 .63027 .12939 .62339 .1198 Mtetra
.664 .74 .906 r
.62339 .1198 .63027 .12939 .64409 .12417 .63725 .11457 Mtetra
.664 .741 .907 r
.63725 .11457 .64409 .12417 .65797 .11896 .65119 .10933 Mtetra
.664 .741 .908 r
.65119 .10933 .65797 .11896 .67193 .11375 .66519 .10408 Mtetra
.66519 .10408 .67193 .11375 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09799 .70762 .08817 Mtetra
.70762 .08817 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31269 .10008 .30476 Mtetra
.663 .741 .908 r
.10008 .30476 .10852 .31269 .11994 .30841 .11153 .30045 Mtetra
.11153 .30045 .11994 .30841 .13142 .30412 .12304 .29612 Mtetra
.12304 .29612 .13142 .30412 .14295 .29982 .1346 .29177 Mtetra
.1346 .29177 .14295 .29982 .15453 .29552 .14621 .28742 Mtetra
.662 .74 .908 r
.14621 .28742 .15453 .29552 .16616 .29124 .15787 .28307 Mtetra
.661 .739 .908 r
.15787 .28307 .16616 .29124 .17783 .287 .16958 .27873 Mtetra
.66 .737 .907 r
.16958 .27873 .17783 .287 .18956 .28279 .18135 .2744 Mtetra
.659 .734 .906 r
.18135 .2744 .18956 .28279 .20133 .27862 .19316 .27007 Mtetra
.658 .731 .903 r
.19316 .27007 .20133 .27862 .21315 .27449 .20503 .26575 Mtetra
.657 .727 .901 r
.20503 .26575 .21315 .27449 .22503 .27037 .21695 .26142 Mtetra
.657 .722 .897 r
.21695 .26142 .22503 .27037 .23696 .26628 .22893 .25708 Mtetra
.655 .717 .894 r
.22893 .25708 .23696 .26628 .24893 .26226 .24096 .25274 Mtetra
.652 .709 .889 r
.24096 .25274 .24893 .26226 .26096 .2584 .25304 .24845 Mtetra
.647 .698 .883 r
.25304 .24845 .26096 .2584 .27301 .25481 .26517 .24428 Mtetra
.64 .683 .875 r
.26517 .24428 .27301 .25481 .2851 .25165 .27734 .2403 Mtetra
.63 .663 .864 r
.27734 .2403 .2851 .25165 .29722 .249 .28956 .23658 Mtetra
.618 .638 .848 r
.28956 .23658 .29722 .249 .30937 .24691 .30181 .23315 Mtetra
.607 .611 .829 r
.30181 .23315 .30937 .24691 .32156 .2453 .31411 .23 Mtetra
.598 .583 .808 r
.31411 .23 .32156 .2453 .33381 .24402 .32647 .22708 Mtetra
.591 .559 .787 r
.32647 .22708 .33381 .24402 .34614 .24282 .33889 .22427 Mtetra
.588 .54 .768 r
.33889 .22427 .34614 .24282 .35857 .24141 .35139 .22145 Mtetra
.588 .527 .753 r
.35139 .22145 .35857 .24141 .37111 .23953 .36397 .21845 Mtetra
.592 .52 .742 r
.36397 .21845 .37111 .23953 .38376 .23695 .37663 .21514 Mtetra
.598 .518 .735 r
.37663 .21514 .38376 .23695 .39653 .23352 .38939 .21139 Mtetra
.606 .52 .732 r
.38939 .21139 .39653 .23352 .4094 .22917 .40224 .20709 Mtetra
.616 .527 .731 r
.40224 .20709 .4094 .22917 .42237 .22386 .41518 .20218 Mtetra
.627 .537 .733 r
.41518 .20218 .42237 .22386 .43543 .21762 .4282 .19662 Mtetra
.639 .549 .737 r
.4282 .19662 .43543 .21762 .44855 .2105 .4413 .19046 Mtetra
.651 .564 .745 r
.4413 .19046 .44855 .2105 .46174 .20264 .45445 .18378 Mtetra
.661 .581 .755 r
.45445 .18378 .46174 .20264 .47497 .19424 .46767 .17675 Mtetra
.67 .6 .768 r
.46767 .17675 .47497 .19424 .48824 .18559 .48092 .16958 Mtetra
.677 .621 .785 r
.48092 .16958 .48824 .18559 .50154 .17701 .49423 .16247 Mtetra
.682 .644 .806 r
.49423 .16247 .50154 .17701 .51487 .16878 .50757 .1556 Mtetra
.683 .667 .828 r
.50757 .1556 .51487 .16878 .52823 .16108 .52097 .14907 Mtetra
.681 .688 .849 r
.52097 .14907 .52823 .16108 .54164 .15399 .53442 .14289 Mtetra
.678 .706 .868 r
.53442 .14289 .54164 .15399 .55511 .14749 .54793 .13703 Mtetra
.674 .719 .883 r
.54793 .13703 .55511 .14749 .56863 .14147 .5615 .13143 Mtetra
.67 .729 .894 r
.5615 .13143 .56863 .14147 .58222 .1358 .57513 .126 Mtetra
.667 .735 .9 r
.57513 .126 .58222 .1358 .59587 .13036 .58884 .12068 Mtetra
.666 .738 .904 r
.58884 .12068 .59587 .13036 .6096 .12505 .60261 .11541 Mtetra
.664 .74 .906 r
.60261 .11541 .6096 .12505 .62339 .1198 .61645 .11015 Mtetra
.664 .741 .907 r
.61645 .11015 .62339 .1198 .63725 .11457 .63036 .10489 Mtetra
.664 .741 .908 r
.63036 .10489 .63725 .11457 .65119 .10933 .64434 .09962 Mtetra
.64434 .09962 .65119 .10933 .66519 .10408 .65839 .09432 Mtetra
.65839 .09432 .66519 .10408 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29678 Mtetra
.663 .741 .908 r
.09156 .29678 .10008 .30476 .11153 .30045 .10305 .29242 Mtetra
.10305 .29242 .11153 .30045 .12304 .29612 .11459 .28805 Mtetra
.11459 .28805 .12304 .29612 .1346 .29177 .12618 .28366 Mtetra
.12618 .28366 .1346 .29177 .14621 .28742 .13782 .27926 Mtetra
.663 .74 .908 r
.13782 .27926 .14621 .28742 .15787 .28307 .14951 .27486 Mtetra
.662 .74 .908 r
.14951 .27486 .15787 .28307 .16958 .27873 .16126 .27044 Mtetra
.662 .739 .907 r
.16126 .27044 .16958 .27873 .18135 .2744 .17305 .26602 Mtetra
.661 .737 .906 r
.17305 .26602 .18135 .2744 .19316 .27007 .18491 .2616 Mtetra
.661 .736 .905 r
.18491 .2616 .19316 .27007 .20503 .26575 .19681 .25716 Mtetra
.66 .734 .904 r
.19681 .25716 .20503 .26575 .21695 .26142 .20877 .2527 Mtetra
.66 .731 .902 r
.20877 .2527 .21695 .26142 .22893 .25708 .22079 .24822 Mtetra
.66 .729 .9 r
.22079 .24822 .22893 .25708 .24096 .25274 .23287 .24372 Mtetra
.659 .725 .898 r
.23287 .24372 .24096 .25274 .25304 .24845 .245 .23922 Mtetra
.657 .72 .895 r
.245 .23922 .25304 .24845 .26517 .24428 .25718 .23475 Mtetra
.654 .713 .891 r
.25718 .23475 .26517 .24428 .27734 .2403 .26941 .23035 Mtetra
.649 .702 .886 r
.26941 .23035 .27734 .2403 .28956 .23658 .28169 .22606 Mtetra
.643 .688 .878 r
.28169 .22606 .28956 .23658 .30181 .23315 .29402 .22191 Mtetra
.636 .671 .867 r
.29402 .22191 .30181 .23315 .31411 .23 .3064 .2179 Mtetra
.63 .652 .854 r
.3064 .2179 .31411 .23 .32647 .22708 .31884 .21402 Mtetra
.624 .633 .839 r
.31884 .21402 .32647 .22708 .33889 .22427 .33133 .21023 Mtetra
.62 .616 .825 r
.33133 .21023 .33889 .22427 .35139 .22145 .34389 .20646 Mtetra
.618 .601 .811 r
.34389 .20646 .35139 .22145 .36397 .21845 .35652 .20265 Mtetra
.618 .59 .8 r
.35652 .20265 .36397 .21845 .37663 .21514 .36922 .19871 Mtetra
.62 .584 .791 r
.36922 .19871 .37663 .21514 .38939 .21139 .382 .19455 Mtetra
.625 .582 .786 r
.382 .19455 .38939 .21139 .40224 .20709 .39486 .19009 Mtetra
.631 .584 .783 r
.39486 .19009 .40224 .20709 .41518 .20218 .4078 .18528 Mtetra
.639 .59 .783 r
.4078 .18528 .41518 .20218 .4282 .19662 .42082 .18007 Mtetra
.648 .599 .786 r
.42082 .18007 .4282 .19662 .4413 .19046 .4339 .17448 Mtetra
.656 .611 .792 r
.4339 .17448 .4413 .19046 .45445 .18378 .44705 .16857 Mtetra
.664 .625 .801 r
.44705 .16857 .45445 .18378 .46767 .17675 .46026 .16245 Mtetra
.67 .642 .813 r
.46026 .16245 .46767 .17675 .48092 .16958 .47353 .15625 Mtetra
.674 .66 .828 r
.47353 .15625 .48092 .16958 .49423 .16247 .48685 .15009 Mtetra
.676 .678 .844 r
.48685 .15009 .49423 .16247 .50757 .1556 .50022 .14405 Mtetra
.676 .695 .861 r
.50022 .14405 .50757 .1556 .52097 .14907 .51365 .13819 Mtetra
.674 .71 .875 r
.51365 .13819 .52097 .14907 .53442 .14289 .52714 .13252 Mtetra
.672 .721 .887 r
.52714 .13252 .53442 .14289 .54793 .13703 .54069 .12701 Mtetra
.669 .73 .895 r
.54069 .12701 .54793 .13703 .5615 .13143 .5543 .12161 Mtetra
.667 .735 .901 r
.5543 .12161 .5615 .13143 .57513 .126 .56799 .11628 Mtetra
.665 .738 .904 r
.56799 .11628 .57513 .126 .58884 .12068 .58174 .11099 Mtetra
.664 .74 .906 r
.58174 .11099 .58884 .12068 .60261 .11541 .59555 .10572 Mtetra
.664 .741 .907 r
.59555 .10572 .60261 .11541 .61645 .11015 .60944 .10044 Mtetra
.664 .741 .908 r
.60944 .10044 .61645 .11015 .63036 .10489 .6234 .09514 Mtetra
.6234 .09514 .63036 .10489 .64434 .09962 .63743 .08982 Mtetra
.63743 .08982 .64434 .09962 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29678 .08298 .28872 Mtetra
.08298 .28872 .09156 .29678 .10305 .29242 .09449 .28433 Mtetra
.663 .741 .908 r
.09449 .28433 .10305 .29242 .11459 .28805 .10606 .27992 Mtetra
.10606 .27992 .11459 .28805 .12618 .28366 .11768 .27549 Mtetra
.11768 .27549 .12618 .28366 .13782 .27926 .12935 .27105 Mtetra
.12935 .27105 .13782 .27926 .14951 .27486 .14108 .26659 Mtetra
.663 .74 .908 r
.14108 .26659 .14951 .27486 .16126 .27044 .15286 .26212 Mtetra
.662 .74 .907 r
.15286 .26212 .16126 .27044 .17305 .26602 .16469 .25764 Mtetra
.662 .739 .907 r
.16469 .25764 .17305 .26602 .18491 .2616 .17657 .25314 Mtetra
.662 .738 .906 r
.17657 .25314 .18491 .2616 .19681 .25716 .18852 .24862 Mtetra
.662 .737 .906 r
.18852 .24862 .19681 .25716 .20877 .2527 .20051 .24408 Mtetra
.662 .736 .905 r
.20051 .24408 .20877 .2527 .22079 .24822 .21257 .23952 Mtetra
.662 .735 .904 r
.21257 .23952 .22079 .24822 .23287 .24372 .22468 .23492 Mtetra
.662 .734 .903 r
.22468 .23492 .23287 .24372 .245 .23922 .23685 .23031 Mtetra
.661 .732 .902 r
.23685 .23031 .245 .23922 .25718 .23475 .24907 .22569 Mtetra
.66 .729 .9 r
.24907 .22569 .25718 .23475 .26941 .23035 .26135 .2211 Mtetra
.658 .724 .898 r
.26135 .2211 .26941 .23035 .28169 .22606 .27368 .21653 Mtetra
.655 .717 .894 r
.27368 .21653 .28169 .22606 .29402 .22191 .28606 .21202 Mtetra
.652 .708 .889 r
.28606 .21202 .29402 .22191 .3064 .2179 .2985 .20756 Mtetra
.648 .698 .882 r
.2985 .20756 .3064 .2179 .31884 .21402 .311 .20316 Mtetra
.645 .686 .874 r
.311 .20316 .31884 .21402 .33133 .21023 .32356 .19881 Mtetra
.642 .674 .865 r
.32356 .19881 .33133 .21023 .34389 .20646 .33617 .19448 Mtetra
.64 .663 .857 r
.33617 .19448 .34389 .20646 .35652 .20265 .34885 .19014 Mtetra
.639 .654 .848 r
.34885 .19014 .35652 .20265 .36922 .19871 .36159 .18575 Mtetra
.64 .647 .841 r
.36159 .18575 .36922 .19871 .382 .19455 .37441 .18125 Mtetra
.642 .643 .835 r
.37441 .18125 .382 .19455 .39486 .19009 .3873 .1766 Mtetra
.646 .642 .832 r
.3873 .1766 .39486 .19009 .4078 .18528 .40025 .17175 Mtetra
.65 .644 .83 r
.40025 .17175 .4078 .18528 .42082 .18007 .41328 .16667 Mtetra
.656 .649 .832 r
.41328 .16667 .42082 .18007 .4339 .17448 .42638 .16138 Mtetra
.661 .657 .836 r
.42638 .16138 .4339 .17448 .44705 .16857 .43954 .15591 Mtetra
.665 .668 .843 r
.43954 .15591 .44705 .16857 .46026 .16245 .45277 .15032 Mtetra
.669 .68 .852 r
.45277 .15032 .46026 .16245 .47353 .15625 .46605 .14467 Mtetra
.671 .693 .862 r
.46605 .14467 .47353 .15625 .48685 .15009 .4794 .13904 Mtetra
.671 .705 .873 r
.4794 .13904 .48685 .15009 .50022 .14405 .4928 .13346 Mtetra
.67 .716 .882 r
.4928 .13346 .50022 .14405 .51365 .13819 .50627 .12796 Mtetra
.669 .724 .891 r
.50627 .12796 .51365 .13819 .52714 .13252 .5198 .12254 Mtetra
.667 .731 .897 r
.5198 .12254 .52714 .13252 .54069 .12701 .53339 .11718 Mtetra
.666 .735 .902 r
.53339 .11718 .54069 .12701 .5543 .12161 .54705 .11186 Mtetra
.665 .738 .904 r
.54705 .11186 .5543 .12161 .56799 .11628 .56078 .10656 Mtetra
.664 .74 .906 r
.56078 .10656 .56799 .11628 .58174 .11099 .57457 .10127 Mtetra
.664 .741 .907 r
.57457 .10127 .58174 .11099 .59555 .10572 .58844 .09596 Mtetra
.664 .741 .908 r
.58844 .09596 .59555 .10572 .60944 .10044 .60237 .09064 Mtetra
.60237 .09064 .60944 .10044 .6234 .09514 .61637 .08529 Mtetra
.61637 .08529 .6234 .09514 .63743 .08982 .63045 .07993 Mtetra
.63045 .07993 .63743 .08982 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.663 .741 .908 r
.09746 .27172 .10606 .27992 .11768 .27549 .10911 .26725 Mtetra
.10911 .26725 .11768 .27549 .12935 .27105 .12081 .26277 Mtetra
.12081 .26277 .12935 .27105 .14108 .26659 .13257 .25827 Mtetra
.13257 .25827 .14108 .26659 .15286 .26212 .14438 .25375 Mtetra
.14438 .25375 .15286 .26212 .16469 .25764 .15625 .24921 Mtetra
.663 .74 .907 r
.15625 .24921 .16469 .25764 .17657 .25314 .16816 .24465 Mtetra
.16816 .24465 .17657 .25314 .18852 .24862 .18014 .24008 Mtetra
.663 .739 .907 r
.18014 .24008 .18852 .24862 .20051 .24408 .19217 .23548 Mtetra
.663 .739 .906 r
.19217 .23548 .20051 .24408 .21257 .23952 .20426 .23085 Mtetra
.663 .738 .906 r
.20426 .23085 .21257 .23952 .22468 .23492 .2164 .2262 Mtetra
.663 .738 .905 r
.2164 .2262 .22468 .23492 .23685 .23031 .22861 .22152 Mtetra
.663 .737 .905 r
.22861 .22152 .23685 .23031 .24907 .22569 .24087 .21683 Mtetra
.662 .736 .904 r
.24087 .21683 .24907 .22569 .26135 .2211 .25318 .21213 Mtetra
.661 .734 .904 r
.25318 .21213 .26135 .2211 .27368 .21653 .26556 .20743 Mtetra
.66 .731 .902 r
.26556 .20743 .27368 .21653 .28606 .21202 .27799 .20274 Mtetra
.659 .728 .9 r
.27799 .20274 .28606 .21202 .2985 .20756 .29047 .19806 Mtetra
.657 .723 .897 r
.29047 .19806 .2985 .20756 .311 .20316 .30302 .1934 Mtetra
.656 .717 .893 r
.30302 .1934 .311 .20316 .32356 .19881 .31562 .18875 Mtetra
.654 .71 .889 r
.31562 .18875 .32356 .19881 .33617 .19448 .32828 .18411 Mtetra
.653 .704 .884 r
.32828 .18411 .33617 .19448 .34885 .19014 .34101 .17946 Mtetra
.652 .697 .879 r
.34101 .17946 .34885 .19014 .36159 .18575 .3538 .17478 Mtetra
.652 .692 .874 r
.3538 .17478 .36159 .18575 .37441 .18125 .36665 .17004 Mtetra
.653 .688 .87 r
.36665 .17004 .37441 .18125 .3873 .1766 .37957 .16522 Mtetra
.655 .687 .868 r
.37957 .16522 .3873 .1766 .40025 .17175 .39256 .1603 Mtetra
.658 .687 .866 r
.39256 .1603 .40025 .17175 .41328 .16667 .40562 .15525 Mtetra
.66 .69 .867 r
.40562 .15525 .41328 .16667 .42638 .16138 .41874 .15009 Mtetra
.663 .694 .869 r
.41874 .15009 .42638 .16138 .43954 .15591 .43193 .14482 Mtetra
.665 .701 .873 r
.43193 .14482 .43954 .15591 .45277 .15032 .44518 .13949 Mtetra
.667 .708 .878 r
.44518 .13949 .45277 .15032 .46605 .14467 .4585 .13412 Mtetra
.667 .715 .884 r
.4585 .13412 .46605 .14467 .4794 .13904 .47187 .12874 Mtetra
.667 .722 .89 r
.47187 .12874 .4794 .13904 .4928 .13346 .48531 .12338 Mtetra
.667 .728 .895 r
.48531 .12338 .4928 .13346 .50627 .12796 .49882 .11803 Mtetra
.666 .733 .9 r
.49882 .11803 .50627 .12796 .5198 .12254 .51239 .11271 Mtetra
.665 .736 .903 r
.51239 .11271 .5198 .12254 .53339 .11718 .52603 .10741 Mtetra
.665 .738 .905 r
.52603 .10741 .53339 .11718 .54705 .11186 .53973 .1021 Mtetra
.664 .74 .906 r
.53973 .1021 .54705 .11186 .56078 .10656 .5535 .09679 Mtetra
.664 .741 .907 r
.5535 .09679 .56078 .10656 .57457 .10127 .56734 .09147 Mtetra
.664 .741 .908 r
.56734 .09147 .57457 .10127 .58844 .09596 .58125 .08612 Mtetra
.58125 .08612 .58844 .09596 .60237 .09064 .59523 .08075 Mtetra
.59523 .08075 .60237 .09064 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07993 .62341 .06994 Mtetra
.62341 .06994 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25895 Mtetra
.663 .741 .908 r
.10047 .25895 .10911 .26725 .12081 .26277 .1122 .25442 Mtetra
.1122 .25442 .12081 .26277 .13257 .25827 .12399 .24988 Mtetra
.12399 .24988 .13257 .25827 .14438 .25375 .13583 .24531 Mtetra
.13583 .24531 .14438 .25375 .15625 .24921 .14773 .24073 Mtetra
.14773 .24073 .15625 .24921 .16816 .24465 .15968 .23612 Mtetra
.663 .74 .907 r
.15968 .23612 .16816 .24465 .18014 .24008 .17169 .2315 Mtetra
.17169 .2315 .18014 .24008 .19217 .23548 .18375 .22685 Mtetra
.18375 .22685 .19217 .23548 .20426 .23085 .19587 .22218 Mtetra
.19587 .22218 .20426 .23085 .2164 .2262 .20805 .21748 Mtetra
.20805 .21748 .2164 .2262 .22861 .22152 .22029 .21275 Mtetra
.663 .739 .907 r
.22029 .21275 .22861 .22152 .24087 .21683 .23258 .20801 Mtetra
.663 .739 .906 r
.23258 .20801 .24087 .21683 .25318 .21213 .24494 .20325 Mtetra
.24494 .20325 .25318 .21213 .26556 .20743 .25735 .19847 Mtetra
.662 .738 .906 r
.25735 .19847 .26556 .20743 .27799 .20274 .26982 .19369 Mtetra
.662 .736 .905 r
.26982 .19369 .27799 .20274 .29047 .19806 .28234 .18889 Mtetra
.661 .734 .904 r
.28234 .18889 .29047 .19806 .30302 .1934 .29493 .18409 Mtetra
.66 .731 .902 r
.29493 .18409 .30302 .1934 .31562 .18875 .30757 .17929 Mtetra
.66 .728 .9 r
.30757 .17929 .31562 .18875 .32828 .18411 .32028 .17447 Mtetra
.659 .725 .898 r
.32028 .17447 .32828 .18411 .34101 .17946 .33305 .16964 Mtetra
.659 .722 .895 r
.33305 .16964 .34101 .17946 .3538 .17478 .34588 .16479 Mtetra
.659 .719 .893 r
.34588 .16479 .3538 .17478 .36665 .17004 .35877 .1599 Mtetra
.659 .716 .891 r
.35877 .1599 .36665 .17004 .37957 .16522 .37173 .15497 Mtetra
.66 .715 .889 r
.37173 .15497 .37957 .16522 .39256 .1603 .38476 .14997 Mtetra
.661 .715 .888 r
.38476 .14997 .39256 .1603 .40562 .15525 .39785 .1449 Mtetra
.662 .716 .888 r
.39785 .1449 .40562 .15525 .41874 .15009 .411 .13977 Mtetra
.663 .718 .889 r
.411 .13977 .41874 .15009 .43193 .14482 .42422 .13458 Mtetra
.664 .721 .891 r
.42422 .13458 .43193 .14482 .44518 .13949 .43751 .12935 Mtetra
.665 .725 .894 r
.43751 .12935 .44518 .13949 .4585 .13412 .45086 .12409 Mtetra
.665 .729 .897 r
.45086 .12409 .4585 .13412 .47187 .12874 .46427 .11881 Mtetra
.665 .732 .9 r
.46427 .11881 .47187 .12874 .48531 .12338 .47775 .11352 Mtetra
.665 .735 .902 r
.47775 .11352 .48531 .12338 .49882 .11803 .4913 .10823 Mtetra
.665 .737 .904 r
.4913 .10823 .49882 .11803 .51239 .11271 .50491 .10293 Mtetra
.664 .739 .906 r
.50491 .10293 .51239 .11271 .52603 .10741 .51859 .09762 Mtetra
.664 .74 .907 r
.51859 .09762 .52603 .10741 .53973 .1021 .53234 .09229 Mtetra
.664 .741 .907 r
.53234 .09229 .53973 .1021 .5535 .09679 .54616 .08695 Mtetra
.664 .741 .908 r
.54616 .08695 .5535 .09679 .56734 .09147 .56005 .08158 Mtetra
.56005 .08158 .56734 .09147 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25895 .09176 .25057 Mtetra
.09176 .25057 .10047 .25895 .1122 .25442 .10352 .246 Mtetra
.663 .741 .908 r
.10352 .246 .1122 .25442 .12399 .24988 .11534 .24142 Mtetra
.11534 .24142 .12399 .24988 .13583 .24531 .12721 .23681 Mtetra
.12721 .23681 .13583 .24531 .14773 .24073 .13914 .23218 Mtetra
.13914 .23218 .14773 .24073 .15968 .23612 .15112 .22753 Mtetra
.15112 .22753 .15968 .23612 .17169 .2315 .16316 .22286 Mtetra
.16316 .22286 .17169 .2315 .18375 .22685 .17526 .21817 Mtetra
.663 .741 .907 r
.17526 .21817 .18375 .22685 .19587 .22218 .18741 .21345 Mtetra
.18741 .21345 .19587 .22218 .20805 .21748 .19963 .20871 Mtetra
.664 .741 .907 r
.19963 .20871 .20805 .21748 .22029 .21275 .2119 .20395 Mtetra
.2119 .20395 .22029 .21275 .23258 .20801 .22422 .19916 Mtetra
.663 .74 .907 r
.22422 .19916 .23258 .20801 .24494 .20325 .23661 .19435 Mtetra
.23661 .19435 .24494 .20325 .25735 .19847 .24906 .18952 Mtetra
.24906 .18952 .25735 .19847 .26982 .19369 .26156 .18467 Mtetra
.663 .739 .907 r
.26156 .18467 .26982 .19369 .28234 .18889 .27413 .17981 Mtetra
.663 .739 .906 r
.27413 .17981 .28234 .18889 .29493 .18409 .28675 .17493 Mtetra
.662 .738 .906 r
.28675 .17493 .29493 .18409 .30757 .17929 .29944 .17003 Mtetra
.662 .736 .905 r
.29944 .17003 .30757 .17929 .32028 .17447 .31218 .16512 Mtetra
.662 .735 .904 r
.31218 .16512 .32028 .17447 .33305 .16964 .32499 .16018 Mtetra
.662 .733 .903 r
.32499 .16018 .33305 .16964 .34588 .16479 .33786 .15523 Mtetra
.662 .732 .902 r
.33786 .15523 .34588 .16479 .35877 .1599 .3508 .15024 Mtetra
.662 .731 .901 r
.3508 .15024 .35877 .1599 .37173 .15497 .36379 .14522 Mtetra
.662 .73 .9 r
.36379 .14522 .37173 .15497 .38476 .14997 .37686 .14016 Mtetra
.663 .73 .899 r
.37686 .14016 .38476 .14997 .39785 .1449 .38998 .13506 Mtetra
.38998 .13506 .39785 .1449 .411 .13977 .40318 .12992 Mtetra
.664 .731 .9 r
.40318 .12992 .411 .13977 .42422 .13458 .41643 .12474 Mtetra
.664 .732 .901 r
.41643 .12474 .42422 .13458 .43751 .12935 .42976 .11952 Mtetra
.664 .734 .902 r
.42976 .11952 .43751 .12935 .45086 .12409 .44315 .11428 Mtetra
.664 .736 .903 r
.44315 .11428 .45086 .12409 .46427 .11881 .4566 .10902 Mtetra
.664 .737 .904 r
.4566 .10902 .46427 .11881 .47775 .11352 .47012 .10374 Mtetra
.664 .739 .906 r
.47012 .10374 .47775 .11352 .4913 .10823 .48371 .09844 Mtetra
.664 .74 .906 r
.48371 .09844 .4913 .10823 .50491 .10293 .49737 .09312 Mtetra
.664 .74 .907 r
.49737 .09312 .50491 .10293 .51859 .09762 .51109 .08778 Mtetra
.664 .741 .907 r
.51109 .08778 .51859 .09762 .53234 .09229 .52489 .08241 Mtetra
.664 .741 .908 r
.52489 .08241 .53234 .09229 .54616 .08695 .53875 .07703 Mtetra
.53875 .07703 .54616 .08695 .56005 .08158 .55268 .07162 Mtetra
.55268 .07162 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23752 Mtetra
.09476 .23752 .10352 .246 .11534 .24142 .10661 .23289 Mtetra
.663 .741 .908 r
.10661 .23289 .11534 .24142 .12721 .23681 .11851 .22824 Mtetra
.11851 .22824 .12721 .23681 .13914 .23218 .13047 .22357 Mtetra
.13047 .22357 .13914 .23218 .15112 .22753 .14249 .21888 Mtetra
.14249 .21888 .15112 .22753 .16316 .22286 .15456 .21417 Mtetra
.15456 .21417 .16316 .22286 .17526 .21817 .16669 .20943 Mtetra
.16669 .20943 .17526 .21817 .18741 .21345 .17888 .20467 Mtetra
.664 .741 .908 r
.17888 .20467 .18741 .21345 .19963 .20871 .19112 .19989 Mtetra
.19112 .19989 .19963 .20871 .2119 .20395 .20343 .19508 Mtetra
.20343 .19508 .2119 .20395 .22422 .19916 .21579 .19025 Mtetra
.21579 .19025 .22422 .19916 .23661 .19435 .22821 .1854 Mtetra
.22821 .1854 .23661 .19435 .24906 .18952 .24069 .18052 Mtetra
.663 .741 .908 r
.24069 .18052 .24906 .18952 .26156 .18467 .25323 .17563 Mtetra
.25323 .17563 .26156 .18467 .27413 .17981 .26583 .17071 Mtetra
.663 .74 .907 r
.26583 .17071 .27413 .17981 .28675 .17493 .2785 .16577 Mtetra
.2785 .16577 .28675 .17493 .29944 .17003 .29122 .16081 Mtetra
.29122 .16081 .29944 .17003 .31218 .16512 .304 .15583 Mtetra
.663 .739 .906 r
.304 .15583 .31218 .16512 .32499 .16018 .31685 .15083 Mtetra
.663 .738 .906 r
.31685 .15083 .32499 .16018 .33786 .15523 .32976 .1458 Mtetra
.32976 .1458 .33786 .15523 .3508 .15024 .34273 .14075 Mtetra
.663 .737 .905 r
.34273 .14075 .3508 .15024 .36379 .14522 .35577 .13566 Mtetra
.35577 .13566 .36379 .14522 .37686 .14016 .36887 .13055 Mtetra
.663 .737 .904 r
.36887 .13055 .37686 .14016 .38998 .13506 .38204 .1254 Mtetra
.38204 .1254 .38998 .13506 .40318 .12992 .39527 .12023 Mtetra
.664 .737 .905 r
.39527 .12023 .40318 .12992 .41643 .12474 .40857 .11502 Mtetra
.664 .738 .905 r
.40857 .11502 .41643 .12474 .42976 .11952 .42193 .10979 Mtetra
.664 .738 .906 r
.42193 .10979 .42976 .11952 .44315 .11428 .43536 .10453 Mtetra
.664 .739 .906 r
.43536 .10453 .44315 .11428 .4566 .10902 .44886 .09924 Mtetra
.664 .74 .907 r
.44886 .09924 .4566 .10902 .47012 .10374 .46242 .09393 Mtetra
.46242 .09393 .47012 .10374 .48371 .09844 .47605 .0886 Mtetra
.664 .741 .907 r
.47605 .0886 .48371 .09844 .49737 .09312 .48975 .08324 Mtetra
.664 .741 .908 r
.48975 .08324 .49737 .09312 .51109 .08778 .50352 .07786 Mtetra
.50352 .07786 .51109 .08778 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07703 .53127 .06702 Mtetra
.53127 .06702 .53875 .07703 .55268 .07162 .54525 .06156 Mtetra
.54525 .06156 .55268 .07162 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.3968 .23262 m
.4226 .22309 L
.4484 .21908 L
.4742 .21974 L
.5 .2272 L
.51389 .242 L
.52207 .2678 L
.51502 .2936 L
.5 .31355 L
.49428 .3194 L
.4742 .33503 L
.4508 .3452 L
.4484 .34602 L
.4226 .35312 L
.3968 .35492 L
.371 .3501 L
.35888 .3452 L
.3452 .3325 L
.33787 .3194 L
.33774 .2936 L
.3452 .27681 L
.35118 .2678 L
.371 .24646 L
.38 .242 L
.3968 .23262 L
s
.3452 .64994 m
.371 .64651 L
.3968 .64836 L
.4226 .6544 L
.42401 .6548 L
.4484 .663 L
.4742 .67913 L
.47605 .6806 L
.5 .70339 L
.50139 .7064 L
.51129 .7322 L
.50317 .758 L
.5 .76134 L
.4742 .77842 L
.4484 .78086 L
.4226 .77959 L
.3968 .77447 L
.371 .7648 L
.35767 .758 L
.3452 .75255 L
.3237 .7322 L
.3194 .72711 L
.30719 .7064 L
.30621 .6806 L
.3194 .66259 L
.32995 .6548 L
.3452 .64994 L
s
.629 .26591 m
.6548 .26753 L
.65587 .2678 L
.6806 .27756 L
.70386 .2936 L
.7064 .29673 L
.72626 .3194 L
.7322 .32671 L
.74024 .3452 L
.74783 .371 L
.74768 .3968 L
.7322 .42232 L
.73187 .4226 L
.7064 .4334 L
.6806 .43052 L
.66145 .4226 L
.6548 .41919 L
.629 .39863 L
.62717 .3968 L
.60686 .371 L
.6032 .36371 L
.59494 .3452 L
.58963 .3194 L
.59314 .2936 L
.6032 .27483 L
.62121 .2678 L
.629 .26591 L
s
.7064 .52436 m
.73177 .5258 L
.7322 .52593 L
.75706 .5516 L
.758 .55407 L
.76246 .5774 L
.76036 .6032 L
.758 .61354 L
.75367 .629 L
.74167 .6548 L
.7322 .66971 L
.72481 .6806 L
.7064 .69854 L
.69607 .7064 L
.6806 .71567 L
.6548 .72268 L
.629 .7161 L
.61604 .7064 L
.60735 .6806 L
.607 .6548 L
.61175 .629 L
.62164 .6032 L
.629 .58885 L
.6358 .5774 L
.6548 .5551 L
.65621 .5516 L
.6806 .53443 L
.70057 .5258 L
.7064 .52436 L
s
.242 .3966 m
.2678 .38725 L
.29304 .3968 L
.2936 .39721 L
.31521 .4226 L
.3194 .4299 L
.32753 .4484 L
.33448 .4742 L
.33743 .5 L
.33702 .5258 L
.33285 .5516 L
.3226 .5774 L
.3194 .58264 L
.30073 .6032 L
.2936 .60718 L
.2678 .6086 L
.2563 .6032 L
.242 .59102 L
.23019 .5774 L
.21858 .5516 L
.2162 .54251 L
.21243 .5258 L
.20897 .5 L
.20912 .4742 L
.21325 .4484 L
.2162 .43713 L
.21879 .4226 L
.24176 .3968 L
.242 .3966 L
s
0 g
.03 w
.42899 .28696 Mdot
.40798 .7135 Mdot
.66913 .34927 Mdot
.68474 .62287 Mdot
.27289 .49878 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.67647 .61243 m
.69608 .60333 L
.69968 .61765 L
.69608 .62772 L
.68853 .63725 L
.67647 .64203 L
.67088 .63725 L
.67332 .61765 L
.67647 .61243 L
s
.63725 .31587 m
.65686 .30893 L
.67647 .32158 L
.67974 .32353 L
.69559 .34314 L
.69608 .344 L
.70492 .36275 L
.69852 .38235 L
.69608 .38595 L
.67647 .38625 L
.66889 .38235 L
.65686 .37712 L
.64644 .36275 L
.63725 .34796 L
.6349 .34314 L
.63075 .32353 L
.63725 .31587 L
s
.42157 .26361 m
.44118 .25713 L
.46078 .26194 L
.46917 .26471 L
.47289 .28431 L
.46078 .29779 L
.45525 .30392 L
.44118 .31133 L
.42157 .31377 L
.40196 .31187 L
.3882 .30392 L
.39322 .28431 L
.40196 .27552 L
.41839 .26471 L
.42157 .26361 L
s
.69608 .56824 m
.71569 .56998 L
.7212 .57843 L
.72718 .59804 L
.72282 .61765 L
.71569 .63402 L
.714 .63725 L
.70085 .65686 L
.69608 .66073 L
.67647 .67353 L
.65686 .67307 L
.64537 .65686 L
.64333 .63725 L
.65017 .61765 L
.65686 .60287 L
.66149 .59804 L
.67647 .58038 L
.6792 .57843 L
.69608 .56824 L
s
.61765 .29596 m
.63725 .28987 L
.65686 .29439 L
.67536 .30392 L
.67647 .30452 L
.69608 .32133 L
.69804 .32353 L
.71201 .34314 L
.71569 .35223 L
.71937 .36275 L
.72191 .38235 L
.71569 .40062 L
.71466 .40196 L
.69608 .41 L
.67647 .40442 L
.67176 .40196 L
.65686 .39234 L
.64477 .38235 L
.63725 .37367 L
.62919 .36275 L
.61811 .34314 L
.61765 .34195 L
.61105 .32353 L
.61096 .30392 L
.61765 .29596 L
s
.46078 .24466 m
.46455 .2451 L
.48039 .24896 L
.5 .26426 L
.50022 .26471 L
.5 .28051 L
.49811 .28431 L
.48039 .30271 L
.47886 .30392 L
.46078 .31667 L
.44118 .32348 L
.44075 .32353 L
.42157 .32852 L
.40196 .33007 L
.38235 .32634 L
.3768 .32353 L
.36575 .30392 L
.37271 .28431 L
.38235 .2729 L
.39153 .26471 L
.40196 .25745 L
.42157 .24848 L
.44118 .24513 L
.44192 .2451 L
.46078 .24466 L
s
.34314 .66589 m
.36275 .66652 L
.38235 .67273 L
.39564 .67647 L
.40196 .6793 L
.42157 .68448 L
.4362 .69608 L
.44118 .70034 L
.45401 .71569 L
.45103 .73529 L
.44118 .73998 L
.42157 .74611 L
.40196 .74222 L
.38267 .73529 L
.38235 .73517 L
.36275 .72543 L
.34845 .71569 L
.34314 .71063 L
.33048 .69608 L
.32459 .67647 L
.34314 .66589 L
s
.69608 .54599 m
.71569 .54063 L
.73529 .55546 L
.73695 .55882 L
.74148 .57843 L
.74074 .59804 L
.73639 .61765 L
.73529 .62173 L
.72909 .63725 L
.71717 .65686 L
.71569 .65887 L
.70024 .67647 L
.69608 .67974 L
.67647 .69218 L
.66358 .69608 L
.65686 .69683 L
.64944 .69608 L
.63725 .69152 L
.62847 .67647 L
.62691 .65686 L
.62998 .63725 L
.6364 .61765 L
.63725 .61541 L
.64557 .59804 L
.65686 .58148 L
.6586 .57843 L
.67647 .56019 L
.67806 .55882 L
.69608 .54599 L
s
.26471 .43399 m
.28431 .43636 L
.28835 .44118 L
.29763 .46078 L
.30243 .48039 L
.30392 .49228 L
.30445 .5 L
.30392 .5172 L
.3037 .51961 L
.30011 .53922 L
.29225 .55882 L
.28431 .56737 L
.26471 .56096 L
.26286 .55882 L
.25129 .53922 L
.2451 .52054 L
.2449 .51961 L
.24168 .5 L
.24214 .48039 L
.2451 .4663 L
.24672 .46078 L
.25698 .44118 L
.26471 .43399 L
s
.59804 .27105 m
.61765 .27178 L
.63725 .27429 L
.65686 .2805 L
.66677 .28431 L
.67647 .29061 L
.69422 .30392 L
.69608 .3058 L
.71218 .32353 L
.71569 .32806 L
.72447 .34314 L
.73247 .36275 L
.73529 .37498 L
.73637 .38235 L
.73592 .40196 L
.73529 .4051 L
.72823 .42157 L
.71569 .43062 L
.69608 .4294 L
.67836 .42157 L
.67647 .42051 L
.65686 .4071 L
.65026 .40196 L
.63725 .38943 L
.63074 .38235 L
.61765 .36556 L
.61576 .36275 L
.6036 .34314 L
.59804 .33597 L
.59356 .32353 L
.58524 .30392 L
.58429 .28431 L
.59804 .27105 L
s
.42157 .23802 m
.44118 .23349 L
.46078 .23191 L
.48039 .23321 L
.5 .23817 L
.51322 .2451 L
.51961 .24919 L
.53375 .26471 L
.5291 .28431 L
.51961 .29219 L
.50229 .30392 L
.5 .30615 L
.48039 .31851 L
.46939 .32353 L
.46078 .32761 L
.44118 .33513 L
.42157 .34 L
.40196 .34236 L
.38235 .34239 L
.36275 .34146 L
.34555 .32353 L
.34557 .30392 L
.35515 .28431 L
.36275 .2722 L
.37285 .26471 L
.38235 .25687 L
.40196 .24569 L
.4032 .2451 L
.42157 .23802 L
s
.71569 .50637 m
.73529 .50911 L
.74289 .51961 L
.75283 .53922 L
.7549 .55813 L
.75498 .55882 L
.75566 .57843 L
.7549 .58831 L
.75359 .59804 L
.74887 .61765 L
.74136 .63725 L
.73529 .64945 L
.73095 .65686 L
.71649 .67647 L
.71569 .67739 L
.6962 .69608 L
.69608 .69617 L
.67647 .70868 L
.65686 .71552 L
.65597 .71569 L
.63725 .71598 L
.63589 .71569 L
.61765 .70534 L
.61343 .69608 L
.61066 .67647 L
.61258 .65686 L
.61709 .63725 L
.61765 .6351 L
.62373 .61765 L
.63292 .59804 L
.63725 .59027 L
.64466 .57843 L
.65686 .56239 L
.65949 .55882 L
.67647 .54072 L
.67678 .53922 L
.69608 .52215 L
.69873 .51961 L
.71569 .50637 L
s
.26471 .39567 m
.28431 .38639 L
.30097 .40196 L
.30392 .41329 L
.30676 .42157 L
.31153 .44118 L
.3154 .46078 L
.31815 .48039 L
.31955 .5 L
.31953 .51961 L
.31825 .53922 L
.31617 .55882 L
.31442 .57843 L
.31639 .59804 L
.31939 .61765 L
.32353 .62351 L
.34238 .63725 L
.34314 .63911 L
.36275 .64882 L
.38235 .65661 L
.38304 .65686 L
.40196 .66341 L
.42157 .67146 L
.43211 .67647 L
.44118 .68013 L
.46078 .69373 L
.46337 .69608 L
.48039 .71461 L
.48104 .71569 L
.48445 .73529 L
.48039 .74274 L
.46151 .7549 L
.46078 .75515 L
.44118 .7592 L
.42157 .75901 L
.40196 .75591 L
.39696 .7549 L
.38235 .75085 L
.36275 .74267 L
.34925 .73529 L
.34314 .73237 L
.32353 .71729 L
.3218 .71569 L
.30392 .69705 L
.30325 .69608 L
.29059 .67647 L
.28431 .66228 L
.28241 .65686 L
.27339 .63725 L
.26848 .61765 L
Mistroke
.26471 .60993 L
.25639 .59804 L
.24886 .57843 L
.2451 .57028 L
.24002 .55882 L
.23331 .53922 L
.22914 .51961 L
.22716 .5 L
.22712 .48039 L
.2291 .46078 L
.23385 .44118 L
.24324 .42157 L
.2451 .41872 L
.2579 .40196 L
.26471 .39567 L
Mfstroke
.44118 .22328 m
.46078 .22123 L
.48039 .22156 L
.5 .22433 L
.50543 .22549 L
.51961 .22864 L
.53922 .23541 L
.55882 .24382 L
.56254 .2451 L
.57843 .24779 L
.59804 .25181 L
.61765 .25523 L
.63725 .26015 L
.6517 .26471 L
.65686 .26747 L
.67647 .27791 L
.68625 .28431 L
.69608 .2922 L
.70857 .30392 L
.71569 .31188 L
.72455 .32353 L
.73529 .3413 L
.73619 .34314 L
.74442 .36275 L
.74949 .38235 L
.75149 .40196 L
.75046 .42157 L
.74689 .44118 L
.73529 .45707 L
.73254 .46078 L
.71569 .46395 L
.70979 .46078 L
.69608 .45022 L
.68183 .44118 L
.67647 .43704 L
.65686 .42164 L
.65678 .42157 L
.63725 .40393 L
.63525 .40196 L
.61765 .38242 L
.61759 .38235 L
.60274 .36275 L
.59804 .35633 L
.5893 .34314 L
.57843 .3291 L
.5754 .32353 L
.55882 .31234 L
.53922 .30772 L
.51961 .31263 L
.5 .32094 L
Mistroke
.49369 .32353 L
.48039 .3301 L
.46078 .33862 L
.44842 .34314 L
.44118 .34541 L
.42157 .35048 L
.40196 .35384 L
.38235 .3558 L
.36275 .35676 L
.34314 .35701 L
.32353 .35263 L
.31717 .34314 L
.31858 .32353 L
.32353 .30942 L
.32603 .30392 L
.3382 .28431 L
.34314 .27738 L
.35589 .26471 L
.36275 .2585 L
.38196 .2451 L
.38235 .24486 L
.40196 .2347 L
.42157 .22768 L
.4278 .22549 L
.44118 .22328 L
Mfstroke
.40196 .22419 m
.42157 .21752 L
.44118 .21303 L
.46078 .2106 L
.48039 .21013 L
.5 .21152 L
.51961 .21464 L
.53922 .21926 L
.55882 .22473 L
.56155 .22549 L
.57843 .22984 L
.59804 .23488 L
.61765 .24015 L
.63351 .2451 L
.63725 .24649 L
.65686 .25468 L
.67553 .26471 L
.67647 .26532 L
.69608 .27914 L
.70233 .28431 L
.71569 .29715 L
.72179 .30392 L
.73529 .32158 L
.73657 .32353 L
.74784 .34314 L
.7549 .35904 L
.75619 .36275 L
.76195 .38235 L
.76535 .40196 L
.76655 .42157 L
.76596 .44118 L
.76452 .46078 L
.76381 .48039 L
.76502 .5 L
.76731 .51961 L
.76926 .53922 L
.76993 .55882 L
.76884 .57843 L
.76577 .59804 L
.76062 .61765 L
.7549 .63363 L
.75328 .63725 L
.74345 .65686 L
.73529 .66995 L
.7307 .67647 L
.71569 .69426 L
.71402 .69608 L
.69608 .7119 L
.69162 .71569 L
.67647 .72453 L
Mistroke
.65686 .73282 L
.64709 .73529 L
.63725 .73676 L
.61765 .73575 L
.61567 .73529 L
.59804 .72907 L
.5916 .71569 L
.59023 .69608 L
.59356 .67647 L
.59804 .65807 L
.59837 .65686 L
.60439 .63725 L
.6117 .61765 L
.61765 .60404 L
.62065 .59804 L
.63174 .57843 L
.63725 .56993 L
.64497 .55882 L
.65686 .54339 L
.65991 .53922 L
.6748 .51961 L
.67647 .51721 L
.68463 .5 L
.68654 .48039 L
.67775 .46078 L
.67647 .45796 L
.66048 .44118 L
.65686 .43727 L
.64034 .42157 L
.63725 .41844 L
.62133 .40196 L
.61765 .39785 L
.60464 .38235 L
.59804 .37409 L
.58942 .36275 L
.57843 .34956 L
.57345 .34314 L
.55882 .33207 L
.53922 .32535 L
.51961 .32715 L
.5 .33353 L
.48039 .34145 L
.47617 .34314 L
.46078 .34915 L
.44118 .35575 L
.42157 .36098 L
.41381 .36275 L
.40196 .36506 L
.38235 .36873 L
.36275 .3733 L
Mistroke
.34314 .38219 L
.34292 .38235 L
.32897 .40196 L
.32603 .42157 L
.32677 .44118 L
.32871 .46078 L
.33062 .48039 L
.3318 .5 L
.332 .51961 L
.33137 .53922 L
.33058 .55882 L
.33105 .57843 L
.3352 .59804 L
.34314 .6138 L
.3467 .61765 L
.36275 .63129 L
.3731 .63725 L
.38235 .64184 L
.40196 .65026 L
.41815 .65686 L
.42157 .65824 L
.44118 .6669 L
.45919 .67647 L
.46078 .67725 L
.48039 .68951 L
.48835 .69608 L
.5 .70587 L
.50842 .71569 L
.5173 .73529 L
.50535 .7549 L
.5 .7599 L
.48039 .76856 L
.46078 .77203 L
.44118 .77306 L
.42157 .77189 L
.40196 .7686 L
.38235 .76324 L
.36275 .75588 L
.36045 .7549 L
.34314 .74669 L
.32432 .73529 L
.32353 .73481 L
.30392 .7199 L
.29938 .71569 L
.28431 .69968 L
.28158 .69608 L
.26884 .67647 L
.26471 .6683 L
.25956 .65686 L
.25192 .63725 L
Mistroke
.24532 .61765 L
.2451 .61689 L
.23812 .59804 L
.23116 .57843 L
.22549 .55932 L
.22535 .55882 L
.22029 .53922 L
.21673 .51961 L
.2148 .5 L
.21459 .48039 L
.21621 .46078 L
.21982 .44118 L
.22549 .42219 L
.22568 .42157 L
.23354 .40196 L
.2451 .38327 L
.24544 .38235 L
.26056 .36275 L
.26471 .35816 L
.27733 .34314 L
.28431 .3342 L
.29198 .32353 L
.30392 .30578 L
.30557 .30392 L
.32059 .28431 L
.32353 .28069 L
.33899 .26471 L
.34314 .2608 L
.36275 .24535 L
.36312 .2451 L
.38235 .23329 L
.39874 .22549 L
.40196 .22419 L
Mfstroke
.51961 .34103 m
.53922 .34115 L
.5464 .34314 L
.55882 .3496 L
.57436 .36275 L
.57843 .36769 L
.59109 .38235 L
.59804 .39085 L
.60754 .40196 L
.61765 .4133 L
.62523 .42157 L
.63725 .43418 L
.64342 .44118 L
.65686 .45726 L
.65874 .46078 L
.66676 .48039 L
.66572 .5 L
.65721 .51961 L
.65686 .52029 L
.64448 .53922 L
.63725 .54986 L
.63111 .55882 L
.61882 .57843 L
.61765 .58044 L
.60827 .59804 L
.59916 .61765 L
.59804 .62018 L
.59117 .63725 L
.58314 .65686 L
.57843 .66676 L
.57471 .67647 L
.55882 .69461 L
.55684 .69608 L
.53922 .69766 L
.52378 .69608 L
.51961 .69425 L
.5 .68394 L
.48554 .67647 L
.48039 .67337 L
.46078 .66306 L
.44769 .65686 L
.44118 .6539 L
.42157 .64541 L
.4029 .63725 L
.40196 .63683 L
.38235 .62673 L
.3697 .61765 L
.36275 .61137 L
.35354 .59804 L
.34671 .57843 L
Mistroke
.34451 .55882 L
.34422 .53922 L
.34428 .51961 L
.34392 .5 L
.34314 .48185 L
.34297 .48039 L
.3418 .46078 L
.34132 .44118 L
.34314 .42256 L
.34334 .42157 L
.35205 .40196 L
.36275 .39172 L
.38235 .38268 L
.38336 .38235 L
.40196 .37692 L
.42157 .37187 L
.44118 .3664 L
.45292 .36275 L
.46078 .36004 L
.48039 .35284 L
.5 .34587 L
.50943 .34314 L
.51961 .34103 L
Mfstroke
.44118 .20252 m
.46078 .19981 L
.48039 .19875 L
.5 .19926 L
.51961 .20123 L
.53922 .20449 L
.54613 .20588 L
.55882 .2087 L
.57843 .21365 L
.59804 .21916 L
.61765 .22534 L
.6181 .22549 L
.63725 .23261 L
.65686 .24144 L
.66408 .2451 L
.67647 .2523 L
.69474 .26471 L
.69608 .26574 L
.71569 .28263 L
.71741 .28431 L
.73502 .30392 L
.73529 .30426 L
.7489 .32353 L
.7549 .33352 L
.75986 .34314 L
.76838 .36275 L
.77451 .38148 L
.77473 .38235 L
.77908 .40196 L
.78172 .42157 L
.78297 .44118 L
.78336 .46078 L
.78358 .48039 L
.78403 .5 L
.78459 .51961 L
.78472 .53922 L
.78389 .55882 L
.78173 .57843 L
.77803 .59804 L
.77451 .612 L
.77265 .61765 L
.76534 .63725 L
.75598 .65686 L
.7549 .65888 L
.74419 .67647 L
.73529 .68885 L
.72949 .69608 L
.71569 .71095 L
.71082 .71569 L
.69608 .72786 L
Mistroke
.68579 .73529 L
.67647 .74071 L
.65686 .75004 L
.64375 .7549 L
.63725 .75612 L
.61765 .75925 L
.59804 .76001 L
.57843 .76003 L
.55882 .76285 L
.53922 .77001 L
.51961 .77444 L
.51915 .77451 L
.5 .78031 L
.48039 .78414 L
.46078 .78596 L
.44118 .78591 L
.42157 .78408 L
.40196 .78055 L
.38235 .7754 L
.37943 .77451 L
.36275 .76863 L
.34314 .76013 L
.33272 .7549 L
.32353 .74985 L
.30392 .73715 L
.30139 .73529 L
.28431 .72122 L
.27868 .71569 L
.26471 .6996 L
.26215 .69608 L
.25011 .67647 L
.2451 .66601 L
.24124 .65686 L
.23419 .63725 L
.22809 .61765 L
.22549 .60877 L
.22234 .59804 L
.21675 .57843 L
.21171 .55882 L
.20756 .53922 L
.20588 .52994 L
.20454 .51961 L
.20281 .5 L
.20249 .48039 L
.20366 .46078 L
.20588 .44337 L
.2064 .44118 L
.21079 .42157 L
.21711 .40196 L
.22549 .38273 L
Mistroke
.22567 .38235 L
.23654 .36275 L
.2451 .35024 L
.25032 .34314 L
.26471 .32541 L
.2663 .32353 L
.28333 .30392 L
.28431 .3028 L
.30117 .28431 L
.30392 .28138 L
.3209 .26471 L
.32353 .26227 L
.34314 .24603 L
.34441 .2451 L
.36275 .23264 L
.37521 .22549 L
.38235 .22188 L
.40196 .21339 L
.42157 .20696 L
.42515 .20588 L
.44118 .20252 L
Mfstroke
.5 .35886 m
.51961 .35519 L
.53922 .35699 L
.55224 .36275 L
.55882 .36716 L
.57548 .38235 L
.57843 .38585 L
.59269 .40196 L
.59804 .40821 L
.60975 .42157 L
.61765 .43035 L
.62674 .44118 L
.63725 .45395 L
.64099 .46078 L
.64875 .48039 L
.64818 .5 L
.64058 .51961 L
.63725 .52639 L
.62914 .53922 L
.61765 .55739 L
.61675 .55882 L
.60522 .57843 L
.59804 .59168 L
.59488 .59804 L
.58545 .61765 L
.57843 .6319 L
.57598 .63725 L
.56416 .65686 L
.55882 .66233 L
.53922 .67369 L
.51961 .67306 L
.5 .66662 L
.48039 .65801 L
.47781 .65686 L
.46078 .6491 L
.44118 .6404 L
.43398 .63725 L
.42157 .63187 L
.40196 .62216 L
.39448 .61765 L
.38235 .6089 L
.37258 .59804 L
.36276 .57843 L
.36275 .57841 L
.35882 .55882 L
.35753 .53922 L
.35708 .51961 L
.35657 .5 L
.35584 .48039 L
.35537 .46078 L
Mistroke
.35639 .44118 L
.36159 .42157 L
.36275 .41888 L
.37803 .40196 L
.38235 .39908 L
.40196 .39015 L
.42157 .38401 L
.42733 .38235 L
.44118 .37809 L
.46078 .37168 L
.48039 .36501 L
.48576 .36275 L
.5 .35886 L
Mfstroke
.40196 .2018 m
.42157 .19565 L
.44118 .19108 L
.46078 .18806 L
.48039 .18651 L
.5 .18633 L
.51961 .18745 L
.53922 .18977 L
.55882 .19323 L
.57843 .19775 L
.59804 .20328 L
.60621 .20588 L
.61765 .2099 L
.63725 .21776 L
.65391 .22549 L
.65686 .22701 L
.67647 .23812 L
.68736 .2451 L
.69608 .25135 L
.71273 .26471 L
.71569 .26735 L
.73279 .28431 L
.73529 .28708 L
.74898 .30392 L
.7549 .31214 L
.76217 .32353 L
.773 .34314 L
.77451 .34616 L
.7816 .36275 L
.78845 .38235 L
.79364 .40196 L
.79412 .40387 L
.79725 .42157 L
.79959 .44118 L
.80091 .46078 L
.8015 .48039 L
.80159 .5 L
.80119 .51961 L
.80017 .53922 L
.79831 .55882 L
.79539 .57843 L
.79412 .58545 L
.79118 .59804 L
.78548 .61765 L
.77825 .63725 L
.77451 .64607 L
.76926 .65686 L
.75822 .67647 L
.7549 .68176 L
.74483 .69608 L
Mistroke
.73529 .70804 L
.72855 .71569 L
.71569 .72862 L
.70833 .73529 L
.69608 .74505 L
.68189 .7549 L
.67647 .75812 L
.65686 .76823 L
.64106 .77451 L
.63725 .77567 L
.61765 .78076 L
.59804 .78408 L
.57843 .78649 L
.55882 .78895 L
.53922 .79184 L
.52452 .79412 L
.51961 .7949 L
.5 .7976 L
.48039 .79932 L
.46078 .79981 L
.44118 .79895 L
.42157 .79671 L
.40622 .79412 L
.40196 .7931 L
.38235 .78801 L
.36275 .78157 L
.34472 .77451 L
.34314 .77382 L
.32353 .76445 L
.30645 .7549 L
.30392 .75335 L
.28431 .73977 L
.27871 .73529 L
.26471 .72258 L
.25825 .71569 L
.2451 .69899 L
.24316 .69608 L
.23205 .67647 L
.22549 .66136 L
.2238 .65686 L
.21739 .63725 L
.21196 .61765 L
.207 .59804 L
.20588 .59347 L
.20237 .57843 L
.19814 .55882 L
.19455 .53922 L
.19186 .51961 L
.19024 .5 L
.18983 .48039 L
Mistroke
.19069 .46078 L
.19287 .44118 L
.19643 .42157 L
.20149 .40196 L
.20588 .38854 L
.2082 .38235 L
.21695 .36275 L
.22549 .34737 L
.22812 .34314 L
.24217 .32353 L
.2451 .31991 L
.25923 .30392 L
.26471 .29819 L
.27873 .28431 L
.28431 .27902 L
.30014 .26471 L
.30392 .26142 L
.32353 .24546 L
.32401 .2451 L
.34314 .23149 L
.35256 .22549 L
.36275 .21961 L
.38235 .2097 L
.39105 .20588 L
.40196 .2018 L
Mfstroke
.48039 .37889 m
.5 .37339 L
.51961 .37096 L
.53922 .3745 L
.556 .38235 L
.55882 .38649 L
.57506 .40196 L
.57843 .40586 L
.59237 .42157 L
.59804 .4281 L
.60873 .44118 L
.61765 .45223 L
.62238 .46078 L
.63008 .48039 L
.62991 .5 L
.623 .51961 L
.61765 .53078 L
.61242 .53922 L
.60077 .55882 L
.59804 .56349 L
.58977 .57843 L
.57916 .59804 L
.57843 .59938 L
.56889 .61765 L
.55882 .63244 L
.55704 .63725 L
.53922 .64931 L
.51961 .65264 L
.5 .64883 L
.48039 .6418 L
.46901 .63725 L
.46078 .63377 L
.44118 .62536 L
.42494 .61765 L
.42157 .61602 L
.40196 .60403 L
.39512 .59804 L
.38235 .58144 L
.38097 .57843 L
.37478 .55882 L
.37234 .53922 L
.37134 .51961 L
.37072 .5 L
.37029 .48039 L
.3707 .46078 L
.37372 .44118 L
.38235 .42271 L
.38364 .42157 L
.40196 .40672 L
.41288 .40196 L
Mistroke
.42157 .39845 L
.44118 .39158 L
.46078 .38521 L
.46957 .38235 L
.48039 .37889 L
Mfstroke
.42157 .18253 m
.44118 .17802 L
.46078 .17476 L
.48039 .17274 L
.5 .17193 L
.51961 .1723 L
.53922 .17386 L
.55882 .17662 L
.57843 .18063 L
.59804 .18591 L
.59925 .18627 L
.61765 .19268 L
.63725 .20083 L
.64813 .20588 L
.65686 .21041 L
.67647 .22166 L
.68263 .22549 L
.69608 .23479 L
.70968 .2451 L
.71569 .25012 L
.73162 .26471 L
.73529 .2684 L
.74972 .28431 L
.7549 .29061 L
.76478 .30392 L
.77451 .31847 L
.77749 .32353 L
.78812 .34314 L
.79412 .35574 L
.79699 .36275 L
.80422 .38235 L
.81006 .40196 L
.81373 .41757 L
.81446 .42157 L
.81748 .44118 L
.81931 .46078 L
.82006 .48039 L
.81987 .5 L
.81885 .51961 L
.81704 .53922 L
.81443 .55882 L
.81373 .56335 L
.81081 .57843 L
.80607 .59804 L
.80018 .61765 L
.79412 .63474 L
.79309 .63725 L
.78425 .65686 L
.77451 .67553 L
.77396 .67647 L
Mistroke
.76153 .69608 L
.7549 .70548 L
.74696 .71569 L
.73529 .72926 L
.72962 .73529 L
.71569 .74871 L
.70864 .7549 L
.69608 .7648 L
.68221 .77451 L
.67647 .77804 L
.65686 .78867 L
.64471 .79412 L
.63725 .79688 L
.61765 .80283 L
.59804 .80692 L
.57843 .80962 L
.55882 .81148 L
.53922 .81298 L
.52847 .81373 L
.51961 .81426 L
.5 .81517 L
.48039 .81549 L
.46078 .81498 L
.44329 .81373 L
.44118 .81351 L
.42157 .81084 L
.40196 .80699 L
.38235 .80201 L
.36275 .79601 L
.3571 .79412 L
.34314 .78874 L
.32353 .7802 L
.31175 .77451 L
.30392 .7703 L
.28431 .75846 L
.27903 .7549 L
.26471 .74403 L
.25475 .73529 L
.2451 .72561 L
.2366 .71569 L
.22549 .70018 L
.223 .69608 L
.21291 .67647 L
.20588 .65851 L
.20534 .65686 L
.19962 .63725 L
.19488 .61765 L
.19063 .59804 L
.18666 .57843 L
.18627 .57645 L
Mistroke
.18315 .55882 L
.18013 .53922 L
.17777 .51961 L
.17629 .5 L
.17581 .48039 L
.17639 .46078 L
.17809 .44118 L
.18094 .42157 L
.18498 .40196 L
.18627 .39668 L
.19048 .38235 L
.19765 .36275 L
.20588 .3448 L
.20675 .34314 L
.21849 .32353 L
.22549 .31375 L
.23345 .30392 L
.2451 .29126 L
.25218 .28431 L
.26471 .27297 L
.27445 .26471 L
.28431 .25676 L
.29945 .2451 L
.30392 .24181 L
.32353 .22805 L
.3274 .22549 L
.34314 .21581 L
.36093 .20588 L
.36275 .20499 L
.38235 .19601 L
.40196 .18839 L
.40814 .18627 L
.42157 .18253 L
Mfstroke
.48039 .39631 m
.5 .39158 L
.51961 .39062 L
.53922 .39639 L
.54997 .40196 L
.55882 .4105 L
.5701 .42157 L
.57843 .43109 L
.58666 .44118 L
.59804 .45686 L
.60008 .46078 L
.60802 .48039 L
.60826 .5 L
.60188 .51961 L
.59804 .52853 L
.59206 .53922 L
.58088 .55882 L
.57843 .56307 L
.57008 .57843 L
.55882 .59686 L
.55824 .59804 L
.543 .61765 L
.53922 .62028 L
.51961 .62871 L
.5 .62776 L
.48039 .62225 L
.46743 .61765 L
.46078 .61487 L
.44118 .60614 L
.42699 .59804 L
.42157 .59473 L
.40492 .57843 L
.40196 .5746 L
.39509 .55882 L
.3909 .53922 L
.38917 .51961 L
.38843 .5 L
.38848 .48039 L
.39032 .46078 L
.39698 .44118 L
.40196 .4331 L
.41625 .42157 L
.42157 .4183 L
.44118 .40926 L
.46078 .40263 L
.46279 .40196 L
.48039 .39631 L
s
.42157 .16571 m
.44118 .16134 L
.46078 .15786 L
.48039 .15538 L
.5 .15397 L
.51961 .15364 L
.53922 .15449 L
.55882 .15659 L
.57843 .16005 L
.59804 .16489 L
.60413 .16667 L
.61765 .17143 L
.63725 .17963 L
.65131 .18627 L
.65686 .18925 L
.67647 .20067 L
.68487 .20588 L
.69608 .21365 L
.71206 .22549 L
.71569 .22844 L
.73485 .2451 L
.73529 .24552 L
.75415 .26471 L
.7549 .26553 L
.77058 .28431 L
.77451 .28938 L
.78466 .30392 L
.79412 .31847 L
.79698 .32353 L
.80755 .34314 L
.81373 .35575 L
.81666 .36275 L
.82429 .38235 L
.83071 .40196 L
.83333 .41135 L
.83558 .42157 L
.83902 .44118 L
.84113 .46078 L
.84193 .48039 L
.8415 .5 L
.84 .51961 L
.83757 .53922 L
.83434 .55882 L
.83333 .56425 L
.83012 .57843 L
.82488 .59804 L
.81876 .61765 L
.81373 .63227 L
.81172 .63725 L
.80307 .65686 L
Mistroke
.79412 .67522 L
.79343 .67647 L
.78183 .69608 L
.77451 .70754 L
.76872 .71569 L
.7549 .7337 L
.75357 .73529 L
.73593 .7549 L
.73529 .75555 L
.71569 .77413 L
.71525 .77451 L
.69608 .78987 L
.69026 .79412 L
.67647 .80306 L
.6573 .81373 L
.65686 .81393 L
.63725 .82223 L
.61765 .8284 L
.59804 .83254 L
.59359 .83333 L
.57843 .83491 L
.55882 .83602 L
.53922 .83635 L
.51961 .83621 L
.5 .83573 L
.48039 .83487 L
.46078 .83351 L
.45854 .83333 L
.44118 .83132 L
.42157 .82823 L
.40196 .82422 L
.38235 .81938 L
.36275 .81389 L
.3622 .81373 L
.34314 .80697 L
.32353 .7992 L
.31152 .79412 L
.30392 .79043 L
.28431 .78001 L
.27487 .77451 L
.26471 .76778 L
.24754 .7549 L
.2451 .75284 L
.22686 .73529 L
.22549 .73379 L
.21112 .71569 L
.20588 .70789 L
.19916 .69608 L
.19006 .67647 L
.18627 .66634 L
Mistroke
.18337 .65686 L
.17838 .63725 L
.17435 .61765 L
.17084 .59804 L
.16758 .57843 L
.16667 .5727 L
.16475 .55882 L
.16228 .53922 L
.16029 .51961 L
.15895 .5 L
.15841 .48039 L
.15875 .46078 L
.16001 .44118 L
.16221 .42157 L
.16537 .40196 L
.16667 .39526 L
.16981 .38235 L
.17567 .36275 L
.18303 .34314 L
.18627 .33571 L
.1925 .32353 L
.20462 .30392 L
.20588 .30212 L
.22033 .28431 L
.22549 .27882 L
.2405 .26471 L
.2451 .26084 L
.26471 .24569 L
.26552 .2451 L
.28431 .23215 L
.29435 .22549 L
.30392 .21949 L
.32353 .2075 L
.32629 .20588 L
.34314 .19682 L
.36275 .18692 L
.36411 .18627 L
.38235 .17883 L
.40196 .17161 L
.41766 .16667 L
.42157 .16571 L
Mfstroke
.5 .42087 m
.51629 .42157 L
.51961 .4222 L
.53922 .43136 L
.55108 .44118 L
.55882 .44996 L
.56608 .46078 L
.57479 .48039 L
.57568 .5 L
.57014 .51961 L
.56024 .53922 L
.55882 .54179 L
.54955 .55882 L
.53922 .57301 L
.53463 .57843 L
.51961 .59086 L
.5 .59518 L
.48039 .59218 L
.46078 .58449 L
.44987 .57843 L
.44118 .57253 L
.42924 .55882 L
.42157 .54044 L
.42127 .53922 L
.41764 .51961 L
.41665 .5 L
.41806 .48039 L
.42157 .46667 L
.42381 .46078 L
.44118 .44148 L
.44181 .44118 L
.46078 .43053 L
.48039 .42413 L
.49438 .42157 L
.5 .42087 L
s
.48039 .12745 m
.5 .12571 L
.51961 .12475 L
.53922 .1248 L
.55882 .126 L
.57263 .12745 L
.57843 .12859 L
.59804 .13306 L
.61765 .1391 L
.63725 .14642 L
.63887 .14706 L
.65686 .15604 L
.67619 .16667 L
.67647 .16684 L
.69608 .17994 L
.70532 .18627 L
.71569 .1943 L
.73021 .20588 L
.73529 .21032 L
.75197 .22549 L
.7549 .22835 L
.77108 .2451 L
.77451 .24886 L
.78787 .26471 L
.79412 .2724 L
.80273 .28431 L
.81373 .29969 L
.81628 .30392 L
.82828 .32353 L
.83333 .3321 L
.8388 .34314 L
.84838 .36275 L
.85294 .37292 L
.85635 .38235 L
.86291 .40196 L
.86824 .42157 L
.87205 .44118 L
.87255 .44233 L
.87407 .46078 L
.87471 .48039 L
.8741 .5 L
.87255 .51917 L
.87236 .51961 L
.86922 .53922 L
.86507 .55882 L
.86013 .57843 L
.85475 .59804 L
.85294 .60457 L
.84831 .61765 L
.84076 .63725 L
Mistroke
.83333 .65622 L
.83303 .65686 L
.82329 .67647 L
.81373 .69524 L
.81323 .69608 L
.80106 .71569 L
.79412 .72672 L
.78798 .73529 L
.77451 .75341 L
.77331 .7549 L
.7566 .77451 L
.7549 .7764 L
.73781 .79412 L
.73529 .79654 L
.71629 .81373 L
.71569 .81422 L
.69608 .82927 L
.69031 .83333 L
.67647 .84181 L
.65686 .85226 L
.65542 .85294 L
.63725 .85993 L
.61765 .86566 L
.59804 .86939 L
.57843 .87124 L
.55882 .87151 L
.53922 .87058 L
.51961 .86887 L
.5 .8667 L
.48039 .86424 L
.46078 .86151 L
.44118 .85851 L
.42157 .85525 L
.40803 .85294 L
.40196 .85152 L
.38235 .84645 L
.36275 .84085 L
.34314 .8351 L
.33698 .83333 L
.32353 .82827 L
.30392 .82039 L
.28772 .81373 L
.28431 .81204 L
.26471 .80158 L
.25162 .79412 L
.2451 .78976 L
.22549 .77535 L
.22444 .77451 L
.20588 .75746 L
.20342 .7549 L
Mistroke
.18668 .73529 L
.18627 .73477 L
.17369 .71569 L
.16667 .70324 L
.16343 .69608 L
.15573 .67647 L
.14984 .65686 L
.14706 .64485 L
.14577 .63725 L
.143 .61765 L
.14072 .59804 L
.13862 .57843 L
.13655 .55882 L
.13459 .53922 L
.13289 .51961 L
.13165 .5 L
.13104 .48039 L
.13114 .46078 L
.13202 .44118 L
.13369 .42157 L
.13621 .40196 L
.13958 .38235 L
.14381 .36275 L
.14706 .34985 L
.14924 .34314 L
.1566 .32353 L
.16545 .30392 L
.16667 .30148 L
.17698 .28431 L
.18627 .27111 L
.19149 .26471 L
.20588 .24937 L
.21046 .2451 L
.22549 .23284 L
.23561 .22549 L
.2451 .21946 L
.26471 .20767 L
.26781 .20588 L
.28431 .1972 L
.30392 .18661 L
.30455 .18627 L
.32353 .17718 L
.34314 .16746 L
.34479 .16667 L
.36275 .1595 L
.38235 .15157 L
.39445 .14706 L
.40196 .14503 L
.42157 .13967 L
.44118 .13474 L
Mistroke
.46078 .13061 L
.48036 .12745 L
.48039 .12745 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3ooonf
o`000=40oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool0c`3oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`3?0?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o
00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003o
ool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?oo
o`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0c`3o
ool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0<l0oooo0009
0?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co0000
0?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0
oooo0?ooojgo0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3o
oon]o`0000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol0
00040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103o
ool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o
00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003o
ool0oooo08/0oooo0_l000120?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o
00000?ooo`3oool0R03oool3o`0000030?ooool00000oooo0440oooo00090?ooo`04o`00003oool0
oooo0?ooojgo0000103oool00ol00000oooo0?ooo`260?ooo`;o00000`3oool00`2Y_NSo0000o`00
00110?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0P`3o
ool3o`000080oooo102Y_NP00ol00000ooooo`0000100?ooo`002@3oool01?l00000oooo0?ooo`3o
oon]o`0000@0oooo00?o00000?ooo`3oool0P03oool3o`000080oooo1`2Y_NP00ol00000ooooo`00
00100?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0OP3o
ool2o`0000<0oooo2@2Y_NP01?l00000ZKgX0?ooool0000o0?ooo`002@3oool01?l00000oooo0?oo
o`3ooon]o`0000@0oooo00?o00000?ooo`3oool0N`3oool3o`000080oooo302Y_NP01Ol00000ZKgX
0?ooo`3ooooo000003h0oooo00090?ooo`04o`00003oool0oooo0?oooe;o000000<00000o`000000
00003P00001:o`0000@0oooo00?o00000?ooo`3oool0N@3oool2o`0000<0oooo3P2Y_NP01Ol00000
ZKgX0:Vmj03ooooo000003h0oooo00090?ooo`04o`00003oool0oooo0?ooodko00001000000B01TI
6@H00000@ol000040?ooo`03o`00003oool0oooo07H0oooo0ol000020?oooa40ZKgX00Ko00000:Vm
j02Y_NP0ZKgX0?ooool0000m0?ooo`002@3oool01?l00000oooo0?ooo`3ooom;o`0000<00000700I
6AT00`00003o0000o`000010o`0000@0oooo00?o00000?ooo`3oool0M03oool2o`000080oooo502Y
_NP00ol00000ZKgX0:Vmj0020:Vmj003o`00003oool0oooo03/0oooo00090?ooo`04o`00003oool0
oooo0?ooodOo00001000000P01TI6@<00000?ol000040?ooo`03o`00003oool0oooo0740oooo0ol0
00020?oooaH0ZKgX00?o00000:Vmj02Y_NP00`2Y_NP00ol00000oooo0?ooo`0j0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooom3o`00000400000?l000000000000002L06ATI0`00000lo`0000@0oooo
00?o00000?ooo`3oool0KP3oool3o`000080oooo6@2Y_NP00ol00000ZKgX0:Vmj0030:Vmj0030?oo
ool00000oooo03X0oooo00090?ooo`04o`00003oool0oooo0?oood3o00000`00000?01TI6@h00000
4@0I6AT00`00003o0000o`00000io`0000@0oooo00?o00000?ooo`3oool0K03oool2o`0000<0oooo
702Y_NP00ol00000ZKgX0:Vmj0030:Vmj003o`00003oool0oooo03T0oooo00090?ooo`04o`00003o
ool0oooo0?ooocgo00000`00000;01TI6@L000003P0c<c<7000000/06ATI0`00000ho`0000@0oooo
00?o00000?ooo`3oool0J@3oool3o`000080oooo7`2Y_NP00ol00000ZKgX0:Vmj0030:Vmj0030?oo
ool00000oooo03T0oooo00090?ooo`04o`00003oool0oooo0?oooc_o00000P00000:01TI6@040000
0?l0003o0000000001`0<c<c00@00000o`000000000000002P0I6AT2000003Ko0000103oool00ol0
0000oooo0?ooo`1W0?ooo`;o00000`3ooolQ0:Vmj003o`00002Y_NP0ZKgX00@0ZKgX00<0ooooo`00
003oool0>03oool000T0oooo00Co00000?ooo`3oool0oooo>Ol0000200000003o`00000I6AT06ATI
00H06ATI0`00000>03<c<`P000003P0c<c<2000000X06ATI00<00000o`000?l00000<ol000040?oo
o`03o`00003oool0oooo06@0oooo0ol000020?ooob@0ZKgX00?o00000:Vmj02Y_NP0102Y_NP00`3o
oooo00000?ooo`0h0?ooo`002@3oool01?l00000oooo0?ooo`3ooolfo`0000<000002P0I6AT00`00
0000<c<c03<c<`0503<c<`X00000201<C4`7000000T0<c<c0P00000901TI6@0300000?l0003o0000
03;o0000103oool00ol00000oooo0?ooo`1R0?ooo`;o00000`3ooolV0:Vmj003o`00002Y_NP0ZKgX
00D0ZKgX00<0ooooo`00003oool0=`3oool000T0oooo00Co00000?ooo`3oool0oooo=Ol000000`00
00006ATI01TI6@0801TI6@<000001@0c<c<3000001T0C4a<0`00000803<c<`800000200I6AT20000
03;o0000103oool00ol00000oooo0?ooo`1O0?ooo`?o00000P3ooolY0:Vmj003o`00002Y_NP0ZKgX
00H0ZKgX00<0ooooo`00003oool0=P3oool000T0oooo00Co00000?ooo`3oool0oooo<ol000020000
00P06ATI0`00000403<c<`0400000?l000000000000000H0C4a<3`00000:04a<C0@000001P0c<c<0
0ol0000000000000000701TI6@800000<?l000040?ooo`03o`00003oool0oooo05d0oooo0_l00003
0?ooo`H0ZKgX00<0ZKgW0:Vmj02Y_NP08P2Y_NP00ol00000ZKgX0:Vmj0070:Vmj003o`00003oool0
oooo03D0oooo00090?ooo`04o`00003oool0oooo0?oooc7o00000P00000901TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`3000000l0IVIV1`00000704a<C0<000001P0c<c<2
000000L06ATI00<00000o`000?l00000;Ol000040?ooo`03o`00003oool0oooo05X0oooo0ol00002
0?ooo`80ZKgW1@2Y_NP40:Vmi`80ZKgX00<0ZKgW0:Vmj02Y_NP00`2Y_NP20:Vmi`80ZKgX00<0ZKgW
0:Vmj02Y_NP0502Y_NP00ol00000ZKgX0:Vmj0080:Vmj003o`00003oool0oooo03@0oooo00090?oo
o`04o`00003oool0oooo0?oooboo00000P00000901TI6@800000100c<c<3000000@0C4a<10000003
06IVIP/000002`1VIVH3000000L0C4a<0`00000503<c<`03o`00000I6AT06ATI00D06ATI00<00000
o`000?l00000;?l000040?ooo`03o`00003oool0oooo05L0oooo0ol000030?ooo`030:Vli`2Y_NL0
ZKgW0080ZKgW00<0ZKgX0:Vli`2Y_NL0102Y_NL20:Zli`<0ZKgW0P2Y_NP20:Zli`030:Vmi`2Z_>L0
Z[cW00<0ZKgW0P2Y_NP00`2Y_NL0ZKgX0:Vmj00@0:Vmj003o`00002Y_NP0ZKgX00P0ZKgX00<0oooo
o`00003oool0=03oool000T0oooo00Co00000?ooo`3oool0oooo;Ol00002000000T06ATI0P000003
03<c<`<000000`1<C4`400000080IVIV1@00000;07moO`P000001P1VIVH01000003o000000000000
000604a<C003o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT^o`0000@0oooo00?o
00000?ooo`3oool0E@3oool2o`0000<0oooo1@2Y_>L20:Vmi`@0ZKcW0P2Y_NL20:ZliP<0Z[cW00<0
ZKgW0:Zli`2Z_>L00P2Z_>L00`2Z_>H0Z[cW0:Zli`020:Zli`030:Vmi`2Z_>L0Z[cW00<0ZKgW0P2Y
_NP00`2Y_NL0ZKgX0:Vmj00<0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX00?o00000?ooo`3oool0<`3o
ool000T0oooo00Co00000?ooo`3oool0oooo;?l000000`00003o000001TI6@0701TI6@0300000?l0
0000<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`00`00003o000006IVIP0306IVIP80000000?o
000007moO`1oOgl00P1oOgl;000000P0Ogmo0`00000706IVIP<00000101<C4`2000000@0<c<c00<0
000001TI6@0I6AT01@0I6AT00`00003o0000o`00000Zo`0000@0oooo00?o00000?ooo`3oool0DP3o
ool3o`0000<0oooo1P2Y_>L20:VkiP@0ZKcW0`2Z^nH00`2Z_>H0Z[[U0:Zji@030:ZkiP80Z[cW00@0
Z[_U0:ZliP2Z_>H0Z[cV0P2Z_>L00`2Z_>H0Z[cW0:Zli`020:Zli`030:Vmi`2Z_>L0ZKgW00<0ZKgW
00<0ZKgX0:Vmi`2Y_NL02P2Y_NP00ol00000ZKgX0:Vmj0090:Vmj0030?ooool00000oooo03<0oooo
00090?ooo`04o`00003oool0oooo0?ooob[o00000P00000901TI6@030000000c<c<0<c<c0080<c<c
0P00000304a<C08000000`1VIVH30000000307moO`000000000000@000002`2IVIT4000000L0Ogmo
0`00000706IVIP<000000`1<C4`2000000<0<c<c0P00000601TI6@0300000?l0003o000002Wo0000
103oool00ol00000oooo0?ooo`1@0?ooo`;o0000103oool60:Vli`D0ZK_V00<0ZKcW0:Zji@2Z^^D0
0P2Z^nH00`2Z^><0Z[[U0:Zji@020:Zji@030:ZkiP2[^N@0Z[_U00<0Z[_U00<0Z[cV0:^ji@2[^^D0
0`2Z_>H20:Zli`040:ZliP2Z_>L0Z[cW0:Zli`80ZKgW00<0Z[cW0:Vmi`2Y_NL00P2Y_NL00`2Y_NP0
ZKgW0:Vmi`020:Vmj0050:Vmi`2Y_NP0ZKgX0:Vmj?l00000302Y_NP00ol00000oooo0?ooo`0b0?oo
o`002@3oool01?l00000oooo0?ooo`3ooolYo`0000030000000I6AT06ATI00L06ATI0P00000403<c
<`040000001<C4`0C4a<04a<C08000000P1VIVH300000080Ogmo0P00000309VIV@;o00002@000007
09VIV@<000001`1oOgl4000000H0IVIV00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`02
03<c<`030000000I6AT06ATI00@06ATI00<00000o`000?l00000:?l000040?ooo`03o`00003oool0
oooo04d0oooo0ol000030?ooo`H0ZKcW1`2Y^nH20:Zii0030:Zji@2Z]n80Z[OR00<0Z[SS0P2Z^^D0
102[]n40ZkWT0:^ii02[^N@20:Zki@030:bhh`2[^^D0Zk[U0080Zk[U00<0Z[cV0:^ji02Z_>H00`2Z
_>H0102Z_>L0ZkcV0:^liP2[_>H20:Zli`80ZKgW0P2Z_>L00`2Y_NL0Z[gW0:Vmi`030:Vmi`80ZKgX
00?o00000:Vmj02Y_NP02P2Y_NP00`3ooooo00000?ooo`0b0?ooo`002@3oool01?l00000oooo0?oo
o`3ooolWo`00000300000?l000006ATI00L06ATI0P00000403<c<`03o`0000000000C4a<0080C4a<
00<0000006IVIP1VIVH00P00000307moO`0300000?l00000VIVI00Co00002`2c/k<00ol000000000
00000003000000@0VIVI1000000707moO`<00000101VIVH2000000<0C4a<0P00000303<c<`03o`00
000000006ATI00@06ATI00?o000000000?l000009ol000040?ooo`03o`00003oool0oooo04/0oooo
0_l000040?ooo`H0ZKcW0P2Y^^H20:VkiP030:Vgh`2Y^>@0ZKST0080ZKST00<0Z[WT0:Zeh02Z]n80
0`2Z]n800`2Z^><0ZkCO0:^dg`030:^gh@030:^ii02/]Ml0[;GO00<0[;SS0P2[^^D0102/^>80Zk[T
0:^ji02[^^@20:ZliP80Zk[T0P2[_>H0102/^^@0ZkcV0:^liP2[_>H20:Zli`040:^liP2Z_NL0Z[gW
0:Zmi`80ZKgW00@0Z[gW0:Vmj02Y_NSo00003@2Y_NP00`3ooooo00000?ooo`0a0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolUo`0000800000200I6AT2000000D0<c<c00L0000004a<C01<C4`0C4a<
00000?l00000IVIV008000000P1oOgl3000000?o0000102c/k<;o`0000H0/k>c00<0000009VIV@2I
VIT01@2IVIT3000000L0Ogmo0`00000306IVIP8000000`1<C4`2000000<0<c<c00<0000001TI6@0I
6AT0100I6AT00`00003o0000o`00000Uo`0000@0oooo00?o00000?ooo`3oool0B03oool3o`0000<0
oooo102Y_>L60:VjiPD0ZKOS0P2Y^>@0102Z/ml0Z[GP0:Zeh02Z]N020:ZghP030:^ag02[]=l0ZkCO
0080ZkCO00<0ZkOQ0:fag02/]Ml00`2/]Ml00`2/^><0[KCN0:bhhP030:bhhP060:^ji02]]n40[KOQ
0:fgh@2[^^@0[KOQ102/^^@00`2[_>H0[;[T0:bji0030:^liP030:Zmi`2Z_>H0Z[cV00<0Z[gW00<0
ZKgXo`00002Z_NL03@2Y_NP00ol00000oooo0?ooo`0`0?ooo`002@3oool01?l00000oooo0?ooo`3o
oolTo`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00200000080IVIV00<0000007moO`1oOgl00P00000209VIV@04o`00002c/k<0/k>c0;>c/`Co0000
2`3<c<`3o`0000@0/k>c0`00000709VIV@L000000`1oOgl00`000000IVIV06IVIP0206IVIP800000
0`1<C4`01@000000<c<c03<c<`0c<c<0000000H06ATI00<00000o`000?l000009?l000040?ooo`03
o`00003oool0oooo04D0oooo0ol000020?ooo`H0ZKcW00<0ZK_V0:VjiP2Y^^H00`2Y^^H60:Vgh`80
ZK7N0`2Z/ml00`2Z]N00ZjkJ0:^^fP030:^ag080ZkCO00@0[JgH0:fag02]/M`0[K7L0P2/]Ml0102^
/=T0[KCN0:fdgP2]]=h20:bhhP050:jcg02]]n40[KOQ0:fgh@2_/m/00`2]]n420:bji0030:fhh@2/
^^@0[;[T0080[;[T00<0ZkcV0:^ki@2Z_>H00`2Z_>H0102Z_NL0Z[cV0:Zmiol000020:Zmi`060:Vm
j02Z_NL0Z[gW0:Zmi`2Y_NP0Z[gW1P2Y_NP00`3ooooo00000?ooo`0`0?ooo`002@3oool01?l00000
oooo0?ooo`3ooolSo`0000030000000I6AT06ATI00H06ATI0P00000403<c<`0300000?l000000000
0080C4a<00<0000006IVIP1VIVH00P00000207moO`030000002IVIT0VIVI00;o000000@0/k>co`00
0?l0003o0000103<c<`8o`0000H0c<c<00?o00000;>c/`2c/k<0102c/k<01000003o000000000000
000:09VIV@04o`00001oOgl0Ogmo07moO`<000000`1VIVH01Ol00000C4a<04a<C01<C4co000000<0
<c<c00<0000001TI6@0I6AT0100I6ATVo`0000@0oooo00?o00000?ooo`3oool0@`3oool2o`000080
oooo0P2Y_NL40:Vli`D0ZK_V0P2Y^^H00`2X]n<0ZKOS0:Vgh`030:Vgh`030:R`g@2Y/Mh0ZK7N0080
ZK7N00<0Z[?O0:Z[e`2[[]X00`2[[]X00`2[/M`0[:SC0:f]f0030:f]f0030:fag02^Z]<0[Z[C00<0
[[3I00<0[KCN0:n^e`2_[]L00`2^/m`01@2]]n40[k?K0:ncf`2_/m/0[KOQ0080[k?K0`2]^>420:bj
i0040:fhh@2[^nD0Zk_U0:^ki@80Z[cV00H0Zk_U0:ZliP2Z_>H0Z[cVo`00002Z_NL20:Zli`H0Z[gW
0P2Y_NP01P2Z_NP0ZKgX0:Vmj02Y_NP0ooooo`000300oooo00090?ooo`04o`00003oool0oooo0?oo
ob?o0000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00@0000006IV
IP1VIVH000000`1oOgl010000000VIVI09VIVOl000020;>c/`03o`00003<c<`0c<c<0080c<c<0ol0
00080>KViP03o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<01`2c/k<3000000P0VIVI0`00
000307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`01@000000<c<c03<c<`0c<c<0000000D0
6ATI00<00000o`000?l000008ol000040?ooo`03o`00003oool0oooo0400oooo0ol000020?ooo`03
0:Vmj02Y_NL0ZKgW0080ZKgW00<0ZKcW0:Vki`2Y^nL0102Y^nH20:Rgi0<0Z;OS00<0ZKOS0:R_g@2X
[md00`2X/=d20:VagP040:VXeP2ZZmL0ZZ_G0:Z[e`80ZjkJ00@0ZjC@0:bXd`2/Z=<0[:SC0P2][MP0
0`2^Y<h0[Z[C0:jZd`020:jZd`030:j`f@2`Z=00[jkG00<0[jkG00<0[[?L0;2]e02_/m/00P2_/m/0
0`2a[M<0[k?K0:ncf`020:ncf`030:fhh@2`]=`0[KSQ00<0[KSQ00<0Zk_U0:fihP2[^nD00`2[^nD0
1P2Z_>H0Zk_Uo`00002[^nD0Z[cW0:^liPH0Z[gW102Z_NP20:Vmj0030?ooool00000oooo02l0oooo
00090?ooo`04o`00003oool0oooo0?ooob;o000000<0000001TI6@0I6AT01@0I6AT00`000000<c<c
03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH000000`1oOgl010000000
VIVI09VIVOl000020;>c/`04o`00003<c<`0c<c<0<c<c0;o00000`3Vi^H4o`0000D0i^KV00?o0000
0<c<c03<c<`00`3<c<`00ol00000/k>c0;>c/`0:0;>c/`L00000102IVIT200000080Ogmo0P000002
06IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0
003o000002?o0000103oool00ol00000oooo0?ooo`0n0?ooo`;o00000`3oool40:Vmj080ZKgW00<0
ZKcW0:Vki`2Y^nL00P2Y^nL00`2Y^nH0Z;ST0:Rgi0030:Rgi0030:Rgh`2W[mh0Z:oM00<0Z:oM00<0
Z;3M0:NVe02YZ=H00`2YZ=H20:Z[e`040:^^fP2[Y=00ZjC@0:^Td080[:SC00@0[JgH0:jTcP2^Y<h0
[ZC>0P2^Z]<0102`XLT0/:S@0;2Xd02`Z=020:n^e`050;:Vc@2`[M@0/:gD0;2]e02_/m/00`2a[M<2
0:ncf`040;:]d`2`]=`0/;CL0;2dg080[KSQ00@0/;GM0:fihP2]^N80[KWR0P2[^nD20:fjh`030:^k
iOl00000[;[T00<0ZkcV0P2Z_NL0102[_>H0Z[gW0:Zmi`2Z_NL20:Zmj0060:Zmi`2Y_NP0ZKgX0:Vm
j03ooooo0000;`3oool000T0oooo00Co00000?ooo`3oool0oooo8Ol000000`0000006ATI01TI6@05
01TI6@030000000c<c<0<c<c00@0<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP050000001o
Ogl0Ogmo07moO`0000000P2IVIT01?l00000/k>c0;>c/ol000020<c<c0;o0000103Vi^H00ol00000
oooo0?ooo`020?ooo`;o0000103Vi^H00ol00000c<c<0<c<c0030<c<c003o`00002c/k<0/k>c0100
/k>c0`00000309VIV@8000000P1oOgl010000000IVIV06IVIP00000304a<C0050000000c<c<0<c<c
03<c<`000000100I6AT00`00003o0000o`00000Ro`0000@0oooo00?o00000?ooo`3oool0>`3oool3
o`000080oooo1P2Y_NP50:Vli`80ZK_W00@0Z;SU0:Rhi02X^>@0Z;ST0P2X]n@0102W/=h0YjoN0:N_
gP2W[mh20:R_g@040:JTe02WY]@0YjKD0:NVe0<0ZJSF00<0ZZ_G0:VOc@2YWld00`2[Y=000`2/Z=<0
[Ik80:fNb0030:jTcP040:jZd`2`XLT0/:790;2Qb@80/:S@102bY/d00`2`[M@0/jG;0;>Ub`030;6]
d`@0/ZgC00<0/;CL0;>_e02`]Md00`2`]Md0202]^N80[kON0:nggP2_]mh0[K[S0:nhh02/^^Co0000
0P2/^^@00`2[_>H0[;_U0:^liP030:^liPH0Z[gW00D0ZKgX0:Zmj02Z_NP0ooooo`00000^0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooolPo`0000030000000I6AT06ATI00D06ATI00?o000003<c<`0c
<c<00`0c<c<200000080C4a<00<00000o`00001VIVH00P1VIVH01?l00000Ogmo07moOol0000209VI
V@04o`00002c/k?o0000o`000080c<c<00Co00000>KViP3Vi^H0i^KV0ol000070?ooo`03o`00003V
i^H0i^KV0080i^KV0_l000040<c<c003o`00002c/k<0/k>c0180/k>c00?o00000000000000000P2I
VIT20000000607moO`000000000006IVI_l0000000000P1<C4`01@000000<c<c03<c<`0c<c<00000
00@06ATI0P00000Ro`0000@0oooo00?o00000?ooo`3oool0>@3oool2o`0000<0oooo1P2Y_NP60:Vl
i`80Z;WU0`2X^>D00`2X^>@0Y[7O0:Jag`030:N`gP030:N_gP2UY=@0YZCD00<0YZCD0`2WY]@00`2Y
Z=H0Yic:0:VOc@030:VOc@030:^Td02[VL@0[Ik800<0[Ik800<0[ZC>0:nK`P2`XLT00`2`XLT00`2`
Z=00/Yo40;:Oa0030;:Vc@@0/jG;00<0/JgC0;BVb@2dY/T00P2b[M<0102fYlX0/joD0;>_e02c[m@2
0;2eg@050;>ae`2_]mh0[kON0:nggP2b]=T00`2_^>000ol00000[;[T0:jihP030:bki@@0ZkcV1P2Z
_NL0102Z_NP0Z[gW0:Zmiol0000^0?ooo`002@3oool01?l00000oooo0?ooo`3ooolPo`0000L06ATI
00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000@0IVIV00@0000007moO`1o
Ogl000000P2IVIT00ol00000/k>co`0000030<c<c005o`00003Vi^H0i^KV0>KVi_l000002P3oool0
0ol00000i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<0202c/k<:
o`0000<0/k>c0P00000209VIV@040000001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`00000
0P0c<c<00`0000006ATI01TI6@0401TI6@0300000?l0003o000001oo0000103oool00ol00000oooo
0?ooo`0f0?ooo`?o00000`3oool60:Vmj080ZKgW102Y_>L20:RjiP<0Z;WU00<0Z;SU0:Jbh@2V/Ml0
0`2V/Ml00`2W/=h0Y:CE0:FTe0020:FTe0<0YZCD0P2WY]@0102UVLT0Yic:0:NLbP2WW<X20:VOc@04
0:VD`@2[VL@0ZiW40:^Ia080[Ik800@0[IFm0:nK`P2_Vl80[i_20P2`XLT00`2aV;d0/Yo40;:Oa002
0;:Oa0030;:Vc@2dWL40]9g10080/jG;00D0]Yfo0;BVb@2dY/T0]:K90;:]d`030;JWbP030;>_e02g
Z/`0]j[<00<0/k7G00L0[kON0;:df@2b]=T0/[CI0:nhh02b]]co000000<0[[WR00<0[;_U0:fkh`2]
^n<00P2[_>H0102]_>D0ZkgV0:^miP2[_NH20:Zmi`030:^mi`2Z_NL0Z[gW0080Z[gW00?o00000?oo
o`3oool0:`3oool000T0oooo00Co00000?ooo`3oool0oooo7_l000000`0000006ATI01TI6@0501TI
6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000406IVIP040000001oOgl0
Ogmo00000080VIVI00Co00000;>c/`2c/k?o00000P3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000`0
oooo00Go00000>KViP3Vi^H0i^KVo`0000050<c<c003o`00002c/k<0/k>c00L0/k>c00?o00000<c<
c03<c<`0203<c<`00ol00000/k>c0;>c/`020;>c/`04o`00002IVIT0VIVIo`000080Ogmo00@00000
06IVIP1VIVH000000P1<C4`010000000<c<c03<c<`00000501TI6@0300000?l0003o000001oo0000
103oool00ol00000oooo0?ooo`0c0?ooo`?o0000103oool80:Vmj0030:Vmi`2Y^nL0ZK_W00<0Z;_V
00<0Z;[V0:Neh`2W]N<00P2W]>830:Jbh@80Y[7O00@0XjGG0:BTe@2TY=D0Y:CE0`2UY=@00`2VY=@0
XiO80:FIb@030:FIb@80Yic:102YU<420:^Ia0040:fNb02]UKd0[IFm0:fE_@80[i_2102aV;d20;:O
a0050;>F^@2dWL40]9g10;BM`@2cYL/00`2fWKl20;BVb@040;RN_`2fYlX0]ZO:0;JWbP@0]j[<00<0
/k7G0;N]c`2b]=T00P2b]=T0102g/M<0/[KL0;:fg?l000020:jihP80/;SO00<0[K_S0:njhP2_^^80
0`2]_>D00`2[_NH0[;gV0:bmiP030:^mi`<0Z[gW00?o00000?ooo`3oool0:`3oool000T0oooo00Co
00000?ooo`3oool0oooo7Ol000000`0000006ATI01TI6@0501TI6@03o`00000c<c<0<c<c00<0<c<c
00D0000004a<C01<C4`0C4a<o`00000306IVIP05o`0000000000Ogmo07moO`0000000P2IVIT01?l0
0000/k>c0;>c/ol000020<c<c005o`00003Vi^H0i^KV0>KVi_l000003@3oool01Ol00000i^KV0>KV
iP3Vi^Ko000000D0c<c<00?o00000;>c/`2c/k<01P2c/k<00ol00000c<c<0<c<c00:0<c<c0Co0000
00D0/k>c0000002IVIT0VIVI0000000207moO`040000001VIVH0IVIVo`000080C4a<00Co000003<c
<`0c<c?o00001@0I6AT00`00003o0000o`00000No`0000@0oooo00?o00000?ooo`3oool0<@3oool2
o`0000@0oooo2P2Y_NP20:Vli`<0ZK_W00<0Z;_V0:Ngi02W]n@00`2W]N<20:NdhP030:Jbh@2SYmT0
XjOI00<0XjGG0P2TY=D20:FTe0040:6Eb02SUlP0XiO80:>Gb0<0YIW900<0Yic:0:J@_P2VT;h00`2Y
U<400`2[VL@0Zi2i0:fE_@030:fE_@030:nK`P2`T[L0/9:g00<0/IRm00@0/Yo40;>F^@2cU[T0/iJi
0P2dWL440;JM_`050;BVb@2hW[l0^9jo0;RN_`2fYlX00P2jXL020;NZc0050;^Va02g[Ll0]jg?0;N]
c`2b]=T00`2g/M<00`2b]]`0]KCHo`0000030;2hg`@0[k[R00<0[KcU0:jli02/_NH00`2/_NH20:^m
i`@0Z[gW00?o00000?ooo`3oool0:P3oool000T0oooo00Co00000?ooo`3oool0oooo7Ol000000`00
00006ATI01TI6@0401TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`01@00
0000IVIV06IVIP1VIVH0000000<0Ogmo00@0000009VIV@2IVIWo00000P2c/k<01?l00000c<c<0<c<
c?l000030>KViP03o`00003oool0oooo00/0oooo00Go00000>KViP3Vi^H0i^KVo`0000040<c<c003
o`00002c/k<0/k>c00L0/k>c00?o00000<c<c03<c<`01@3<c<`5o`0000@0c<c<00?o00000;>c/`00
00000P2IVIT00`000000Ogmo0000000206IVIP050000001<C4`0C4a<04a<C00000000P0c<c<00`00
00006ATI01TI6@0201TI6@0300000?l0003o000001ko0000103oool00ol00000oooo0?ooo`0^0?oo
o`?o00000P3oool<0:Vmj0D0ZKcW00<0ZK_W0:Rii@2W]n@00`2W]n@00`2W]N<0Y:cM0:>Yf`020:>Y
f`<0XjOI00@0XjGG09jEbP2OU<T0WiC9102QULP20:>Gb080YIW900@0Xhbl0:J@_P2VT;h0YY2n0`2Y
U<430:^@^@<0[IFm0`2`T[L30;6H_@@0/iJi00<0]9g10;JE]P2fUKH00`2fWKl40;RN_`<0^Z7000D0
]j[<0;^Va02kY/@0^jK40;N]c`020;bZb0<0]k7C0P2e]=P00ol00000]KCH0;2hg`020;Bhg080[k[R
00@0/[[O0:jli02^_>@0[[cT0P2/_NH20:fmi@80ZkgW102Z_NL00ol00000oooo0?ooo`0Y0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooolLo`0000030000000I6AT06ATI00@06ATI00<0000003<c<`0c
<c<00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl01000
0000VIVI09VIVOl000020;>c/`05o`00003<c<`0c<c<0<c<c?l000000`3Vi^H00ol00000oooo0?oo
o`0:0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000`3<c<`2o`0000X0/k>c00?o00000<c<c03<c<`0
0`3<c<`2o`0000D0i^KV0_l000030<c<c003o`00002c/k<000000080VIVI00<0000007moO`000000
0P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l0
00007Ol000040?ooo`03o`00003oool0oooo02`0oooo0_l000030?ooo``0ZKgX00<0ZKgW0:Vli`2Y
_>L00`2Y_>L0102X^^H0Z;WU0:Rii@2X^ND20:Ngi0040:F_g`2T[=d0Y:cM0:B/g@<0XjWK00<0XjOI
09jGc02NULX00P2NULX209nDb@<0XIG800<0XiO80:29^`2SS;`00`2SS;`30:J@_P030:VD`@2XRkH0
Zi2i00<0Zi2i00<0[IFm0:j=/`2`T[L00`2`T[L00`2aV;d0/Y2b0;>F^@030;>F^@@0]YFf00<0]Yfo
0;RF]@2hU[D00P2hW[l20;^I]@80^Z70102kY/@40;bZb0060;Nad`2k[lh0^jo>0;Fdf?l00000^K?C
0`2d^=`40;:jg`030:jli02`_><0/;cS0080[KgU00@0[[gU0:bmi`2/_NL0[;gW0P2Z_NL00`2[_NOo
00000?ooo`0Z0?ooo`002@3oool01?l00000oooo0?ooo`3ooolKo`0000030000000I6AT06ATI00@0
6ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IV
IP0000000`1oOgl01@000000VIVI09VIV@2IVIWo00000080/k>c00Co00000<c<c03<c<co00000`3V
i^H00ol00000oooo0?ooo`0:0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000`3<c<`00ol00000/k>c
0;>c/`0;0;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H01P3Vi^H2o`000080c<c<
00?o00000;>c/`0000000P2IVIT00ol00000Ogmo0000000206IVIP040000001<C4`0C4a<00000080
<c<c00<0000001TI6@0I6AT00`0I6ATOo`0000@0oooo00?o00000?ooo`3oool0:@3oool3o`000080
oooo302Y_NP50:Vmi`040:Vli`2X^nH0Z;_V0:RkiP80Z;[V00<0Z;WU0:Fbh@2U/^400`2U[ml00`2T
[=d0WYgC09jIc`0209jIc`<0WYO<0P2NULX309nDb@030:6Eb02MQ[/0X8Vk0080X8Vk0`2SS;`20:J@
_P040:F6]02XRkH0Z8^f0:R;]P80Zi2i00@0ZhR`0:j=/`2^SK<0[Xfc0P2`T[L0102`Rjh0/Y2b0;:@
/P2bT;820;>F^@030;B?[`2fUKH0]YFf0080]YFf0`2hU[D01@2hW[l0^iVe0;^I]@2kVKD0^Z700080
_Yfg0`2kY/@01030Xk`0_:[80;bZb031Z<430;^_cP050;Vcdol00000^K?C0;Vcd`2d^=`00P2g]mT2
0;:jg`040;BjgP2`_><0/;cS0;2lh`@0[[gU00<0[;gW0:bmiP2[_NL00`2[_NL00ol00000oooo0?oo
o`0X0?ooo`002@3oool01?l00000oooo0?ooo`3ooolLo`0000H06ATI00?o000003<c<`0c<c<00P0c
<c<00`000000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IVIP0000000`1oOgl01@000000VIVI
09VIV@2IVIWo00000080/k>c00Go00000<c<c03<c<`0c<c<o`0000030>KViP;o00002@3oool2o`00
0080i^KV0_l00000103<c<co0000o`000?l000040;>c/`@000001P2c/k<01Ol00000c<c<0<c<c03<
c<co000000/0i^KV00Go00000<c<c03<c<co00000;>c/`020000000409VIV@000000Ogmo00000080
IVIV00?o000004a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o000001_o
0000103oool00ol00000oooo0?ooo`0W0?ooo`;o00000`3oool?0:Vmj0030:Vmi`2Y_>L0ZK_W00<0
ZK_W00@0Z;_V0:Ngi02V]N<0Y[GS102U/^400`2U[ml0Wj;F09jMd`0209jMd`<0WYW?0P2NUl`00`2N
ULX0VHBl09^5^`0209^5^`80WHJk102PRK/00`2SS;`0XX:b0:F6]0020:F6]0<0Z8^f00<0Zi2i0:^8
/02[R;000`2^SK<00`2`T[L0/8^^0;2;[P030;:@/P040;>F^@2dSjl0]8n_0;B?[`80]YFf00@0^8n]
0;RF]@2hU[D0^9Je102kVKD40;jM]`040;^Va030Xk`0`:>l0;bZb0<0`JS100D0^jo>0<2^b030[/So
00000;Vcd`020;jcc`030;Ngf@2k^=H0];[N00<0];[N00<0/;cS0;:mhP2b_N800P2^_ND0102__^D0
[;gV0:bmiP2/_NH20:^mi`80ZkkW00?o00000?ooo`3oool09`3oool000T0oooo00Co00000?ooo`3o
ool0oooo6ol000000`0000006ATI01TI6@0401TI6@050000000c<c<0<c<c03<c<ol00000101<C4`0
1@000000IVIV06IVIP1VIVH0000000@0Ogmo00@0000009VIV@2IVIWo00000`2c/k<01Ol00000c<c<
0<c<c03<c<co000000D0i^KV2Ol000030>KViP04o`00003<c<`0c<c<o`0000@0/k>c0`00000409VI
V@<000000`2c/k<01Ol00000c<c<0<c<c03<c<co000000H0i^KV0ol000030>KViP04o`00003<c<`0
c<c<o`000080/k>c0P00000207moO`060000001VIVH0IVIV0000001<C4`000000`0c<c<00`000000
6ATI01TI6@0201TI6@0300000?l0003o000001_o0000103oool00ol00000oooo0?ooo`0T0?ooo`?o
00000`3oool@0:Vmj0@0ZKcW0P2Y^nL0102X^ND0YkOT0:Ngi02W]n@20:Jeh`80YK;Q00@0XJKJ09nR
eP2OX]H0Wj;F0`2NWM<209jIc`0309jGc02GQKd0VHBl0080VHBl0P2KQK/309f6^`80X8Vk00<0WWna
0::2/P2RP[80102UQ[@20:R;]P@0ZhR`0P2^SK<40;2;[P80/Y2b102dSjl0102fUKH0^8n]0;R?[@2h
Sjd20;RF]@040;^B[02kVKD0^iVe0;^I]@@0_Yfg0`30Xk`40<6X`@<0`:k800Co00000;jcc`2n/ll0
`kC<0`2k^=H20;BjgP80^;_L00<0/[gR0;Bnh@2__^D00`2__^D00`2/_NH0[KkV0:fniP030:^ni`03
o`00003oool0oooo02L0oooo00090?ooo`04o`00003oool0oooo0?oooa[o000000<0000001TI6@0I
6AT0100I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH00`00
0000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIVOl000000`2c/k<00ol00000c<c<0<c<c002
0<c<c003o`00003Vi^H0i^KV00/0i^KV0ol000000`3<c<co0000o`0000030;>c/`8000002P2IVIT0
1@000000/k>c0;>c/`2c/k?o00000080c<c<00?o00000>KViP3Vi^H00P3Vi^H2o`0000<0oooo0_l0
00020>KViP08o`00003<c<`0c<c<o`00002c/k<0000009VIV@00000207moO`030000001VIVH00000
0080C4a<00Go000003<c<`0c<c<0<c<co`00000401TI6@0300000?l0003o000001[o0000103oool0
0ol00000oooo0?ooo`0R0?ooo`;o0000103oool?0:Vmj0H0ZKcW0P2X^^H30:Rii@030:Ngi02T/>00
Y;3P0080XZ_M0`2QY]X209nReP80WYgC00<0UX[409J6`02FQ/000P2GQKd309V4_0<0VhFk0P2MQ[/0
0`2PRK/0WWna09io/@030::2/P<0YHJd00<0Z8^f0:R4[P2XQ:h00`2[R;020:j=/`050:j7Z`2`Rjh0
/8^^0;2;[P2bT;800P2cRZX30;B?[`@0^8n]00<0^9Je0;^B[02kTZ`00P2kVKD20;nF[@80_Yfg0P32
W;020<2S_0030<FR]@31Z<40`JS10080aZRl0P30[/P00ol00000_[??0<>dc0020<>dc0030;^heP2o
^M@0^;_L0080^;_L00@0^kgK0;Bnh@2d_^40];kQ0P2__^D20;2ni@80[KkV102[_^L00ol00000oooo
0?ooo`0V0?ooo`002@3oool01?l00000oooo0?ooo`3ooolJo`0000030000000I6AT06ATI00<06ATI
00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00<0000007moO`1o
Ogl00P1oOgl01@000000VIVI09VIV@2IVIWo000000@0/k>c00?o00000<c<c03<c<`00`3<c<`00ol0
0000i^KV0>KViP070>KViP?o00000`3<c<`00ol00000/k>c0;>c/`03o`0000d0VIVI00@000000;>c
/`2c/k?o00000P3<c<`01Ol00000i^KV0>KViP3Vi^Ko000000L0oooo00?o00000>KViP3Vi^H00_l0
00001P3<c<co00000;>c/`000000VIVI00000080Ogmo00<0000006IVIP0000000P1<C4`010000000
<c<c03<c<`00000501TI6@0300000?l0003o000001Wo0000103oool00ol00000oooo0?ooo`0O0?oo
o`?o000000<0oooo0:Vmj02Y_NP0402Y_NP60:Vli`80ZK_V0`2X^^H00`2X^ND0Y[?R0:B`h0030:B`
h080XZ_M00@0XJKJ09VEcP2GSlT0Uho90`2FR/@309J6`080UhFm0`2IQ;`209^5^`0309f6^`2JNk00
WWna00<0WWna0P2RP[820:F6]0040:F1[02XQ:h0Z8B^0:R4[P<0ZhR`00<0[Xfc0:j7Z`2^Qj/00`2`
Rjh30;>:ZP<0]8n_00@0]XZW0;R?[@2hSjd0^8n]102kTZ`0102kVKD0_iJ]0;nF[@2nWKL30<:L/004
0<2S_035X[D0aJ:e0<6X`@<0aZRl00<0`:k80<F_a?l000001033]<`30;nie0050;Rkg02k_M/0^kgK
0;^mf`2d_^400P2f_n420;2ni@040;6oi@2]_^H0[KkV0:fniP<0ZkkW00<0ooooo`00003oool09P3o
ool000T0oooo00Co00000?ooo`3oool0oooo6_l000000`0000006ATI01TI6@0301TI6@030000000c
<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP05o`00001oOgl0Ogmo07moO`00
0000102IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00<0c<c<2Ol000030<c<c0?o
000000<0/k>co`000?l00000102IVIT8000000@0VIVI00Co00000;>c/`2c/k?o00000P3<c<`01Ol0
0000i^KV0>KViP3Vi^Ko000000L0oooo00Go00000>KViP3Vi^H0i^KVo`0000020<c<c004o`000000
0000VIVI00000080Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000501TI6@03
00000?l0003o000001Wo0000103oool00ol00000oooo0?ooo`0L0?ooo`?o00000P3ooolB0:Vmj080
ZKgW102Y_>L20:Vki`<0ZK_V00<0Z;[V0:Nfi02V/n800P2V/n820:B`h00309jSf@2KW=@0VicD00<0
VIG>0P2GSlT309J:a080UXK00P2GQKd209V4_00309Af[`2GN:l0UgR_00<0VW^`0`2NOk420::2/P03
0:F6]02UPJ`0YH6/00<0Z8B^0`2[R;030:j7Z`<0/8^^102cRZX00`2dSjl0]XZW0;J:Y`030;R?[@@0
^i:/0`2oUZd40<:L/0<0aJ:e1036Z;`20<F_a003o`00003;/<00`kC<0080`kC<00<0b;O90;nie034
_=800P34_=801@2k_M/0_[oK0;jof`2f_n40^<7Q00@0/KoU00<0[KkV0:foi`2]_nL00`2[_^L00ol0
0000oooo0?ooo`0U0?ooo`002@3oool01?l00000oooo0?ooo`3ooolIo`0000030000000I6AT06ATI
00<06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00D00000
07moO`1oOgl0Ogmo0000000509VIV@03o`00002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`02`3<
c<`3o`0000<0/k>c00Co000009VIV@2IVIT0VIVI0`00000807moO`8000000P2IVIT01@000000/k>c
0;>c/`2c/k?o00000080c<c<00Co00000>KViP3Vi^Ko0000203oool02ol00000i^KV0>KViP3Vi^Ko
00000<c<c?l00000/k>c0000002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`010000000
<c<c03<c<`00000501TI6@0300000?l0003o000001So0000103oool00ol00000oooo0?ooo`0J0?oo
o`;o00000`3ooolD0:Vmj0030:Vmi`2Y_>L0ZKcW00<0ZKcW00<0ZK_W0:Rii@2X^ND00`2X^>D20:Nf
i0030:JchP2QZMd0XJWM00<0WZ?I0P2KW=@209VEcP<0Uho90P2FR/@0102FQ/00SgFb095e/02AMK03
09Af[`80UgR_0`2JNk0309io/@030::2/P2QOJ/0YH6/00<0YH6/0`2XQ:h00`2[R;00[8>Y0:j7Z`03
0:j7Z`030;2;[P2aQZL0/hZZ00<0/hZZ0`2fRZL20;R?[@80^XbV0`2kTZ`30;nF[@@0`Yb`00@0b9b[
0<FR]@35X[D0bj>a0`36Z;`00`3;Z[P0aJo4o`0000020<^``0030<>dc038]lT0b;O900<0a;cB00@0
b;oB0;jof`2n_m/0_[oK0`2h`N420;6oi@80/L3U0P2]_nL40:^ni`03o`00003oool0oooo02@0oooo
00090?ooo`04o`00003oool0oooo0?oooaWo000000<0000001TI6@0I6AT00`0I6AT00`000000<c<c
03<c<`0203<c<`040000001<C4`0C4a<000000<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00D0/k>c0ol000060<c<c0Co0000102c/k<2o`000080
VIVI00?o00000000001oOgl00`1oOgl6000000<0Ogmo00@0000009VIV@2IVIT000000P2c/k<01?l0
0000c<c<0<c<c?l000020>KViP03o`00003oool0oooo00L0oooo00Co00000>KViP3Vi^Ko00000P3<
c<`01?l00000/k>co`000000000207moO`030000001VIVH000000080C4a<00@0000003<c<`0c<c<0
00001@0I6AT00`00003o0000o`00000Ho`0000@0oooo00?o00000?ooo`3oool05`3oool3o`0000<0
oooo5@2Y_NP60:Vli`80Z;[V0`2X^ND00`2X^>D0YK;R0:>^g`020:>^g`<0XJWM0P2NXmT0102KW=@0
T8O608f0`02=P<0308ej^P80SGNe0P2?MK83095e/080U7J_0`2GN:l209Yk/0<0WWna0`2QOJ/30:F1
[080Z8B^00@0ZH6X0:b3Z@2/PjT0[8>Y0`2^Qj/30;66Y`<0/hZZ102fRZL00`2hSjd0^XbV0;Z<YP02
0;^B[080_i2V00<0_iJ]0<>FZ033UZP00P32W;020<RLZ`050<FR]@3;Xk40bj>a0<^S/@36Z;`00P3;
Z[P2o`000080bk300`38]lT00`3=^/P0a;cB0<RodP020<RodP040;jof`31`m/0`L?K0;S1h@<0^L?R
00<0/L3U0;;1i@2]_nL00P2]_nL20:^ni`030:^nj03ooooo000002D0oooo00090?ooo`04o`00003o
ool0oooo0?oooaSo000000<0000001TI6@0I6AT00`0I6AT01P000000<c<c03<c<`0c<c?o00000000
0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI00@0VIVI00?o0000
0;>c/`2c/k<0202c/k<6o`0000@0/k>c1?l0000209VIV@8000000P1oOgl4000000KoIVIV0P000002
07moO`040000002IVIT0VIVI00000080/k>c00?o00000<c<c?l000000P3Vi^H00ol00000oooo0?oo
o`080?ooo`0:o`00003Vi^H0i^KVo`00003<c<co00000;>c/`000000VIVI00000080Ogmo00<00000
06IVIP0000000P1<C4`010000000<c<c03<c<`00000501TI6@0300000?l0003o000001Oo0000103o
ool00ol00000oooo0?ooo`0F0?ooo`;o00000`3ooolE0:Vmj0H0ZKcW00<0Z;_V0:RjiP2X^^H00P2X
^^H00`2X^ND0Y[GS0:FbhP020:FbhP<0XjkO00@0XJWM09RJe02CT<d0Ti3=0P2@QlH308f0`080SGZj
0P2=MkD208me/P<0TGF`0`2DMZl209Mh[`<0VW^`00<0WWna09eiZ@2QOJ/00P2QOJ/30:F1[0030:R4
[P2YPJP0ZH6X00<0[8>Y0P2^Qj/0102_PjH0/HJW0;66Y`2aQZL20;>:ZP030;B6Y02fRZL0]XZW0080
]XZW0`2jS:H01@2kTZ`0_i2V0;n@YP2oT:H0_iJ]0080`iJX00@0`Yb`0<RLZ`38W:/0b9b[103;Xk43
o`0000030=6]]Ol00000bk300080d;Bn00<0b;O90<fjb03=^/P00`38_m80103<`m80`L?K0<73f`31
`m/30;W3hP040;W4h`2b`ND0//7U0;;1i@<0[KoW0`2[_^P00ol00000oooo0?ooo`0S0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooolIo`0000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C004
0000001VIVH0IVIVo`0000@0Ogmo00<0000009VIV@2IVIT01P2IVIT3o`0000d0/k>c1?l0000309VI
V@<0000000@0Ogmo00000000000000003?mVIVH20000000907moOol00000VIVI09VIV@000000/k>c
o`00003<c<co000000<0i^KV00?o00000?ooo`3oool01`3oool01?l00000i^KV0>KViP3Vi^H2o`00
00040;>c/`000000VIVI00000080Ogmo00<0000006IVIP0000000P1<C4`010000000<c<c03<c<`00
000501TI6@0300000?l0003o000001Oo0000103oool00ol00000oooo0?ooo`0F0?ooo`03o`00002Y
_NP0ZKgX01L0ZKgX102Y_>L20:Rki`80Z;_V0P2X^^H01@2W]n@0Y[GS0:Jeh`2V]N<0YK;R0080X:WM
0P2LX]T309RJe080Ti3=0P2@QlH208f0`0<0SGZj0P2=MkD208me/P80TGF`0`2DMZl209Mh[`80VW^`
00<0VWFX09eiZ@2MNJT00`2QOJ/30:F1[0<0ZH6X0`2/PjT00`2^Qj/0[h>V0:n3YP030;66Y`040;>:
ZP2dQZ@0]8JT0;B6Y0<0]XZW0`2jS:H40;n@YP<0`iJX1038W:/01P3;Xk7o0000o`000?l00000dJN]
0<^Z^080dJfe00@0bk30o`00003@];h0d;Bn0`3=^/P00`3B_/L0b;oB0<c3dP020<c3dP040<73f`33
a]`0`lKL0;W3hP<0^LCS00<0//7U0;;2iP2b`^H00P2]_nL40:^nj003o`00003oool0oooo0280oooo
00090?ooo`04o`00003oool0oooo0?oooaSo000000<0000001TI6@0I6AT00P0I6AT01@000000<c<c
03<c<`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`030000002IVIT0VIVI
00X0VIVI3Ol0000409VIV@<000000`1oOgl01000003oIVIVofIVI_mVIVH;000000?oIVIV00<00000
07moO`0000000P2IVIT01@000000/k>co`00003<c<co00000080i^KV00?o00000?ooo`3oool0203o
ool02_l00000i^KV0>KVi_l00000c<c<o`00002c/k<0000009VIV@00000207moO`030000001VIVH0
00000080C4a<00Co000003<c<`0c<c?o00001@0I6AT00`00003o0000o`00000Fo`0000@0oooo00?o
00000?ooo`3oool05P3oool00ol00000ZKgX0:Vmj00F0:Vmj0D0ZKcW00<0Z;_W0:RjiP2X^^H00`2X
^>D20:Ngi0030:Jeh`2S[]l0XjkO00<0X:WM0P2LX]T209RJe080Ti3=0P2@QlH308f0`080SGZj0P2=
MkD208me/P<0TGF`0P2DMZl00`2GN:l0UW6W09YeZ00209YeZ0<0WGVY0`2QOJ/00`2UPJ`0YWjX0:V1
Z0030:V1Z080[8>Y102_PjH20;66Y`@0]8JT0P2fRZL20;R8XP80^XbV00@0_HbQ0;n@YP2oT:H0_i2V
0`33UZP00`39V:@0b9b[o`000002o`000080bj>a0P3AYjd00`3;Z[P0dJfe0=6]]@020=2d_P04o`00
003F^;d0e[Rm0<fjb080d[k70`3<`m820<o8d`030<?6g034b=d0a<SM0080^LCS0P2ia^@00`2b`^H0
/L;W0:foi`020:foi`<0ZkkX00?o00000?ooo`3oool08P3oool000T0oooo00Co00000?ooo`3oool0
oooo5ol000000`0000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@00
0000IVIV06IVIP1VIVH0000000<0Ogmo00?o000009VIV@2IVIT05`2IVIT500000080Ogmo10000003
ofIVIP030000001<C4`0C4a<00T0C4a<00Oo0000ofIVI_mVIVKoIVIVo`00001oOgl000000080VIVI
00Go00000;>c/ol00000c<c<o`0000020>KViP03o`00003oool0oooo00P0oooo00?o00000>KVi_l0
00000P3<c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C0050000000c
<c<0<c<c03<c<`000000100I6AT00`00003o0000o`00000Fo`0000@0oooo00?o00000?ooo`3oool0
5P3oool00ol00000ZKgX0:Vmj00F0:Vmj0@0ZKcW0P2X^nL30:RjiP030:Rhi@2V]><0YK;R0080YK;R
0`2S[]l0102PZMd0V9_E096Ac`2ATLl208^6b080QW_00P22L[P3085//P80PfR]0P2=MkD208me/P80
TGF`00<0SF^V095]YP2AKJH00`2FLJL209YeZ0<0WGVY0P2QOJ/00`2SNjL0YWjX0:InZ0040:V1Z080
[8>Y00@0[86V0:n3YP2_PjH0[h>V0P2aQZL01@2bPj<0]8JT0;B6Y02dQZ@0]XZW00<0^8RR00<0^XbV
0;f<X@2mS:400P2oT:H20<>AXP050<>FZ?l0003o0000o`000038W:/00P3>WjP0103;Xk40dJN]0=6W
[@3AYjd30=6]]@050=Nb/`3@];h0e[Rmo`00003F^;d00`3B_/L01@3F`lL0c<?B0<o8d`3?b=<0dLcD
00<0a<SM0`2ia^@01@2ha^D0/L;W0;72i`2a`^L0[KoW0080[KoX0`2[_^P00ol00000oooo0?ooo`0Q
0?ooo`002@3oool01?l00000oooo0?ooo`3ooolGo`0000030000000I6AT06ATI00<06ATI00D00000
03<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000`1oOgl00`000000VIVI
09VIV@0A09VIV@H000001@1oOgl2000000GoIVIV00<00000o`00001<C4`0301<C4`01000003oIVIV
ofIVIP00000207moO`050000002IVIT000000;>c/ol000000P3<c<`00ol00000i^KVo`00000:0?oo
o`03o`00003Vi^Ko00000080c<c<00Wo00000;>c/`000000VIVI0000001oOgl0000006IVIP000000
0P1<C4`01@000000<c<c03<c<`0c<c<0000000@06ATI00<00000o`000?l000005_l000040?ooo`03
o`00003oool0oooo01D0oooo00Co00000?ooo`3oool0oooo5`2Y_NP00`2Y_>L0Z;_W0:Rki`030:Rk
i`030:RjiP2V]nD0Y[CS0080Y[CS00<0YK;R0:2Yg@2LXmX00P2LXmX309RKe@80TI7?00@0RhK808Ik
`026Nl00QW_00P22L[P2085//P80PfR]0P25IjT208UXY`<0SF^V0P2AKJH309IaY`<0VWFX0P2MNJT0
0`2QOJ/0Xg^W0:=kY`030:InZ0<0ZH6X00<0[8>Y0:b1YP2/PJH00`2_PjH00`2aQZL0/X>S0;:3X`03
0;B6Y0@0^8RR00<0^XbV0;f<X@2mS:400P2oT:H3o`0000<0bIRT00<0b9b[0<jOZ03>WjP0103AYjd0
2P3G[:`0dJfe0=Nb/`3G/[<0gKRc0=Jh_Ol00000e[Rm0=Zm_03B_/L20=K3a`030=[9b03?b=<0dLcD
0080dLcD00@0a<SM0<G;g`35bml0^LKT0`2ha^D01@2a`^L0/<;W0;32i`2]_nP0[;oX00@0ZkkX00?o
00000?ooo`3oool0803oool000T0oooo00Co00000?ooo`3oool0oooo5ol000000`0000006ATI01TI
6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000307moO`03
0000002IVIT0VIVI00l0VIVI0`00000707moO`@000000omVIVH4000000<0C4a<2P00000304a<C004
00000?mVIVKoIVIV00000080Ogmo00D0000009VIV@000000/k>co`0000020<c<c003o`00003Vi^Ko
000000T0oooo00?o00000>KVi_l000000P3<c<`01Ol00000/k>c0000002IVIT000000080Ogmo00D0
000006IVIP000000C4a<0000000303<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l00000
5Ol000040?ooo`03o`00003oool0oooo01D0oooo00Co00000?ooo`3oool0oooo5P2Y_NP20:Rlj0@0
Z;_W0P2W^NH20:Jgi@030:Jdh`2R[^40XZkQ0080X:WM0`2LXmX209RKe@80TI7?0P2;Q/P208Ik`080
PW:h0P21K;8208=X[@80QFNY0`29J:L208e[YP80TFfV0`2FLJL309YeZ080WGVY0`2SNjL30:InZ080
ZH6X00@0ZWnV0:b1YP2/PJH0[86V0`2_PjH30;:3X`<0]8JT102hR:820;f<X@?o00000P33TJ801033
UZP0bIRT0<VHY039V:@30<jOZ0030=FUYP3AYjd0dJN]0080ejb/00<0dJfe0=Nb/`3G/[<00P3M^;<0
0`3F^;go00000=Zm_0030=K3a`030=[9b03Mc/T0dLcD0080dLcD00@0d]3G0<G;g`34cN40a<gQ0P2h
a^D20;O6iP030;32i`2_`^P0[;oX0080[;oX0P2[_^P00`2Z_^So00000?ooo`0Q0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolGo`0000030000000I6AT06ATI00806ATI00D0000003<c<`0c<c<0<c<c
0000000204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl00`000000VIVI09VIV@0?09VIV@03
0000001oOgl0Ogmo00D0Ogmo0`000004ofIVIP<00000101<C4`3000000X0<c<c00D0000004a<C01<
C4`0C4a<00000002ofIVIP050000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<o`000002
0>KViP;o00001P3oool01ol00000i^KV0>KViP3Vi^Ko00000<c<c?l000000P2c/k<01`000000VIVI
0000001oOgoo000006IVIP0000000P1<C4`01@000000<c<c03<c<`0c<c<0000000@06ATI00<00000
o`000?l000005Ol000040?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool00P3ooolE
0:Vmj0030:Rlj02X^nL0Z;_W00<0Yk[W00<0YkWV0:Bfi@2S/^<00P2S/^<30::^h@80X:WM00@0W:?J
09:DdP2;RL`0RhW<0P22O<@207]`^`<0QW_000D0PW:h085//P21K;80PFbb08=X[@0208EWZ@<0RFRW
0`2=JjH2095]YP<0UW6W0P2JMJP00`2MNJT0WgNV09mgYP030:=kY`80YWjX00<0ZH6X0:YoYP2ZOjH0
102/PJH20:n3YP@0/X>S00<0]8JT0;J5X02hR:800P2hR:83o`000080_HbQ0`33TJ840<VHY080cYnX
0`3EYJH00`3AYjd0ejb/0=N/[0020=Nb/`<0gKRc0P3J_K`00ol00000gl>l0=K3a`020=[9b080gLk9
00D0dLcD0=;@e`3Bd=L0d]?I0<C=h@020<;=h`80]lKV00D0]LKW0:o2j02_`^P0[l;X0:boj0020:^o
j0<0Z[kX00?o00000?ooo`3oool07`3oool000T0oooo00Co00000?ooo`3oool0oooo5ol000000`00
00006ATI01TI6@0201TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00
000207moO`030000002IVIT0VIVI00<0VIVI0P00000:09VIV@030000001oOgl0Ogmo0080Ogmo1000
0003ofIVIP80000000?o00000000001<C4`00P1<C4`200000003o`0000000000<c<c00d0<c<c00Go
00000000001<C4`0C4a<00000002ofIVIP05o`00001oOgl0000009VIV@0000000P2c/k<01?l00000
c<c<o`000?l000020>KViPOo00000`3Vi^H00ol00000c<c<o`0000020;>c/`050000002IVIT00000
07moO`0000000P1VIVH00`000000C4a<0000000303<c<`030000000I6AT06ATI00<06ATI00<00000
o`000?l000005?l000040?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool0103ooolB
0:Vmj080Z;cX0`2X^nL00`2W^^L0YKSV0:Bfi@020:Bfi@<0Xk;S00@0XZkQ09^Ug@2HW]P0V9kH0`2B
U=800`2;RL`0PWc4089la00207]`^`<0MVJc0P1dGj`2085//P80PfR]0P25IjT208UXY`<0SF^V0P2A
KJH309IaY`0309YeZ02KLj@0WgNV0080WgNV0`2SNjL20:InZ0<0ZWnV102/PJH00`2_PjH0[h6S0;:3
X`030;:3X`030;B6Y02fQJ3o000000;o000000<0_8RO0;f<X@2mS:400P2mS:430<>AXP030<ZEW`39
V:@0bIRT0080d9fR00@0cYnX0=FUYP3EYJH0eJFV0`3G[:`00`3N/Z/0ek:c0=fh/`020=fh/`060>:m
/`3J_K`0gl>lo`00003Sb;d0f/W80`3Mc/T0103Od//0d]3G0=;Cf@3BdmT30<;=h`@0]LKW00D0[l;X
0:k1j02^`NP0ZkoX0:^nj0040:Znj003o`00003oool0oooo01h0oooo00090?ooo`04o`00003oool0
oooo0?oooaOo000000<0000001TI6@0I6AT00P0I6AT01`000000<c<c03<c<`0c<c<0000004a<C?l0
00000`1VIVH010000000Ogmo07moO`00000409VIV@040000002c/k<0/k>c000000P0VIVI00@00000
07moO`1oOgl0Ogmo0P000004ofIVIP<00000101<C4`3000000L0<c<c2?l0000503<c<`040000001<
C4`0C4a<000000;oIVIV00D0000007moO`000000VIVI000000020;>c/`03o`00003<c<`0c<c<00;o
00002P3Vi^H00ol00000c<c<o`0000020;>c/`050000002IVIT0000007moO`0000000P1VIVH00`00
0000C4a<0000000303<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l000005?l000040?oo
o`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool01@3ooolB0:Vmj080Z;cX00<0Z;_W0:Jj
i`2V^^L00P2U^>H00`2T]^D0X;7T0:2ai00209j/h@<0VjGM0P2HW]P209:DdP80RhW<0P22O<@207]`
^`80MVJc0P1dGj`207IKYP80PfR]0P25IjT308UXY`80SF^V0P2AKJH209IaY`0309M_X`2KLj@0Vg>T
00<0WgNV0`2SNjL00`2VOZP0YgjW0:MnY`030:YoYP<0[86V0`2_PJ<30;:3X`;o000000<0]XFP0;R8
XP2lR9l00P2lR9l20;f<X@030<:>WP33TJ80`i6R0080bYFO0P39V:@20=2MXP040<jOZ03EYJH0eJFV
0=FUYP80ejb/0P3N/Z/30=fh/`80h[fc0P3O`k`00ol00000hlRm0=g>b@020=g>b@80gm;;00D0hMO=
0=;Cf@3AeM`0dMGL0<;=h`020<3=i080]LKW0P2caNL00`2^`NP0[L3X0:^nj0020:^nj0<0Z[kX00?o
00000?ooo`3oool07P3oool000T0oooo00Co00000?ooo`3oool0oooo5_l000000`0000006ATI01TI
6@0201TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`03
0000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0409VIV@05
0000001oOgl0Ogmo07moO`0000001OmVIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00D0<c<c0ol0000801TI6@;o0000100c<c<010000000C4a<04a<C0000002ofIVIP050000001oOgl0
000009VIV@0000000P2c/k<01Ol00000c<c<0<c<c03<c<co000000P0i^KV00Co00000<c<c03<c<co
00000P2c/k<00`000000VIVI0000000207moO`060000001VIVH0IVIV0000001<C4`000000`0c<c<0
0`0000006ATI01TI6@0301TI6@0300000?l0003o000001?o0000103oool00ol00000oooo0?ooo`0E
0?ooo`03o`00003oool0oooo00H0oooo402Y_NP01@2X_>P0Yk_X0:Nkj02W^nP0Y[[W0080Y;SW0`2R
]NH20:2ai080WZcQ00@0VjGM09:If02<Sm40S8oA0P24PlX207Yf`P80PWc40P1kL;/207IV/`80M5n/
0P1fFjH207YKX`80QFNY0`29J:L208e[YP03095]YP2BJZ40UfnS0080UfnS0P2KLj@409mgYP80Xg^W
0`2WOZL30:YoYP80[86V00@0[82T0:n1X`2_PJ<0[h6S0ol000030;J5X0040;R8XP2lR9l0_8RO0;b8
W`80_HbQ0P32SYh00`33TJ80bYFO0<ZEW`020<VHY080d9fR0`3EYJH20=b/Y@050=N/[03N/Z/0g[:[
0>Bj[03M^;<00`3R_K<01P3V`k@0gl>l0>?8_Ol00000i/fn0=g>b@80gm;;0P3Qeld30=7Eg0040<oF
gP30cN@0_LcV0;g<iP80/lGW0P2aa>P20:g0j0<0ZkkX0P2Z_^P00`2Z_NSo00000?ooo`0N0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooolFo`0000030000000I6AT06ATI00806ATI00Go000003<c<`0c
<c<0<c<co`00000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@2IVIT00P2IVIT00ol0
0000/k>c0;>c/`040;>c/`030000002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo00000004
ofIVIP03o`0000000000C4a<0080C4a<1000000403<c<`Co00003@0I6AT00ol00000<c<c03<c<`02
03<c<`04o`00001<C4`0C4a<o`0000;oIVIV00P0000007moOol00000VIVI00000?l00000/k>co`00
00<0c<c<00?o00000>KViP3Vi^H0103Vi^H2o`000080c<c<00Ko00000;>c/`2c/k<0000009VIV@00
000207moO`060000001VIVH0IVIV0000001<C4`000000`0c<c<00`0000006ATI01TI6@0301TI6@03
00000?l0003o000001?o0000103oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00P0
oooo3`2Y_NP20:Rlj0030:Nkj02V^^P0Y[[X00<0Y;SW00@0X[GV09f`i@2JZ^80VZ[R0P2FX]d309:I
f080S8oA0P24PlX00`1jM/80L6Ni071W^@0306QK/080MVJc00<0M5n/07IKYP1fFjH00P1jFj<2081M
X@<0QV6P0P2<IJ02099ZX@<0UfnS0`2KLj@309mgYP030:=kY`2VOJL0YgjW0080YgjW0`2ZOjH00`2/
PJH0[82T0:b0Y003o`000080/X>S00@0/h:P0;J5X02fQJ00]XFP102lR9l01@2mS:40`XjN0<:>WP32
SYh0`i6R00<0bYFO0`3@WJ830=FUYP80g:bU00D0ejb/0=jbZ`3T^Z`0i;Z/0=fh/`020>:m/`80i/>d
0P3Sb;d0103VcKko00000>WB_P3Od//20>7Gc@80hM_@00D0dMGL0<oFgP3?e]h0bmKQ0;g<iP020;[;
i`80/LCX00H0[l?X0:c0j02/`>P0[<3X0:^nj02Z_^P40:Zmj003o`00003oool0oooo01`0oooo0009
0?ooo`04o`00003oool0oooo0?oooaKo000000<0000001TI6@0I6AT00P0I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00<0000006IVIP0000000P1oOgl01@000000VIVI09VIV@2IVIT0000000L0
/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000?oIVIV00<0000004a<
C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`?o00004P0I6AT01Ol00000<c<c03<c<`0c<c<0
000000<0C4a<00<00000ofIVIP0000000P1oOgl00`000000VIVI000000020;>c/`;o00000P3<c<`3
o`0000030>KVi_l0003o000000@0c<c<00Ko00000;>c/`2c/k<0000009VIV@00000207moO`060000
001VIVH0IVIV0000001<C4`000000`0c<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o0000
01?o0000103oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00X0oooo302Y_NP0102X
_>P0YkcX0:Nlj02W_>P30:Jjj0030:Bhi`2Q]^L0WK3U0080WK3U0P2JZ^8209JRg@80TYWH0P2<Sm42
08B3bP80NWK20P1`IkT206QK/00506ABZ01fI[<0M5n/07AO[01fFjH00P1jFj<2081MX@<0QV6P0P2<
IJ02099ZX@@0UfnS0P2KLj@209mgYP030:AkYP2VOJL0YWfW00@0YgjW0P2ZOjH3o`0000040:b0Y02_
PJ<0[h6S0;:3X`<0/h:P0P2fQJ040;b8W`040;f<X@32SYh0`XjN0<:>WP@0bYFO0`3@WJ800`3HYJ40
eJFV0=b/Y@020=b/Y@80g[:[0P3T^Z`00`3X`:d0h[fc0>:m/`020>K3]0070>S7]03Sb;d0i/fn0>K=
__l00000jmNo0>7Gc@020>7Kd080h=kC00H0cmKN0<_Fh@3;e^40amCT0;[;i`2fb>P40:o3j0030:c0
j02[_nP0ZkoX0080Z[kX0P2Z_NP00`2Y_NSo00000?ooo`0M0?ooo`002@3oool01?l00000oooo0?oo
o`3ooolFo`0000030000000I6AT06ATI00806ATI00D0000003<c<`0c<c<0<c<c0000000204a<C003
0000001VIVH000000080Ogmo00@0000009VIV@2IVIT000002@2c/k<01@000000VIVI09VIV@2IVIT0
000000<0Ogmo00@00000ofIVI_mVIVH00000101<C4`00`000000<c<c03<c<`0303<c<`03o`00000I
6AT06ATI01@06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C00400000?mVIVKoIVIV00000080
Ogmo00<0000009VIV@0000000`2c/k<2o`0000<0c<c<00?o00000<c<c03<c<`0103<c<`01_l00000
/k>c0;>c/`000000VIVI00000080Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c
<`0c<c<0000000@06ATI00<00000o`000?l000004ol000040?ooo`03o`00003oool0oooo01@0oooo
00?o00000?ooo`3oool02P3oool;0:Vmj0<0Z;cX00<0YkcX0:Jkj02V^nP00`2T^NP20:6fi`0309f`
i@2FZ^@0UZ[T0080T:7P00<0RYKI08B:dP24R]800P1lO/T3079``@0307Yf`P1`IkT0L6Ni0080J5^`
0P1TDZP207AO[080MU^V00<0NU^S081MX@20GJ400`26HJ0208aUX080TVZQ102GKj<209]cY00309mg
YP2TNjH0Y7^V00<0YWfW0P2WOZL3o`0000@0[82T0P2_PJ<40;>2X0030;J5X02iQIh0^HFN00<0_8RO
1032SYh40<ZEW`80d9fR0P3HYJ401P3EYJH0g:bU0=b/Y@3L[:D0i;JU0=jbZ`80i;Z/0P3X`:d02`3R
_K<0i/>d0>S7]03Xak@0jl^d0>K=_P3Yd[ko00000>_G_`3]g<40hM_@0080h=kC0P3MgmL00`3;e^40
amCT0<ODi0030;K8j080[l?X00@0[/7X0:^oj02[_nP0ZkkX0`2Z_^P30:Vmj003o`00003oool0oooo
01/0oooo00090?ooo`04o`00003oool0oooo0?oooaKo000000<0000001TI6@0I6AT00P0I6AT01000
0000<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo00@0000009VIV@2IVIT000002P2c
/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@00000ofIVI_mVIVH00000101<C4`00`000000
<c<c03<c<`0303<c<`03o`00000I6AT06ATI00X06ATI0ol0000901TI6@05o`00000c<c<0<c<c03<c
<`0000000P1<C4`01000003oIVIVofIVIP00000207moO`050000002IVIT000000;>c/ol000000P2c
/k<00ol00000c<c<0<c<c0060<c<c005o`00002c/k<0/k>c0;>c/`0000000P2IVIT00`000000Ogmo
0000000206IVIP040000001<C4`0C4a<o`0000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o
0000o`00000Bo`0000@0oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`0;0?ooo`/0
ZKgX102X_>P20:Jkj0030:Bij02Q]nP0Vk7W0080Vk7W0`2FZ^@2092Qh00308ZFf@24R]80Q8[B0080
O7k90P1bL<4206MQ^003071W^@1XFk00J5^`0080I5:X0P1UCj<207IKYP80NU^S00@0P5fQ08IQX026
HJ00QV6P0P2<IJ03099ZX@<0UfnS0P2KLj@30:AkYP80YWfW0ol000000`2WOZL0ZX2W0:Z0Y`040:b0
Y080[h6S102cPZ000`2fQJ00^HFN0;V5WP030;b8W`@0`XjN0`3:UIl20=:LWP030=2MXP3HYJ40f:FQ
00<0g:bU0P3T]ZD20>Bj[0<0j<2]0P3V`k@20>S7]0080>_;]03]ck@0jM:n0>_G_ol00000kMc10>kP
``3Pg]<20=gOe`80fN3K00@0amCT0<;BiP32d^H0]/SX0P2ca^P00`2^`NP0[L3X0:^nj0030:^nj080
Z[kX0`2Y_NP00`3ooooo00000?ooo`0K0?ooo`002@3oool01?l00000oooo0?ooo`3ooolFo`000003
0000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207mo
O`040000002IVIT0VIVIo`0000X0/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`0400000?mV
IVKoIVIVo`0000<0C4a<00<0000003<c<`0c<c<00P0c<c<2o`0000T06ATI1?l00003000000Co0000
1P0I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<00So0000ofIVI_mVIVH0000007moOol00000
000009VIV@8000000P2c/k<3o`0000D0c<c<0_l000030;>c/`060000002IVIT0VIVI0000001oOgl0
00000P1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI00<00000o`00
0?l000004_l000040?ooo`03o`00003oool0oooo01@0oooo00?o00000?ooo`3oool03@3oool80:Vm
j0<0Z;gX00<0Z;cX0:Nlj02T^^P00P2T^^P20:6gj00309^ai`2C[>L0TjcW0080RZ;T0P21U=d207V7
e080Q8[B00<0O7k9079``@1bL<400P1WHKP205]C[`80J5^`00D0I5:X06E?X`1UCj<0JdnO07IKYP02
07YKX`80P5fQ0`26HJ0208aUX080TVZQ0`2GKj<0102KLj@0XGNT0:AkYP2TNjH3o`0000040:ImY`2W
OZL0YgjW0:V2ZP<0ZX2W0`2/P:@00`2_PJ<0[h2R0:n0XP030;>2X0030;J5X02iQIh0^HFN0080_8RO
0P30S9d30<:>WP<0bYFO0P3BW9h0103@WJ80f:FQ0=RUX@3R[j420=b/Y@80i;JU00<0jknW0>Bj[03X
`:d00P3X`:d00`3[aJh0i/>d0>S7]0020>_;]0080>g?]03`dk@0jmNo0>gL`Ol00000k^330>gUaP3M
gmL20=WPf`80e=oP00@0`];V0;g?i`2mcnL0/lKX0P2`a>P20:g0j080ZkkX102Z_^P30:Vmj003o`00
003oool0oooo01X0oooo00090?ooo`04o`00003oool0oooo0?oooaKo000000<0000001TI6@0I6AT0
0P0I6AT010000000<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo00@0000009VIV@2I
VIT000002P2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@00000ofIVI_mVIVH000000`1<
C4`01@000000<c<c03<c<`0c<c?o000000P06ATI0ol0000;000000;o00001@0I6AT01Ol00000<c<c
03<c<`0c<c<000000080C4a<00@00000ofIVI_mVIVH000000P1oOgl00`000000VIVI09VIV@020000
00<0/k>c1Ol000050;>c/`060000002IVIT0VIVI0000001oOgl000000P1VIVH010000000C4a<04a<
C000000303<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l000004_l000040?ooo`03o`00
003oool0oooo01@0oooo00?o00000?ooo`3oool03@3oool90:Vmj080Z;gX0`2W_>P00`2T^^P0XKSY
0:6hj@0309^dj@80TjcW0P2:X^@2086Dg@0307V7e01bNL/0LWW;0080JFc20P1bL<401P1WHKP0Fe>_
05]C[`1BAjL0J5^`06ABZ080IDnS0P1[Cil207YKX`80P5fQ0`26HJ0208aUX080TVZQ0P2GKj<00`2L
LZ80XGNTo`000002o`000080Y7^V0P2VOJL00`2WOZL0ZH:Z0:V2ZP030:Z0Y`<0[82T0`2_P:830;>2
X0<0^HFN0P2lR9l20<2<W@80`XjN0P39Tid0103:UIl0dYbN0=:LWP3BW9h30=RUX@040>:_X@3L[:D0
g:bU0>BfY@80jknW00<0i;Z/0>S0[@3X`:d00P3[aJh00`3/b:l0j<Nd0>_;]0020>g?]0080?3C]03c
f;<0kMc1o`00003^h<<0kNG60>_Xb`3Ih=/20=COh080cMcT00D0_LoW0;S;j02hbnP0/<CX0:k2j003
0:boj0<0Z[kX1@2Y_NP00`3ooooo00000?ooo`0J0?ooo`002@3oool01?l00000oooo0?ooo`3ooolE
o`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000
000207moO`040000002IVIT0VIVI000000<0/k>c1Ol000040;>c/`060000002IVIT0VIVI0000001o
Ogl000000_mVIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00?o000001TI6@0I6AT01@0I6AT2
o`000100000000?o000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<00@0
0000ofIVI_mVIVKo00000P1oOgl01@000000VIVI09VIV@2IVIT0000000/0/k>c00D0000009VIV@2I
VIT0VIVI0000000207moO`040000001VIVH0IVIV00000080C4a<00D0000003<c<`0c<c<0<c<c0000
000401TI6@0300000?l0003o000001;o0000103oool00ol00000oooo0?ooo`0C0?ooo`03o`00003o
ool0oooo00l0oooo2@2Y_NP20:Rmj0040:Nlj02U^nT0YK_Y0:Fkj@80XKSY00@0VkCY09B`jP28YNP0
R:GX0P1jU^8206f5fP80NHOD0P1bNL/00`1YK<80GUfi05iM^@0206MQ^00305]C[`1BAjL0DTNW0080
I5:X00<0IDnS06]?W`1[Cil00P1cDid2081MX@<0QV6P0P2<IJ02099ZX@0409M_Xol0003o0000o`00
0080XGNT0`2TNjH20:ImY`@0ZH:Z0P2ZP:L20:b0Y0040:^0YP2_P:80[h2R0:n0XP<0/h:P102iQIh0
0`2lR9l0`8bM0<2<W@020<:>WP80bI>M00@0bYFO0=:LWP3BW9h0dYbN0P3HYJ430>:_X@80i;JU0P3[
_jL20>S0[@<0jlF^00@0k<R_0>_;]03[bk@0kLnd0P3`dk@0203cf;<0m]fc0>kP`ol00000kNG60>_X
b`3Wjm40e=oP0P3=g>@20<KGi`030;S;j02db>T0[/;X0080[/;X00<0[;oX0:^oj02[_nP00`2Z_^P5
0:Vmj003o`00003oool0oooo01T0oooo00090?ooo`04o`00003oool0oooo0?oooaGo000000<00000
01TI6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo00<0
000009VIV@0000000`2c/k<00ol00000c<c<0<c<c0030<c<c005o`00002c/k<0/k>c0;>c/`000000
0P2IVIT00`000000Ogmo00000002ofIVIP040000001<C4`0C4a<000000<0<c<c00?o000001TI6@0I
6AT01@0I6AT00ol0000000000000000A00000003o`00000I6AT06ATI00<06ATI00Go000003<c<`0c
<c<0<c<c0000000204a<C00400000?mVIVKoIVIV00000080Ogmo00Go000009VIV@2IVIT0VIVIo`00
000:0;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000204a<C005
0000000c<c<0<c<c03<c<`000000100I6AT00`00003o0000o`00000Bo`0000@0oooo00?o00000?oo
o`3oool04`3oool00ol00000oooo0?ooo`0A0?ooo`H0ZKgX0P2X_NP30:Nlj0030:Fkj@2S^^T0WKOZ
0080WKOZ0P2D/>X208RUj080NYKR00<0KHGJ06=ec`1SMLl00P1LIlD01P1YK<80GUfi05iM^@1@C[00
If6h05]C[`80DTNW0P1TDZP00`1UCj<0JdnO06]?W`0207=CW@80O5RM0`26HJ0208aUX003099ZXOl0
003o00000080W7:R0`2QMj@30:AkYP030:ImY`2ZQ:`0ZXB/00<0ZH:Z0P2ZP:L00`2/P:@0Zh2V0:^0
YP040:n0XP030;>2X02dPj00^HFN00<0^HFN1030S9d01032SYh0bI>M0<VCW@3:UIl30=:LWP80f:FQ
0`3R[j420>BfY@80jknW00@0klNY0>S0[@3[aJh0jlF^0P3/b:l0103/bK00jl^d0>g?]03`dk@20??H
/`040?KM/`3gi;<0kNG6o`000080in_A00D0hN_H0<gLi036enL0a]OW0;oBj0030;C8j@040:k2j02]
`NP0[L7X0:^oj0D0Z[kX1@2Y_NP00ol00000oooo0?ooo`0H0?ooo`002@3oool01?l00000oooo0?oo
o`3ooolEo`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`00`000000
IVIV0000000207moO`030000002IVIT0000000<0/k>c00?o00000<c<c03<c<`00`3<c<`01Ol00000
/k>c0;>c/`2c/k<000000080VIVI00<0000007moO`0000000_mVIVH010000000C4a<04a<C0000003
03<c<`03o`00000I6AT06ATI00D06ATI00?o00000000000000004@0000000ol000006ATI01TI6@03
01TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`00`00003oIVIV0000000307moO`050000002I
VIT0VIVI09VIV@0000002@2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1V
IVH000000P1<C4`01@000000<c<c03<c<`0c<c<0000000@06ATI00<00000o`000?l000004_l00004
0?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool04P3oool60:Vmj080Z;gX00<0YkcX
0:Jlj@2V_>T00P2S^^T00`2M]nX0V;C[09Rdj`0208^[j`80N9cX00@0HhOP06f5fP1]QMX0HgG?0P1L
IlD00`1DF[/0JFc205iM^@02051>/080Fe>_00<0DTNW0511X@1TDZP00P1UCj<00`1[Cil0Le>M07=C
W@0207aHW@<0QUnM0ol000000`2FK:00W7:R09abXP0209abXP80XGNT0P2TNjH0102[QJ`0ZXB/0:Z4
[02ZQ:`30:V2ZP80ZX2W102[P:H30:n0XP030;>2X02dPj00^HFN00<0^HFN1030S9d30<VCW@@0dYbN
00<0g:NO0=RUX@3R[j400P3R[j400`3[_:80jknW0>^oY`020>o7Z@80l<^]00P0jlF^0>c8[`3/bK00
k<V`0>g:[`3]ck@0l=>d0??H/`80m]fc00@0mnBc0?OY]03ekkSo00000P3QjmP0103Iiml0a]OW0;oB
j02od^P20;C8j@80/LGY00<0[L7X0:boj02Z_^P0102Z_^P70:Vmj003o`00003oool0oooo01L0oooo
00090?ooo`04o`00003oool0oooo0?oooaGo000000<0000001TI6@0I6AT00P0I6AT010000000<c<c
03<c<`00000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@0000000`2c/k<00ol00000
c<c<0<c<c0040<c<c004o`00002c/k<0/k>c00000080VIVI00<0000007moO`0000000_mVIVH01000
0000C4a<04a<C000000303<c<`03o`00000I6AT06ATI00@06ATI00?o00000000000000004`000000
0ol000006ATI01TI6@0301TI6@05o`00000c<c<0<c<c03<c<`0000000`1<C4`00`00003oIVIV0000
000307moO`040000002IVIT0VIVI09VIV@8000001P2c/k<00`000000VIVI09VIV@0209VIV@040000
001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0201TI
6@0300000?l0003o000001;o0000103oool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo
01<0oooo1@2Y_NP30:Rmj0030:Jlj@2U^nT0YK_Y00<0XKWZ0P2H]>/208^[j`80N9cX00D0HhOP055a
e01SMLl0HgG?05aWa@0205AJ^`80GUfi00@0D4j`048oY`1KDjl0DTNW0P1@@J4206E?X`0306]?W`1c
Did0Le>M0080O5RM0ol0000208mVWP<0UVbP0`2LLZ820:5gY0030:AkYP2[QJ`0ZhF/00<0ZXB/0`2Y
PZX00`2ZP:L0Z8>/0:R3[0030:^0YP<0[h2R0`2dPj030;V5WP@0`8bM0`39Tid30=:LWP80g:NO0`3R
[j420>^lXP80jknW0P3_ajT20?3;[@80k<R_0P3/bK001@3]bZl0l<f^0?3C]03cf;<0m]fc0080mnBc
00D0mnVd0?G_^?l00000hN_H0=WWg`020=3Ri@030;oBj02icNT0^LgY0080/LGY0P2^`nT20:boj0<0
Z[kX202Y_NP00ol00000oooo0?ooo`0G0?ooo`002@3oool01?l00000oooo0?ooo`3ooolEo`000003
0000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`01`000000IVIV0000001oOgl0
000009VIV@0000000`2c/k<00ol00000c<c<0<c<c0050<c<c009o`00002c/k<0/k>c0;>c/`000000
VIVI0000001oOgl0000000;oIVIV00@0000004a<C01<C4`000000P0c<c<00ol000006ATI01TI6@04
01TI6@03o`0000000000000001@0000000?o000001TI6@0I6AT0100I6AT01?l00000<c<c03<c<`00
000304a<C00400000?mVIVKoIVIVo`0000<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c
0;>c/`020;>c/`03o`00002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP04
0000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000Ao`00
00@0oooo00?o00000?ooo`3oool04`3oool00ol00000oooo0?ooo`0D0?ooo`D0ZKgX00<0Z;gX0:Rl
j02X_>P00`2U^nT0102Q^NX0W[S[09:ak02B/N`207jUk080HXoW0P13L]/204MPb080G6O500@0E5Zk
04Q</`18C;<0D4j`0P12?jL20597Y`030511X@1D@9d0IDnS0080JdnO0ol0000308IOW@80SfJN0`2F
K:0309abXP80XGNT102[QJ`30:Z4[0030:V2ZP2YRK<0Z8>/0080Z8>/0`2[P:H20:n0XP040:j2Y02d
Pj00]8>P0;B3X080^HFN00<0_8VO0<2<W@30S9d00P30S9d30<VCW@<0dYbN0P3LYil30>:_X@80jkbR
00<0llZU0>^oY`3_ajT00`3`bjd00`3^bk00k<R_0>c9/0020>g:[`060?3=[P3ddJ/0lmRc0?KM/`3g
i;<0mnVd0P3ekkP0103all3o00000>?ce`3@h^D20<KKj0030;W=j@2db>T0]<SY0080[/?Y00@0[L7X
0:^oj02[_nP0ZkoX0P2Z_^P90:Vmj003o`00003oool0oooo01H0oooo00090?ooo`04o`00003oool0
oooo0?oooaGo000000<0000001TI6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C0070000
001VIVH0000007moO`000000VIVI000000030;>c/`03o`00003<c<`0c<c<00H0c<c<00So00000;>c
/`2c/k<0000009VIV@000000Ogmo000000;oIVIV00@0000004a<C01<C4`000000P0c<c<00ol00000
6ATI01TI6@0301TI6@03o`0000000000000001H0000000?o000001TI6@0I6AT00`0I6AT01Ol00000
<c<c03<c<`0c<c<000000080C4a<00D00000ofIVI_mVIVKoIVIV0000000207moO`03o`00002IVIT0
VIVI00<0VIVI00<00000o`00000000000P00000409VIV@050000001oOgl0Ogmo07moO`0000000P1V
IVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l00000
4Ol000040?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool05@3oool50:Vmj0030:Rl
j02W_>T0YkcY00<0Y;_Y0P2N^>/209:ak080OZG/0P1RSnL00`13L]/0;ES;04MPb00204=C_@0305AJ
^`18C;<0B4bc0080D4j`00D0@SnW0597Y`1BAjL0D46Q05A0W@03o`000080Le>M00@0O5RM08IOW@26
Gid0QUnM0P2?IYh309I/X0<0W7:R00<0XGNT0:^2Z@2[PZT00`2[QJ`20:Z4[0030:nC^@2YRK<0ZHVc
00<0Z8>/0`2[P:H00`2_P:80[X:T0:j2Y0030;B3X0040;V5WP2lRIl0_8VO0;b9W`80`8bM00<0ai:N
0<VCW@39Tid0103BW9h20=bWW`80hZnQ0`3[_:800`3cbZD0klNY0>o7Z@020?3;[@80k/^`00<0jlNa
0>c9/03]bZl00P3`cJh01`3ddJ/0n=NX0?_NY03gi;<0mnVd0?G_^03all000P3[m</00ol00000fNgQ
0<KKj0020;kCjP030;C8j@2`aNT0/<GY00<0[L7X00<0ZkoX0:Znj02Z_^P00P2Z_^P90:Vmj003o`00
003oool0oooo01D0oooo00090?ooo`04o`00003oool0oooo0?oooaGo000000<0000001TI6@0I6AT0
0P0I6AT010000000<c<c03<c<`00000204a<C0070000001VIVH0000007moO`000000VIVI00000002
0;>c/`03o`00003<c<`0c<c<00L0c<c<00So00000;>c/`2c/k<0000009VIV@000000Ogmo000000;o
IVIV00@0000004a<C01<C4`000000P0c<c<00ol000006ATI01TI6@0301TI6@03o`00000000000000
01H0000000?o000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<00D00000
ofIVI_mVIVKoIVIV0000000207moO`030000002IVIT0VIVI00`0VIVI00D0000007moO`1oOgl0Ogmo
0000000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o
0000o`00000Ao`0000@0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`0G0?ooo`<0
ZKgX0`2X_NP20:Nlj@030:Bkj@2R^nX0V[O/0080V[O/0P2:[^h03`1^W>d0A7kS04Anh`0IF=00@g;K
02E7_P17H<P0@e>m03i9]@1DF[/0B4bc03PlZP1@C[00@SnW03PcX003o`00000305A0W@1OAI`0JdnO
0080Le>M0P1lF9d308IOW@80SfJN0`2FK:0209abXP<0Zh:Y0`2[QJ`00`2ZQ:`0[i>i0:nC^@030:V9
/`<0Z8>/0P2[P:H30:j2Y0<0]8>P00@0^HFN0;b9W`2lRIl0_8VO0P30S9d20<NBWP040<VCW@3BW9h0
dYbN0=:LWP<0g:NO00@0j;JP0>:_X@3[_:80jkbR0P3cbZD00`3ge:T0klNY0?3;[@030>k;/0040>_7
/@3]bZl0kLZ_0?3=[P80m=6[00`0n=NX0?_NY03liJ00n^^M0?G`W`3`m:L0joC;0>?ce`3IkN7o0000
0<gTj02ndnX20;O=jP030;35j@2^`^T0ZkoX00<0ZkoX0P2Z_^P;0:Vmj003o`00003oool0oooo01D0
oooo00090?ooo`04o`00003oool0oooo0?oooaGo000000<0000001TI6@0I6AT00P0I6AT010000000
<c<c03<c<`00000204a<C0070000001VIVH0000007moO`000000VIVI000000020;>c/`03o`00003<
c<`0c<c<00L0c<c<00Ko00000;>c/`2c/k<0000009VIV@00000207moO`0500000?mVIVH0000004a<
C00000000`0c<c<00ol000006ATI01TI6@0301TI6@03o`0000000000000001L0000000?o000001TI
6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c<000000080C4a<00D00000ofIVI_mVIVKoIVIV0000
000207moO`030000002IVIT0VIVI00/0VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP040000
001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000Ao`0000@0
oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`0H0?ooo`<0ZKgX0P2X_NP30:Jlj@80
X[_Z00<0V[O/09Jek@2F]Nd00P20Z^l01`1IT^`0A7kS04Anh`0IF=00;ES;02E7_P13Dkd00P0nBKD2
04Q</`?o000000@0>3>P0511X@1@@J40E42M0P1OAI`207=CW@80O5RM0`26Gid208mVWP<0UVbP00<0
W7:R0:MmYP2[PZT00P2[PZT30:^5[0@0[i>i0P2YRK<30:R3[0030:^0YP2WPZ`0[X:T00<0[X:T0P2d
Pj040;b9W`050<2<W@37TYh0ai:N0<NBWP39Tid00`3BW9h20=bWW`80j;JP00@0hZnQ0>^lXP3[_:80
llZU0P3ge:T0103df;40l<^]0>k;/03^bk020>_7/@050>W4/03]bZl0l<f^0?CAZ`3hejP00P3kgZ@0
203liJ00n^^M0?G`W`3`m:L0k?Vf0>KkbP3IkN7o00000P33f^/00`2gcNX0//OZ0:k2j@020:k2j@80
ZkoX00@0ZkkX0:Znj02Z_^P0Z[kX2`2Y_NP00ol00000oooo0?ooo`0D0?ooo`002@3oool01?l00000
oooo0?ooo`3ooolEo`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`0
1`000000IVIV0000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0070<c<c006o`00
002c/k<0/k>c0000002IVIT000000P1oOgl01@00003oIVIV0000001<C4`0000000<0<c<c00?o0000
01TI6@0I6AT00P0I6AT00ol0000000000000000I00000003o`00000I6AT06ATI00<06ATI00Go0000
03<c<`0c<c<0<c<c0000000204a<C00400000?mVIVKoIVIV000000<0Ogmo00<0000009VIV@2IVIT0
2P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@0000004a<C01<C4`000000`0c<c<00`00
00006ATI01TI6@0301TI6@0300000?l0003o0000017o0000103oool00ol00000oooo0?ooo`0B0?oo
o`03o`00003oool0oooo01T0oooo0`2Y_NP20:Rmj0@0Y[cY0P2Q^^/209Jek@80P:[_0P1IT^`01@0I
F=0003Zl000j_00W@;H0@e>m00?o000000@0>3bZ048oY`12?jL0>3>P0P1@@J401@1D@9d0GdFL05m5
W01/CY`0Le>M0080O5RM0`26Gid208mVWP80UVbP00<0X7JT0:MmYP2WOJH0102[PZT00`2[QJ`0^9^j
0:nC^@030:nC^@80ZHVc0P2XPj`0102OQkX0Yh:/0:N2[02WPZ`30:j2Y080]8>P102lRIl01030S9d0
ai:N0<NBWP37TYh40=:LWP80g:NO0P3X]Z00103dbJ80jkbR0>^lXP3cbZD20?ODZ@050?CH/@3^d[L0
k/^`0>k;/03[ak400P3Ya;00203[a:d0l<f^0?CAZ`3hejP0nmjT0?cUX03jjid0mO2O0P3`m:L01@3/
nKH0i__:0=;/iP3Bk>Ko00000080^]7[0P2banX01@2^`^T0[<3X0:c0j02[_^P0Z[kX00l0ZKgX00?o
00000?ooo`3oool04`3oool000T0oooo00Co00000?ooo`3oool0oooo5Ol000000`0000006ATI01TI
6@0201TI6@040000000c<c<0<c<c00000080C4a<00L0000006IVIP000000Ogmo0000002IVIT00000
0080/k>c00?o00000<c<c03<c<`01`3<c<`01_l00000/k>c0;>c/`000000VIVI00000080Ogmo00D0
0000ofIVIP000000C4a<0000000303<c<`03o`00000I6AT06ATI00806ATI00?o0000000000000000
6@0000000ol000006ATI01TI6@0301TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`01000003o
IVIVofIVIP00000307moO`030000002IVIT0VIVI00X0VIVI00D0000007moO`1oOgl0Ogmo00000002
06IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00
000Ao`0000@0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`0J0?ooo`<0ZKgX0`2X
_NP00`2V_>T0YKcY09njj`0209njj`80T[C^0P1fY_00100oQNT004[9000f_000>[`2o`00000:03i9
]@0c?Zh0<cj^03PlZP0T;:80@SnW03PcX00e;Y/0D46Q05A0W@80GdFL0P1/CY`207aHW@<0QUnM0P2?
IYh00`2FK:00X7JT0:1fY0030:MmYP<0Zh:Y0`2hVkX30:nC^@030:V9/`2NVLh0WhNj0080WhNj0`2W
PZ`30:j2Y0030;B3X02fQj<0]XNS00<0_8VO1037TYh30=:LWP80gj^P00<0g:NO0>RfX03X]Z000P3d
bJ820??:Y@030?ODZ@3df;40m=Ra0080k]:g00l0k/^`0>_7/@3Ya;00jLB`0>_4[@3_b:T0m=6[0?SG
Z03kgZ@0o>FP0?[[W@3el9l0l?BW0>ci]P3VnlX00P3Bk>H01036h>/0^]7[o`00002db^/30:o4j@03
0:c0j02[_nP0ZkoX0080Z[kX3P2Y_NP00ol00000oooo0?ooo`0C0?ooo`002@3oool01?l00000oooo
0?ooo`3ooolEo`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`01`00
0000IVIV0000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0080<c<c003o`00002c
/k<000000080VIVI00D0000007moO`00003oIVIV0000000204a<C0040000000c<c<0<c<co`0000@0
6ATI00?o00000000000000006@0000000ol000006ATI01TI6@0301TI6@04o`00000c<c<0<c<c0000
00<0C4a<00@00000ofIVI_mVIVH000000P1oOgl00`000000VIVI09VIV@0;09VIV@050000001oOgl0
Ogmo07moO`0000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00<06ATI
00<00000o`000?l000004Ol000040?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool0
703oool20:Vmj0<0Z;gX0P2U_>T00`2O^^/0WKW/08fck`0208fck`0306ZQl@0RMN?o000000;o0000
00D002fa02M0]P0Z?;40?TVe03<n[P0203PlZP0402@/XP0h<j00=BjK03D^V`80E42M00<0GdFL06a>
W01/CY`00P1kF9d308IOW@0308mVWP2FKJ40X7JT0080X7JT0`2WOJH20:^2Z@040;fL]`2hVkX0^9^j
0;RK^P80[i>i00@0[k[Q09jIcP2NVLh0WYW>0P2OQkX30:N2[0<0[X:T00<0]8>P0;J7X`2fQj<00`2l
RIl40<NBWP<0dYbN0P3OZj000`3LYil0j;JP0?C9XP020?C9XP040?_NY03ge:T0mmBY0?CH/@<0k]:g
00<0i<Jh0>_7/@3Ya;000P3[a:d0303_b:T0m/nU0?_NY03kgZ@0o>FP0?[[W@3ViWh0h>^60=odV`3N
oM@0d^cV0<KPj`80_=C/00@0]<[[o`00002db^/0[lCY0P2]`NT00`2[_nP0Z[kX0:Znj0020:Znj0h0
ZKgX00?o00000?ooo`3oool04P3oool000T0oooo00Co00000?ooo`3oool0oooo5Ol000000`000000
6ATI01TI6@0201TI6@040000000c<c<0<c<c00000080C4a<00L0000006IVIP000000Ogmo0000002I
VIT000000080/k>c00?o00000<c<c03<c<`0203<c<`00ol00000/k>c0000000209VIV@050000001o
Ogl00000ofIVIP0000000P1<C4`010000000<c<c03<c<ol0000401TI6@03o`0000000000000001T0
000000?o000001TI6@0I6AT00`0I6AT01?l00000<c<c03<c<`00000304a<C00400000?mVIVKoIVIV
00000080Ogmo00<0000009VIV@2IVIT02`2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@0
000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o0000017o0000
103oool00ol00000oooo0?ooo`0B0?ooo`03o`00003oool0oooo01`0oooo0`2Y_NP00`2X_NP0YkgY
0:BljP020:BljP80WKW/00l0SK?_o`000?l0003o0000029eh`00:K0003Jl000j_000;K409d2f02Xl
/@0c?Zh07bnW03PlZP0T;:800P0h<j00100e;Y/0E42M05A0W@1OAI`206a>W080NeRM0`29HYl209I]
X@@0X7JT0P2WOJH0102[PZT0_Ibg0;fL]`2mW;L20;RK^P040<gGh@2_^^40[k[Q0:njh@80WYW>0`2O
QkX30:N2[080[X:T0`2fQj<20;b9W`80`i6R0`37TYh30=:LWP80gj^P0P3X]Z030?C9XP040?_NY03i
kJX0mmBY0?CH/@<0k]:g00@0i<Jh0>W4/03Ya;00jlB]0P3_b:T0203fcjD0o=RN0?kPU03ii8T0l>F0
0>KVOP3PjhH0g_gD0P3DlnD01@38i>`0_=C/0;G<j`2`aN[o00000080/<GZ00<0[L7Y0:^oj02[_nP0
0`2Z_^P?0:Vmj003o`00003oool0oooo0180oooo00090?ooo`04o`00003oool0oooo0?oooaGo0000
00<0000001TI6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C0070000001VIVH0000007mo
O`000000VIVI000000020;>c/`03o`00003<c<`0c<c<00P0c<c<00?o00000;>c/`0000000P2IVIT0
1@000000Ogmo00000?mVIVH000000080C4a<00@0000003<c<`0c<c?o0000100I6AT00ol000000000
0000000I00000003o`00000I6AT06ATI00<06ATI00Co000003<c<`0c<c<000000`1<C4`01000003o
IVIVofIVIP00000207moO`030000002IVIT0VIVI00/0VIVI00D0000007moO`1oOgl0Ogmo00000002
06IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00
000Ao`0000@0oooo00?o00000?ooo`3oool04P3oool00ol00000oooo0?ooo`0M0?ooo`<0ZKgX0P2W
_NT20:BljP?o000000<0W;W]08Vbl029/_000P1NW?401@00:K0001JU000]/@0=;Zh0:Sba0080<cj^
00L07bnW02@/XP0B7IX0>3>P03D^V`0m<YX0E42M0080GdFL00<0K4jL07]HW@1kF9d00`29HYl209I]
X@@0X7JT0P2WOJH40;fL]`040;RK^P3=en40cMOQ0<gGh@80[k[Q0`2NVLh209n7^P<0Yh:/00<0[X:T
0:b5[02fQj<00`2fQj<00`2lRIl0`i6R0<>AXP020<NBWP80dYjQ00@0dYbN0=n[X03OZj00gj^P0P3X
]Z020?C9XP80nmjT00<0nNfZ0?;b_03df;400P3^d[L20>C6^0040=jk]@3Ya;00jlB]0>o8Z@80m/nU
00P0o=RN0?kPU03ii8T0i^In0>3[QP3BmjH0fOo>0=Cci@80b>C/00D0_MO]0;G<j`2ec>/0/<GZo`00
00020:g2j@030:^oj02Z_^P0Z[kX0080Z[kX402Y_NP00ol00000oooo0?ooo`0A0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolEo`0000030000000I6AT06ATI00806ATI00@0000003<c<`0c<c<00000
0P1<C4`01`000000IVIV0000001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0080<c<
c003o`00002c/k<000000080VIVI00D0000007moO`00003oIVIV0000000204a<C0040000000c<c<0
<c<co`0000@06ATI00?o00000000000000006@0000000ol000006ATI01TI6@0301TI6@04o`00000c
<c<0<c<c00000080C4a<00@00000ofIVI_mVIVH000000`1oOgl00`000000VIVI09VIV@0209VIV@Go
0000102IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@0000004a<C01<C4`000000`0c<c<0
0`0000006ATI01TI6@0301TI6@0300000?l0003o0000017o0000103oool00ol00000oooo0?ooo`0A
0?ooo`03o`00003oool0oooo01l0oooo0`2Y_NP3o`000080Y;cZ0`2K^Nd208Jal@0905:Gl@00D</0
01JU000AX000;K403Bj^02Xl/@0c?Zh07bnW008092bR00@04QfJ03D^V`0m<YX0?C:J0P1OAI`0101/
CY`0NeRM07]HW@1kF9d208URW`<0UVfQ0`2PMZ@20:MmYP050;^G/P2mW;L0_Ibg0;fL]`3Og=800P3=
en400`3D_L<0d;Fo0=2e_`020;jT_`0300n8i01^RM`0KXWL0080Yh:/00<0V8Fm0:b5[02/QJ`0102f
Qj<00`2lRIl0`i6R0<>AXP020<NBWP80dYjQ00D0dYbN0=n[X03OZj00gj^P0>o3Y0030?C9XP060?_N
Y03ikJX0nNfZ0?;b_03Wh/d0k]:g0P3Ta[P20=jk]@80jlB]00h0klRY0?K?Y@3lf9h0o^2D0?WTR@3`
iH00i^In0<KUO@3BmjH0fOo>0=?gi@38i>`0_MO]0;K>k0<0/<KZ00<0[L;Yo`00002/`>P0102Z_^PB
0:Vmj003o`00003oool0oooo0100oooo00090?ooo`04o`00003oool0oooo0?oooaGo000000<00000
01TI6@0I6AT00P0I6AT010000000<c<c03<c<`00000204a<C0070000001VIVH0000007moO`000000
VIVI000000020;>c/`03o`00003<c<`0c<c<00P0c<c<00?o00000;>c/`0000000P2IVIT01@000000
Ogmo00000?mVIVH000000080C4a<00@0000003<c<`0c<c?o0000100I6AT00ol0000000000000000H
00000003o`00000I6AT06ATI00<06ATI00Co000003<c<`0c<c<000000`1<C4`01000003oIVIVofIV
IP00000207moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000VIVI
09VIV@0209VIV@040000001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000000`0c<c<00`00
00006ATI01TI6@0201TI6@0300000?l0003o000001;o0000103oool00ol00000oooo0?ooo`0A0?oo
o`03o`00003oool0oooo01l0oooo0ol00000102Y_NP0YkgY0:Nmj@2W_NT20:BljP0309^ik@2J^Nd0
Pk3b0080Pk3b00/0B9?`001@b`005ZD0016P00d^[P0M=Jl09CN]01l_Y`006Yd092bR018MVP0203D^
V`0303dbVP1OAI`0GdFL0080K4jL0P1kF9d208URW`<0UVfQ0`2PMZ@01@2WOJH0^iNb0;^G/P2kUk80
_Ibg0080gmcB0P3O_[P30=2e_`050<RX^@2nY;l0]iJe00n8i01^RM`00`2HQKd30:b5[0<0]XNS1033
TJ801037TYh0dYjQ0=:NX@3BW9h20=n[X080kl>T0P3dbJ820?_NY0060?W]ZP3bl[`0l_:l0>ORc@3D
`/T0i<Jh0`3N^kD0303N^;00klRY0>o8Z@3fcjD0o=RN0?kPU03ii8T0l>F00<G@E`3BmjH0fOo>0=?g
i@80b>O]00@0_MW^0;K>k02fc^`0/<KZ0P2]`^T00`2/`>So00000:Znj0030:Znj180ZKgX00?o0000
0?ooo`3oool0403oool000T0oooo00Co00000?ooo`3oool0oooo5Ol000000`0000006ATI01TI6@02
01TI6@040000000c<c<0<c<c00000080C4a<00L0000006IVIP000000Ogmo0000002IVIT000000080
/k>c00?o00000<c<c03<c<`0203<c<`00ol00000/k>c0000000209VIV@050000001oOgl00000ofIV
IP0000000P1<C4`010000000<c<c03<c<ol0000401TI6@03o`0000000000000001P0000000?o0000
01TI6@0I6AT00`0I6AT01?l00000<c<c03<c<`00000204a<C004o`000?mVIVKoIVIV00000080Ogmo
00Co00000000002IVIT0VIVI0_l000070;>c/`05o`00002IVIT0VIVI09VIV@0000000P1oOgl01000
0000IVIV06IVIP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6AT00`00003o0000o`00
000Bo`0000@0oooo00?o00000?ooo`3oool04@3oool00ol00000oooo0?ooo`0L0?ooo`?o00000P3o
ool30:Vmj0<0YkgY0P2S_>X209Zik@0708>`lP21/?<0PK3c046@k`0007P0016P00d^[P0201de[`09
00l[Z@0O;jL001ZM018MVP095iH0=BjK03dbVP1>?9`0GdFL0080K4jL0P1kF9d308URW`80UVfQ0P2P
MZ@00`2cSJh0^iNb0;^G/P020;^G/P040>?Ca`3Og=80gkjh0=nn^080f[Rf00<0d;Fo0<RX^@38Z;T0
0`2gU[D0101^RM`0V8Fm09R5_@2HQKd30:b5[0<0]XNS1033TJ830=:NX@<0gj^P0P3_`j@01`3lhZ@0
m<VR0?_NY03kgZ@0nNfZ0?;b_03Wh/d00P3D`/T30=jk]@80g[R`00h0iK^/0?K?Y@3fcjD0o=RN0?kP
U03ii8T0e=AK0:WCIP31l9X0dOo;0=3hiP38ind0_MW^0;K>k0<0/LO[00D0[L;Y0:c0j@2/`>Wo0000
0:^oj0040:Znj180ZKgX00?o00000?ooo`3oool03`3oool000T0oooo00Co00000?ooo`3oool0oooo
5Ol000000`0000006ATI01TI6@0201TI6@040000000c<c<0<c<c00000080C4a<00L0000006IVIP00
0000Ogmo0000002IVIT000000080/k>c00?o00000<c<c03<c<`0203<c<`00ol00000/k>c00000002
09VIV@050000001oOgl00000ofIVIP0000000P1<C4`010000000<c<c03<c<ol0000401TI6@03o`00
00000000000001P0000000?o000001TI6@0I6AT00`0I6AT01?l00000<c<c03<c<`00000204a<C004
00000?mVIVKoIVIV00000080Ogmo00@0000009VIV@2IVIWo00002@2c/k<01Ol00000VIVI09VIV@2I
VIT000000080Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c<`0c<c<0000000@0
6ATI00<00000o`000?l000004_l000040?ooo`03o`00003oool0oooo0140oooo00?o00000?ooo`3o
ool06@3oool3o`0000H0oooo0`2Y_NP30:Nmj@<0Xkc[0P2J^Nh2086`l`0<046@k`004J0001nW00d^
[P0M=Jl09C^b00l[Z@006Yd04QfJ00TGUP0e;Y/0?C:J0P1>?9`206a>W080NeRM0`29HYl209I]X@03
0:1fY02cSJh0/hf^00@0^iNb00<0hm?70:_NO03O_[P00`3J^;H30<RX^@<0]iJe00<0/IFj06j9g02H
QKd00P2HQKd20:b5[080]XNS00<0^Y6[0<>AXP33TJ800P33TJ830=:NX@040>:dY`3OZj00gj^P0>o3
Y080o>:T0P3Rl9400`24gIX0[O7f0:Rch@030=C2b@030<V]_P3N^kD0g[^e0080g[R`00X0iK^/0>o5
Y`3lf9h0o^2D0?WTR@3Xg6/0aM1G0:WCIP3Aol/0d?SV0P36j>h0102lfNl0]/k/0;K>k02aan/20:k3
j@040:c0j@2[_nP0Z[kXo`0000<0Z[kX502Y_NP00ol00000oooo0?ooo`0>0?ooo`002@3oool01?l0
0000oooo0?ooo`3ooolFo`0000030000000I6AT06ATI00806ATI00P0000003<c<`0c<c<0000004a<
C0000000IVIV00000080Ogmo00<0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0060<c<c004
o`00002c/k<0/k>c00000080VIVI00D0000007moO`00003oIVIV0000000204a<C0040000000c<c<0
<c<co`0000D06ATI00?o00000000000000005P0000000ol000006ATI01TI6@0301TI6@04o`00000c
<c<0<c<co`000080C4a<00@00000ofIVI_mVIVH000000P1oOgl010000000VIVI09VIVOl0000;0;>c
/`04o`00002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c03<c
<`00000501TI6@0300000?l0003o000001;o0000103oool00ol00000oooo0?ooo`0A0?ooo`03o`00
003oool0oooo01H0oooo0ol0000:0?ooo`@0ZKgX0P2W_NT30:>lj`80V[W^0P21/?<0102X>000016P
000OY`0M=Jl202Dk/P04000JW@000Y404QfJ00TGUP80?C:J00<0CSbL06E<X01/CY`00P1kF9d308UR
W`80UVfQ102cSJh20;^G/P80hm?700<0i[n^0>>l[`3J^;H00P3J^;H0103B[K<0b:Ri0;nI/@2oVK42
0;NF]@80[XZ_0`2HQKd20:b5[0040;J7X`2jTJ/0^Y6[0;ZAZ`<0`i6R0P3BWZ430>:dY`80kl>T0P3l
hZ@00`3Rl940>GWR03UihP030:Rch@060=C2b@39[Kh0bJfn0<V]_P3N^kD0g[R`0P3U^j`01`3_aJL0
nM6P0?kLT`3ihH00j=a[0<G@E`2ck9L00P3;n>T01036j>h0_=W_0;C>k@2dc^d20;37j`030:k3j@2/
`>T0[<3Y0080ZkoX00<0Z[kXo`00002Z_^P05@2Y_NP00ol00000oooo0?ooo`0>0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolFo`0000030000000I6AT06ATI00806ATI00H0000003<c<`0c<c<00000
04a<C000000206IVIP05o`00001oOgl0000009VIV@0000000P2c/k<00ol00000c<c<0<c<c0060<c<
c004o`00002c/k<0/k>c00000080VIVI00D0000007moO`00003oIVIV0000000204a<C0040000000c
<c<0<c<co`0000D06ATI00?o00000000000000005@0000000ol000006ATI01TI6@0301TI6@04o`00
000c<c<0<c<c00000080C4a<00@00000ofIVI_mVIVH000000P1oOgl010000000VIVI09VIVOl0000<
0;>c/`04o`00002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c
03<c<`00000501TI6@0300000?l0003o000001;o0000103oool00ol00000oooo0?ooo`0A0?ooo`03
o`00003oool0oooo01@0oooo0_l0000?0?ooo`80ZKgX0`2W_NT00`2S_>/0Y;cZ09ZikP0209ZikP80
P[7c00T0001P000OY`0M=k407CF_02Dk/P0?:jT001ZM018MVP095iH00P0m<YX00`1>?9`0IDbP06E<
X00307]HW@80RF:O00<0UVfQ0:EoZ`2UOj/00`2cSJh00`2kUk80hm?70>?Ca`020>Jo[P80hkb_00<0
f[Rf0=:]/`3B[K<00`2oVK400`2gU[D0/X^]0;:;[@020:j:[`80@g_R00<0[8F/0:B@`02jTJ/00`2j
TJ/20<>AXP80cZ:Z00@0dYjQ0>:dY`3R]:L0h[BW0P3_`j@00`3lhZ@0h_2A02M3^@0306U^a@030:Rc
h@2SU<H0bJfn00<0bJfn0P3N^;00203U^j`0klFW0>o5Y`3idJ00o]bC0?WQP03De5/0/nbG0P3;n>T2
0;WGk`80]<k]00D0[lO[0:g3jP2]`nX0[L?Z0:c0j@020:^oj0<0Z[kX00?o00000:Vmj02Y_NP0402Y
_NP30?ooo`03o`00003oool0oooo00h0oooo00090?ooo`04o`00003oool0oooo0?oooaKo000000<0
000001TI6@0I6AT00P0I6AT01P000000<c<c03<c<`000000C4a<00000080IVIV00D0000007moO`00
0000VIVI000000020;>c/`03o`00003<c<`0c<c<00H0c<c<00Co00000;>c/`2c/k<000000P2IVIT0
1@000000Ogmo00000?mVIVH000000080C4a<00@0000003<c<`0c<c?o00001@0I6AT00ol000000000
0000000E00000003o`00000I6AT06ATI00<06ATI00Co000003<c<`0c<c<000000P1<C4`01P00003o
IVIVofIVIP000000Ogmoo`0000<0VIVI00?o00000;>c/`2c/k<00P2c/k<4o`0000@0/k>c00Co0000
09VIV@2IVIT000000P1oOgl010000000IVIV06IVIP00000204a<C0040000000c<c<0<c<c000000D0
6ATI00<00000o`000?l000004_l000040?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3o
ool04P3oool3o`000180oooo0P2Y_NP30:Nmj@80Y;cZ0100V[W^09^ik@2K^Nd0VkW]08Bbl`005:00
01nW01dg/@0U>k805c^g000AW`000Y402ANF014LV@0m<YX0CSbL0P1UC:0307eNY00308URW`2CL:L0
YGn[0080YGn[0`2cSJh20=c4`P030>?Ca`3V_jh0hkb_0080hkb_0`3B[K<30;nI/@<0/X^]0`2^RZl0
1013Nn80Y9300:B@`02TT<030;ZAZ`050<>AXP3>XZX0cZ:Z0<jRZP3BWZ400`3R]:L01P3gg[00o>:T
0?cRY00U<jT0CDfa02M3^@80JFk50`2SU<H20<V]_P80bJJf00T0g[R`0>Fk[03_aJL0klFW0?WAX03n
g9<0j=a[0<G@E`34m>h00P2mh_800`2ienl0//c]0;;<k@020:o7j`80[L?Z0P2[`>T00`2[_nP0Z[kX
0:Znj0020:Znj003o`00002Y_NP0ZKgX00h0ZKgX1@3oool00ol00000oooo0?ooo`0>0?ooo`002@3o
ool01?l00000oooo0?ooo`3ooolFo`0000030000000I6AT06ATI00806ATI00H0000003<c<`0c<c<0
000004a<C000000206IVIP050000001oOgl0000009VIV@0000000`2c/k<00ol00000c<c<0<c<c005
0<c<c004o`00002c/k<0/k>c00000080VIVI00D0000007moO`00003oIVIV0000000204a<C0040000
000c<c<0<c<co`0000D06ATI00?o00000000000000005@0000000ol000006ATI01TI6@0201TI6@04
o`00000c<c<0<c<c00000080C4a<00@00000ofIVI_mVIVH000000P1oOgl010000000VIVI09VIVOl0
00020;>c/`?o0000103<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00@0000007moO`1oOgl0
00000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00<06ATI00<00000o`00
0?l000004_l000040?ooo`03o`00003oool0oooo0100oooo00?o00000?ooo`3oool03`3oool3o`00
01D0oooo0`2Y_NP40:Nmj@80Y;cZ00X0VkW]09bik@27/_80^500000DX00M=k40>Tjl02Dk/P0G>kL0
00:A0P095iH0100A79T0CSbL04hlW01UC:0307eNY080Tg2W0`2UOj/30;>=[P80g<C200<0i/2_0>Jo
[P3S_:l00P3S_:l0103L/jh0dZfc0<RO[P38Wjh20;nI/@@0/X^]00@0[XZ_0:f3Z02[Q:/0@g_R0P2T
T<030;ZAZ`@0cZ:Z0`3R]:L20?ON/0030;_TP00G9Z809C>Y0080CDfa0`1YK/D20:>DaP040<V]_P39
Y[H0bJJf0<VV]P80iK^/00P0klFW0?WAX03ng9<0nN600>SLJ`2lo>@0_Nkc0;gRlP80]M?`00<0//c]
0:k6j`2]`nX00P2]`nX20:_0j@80Z[oX0`2Z_^P20:Vmj003o`00002Y_NP0ZKgX00T0ZKgX2P3oool0
0ol00000oooo0?ooo`0=0?ooo`002@3oool01?l00000oooo0?ooo`3ooolFo`0000030000000I6AT0
6ATI00806ATI00@0000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002I
VIT000000080/k>c00?o00000<c<c03<c<`0103<c<`01ol00000/k>c0;>c/`2c/k<0000009VIV@00
00000P1oOgl00`00003oIVIV0000000204a<C0050000000c<c<0<c<c03<c<ol000001@0I6AT00ol0
000000000000000C00000003o`00000I6AT06ATI00<06ATI00Co000003<c<`0c<c<000000P1<C4`0
1P00003oIVIVofIVIP000000Ogmo00000080VIVI00Co00000;>c/`2c/k?o0000203<c<`01ol00000
/k>c0;>c/`2c/k?o000009VIV@0000000P1oOgl00`000000IVIV0000000204a<C0050000000c<c<0
<c<c03<c<`000000100I6AT00`00003o0000o`00000Co`0000@0oooo00?o00000?ooo`3oool0403o
ool00ol00000oooo0?ooo`0<0?ooo`?o00006@3oool40:Vmj080YkgY0`2T_>X209bik@0:08NblP00
5:009Sne01dg/@0jC[`05c^g000Y/`000Y402ANF014LV@80CSbL00@0IDbP07eNY01mGZ@0OEjT0P2C
L:L40:EoZ`060;>=[P3La<80g<C20=c4`P3[`JT0i[n^0P3S_:l20=bc[P040=:]/`38Wjh0b9n^0;nI
/@80]hf[0`2bRjd30:f3Z0030:^4Z`2TT<00Y93000<0^Y6[00@0`J_30<jRZP3>XZX0cZ:Z0P3R]:L3
0?ON/005000GV`0G9Z80=3RW02DcZ@1=CK400`1lKKP00`2SU<H0Yhfi0<VV]P030<VV]P080=6Z/@3_
aJL0klFW0?WAX03ng9<0nN600=CDF`2mk_<20;OLl`030;GCl02`b^d0/<[]0080[/K[00<0[L?Z0:_0
j@2[`>T00P2Z_nP40:Znj0<0ZKgX00?o00000:Vmj02Y_NP01@2Y_NP=0?ooo`03o`00003oool0oooo
00d0oooo00090?ooo`04o`00003oool0oooo0?oooaKo000000<0000001TI6@0I6AT00P0I6AT01000
0000<c<c03<c<`00000204a<C0030000001VIVH000000080Ogmo00<0000009VIV@0000000`2c/k<4
o`0000030<c<c?l0003o000000<0/k>c00<0000009VIV@0000000P1oOgl00`00003oIVIV00000002
04a<C0050000000c<c<0<c<c03<c<ol000001@0I6AT00ol0000000000000000B00000003o`00000I
6AT06ATI00<06ATI00Co000003<c<`0c<c?o00000P1<C4`01P00003oIVIVofIVIP000000Ogmo0000
0080VIVI00Co00000;>c/`2c/k?o00002@3<c<`01ol00000/k>c0;>c/`2c/k?o000009VIV@000000
0P1oOgl00`000000IVIV0000000204a<C005o`00000c<c<0<c<c03<c<ol00000100I6AT00`00003o
0000o`00000Co`0000@0oooo00?o00000?ooo`3oool0403oool00ol00000oooo0?ooo`090?ooo`?o
00007P3oool00`2Y_NP0Z;gX0:Rmj0020:Nmj@<0Y;cZ0P2L^Nd010005:009Sne02Ho]@0jC[`204MS
b`05000Y/`0008D04AbI02`aY01>?9`00P1UC:0207eNY0<0Tg2W0`2UOj/30=c4`P040>ZoZ03[`JT0
hkb_0>>l[`<0g;>^0`38Wjh30;N=Z`80/X^]00@0[hBW0:f3Z02]PjP0[H>X0P2[Q:/204ZNm@030;ZA
Z`31Zl<0`J_300<0cZ:Z00T0i<^o0>:dY`3gg[00mmj`0000R@005i/04R6N01LVXP0d>:L00P1=CK42
07a]^0<0Yhfi0P39Y[H20=6Z/@80klFW00H0nM6P0?kLT`3Xg6/000000;OTmP2gg?<20;7?k`030;3:
k@2]a>/0[LC[0080[<;Z00<0Zl3Y0:Znj02Z_^P0102Z_^P40:Vmj004o`00002Y_NP0ZKgX0:Vmj140
oooo00?o00000?ooo`3oool03@3oool000T0oooo00Co00000?ooo`3oool0oooo5_l000000`000000
6ATI01TI6@0201TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl00`00
0000VIVI000000070;>c/`03o`00002c/k<0/k>c00<0/k>c00<0000009VIV@0000000P1oOgl00`00
003oIVIV0000000204a<C0050000000c<c<0<c<c03<c<ol000001P0I6AT00ol0000000000000000@
00000003o`00000I6AT06ATI00<06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C00800000?mV
IVKoIVIV0000001oOgl0000009VIVOl000020;>c/`03o`00003<c<`0c<c<00P0c<c<00Oo00000;>c
/`2c/k<0/k>co`00002IVIT000000080Ogmo00<0000006IVIP0000000P1<C4`01@000000<c<c03<c
<`0c<c<0000000@06ATI00<00000o`000?l000004ol000040?ooo`03o`00003oool0oooo0100oooo
00?o00000?ooo`3oool01P3oool3o`000280oooo0P2X_NP30:Nlj@80Y;cZ0`2M^^`01@005:009Sne
05eWa00jC[`0Af?;0080<W_U00<04AbI02`aY00/<J@00P1UC:0307eNY080Tg2W0P2UOj/20<^a`@06
0=c4`P3CmjD0jl6Y0>_1Z@3Z`:X0hkb_0`3L/jh00`3AYZ`0b9n^0<RO[P030;N=Z`030;:;[@2_Q:L0
[hBW00<0[H>X00@0ZhB[0:b2Y`2YPZX0BYke1031Zl<03@3>XZX0i<^o0>C;_`2TjYl0mmj`0003T`00
08T000NB000GV`0G9Z80=3RW05eC[P1=CK400P1lKKP40:N=^@090<VV]P3AZ[40dJZa0=jf[P3idJ00
o]bC0?WQP03Ref40]nCf0080/]Cb00D0/Lo_0:k7k02^an`0[LC[0:_1j@030:^oj@<0Z[kX0P2Y_^P6
0:Vmj003o`00003oool0oooo0140oooo00?o00000?ooo`3oool03@3oool000T0oooo00Co00000?oo
o`3oool0oooo5_l000000`0000006ATI01TI6@0201TI6@050000000c<c<0<c<c03<c<`0000000P1<
C4`00`000000IVIV0000000207moO`030000002IVIT0000000`0/k>c00H0000009VIV@2IVIT00000
07moO`000002ofIVIP040000001<C4`0C4a<000000<0<c<c00?o000001TI6@0I6AT0100I6AT2o`00
00l0000000?o000001TI6@0I6AT0100I6AT01?l00000<c<c03<c<`00000204a<C00800000?mVIVKo
IVIV0000001oOgl0000009VIVOl000020;>c/`04o`00003<c<`0c<c<0<c<c0Ko00000`3<c<`02?l0
0000/k>c0;>c/ol00000VIVI0000001oOgl000000P1VIVH010000000C4a<04a<C000000303<c<`05
0000000I6AT06ATI01TI6@0000005_l000040?ooo`03o`00003oool0oooo0100oooo00?o00000?oo
o`3oool00`3oool3o`0002H0oooo0P2X_NP40:Nlj@050:BljP2M^^`0WK[/0000C`0V?kD00P1MIl@2
04MSb`80<W_U00@04AbI02`aY01FD[40IDbP0`1mGZ@209=`Y`070:EoZ`3;/L40bk710<^a`@3CmjD0
j[nX0>_1Z@020>[0ZP<0g;>^0P3AYZ`00`38Wjh0_Y:Y0;jBZ@020;N=Z`@0[hBW0P2]PjP30:b2Y`80
ZH:Z0P31Zl<01`24j>l0i<^o0>C;_`3Tbkl0M6Ng024g[`0009400P0008T01@005i/04R6N03@hY`0d
>:L0GE>^00<0O6fh0P2WSKT00`2bTK@0dJZa0=6Z/@020=jf[P060>o7Z@3lfId0n^640;o4@`2afOD0
/]Cb0P2^b^h00`2^an`0[<;Z0:c2jP020:_1j@040:^oj@2Z_^P0Z[kX0:Znj0D0ZKgX1@3oool00ol0
0000oooo0?ooo`0@0?ooo`03o`00003oool0oooo00d0oooo00090?ooo`04o`00003oool0oooo0?oo
oaKo000000<0000001TI6@0I6AT00`0I6AT01?l00000<c<c03<c<`00000204a<C0030000001VIVH0
00000080Ogmo00@0000009VIV@2IVIWo00002`2c/k<01P000000VIVI09VIV@000000Ogmo000000;o
IVIV00@0000004a<C01<C4`000000`0c<c<2o`0000L06ATI0_l0000=00000003o`00000I6AT06ATI
00<06ATI00Co000003<c<`0c<c<000000P1<C4`02000003oIVIVofIVI_l00000Ogmoo`00002IVIWo
00000P2c/k<00ol00000c<c<0<c<c002o`0000H0i^KV00Co00000<c<c03<c<co00000P2c/k<01Ol0
0000VIVI0000001oOgl000000080IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI
6@0201TI6@0300000?l0003o000001Co0000103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooo`?o0000:`3oool20:Rmj0030:Nlj@2W_NT0YkgY0080Y;cZ00@0WK[/03=9^P0V?kD0
GFO41025Rm80100A79T0;36T05IB/@1FD[4307eNY00309=`Y`2^V<40[YS100<0bk710P3Z_jP01@3[
`JT0j/2Z0>[0ZP3T^Z/0g;>^00<0dJJ/0`2nTZT20;N=Z`040;:6YP2_Q:L0[hBW0:n4Y`80[H>X0`2/
PZL20:V2ZP0=0:J1Z`24j>l0Q>S_08CXk`3Tbkl0UWVa07AW]`0`@K<08CN_0003T`0008T000NB018Q
WP0203@hY`80GE>^0P1lKKP01@2WSKT0/Y6d0;:A]02bTK@0dJZa0080g[J^00H0klNY0?cIW@3jhH@0
[Lob0:k=l02/aN`30:c4j`030:c2jP2[_nT0ZkoY0080Z[oY00<0Z[kX0:Vnj02Y_^P00`2Y_NP80?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool03@3oool000T0oooo00Co00000?ooo`3o
ool0oooo5_l000000`0000006ATI01TI6@0301TI6@040000000c<c<0<c<c00000080C4a<00<00000
06IVIP0000000P1oOgl010000000VIVI09VIV@00000;0;>c/`060000002IVIT0VIVI0000001oOgl0
00000_mVIVH01@000000C4a<04a<C01<C4co000000@0<c<c00?o000001TI6@0I6AT01P0I6AT2o`00
00X0000000?o000001TI6@0I6AT0100I6AT01?l00000<c<c03<c<`00000204a<C00300000?mVIVH0
00000080Ogmo00D0000009VIVOl00000/k>co`0000030<c<c003o`00003Vi^H0i^KV00D0i^KV00Co
00000<c<c03<c<co00000P2c/k<01Ol00000VIVI0000001oOgl000000080IVIV00@0000004a<C01<
C4`000000P0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0003o000001Co0000103oool00ol0
0000oooo0?ooo`0?0?ooo`Co0000;P3oool30:Rmj0<0YkgY0P2T_>X0100004l0<dVj05eWa01MIl@2
08F;dP050:bMb03;_Ld0;36T02`aY01FD[400`25Mk`40:jH`@030<^a`@3/`:L0k<2W0080jl6Y00<0
j/2Z0>BjZ`3T^Z/0103AYZ`30;jBZ@030;N=Z`2bQZH0/XJV00<0[hBW00<0[H>X0:f1Y@2/PZL00P2/
PZL00`2YPZX0[X>W0:j3Y`020:J1Z`<0UWVa0P1dIkL01`0`@K<0002A0000N`0008L04R6N03PiY`0d
>:L00P1MDjh208Uc]0@0/Y6d00L0dJZa0=jf[P3_ajT0klNY0?cIW@3Ref40[<K]00<0[<G/00@0[<C[
0:_0j@2[`>T0ZkoY102Z_^P00`2Y_^P0oooo0?ooo`0:0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool03@3oool000T0oooo00Co00000?ooo`3oool0oooo5_l000000`0000006ATI01TI
6@0301TI6@040000000c<c<0<c<c00000080C4a<00<0000006IVIP0000000P1oOgl010000000VIVI
09VIV@00000;0;>c/`040000002IVIT0VIVI00000080Ogmo00@00000ofIVI_mVIVH000000P1<C4`0
0`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000001P000000
0ol000006ATI01TI6@0401TI6@04o`00000c<c<0<c<c00000080C4a<00P00000ofIVI_mVIVH00000
07moO`000000VIVIo`000080/k>c00Co00000<c<c03<c<co0000203Vi^H01?l00000c<c<0<c<c?l0
00020;>c/`05o`00002IVIT0000007moO`0000000P1VIVH010000000C4a<04a<C000000203<c<`03
0000000I6AT06ATI00806ATI00<00000o`000?l000005?l000040?ooo`03o`00003oool0oooo00l0
oooo0_l0000a0?ooo`<0Z;gX0P2W_NT30:BljP030000S01nN/D0OW[500@0[9g800@0bkg=02`aY01F
D[40EU:a0P25Mk`40:jH`@040<Soc@3/`:L0k<2W0>k5Y`80j/2Z0P3T^Z/00`3K[j`0dJJ/0=6V[002
0<JJZP80_Y:Y0`2bQZH30:n4Y`<0[H6U0P2/PZL30:j3Y`<0YX6[00d0UWVa0:21/@22L[T0PW:i0311
/`001IH0001k0000R@0269X04R6N03PiY`0d>:L0GE>^0080RG>d102bTK@20=jf[P040>o7Z@3lfId0
n^640;o4@`80Zl;[0`2[`NX00`2[`>T0Z[oY0:Zoj@030:Znj0l0oooo00?o00000?ooo`3oool03`3o
ool00ol00000oooo0?ooo`0<0?ooo`002@3oool01?l00000oooo0?ooo`3ooolGo`0000030000000I
6AT06ATI00806ATI00L0000003<c<`0c<c<0<c<c0000001<C4`000000080IVIV00@0000007moO`1o
Ogl000000P2IVIT00`000000/k>c0;>c/`080;>c/`040000002IVIT0VIVI00000080Ogmo00@00000
ofIVI_mVIVH000000`1<C4`00`000000<c<c03<c<`0303<c<`03o`00000I6AT06ATI00L06ATI2?l0
000701TI6@04o`00000c<c<0<c<c00000080C4a<00?o0000ofIVIP0000000P1oOgl01@000000VIVI
o`00002c/k?o00000080c<c<00?o00000>KViP3Vi^H0203Vi^H00ol00000c<c<o`0000020;>c/`05
o`00002IVIT0000007moO`0000000P1VIVH00`000000C4a<0000000203<c<`030000000I6AT06ATI
00806ATI00<00000o`000?l000005Ol000040?ooo`03o`00003oool0oooo0140oooo00?o00000?oo
o`3oool0;`3oool30:Rmj080YkgY00@0Y;cZ0:FmjP0008`0>e2m0P1nN/D30:bMb080eKJk0P1FD[43
08Eg_080[YS100D0b?o=0>NkY`3/`:L0k<2W0>k5Y`020>[0ZP050>BjZ`3K[j`0fjn/0=^_[03AYZ`0
0P36VZX20;jBZ@@0/XJV0P2_Q:L30:f1Y@80[8:W0`2^PjL30:J1Z`80X86a0P22L[T01P13D[`0<46c
0005UP0007/000NB018QWP80>3VW0P1MDjh208Uc]080/Y6d0P32W[@01P3N]Zh0klNY0?cIW@3jhH@0
Z/;[0:_2j`H0Z[oY503oool00ol00000oooo0?ooo`0>0?ooo`03o`00003oool0oooo00`0oooo0009
0?ooo`04o`00003oool0oooo0?oooaOo000000<0000001TI6@0I6AT00P0I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00?o000006IVIP0000000P1oOgl010000000VIVI09VIV@00000:0;>c/`04
0000002IVIT0VIVI000000<0Ogmo00@00000ofIVI_mVIVH000000`1<C4`00`000000<c<c03<c<`03
03<c<`;o00005@0I6AT01?l00000<c<c03<c<`00000204a<C00:00000?mVIVKoIVIV0000001oOgl0
000009VIVOl00000/k>co`000080c<c<00?o00000>KViP3Vi^H02@3Vi^H01Ol00000c<c<o`00002c
/k?o00000080VIVI00D0000007moO`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@0
6ATI6?l000040?ooo`03o`00003oool0oooo0180oooo00?o00000?ooo`3oool0;`3oool40:Rmj080
YkgY00<0`Uh003]@_@0kD;d00P1nN/D01@2/WLP0_J:n0;fR_P3E][/0f;:a008006WI0P25Mk`00`2^
V<40i;RX0>NkY`020>c0Y`80k/FW00<0klJY0>BjZ`3T^Z/00`3K[j`30<JJZP030;jBZ@2gRZH0/XJV
00<0/XJV00<0[hBW0:j1Y02]PJD00P2]PJD00`2/PZL0/8BU0:j3Y`030:j3Y`030:J1Z`2^Qj`0X86a
0080X86a0P22L[T01@13D[`000FF0000N`0008L00QRJ0080>3VW0P1XFk0208Uc]0040;:A]032W[@0
`Yjd0<:N]080klNY00<0o=VM0>;GH@2Z_nT00P2Z_nTJ0?ooo`03o`00003oool0oooo00d0oooo00?o
00000?ooo`3oool0303oool000T0oooo00Co00000?ooo`3oool0oooo5ol000000`0000006ATI01TI
6@0201TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV0000000207moO`050000
002IVIT0VIVI09VIV@0000002@2c/k<010000000VIVI09VIV@00000307moO`0500000?mVIVKoIVIV
ofIVIP0000000`1<C4`00ol00000000003<c<`0403<c<`;o00004P0I6AT01Ol00000<c<c03<c<`0c
<c<000000080C4a<00D00000ofIVI_mVIVH00000o`00000209VIV@05o`00002c/k?o00000<c<c?l0
00001@3Vi^H2o`0000D0i^KV00Go00000<c<c?l00000/k>co`00000209VIV@050000001oOgl00000
06IVIP0000000P1<C4`010000000<c<c03<c<`00000401TI6@0300000?l0003o000001Go0000103o
ool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo0300oooo0P2X_NP30:Rmj@040000S00k
D;d0ThO309>7``<0_J:n00<0aZFh0=Rb/@3H/[400P00JMT01023h_X0gkF[0>NkY`3W^jL20>c0Y`03
0>k5Y`3_aZT0klJY0080i;Z[0`3K[j`30<JJZP<0]hZV0`2bQZH30:j1Y080[H6U0`2`Q:D30:j3Y`<0
[XN/0P2PPK42089b^@80@e:l00<000FF0000MP0269X00P0h>JL206QK/080VGne1032W[@01@3I];@0
o=VM0?[QQ0000000Z[oY01`0oooo00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0<0?oo
o`002@3oool01?l00000oooo0?ooo`3ooolGo`0000030000000I6AT06ATI00<06ATI00@0000003<c
<`0c<c<000000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIV@000000
202c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00@00000ofIVI_mVIVKoIVIV0P00000304a<
C08000001@0c<c<2o`0000l06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C00:00000?mVIVKo
IVIV0000001oOgl0000009VIVOl00000/k>co`000080c<c<00Co00000>KViP3Vi^H0i^KV0_l00000
0`3ooooo00000>KViP030>KViP03o`00003<c<co00000080/k>c00Oo000009VIV@000000Ogmoo`00
001VIVH000000080C4a<00@0000003<c<`0c<c<000001@0I6AT00`00003o0000o`00000Eo`0000@0
oooo00?o00000?ooo`3oool0503oool2o`000340oooo0P2X_NP20:Rmj@030000M@0kD;d0>e2m0080
ThO30P2mX[h20<JU^0030=Rb/@3K/Jd0gkF[0080gkF[0P3W^jL00`3/`:L0k/FW0>k5Y`020>o6Z@04
0>_3[03K[j`0fjn/0=^_[080cj>[0P36VZX30;N:YP80/XJV00@0/8>T0:j1Y02^PJ@0[X6T0P2]PJD3
0;24Y@80[X>W00H0]HZX0:j7[02^Qj`0[XN/0:21/@2]SkL209:4`P<0EVc=00<0001k000:UP0269X0
0P0h>JL0101XFk00VGne09Uo]@2IOkD20<:N]080fKBd00<0l]6`0?_WU`3oool07P3oool00ol00000
oooo0?ooo`0<0?ooo`03o`00003oool0oooo00`0oooo00090?ooo`04o`00003oool0oooo0?oooaOo
000000<0000001TI6@0I6AT00`0I6AT010000000<c<c03<c<`00000204a<C0040000001VIVH0IVIV
o`000080Ogmo00D0000009VIV@2IVIT0VIVIo`0000080;>c/`03o`00002IVIT0VIVI0080VIVI00H0
000007moO`1oOgl0Ogmoo`0000000003ofIVIP030000001<C4`0C4a<0080C4a<0P00000503<c<`?o
00002`0I6AT00ol00000<c<c03<c<`0203<c<`0:0000001<C4`0C4a<00000?mVIVKo000007moO`00
0000VIVIo`000080/k>c00?o00000<c<c?l000000`3Vi^H00ol00000oooo0?ooo`020?ooo`07o`00
003Vi^H0i^KV0>KVi_l00000c<c<o`0000020;>c/`07o`00002IVIT0000007moO`000000IVIV0000
000204a<C0040000000c<c<0<c<c000000@06ATI00<00000o`000?l000005_l000040?ooo`03o`00
003oool0oooo01H0oooo00?o00000?ooo`3oool0;`3oool20:Vmj0040:Rmj@2X_NP0>5;103QB`@80
ThO300@0_J:n0<JU^036YKP0aZFh0P3K/Jd30=neZ`040>FkZ`3/`:L0k<2W0>k5Y`80klJY0P3[`j`2
0=^_[0<0cj>[00<0aYZZ0;f@Z02gRZH00P2gRZH00`2bQZH0/8>T0;23Y0030:j1Y0030:f1Y@2aPj@0
/8BU0080/8BU00@0[X>W0;F:Z02eRZP0]HZX0P2^Qj`30:f?]`80TXC20P1FK<d01@00;kL00027000:
UP0c>ZX0>3VW0080J5^`0`2IOkD01@32W[@0fKBd0=Vd]03bdK00fmUT0200oooo00?o00000?ooo`3o
ool02`3oool00ol00000oooo0?ooo`0<0?ooo`002@3oool01?l00000oooo0?ooo`3ooolGo`000003
0000000I6AT06ATI00<06ATI00@0000003<c<`0c<c<000000P1<C4`010000000IVIV06IVIP000002
07moO`050000002IVIT0VIVI09VIV@0000002@2c/k<2000000<0VIVI00<0000007moO`1oOgl00P1o
Ogl01P00003oIVIVofIVI_mVIVKo0000000000@0C4a<00<0000003<c<`0c<c<01@0c<c<3o`0000H0
6ATI0_l0000503<c<`0:0000001<C4`0C4a<00000?mVIVH0000007moO`000000VIVIo`000080/k>c
00?o00000<c<c?l000000`3Vi^H00ol00000oooo0?ooo`020?ooo`07o`00003Vi^H0i^KV0>KVi_l0
0000c<c<o`0000020;>c/`07o`00002IVIT0000007moO`000000IVIV0000000204a<C0040000000c
<c<0<c<c000000@06ATI00<00000o`000?l000005_l000040?ooo`03o`00003oool0oooo01L0oooo
00?o00000?ooo`3oool0;`3oool20:Vmj0030:Rmj00007D0>5;10080X8o21036YKP0103=ZKD0fk6]
0=neZ`3O]J/20>FkZ`030>_4[03/`:L0k/FW0080klJY0P3[`j`00`3S^jh0fjn/0<nSZ`020<nSZ`03
0<JJZP2mT:P0_I2X0080]hZV102`Pj@20:j1Y0<0/H>T0P2`Q:D40;F:Z080[XN/0`2]SkL00`2BQ<80
YZSG0:JXe`0206JHk0040000MP002YH0<cZZ03<jZP80J5^`0P2IOkD01P2_U;`0fKBd0=Vd]03bdK00
nnNG00000240oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0<0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolGo`0000030000000I6AT06ATI00<06ATI00@0000003<c<`0c<c<00000
0P1<C4`010000000IVIV06IVIP00000307moO`040000002IVIT0VIVI000000/0/k>c00D0000009VI
V@2IVIT0VIVI0000000407moO`8000000omVIVH2000000<0C4a<0`00000703<c<`Ko00001P0c<c<0
10000000C4a<04a<C0000002ofIVIP040000001oOgl00000o`0000<0/k>c00?o00000<c<c?l00000
0`3Vi^H01Ol00000oooo0?ooo`3ooooo000000<0i^KV00[o00000<c<c03<c<co00000;>c/ol00000
VIVI0000001oOgl000000P1VIVH00`000000C4a<0000000203<c<`030000000I6AT06ATI00<06ATI
00<00000o`000?l000005_l000040?ooo`03o`00003oool0oooo01P0oooo00?o00000?ooo`3oool0
;`3oool20:Vmj0030:I2000hD/40X8o20080X8o20P36YKP20<fY]@<0gkF[0P3U^j/00`3[a:`0l<b]
0>k5Y`020>o6Z@030>_3[03S^jh0hk^^00@0cj>[0`2mT:P20;N:YP040;:6YP2`Pj@0/8>T0;23Y080
[X6T0`2aPj@20;24Y@050;R;Y`2eRZP0]HZX0;F:Z02^Qj`00P2kUK420:f?]`@0YZSG0P1VV>`2000:
UP0403<jZP1bJ;P0LVRh09Uo]@<0[iBl00<0fKBd0?;A/03kiiL08P3oool00ol00000oooo0?ooo`0;
0?ooo`03o`00003oool0oooo00/0oooo00090?ooo`04o`00003oool0oooo0?oooaSo000000<00000
01TI6@0I6AT00P0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH00000
0P1oOgl01@000000VIVI09VIV@2IVIT0000000/0/k>c00@0000009VIV@2IVIT0VIVI0P00000407mo
O`0300000?mVIVKoIVIV00;oIVIV0P00000404a<C0800000400c<c<01?l00000C4a<04a<C?l00002
ofIVIP050000001oOgl0000009VIVOl000000P2c/k<00ol00000c<c<o`0000040>KViP05o`00003o
ool0oooo0?ooool000000`3Vi^H00ol00000c<c<o`0000020;>c/`07o`00002IVIWo000007moO`00
0000IVIV0000000204a<C004o`00000c<c<0<c<co`0000@06ATI00<00000o`000?l000005ol00004
0?ooo`03o`00003oool0oooo01T0oooo0_l0000`0?ooo`80ZKgX00D08Tg403QB`@2PSl80X8o20<JU
^0030<fY]@80gkF[0P3U^j/20>_4[0030?3<[@3bdZl0l]:_0080jl>/0P3S^jh0103G[k00cj>[0<nS
Z`3?Xj/30;f@Z0030;N:YP2bQZH0/XJV00<0/8>T00<0[X6T0;23Y02aPj@00P2aPj@00`2`Q:D0^8^W
0;R;Y`030;F:Z0<0^iFa00<0[Hng0<:_a`32[lL00P2VZ=L01P2dk_H0ZKkX0?ooo`0007H000ZF03<j
ZP80LVRh102_U;`00`3I];@0l]6`0=_II00S0?ooo`03o`00003oool0oooo00X0oooo00?o00000?oo
o`3oool02`3oool000T0oooo00Co00000?ooo`3oool0oooo6?l000000`0000006ATI01TI6@0201TI
6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000307moO`040000002I
VIT0VIVI000000`0/k>c0P00000309VIV@8000000`1oOgl3000000?oIVIV00<00000o`0000000000
0`1<C4`00ol00000000003<c<`0<03<c<`8000000P1<C4`02000003oIVIVofIVIP000000Ogmo0000
002IVIWo00000P2c/k<00ol00000c<c<o`0000040>KViP04o`00003ooooo0000o`0000<0i^KV00[o
00000<c<c03<c<co00000;>c/ol00000VIVI0000001oOgl000000P1VIVH00ol00000C4a<00000003
03<c<`030000000I6AT06ATI00806ATI00<00000o`000?l000005ol000040?ooo`03o`00003oool0
oooo01/0oooo00?o00000?ooo`3oool0;P3oool0102Y_NP0YT80029=a02PSl820:RHaP<0cJVe00D0
e;6f0=neZ`3U^j/0iK^[0>_4[0020?3<[@80l]:_00<0l=:c0>_3[03S^jh00`3G[k000`3?Xj/0a9V[
0<BIZ`020;f@Z0<0/XJV1P2`Pj@20;63Y0<0^8^W0`2eRZP30;^E/@<0`Zo700<0f_?P0?ooo`3oool0
0`3oool00`0008`09Sfc03<jZP02079X^0<0[iBl00<0ck[60?_WU`000000903oool00ol00000oooo
0?ooo`090?ooo`03o`00003oool0oooo00/0oooo00090?ooo`04o`00003oool0oooo0?oooaWo0000
100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000`1oOgl01000
0000VIVI09VIV@00000>0;>c/`030000002IVIT0VIVI0080VIVI0`00000307moO`<000000omVIVH2
000000<0C4a<0`00000803<c<`800000101<C4`02000003oIVIVofIVIP000000Ogmo0000002IVIWo
00000P2c/k<00ol00000c<c<o`0000050>KViP03o`00003Vi^H0i^KV00<0i^KV00co00000<c<c03<
c<co00000;>c/ol00000VIVI0000001oOgl0000006IVIP00000204a<C0050000000c<c<0<c<c03<c
<`000000100I6AT00`00003o0000o`00000Go`0000@0oooo00?o00000?ooo`3oool0703oool00ol0
0000oooo0?ooo`0^0?ooo`030:Vmj00RCL@0Z9S600<0Z9S600<0cJVe0=Ba]P3D/KH00P3M_KT00`3U
^j/0jlB/0?3<[@030?;B[`030?3B/`3Yc;T0hk^^00<0ejn`0`34VJ/20;f@Z0@0/XJV1@2`Pj@20;63
Y0@0^8^W00<0]HZX0<:I[P32VJh00P2kUK400`3A]Kl0`Zo70=[ch0060?ooo`030000S0002YH09Sfc
00<0LVRh00@0[iBl0<njaP3?^/H0lNc19P3oool00ol00000oooo0?ooo`080?ooo`03o`00003oool0
oooo00/0oooo00090?ooo`04o`00003oool0oooo0?oooaSo000000<0000001TI6@0I6AT00`0I6AT0
1@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000`1oOgl010000000VIVI
09VIV@00000>0;>c/`<00000102IVIT3000000<0Ogmo00<00000ofIVI_mVIVH00_mVIVH3000000<0
C4a<0`00000303<c<`8000001@1<C4`02000003oIVIVofIVIP000000Ogmo0000002IVIWo00000P2c
/k<01?l00000c<c<0<c<c?l0000:0>KViP0:o`00003<c<`0c<c<o`00002c/k?o000009VIV@000000
Ogmo00000080IVIV00<0000004a<C00000000`0c<c<00`0000006ATI01TI6@0201TI6@0300000?l0
003o000001So0000103oool00ol00000oooo0?ooo`0M0?ooo`03o`00003oool0oooo02h0oooo00D0
ZKgX000h_P2XV<H0Z9S60:jUc`030=Ba]P80gKfi0P3[a:`00`3`c:d0l]:_0?;B[`020?3B/`030>W<
^@3G[k00ejn`0080ejn`0`34VJ/00`2mT:P0]X^X0;:6YP030;:6YP030;23Y02`Q:H0/8>T0080/8>T
00<0/H>T0;R<Y`2hRjL00`2hRjL30<:I[P040;^E/@3A]Kl0dKFo0>Ojb`P0oooo00<0002<02Hm/`23
Pl/00P23Pl/30<njaP030<oUN`3oool0oooo02@0oooo00?o00000?ooo`3oool0203oool00ol00000
oooo0?ooo`0;0?ooo`002@3oool01?l00000oooo0?ooo`3ooolHo`0000030000000I6AT06ATI00<0
6ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV00000080Ogmo00D00000
09VIV@2IVIT0VIVI0000000@0;>c/`@000000`2IVIT01_l00000Ogmo07moO`1oOgl00000o`000080
00000omVIVH2000000@0C4a<0`00000604a<C004o`000?mVIVKoIVIV00000080Ogmo00<0000009VI
VOl000000P2c/k<01?l00000c<c<0<c<c?l000090>KViP06o`00003<c<`0c<c<o`00002c/k?o0000
0P2IVIT01@000000Ogmoo`00001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6AT00`00
003o0000o`00000Io`0000@0oooo00?o00000?ooo`3oool07P3oool2o`0002l0oooo00<0ZKgX0:jU
c`2^YLl00P2^YLl01@3D/KH0gKfi0=fm^@3M_KT0i/fm0080l<b]00<0l]:_0?3B/`3`d[<00P3Yc;T0
0`3L`[h0ejn`0=N_/0020<ZU/`80a9V[0`2fRjP30;:6YP<0/8BV0P2`Pj@00`2aPj@0^8bW0;R<Y`03
0;R;Y`<0`YV^0`3A]Kl00`3Wn//0oooo0?ooo`070?ooo`0300M5a00V?K<0Ph?;0080Ph?;00<0ck[6
0?7/`@3oool09`3oool00ol00000oooo0?ooo`070?ooo`03o`00003oool0oooo00/0oooo00090?oo
o`04o`00003oool0oooo0?oooaSo000000<0000001TI6@0I6AT00`0I6AT01@000000<c<c03<c<`0c
<c?o000000<0C4a<00Co000006IVIP1VIVH000000P1oOgl01@000000VIVI09VIV@2IVIWo000001@0
/k>c0P00000209VIV@<00000101oOgl2000000?oIVIV00<0000004a<C01<C4`0201<C4`2000000?o
IVIV00H0000007moO`1oOgoo000009VIVOl000020;>c/`04o`00003<c<`0c<c<o`0000L0i^KV0_l0
00030<c<c003o`00002c/k?o00000080VIVI00D0000007moO`000000IVIV0000000204a<C0040000
000c<c<0<c<c000000@06ATI00<00000o`000?l000006Ol000040?ooo`03o`00003oool0oooo0200
oooo00?o00000?ooo`3oool0;@3oool01@2Y_NP0[ZG?0:jUc`2^YLl0e;6f0080gKfi0P3VcKd01P3^
gl80kng60>[bc@3Zl/d0l=:c0>W<^@80g<:n00@0ejn`0<ZU/`3:YK<0bZFc0P34VJ/30;J;Z080/XJV
00@0/HNY0;24YP2`Q:H0/8BV0P2`Pj@30;R<Y`80^8^W0P35WJh20<:I[P030=^n_03A]Kl0io[;00/0
oooo00<01dG408>3b`23Pl/00P2S`nl00`3ak<40oooo0?ooo`0W0?ooo`03o`00003oool0oooo00L0
oooo00?o00000?ooo`3oool02P3oool000T0oooo00Co00000?ooo`3oool0oooo6?l000000`000000
6ATI01TI6@0401TI6@040000000c<c<0<c<c000000<0C4a<00@0000006IVIP1VIVH000000`1oOgl0
10000000VIVI09VIV@0000090;>c/`Oo00001P2c/k<2000000<0VIVI0P00000407moO`0400000?mV
IVKoIVIVofIVIP<000001@1<C4`2000000CoIVIV00L0000007moO`1oOgl0Ogmo0000002IVIWo0000
0080/k>c00Go00000<c<c03<c<`0c<c<o`0000050>KViP03o`00003<c<`0c<c<0080c<c<00?o0000
0;>c/ol000000P2IVIT00`000000Ogmo07moO`0200000080C4a<00D0000003<c<`0c<c<0<c<c0000
000401TI6@0300000?l0003o000001Wo0000103oool00ol00000oooo0?ooo`0Q0?ooo`03o`00003o
ool0oooo02h0oooo00@0[ZG?0;>kh02c^n00gKfi0`3VcKd01P3^gl80kng60>[bc@3Zl/d0hO3J0>W<
^@80g<:n103:YK<00`34VJ/0^i>^0;^C[P020;J;Z0030;:6YP2aQjT0/HNY00<0/8BV0P2`Pj@30;R<
Y`050;R;Y`35WJh0aIf^0<FM[P32VJh00P3K_[`00`3JnZh0oooo0?ooo`0;0?ooo`040019[@2S`nl0
Xl?_097/^b/0oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`0:0?ooo`002@3oool0
1?l00000oooo0?ooo`3ooolIo`0000030000000I6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c
0000000304a<C0030000001VIVH0000000<0Ogmo00D0000009VIV@2IVIT0VIVI000000060;>c/`;o
00001oo<c<`3o`0000D0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03
00000?mVIVKoIVIV00?oIVIV1@000006ofIVIP040000001oOgl0Ogmo00000080VIVI00Co00000;>c
/`2c/k?o0000103<c<`5o`0000@0c<c<00Ko00000;>c/`2c/k?o000009VIVOl0000207moO`030000
001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6AT00`00003o0000o`00000Jo`0000@0
oooo00?o00000?ooo`3oool08P3oool00ol00000oooo0?ooo`0^0?ooo`070;>kh02]foL0[M_g0:gK
m`3VcKd0k]o20>o]aP020>[bc@040>7`fP3>iNP0c^GX0=c2_P80cKS60`3:YK<30;^C[P80]X^X102a
QjT20;24YP030;23Y02gS:T0]hbY0080^8bW1035WJh30=^n_3d0oooo00?o00000?ooo`3oool01P3o
ool00ol00000oooo0?ooo`0:0?ooo`002@3oool01?l00000oooo0?ooo`3ooolIo`0000030000000I
6AT06ATI00@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV000000<0
Ogmo00@0000009VIV@2IVIT000001@2c/k<00ol0003oc<c<olc<c00:olc<c0Co00000P2c/k<40000
000409VIVOl00000000000000080Ogmo00?o000000000?mVIVH03OmVIVH010000000Ogmo07moO`00
000209VIV@04o`00002c/k<0/k>co`0000/0c<c<0_l000001@2c/k?o0000o`00002IVIT000000080
Ogmo00<0000006IVI_l000000P1<C4`01@000000<c<c03<c<`00003o000000@06ATI00<00000o`00
0?l000006_l000040?ooo`03o`00003oool0oooo02<0oooo00?o00000?ooo`3oool0;P3oool20:gK
m`0307WSkP000000ZKgX00@0ZKgX00<0c^GX0:KFn03=^<H00`3=^<H00`3:YK<0_Z6j0;^C[P020;^C
[P030;J;Z02bS:h0/Xb^00<0/HNY0P2`Q:H30;N<Z@80^8bW00H0aj6a0<FM[P35WJh0aIf^0>?<`03K
_[`o0?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool02P3oool000T0oooo00Co0000
0?ooo`3oool0oooo6Ol000000`0000006ATI01TI6@0401TI6@050000000c<c<0<c<c03<c<`000000
0P1<C4`010000000IVIV06IVIP00000307moO`050000002IVIT0VIVI09VIV@000000102c/k<00ol0
003oc<c<olc<c00>olc<c0;o0000102c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo0P00000;
ofIVIP050000001oOgl0Ogmo07moO`0000000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000T0c<c<
00Co00000;>c/`2c/k?o00000`2IVIT00`000000Ogmo0000000206IVIP040000001<C4`0C4a<0000
0080<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000Jo`0000@0oooo00?o00000?oo
o`3oool0903oool2o`0002l0oooo2@2Y_NP20:KFn080cKS600@0]kOH0;jQ^P2nXKX0_Z6j0P2kTjh3
0;:<[P<0/HNY00<0/8BV0;F>[@2gS:T00P2gS:T00`2hS:L0aj6a0<NQ/@020<FM[P80hlc0@@3oool0
0ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo
0?oooa[o000000<0000001TI6@0I6AT0100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0
000006IVIP1VIVH000000`1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00?o0000olc<c?o<
c<`03oo<c<`00ol00000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIVOl00000101oOgl20000
00SoIVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@04o`00002c/k<0/k>c0;>c/`;o00001P3<
c<`01?l00000/k>c0;>c/ol0000309VIV@030000001oOgoo00000080IVIV00@0000004a<C01<C4`0
00000P0c<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o000001_o0000103oool00ol00000
oooo0?ooo`0V0?ooo`03o`00003oool0oooo02d0oooo302Y_NP20;Ngf080_Z6j00<0^i>^0;>F^P2b
S:h00P2bS:h30;67Z@<0]Hj]0P2gS:T40<NQ/@030<FM[P3Sc<00hlc00440oooo00?o00000?ooo`3o
ool0103oool00ol00000oooo0?ooo`0:0?ooo`002@3oool01?l00000oooo0?ooo`3ooolKo`000003
0000000I6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV
000000<0Ogmo00D0000009VIV@2IVIT0VIVI000000030;>c/`03o`000?o<c<coc<c<013oc<c<00?o
00000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000D0Ogmo00<00000o`0000000000
0_mVIVH3000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`030;>c/`Ko0000
00<0/k>co`000?l000000P2IVIT01000003o000007moO`00000206IVIP040000001<C4`0C4a<0000
0080<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000Lo`0000@0oooo00?o00000?oo
o`3oool09`3oool00ol00000oooo0?ooo`0]0?ooo`P0ZKgX103oool00`1I]?/0_Z6j0:fYd`030;>F
^P<0/Xb^00<0/HNY0;>B]@2eSZd00P2eSZd20;N<Z@@0aj6a00<0jN?;0>?<`03oool0@P3oool00ol0
0000oooo0?ooo`030?ooo`03o`00003oool0oooo00X0oooo00090?ooo`04o`00003oool0oooo0?oo
oa_o000000<0000001TI6@0I6AT00`0I6AT00`000000<c<c03<c<`0203<c<`04o`00001<C4`0C4a<
o`0000<0IVIV00Co000007moO`1oOgoo00000`2IVIT00`000000/k>c0;>c/`020;>c/`03o`000?o<
c<coc<c<013oc<c<00Go00000;>c/`2c/k<0/k>c0000000409VIV@030000001oOgl0Ogmo00D0Ogmo
0P00000707moO`030000002IVIT0VIVI0080VIVI00?o00000;>c/`2c/k<02@2c/k<01Ol00000VIVI
09VIV@2IVIT0000000<0Ogmo00<0000006IVIP0000000`1<C4`010000000<c<c03<c<`00000501TI
6@0300000?l0003o000001co0000103oool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo
02d0oooo0`2Y_NP90?ooo`<0[JWC0P2cU[X20;:<[P040:nMa02cT[D0/i:e0;>B]@80]Hj]00<0]hbY
0<NW^@37YkT00P37XK420>WSbdD0oooo00?o00000?ooo`3oool00`3oool00ol00000oooo0?ooo`09
0?ooo`002@3oool01?l00000oooo0?ooo`3ooolKo`0000030000000I6AT06ATI00@06ATI00D00000
03<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV000000<0Ogmo00D0000009VIV@2IVIT0
VIVI000000040;>c/`03o`000?o<c<coc<c<00ooc<c<00?o00000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo00d0Ogmo00<0000009VIV@2IVIT00P2IVIT2o`0000P0
/k>c0_l0000309VIV@070000001oOgl0Ogmo07moO`000000IVIV0000000304a<C0040000000c<c<0
<c<c000000D06ATI00<00000o`000?l000007Ol000040?ooo`03o`00003oool0oooo02T0oooo0_l0
000]0?ooo`03o`00003oool0oooo00X0oooo0P2]ZM<20;>F^P030;:<[P2_WL@0[ig400<0/i:e0P2e
SZd30<NW^@030<NQ/@3Yhl/0jN?;04L0oooo00?o00000?ooo`3oool00P3oool00ol00000oooo0?oo
o`090?ooo`002@3oool01?l00000oooo0?ooo`3ooolLo`0000030000000I6AT06ATI00<06ATI00<0
000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00D0000007moO`1oOgl0
Ogmo0000000309VIV@030000002c/k<0/k>c0080/k>c00?o0000olc<c?o<c<`03oo<c<`00ol00000
/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl03@1oOgl00`000000
VIVI09VIV@0309VIV@;o0000102c/k<2o`0000@0VIVI00Go000007moO`1oOgl0Ogmoo`00000206IV
IP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000M
o`0000@0oooo00?o00000?ooo`3oool0:`3oool00ol00000oooo0?ooo`0Z0?ooo`03o`00003oool0
oooo00d0oooo0P2M/^L30:nMa080/i:e00<0]Hj]0<Fcb@35/lT00P37YkT00`3@oll0oooo0?ooo`17
0?ooo`03o`00003oool0oooo0080oooo00?o00000?ooo`3oool02@3oool000T0oooo00Co00000?oo
o`3oool0oooo7Ol000000`0000006ATI01TI6@0301TI6@030000000c<c<0<c<c0080<c<c00D00000
04a<C01<C4`0C4a<0000000206IVIP060000001oOgl0Ogmo07moO`00003o00000P2IVIT2000000<0
/k>c0_l0000@olc<c003o`00002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0<07moO`030000002IVIT0VIVI00D0VIVI1?l0000409VIV@8000000P1oOgl200000080
IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o0000
01ko0000103oool00ol00000oooo0?ooo`0/0?ooo`03o`00003oool0oooo02T0oooo00?o00000?oo
o`3oool0403oool20:nMa0030;>B]@2gcn`0aK?90080aK?900<0ajNi0?ooo`3oool0BP3oool01Ol0
0000oooo0?ooo`3ooooo000000/0oooo00090?ooo`04o`00003oool0oooo0?oooago000000<00000
01TI6@0I6AT0100I6AT00`000000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<04a<C?l000000P1V
IVH00ol00000000007moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<2o`0000koc<c<
00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00`0Ogmo
00<0000009VIV@2IVIT02`2IVIT2000000<0Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C003
0000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00`0I6AT00`00003o0000o`00000No`0000@0
oooo00?o00000?ooo`3oool0;@3oool00ol00000oooo0?ooo`0X0?ooo`03o`00003oool0oooo01<0
oooo0P2gcn`00`35/lT0oooo0?ooo`1=0?ooo`04o`00003oool0ooooo`0000/0oooo00090?ooo`04
o`00003oool0oooo0?oooako000000<0000001TI6@0I6AT0100I6AT00`000000<c<c03<c<`0203<c
<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<0
00000;>c/`2c/k<00`2c/k<2o`0000coc<c<00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00`0Ogmo0`00000809VIV@8000000`1oOgl200000080IVIV0P00
000204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00`0I6ATRo`0000@0oooo00?o
00000?ooo`3oool0;P3oool2o`0002P0oooo00?o00000?ooo`3oool0IP3oool00ol00000ooooo`00
000;0?ooo`002@3oool01?l00000oooo0?ooo`3ooolOo`0000030000000I6AT06ATI00@06ATI00<0
000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl0
Ogmo0P00000209VIV@0300000?l00000/k>c00@0/k>c0ol00008olc<c0;o00001@2c/k<00`000000
VIVI09VIV@0309VIV@030000001oOgl0Ogmo00h0Ogmo1`0000000ol00000Ogmo07moO`0207moO`05
o`00001VIVH0IVIV06IVIP0000000`1<C4`01P000000<c<c03<c<`0c<c<00000o`0000D06ATI00<0
0000o`000?l000008?l000040?ooo`03o`00003oool0oooo0300oooo00?o00000?ooo`3oool09@3o
ool00ol00000oooo0?ooo`1V0?ooo`03o`00003ooooo000000/0oooo00090?ooo`04o`00003oool0
oooo0?oooaoo000000<0000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0203<c<`060000001<
C4`0C4a<04a<C?l0000000000P1VIVH00ol00000000007moO`0207moO`8000000P2IVIT00`000000
/k>c0;>c/`050;>c/`?o00000oo<c<`2o`0000L0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0H07moO`8000000`1VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c03<c
<`0000001@0I6AT00`00003o0000o`00000Qo`0000@0oooo00?o00000?ooo`3oool0<@3oool00ol0
0000oooo0?ooo`0T0?ooo`03o`00003oool0oooo06L0oooo00?o00000?ooool000002P3oool000T0
oooo00Co00000?ooo`3oool0oooo8?l000000`0000006ATI01TI6@0501TI6@030000000c<c<0<c<c
0080<c<c00<0000004a<C01<C4`00P1<C4`200000080IVIV00<0000007moO`1oOgl00P1oOgl20000
000409VIV@0000000000000000L0/k>c0ol000070;>c/`8000001@2IVIT00`000000Ogmo07moO`0G
07moO`800000101VIVH00`000000C4a<04a<C00204a<C0050000000c<c<0<c<c03<c<`0000001@0I
6AT00`00003o0000o`00000Ro`0000@0oooo00?o00000?ooo`3oool0<P3oool00ol00000oooo0?oo
o`0S0?ooo`03o`00003oool0oooo06P0oooo0_l0000:0?ooo`002@3oool01?l00000oooo0?ooo`3o
oolQo`0000030000000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<
C00304a<C0030000001VIVH0IVIV00800000101oOgl010000000VIVI09VIV@2IVIT3000000d0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0F07moO`8000001@1VIVH010000000C4a<
04a<C01<C4`2000000<0<c<c00<0000001TI6@0I6AT00`0I6ATVo`0000@0oooo00?o00000?ooo`3o
ool0<`3oool2o`0002<0oooo00?o00000?ooo`3oool0I`3oool3o`0000X0oooo00090?ooo`04o`00
003oool0oooo0?ooob;o00000P00000601TI6@03o`0000000000<c<c0080<c<c00<00000o`000000
00000P1<C4`00ol0000000000000000206IVIP8000000`1oOgl3000000<0VIVI00<00000o`000000
00002P00000609VIV@03o`00001oOgl0Ogmo0100Ogmo1P0000000ol00000IVIV06IVIP0206IVIP80
000000?o000004a<C01<C4`00P00000403<c<`030000000I6AT06ATI00@06ATI00<00000o`000?l0
00008ol000040?ooo`03o`00003oool0oooo03D0oooo00?o00000?ooo`3oool0803oool00ol00000
oooo0?ooo`1S0?ooo`Co00003@3oool000T0oooo00Co00000?ooo`3oool0oooo9?l000000`000000
6ATI01TI6@0501TI6@030000000c<c<0<c<c00<0<c<c0P00000304a<C08000000P1VIVH3000000<0
Ogmo1000000@09VIV@800000201oOgl;000000T0IVIV0P00000404a<C0030000000c<c<0<c<c00<0
<c<c00<0000001TI6@0I6AT0100I6AT00`00003o0000o`00000To`0000@0oooo00?o00000?ooo`3o
ool0=P3oool00ol00000oooo0?ooo`0O0?ooo`03o`00003oool0oooo0600oooo0ol0000A0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooolUo`0000030000000I6AT06ATI00D06ATI0P00000503<c<`03
0000001<C4`0C4a<0080C4a<0P00000306IVIP<00000101oOgl3000000X0VIVI0`00000707moO`<0
00004P1VIVH2000000D0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0401TI6@03
00000?l0003o000002Go0000103oool00ol00000oooo0?ooo`0g0?ooo`03o`00003oool0oooo01h0
oooo00?o00000?ooo`3oool0G03oool4o`0001@0oooo00090?ooo`04o`00003oool0oooo0?ooobKo
000000<0000001TI6@0I6AT01P0I6AT00`000000<c<c03<c<`0303<c<`03o`0000000000C4a<00<0
C4a<0`00000306IVIP0400000?l000000000000000<0Ogmo2P00000607moO`@000004@1VIVH40000
00H0C4a<00?o000003<c<`0c<c<00P0c<c<2000000H06ATI00<00000o`000?l000009_l000040?oo
o`03o`00003oool0oooo03P0oooo0_l0000N0?ooo`03o`00003oool0oooo05P0oooo1?l0000H0?oo
o`002@3oool01?l00000oooo0?ooo`3ooolWo`0000030000000I6AT06ATI00H06ATI00?o00000000
000c<c<0100c<c<2000000D0C4a<0P00000506IVIP<000003@1oOgl300000180IVIV0`00000804a<
C0800000100c<c<00`0000006ATI01TI6@0601TI6@0300000?l0003o000002Ko0000103oool00ol0
0000oooo0?ooo`0j0?ooo`03o`00003oool0oooo01/0oooo00?o00000?ooo`3oool0E03oool4o`00
01`0oooo00090?ooo`04o`00003oool0oooo0?ooobSo000000<0000001TI6@0I6AT01`0I6AT20000
00D0<c<c0P00000504a<C08000001P1VIVH=000000h0IVIV1`00000904a<C08000001@0c<c<00`00
00006ATI01TI6@0601TI6@0300000?l0003o000002Oo0000103oool00ol00000oooo0?ooo`0k0?oo
o`03o`00003oool0oooo01X0oooo00?o00000?ooo`3oool0D@3oool3o`000200oooo00090?ooo`04
o`00003oool0oooo0?ooobWo000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c
<`8000001@1<C4`4000001H0IVIV1`00000>04a<C08000001P0c<c<00ol000006ATI01TI6@0601TI
6@0300000?l0003o000002So0000103oool00ol00000oooo0?ooo`0l0?ooo`03o`00003oool0oooo
01T0oooo00?o00000?ooo`3oool0C@3oool4o`0002<0oooo00090?ooo`04o`00003oool0oooo0?oo
ob_o00000P00000801TI6@03o`0000000000<c<c00D0<c<c00@00000o`000000000000001@1<C4`0
0ol00000000000000006000000H0IVIV1P0000000ol00000C4a<04a<C00?04a<C0<0000000?o0000
03<c<`0c<c<0100c<c<2000000L06ATI00<00000o`000?l00000:_l000040?ooo`03o`00003oool0
oooo03d0oooo0_l0000I0?ooo`03o`00003oool0oooo04T0oooo1?l0000W0?ooo`002@3oool01?l0
0000oooo0?ooo`3oool]o`0000800000200I6AT3000000L0<c<c1000000:04a<C0H000005@1<C4`3
000000P0<c<c0P00000801TI6@0300000?l0003o000002_o0000103oool00ol00000oooo0?ooo`0o
0?ooo`03o`00003oool0oooo01H0oooo00?o00000?ooo`3oool0A@3oool4o`0002/0oooo00090?oo
o`04o`00003oool0oooo0?oooboo000000<0000001TI6@0I6AT0200I6AT4000000L0<c<c0`00000K
04a<C0L000002@0c<c<2000000T06ATI00<00000o`000?l00000;?l000040?ooo`03o`00003oool0
oooo0400oooo00?o00000?ooo`3oool0503oool00ol00000oooo0?ooo`130?ooo`?o0000;`3oool0
00T0oooo00Co00000?ooo`3oool0oooo<?l000001000003o000000000000000:01TI6@<000001`0c
<c<E00000003o`0000000000000000<000003P0c<c<2000000T06ATI0P00000_o`0000@0oooo00?o
00000?ooo`3oool0@@3oool00ol00000oooo0?ooo`0C0?ooo`03o`00003oool0oooo03l0oooo1?l0
000b0?ooo`002@3oool01?l00000oooo0?ooo`3oooldo`00008000002`0I6AT4000002/0<c<c00<0
000001TI6@0I6AT0200I6AT00`00003o0000o`00000_o`0000@0oooo00?o00000?ooo`3oool0@P3o
ool2o`0001<0oooo00?o00000?ooo`3oool0>`3oool4o`0003H0oooo00090?ooo`04o`00003oool0
oooo0?ooocKo000000<0000001TI6@0I6AT0300I6AT3000002D0<c<c0`00000:01TI6@0300000?l0
003o0000033o0000103oool00ol00000oooo0?ooo`140?ooo`03o`00003oool0oooo0100oooo00?o
00000?ooo`3oool0=`3oool4o`0003X0oooo00090?ooo`04o`00003oool0oooo0?ooocOo00000`00
000>01TI6@L000006@0c<c<00ol00000000000000002000000`06ATI=?l000040?ooo`03o`00003o
ool0oooo04D0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0c0?ooo`Co0000?P3o
ool000T0oooo00Co00000?ooo`3oool0oooo>_l000001000003o000000000000000A01TI6@030000
0?l00000000001H000003`0I6AT2000003Co0000103oool00ol00000oooo0?ooo`160?ooo`03o`00
003oool0oooo00h0oooo00?o00000?ooo`3oool0<03oool3o`000480oooo00090?ooo`04o`00003o
ool0oooo0?ooocko00000`00000d01TI6@800000=_l000040?ooo`03o`00003oool0oooo04L0oooo
00?o00000?ooo`3oool03@3oool00ol00000oooo0?ooo`0/0?ooo`Co0000A@3oool000T0oooo00Co
00000?ooo`3oool0oooo@Ol00004000002h06ATI0P00000ho`0000@0oooo00?o00000?ooo`3oool0
B03oool2o`0000d0oooo00?o00000?ooo`3oool0:03oool4o`0004T0oooo00090?ooo`04o`00003o
ool0oooo0?ooodGo000000<00000o`00000000001000000U01TI6@800000>_l000040?ooo`03o`00
003oool0oooo04X0oooo00?o00000?ooo`3oool02P3oool00ol00000oooo0?ooo`0T0?ooo`Co0000
C@3oool000T0oooo00Co00000?ooo`3oool0ooooC?l00003000001h06ATI1000000lo`0000@0oooo
00?o00000?ooo`3oool0B`3oool00ol00000oooo0?ooo`090?ooo`03o`00003oool0oooo0240oooo
0ol0001A0?ooo`002@3oool01?l00000oooo0?ooo`3ooom?o`0000X000004@0I6AT30000043o0000
103oool00ol00000oooo0?ooo`1<0?ooo`03o`00003oool0oooo00P0oooo00?o00000?ooo`3oool0
7@3oool4o`0005@0oooo00090?ooo`04o`00003oool0oooo0?oooeWo00004@000013o`0000@0oooo
00?o00000?ooo`3oool0C@3oool2o`0000P0oooo00?o00000?ooo`3oool06@3oool4o`0005P0oooo
00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`1?0?ooo`03o`00
003oool0oooo00D0oooo00?o00000?ooo`3oool05@3oool4o`0005`0oooo00090?ooo`04o`00003o
ool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`1@0?ooo`03o`00003oool0oooo00@0oooo
00?o00000?ooo`3oool04P3oool3o`000600oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000
103oool00ol00000oooo0?ooo`1A0?ooo`03o`00003oool0oooo00<0oooo00?o00000?ooo`3oool0
3P3oool4o`0006<0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo
0?ooo`1B0?ooo`;o00000`3oool00ol00000oooo0?ooo`0:0?ooo`Co0000I`3oool000T0oooo00Co
00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo05@0oooo00Co00000?ooo`3ooooo
0000203oool4o`0006/0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000
oooo0?ooo`1E0?ooo`03o`00003ooooo000000D0oooo0ol0001_0?ooo`002@3oool01?l00000oooo
0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0EP3oool2o`0000030?ooool0003o000000;o
0000LP3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo05L0
oooo0_l0001f0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3o
ool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0<l0
oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`3?0?ooo`00
2@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo
00Co00000?ooo`3oool0oooo[Ol000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00
003oool0oooo0?ooojgo0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo
0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0
oooo[Ol000040?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojgo
0000103oool00ol00000oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0
oooo00?o00000?ooo`3oool0c`3oool000T0oooo00Co00000?ooo`3oool0oooo[Ol000040?ooo`03
o`00003oool0oooo0<l0oooo00090?ooo`04o`00003oool0oooo0?ooojgo0000103oool00ol00000
oooo0?ooo`3?0?ooo`002@3oool01?l00000oooo0?ooo`3ooon]o`0000@0oooo00?o00000?ooo`3o
ool0c`3oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`3?0?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo0<l0oooo00090?ooo`03o`00003oool0
oooo0;80oooo00?o00000?ooo`3oool0c`3oool000T0oooo]_l0003A0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`002@3ooonfo`000140oooo]_l0000:0?ooo`002@3oool00ol00000oooo0?ooo`2b
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0DP3oool200000003o`0000000000000000h0
000000Co00000000000000000000B@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0C`3oool3000001L0
oooo0`0000160?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`180?ooo`L000007@3oool3000004<0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo04D0oooo0`00000W0?ooo`030000003oool0oooo0400oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo04<0oooo0P00000[0?ooo`04o`00000000000000000003h0oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo0440oooo0P00000?0?oooa<000003`3oool2000003`0oooo00?o0000
0?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?oo
o`03o`00003oool0oooo03d0oooo1000000:0?ooo`L000004`3oool4000000d0oooo00<000000?oo
o`3oool0>@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`1<0?oooaT0
okK1C@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03X0oooo0`00000;0?ooo`04
00000?l0000000000?oooaT0okK1103oool01?l00000000000000000000:0?ooo`800000>@3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`190?oooal0okK1BP3oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03T0oooo00<000000?ooo`3oool0203oool40000
00030?ooo`3o]/40okK100L0okK13000000:0?nf`@D0oooo0P00000:0?ooo`030000003oool0oooo
03H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0AP3ooolU0?nf`DL0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0g0?ooo`800000203oool300000080
oooo1@3o]/47000000`0okK11`0000060?nf`@@0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0e0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo04<0oooo
:`3o]/540?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0=@3oool2000000T0oooo
00<000000?ooo`3oool01@3o]/43000001X0okK1100000050?nf`@80oooo0`0000080?ooo`800000
=@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`100?oooc40okK1@@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03<0oooo0P0000090?ooo`8000001@3o
]/400`00003o0000000000070?nf`A<000001`3o]/43000000D0okK10P3oool00ol0000000000000
00070?ooo`03o`00003oool0oooo0380oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0?@3ooolg0?nf`Ch0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0a
0?ooo`8000002@3oool2000000D0okK10P0000060?nf`@@000004`3o]/43000000L0okK110000004
0?nf`@80oooo00<000000?ooo`3oool01@3oool200000380oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0>P3ooolk0?nf`Cd0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0_0?ooo`8000002@3oool2000000D0okK10P0000050?nf`@<00000103o]/4;0000
00/0okK1100000070?nf`@8000000`3o]/420?ooo`8000001`3oool00`000000oooo0?ooo`0_0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03T0oooo?@3o]/4l0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0;P3oool00`000000oooo0?ooo`070?ooo`80
00000`3o]/401000003o00000000000000020?nf`@D000000P3o]/45000000/0okK11@0000000ol0
00000000000000070?nf`@@000001@3o]/4200000080okK10`3oool00`000000oooo0?ooo`050?oo
o`03o`00003oool0oooo02h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool0=`3ooom20?nf`CT0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0/0?ooo`03
00000?l00000oooo00P0oooo00<00000o`00003o]/400P3o]/400`000000okK10?nf`@020?nf`@80
00001@3o]/400`00003o00000?nf`@040?nf`@/00000203o]/43000000P0okK10P0000050?nf`@80
00000`3o]/400`3oool000000?ooo`060?ooo`030000003oool0oooo02d0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool0=@3ooom60?nf`CL0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0Z0?ooo`8000002@3oool2000000<0okK10P0000040?nf`@040000
003o]/40okK10?nf`@/000002`3o]/44000000L0okK1100000060?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/400P3o]/42000000H0oooo00<000000?ooo`3oool0;03oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0d0?oooa@0okK13_l00?lV0?nf`CH0oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo
0P0000040?nf`@030000003o]/40okK10080okK10P0000020?nf`@8000000`3o]/400`000000okK1
0?nf`@050?nf`@P000001`3o]/44000000L0okK10`0000040?nf`@<00000103o]/400ol00000okK1
0?nf`@020?nf`@030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0:`3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0c0?oooa<0okK10_l00?l>0?nf`@;o003o9@3o
]/4e0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool09`3oool00`00003o00000?oo
o`070?ooo`800000103o]/42000000<0okK10P0000020?nf`@0500000?l00000okK10?nf`@000000
0_l000000`3o]/400000o`000005000000P0okK100?o00000000000000000`0000050?nf`@04o`00
000000000000000000H0okK1100000030?nf`@03o`000000000000000080okK10P0000030?nf`@03
0?ooo`000000000000D0oooo00?o00000000003oool0:P3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`0b0?oooa80okK10_l00?lB0?nf`@03o`00o`3o]/40okK102<0okK1
=03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02D0oooo0P0000080?ooo`800000
00<0oooo0?nf`@3o]/400P3o]/4010000000okK10?nf`@3o]/4200000080okK10P000000103o]/40
00000000000000030?nf`@040000003o]/40okK10?nf`@co00001P3o]/42000000L0okK10`000007
0?nf`@800000103o]/401@000000okK10?nf`@3o]/40000000<0okK10P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0<03ooolC0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40903o]/4b
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0903oool00`000000oooo0?ooo`07
0?ooo`030000003oool0okK100@0okK100D000000?nf`@3o]/40okK1000000020?nf`@8000000P3o
]/4010000000okK10?nf`@3o]/43000000040?nf`Ol0003o0000o`0000`0okK10ol000050?nf`@<0
00001`3o]/43000000H0okK10P0000030?nf`@8000000P3o]/42000000<0okK100<0oooo0000003o
ool0103oool00`000000oooo0?ooo`0X0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02l0oooo4P3o]/42o`00oaL0okK100?o003o0?nf`@3o]/40903o]/4a0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0okK100<0okK100?o00000000003o]/400P3o]/4010000000okK10?nf`@0000030?nf`@03
0000003o]/40okK1008000000P3o]/42o`0000<0okK12Ol000060?nf`@03o`00003o]/40okK100D0
okK100Co000000000000000000001P3o]/4400000006o`00003o]/40okK10?nf`Ol0000000000`3o
]/401@000000okK10?nf`@3o]/7o000000<0okK100<0ooooo`00003oool0103oool00ol00000oooo
0?ooo`0W0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02h0oooo4P3o
]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK102D0okK1<03oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo0280oooo00?o00000?ooo`3oool01`3oool00`00003o00000?nf
`@030?nf`@030000003o]/40okK10080okK100D00000o`00003o]/40okK1o`0000020?nf`@040000
0?l00000okK1000000<0okK10_l00000103o]/7o0000o`000?l000090?nf`@03o`00003o]/40okK1
00@0okK100?o00000?nf`@3o]/40203o]/43000000L0okK10`0000030?nf`@050000003o]/40okK1
0?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40000000H0oooo00<000000?ooo`3oool09P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0]0?oooa<0okK100?o003o
0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@0V0?nf`Bl0oooo00?o00000?ooo`3oool03`3oool0
0ol00000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool0okK10?nf`@02
0?nf`@040000003o]/40okK10?nf`@8000000`3o]/4010000000okK10000000000020?nf`@030000
003o]/40okK100;o00000P3o]/400ol00000okK10?nf`@0;0?nf`@03o`00003o]/40okK100@0okK1
00?o00000?nf`@3o]/402P3o]/47000000<0okK10`0000000`3o]/400000000000020?nf`@800000
0P3o]/401@000000okK10?nf`@3o]/40000000D0oooo00<000000?ooo`3oool09P3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0/0?oooa<0okK100?o003o0?nf`@3o]/40
6@3o]/400ol00?l0okK10?nf`@0V0?nf`Bh0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o]/401@000000okK1
0?nf`@3o]/40000000@0okK100<000000?nf`@0000000P3o]/42000000030?nf`Ol0003o00000080
okK10_l000040?nf`@Go00001P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK10100
okK10`0000030?nf`@030000003o]/40okK1008000000P3o]/4010000000okK10?nf`@0000030?nf
`@030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`0[0?oooa<0okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0
okK10?nf`@0@0?nf`@Co003o4`3o]/4]0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0803oool00`000000oooo0?ooo`060?ooo`03o`00003oool0okK100<0okK100Go00000?nf`@3o
]/40okK1o`0000030?nf`@04o`0000000000okK1o`000080okK100@000000?nf`@3o]/7o00000P3o
]/42o`0000<0okK10ol000050?nf`@?o0000103o]/42o`0000D0okK100?o00000?nf`@3o]/404P3o
]/401?l00000okK10?nf`@3o]/4200000080okK100@000000?nf`@3o]/4000000P3o]/401_l00000
okK10?nf`@3o]/7o0000000000@0oooo0P00000U0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo02X0oooo4`3o]/400ol00?l0okK10?nf`@0K0?nf`@03o`00o`3o]/40okK1
00h0okK10_l00?l40?nf`@Go003o3P3o]/4]0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool07`3oool00ol00000oooo0?ooo`060?ooo`030000003oool0okK100<0okK100D000000?nf
`@3o]/40okK1000000030?nf`@070000003o]/40okK10?nf`@000000okK1000000020?nf`@04o`00
003o]/40okK1o`0000@0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@030?nf`@03
o`00003o]/40okK100<0okK100?o00000?nf`@3o]/40203o]/47o`0000@0okK10`0000020?nf`@04
0000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/400`3oool000000?ooo`05
0?ooo`030000003oool0oooo0280oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0:P3ooolB0?nf`@03o`00o`3o]/40okK100X0okK10`00000?0?nf`@03o`00o`3o]/40okK1
00`0okK10_l00?l;0?nf`@?o003o303o]/4/0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0okK100D000000?nf
`@3o]/40okK1000000030?nf`@070000003o]/40okK10?nf`@000000okK1000000030?nf`@04o`00
003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/402@3o]/400ol00000okK10?nf`@020?nf`@03
o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@040?nf`@?o
0000103o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100D00000
0?nf`@3o]/40oooo000000050?ooo`030000003oool0oooo0280oooo00?o00000?ooo`3oool0203o
ool000T0oooo00?o00000?ooo`3oool0:@3ooolC0?nf`@03o`00o`3o]/40okK100T0okK11@00000>
0?nf`@03o`00o`3o]/40okK100`0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0:
0?nf`B/0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0N0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3o]/401@000000okK10?nf`@3o]/40000000<0okK100D0
00000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1o`000080okK100Go00000?nf`@3o
]/40okK1o`00000=0?nf`@05o`00003o]/40okK10?nf`Ol000001@3o]/400ol00000okK10?nf`@08
0?nf`@03o`00003o]/40okK100P0okK10ol000020?nf`@040000003o]/40okK1o`000080okK100Co
00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000060?ooo`030000003oool0oooo0240
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0:03ooolC0?nf`@03o`00
o`3o]/40okK100X0okK11@00000=0?nf`@03o`00o`3o]/40okK100`0okK100?o003o0?nf`@3o]/40
3`3o]/400ol00?l0okK10?nf`@0:0?nf`BX0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00?o00000?ooo`3oool00P3o]/42000000<0okK1
00Ko00000?nf`@3o]/40okK100000?l000020?nf`@04o`00003o]/40okK100000080okK100Co0000
0?nf`@3o]/7o00000`3o]/400ol00000okK10?nf`@0;0?nf`@;o00000`3o]/400ol00000okK10?nf
`@020?nf`@;o00002@3o]/400ol00000okK10?nf`@0<0?nf`@03o`00003o]/40okK10080000000D0
okK10000003o]/40okK1000000020?nf`@040000003o]/40okK1o`000080okK100?o00000000003o
ool00`3oool00`000000oooo0?ooo`0Q0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02L0oooo4`3o]/400ol00?l0okK10?nf`@0;0?nf`@D000003@3o]/400ol00?l0okK1
0?nf`@0;0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/402P3o]/4Y0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0
okK100D000000?nf`@3o]/40okK1000000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o0000
0?nf`@3o]/402P3o]/400ol00000okK10?nf`@020?nf`@04o`00003o]/40okK10?nf`@;o00002`3o
]/400ol00000okK10?nf`@050?nf`@Oo000000<0okK1o`000?l000000P3o]/400`000000okK10000
00020?nf`@030000003o]/40000000<0okK100@000000?nf`@3o]/4000001@3oool00`000000oooo
0?ooo`0P0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02H0oooo503o
]/400ol00?l0okK10?nf`@0<0?nf`@<000003P3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o
]/40okK10180okK100?o003o0?nf`@3o]/402@3o]/4Y0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080okK100<0
00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40
okK1000000020?nf`@04o`00003o]/40okK1o`0000<0okK100?o00000?nf`@3o]/402P3o]/400ol0
0000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf`Ol000003@3o]/400ol00000okK10?nf`@03
0?nf`@;o00001`3o]/400ol00000okK10?nf`@02o`0000030?nf`@000000okK10080000000@0okK1
0000003o]/4000000P3o]/401@000000okK10?nf`@3oool0000000D0oooo00?o00000?ooo`3oool0
7`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0V0?oooa@0okK100?o
003o0?nf`@3o]/40703o]/400ol00?l0okK10?nf`@0<0?nf`@03o`00o`3o]/40okK10180okK100?o
003o0?nf`@3o]/402P3o]/4X0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`060000003oool0oooo0?ooo`3o]/400000103o]/401Ol00000
okK10?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK1000000030?nf`@04o`00003o]/40
okK1o`0000<0okK10_l000090?nf`@;o00000`3o]/42o`0000<0okK100?o00000?nf`@3o]/40303o
]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK100P0okK10_l000020?nf`@03o`00003o
]/4000000080okK100D000000?nf`@000000okK1000000020?nf`@050000003o]/40okK10?ooo`00
00001@3oool00`000000oooo0?ooo`0N0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo02D0oooo5@3o]/400ol00?l0okK10?nf`@0K0?nf`@03o`00o`3o]/40okK100d0okK1
00?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0:0?nf`BL0oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3o]/401@000000okK10?nf`@3o]/40000000@0okK100D000000?nf`@3o]/40okK1000000030?nf
`@05o`00003o]/40okK10?nf`Ol000000P3o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40
okK100<0okK10ol000030?nf`@;o00000`3o]/42o`0000D0okK11@0000050?nf`@03o`00003o]/40
okK10080okK100?o00000?nf`@3o]/400`3o]/44o`0000<0okK100Go00000?nf`Ol00000okK10000
00020?nf`@030000003o]/4000000080okK100<000000?nf`@0000000`3o]/400`000000oooo0?oo
o`030?ooo`030000003oool0oooo01h0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0903ooolF0?nf`@03o`00o`3o]/40okK101X0okK100?o003o0?nf`@3o]/403P3o]/40
0ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100T0okK19`3oool00ol00000oooo0?ooo`0?
0?ooo`03o`00003oool0oooo01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?nf`@050000003o]/40okK10?nf`@000000103o]/401@000000okK10?nf`@3o]/40000000@0okK1
00D000000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK100<0okK11Ol000040?nf`@;o
0000103o]/401?l00000okK10?nf`@3o]/44000000D0okK10P0000030?nf`@03o`00003o]/40okK1
0080okK100Co00000?nf`@3o]/40okK10_l000040?nf`@09o`00003o]/40okK10?nf`Ol00000okK1
o`00003o]/4000000080okK100<000000?nf`@0000000P3o]/400`000000okK1000000020?nf`@03
0?ooo`000000oooo00@0oooo00<000000?ooo`3oool07@3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`0T0?oooaH0okK100?o003o0?nf`@3o]/406@3o]/400ol00?l0okK1
0?nf`@0?0?nf`@03o`00o`3o]/40okK101D0okK100?o003o0?nf`@3o]/402@3o]/4V0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080okK100@000000?nf`@3o]/400000103o]/400`000000okK10?nf`@020?nf`@05
0000003o]/40okK10?nf`@000000103o]/401Ol00000okK10?nf`@3o]/7o000000d0okK100?o0000
0?nf`@3o]/400P3o]/42o`000080okK100?o00000000003o]/402P3o]/401@000000okK10?nf`@3o
]/7o000000<0okK100Go00000?nf`@3o]/40okK1o`0000060?nf`@09o`00003o]/40okK10?nf`Ol0
0000okK1o`00003o]/4000000080okK100Go00000000003o]/40okK1000000020?nf`@05o`00003o
]/40okK10?ooool00000103oool00`000000oooo0?ooo`0M0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo02<0oooo603o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o
]/40okK10100okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@080?nf`BH0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3o]/401@000000okK10?nf`@3o]/7o000000<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/40
0P3o]/44o`0000H0okK10ol000000`3o]/7o0000o`000002o`000080okK10P0000020?nf`@T00000
0`3o]/4010000000okK10?nf`Ol000030?nf`@04o`00003o]/40okK1o`0000P0okK100Co00000?nf
`@3o]/7o00000P3o]/401_l00000okK10000003o]/4000000?nf`@80000000P0okK10000003o]/40
okK10000003o]/40oooo000000D0oooo00?o00000?ooo`3oool0703oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`0S0?oooaT0okK100?o003o0?nf`@3o]/405@3o]/400ol0
0?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/402@3o]/4U0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool06@3oool00`000000oooo0?ooo`040?oo
o`050000003oool0oooo0?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40000000@0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100D0okK11_l0
00030?nf`@04o`00003o]/40okK10?nf`@<0000000@0okK100000000000000002@3o]/4200000080
okK100?o00000?nf`Ol000000`3o]/401?l00000okK10?nf`Ol000090?nf`@0:o`00003o]/40okK1
o`00003o]/7o00000?nf`@000000okK1000000<0okK10P0000020?nf`@040000003o]/40okK10000
00H0oooo00<000000?ooo`3oool06`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0R0?oooaX0okK100?o003o0?nf`@3o]/404`3o]/42o`00oaD0okK100?o003o0?nf`@3o
]/402@3o]/43000000X0okK100?o003o0?nf`@3o]/402@3o]/4T0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?nf
`@0000000`3o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@050?nf`@03o`00003o]/40okK100X0okK10ol00000103o]/40000000000000
00030?nf`@030000003o]/40okK100`0okK100H000000?nf`@3o]/4000000?nf`Ol000030?nf`@04
o`00003o]/40okK1o`0000T0okK100[o00000?nf`@3o]/7o00000?nf`Ol00000okK10000003o]/40
00000P3o]/400`000000okK1000000020?nf`@040000003o]/40okK1000000D0oooo00<000000?oo
o`3oool06`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Q0?oooa`0
okK100?o003o0?nf`@3o]/40403o]/42o`00oaL0okK100?o003o0?nf`@3o]/40203o]/45000000T0
okK100?o003o0?nf`@3o]/402@3o]/4T0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0603oool00`000000oooo0?ooo`030?ooo`05o`00003oool0oooo0?nf`@0000000`3o]/401@00
0000okK10?nf`@3o]/40000000@0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@06
0?nf`@co00000`3o]/401?l00000okK10?nf`@3o]/4200000004o`00003o]/40okK10?nf`@L00000
00?o00000000000000000`3o]/401P000000okK10?nf`@000000okK1o`000080okK100Co00000?nf
`@3o]/7o00002P3o]/403?l00000okK10?nf`Ol00000okK1o`00003o]/4000000?nf`@000000okK1
00000080okK100Oo00000?nf`@3o]/4000000?nf`@3oool0000000D0oooo00<000000?ooo`3oool0
6P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0Q0?oooad0okK11_l0
0?l80?nf`@Co003o6@3o]/400ol00?l0okK10?nf`@080?nf`@D000002P3o]/400ol00?l0okK10?nf
`@090?nf`B<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0H0?ooo`03o`00003o
ool0oooo00<0oooo00D000000?ooo`3oool0okK1000000030?nf`@04o`00003o]/40okK1o`0000D0
okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0A0?nf`@<0000000@0okK100000000
00000000103o]/42000000X0okK100T000000?nf`@3o]/40okK1o`00003o]/4000000?nf`Ol00000
0P3o]/401?l00000okK10?nf`Ol0000:0?nf`@0<o`00003o]/40okK1o`00003o]/7o00000?nf`@00
0000okK10000003o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003oool0oooo
00<0oooo00<000000?ooo`3oool06P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0P0?ooob@0okK12?l00?lM0?nf`@03o`00o`3o]/40okK100P0okK11@00000:0?nf`@03
o`00o`3o]/40okK100T0okK18`3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01P0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?nf`@3o]/40000000<0okK100@000000?nf
`@3o]/400000103o]/400`000000okK10?nf`@070?nf`@<000001P3o]/4>000000<0okK110000003
0?nf`@D000001@3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/7o00000080okK100?o
00000?nf`Ol000002P3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100L000000?nf`@00
0000okK10000003o]/40000000<0okK100@000000?nf`@3oool00000103oool00`000000oooo0?oo
o`0J0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0200ooooBP3o]/40
0ol00?l0okK10?nf`@080?nf`@<000002`3o]/400ol00?l0okK10?nf`@0:0?nf`B80oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0okK1000000030?nf`@040000003o]/40okK1000000@0okK100<000000?nf`@3o]/40
2`3o]/46000000P0okK100?o00000000003o]/40103o]/42000000@0okK10`0000050?nf`@<00000
0`3o]/4020000000okK10?nf`@000000okK10000003o]/7o00000P3o]/401?l00000okK10?nf`Ol0
000:0?nf`@03o`00003o]/7o00000080okK100?o00000?nf`@0000000P3o]/401Ol0000000000?nf
`@3o]/4000000080okK100@000000?nf`@3o]/4000001@3oool00`000000oooo0?ooo`0I0?ooo`03
o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01l0ooooB`3o]/400ol00?l0okK1
0?nf`@0G0?nf`@03o`00o`3o]/40okK100X0okK18@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?nf`@3o]/4000000080
okK100D000000?nf`@3o]/40okK1000000030?nf`@03o`00003o]/40okK101D0okK11@0000020?nf
`@@0000000?o00000?nf`@3o]/400P0000000ol0000000000?nf`@0:0?nf`@05o`00003o]/40okK1
0?nf`Ol000000P3o]/4010000000okK1o`00003o]/42o`0000050?nf`Ol00000okK10?nf`Ol00000
2@3o]/401_l00000okK10?nf`Ol00000okK1o`000080okK100L000000?nf`@000000okK10000003o
]/4000000080okK100D000000?nf`@3o]/40okK1000000040?ooo`030000003oool0oooo01T0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool07P3ooom=0?nf`@03o`00o`3o
]/40okK101H0okK100?o003o0?nf`@3o]/402P3o]/4Q0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`050000003o]/40okK10?nf`@000000
0P3o]/401@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/404`3o]/43000000@0
okK10`0000040?nf`@<000001`3o]/45000000@0okK10P0000020?nf`@030000003o]/4000000080
okK100D000000?nf`Ol00000okK1o`0000030?nf`@03o`00003o]/40okK100H0okK100Ko00000?nf
`@3o]/7o00000?nf`Ol000020?nf`@070000003o]/4000000?nf`@000000okK1000000020?nf`@05
0000003o]/40okK10?nf`@000000103oool00`000000oooo0?ooo`0I0?ooo`03o`00003oool0oooo
00P0oooo00090?ooo`03o`00003oool0oooo01h0ooooC@3o]/400ol00?l0okK10?nf`@0F0?nf`@03
o`00o`3o]/40okK100/0okK1803oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01H0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?nf`@3o]/4000000080okK100D000000?nf
`@3o]/40okK1000000020?nf`@030000003o]/40okK10100okK1100000030?nf`@@000001P3o]/40
0`000000okK10?nf`@050?nf`@<000001@3o]/4400000080okK100H000000?nf`@3o]/4000000?nf
`@0000020?nf`@040000003o]/7o00000?nf`@;o00000P3o]/42o`0000D0okK100?o00000?nf`@3o
]/400P3o]/400ol00000okK1o`0000020?nf`@070000003o]/4000000?nf`@000000okK100000002
0?nf`@050000003o]/40okK10?nf`@000000103oool00ol00000oooo0?ooo`0H0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01d0ooooC`3o]/400ol00?l0okK10?nf`@0E
0?nf`@03o`00o`3o]/40okK100/0okK1803oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo01H0oooo00<000000?ooo`3oool00`3oool01@000000okK10?nf`@3o]/4000000080okK100@0
00000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@0?0?nf`@800000103o]/43000000H0okK1
100000030?nf`@D00000303o]/401?l00000okK10?nf`Ol000020?nf`@030000003o]/7o00000080
okK100<000000?nf`Ol000000P3o]/401Ol00000okK10?nf`@3o]/7o000000@0okK100?o00000?nf
`@3o]/400P3o]/400ol00000okK1o`0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/40
0`000000okK1000000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0M0?oooa00okK10ol00?lT0?nf
`@L0oooo4P3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100/0okK1803oool00ol0
0000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool01`00
0000okK10?nf`@3o]/4000000?nf`Ol000000`3o]/4010000000okK10?nf`@0000050?nf`@?o0000
2@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100D0okK100<00000o`00003o]/40
103o]/42000000<0okK11`3oool70?nf`@070000003o]/40okK10?nf`@000000okK1000000020?nf
`@050000003o]/4000000?nf`Ol000000`3o]/401?l00000okK10?nf`@3o]/45o`0000@0okK100?o
00000?nf`Ol000000P3o]/401@000000okK10000003o]/4000000080okK100<000000?nf`@000000
0`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool07@3oool=0?nf`@?o003o0`3o]/42o`00oah0okK13`3o
ool>0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/40303o]/4O0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK100<0
okK100Go00000?nf`@3o]/40okK1o`0000070?nf`@030000003o]/40okK10080okK100<000000?nf
`@3o]/400P3o]/44000000<0okK1100000000`3o]/40oooo0?ooo`040?ooo`P0000000<0oooo0?nf
`@3o]/400P3o]/4010000000okK10?nf`@0000020?nf`@070000003o]/40okK10000003o]/400000
0?nf`@02o`000080okK10_l000090?nf`@04o`00003o]/40okK1o`000080okK100D000000?nf`@00
0000okK1000000020?nf`@030000003o]/40000000<0okK100<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0G0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01`0
oooo3@3o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40okK101T0okK14`3oool=0?nf`@;o
003o503o]/400ol00?l0okK10?nf`@0<0?nf`Al0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00D000000?nf`@3o]/40okK1000000020?nf
`@040000003o]/40okK100000080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@03
0?nf`@03o`00003o]/40okK100@0okK100D000000?nf`@3o]/40okK1000000030?nf`@8000001@3o
]/42000000<0okK11@3oool3000000P0oooo00<00000o`00003oool00`3o]/4010000000okK10?nf
`@0000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/401Ol00000okK10?nf`@3o]/7o
000000P0okK100Co00000?nf`@3o]/7o00000P3o]/400`000000okK1000000020?nf`@060000003o
]/40okK10000003o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0
oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0703oool=0?nf`@03o`00
o`3o]/40okK100H0okK100?o003o0?nf`@3o]/405`3o]/4G0?ooo`d0okK100?o003o0?nf`@3o]/40
4@3o]/400ol00?l0okK10?nf`@0<0?nf`Al0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0F0?ooo`030000003oool0oooo0080oooo00Go00000?nf`@3o]/40okK1o`0000020?nf`@03
0000003o]/4000000080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@050?nf`@03
o`00003o]/40okK10080okK100D000000?nf`@3o]/40okK1000000030?nf`@03o`00003o]/40okK1
00<0okK100<00000o`00003o]/400P3o]/430?ooo`0400000?l000000000000000d0oooo0P000000
103oool0okK10?nf`Ol000020?nf`@06o`00003o]/40okK10000003o]/7o00000P3o]/4200000003
0?nf`Ol00000okK10080okK10ol000030?nf`@;o00000`3o]/401_l00000okK10?nf`@000000okK1
00000080okK100H000000?nf`@3o]/4000000?nf`@0000030?nf`@030000003oool0oooo00<0oooo
00<000000?ooo`3oool05P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`0L0?ooo``0okK100?o003o0?nf`@3o]/40203o]/400ol00?l0okK10?nf`@0E0?nf`AX0oooo303o
]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100h0okK17P3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool01@000000okK10?nf
`@3o]/4000000080okK100<000000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000P0
okK100?o00000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK100@000000?nf
`@3o]/40okK10P0000040?nf`@040?ooo`0000000000000001<0oooo00D000000?ooo`3oool0okK1
000000020?nf`@060000003o]/40okK10000003o]/4000000`3o]/4010000000okK1o`000?l00004
0?nf`@?o00001@3o]/401_l00000okK10?nf`@000000okK100000080okK100H000000?nf`@3o]/40
00000?nf`@0000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo``0okK100?o003o0?nf`@3o
]/402P3o]/400ol00?l0okK10?nf`@0C0?nf`A`0oooo303o]/400ol00?l0okK10?nf`@0=0?nf`@03
o`00o`3o]/40okK100l0okK17P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool01@000000okK10?nf`@3o]/4000000080okK100<000000?nf
`@0000000P3o]/401@000000okK10?nf`@3o]/40000000T0okK100Go00000?nf`@3o]/40okK10000
00030?nf`@050000003o]/40okK10?nf`@0000000P3o]/42000000D0okK10P00000G0?ooo`050000
003oool0oooo0?nf`@0000000P3o]/401P000000okK10?nf`Ol00000okK1000000<0okK100@00000
0?nf`@3o]/7o00002P3o]/401Ol00000okK10?nf`@3o]/4000000080okK100<000000?nf`@000000
0P3o]/4010000000okK10?nf`@0000030?nf`@03o`00003oool0oooo00<0oooo00<000000?ooo`3o
ool05@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo`/0okK1
00?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0A0?nf`Ah0oooo303o]/42o`00o``0okK1
00?o003o0?nf`@3o]/40403o]/4N0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
5@3oool00`000000oooo0?ooo`020?ooo`050000003o]/40okK10?nf`@0000000P3o]/400`000000
okK1000000020?nf`@040000003o]/40okK1000000/0okK100Co00000?nf`@3o]/4000000P3o]/40
1@000000okK10?nf`Ol0000000000080okK100<000000?nf`@3o]/400`3o]/400ol0000000000?oo
o`0:0?ooo`0300000?l0003o00000080000000?o00000000000000001`3oool01@000000oooo0?oo
o`3o]/4000000080okK100L000000?nf`@3o]/4000000?nf`@00003o00000080okK100<000000?nf
`@3o]/400ol000060?nf`@;o00000`3o]/401P000000okK10?nf`@000000okK100000080okK100@0
00000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo
00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06`3oool:0?nf`@03o`00o`3o
]/40okK100h0okK100?o003o0?nf`@3o]/403`3o]/4P0?ooo`d0okK10ol00?l70?nf`@?o003o4P3o
]/4N0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool00`000000oooo0?oo
o`020?ooo`050000003o]/40okK10?nf`@0000000P3o]/400`000000okK1000000020?nf`@040000
003o]/40okK1000000/0okK100Co00000?nf`@3o]/4000000P3o]/401?l00000okK10?nf`@000003
0?nf`@03o`00003o]/40okK10080okK100<000000?ooo`3oool0203oool3000000P0oooo0P000006
0?ooo`040000003oool0oooo000000<0okK100<000000?nf`@0000000`3o]/4010000000okK10?nf
`@0000040?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/400`3o]/401P000000okK1
0?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool06`3oool:0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/403P3o]/4P0?oo
oa00okK11ol00?lE0?nf`Ah0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?oo
o`030000003oool0oooo0080oooo00D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40
00000080okK100<000000?nf`@000000303o]/401?l00000okK10?nf`@0000020?nf`@040000003o
]/40okK1000000<0okK100H000000?nf`@3o]/40okK10000003o]/470?ooo`<000003@3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0okK1000000<0okK100<000000?nf`@0000000`3o]/40
10000000okK10?nf`@0000040?nf`@Co00001P3o]/401P000000okK10?nf`@000000okK100000080
okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo
01D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06`3oool90?nf`@03
o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/40303o]/4S0?ooob/0okK17P3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool010000000
okK10?nf`@0000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/400000103o]/44
o`0000@0okK100Co00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000
003o]/40okK10080okK100<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0okK1000000020?nf`@040000003o]/40okK1o`00
00<0okK100@000000?nf`@3o]/400000303o]/401@000000okK10?nf`@3o]/4000000080okK100@0
00000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3oool0000000D0oooo00<000000?ooo`3o
ool0503oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo`T0okK1
00?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0:0?nf`BD0oooo:`3o]/4M0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`040000
003o]/40okK100000080okK100<000000?nf`@0000000P3o]/400`000000okK1000000040?nf`@03
o`00003o]/40okK10080okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@040000003o]/40okK1
00000080okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0140oooo00?o00000?ooo`3oool00`3oool01@000000oooo0?ooo`3o]/4000000080okK1
00@000000?nf`@3o]/4000000P3o]/401_l00000okK10?nf`@3o]/7o0000000000X0okK100D00000
0?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40
okK1000000050?ooo`030000003oool0oooo01@0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool06P3oool:0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/40
2P3o]/4U0?ooob/0okK17@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo
00<000000?ooo`3oool00P3oool010000000okK10?nf`@0000020?nf`@030000003o]/4000000080
okK100<000000?nf`@000000103o]/400ol00000okK10?nf`@020?nf`@05o`00003o]/40okK10?nf
`Ol000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000<0okK100<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000@0
okK100<000000?nf`@3o]/401`3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf
`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000D0oooo00<000000?ooo`3oool0503o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0J0?ooo`X0okK100?o003o
0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@090?nf`BL0oooo:P3o]/4M0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`040000003o]/40
okK100000080okK100D000000?nf`@000000okK1000000020?nf`@050000003o]/40okK10?nf`Ol0
00001P3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100D000000?nf`@000000okK100000002
0?nf`@050000003o]/40okK10?nf`@0000001P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3o]/401?l00000okK10?nf`Ol000020?nf`@040000
003o]/40okK1000000@0okK10P0000060?nf`@050000003o]/40okK10?nf`@0000000`3o]/401000
0000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000001@3oool00`000000oooo0?oo
o`0D0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01X0oooo2P3o]/40
0ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK100P0okK19`3ooolZ0?nf`Ad0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@00000
0?nf`@3o]/4000000P3o]/401@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/7o
0000203o]/401?l00000okK10?nf`Ol000020?nf`@050000003o]/4000000?nf`@0000000P3o]/40
1@000000okK10?nf`@3o]/40000000D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`03o`0000000000okK10080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK1
0?nf`@00003o000000@0okK100<000000?nf`@3o]/400P0000000ol00000okK10?nf`@020?nf`@05
0000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0J0?ooo`T0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@070?nf
`BT0oooo:@3o]/4M0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`040000003o]/40okK100000080okK100D000000?nf`@000000okK10000
00020?nf`@030000003o]/7o000000T0okK100Co00000?nf`@3o]/7o00000P3o]/401@000000okK1
0000003o]/4000000080okK100D000000?nf`@3o]/40oooo000000050?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0103oool01@000000oooo0?nf`@3o]/4000000080okK100@00000
0?nf`@3o]/4000000`3o]/400`000000okK10?nf`@030?nf`@03o`0000000000okK100H0okK100D0
00000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK100<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo01X0oooo2@3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100L0okK1
:@3ooolY0?nf`Ad0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?ooo`030000
003oool0oooo0080oooo00@000000?nf`@3o]/4000000P3o]/401@000000okK10000003o]/400000
0080okK100<000000?nf`Ol000002@3o]/401?l00000okK10?nf`Ol000020?nf`@050000003o]/40
00000?nf`@0000000P3o]/401@000000okK10?nf`@3oool0000000@0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`030?ooo`050000003oool0okK10?nf`@0000000P3o]/401@000000
okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/40303o]/401@000000okK10?nf`@3o]/40
00000080okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06P3oool9
0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/401P3o]/4Y0?ooobT0okK17@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool0
1P000000okK10?nf`@000000okK100000080okK100D000000?nf`@000000okK1000000020?nf`@03
o`00003o]/40okK100P0okK100[o00000?nf`@3o]/7o00000?nf`@000000okK10000003o]/400000
0P3o]/4010000000okK10?nf`@0000050?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0103oool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@0;0?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf
`@0000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0J0?ooo`T0okK100?o003o0?nf`@3o]/40503o
]/400ol00?l0okK10?nf`@060?nf`BT0oooo:@3o]/4M0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`060000003o]/40okK10000003o]/40
00000P3o]/401@000000okK10000003o]/4000000080okK100?o00000?nf`@3o]/40203o]/402_l0
0000okK10?nf`Ol00000okK10000003o]/4000000?nf`@0000020?nf`@040000003o]/40okK10000
00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`050000003o]/40okK1
0?nf`@0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/402`3o
]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/400`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool06P3oool90?nf`@03o`00o`3o]/40okK100L0okK10`00000:0?nf`@03o`00
o`3o]/40okK100D0okK1:`3ooolX0?nf`Ad0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0E0?ooo`030000003oool0oooo0080oooo00H000000?nf`@3o]/4000000?nf`@0000020?nf
`@050000003o]/4000000?nf`@0000000P3o]/400ol00000okK10?nf`@080?nf`@0:o`00003o]/40
okK1o`00003o]/4000000?nf`@000000okK100000080okK100@000000?nf`@3oool000001@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o]/40okK10000
00020?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@0;0?nf`@050000
003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@030000003oool0oooo
00<0oooo00<000000?ooo`3oool0503oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`0J0?ooo`T0okK100?o003o0?nf`@3o]/401P3o]/45000000T0okK100?o003o0?nf`@3o
]/401@3o]/4[0?ooobP0okK17@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool01P000000okK10?nf`@000000okK100000080okK100D00000
0?nf`@000000okK1000000020?nf`@03o`00003o]/40okK100P0okK100[o00000?nf`@3o]/7o0000
0?nf`@000000okK10000003o]/4000000P3o]/4010000000okK10?ooo`0000050?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?nf`@3o]/4000000080okK1
00D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100/0okK100D000000?nf`@3o
]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK100<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo
01T0oooo2P3o]/400ol00?l0okK10?nf`@060?nf`@D000002@3o]/400ol00?l0okK10?nf`@050?nf
`B/0oooo:03o]/4M0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool01P00
0000oooo0?ooo`3oool0okK100000080okK100X000000?nf`@3o]/4000000?nf`@000000okK10000
003o]/4000000P3o]/400ol00000okK10?nf`@080?nf`@08o`00003o]/40okK1o`00003o]/400000
0?nf`@0000020?nf`@060000003o]/4000000?nf`@3oool00000103oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o]/40okK1000000020?nf`@040000003o
]/40okK1000000<0okK100<000000?nf`@3o]/402`3o]/401@000000okK10?nf`@3o]/4000000080
okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool06@3oool:0?nf`@03
o`00o`3o]/40okK100H0okK11@0000090?nf`@03o`00o`3o]/40okK100D0okK1:`3ooolX0?nf`Ad0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?ooo`060000003oool0oooo0?oo
o`3o]/4000000P3o]/402P000000okK10?nf`@000000okK10000003o]/4000000?nf`@0000020?nf
`@03o`00003o]/40okK100P0okK100So00000?nf`@3o]/7o00000?nf`@000000okK100000080okK1
00H000000?nf`@000000okK10?ooo`0000040?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o
]/400`000000okK10?nf`@0;0?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK1
0?nf`@0000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0I0?ooo`X0okK100?o003o0?nf`@3o]/40
1`3o]/43000000X0okK100?o003o0?nf`@3o]/401@3o]/4[0?ooobP0okK17@3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00H000000?ooo`3oool0oooo0?nf`@0000020?nf
`@0:0000003o]/40okK10000003o]/4000000?nf`@000000okK100000080okK100?o00000?nf`@3o
]/40203o]/402?l00000okK10?nf`Ol00000okK10000003o]/4000000P3o]/401P000000okK10000
003o]/40oooo000000@0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40
okK10?nf`@H00000103o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/40
00000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool06@3oool:0?nf`@03o`00o`3o]/40okK101@0okK1
00?o003o0?nf`@3o]/401@3o]/4[0?ooobP0okK17@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo01D0oooo00H000000?ooo`3oool0oooo0?nf`@0000020?nf`@080000003o]/40okK1
0000003o]/4000000?nf`@0000020?nf`@030000003o]/7o000000X0okK100So00000?nf`@3o]/7o
00000?nf`@000000okK100000080okK100H000000?nf`@000000okK10?ooo`0000050?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o]/4000000080
okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/40000000D0okK100<00000
0?nf`@3o]/400`3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1000000<0okK1
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo01X0oooo2P3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o
]/40okK100D0okK1:`3ooolX0?nf`Ad0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`0E0?ooo`030000003oool0oooo0080oooo00@000000?nf`@3o]/4000000P3o]/401@000000okK1
0000003o]/4000000080okK100<000000?nf`Ol000002P3o]/402?l00000okK10?nf`Ol00000okK1
0000003o]/4000000P3o]/401P000000okK10000003o]/40oooo000000D0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?nf`@0000000P3o]/401?l0
0000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000001`3o]/400`000000okK10?nf
`@020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000
oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool06P3oool:0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40
1@3o]/4[0?ooo`h0okK11ol00?lC0?nf`Ad0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0E0?ooo`030000003oool0oooo0080oooo00@000000?nf`@3o]/4000000P3o]/401@000000
okK10000003o]/4000000080okK100<000000?nf`Ol000002P3o]/402?l00000okK10?nf`Ol00000
okK10000003o]/4000000P3o]/401P000000okK10000003o]/40oooo000000D0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?nf`@000000okK10000
00030?nf`@040000003o]/40okK100000080okK100<00000o`00003o]/401P3o]/400`000000okK1
0?nf`@020?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool06P3oool:0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o
]/401P3o]/4Y0?ooo`d0okK10_l00?l70?nf`@03o`00o`3o]/40okK10100okK17@3oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo01D0oooo00<000000?ooo`3oool00P3oool010000000
okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf`Ol0
00090?nf`@08o`00003o]/40okK1o`00003o]/4000000?nf`@0000020?nf`@030000003o]/400000
0080okK100<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0okK1000000020?nf`@040000003o]/40okK100000080okK100@0
00000?nf`@3o]/4000002P3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o
]/4000000P3o]/401@000000okK10?nf`@3o]/40000000D0oooo00<000000?ooo`3oool0503oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0J0?ooo`X0okK100?o003o0?nf
`@3o]/404`3o]/400ol00?l0okK10?nf`@060?nf`BT0oooo2`3o]/42o`00o`X0okK100?o003o0?nf
`@3o]/403`3o]/4M0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool00`00
0000oooo0?ooo`020?ooo`090000003o]/40okK10?nf`@000000okK10000003o]/4000000080okK1
00<000000?nf`@0000000P3o]/400ol00000okK10?nf`@060?nf`@09o`00003o]/40okK10?nf`Ol0
0000okK10000003o]/4000000080okK100<000000?nf`@0000000P3o]/400`3oool000000?ooo`03
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3o
]/4000000?nf`@0000000`3o]/400`000000okK1000000020?nf`@030000003o]/40okK100T0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK100@000000?nf
`@3o]/4000001@3oool00`000000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo01X0oooo2P3o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK1
00L0okK1:@3oool:0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/403P3o]/4M0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05@3oool00`000000oooo0?ooo`020?oo
o`070000003o]/40okK10?nf`@000000okK1000000020?nf`@050000003o]/4000000?nf`@000000
0`3o]/400ol00000okK10?nf`@050?nf`@09o`00003o]/40okK10?nf`Ol00000okK10000003o]/40
00000080okK100<000000?nf`@0000000P3o]/400`3oool000000?ooo`030?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080okK100H0
00000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o]/40okK100<0okK10ol000050?nf`@04
0000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@00
00050?ooo`030000003oool0oooo01D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool06P3oool:0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/401`3o]/4Y
0?ooo`T0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0=0?nf`Ad0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00L00000
0?nf`@3o]/40okK10000003o]/4000000080okK100D000000?nf`@000000okK1000000030?nf`@03
o`00003o]/40okK100D0okK100Wo00000?nf`@3o]/40okK1o`00003o]/4000000?nf`@0000000P3o
]/400`000000okK1000000020?nf`@030?ooo`000000oooo00<0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o]/400`000000okK1
000000020?nf`@030000003o]/40000000<0okK10ol000030?nf`@03o`00003o]/40okK10080okK1
00@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1
000000D0oooo00<000000?ooo`3oool05@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0J0?ooo`/0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@080?nf
`BL0oooo203o]/42o`00oa40okK100?o003o0?nf`@3o]/40303o]/4M0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool05P3oool01P000000oooo0?ooo`3oool0okK100000080okK100H0
00000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o]/40000000<0okK100?o00000?nf`@3o
]/400`3o]/401Ol00000okK10?nf`@3o]/7o00000080okK100<000000?nf`@0000000P3o]/401000
0000okK10?nf`@0000020?nf`@030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o]/400`000000okK1o`00
00020?nf`@030000003o]/40000000<0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@020?nf`@030000003o]/4000000080okK100<000000?nf`@0000000P3o]/401@000000okK10?nf
`@3o]/40000000@0oooo00<000000?ooo`3oool05P3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`0J0?ooo`/0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf
`@080?nf`BL0oooo203o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100`0okK17@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01H0oooo00H000000?ooo`3oool0oooo
0?nf`@0000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/400`000000okK100000004
0?nf`@03o`00003o]/40okK10080okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@030000003o
]/4000000080okK100@000000?nf`@3o]/4000000P3o]/400`3oool000000?ooo`040?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00`3oool01Ol00000oooo0?ooo`3ooooo00000080
okK100<000000?nf`@0000000P3o]/400`000000okK1000000020?nf`@;o00002@3o]/401ol00000
okK10?nf`@3o]/4000000?nf`@0000000P3o]/400`000000okK1000000020?nf`@05o`00003o]/40
okK10?nf`Ol00000103oool00`000000oooo0?ooo`0F0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo01X0oooo303o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40
okK100X0okK19@3oool80?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/40303o]/4M
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05P3oool01P000000oooo0?ooo`3o
ool0okK100000080okK100H000000?nf`@3o]/4000000?nf`@0000020?nf`@030000003o]/400000
00@0okK10ol000000`3o]/7o00000?nf`@030?nf`@06o`00003o]/40okK10000003o]/4000000P3o
]/4010000000okK10?nf`@0000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000<0okK100D000000?nf`@00
0000okK1000000020?nf`@04o`00003o]/40okK1o`0000X0okK100Oo00000?nf`@3o]/40okK10000
003o]/4000000080okK100<000000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000@0
oooo00<000000?ooo`3oool05P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0K0?ooo`/0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@0<0?nf`B<0oooo
1`3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100/0okK17@3oool00ol00000oooo
0?ooo`0?0?ooo`03o`00003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool02@000000okK1
0?nf`@3o]/4000000?nf`@000000okK1000000020?nf`@040000003o]/40okK1000000H0okK100?o
00000?nf`@3o]/400`3o]/401_l00000okK10?nf`@000000okK100000080okK100@000000?nf`@3o
]/400000103o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`0000020?nf`@050000003o]/4000000?nf`@0000000`3o
]/400`000000okK1o`0000030?nf`@Go00000`3o]/401ol00000okK10?nf`@3o]/4000000?nf`@00
00000P3o]/400`000000okK1000000020?nf`@050000003o]/40okK10?nf`@000000103oool00`00
0000oooo0?ooo`0F0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01/0
oooo2`3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100`0okK18P3oool80?nf`@03
o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/402P3o]/4N0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`050000003o]/40okK10?nf
`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/40000000`0okK100Co00000?nf
`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@000000
1P3oool00`000000oooo0?ooo`0?0?ooo`03o`00003oool0oooo00<0oooo00@000000?ooo`3oool0
00000P3o]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf`Ol000000`3o]/40
0ol00000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100So00000?nf`@3o]/4000000?nf
`@000000okK100000080okK100@000000?nf`@3o]/4000000P3o]/400`000000oooo0?ooo`030?oo
o`030000003oool0oooo01H0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3o
ool06`3oool<0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/403P3o]/4P0?ooo`P0
okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0:0?nf`Ah0oooo00?o00000?ooo`3o
ool03`3oool00ol00000oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00Go00000?nf`@3o
]/40okK1o`0000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/4000002`3o]/40
1?l00000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100H000000?nf`@3o]/40
okK1o`00003o]/460?ooo`03o`0000000000oooo00`0oooo0P0000050?ooo`070000003oool0oooo
0?ooo`000000okK1000000020?nf`@030000003o]/4000000080okK100<000000?nf`Ol000000P3o
]/42o`0000H0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@05o`00003o]/4000000?nf`@00
00000P3o]/401?l00000okK10?nf`@0000020?nf`@030000003oool0oooo00<0oooo00<000000?oo
o`3oool05P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo`d0
okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0@0?nf`Ah0oooo2@3o]/400ol00?l0
okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100X0okK17P3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool01@000000okK10?nf`@3o]/400000
0080okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@00000;0?nf`@04o`00003o]/40
okK100000080okK100@000000?nf`@3o]/4000000`3o]/401P000000okK10?nf`@3o]/4000000?nf
`@L0oooo0`0000090?ooo`030000003oool0oooo00D0oooo00L000000?ooo`3oool0okK10000003o
]/4000000080okK100D000000?nf`@000000okK1000000020?nf`@04o`00003o]/40okK1o`0000L0
okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/40
10000000okK10?nf`@0000020?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0K0?ooo`h0okK100?o003o
0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@0B0?nf`A`0oooo2@3o]/400ol00?l0okK10?nf`@0E
0?nf`@03o`00o`3o]/40okK100X0okK17P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0
oooo01L0oooo00H000000?ooo`3oool0oooo0?nf`@0000030?nf`@030000003o]/4000000080okK1
00@000000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@080?nf`@05o`00003o]/40okK10?nf
`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@060000003o]/40okK10?nf`@000000okK1
2@3oool400000080oooo0`0000070?ooo`070000003oool0oooo0?nf`@000000okK1o`0000020?nf
`@050000003o]/4000000?nf`@0000000P3o]/401?l00000okK10?nf`Ol000090?nf`@04o`00003o
]/40okK1o`000080okK10P0000020?nf`@060000003o]/40okK10000003o]/4000000P3o]/400`00
0000okK10?ooo`030?ooo`030000003oool0oooo01L0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0703oool>0?nf`@03o`00o`3o]/40okK100L0okK100?o003o0?nf`@3o
]/40503o]/4I0?ooo`X0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0:0?nf`Ah0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0G0?ooo`030000003oool0oooo0080
oooo00D000000?nf`@3o]/40okK1000000020?nf`@03o`00003o]/4000000080okK100@000000?nf
`@3o]/4000002P3o]/401Ol00000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/400000
103o]/401`000000okK10?nf`@3o]/400000o`00000000002`3oool2000000T0oooo00D000000?oo
o`3o]/40okK1000000020?nf`@070000003o]/4000000?nf`@000000okK1o`0000020?nf`@04o`00
003o]/40okK1o`0000/0okK100Oo00000?nf`Ol00000okK10000003o]/4000000080okK100<00000
0?nf`@0000000P3o]/401@000000okK10?nf`@000000okK100@0oooo00?o00000?ooo`3oool05`3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0L0?ooo`l0okK10ol00?l5
0?nf`@03o`00o`3o]/40okK101L0okK15@3oool;0?nf`@03o`00o`3o]/40okK101L0okK100?o003o
0?nf`@3o]/402@3o]/4O0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool05`3oool0
0`000000oooo0?ooo`020?ooo`050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10000
00020?nf`@050000003o]/40okK10?nf`@0000002@3o]/401Ol00000okK10?nf`@3o]/4000000080
okK100D000000?nf`@3o]/40okK1000000040?nf`@03o`0000000000okK100<0okK100<000000?oo
o`3oool04`3oool01@000000okK10?nf`@3o]/4000000080okK100L000000?nf`@000000okK1o`00
003o]/4000000080okK100?o00000?nf`Ol000001@3o]/42o`0000D0okK100Oo00000?nf`Ol00000
okK10000003o]/4000000080okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@000004
0?ooo`030000003oool0oooo01P0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0703ooolB0?nf`@Go003o703o]/4A0?ooo`d0okK100?o003o0?nf`@3o]/405`3o]/400ol0
0?l0okK10?nf`@090?nf`Al0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0G0?oo
o`030000003oool0oooo0080oooo00D000000?nf`@3o]/40okK1000000020?nf`@060000003o]/40
okK10000003o]/400000103o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK10080okK1
00@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080
okK10`00000@0?ooo`030?nf`@000000okK10080okK100H000000?nf`@3o]/4000000?nf`@000002
0?nf`@050000003o]/4000000?nf`Ol000000P3o]/401?l00000okK10?nf`@3o]/42o`0000030?nf
`Ol00000okK100@0okK100Wo00000?nf`Ol00000okK10000003o]/4000000?nf`@0000000P3o]/40
10000000okK10?nf`@0000020?nf`@030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0M0?oooc@0okK13@3oool?
0?nf`@03o`00o`3o]/40okK100P0okK10`00000;0?nf`@03o`00o`3o]/40okK100X0okK17`3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01L0oooo00<000000?ooo`3oool00`3oool0
10000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40
okK1000000090?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/401@000000okK10?nf`@3o]/40
000000D0okK100<000000?nf`@3o]/40103o]/42000000`0oooo0P3o]/400`000000okK10?nf`@02
0?nf`@0<0000003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/7o00000P3o]/40
1Ol00000okK10?nf`@3o]/7o000000@0okK100Wo00000?nf`@3o]/40okK1o`00003o]/7o00000?nf
`@0000000P3o]/401@000000okK1o`00003o]/4000000080okK100D000000?nf`@3o]/4000000?nf
`@030?ooo`030000003oool0oooo01T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool07@3ooolh0?nf`@D0oooo4P3o]/400ol00?l0okK10?nf`@080?nf`@D000002P3o]/40
0ol00?l0okK10?nf`@090?nf`B00oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0G
0?ooo`030000003oool0oooo00<0oooo00@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf
`@0000020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401P3o]/400ol00000okK1
0?nf`@020?nf`@8000000P3o]/401?l0000000000?nf`@3o]/42000000@0okK100?o000000000000
00001@3o]/42000000030?nf`@3oool0oooo00<0oooo103o]/42000000@0okK100H000000?nf`@3o
]/4000000?nf`@0000020?nf`@050000003o]/4000000?nf`Ol000000P3o]/401Ol00000okK10?nf
`@3o]/7o000000@0okK100Wo00000?nf`@3o]/40okK1o`00003o]/7o00000?nf`@0000000P3o]/40
1@000000okK10000003o]/4000000080okK100@000000?nf`@3o]/400000103oool00`000000oooo
0?ooo`0I0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo01d0ooooC`3o
]/400ol00?l0okK10?nf`@080?nf`@D000002@3o]/400ol00?l0okK10?nf`@0:0?nf`B00oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00@0
00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK10080
okK100?o00000?nf`@3o]/401`3o]/42o`0000@0okK100@000000?nf`@3o]/40okK10P0000020?nf
`@<00000103o]/42000000D0okK10`0000050?nf`@8000001@3o]/401`000000okK10?nf`@3o]/40
00000?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100Go00000?nf`@3o]/40
okK1o`0000040?nf`@09o`00003o]/40okK10?nf`Ol00000okK1o`00003o]/4000000080okK100D0
00000?nf`@000000okK1000000020?nf`@040000003o]/40okK1000000@0oooo00<000000?ooo`3o
ool06@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0N0?ooodh0okK1
00?o003o0?nf`@3o]/40203o]/45000000T0okK100?o003o0?nf`@3o]/402P3o]/4P0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`050000
003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK1
0080okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@020?nf`@8000000`3o]/420000
00<0okK10`0000030?nf`@030000003o]/40okK100D0okK11@0000060?nf`@07o`00003o]/40okK1
0?nf`Ol00000okK1000000020?nf`@050000003o]/4000000?nf`Ol000000P3o]/401Ol00000okK1
0?nf`@3o]/7o000000@0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@09o`0000000000okK1
0?nf`@000000okK10000003o]/4000000080okK100D000000?nf`@3o]/7o00000?nf`@030?ooo`03
0000003oool0oooo01X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0
7P3ooom>0?nf`@03o`00o`3o]/40okK100T0okK10`00000:0?nf`@03o`00o`3o]/40okK100T0okK1
8@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01L0oooo00<000000?ooo`3oool0
0`3oool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/401@00
0000okK10?nf`@3o]/7o000000/0okK100?o00000?nf`@3o]/400`3o]/400ol00000okK10?nf`@02
0?nf`@800000103o]/4010000000okK10?nf`@3o]/44000000h0okK100@000000?nf`@3o]/400000
0P3o]/400`000000okK1000000020?nf`@050000003o]/7o00000?nf`Ol00000103o]/400ol00000
okK10?nf`@02o`0000<0okK100[o00000?nf`@3o]/7o00000?nf`@000000okK100000?l000000000
0P3o]/4010000000okK100000?l000020?nf`@030000003oool0oooo0080oooo00<000000?ooo`3o
ool06P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0O0?ooodd0okK1
00?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0:0?nf`B40oooo00?o00000?ooo`3oool0
3`3oool00ol00000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o]/40
okK1000000020?nf`@040000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK1o`00000;
0?nf`@?o0000103o]/42000000@0okK100<000000?nf`@3o]/400P3o]/400ol00000000000000004
0?nf`@<000002P3o]/401@000000okK10?nf`@3o]/4000000080okK100<000000?nf`@0000000P3o
]/401@000000okK1o`00003o]/7o000000D0okK10_l000050?nf`@0:o`00003o]/40okK1o`00003o
]/4000000?nf`@000000okK100000080okK100<000000?nf`@0000000`3o]/400`000000oooo0?oo
o`020?ooo`030000003oool0oooo01X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o0000
0?ooo`3oool0803ooolN0?nf`@[o003o8`3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40
okK100T0okK18P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01P0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3o]/40000000<0okK100@000000?nf`@3o]/400000
0P3o]/401@000000okK10?nf`@3o]/7o000000h0okK10ol000030?nf`@8000000`3o]/43000000@0
okK10P0000050?nf`@<000001P3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf
`@3o]/4000000P3o]/401@000000okK1o`00003o]/7o000000/0okK100So00000?nf`@3o]/7o0000
0?nf`@000000okK100000080okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@000005
0?ooo`030000003oool0oooo01X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0803ooolI0?nf`@Go003o2P3o]/44o`00oal0okK100?o003o0?nf`@3o]/405@3o]/400ol0
0?l0okK10?nf`@090?nf`B<0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0H0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3o]/40okK1000000020?nf`@040000003o]/40
okK1000000<0okK100D000000?nf`@3o]/40okK1o`00000@0?nf`@03o`00003o]/40okK10080okK1
0`0000030?nf`@800000103o]/400`000000okK10?nf`@050?nf`@H00000103o]/401P000000okK1
0?nf`@000000okK100000080okK100<000000?nf`Ol000000`3o]/400ol00000okK10?nf`@080?nf
`@0:o`00003o]/40okK1o`00003o]/7o00000?nf`@000000okK100000080okK100<000000?nf`@00
00000`3o]/400`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00?o00000?ooo`3o
ool0203oool000T0oooo00?o00000?ooo`3oool08@3ooolG0?nf`@03o`00o`3o]/40okK10140okK1
0_l00?lM0?nf`@03o`00o`3o]/40okK101D0okK100?o003o0?nf`@3o]/402@3o]/4S0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?nf`@0000000`3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK1
0?nf`Ol000004@3o]/43o`0000@0okK10P0000030?nf`@03o`0000000000okK10080okK100<00000
o`00000000003@3o]/401?l00000okK10?nf`@0000020?nf`@060000003o]/40okK10000003o]/7o
00000`3o]/400ol00000okK10?nf`@070?nf`@08o`00003o]/7o0000o`00003o]/4000000?nf`@00
00020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/4000001@3oool00`000000oooo
0?ooo`0K0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0240oooo5P3o
]/400ol00?l0okK10?nf`@0D0?nf`@;o003o6`3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o
]/40okK100T0okK1903oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01P0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3o]/40000000<0okK100Co00000?nf`@3o]/40
00000P3o]/401@000000okK10?nf`@3o]/7o000001@0okK10ol000030?nf`@8000000`3o]/420000
00@0okK100<000000?nf`@3o]/40203o]/42000000<0okK100@000000?nf`@3o]/4000000P3o]/40
0`000000okK1o`0000030?nf`@03o`00003o]/40okK100D0okK10_l000020?nf`@06o`00003o]/40
okK10000003o]/4000000P3o]/400`000000okK1000000020?nf`@040000003o]/40okK1000000D0
oooo00<000000?ooo`3oool06`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`0Q0?oooaD0okK100?o003o0?nf`@3o]/405`3o]/42o`00oaT0okK100?o003o0?nf`@3o]/40
4`3o]/400ol00?l0okK10?nf`@0:0?nf`B@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo
0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o]/40okK1000000020?nf`@04
0000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK1o`0000080?nf`@So00001P3o]/40
0ol00000okK10?nf`@020?nf`@<000000P3o]/42000000<0okK10`0000060?nf`@030000003o]/40
okK100<0okK100?o00000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/7o000000<0okK100?o
00000?nf`@3o]/400P3o]/42o`0000<0okK100Ko00000?nf`@3o]/4000000?nf`Ol000020?nf`@03
0000003o]/4000000080okK100@000000?nf`@3o]/4000001@3oool00`000000oooo0?ooo`0L0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0280oooo4`3o]/400ol00?l0
okK10?nf`@0J0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0
okK10?nf`@0:0?nf`B@0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00<0oooo00?o00000?ooo`3oool00P3o]/4010000000okK10?nf`@0000020?nf
`@05o`00003o]/40okK10?nf`Ol000000`3o]/400ol00000okK10?nf`@030?nf`@;o0000203o]/44
o`0000<0okK11?l000030?nf`@06o`00003o]/40okK10?nf`@00003o0000103o]/46000000D0okK1
00@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/7o000000@0okK11?l000040?nf
`@06o`00003o]/40okK1o`00003o]/4000000P3o]/400`000000okK1o`0000020?nf`@050000003o
]/40okK100000?l00000103oool00`000000oooo0?ooo`0M0?ooo`03o`00003oool0oooo00P0oooo
00090?ooo`03o`00003oool0oooo02<0oooo4@3o]/400ol00?l0okK10?nf`@0L0?nf`@03o`00o`3o
]/40okK101D0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@0:0?nf`BD0oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo00H0
00000?ooo`3oool0oooo0?nf`@0000020?nf`@040000003o]/40okK1000000<0okK100D000000?nf
`@3o]/40okK1o`0000050?nf`@03o`00003o]/40okK100/0okK10ol000040?nf`@03o`00003o]/40
okK100800000103o]/400`000000okK10?nf`@0<0?nf`@040000003o]/40okK100000080okK100D0
00000?nf`@3o]/40okK1o`00000:0?nf`@;o00000P3o]/4010000000okK10?nf`@0000020?nf`@03
0000003o]/4000000080okK100@000000?nf`@3o]/4000001@3oool00`000000oooo0?ooo`0M0?oo
o`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02<0oooo4@3o]/400ol00?l0
okK10?nf`@0M0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0
okK10?nf`@0:0?nf`BH0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0okK1000000030?nf`@040000003o]/40okK1
000000<0okK100D000000?nf`@3o]/40okK1o`0000040?nf`@03o`00003o]/40okK100h0okK10_l0
00030?nf`@04o`00003o]/40okK10?nf`@8000000`3o]/42000000/0okK100D000000?nf`@3o]/40
okK1000000020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/401@3o]/42o`0000<0
okK100@000000?nf`@3o]/4000000P3o]/401P000000okK10?nf`@000000okK100000080okK100<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo02@0oooo403o]/400ol00?l0okK10?nf`@0N0?nf`@03o`00o`3o]/40
okK101<0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0;0?nf`BH0oooo00?o0000
0?ooo`3oool03`3oool00ol00000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo00H00000
0?ooo`3oool0oooo0?nf`@0000020?nf`@040000003o]/40okK1000000<0okK100D000000?nf`@3o
]/40okK1o`0000050?nf`@03o`00003o]/40okK100l0okK100Go00000?nf`@3o]/40okK1o`000004
0?nf`@03o`00003o]/40okK10080okK10P0000080?nf`@030000003o]/40okK10080okK100D00000
0?nf`@3o]/40okK1000000030?nf`@;o0000103o]/42o`0000@0okK100@000000?nf`@3o]/400000
0P3o]/401?l00000okK10?nf`@0000020?nf`@040000003o]/40okK1000000D0oooo00<000000?oo
o`3oool07P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0T0?oooa40
okK100?o003o0?nf`@3o]/407P3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100h0
okK100?o003o0?nf`@3o]/402`3o]/4W0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool06`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?nf`@0000000`3o]/401000
0000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`Ol00000103o]/400ol00000okK10?nf
`@0@0?nf`@04o`00003o]/40okK10?nf`@;o00000`3o]/400`000000okK10?nf`@030?nf`@030000
0?l00000000000D000001@3o]/401@000000okK10?nf`@3o]/40000000D0okK11?l000040?nf`@80
00000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0O0?ooo`03o`00003oool0oooo00P0oooo00090?oo
o`03o`00003oool0oooo02D0oooo403o]/400ol00?l0okK10?nf`@0>0?nf`@<000003P3o]/400ol0
0?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/40303o]/4W0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool06`3oool00ol00000oooo0?ooo`030?oo
o`060000003oool0oooo0?ooo`3o]/7o00000P3o]/401@000000okK10?nf`@3o]/7o00000080okK1
00Go00000?nf`@3o]/40okK1o`0000040?nf`@03o`00003o]/40okK10140okK100?o00000?nf`@3o
]/400P3o]/401Ol00000okK10?nf`@3o]/4000000140okK100D000000?nf`@3o]/40okK10000000;
0?nf`@8000000`3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@000000
0P3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00?o00000?ooo`3oool0
203oool000T0oooo00?o00000?ooo`3oool09P3oool?0?nf`@03o`00o`3o]/40okK100d0okK11@00
000>0?nf`@03o`00o`3o]/40okK10140okK10_l00?l<0?nf`@;o003o3P3o]/4X0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000000`3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf
`Ol00000103o]/400ol00000okK10?nf`@0@0?nf`@03o`00003o]/40okK100<0okK100Go00000?nf
`@3o]/40okK10000000@0?nf`@030000003o]/40okK10080okK10P0000070?nf`@800000103o]/40
10000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000oooo
0?ooo`030?ooo`030000003oool0oooo0200oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool09`3oool>0?nf`@03o`00o`3o]/40okK100d0okK11@00000>0?nf`@03o`00o`3o
]/40okK101<0okK100?o003o0?nf`@3o]/401P3o]/43o`00o`l0okK1:@3oool00ol00000oooo0?oo
o`0?0?ooo`03o`00003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000<0
okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@0@0?nf`@03o`00003o]/40okK100<0
okK100Go00000?nf`@3o]/40okK10000000?0?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/400P3o]/400ol0000000000?nf`@040?nf`@04o`00003o]/40okK1o`0000<0okK100@00000
0?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo0200oooo00?o
00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0:03oool>0?nf`@03o`00o`3o]/40
okK100`0okK11@00000?0?nf`@03o`00o`3o]/40okK101<0okK10ol00?l20?nf`@?o003o4@3o]/4Z
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool07@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00D000000?nf`@3o]/40okK1000000020?nf`@080000003o
]/40okK10?nf`@00003o00000000003o]/42o`0000<0okK10ol0000@0?nf`@03o`00003o]/40okK1
0080okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK1
00D0okK11@0000040?nf`@8000000P3o]/42000000030?nf`@00000000000080okK100D000000?nf
`@3o]/40okK1000000050?ooo`03o`00003oool0oooo0240oooo00?o00000?ooo`3oool0203oool0
00T0oooo00?o00000?ooo`3oool0:03oool>0?nf`@03o`00o`3o]/40okK100d0okK10`00000@0?nf
`@03o`00o`3o]/40okK101H0okK10_l00?lC0?nf`B/0oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00H000000?ooo`3oool0oooo0?nf`Ol0
00030?nf`@05o`00003o]/40okK1o`0000000000103o]/4010000000okK10?nf`Ol000050?nf`@;o
00003P3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o
]/40303o]/400`000000okK10?nf`@0;0?nf`@<000000`3o]/4010000000okK10?nf`@0000030?nf
`@060000003o]/40okK10?nf`@3oool00000103oool00`000000oooo0?ooo`0R0?ooo`03o`00003o
ool0oooo00P0oooo00090?ooo`03o`00003oool0oooo02T0oooo3P3o]/42o`00ob40okK100?o003o
0?nf`@3o]/40:P3o]/4[0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool07P3oool0
0`000000oooo0?ooo`040?ooo`060000003oool0oooo0?ooo`3o]/4000000`3o]/4010000000okK1
0?nf`@3o]/42000000<0okK100@000000?nf`@3o]/7o00001P3o]/400ol00000okK10?nf`@0;0?nf
`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf`@0<0?nf
`@<000002@3o]/400`000000okK10?nf`@020?nf`@8000000P3o]/401Ol00000okK10?nf`@3o]/7o
000000@0okK100<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo02X0oooo3`3o]/400ol00?l0okK10?nf`@0N0?nf
`@03o`00o`3o]/40okK102T0okK1;03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo
01l0oooo00<000000?ooo`3oool0103oool01P000000oooo0?ooo`3oool0okK1000000<0okK100<0
00000?nf`@3o]/400P3o]/4200000080okK10P0000000`3o]/7o0000o`000002o`0000<0okK10ol0
00090?nf`@;o00001@3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100h0okK100<0
0000o`00000000001P0000030?nf`@8000000`3o]/400`000000okK10?nf`@02000000<0okK100<0
0000o`00003oool0103oool00`000000oooo0?ooo`0S0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo02/0oooo3`3o]/400ol00?l0okK10?nf`@0L0?nf`@03o`00o`3o]/40
okK102T0okK1;@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo01l0oooo00<00000
0?ooo`3oool01@3oool01P000000oooo0?ooo`3oool0okK1000000<0okK100?o00000000003o]/40
0`3o]/401@000000okK10?nf`@3o]/40000000@0okK10_l000040?nf`@Co00000P3o]/43o`0000H0
okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@0H0?nf`@800000103o]/4010000000
okK10?nf`@0000050?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0/0?ooo`l0okK100?o003o0?nf`@3o
]/406`3o]/400ol00?l0okK10?nf`@0X0?nf`Bh0oooo00?o00000?ooo`3oool03`3oool00ol00000
oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0?nf`@020000
00<0okK10P0000030?nf`@040000003o]/40okK10?nf`@800000103o]/400ol00000okK10?nf`@05
0?nf`@;o0000203o]/400ol00000okK10?nf`@040?nf`@030000003o]/40okK101P0okK100<00000
0?nf`@3o]/400P3o]/4200000080okK100<000000?nf`@3o]/400`3o]/400`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02D0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?oo
o`3oool0;@3oool?0?nf`@;o003o6`3o]/400ol00?l0okK10?nf`@0V0?nf`C00oooo00?o00000?oo
o`3oool03`3oool00ol00000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool0oooo0P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@000000103o
]/400`000000okK10?nf`@020?nf`@?o00003@3o]/400ol00000okK10?nf`@040?nf`@030000003o
]/40okK101L0okK10P0000040?nf`@030000003o]/40okK10080okK100H000000?nf`@3o]/40okK1
0?ooo`0000050?ooo`03o`00003oool0oooo02H0oooo00?o00000?ooo`3oool0203oool000T0oooo
00?o00000?ooo`3oool0;P3oool@0?nf`@;o003o603o]/400ol00?l0okK10?nf`@0V0?nf`C40oooo
00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0R0?ooo`8000001P3oool01?l000000000
0?ooo`3oool20?nf`@8000000P3o]/400ol000000000000000020?nf`@03o`0000000000okK10080
okK100@00000o`000000000000000`3o]/4=o`0000@0okK10P0000000ol00000okK10?nf`@0@0?nf
`@H0000000?o00000000003o]/400P3o]/4200000004o`00003o]/40okK10?nf`@8000000`3o]/42
000000H0oooo00<000000?ooo`3oool09P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`0`0?oooa00okK10_l00?lD0?nf`@;o003o:03o]/4b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0903oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
0?ooo`80okK10P0000030?nf`@<0000000@0okK10000000000000000103o]/4300000100okK100<0
00000?nf`@3o]/402@3o]/4:000000X0okK100<000000?nf`@3o]/400P3o]/42000000@0okK100<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`03o`00003oool0oooo00P0oooo0009
0?ooo`03o`00003oool0oooo0340oooo4@3o]/43o`00oa00okK100?o003o0?nf`@3o]/409`3o]/4c
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`8000000P3oool30?nf`@030000003o]/40okK100<0okK100@000000?nf`@3o]/40okK11000
00030?nf`@@000002@3o]/43000000P0okK11000000B0?nf`@800000103o]/400`000000okK10?nf
`@030?nf`@030000003oool0oooo00D0oooo00<000000?ooo`3oool0:03oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`0b0?oooa<0okK10ol00?l<0?nf`@03o`00o`3o]/40
okK102L0okK1=03oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`030?nf`@03o`0000000000000000<0okK10`000004
0?nf`@<00000103o]/49000000L0okK11000000B0?nf`@80000000?o00000000003o]/40103o]/40
0ol00000okK10?nf`@030?nf`@030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0c0?oooaD0okK13?l00?lY0?nf
`CD0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0W0?ooo`030000003oool0oooo
00H0oooo00?o00000000003oool01@3o]/42000000@0okK10`0000040?nf`@@000003@3o]/430000
0180okK1100000070?nf`@8000001@3o]/400`000000oooo0?ooo`050?ooo`030000003oool0oooo
02X0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0=@3ooom60?nf`CL0
oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0
oooo0P0000000`3oool0okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/401@3o]/4=000000h0okK11`00000:0?nf`@030000003o]/40okK100<0okK100<0oooo0000003o
ool01P3oool00`000000oooo0?ooo`0[0?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00
003oool0oooo03H0ooooA03o]/4h0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
:@3oool2000000T0oooo00<000000?ooo`3o]/40103o]/43000000@0okK11@00000G0?nf`@H00000
3`3o]/42000000D0okK100<0ooooo`00003oool01P3oool00`000000oooo0?ooo`0/0?ooo`03o`00
003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo03P0oooo@03o]/4j0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0:`3oool2000000P0oooo00?o00000000000000001P3o
]/401000003o00000000000000050?nf`@03o`00000000000000008000002P3o]/4600000003o`00
00000000okK10100okK1100000050?nf`@030?ooo`000000000000L0oooo00<000000?ooo`3oool0
;@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0j0?oooc`0okK1?03o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02d0oooo0P0000090?ooo`<000001`3o
]/43000000L0okK12P00000E0?nf`@@000001`3o]/43000000P0oooo00<000000?ooo`3oool0;P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`0k0?ooocX0okK1?@3oool0
0ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo02l0oooo00<000000?ooo`3oool02@3oool3
000000L0okK11000000K0?nf`@L000002P3o]/400`000000oooo0?ooo`080?ooo`030000003oool0
oooo02l0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0?P3ooole0?nf
`Cl0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0`0?ooo`0400000?l000000000
000000X0oooo100000070?nf`@X000000`3o]/4>000000l0okK10P0000090?ooo`0300000?l00000
oooo0340oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0@@3oool_0?nf
`D80oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0d0?ooo`8000002`3oool0103o
]/40000000000000000>0?nf`@<000006P3o]/400`3oool000000000000:0?ooo`030000003oool0
oooo0380oooo00?o00000?ooo`3oool0203oool000T0oooo00?o00000?ooo`3oool0A03ooolY0?nf
`DD0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?ooo`0f0?ooo`800000303oool00`3o
]/40000000000002000002@0okK10P3oool2000000/0oooo00<000000?ooo`3oool0<`3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`170?ooob<0okK1B03oool00ol00000
oooo0?ooo`0?0?ooo`03o`00003oool0oooo03P0oooo0P00000=0?ooo`80okK11`00000J0?nf`@03
0?ooo`000000000000800000303oool00ol00000oooo0?ooo`0d0?ooo`03o`00003oool0oooo00P0
oooo00090?ooo`03o`00003oool0oooo04X0oooo7@3o]/5;0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0>P3oool01000003o000000000000000<0?ooo`H0okK16@0000000ol00000
00000?ooo`0=0?ooo`800000=`3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`1=0?oooaL0okK1CP3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo03h0oooo
1000000;0?oooaL0okK14P3oool3000003T0oooo00?o00000?ooo`3oool0203oool000T0oooo00?o
00000?ooo`3oool0EP3oool40?nf`EP0oooo00?o00000?ooo`3oool03`3oool00ol00000oooo0?oo
o`120?ooo`<000004@3oool40?nf`A/0oooo00<000000?ooo`3oool0>P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0A@3oool200000003o`0000000000oooo02T0oooo0P00000m0?ooo`03o`00003oool0
oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o00000?ooo`3oool03`3oool00ol0
0000oooo0?ooo`190?ooo`L000008@3oool2000003l0oooo00?o00000?ooo`3oool0203oool000T0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0500
oooo1`00000H0?ooo`800000@@3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0E`3oool;000000H0oooo
1`0000130?ooo`03o`00003oool0oooo00P0oooo00090?ooo`03o`00003oool0oooo0;80oooo00?o
00000?ooo`3oool03`3oool00ol00000oooo0?ooo`1R0?ooo`H00000BP3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?oo
o`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3o
ool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00
003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3o
ool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3o
ool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0
oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol0
0000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol0
0000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0
oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo
0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo
0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o
00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b
0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`08
0?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?oo
o`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`00
2@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool0
0ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool0
0ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000
oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000
oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?oo
o`2b0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?oo
o`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?ooo`03o`00003oool0oooo00l0oooo00?o0000
0?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?ooo`002@3oool00ol00000oooo0?ooo`2b0?oo
o`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/P3oool00ol00000oooo0?ooo`080?oo
o`002@3ooonfo`000140oooo]_l0000:0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(full1\  = \ em\  // \ Last;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification", "Subsection"],

Cell[CellGroupData[{

Cell["Classification parameters", "Subsubsection"],

Cell[BoxData[{
    \(\(model\  = \ full1;\)\), "\[IndentingNewLine]", 
    \(\(thresholdList\  = \ Table[i/5, {i, 1, 15}]\  // \ N;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate classification data for increasing thresholds (1/5 to 3)\
\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(OneClassClassify1[model, #] &\)\  /@ \ thresholdList;\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooomG0000
o`X0o`00C0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooodl0003o6@3o0015
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooBP000?lR0?l00440003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooom:0000ob80o`00@@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooodH0003o:@3o000n0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo@P000?l_0?l003`0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolo0000ocD0o`00>@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooocd0003o>@3o000g0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
>@000?ln0?l003H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolg0000od80
o`00=0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooodd0
003o4`3o001<0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooole0000
odH0o`00<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
odL0003o7`3o00160000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooole
0000odH0o`00<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooodD0003o903o00130000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolb0000od/0o`00<0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooood80003o:P3o00100000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ooooool`0000odh0o`00;`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooocl0003o;`3o000n0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooooooool]0000oe80o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooc`0003o=@3o000k0000o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolZ0000oeH0o`00;@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooocX0003o>@3o000i0000o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolY0000oeP0o`00;0000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooocT0003o>`3o000h0000o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolW0000oe`0o`00:P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooocL0003o?`3o000f0000o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolW0000oe`0o`00:P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooocD0003o@`3o000d0000o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolU0000oel0o`00:@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooc@0003oA@3o000c0000o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolT0000of40o`00:0000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooc80003oB03o000b0000o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolR0000of@0o`009`000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooc40003oBP3o000a0000o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolQ0000ofH0o`009P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc00003oC03o000`0000o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolP0000ofP0o`009@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobl0003oCP3o000_0000o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO0000ofX0o`0090000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobh0003oD@3o000]0000o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ofd0o`008P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobd0003oD`3o000/0000
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ofd0o`008P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob`0003oE@3o000[
0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolM0000ofl0o`008@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob/0003oE`3o
000Z0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000og80o`00
80000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobX0003o
F@3o000Y0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000og80
o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobT0
003oF`3o000X0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000
og@0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
obP0003oG03o000X0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ
0000ogD0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooobP0003oG@3o000W0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolI0000ogL0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooobL0003oG`3o000V0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolI0000ogL0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooobH0003oH03o000V0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolI0000ogL0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooobD0003oHP3o000U0000o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolH0000ogX0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooob@0003oH`3o000U0000o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolH0000og/0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooob@0003oI03o000T0000o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolG0000og`0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooob<0003oIP3o000S0000o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolG0000ogd0o`006@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooob<0003oIP3o000S0000o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolG0000ogd0o`006@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooob80003oJ03o000R0000o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolF0000ogl0o`0060000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooob40003oJ@3o000R0000o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolF0000ogl0o`0060000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooob40003oJP3o000Q0000o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolF0000ogl0o`0060000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob00003oK03o000P0000o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolF0000oh00o`005`000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob00003oK03o000P0000o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolE0000oh40o`005`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooal0003oKP3o000O0000o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolE0000oh80o`005P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooah0003oK`3o000O0000
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolE0000oh80o`005P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooah0003oK`3o000O
0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolE0000oh<0o`005@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooad0003oL@3o
000N0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolE0000oh<0o`00
5@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooad0003o
=@3o00070000ocD0o`007P000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo4`000?n50?l001D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolM0000oc40o`003`000?lb0?l001d0003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooa<0003oQ@3o000E0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo70000?l`0?l001@0003o;`3o000M0000o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolC0000ohL0o`004`000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooa`0003o;`3o000F0000obh0o`007@000?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo4`000?n70?l001<0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolL0000obd0o`006P00
0?l]0?l001`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa<0003o
Q`3o000C0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
70000?l/0?l001`0003o;03o000L0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolC0000ohP0o`004P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa`0003o;03o000M0000ob/0o`0070000?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo4`000?n80?l00180003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolL0000obX0o`0080000?l[0?l001/0003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooa<0003oR03o000B0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6`000?lZ0?l00280003o:P3o000K
0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolC0000ohP0o`004P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa/0003o:P3o
000R0000obX0o`006`000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
4`000?n80?l00180003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolK0000obT0o`0090000?lY0?l001/0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooa<0003o@@3o00050000od80o`004P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooaX0003o:P3o000T0000obT0o`006`000?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo4`000?lm0?l000`0003o@03o000A0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6P000?lY0?l0
02H0003o:03o000K0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolC
0000oc`0o`003P000?lo0?l00140003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJ0000obT0o`009P000?lX0?l001/0003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooa<0003o>`3o000@0000och0o`004@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaX0003o:03o000W0000obP0o`006`00
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo4`000?lj0?l00180003o
?@3o000A0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6P000?lX0?l002L0003o:03o000K0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolC0000ocT0o`004`000?lm0?l00140003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJ0000obP0o`00:0000?lX0?l001X0003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooa<0003o>@3o000D0000oc`0o`004@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaX0003o:03o000X0000
obP0o`006P000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo4`000?li
0?l001@0003o?03o000A0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolC0000ocT0o`0050000?ll0?l00140003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJ0000obL0o`00:@000?lX0?l001X0003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa<0003o>@3o000D0000oc`0o`00
4@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaX0003o
9`3o000Y0000obP0o`006P000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo4`000?lg0?l001H0003o?03o000A0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolC0000ocL0o`005P000?ll0?l00140003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ0000obL0o`00:@000?lX0?l0
01X0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa<0003o>@3o000D
0000oc/0o`004P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooaX0003o9`3o000Y0000obP0o`006P000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo4`000?li0?l001<0003o?03o000B0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6P000?lW0?l002T0003o:03o000J0000o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolC0000ocT0o`004`000?ll0?l00180003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ0000obP0o`00
:0000?lX0?l001X0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa<0
003o>@3o000C0000oc`0o`004P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooaX0003o:03o000X0000obL0o`006`000?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo4`000?li0?l00180003o?@3o000B0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6P000?lX0?l002L0003o:03o000K0000
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolC0000ocT0o`004P000?lm
0?l00180003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
0000obP0o`009`000?lX0?l001/0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa<0003o>P3o000@0000och0o`004P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooaX0003o:@3o000V0000obP0o`006`000?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo4`000?lk0?l000h0003o?P3o000C0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6P000?lY0?l002H0003o
:03o000K0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolC0000oc`0
o`003@000?ln0?l001<0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolK0000obT0o`0090000?lY0?l001/0003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooa<0003o?@3o000;0000ocl0o`004`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa/0003o:P3o000R0000obX0o`006`000?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo4`000?lm0?l000/0003o?`3o000C
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6`000?l[
0?l00240003o:P3o000K0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolC0000ocl0o`001P000?m20?l001<0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolL0000ob/0o`007`000?l[0?l001/0003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooa<0003oQ@3o000E0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo70000?l/0?l001d0003o:`3o000L0000o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolC0000ohD0o`005@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa`0003o;@3o000K0000ob`0
o`0070000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo5@000?n30?l0
01D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolL0000
obh0o`0060000?l^0?l001`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaD0003oP`3o000E0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo70000?l_0?l001D0003o;`3o000M0000o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolE0000oh80o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa`0003o<@3o000A0000oc40o`007@000?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo5@000?n20?l001H0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolM0000oc@0o`002`000?lc0?l001d0003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0003oPP3o000F0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7@000?ma0?l001h0
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0003oPP3o000F0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7P000?m`0?l0
01h0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0003oP@3o000G
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7P000?m_
0?l001l0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0003oP@3o
000G0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7P00
0?m_0?l001l0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0003o
P03o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7`000?m^0?l001l0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaD0
003oP03o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo80000?m/0?l00200003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oaH0003oO`3o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo80000?m/0?l00200003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaH0003oOP3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo8@000?m[0?l00200003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooaH0003oOP3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8@000?mZ0?l00240003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooaH0003oOP3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8P000?mX0?l00280003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooaH0003oO@3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8`000?mW0?l00280003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooaL0003oO03o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8`000?mV0?l002<0003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooaL0003oN`3o000K0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo90000?mU0?l002<0003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooaL0003oN`3o000K0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo90000?mT0?l002@0003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooaP0003oN03o000M0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo9@000?mR0?l002D0003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooaP0003oN03o000M0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo9P000?mQ0?l002D0003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooaP0003oN03o000M0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo9`000?mO0?l002H0003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003oMP3o000N0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:0000?mM0?l002L0003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003oMP3o000N0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:0000?mL0?l002P0003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oM03o000O0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:@000?mK0?l002P0003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oL`3o000P0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:P000?mI0?l002T0
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oLP3o000P0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:`000?mG0?l0
02X0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003oK`3o000Q
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;0000?mE
0?l002/0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003oK@3o
000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;@00
0?mB0?l002d0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o
K@3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
;P000?m@0?l002h0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0
003oK@3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo;`000?m>0?l002l0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oal0003oJP3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo<0000?m<0?l00300003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooob00003oJ03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo<P000?m90?l00340003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob40003oIP3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo<`000?m70?l00380003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob80003oI03o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=@000?m30?l003@0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooob@0003oH@3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=`000?lo0?l003H0003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobH0003oG`3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo>0000?lm0?l003L0003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobH0003oG`3o000X0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo>P000?li0?l003T0003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobL0003oG@3o000Y0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo?0000?ld0?l003`0003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobT0003oFP3o000Z0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo?@000?lb0?l003d0003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooobX0003oE`3o000/0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo@0000?l]0?l003l0003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooobd0003oD`3o000]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo@`000?lX0?l00440003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oD03o000^0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooA@000?lS0?l004@0003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oC03o000`0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooB`000?lG0?l004X0003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oC03o000`0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooD@000?l;0?l00500003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003oA`3o000a0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>0000?m30?l00380003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooooooooll0000oc`0o`00=@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooocl0003o>03o000f0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000ooooooooooooooooA0000?la0?l003P0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooom90000obX0o`00>P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
odl0003o8@3o000m0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooC`000?lQ
0?l003d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooomG0000oaH0o`00@000
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooof00003o1@3o00180000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooj`0003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/0000o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo[0000?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooj`0003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooF@000?l40?l00500
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooom?0000oaL0o`00A`000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooodT0003o8P3o00120000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooAP000?lX0?l003l0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooom20000obh0o`00?@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooocl0003o=03o000j0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000ooooooooooooooooCOl00?lC0?l004co003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooocd0003o>03o000h0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000ooooooooooooooooAol00?lO0?l004Ko003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooocd0003o>03o000h0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000ooooooooooooooooAOl00?lT0?l004?o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooocX0003o?03o000g0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo@_l00?lZ0?l0043o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocP0003o@03o000e0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo?ol00?l_0?l003ko003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooocH0003o@`3o000d0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo??l00?le0?l003_o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooc@0003oB03o000a0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo>_l00?li0?l003Wo003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oC03o000`0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo>Ol00?lk0?l003So003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oC`3o000_0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo=ol00?lo0?l003Ko003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oC`3o000_0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo=Ol00?m30?l003Co003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobd0003oDP3o000^0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo=?l00?m50?l003?o
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob`0003oE03o000]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo<_l00?m80?l0
03;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0003oF03o000/
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo<Ol00?m:
0?l0037o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0003oG03o
000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo<?l0
0?m<0?l0033o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0003o
GP3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
;ol00?m>0?l002oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0
003oH03o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo;_l00?mA0?l002go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ob@0003oHP3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo;Ol00?mC0?l002co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooob@0003oHP3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo;?l00?mE0?l002_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob80003oI@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo:ol00?mG0?l002[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob40003oI`3o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo:_l00?mI0?l002Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooob00003oJ@3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo:Ol00?mK0?l002So003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooal0003oK03o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo:?l00?mL0?l002So003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooal0003oK03o000R0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo:?l00?mM0?l002Oo003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooah0003oKP3o000Q0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo9ol00?mO0?l002Ko003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooad0003oL03o000P0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo9_l00?mP0?l002Ko003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooad0003oL03o000P0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo9Ol00?mR0?l002Go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooad0003oL03o000P0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo9?l00?mS0?l002Go003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oL`3o000O0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9?l00?mT0?l002Co003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM03o000N0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8ol00?mV0?l002?o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oM@3o000N0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8ol00?mV0?l002?o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oMP3o000M0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8_l00?mX0?l002;o
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oMP3o000M0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?mY0?l0
02;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003oN@3o000K
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?mZ
0?l0027o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003oN@3o
000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8?l0
0?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o
N@3o000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
8?l00?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0
003oNP3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo7ol00?m^0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oaP0003oN`3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo7_l00?m_0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaP0003oO03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooaP0003oO03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo7Ol00?ma0?l001ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooaP0003oO@3o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo7Ol00?le0?l000L0003o=@3o000No`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolH0000ogd0o`0060000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooago003o<@3o000?0000oc80o`007Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo60000?mm0?l001P0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00oc00o`0050000?l_0?l0
01go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaL0003oOP3o000H
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l_
0?l001H0003o;P3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolG0000ogl0o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooaco003o;@3o000J0000obd0o`007?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo5`000?mo0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolLo`00ob`0o`0070000?l/0?l001co003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooaL0003oO`3o000G0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolG0000ocd0o`0020000?lj0?l0
01L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00
obX0o`0080000?l[0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaL0003o>@3o000>0000ocT0o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo5`000?lf0?l00180003o>03o000F0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o
000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolG0000ocH0o`00
4P000?lh0?l001H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooaL0003o=@3o000D0000ocL0o`005P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooa[o003o:P3o000T0000obT0o`006ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo5`000?lc0?l001L0003o=P3o000F0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l0
02H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolF
0000oc<0o`0060000?lf0?l001H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooaH0003o<P3o000K0000oc@0o`005P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W0000obP0o`006ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo5P000?lb0?l001`0003o
<`3o000F0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolF0000oc80o`0070000?lc0?l001H0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJo`00obP0o`00:0000?lX0?l001[o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooaH0003o<P3o000L0000oc<0o`005P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000
obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo5P000?lb
0?l001`0003o<`3o000F0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolF0000oc40o`007P000?lb0?l001H0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaH0003o<@3o000N0000oc80o`00
5P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o
9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo5`000?l`0?l001h0003o<P3o000F0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolG0000oc00o`007@000?lc0?l001H0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l0
01[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaL0003o<03o000M
0000oc<0o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo5`000?l`0?l001d0003o<`3o000F0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolG0000oc00o`007@000?lc0?l001H0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
:0000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaL0
003o<@3o000K0000oc@0o`005P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obL0o`006ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo5`000?la0?l001/0003o=03o000F0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolG0000oc40o`006@000?lf
0?l001H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooaL0003o<@3o000I0000ocD0o`005`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo5`000?lb0?l001L0003o=P3o000G0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l002H0003o
:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolG0000oc80
o`005P000?lg0?l001L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooaL0003o<`3o000E0000ocL0o`005`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo5`000?lc0?l001D0003o=`3o000G
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?l[
0?l00240003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolG0000ocD0o`004P000?lg0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolLo`00ob/0o`007`000?l[0?l001_o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooaP0003o=@3o000@0000ocP0o`0060000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;03o000M0000ob/0o`00
7?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo60000?lg0?l000h0
003o>03o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo7?l00?l]0?l001/0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolH0000ocT0o`002P000?lj0?l001P0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolLo`00obh0o`0060000?l^0?l001co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooaP0003o?P3o00020000oc`0o`006@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;`3o000E
0000obl0o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6000
0?ml0?l001T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolLo`00oc40o`004@000?la0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooaP0003oO03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo7Ol00?ld0?l000/0003o<`3o000Mo`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolH0000og`0o`006@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooago003oL@3o000No`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolH0000og/0o`006P000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooako003oL03o000No`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolH0000og/0o`006P000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolI0000ogX0o`006P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolI0000ogT0o`006`000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaoo003oKP3o000Oo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolI0000ogT0o`006`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob3o003oK03o000Po`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolI0000ogL0o`007@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob3o003oK03o000Po`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolI0000ogL0o`007@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob7o003oJ`3o000P
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolI0000ogL0o`007@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob7o003oJP3o
000Qo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ogH0o`00
7@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob;o003o
J03o000Ro`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ogD0
o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob?o
003oI`3o000Ro`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000
ogD0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ob?o003oIP3o000So`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK
0000og<0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooobCo003oI@3o000So`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolK0000og<0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooobCo003oI03o000To`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolM0000og00o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooobGo003oHP3o000Uo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolM0000ofl0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooobKo003oH@3o000Uo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolM0000ofl0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooobOo003oG`3o000Vo`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolN0000ofh0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooobSo003oG@3o000Wo`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolN0000ofd0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooobSo003oG03o000Xo`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolO0000ofX0o`0090000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooobWo003oF`3o000Xo`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolO0000ofX0o`0090000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooob[o003oF@3o000Yo`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolP0000ofP0o`009@000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooob_o003oE`3o000Zo`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolQ0000ofH0o`009P000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooobco003oE@3o000[o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolR0000ofD0o`009P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobgo003oDP3o000]o`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolR0000ofD0o`009P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobko003oD03o000^o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolT0000of80o`009`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooboo003oCP3o000_o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolU0000of00o`00:0000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc3o003oC03o000`o`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolV0000oeh0o`00:@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc;o003oB@3o000a
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolW0000oe`0o`00:P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc?o003oA`3o
000bo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolX0000oeT0o`00
;0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocGo003o
@`3o000do`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolZ0000oeH0
o`00;@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocOo
003o?`3o000fo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool/0000
oe<0o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ocSo003o?@3o000go`00o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool/
0000oe<0o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooc[o003o>@3o000io`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
ool^0000oe00o`00;`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooocco003o=03o000lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ooooool`0000odd0o`00<0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooocgo003o<P3o000mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolb0000odX0o`00<@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooood3o003o;@3o000oo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooole0000odH0o`00<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooood?o003o:03o0011o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolh0000od00o`00=@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooodGo003o8`3o0014o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooooll0000oc/0o`00=P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooood_o003o5`3o001:o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003oooooooooooooooll0000oc/0o`00=P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooe7o003o2`3o001@o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolo0000ocH0o`00>0000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooood@0003o;`3o000j0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
ooooooooooooB@000?lW0?l003d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oom@0000oad0o`00@0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooe/0003o
303o00160000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooookGo00004Ooooone
o`0000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooCP00
0?lG0?l004P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooom90000ob00o`00
A0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooodD0003o:03o00100000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooCOl00?lC0?l004co
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooood40003o;P3o000n0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooAol00?lO0?l0
04Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooood40003o;P3o000n
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooAOl00?lT
0?l004?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocl0003o<P3o
000l0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo@_l0
0?lZ0?l0043o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocd0003o
=`3o000i0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
?ol00?l_0?l003ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocX0
003o?03o000g0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo??l00?le0?l003_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ocP0003o?`3o000f0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo>_l00?li0?l003Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooocH0003o@`3o000d0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo>Ol00?lk0?l003So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooc@0003oA`3o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo=ol00?lo0?l003Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooc@0003oA`3o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=Ol00?m30?l003Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooc40003oB`3o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=?l00?m50?l003?o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooc00003oCP3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo<_l00?m80?l003;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobh0003oD@3o000^0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo<Ol00?m:0?l0037o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobd0003oD`3o000]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo<?l00?m<0?l0033o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobX0003oE`3o000/0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo;ol00?m>0?l002oo003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooobT0003oFP3o000Z0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo;_l00?mA0?l002go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooobP0003oG03o000Y0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo;Ol00?mC0?l002co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0003oG03o000Y0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;?l00?mE0?l002_o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0003oG`3o000X0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:ol00?mG0?l002[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0003oH@3o000W0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:_l00?mI0?l002Wo003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003oH`3o000V0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:Ol00?mK0?l002So
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oI@3o000V0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mL0?l0
02So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oIP3o000U
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mM
0?l002Oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oJ03o
000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9ol0
0?mO0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o
J`3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
9_l00?mP0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00
003oJ`3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo9Ol00?mR0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ob00003oJ`3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo9?l00?mS0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooal0003oK@3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo9?l00?mT0?l002Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooah0003oKP3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooah0003oK`3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooad0003oL@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8_l00?mX0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooad0003oL@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8Ol00?mY0?l002;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooad0003oLP3o000N0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo8Ol00?mZ0?l0027o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooad0003oLP3o000N0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooa/0003oM03o000N0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o000M0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7ol00?m^0?l001oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o000M0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oN03o000K0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oN03o000K0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ma0?l001ko003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003oN03o000K0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?le0?l000L0003o
=@3o000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ogT0
o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooago
003o<@3o000?0000oc80o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo6P000?mi0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolLo`00oc00o`0050000?l_0?l001go003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooaT0003oNP3o000J0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001H0003o;P3o000Mo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolI0000ogX0o`006P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;@3o000J0000obd0o`007?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6@000?lk0?l000T0003o
=`3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7?l00?l/0?l001`0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolI0000ocH0o`003`000?lf0?l001T0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolLo`00ob`0o`007@000?l[0?l001co003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o=03o000C0000oc@0o`006@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o:P3o000P0000
ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6@000?la
0?l001L0003o<`3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolI0000oc00o`006P000?la0?l001T0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l001_o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o<03o000J0000oc40o`00
6@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o
:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo6@000?l^0?l001`0003o<P3o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lZ0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolH0000obl0o`007@000?la0?l001P0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l0
01_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaP0003o;P3o000O
0000oc00o`0060000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo60000?l^0?l001l0003o<03o000H0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolH0000obh0o`0080000?l_0?l001P0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
9`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaP0
003o;P3o000P0000obl0o`0060000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo60000?l]0?l00280003o;P3o000H0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002P0003o:03o000Jo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolH0000obd0o`008P000?l^
0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooaP0003o;@3o000R0000obh0o`0060000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo60000?l]0?l00280003o;P3o000H0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o
:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolH0000obd0
o`008P000?l^0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooaP0003o;@3o000R0000obh0o`0060000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6@000?l/0?l00240003o;`3o000H
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW
0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolI0000ob`0o`008@000?l_0?l001P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooaT0003o;03o000Q0000obl0o`0060000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000obP0o`00
6_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6@000?l]0?l001l0
003o<03o000H0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo6_l00?lX0?l002P0003o9`3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolI0000obd0o`007`000?l_0?l001T0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolJo`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o;@3o000N0000oc00o`006@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W
0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6@00
0?l]0?l001h0003o<03o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo6_l00?lY0?l002H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolI0000obd0o`007@000?la0?l001T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaT0003o;P3o000L0000oc40
o`006@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o
003o:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo6@000?l^0?l001X0003o<`3o000I0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolI0000obh0o`006P000?lc0?l001T0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00ob/0o`008@000?lZ
0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003o;P3o
000I0000oc80o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooaco003o:`3o000O0000ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo6P000?l_0?l001L0003o<`3o000J0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000oc00o`005@000?ld0?l001X0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00obd0
o`006`000?l/0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oaX0003o<P3o000C0000oc@0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooaco003o;P3o000H0000obh0o`007?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo6P000?ld0?l00100003o=03o000K0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001D0003o;`3o000M
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ocL0o`003000
0?le0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolLo`00oc40o`004@000?la0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooaX0003o>`3o00060000ocL0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooago003o=03o000;0000oc<0o`007Ol00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo6P000?lk0?l000H0003o=`3o000K0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ma0?l001ko
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o000M0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m`0?l0
01ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o000M
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_
0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o
000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l0
0?m_0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o
M03o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7ol00?m^0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0
003oM03o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo8?l00?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oad0003oL@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo8?l00?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooad0003oL@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo8Ol00?m[0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooad0003oL@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8Ol00?mZ0?l0027o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooooad0003oL03o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8_l00?mX0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooad0003oL03o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8ol00?mW0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooah0003oKP3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooah0003oKP3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo9?l00?mU0?l002?o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooal0003oK03o000R0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo9?l00?mT0?l002Co003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooal0003oK03o000R0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo9Ol00?mR0?l002Go003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ@3o000T0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo9_l00?mQ0?l002Go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ@3o000T0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo9ol00?mO0?l002Ko003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ@3o000T0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mM0?l002Oo003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oI`3o000U0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mL0?l002So003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oIP3o000V0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:Ol00?mK0?l002So003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oI03o000W0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:_l00?mI0?l002Wo
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003oHP3o000W0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:ol00?mG0?l0
02[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0003oH03o000X
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;?l00?mE
0?l002_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0003oGP3o
000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;Ol0
0?mB0?l002go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0003o
GP3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
;_l00?m@0?l002ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobL0
003oG03o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo;ol00?m>0?l002oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
obP0003oF@3o000/0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo<?l00?m<0?l0033o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooobT0003oE`3o000]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo<_l00?m90?l0037o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob`0003oD`3o000^0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo<ol00?m70?l003;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooobd0003oD@3o000_0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=Ol00?m30?l003Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooobl0003oCP3o000`0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=ol00?lo0?l003Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooc00003oC03o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo>?l00?lm0?l003Oo003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooc00003oC03o000a0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo>_l00?li0?l003Wo003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooc80003oB@3o000b0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo??l00?ld0?l003co003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocH0003o@`3o000d0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo?Ol00?lb0?l003go003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooocP0003o?`3o000f0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo@?l00?l]0?l003oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooc`0003o>P3o000g0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo@ol00?lX0?l0047o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooocl0003o=@3o000i0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooAOl00?lS0?l004Co003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooood80003o;`3o000l0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooBol00?lG0?l004[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooood80003o;`3o000l0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooDOl00?l;0?l0053o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooodP0003o9P3o000o0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000ooooooooooooooooD0000?lK0?l00480003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]Ol0000AoooookGo00002oooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooe40003o3`3o001=0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000ooooooooooooooooBP000?lL0?l004L0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom=o`00oa<0o`00C?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000ooooooooooooooooA`000?lT0?l00480003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom7o`00oal0o`00A_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooA`000?lT0?l00480003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom5o`00ob@0o`00@ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooA0000?lY0?l00400003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom2o`00obX0o`00@?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo@0000?l`0?l003d0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooloo`00obl0o`00
?_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo?P000?lc0?l003`0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooollo`00ocD0
o`00>ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo?0000?lh0?l0
03T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooljo`00
ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>@000?lm
0?l003L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooli
o`00oc/0o`00>?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=`00
0?m00?l003H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
=`000?m00?l003H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo=P000?m30?l003@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
ooooooooooldo`00odD0o`00<ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo=0000?m70?l00380003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolbo`00odP0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo<@000?m<0?l00300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolao`00odX0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo<0000?m>0?l002l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003oooooooooooooool`o`00od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo;P000?mA0?l002h0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003oooooooooooooool_o`00odh0o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo;@000?mC0?l002d0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003oooooooooooooool^o`00oe40o`00;Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo;0000?mE0?l002`0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003oooooooooooooool]o`00oe<0o`00;?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo;0000?mE0?l002`0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo:@000?mJ0?l002X0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo:0000?mL0?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo9`000?mN0?l002P0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9P000?mP0?l002L0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9@000?mQ0?l002L0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo90000?mS0?l002H0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P000?mV0?l002D0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolVo`00of00o`00
9_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P000?mV0?l002D0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolUo`00of80
o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P000?mW0?l0
02@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolTo`00
of<0o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mX
0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolT
o`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8000
0?m[0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
80000?m[0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo7`000?m]0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolRo`00ofP0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo7`000?m]0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolQo`00ofT0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo7`000?m^0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolQo`00ofX0o`008Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo7`000?m^0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolPo`00of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo7P000?m_0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolPo`00of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo7P000?m`0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolOo`00ofh0o`007ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7@000?ma0?l001l0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolNo`00ofl0o`007ol00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo7@000?mb0?l001h0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolNo`00ofl0o`007ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7@000?mb0?l001h0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolMo`00og40o`007_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7@000?mc0?l001d0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolMo`00ocD0o`001`000?le0?l001ko003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003oM@3o000M0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000
ogD0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oaco003o<03o000D0000obl0o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo6`000?lk0?l000H0003o=03o000M0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001H0003o;P3o000Mo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolK0000ocH0o`003@000?ld0?l001/0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00obd0o`006P00
0?l]0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o
<`3o000B0000oc80o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
oooooooooooooaco003o;03o000L0000ob`0o`007?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo6`000?l_0?l001L0003o<@3o000K0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000obh0o`006`000?l_0?l0
01/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00
obX0o`0080000?l[0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooaX0003o;@3o000M0000obl0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6P000?l/0?l001h0003o;`3o000J0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o
000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000ob`0o`00
7P000?l_0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooaX0003o:`3o000P0000obh0o`006P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooa[o003o:P3o000T0000obT0o`006ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6P000?l[0?l00240003o;@3o000J0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l0
02H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ
0000obX0o`008`000?l/0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooaX0003o:P3o000S0000ob`0o`006P000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W0000obP0o`006ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6P000?lZ0?l002@0003o
:`3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolJ0000obX0o`0090000?l[0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJo`00obP0o`00:0000?lX0?l001[o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003o:P3o000U0000obX0o`006P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000
obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6P000?lZ
0?l002D0003o:P3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolJ0000obX0o`009@000?lZ0?l001X0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003o:P3o000U0000obX0o`00
6P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o
9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo6P000?lZ0?l002D0003o:P3o000J0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolJ0000obX0o`0090000?l[0?l001X0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l0
01[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0003o:P3o000T
0000ob/0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo6P000?lZ0?l002@0003o:`3o000J0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000obX0o`0090000?l[0?l001X0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
:0000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooaX0
003o:P3o000S0000ob`0o`006P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obL0o`006ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo6P000?lZ0?l002<0003o;03o000J0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJ0000obX0o`008P000?l]
0?l001X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa/0003o:@3o000R0000ob`0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo6`000?lZ0?l00200003o;@3o000K0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l002H0003o
:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000obX0
o`007`000?l^0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooa/0003o:P3o000O0000obh0o`006`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?lZ0?l001l0003o;P3o000K
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?l[
0?l00240003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolK0000ob/0o`007@000?l_0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolLo`00ob/0o`007`000?l[0?l001_o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooa/0003o;03o000L0000obd0o`007@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;03o000M0000ob/0o`00
7?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?l/0?l001X0
003o;`3o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo7?l00?l]0?l001/0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolM0000ob`0o`0060000?l_0?l001d0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolLo`00obh0o`0060000?l^0?l001co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o;@3o000F0000oc00o`007@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;`3o000E
0000obl0o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7@00
0?l`0?l00180003o<03o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo7?l00?la0?l00140003o<@3o000Mo`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolM0000oc80o`003`000?la0?l001h0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolMo`00oc@0o`002`000?lc0?l001go003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o<P3o000?0000oc40
o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooago
003oL@3o000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolM0000
ocD0o`002`000?lb0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolNo`00og00o`007_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo7@000?li0?l000D0003o<`3o000O0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooah0003oL03o000O0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooah0003oL03o000O0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo7ol00?m^0?l001oo003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooah0003oK`3o000P0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooah0003oK`3o000P0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003oK@3o000Q0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?m[0?l0023o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003oK@3o000Q0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?mZ0?l0027o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003oK@3o000Q0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8_l00?mX0?l002;o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003oK03o000R0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8ol00?mW0?l002;o
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ`3o000R0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8ol00?mV0?l0
02?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ@3o000T
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9?l00?mU
0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003oJ@3o
000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9?l0
0?mT0?l002Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003o
I`3o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
9Ol00?mR0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80
003oI@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo9_l00?mQ0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ob80003oI@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo9ol00?mO0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooob80003oI@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo:?l00?mM0?l002Oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob@0003oHP3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo:?l00?mL0?l002So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooobD0003oH03o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo:Ol00?mK0?l002So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooobD0003oH03o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo:_l00?mI0?l002Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobH0003oGP3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo:ol00?mG0?l002[o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobL0003oG03o000Z0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo;?l00?mE0?l002_o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobP0003oF@3o000/0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo;Ol00?mB0?l002go003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobP0003oF@3o000/0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo;_l00?m@0?l002ko003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooobT0003oE`3o000]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo;ol00?m>0?l002oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooobX0003oE@3o000^0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo<?l00?m<0?l0033o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooobd0003oD@3o000_0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo<_l00?m90?l0037o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobh0003oC`3o000`0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo<ol00?m70?l003;o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00003oC03o000a0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo=Ol00?m30?l003Co003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc80003oB@3o000b0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo=ol00?lo0?l003Ko
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003o@`3o000e0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo>?l00?lm0?l0
03Oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003o@`3o000e
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo>_l00?li
0?l003Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocL0003o@03o
000f0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo??l0
0?ld0?l003co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocT0003o
?03o000h0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
?Ol00?lb0?l003go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocd0
003o=`3o000i0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo@?l00?l]0?l003oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
od40003o<03o000l0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo@ol00?lX0?l0047o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooodD0003o:@3o000o0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
ooooooooooooAOl00?lS0?l004Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooood`0003o7`3o00120000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
ooooooooooooooooBol00?lG0?l004[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooood`0003o7`3o00120000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000ooooooooooooooooDOl00?l;0?l0053o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooookGo00004Ooooone
o`0000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooomE0000o`P0o`00D0000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooodgo003o4`3o001<o`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooom<0000oaT0o`00B0000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooodOo003o7`3o0016o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooom<0000oaT0o`00B0000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooodGo003o903o0013o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooom70000ob40o`00A@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooood;o003o:P3o0010o`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooom40000obP0o`00@@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocoo003o;`3o000no`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooom10000obd0o`00?`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocco003o=@3o000ko`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003oooooooooooooooln0000oc<0o`00?0000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc[o003o>@3o000io`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooooll0000ocL0o`00>P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocWo003o>`3o000h
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolj0000oc/0o`00>000
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocOo003o?`3o
000fo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolj0000oc/0o`00
>0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocGo003o
@`3o000do`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolh0000ocl0
o`00=P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooocCo
003oA@3o000co`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolf0000
od80o`00=@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oc;o003oB03o000bo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooole
0000odH0o`00<P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooc7o003oBP3o000ao`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolb0000odX0o`00<@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooc3o003oC03o000`o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooola0000od`0o`00<0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
oooooooooooooboo003oCP3o000_o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
ooooooooool_0000odl0o`00;`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooobko003oD@3o000]o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
ooooooooooooool^0000oe40o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooobgo003oD`3o000/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003oooooooooooooool^0000oe40o`00;P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooobco003oE@3o000[o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooool]0000oe<0o`00;@000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooob_o003oE`3o000Zo`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolZ0000oeL0o`00;0000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooob[o003oF@3o000Yo`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolY0000oeX0o`00:P000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooobWo003oF`3o000Xo`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolX0000oe`0o`00:@000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooobSo003oG03o000Xo`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolW0000oeh0o`00:0000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooobSo003oG@3o000Wo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolV0000of00o`009`000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobOo003oG`3o000Vo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolU0000of40o`009`000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobKo003oH03o000Vo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolU0000of40o`009`000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobGo003oHP3o000Uo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolU0000of80o`009P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobCo003oH`3o000Uo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolT0000of@0o`009@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobCo003oI03o000T
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolR0000ofH0o`009@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob?o003oIP3o
000So`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolR0000ofL0o`00
90000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob?o003o
IP3o000So`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ofX0
o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob;o
003oJ03o000Ro`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000
ofX0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ob7o003oJ@3o000Ro`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP
0000of`0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooob7o003oJP3o000Qo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolP0000of`0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooob3o003oK03o000Po`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolP0000of`0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooob3o003oK03o000Po`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolO0000ofh0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooaoo003oKP3o000Oo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolO0000ofh0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolO0000ofh0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolN0000og00o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooago003oL@3o000No`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolN0000og00o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooago003o=@3o00070000ocD0o`007_l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?lg0?l000P0003o<@3o000O0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000
ocL0o`0020000?la0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolLo`00oc00o`0050000?l_0?l001go003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooad0003o<`3o000?0000oc00o`007P000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;`3o000F0000obh0o`007Ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?l`0?l001<0003o;`3o
000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l0
0?l]0?l001X0003o;@3o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolM0000obd0o`005`000?l^0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolLo`00ob`0o`0070000?l/0?l001co003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooad0003o:P3o000L0000obd0o`007@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;03o000M0000ob/0
o`007?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?lY0?l0
01h0003o;03o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo7?l00?lZ0?l00200003o:`3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolM0000obP0o`0080000?l[0?l001d0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l001_o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o:@3o000R0000obX0o`007@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o:P3o
000R0000obX0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
6`000?lY0?l00280003o:P3o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo6ol00?lY0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolK0000obT0o`008`000?lY0?l001d0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obX0o`0090000?lY0?l001_o
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o9`3o000V0000
obP0o`007@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo6`000?lW0?l002H0003o:P3o000K0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo6_l00?lY0?l002H0003o:03o000Ko`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolK0000obL0o`009`000?lY0?l001/0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`009`00
0?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa/0003o
9`3o000W0000obT0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
oooooooooooooa[o003o:03o000W0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo6`000?lW0?l002T0003o9`3o000K0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002P0003o:03o000Jo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000obL0o`00:@000?lW0?l0
01/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00
obP0o`00:0000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooa/0003o9`3o000Y0000obL0o`006`000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6`000?lW0?l002T0003o9`3o000K0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o
000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK0000obL0o`00
:@000?lW0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooa/0003o9`3o000Y0000obL0o`006`000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?lW0?l002T0003o9`3o000K0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l0
02T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolK
0000obL0o`00:@000?lW0?l001/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooa/0003o9`3o000W0000obT0o`006`000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6`000?lW0?l002L0003o
:@3o000K0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6_l00?lX0?l002P0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolK0000obL0o`009`000?lW0?l001d0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJo`00obP0o`00:0000?lW0?l001_o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o9@3o000V0000obP0o`007@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W0000
obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?lU
0?l002H0003o:03o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolM0000obD0o`009@000?lY0?l001d0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o9@3o000T0000obX0o`00
7@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o
:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo7@000?lU0?l002@0003o:P3o000M0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6ol00?lY0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolM0000obL0o`008@000?lZ0?l001h0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l0
01_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o9`3o000Q
0000obX0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa_o003o:`3o000Q0000obX0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo7@000?lW0?l00240003o:P3o000N0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo7?l00?l[0?l001l0003o:`3o000Ko`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolN0000obL0o`007`000?l[0?l001h0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00ob`0o`00
7@000?l[0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0
003o9`3o000O0000ob/0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooaco003o;@3o000K0000ob`0o`007?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7P000?lX0?l001d0003o;03o000N0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l^0?l001P0003o;P3o000Lo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000obX0o`006@000?l]
0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolL
o`00obl0o`005@000?l_0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooah0003o:`3o000H0000obd0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooaco003o<@3o000A0000oc40o`007Ol00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7P000?l^0?l001@0003o;P3o000O0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ld0?l000/0003o
<`3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000obh0
o`0050000?l^0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolMo`00og40o`007_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo7`000?l_0?l00140003o;P3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo7_l00?m`0?l001ko003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooal0003o<P3o000>0000obh0o`0080000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolO0000ocH0o`0020000?l`0?l00200003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolNo`00ofl0o`007ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?m]0?l00240003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolOo`00ofh0o`00
7ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m/0?l00240
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolPo`00of`0
o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m[0?l0
0280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolPo`00
of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?m[
0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolQ
o`00of/0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8000
0?m[0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolQo`00ofX0o`008Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
80000?mY0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolRo`00ofP0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo8@000?mX0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolSo`00ofL0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo8@000?mW0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo8P000?mV0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolTo`00ofD0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8P000?mU0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolTo`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo90000?mS0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolUo`00of80o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo90000?mR0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolVo`00of40o`009Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo90000?mR0?l002L0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo9@000?mP0?l002P0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9P000?mO0?l002P0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo9P000?mN0?l002T0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo9`000?mL0?l002X0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:0000?mI0?l002`0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:@000?mG0?l002d0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:P000?mE0?l002h0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool]o`00oe80o`00;Ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:P000?mE0?l002h0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool^o`00oe00o`00
;_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;0000?mB0?l002l0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool_o`00odh0
o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?m?0?l0
0300003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool`o`00
od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;`000?m=
0?l00340003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolb
o`00odT0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<@00
0?m:0?l00380003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolco`00odL0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
=0000?m50?l003@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo=P000?m10?l003H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo>0000?ln0?l003L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolho`00ocd0o`00=ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo>0000?ln0?l003L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003oooooooooooooooljo`00ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo>P000?lj0?l003T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooollo`00oc@0o`00??l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo?P000?lc0?l003`0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolmo`00oc80o`00?Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo@@000?l^0?l003h0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooom0o`00obd0o`00?ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000ooooooooooooooooAP000?lV0?l00440003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooom3o`00obP0o`00@Ol00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000ooooooooooooooooCP000?lG0?l004P0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooom5o`00ob<0o`00A?l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooood_o003o5`3o001:o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000ooooooooooooooooDOl00?l;0?l0053o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooookGo00004Ooooone
o`0000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000ooooooooooooooooCOl00?lC0?l004co003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooom7o`00oal0o`00A_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooodGo003o903o0013o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oom=0000oaH0o`00BP000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooood;o003o:P3o0010o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooom70000ob00o`00AP000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooocoo003o;`3o000no`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooom40000obL0o`00@P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooocco003o=@3o000ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooom10000obd0o`00?`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooc[o003o>@3o000io`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolo0000oc40o`00?@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooocWo003o>`3o000ho`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolm0000ocH0o`00>P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooocOo003o?`3o000fo`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolm0000ocH0o`00>P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooocGo003o@`3o000do`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolj0000oc/0o`00>0000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooocCo003oA@3o000co`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolh0000och0o`00=`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooc;o003oB03o000bo`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolg0000od40o`00=@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooc7o003oBP3o000ao`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooole0000od@0o`00=0000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooc3o003oC03o000`o`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooold0000odL0o`00<P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooboo003oCP3o000_o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooola0000od`0o`00<0000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobko003oD@3o000]o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool`0000odh0o`00;`000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobgo003oD`3o000/o`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool`0000odh0o`00;`000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobco003oE@3o000[
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool_0000oe00o`00;P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob_o003oE`3o
000Zo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool^0000oe80o`00
;@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob[o003o
F@3o000Yo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool/0000oeD0
o`00;0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooobWo
003oF`3o000Xo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolZ0000
oeT0o`00:P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
obSo003oG03o000Xo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolY
0000oe/0o`00:@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooobSo003oG@3o000Wo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolX0000oe`0o`00:@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooobOo003oG`3o000Vo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolW0000oeh0o`00:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooobKo003oH03o000Vo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolW0000oeh0o`00:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooobGo003oHP3o000Uo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolV0000of00o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooobCo003oH`3o000Uo`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolV0000of40o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooobCo003oI03o000To`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolU0000of80o`009P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooob?o003oIP3o000So`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolT0000of@0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooob?o003oIP3o000So`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolT0000of@0o`009@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooob;o003oJ03o000Ro`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolR0000ofL0o`0090000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooob7o003oJ@3o000Ro`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolR0000ofL0o`0090000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooob7o003oJP3o000Qo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolR0000ofL0o`0090000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob3o003oK03o000Po`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ofX0o`008P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob3o003oK03o000Po`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ofX0o`008P000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaoo003oKP3o000Oo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000of`0o`008@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000of`0o`008@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000O
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000ofd0o`008000
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooago003oL@3o
000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO0000ocD0o`00
2P000?l_0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolMo`00ocD0o`001`000?le0?l001ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooal0003o<@3o000@0000obd0o`0080000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooago003o<@3o000?0000oc80o`007Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?la0?l00100003o;@3o000P0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l`0?l0
01@0003o;`3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO
0000obh0o`0050000?l]0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolLo`00obl0o`005P000?l^0?l001go003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooah0003o:`3o000J0000ob/0o`007`000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;@3o000J0000obd0o`007?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?lY0?l001d0003o
:P3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7?l00?l/0?l001`0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolN0000obL0o`0080000?lY0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolLo`00ob`0o`007@000?l[0?l001co003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o9P3o000R0000obT0o`007P000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o:P3o000P0000
ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?lT
0?l002D0003o:03o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolN0000ob@0o`009@000?lX0?l001h0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l001_o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o903o000U0000obP0o`00
7P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o
:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo7@000?lT0?l002L0003o9`3o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lZ0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolM0000ob@0o`00:0000?lV0?l001h0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l0
01_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0003o903o000Z
0000ob@0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo7@000?lT0?l002X0003o903o000N0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolM0000ob<0o`00;0000?lS0?l001h0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
9`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooad0
003o8`3o000/0000ob<0o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7@000?lS0?l002`0003o8`3o000N0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002P0003o:03o000Jo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolM0000ob<0o`00;0000?lS
0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooad0003o8`3o000]0000ob80o`007P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7@000?lS0?l002d0003o8P3o000N0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o
:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolM0000ob<0
o`00;0000?lS0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooad0003o903o000[0000ob<0o`007P000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7@000?lT0?l002/0003o8`3o000N
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW
0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolM0000ob@0o`00:P000?lT0?l001h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooad0003o903o000Z0000ob@0o`007P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000obP0o`00
6_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?lS0?l002X0
003o903o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo6_l00?lX0?l002P0003o9`3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolN0000ob<0o`00:0000?lV0?l001h0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolJo`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o8`3o000X0000obH0o`007P000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W
0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7P00
0?lS0?l002L0003o9`3o000N0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo6_l00?lY0?l002H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolN0000ob<0o`009`000?lW0?l001h0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o8`3o000V0000obL0
o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o
003o:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo7P000?lS0?l002H0003o9`3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolN0000ob<0o`009P000?lW0?l001l0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00ob/0o`008@000?lZ
0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o8`3o
000T0000obP0o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooaco003o:`3o000O0000ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo7`000?lS0?l002<0003o:@3o000O0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO0000obD0o`008@000?lY0?l001l0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00obd0
o`006`000?l/0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oal0003o9P3o000O0000obT0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooaco003o;P3o000H0000obh0o`007?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo7`000?lW0?l001h0003o:@3o000P0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001D0003o;`3o000M
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000obL0o`007000
0?lZ0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolLo`00oc40o`004@000?la0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob00003o:@3o000J0000obX0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooago003o=03o000;0000oc<0o`007Ol00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lY0?l001X0003o:P3o000P0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ma0?l001ko
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o;03o000E0000
ob/0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oako003oL03o000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP
0000obh0o`004P000?l/0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolNo`00ofl0o`007ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo80000?l`0?l00100003o;03o000Q0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob40003o<`3o000:0000obd0o`008P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaoo003oKP3o000Oo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ocH0o`001P000?l^0?l00280
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolPo`00of`0
o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mX0?l0
02@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolPo`00
of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?mX
0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolQ
o`00of/0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@00
0?mX0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolQo`00ofX0o`008Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
8P000?mV0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolRo`00ofP0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo8P000?mV0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolSo`00ofL0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo90000?mS0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo90000?mS0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolTo`00ofD0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo9@000?mQ0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolTo`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo9@000?mP0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolUo`00of80o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo9P000?mO0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolVo`00of40o`009Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo9P000?mO0?l002P0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo9P000?mN0?l002T0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9`000?mL0?l002X0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo:0000?mI0?l002`0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo:@000?mH0?l002`0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:P000?mF0?l002d0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;0000?mC0?l002h0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;@000?mA0?l002l0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool]o`00oe80o`00;Ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;@000?mA0?l002l0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool^o`00oe00o`00
;_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?m?0?l00300
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool_o`00odh0
o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<0000?m;0?l0
0380003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool`o`00
od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<@000?m8
0?l003@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolb
o`00odT0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=000
0?m40?l003D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolco`00odL0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
=P000?m00?l003L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo>0000?lm0?l003P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo?0000?lg0?l003X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolho`00ocd0o`00=ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo?0000?lg0?l003X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003oooooooooooooooljo`00ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo?P000?lb0?l003d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooollo`00oc@0o`00??l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo@P000?l[0?l00400003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolmo`00oc80o`00?Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000ooooooooooooooooA`000?lQ0?l004D0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooom0o`00obd0o`00?ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000ooooooooooooooooD0000?l;0?l00580003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooom3o`00obP0o`00@Ol00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooodGo003o8`3o0014o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
ooooooooooooooooBol00?lG0?l004[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooomAo`00o`/0o`00D?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]Ol0000AoooookGo00002oooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000ooooooooooooooooCOl00?lC0?l004co003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooom7o`00oal0o`00A_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooodGo003o903o0013o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo@_l0
0?lZ0?l0043o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooood`0003o
5`3o001:0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
?ol00?l_0?l003ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooodL0
003o803o00160000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo??l00?le0?l003_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
od@0003o9`3o00120000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo>_l00?li0?l003Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooood40003o;03o00100000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo>Ol00?lk0?l003So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooocl0003o<@3o000m0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo=ol00?lo0?l003Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooocl0003o<@3o000m0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=Ol00?m30?l003Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooocd0003o=P3o000j0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=?l00?m50?l003?o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooocX0003o>P3o000i0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo<_l00?m80?l003;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooocT0003o?@3o000g0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo<Ol00?m:0?l0037o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooocL0003o@@3o000e0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo<?l00?m<0?l0033o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocH0003o@`3o000d0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo;ol00?m>0?l002oo003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooc@0003oA`3o000b0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo;_l00?mA0?l002go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooc80003oBP3o000a0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo;Ol00?mC0?l002co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooc80003oBP3o000a0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;?l00?mE0?l002_o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oC@3o000_0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:ol00?mG0?l002[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oD03o000^0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:_l00?mI0?l002Wo003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobh0003oDP3o000]0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:Ol00?mK0?l002So
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobd0003oE03o000/0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mL0?l0
02So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob`0003oE@3o000/
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mM
0?l002Oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobX0003oF@3o
000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9ol0
0?mO0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0003o
F`3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
9_l00?mP0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0
003oF`3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo9Ol00?mR0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
obP0003oG@3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo9?l00?mS0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooobL0003oGP3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo9?l00?mT0?l002Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooobL0003oG`3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooobH0003oH@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooobD0003oHP3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8_l00?mX0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobD0003oH`3o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8Ol00?mY0?l002;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooob@0003oI03o000U0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo8Ol00?mZ0?l0027o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob@0003oI03o000U0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80003oI`3o000T0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooob80003oI`3o000T0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7ol00?m^0?l001oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooob80003oJ@3o000R0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003oJP3o000R0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003o<`3o000;0000ob`0o`008P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooago003oL@3o
000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000oc00o`00
40000?l/0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolMo`00ocD0o`001`000?le0?l001ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooob00003o;@3o000D0000ob/0o`008@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooago003o<@3o000?0000oc80o`007Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?l]0?l001@0003o:`3o000Q0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l`0?l0
01@0003o;`3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP
0000obT0o`006P000?lY0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolLo`00obl0o`005P000?l^0?l001go003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob00003o9`3o000M0000obT0o`0080000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;@3o000J0000obd0o`007?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?lV0?l00200003o
:03o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7?l00?l/0?l001`0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolO0000ob<0o`0090000?lW0?l00200003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolLo`00ob`0o`007@000?l[0?l001co003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o8P3o000V0000obH0o`0080000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o:P3o000P0000
ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?lR
0?l002L0003o9@3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolO0000ob40o`00:@000?lU0?l001l0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l001_o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o8@3o000Y0000obD0o`00
7`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o
:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo7P000?lR0?l002T0003o9@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lZ0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolN0000ob80o`00:`000?lS0?l001l0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l0
01_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0003o8P3o000/
0000ob80o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo7P000?lQ0?l002h0003o8@3o000O0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ob40o`00;P000?lQ0?l001l0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
9`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooah0
003o8@3o000^0000ob40o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo7P000?lQ0?l002l0003o803o000O0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002P0003o:03o000Jo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ob40o`00;`000?lP
0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooah0003o8@3o000_0000ob00o`007`000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo7P000?lQ0?l002l0003o803o000O0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o
:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolN0000ob40
o`00;`000?lP0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooah0003o8P3o000]0000ob40o`007`000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7P000?lR0?l002d0003o8@3o000O
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW
0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolN0000ob80o`00;@000?lQ0?l001l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?oooooooooooooooah0003o8P3o000]0000ob40o`007`000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000obP0o`00
6_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?lQ0?l002`0
003o8P3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo6_l00?lX0?l002P0003o9`3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolO0000ob40o`00;0000?lR0?l001l0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolJo`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o8@3o000[0000ob<0o`007`000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W
0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`00
0?lQ0?l002T0003o9@3o000O0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo6_l00?lY0?l002H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolO0000ob40o`00:@000?lT0?l00200003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o8@3o000X0000obD0
o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o
003o:@3o000T0000obT0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo7`000?lQ0?l002P0003o9@3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o000Ko`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooolO0000ob40o`00:0000?lU0?l00200003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00ob/0o`008@000?lZ
0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o8@3o
000V0000obH0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
oooooooooaco003o:`3o000O0000ob/0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo80000?lQ0?l002D0003o9`3o000P0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000ob40o`009@000?lW0?l00200
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00obd0
o`006`000?l/0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ob00003o8P3o000S0000obL0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?oooooooooooooooaco003o;P3o000H0000obh0o`007?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo80000?lT0?l00240003o9`3o000Q0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001D0003o;`3o000M
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ob@0o`007`00
0?lX0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolLo`00oc40o`004@000?la0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob40003o9P3o000M0000obP0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooago003o=03o000;0000oc<0o`007Ol00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?lV0?l001d0003o:03o000Q0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ma0?l001ko
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003o9`3o000K0000
obP0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oako003oL03o000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ
0000ob/0o`005`000?lX0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolNo`00ofl0o`007ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8P000?l/0?l001<0003o:03o000T0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80003o;P3o000@0000obT0o`0090000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaoo003oKP3o000Oo`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooolR0000oc80o`002`000?lZ0?l002@0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolPo`00of`0
o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P000?ld0?l0
00P0003o:P3o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo8?l00?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooob@0003oI03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo8Ol00?m[0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob@0003oI03o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8Ol00?mZ0?l0027o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob@0003oH`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8_l00?mX0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooob@0003oH`3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8ol00?mW0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobD0003oH@3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobD0003oH@3o000W0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo9?l00?mU0?l002?o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobH0003oG`3o000X0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo9?l00?mT0?l002Co003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobH0003oGP3o000Y0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo9Ol00?mR0?l002Go003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooobL0003oG@3o000Y0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo9_l00?mQ0?l002Go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooobL0003oG@3o000Y0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo9ol00?mO0?l002Ko003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooobP0003oF`3o000Z0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mM0?l002Oo003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0003oF03o000/0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mL0?l002So003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobT0003oE`3o000]0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:Ol00?mK0?l002So003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobX0003oE@3o000^0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:_l00?mI0?l002Wo
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob`0003oDP3o000_0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:ol00?mG0?l0
02[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobh0003oC`3o000`
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;?l00?mE
0?l002_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oC@3o
000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;Ol0
0?mB0?l002go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003o
C@3o000a0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
;_l00?m@0?l002ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00
003oB`3o000b0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo;ol00?m>0?l002oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
oc80003oA`3o000d0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo<?l00?m<0?l0033o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooc@0003o@`3o000f0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo<_l00?m90?l0037o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooocH0003o@03o000g0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo<ol00?m70?l003;o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooocP0003o?03o000i0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=Ol00?m30?l003Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooc`0003o=@3o000l0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=ol00?lo0?l003Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?oooooooooooooooch0003o<@3o000n0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo>?l00?lm0?l003Oo003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?oooooooooooooooch0003o<@3o000n0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo>_l00?li0?l003Wo003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooood80003o:@3o00120000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo??l00?ld0?l003co003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooodL0003o7@3o00190000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo?Ol00?lb0?l003go003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?oooooooooooooooe80003o0P3o001I0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo@?l00?l]0?l003oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooom3o`00obP0o`00@Ol00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?ooooooooooooooodGo003o8`3o0014o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
ooooooooooooooooBol00?lG0?l004[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooomAo`00o`/0o`00D?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
ojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo]Ol0000AoooookGo00002oooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000ooooooooooooooooCOl00?lC0?l004co003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooom7o`00oal0o`00A_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooodGo003o903o0013o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo@_l0
0?lZ0?l0043o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooe@0003o
103o001E0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
?ol00?l_0?l003ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooodX0
003o5`3o001<0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo??l00?le0?l003_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
odL0003o7`3o00170000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo>_l00?li0?l003Wo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooood@0003o9@3o00140000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo>Ol00?lk0?l003So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooood40003o;03o00100000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo=ol00?lo0?l003Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
oooooooooooood40003o;03o00100000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo=Ol00?m30?l003Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooocl0003o<03o000n0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo=?l00?m50?l003?o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooocd0003o=03o000l0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo<_l00?m80?l003;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooocX0003o>P3o000i0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo<Ol00?m:0?l0037o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooocT0003o?@3o000g0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo<?l00?m<0?l0033o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooocL0003o@03o000f0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo;ol00?m>0?l002oo003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooocH0003o@`3o000d0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo;_l00?mA0?l002go003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003oAP3o000b0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo;Ol00?mC0?l002co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooocD0003oAP3o000b0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo;?l00?mE0?l002_o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc80003oBP3o000a0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:ol00?mG0?l002[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc40003oC03o000`0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:_l00?mI0?l002Wo003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc00003oCP3o000_0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:Ol00?mK0?l002So
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobl0003oD03o000^0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mL0?l0
02So003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobh0003oDP3o000]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo:?l00?mM
0?l002Oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobd0003oE03o
000/0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo9ol0
0?mO0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob`0003o
E`3o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
9_l00?mP0?l002Ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob`0
003oE`3o000Z0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo9Ol00?mR0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
obX0003oFP3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo9?l00?mS0?l002Go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooobT0003oF`3o000Y0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo9?l00?mT0?l002Co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooobP0003oG@3o000X0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooobL0003oG`3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo8ol00?mV0?l002?o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooobL0003oG`3o000W0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo8_l00?mX0?l002;o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooobH0003oH@3o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo8Ol00?mY0?l002;o003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooobD0003oHP3o000V0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo8Ol00?mZ0?l0027o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobD0003oHP3o000V0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooobD0003oH`3o000U0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo8?l00?m/0?l0023o003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooob@0003oI03o000U0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7ol00?m^0?l001oo003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003o=@3o00020000obh0o`0090000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolR0000oc<0o`002P000?lZ
0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolN
o`00ofl0o`007ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P00
0?l_0?l000l0003o:@3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo7Ol00?ma0?l001ko003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooob80003o;03o000E0000obP0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?oooooooooooooooago003o=@3o00070000ocD0o`007_l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?lX0?l001/0003o9`3o000R0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000
obP0o`006`000?lW0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolLo`00oc00o`0050000?l_0?l001go003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooob40003o9@3o000O0000obH0o`008P000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;`3o000F0000obh0o`007Ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?lS0?l00240003o9`3o
000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l0
0?l]0?l001X0003o;@3o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooolP0000ob80o`0090000?lV0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolLo`00ob`0o`0070000?l/0?l001co003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooob00003o8@3o000V0000obD0o`008@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;03o000M0000ob/0
o`007?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lP0?l0
02P0003o903o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo7?l00?lZ0?l00200003o:`3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolP0000oal0o`00:P000?lS0?l00240003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l001_o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7`3o000/0000ob80o`008000
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o:P3o
000R0000obX0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
80000?lO0?l002`0003o8P3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo6ol00?lY0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolO0000ob00o`00;@000?lQ0?l00200003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obX0o`0090000?lY0?l001_o
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o803o000]0000
ob40o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo7`000?lP0?l002h0003o803o000P0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo6_l00?lY0?l002H0003o:03o000Ko`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolO0000oal0o`00<0000?lO0?l00200003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`009`00
0?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooal0003o
7`3o000`0000oal0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
oooooooooooooa[o003o:03o000W0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo7`000?lO0?l00340003o7P3o000P0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002P0003o:03o000Jo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO0000oal0o`00<@000?lN0?l0
0200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00
obP0o`00:0000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
oooooal0003o7`3o000a0000oah0o`0080000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7`000?lP0?l00300003o7P3o000P0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o
000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO0000ob00o`00
<0000?lN0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooooooooal0003o803o000`0000oah0o`0080000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?lP0?l00300003o7P3o000P0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l0
02T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolO
0000ob00o`00;`000?lO0?l00200003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooal0003o803o000_0000oal0o`0080000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o9`3o000Y0000obP0o`006_l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7`000?lP0?l002l0003o
7`3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6_l00?lX0?l002P0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolO0000ob00o`00;P000?lP0?l00200003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJo`00obP0o`00:0000?lW0?l001_o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7`3o000^0000ob00o`0080000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W0000
obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lO
0?l002d0003o8@3o000P0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolP0000oal0o`00;0000?lR0?l00200003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7`3o000/0000ob40o`00
8@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o
:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo80000?lO0?l002X0003o8`3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6ol00?lY0?l002@0003o:@3o000Ko`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolP0000oal0o`00:P000?lS0?l00240003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolKo`00obX0o`008P000?lZ0?l0
01_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7`3o000Z
0000ob<0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa_o003o:`3o000Q0000obX0o`006ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8@000?lN0?l002T0003o903o000Q0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo7?l00?l[0?l001l0003o:`3o000Ko`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000oal0o`009`000?lU0?l00240003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00ob`0o`00
7@000?l[0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40
003o7`3o000W0000obD0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooaco003o;@3o000K0000ob`0o`007?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo8@000?lP0?l002D0003o9@3o000R0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l^0?l001P0003o;P3o000Lo`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000ob40o`0090000?lU
0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolL
o`00obl0o`005@000?l_0?l001go003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob80003o8P3o000Q0000obH0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooaco003o<@3o000A0000oc40o`007Ol00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo8P000?lS0?l00200003o9P3o000R0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo7Ol00?ld0?l000/0003o
<`3o000Mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolR0000ob<0
o`0080000?lV0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolMo`00og40o`007_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo8P000?lT0?l001h0003o9@3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo7_l00?m`0?l001ko003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooob80003o9P3o000L0000obD0o`0090000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolT0000obP0o`005`000?lV0?l002@0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolNo`00ofl0o`007ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo90000?lZ0?l001D0003o
9@3o000U0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
7ol00?m^0?l001oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0
003o;03o000A0000obL0o`009@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooob3o003oK03o000Po`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolU0000obl0o`0030000?lW0?l002H0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolPo`00of`0o`008?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo9@000?la0?l000T0003o:03o000V0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?m[0?l0023o003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobD0003o<@3o00090000obP0o`009P00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob7o003oJP3o
000Qo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolU0000ocH0o`00
0P000?lY0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolRo`00ofP0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo9P000?mP0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolSo`00ofL0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo9P000?mO0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo9`000?mN0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolTo`00ofD0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo9`000?mM0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolTo`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo:0000?mK0?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolUo`00of80o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo:0000?mI0?l002`0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolVo`00of40o`009Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo:0000?mI0?l002`0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo:@000?mH0?l002`0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo:P000?mF0?l002d0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo;0000?mC0?l002h0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo;@000?mA0?l002l0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?m?0?l00300003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;`000?m=0?l00340003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<0000?m;0?l00380003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool]o`00oe80o`00;Ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<0000?m;0?l00380003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool^o`00oe00o`00
;_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<P000?m60?l003D0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool_o`00odh0
o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=@000?m20?l0
03H0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool`o`00
od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=P000?lo
0?l003P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolb
o`00odT0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>000
0?ll0?l003T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolco`00odL0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
?0000?ld0?l003d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo?P000?l`0?l003l0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo@@000?lW0?l004D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolho`00ocd0o`00=ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo@@000?lW0?l004D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003oooooooooooooooljo`00ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooAP000?lJ0?l004d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooollo`00oc@0o`00??l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooocgo003o<P3o000mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo@?l00?l]0?l003oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom3o`00
obP0o`00@Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooodGo003o8`3o0014
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooBol00?lG0?l004[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooomAo`00o`/0o`00D?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Ooo
ool000[ooooo]Ol0000AoooookGo00002oooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooo
oooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooo
ooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooo
ooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo
00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
oooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@00
0?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000ooooooooooooooooCOl00?lC0?l004co003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooom7o`00oal0o`00A_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooodGo003o903o0013o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo@_l0
0?lZ0?l0043o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooloo`00obl0o`00
?_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooD@000?l:0?l00580
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooollo`00ocD0
o`00>ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooBP000?lG0?l0
04`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooljo`00
ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooAP000?lP
0?l004L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooooli
o`00oc/0o`00>?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo@P00
0?lW0?l004@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
@P000?lW0?l004@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo@0000?l]0?l00400003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
ooooooooooldo`00odD0o`00<ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo?P000?la0?l003h0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolbo`00odP0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo?@000?ld0?l003`0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolao`00odX0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo>P000?lj0?l003T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003oooooooooooooool`o`00od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo>@000?lm0?l003L0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003oooooooooooooool_o`00odh0o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo=`000?m00?l003H0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003oooooooooooooool^o`00oe40o`00;Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo=P000?m30?l003@0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003oooooooooooooool]o`00oe<0o`00;?l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo=P000?m30?l003@0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo=@000?m60?l00380003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo=0000?m80?l00340003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo<@000?m<0?l00300003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<0000?m>0?l002l0003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;`000?m@0?l002h0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?mB0?l002d0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;@000?mD0?l002`0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolVo`00of00o`00
9_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;@000?mD0?l002`0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolUo`00of80
o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;0000?mG0?l0
02X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolTo`00
of<0o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:P000?mJ
0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolT
o`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:P00
0?mJ0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
:@000?mL0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo:0000?mM0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolRo`00ofP0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo9`000?mO0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolQo`00ofT0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo9`000?mO0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolQo`00ofX0o`008Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo9`000?mO0?l002L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolPo`00of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo9P000?mQ0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolPo`00of`0o`008?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo9@000?mR0?l002H0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolOo`00ofh0o`007ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo9@000?l`0?l000X0003o:@3o000U0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003o;@3o000@0000obL0o`009@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000O
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolT0000obX0o`005@00
0?lV0?l002@0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolMo`00og40o`007_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
90000?lV0?l001X0003o9@3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co
0000oooooooooooooooo7Ol00?le0?l000L0003o=@3o000No`00o`Cooooo00?o0000ooooooooool0
3oooool01?l0003ooooooooooooooolR0000obD0o`007P000?lT0?l002@0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolMo`00oc40o`003`000?lb0?l001go
003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003o9@3o000N0000
ob@0o`0090000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooo
oaco003o<03o000D0000obl0o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo8P000?lR0?l00280003o8`3o000T0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo7?l00?l_0?l001H0003o;P3o000Mo`00o`Cooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolR0000oal0o`009@000?lU0?l00280003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00obd0o`006P00
0?l]0?l001co003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob40003o
7`3o000W0000ob@0o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
oooooooooooooaco003o;03o000L0000ob`0o`007?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo8@000?lN0?l002T0003o8`3o000R0000o`?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00Co0000oooooooooooooooo7?l00?l/0?l001d0003o:`3o000Lo`00o`Co
oooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000oah0o`00:P000?lR0?l0
0280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolLo`00
obX0o`0080000?l[0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
ooooob40003o7@3o000]0000ob00o`008P000?l3ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo80000?lN0?l002h0003o7`3o000R0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?lZ0?l00280003o:P3o
000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP0000oah0o`00
;P000?lO0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`00
0?ooooooooooooooob00003o7P3o000_0000oal0o`008@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?oooooooooooooooa[o003o:P3o000T0000obT0o`006ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lN0?l002l0003o7`3o000Q0000
o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l0
02H0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolP
0000oah0o`00<0000?lN0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolJo`00obT0o`009P000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob00003o7P3o000a0000oad0o`008@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000W0000obP0o`006ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lN0?l00340003o
7@3o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo
6_l00?lX0?l002L0003o:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooolP0000oah0o`00<P000?lL0?l00240003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolJo`00obP0o`00:0000?lX0?l001[o003o1?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7P3o000b0000oa`0o`008@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o:03o000X0000
obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo80000?lN
0?l00380003o703o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooo
oooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolP0000oah0o`00<P000?lL0?l00240003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l001[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7P3o000b0000oa`0o`00
8@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooa[o003o
9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo80000?lN0?l00380003o703o000Q0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo
00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooolP0000oah0o`00<P000?lL0?l00240003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obL0o`00:@000?lX0?l0
01[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00003o7P3o000a
0000oad0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
oooooa[o003o9`3o000Y0000obP0o`006_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo80000?lN0?l00340003o7@3o000Q0000o`?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00Co0000oooooooooooooooo6_l00?lW0?l002T0003o:03o000Jo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolP0000oah0o`00<@000?lM0?l00240003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJo`00obP0o`00
:0000?lX0?l001[o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob00
003o7P3o000`0000oah0o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?oooooooooooooooa[o003o:03o000X0000obL0o`006ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo80000?lN0?l00300003o7P3o000Q0000o`?ooooo00?o0000oooo
ooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lX0?l002L0003o:03o000Ko`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000oad0o`00;`000?lO
0?l00240003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolJ
o`00obP0o`009`000?lX0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob40003o7@3o000^0000ob00o`008@000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?oooooooooooooooa[o003o:@3o000V0000obP0o`006ol00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo8@000?lM0?l002h0003o7`3o000R0000o`?ooooo
00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6_l00?lY0?l002H0003o
:03o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQ0000oad0
o`00;@000?lP0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolKo`00obT0o`0090000?lY0?l001_o003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooob40003o7@3o000]0000ob00o`008P000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?oooooooooooooooa_o003o:P3o000R0000obX0o`006ol00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8@000?lM0?l002d0003o803o000R
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo6ol00?l[
0?l00240003o:P3o000Ko`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolR0000oa`0o`00:`000?lR0?l00280003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolLo`00ob/0o`007`000?l[0?l001_o003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooob80003o7@3o000Y0000ob<0o`008P000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;03o000M0000ob/0o`00
7?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8P000?lM0?l002T0
003o8`3o000R0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo7?l00?l]0?l001/0003o;03o000Lo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooolR0000oah0o`009`000?lR0?l002@0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolLo`00obh0o`0060000?l^0?l001co003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooob80003o7P3o000W0000ob80o`0090000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooaco003o;`3o000E
0000obl0o`007Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9000
0?lM0?l002D0003o8`3o000T0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo7?l00?la0?l00140003o<@3o000Mo`00o`Cooooo00?o0000ooooooooool03ooo
ool01?l0003ooooooooooooooolT0000oah0o`0090000?lS0?l002@0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolMo`00oc@0o`002`000?lc0?l001go003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob@0003o7P3o000T0000ob<0
o`0090000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooago
003oL@3o000No`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolT0000
ob40o`0080000?lS0?l002D0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolNo`00og00o`007_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo90000?lR0?l001l0003o8`3o000U0000o`?ooooo00?o0000ooooooooool02Oooool0
00[ooooo00Co0000oooooooooooooooo7_l00?m_0?l001oo003o1?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooobD0003o903o000K0000ob@0o`009@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?oooooooooooooooako003oK`3o000Oo`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooolU0000obL0o`0060000?lS0?l002H0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolOo`00ofh0o`00
7ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9@000?lY0?l001D0
003o903o000V0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo8?l00?m/0?l0023o003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
obH0003o:P3o000C0000ob<0o`009`000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04
o`000?ooooooooooooooob3o003oK03o000Po`00o`Cooooo00?o0000ooooooooool03oooool01?l0
003ooooooooooooooolV0000obh0o`003@000?lU0?l002L0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolQo`00of/0o`008?l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9P000?l^0?l000d0003o9@3o000W0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo8Ol00?mZ0?l0027o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobH0003o<03o000:0000obD0o`00
:0000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooob;o003o
J03o000Ro`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolW0000oc80
o`001@000?lW0?l002P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolSo`00ofL0o`008_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooooooo9`000?mM0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolSo`00ofH0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo:0000?mL0?l002T0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooolTo`00ofD0o`008ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo:0000?mK0?l002X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooolTo`00of@0o`009?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo:@000?mH0?l002`0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooolUo`00of80o`009Ol00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo:P000?mF0?l002d0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooolVo`00of40o`009Ol00?l4ooooo`03o`000?oooooooooo00oo
oooo00Co0000oooooooooooooooo:P000?mF0?l002d0003o0oooool00ol0003oooooooooo`09oooo
o`002_ooool01?l0003ooooooooooooooolWo`00oel0o`009_l00?l4ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooooooo:P000?mF0?l002d0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooolXo`00oed0o`009ol00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo;0000?mC0?l002h0003o0oooool00ol0003ooooooooo
o`09ooooo`002_ooool01?l0003ooooooooooooooolXo`00oe`0o`00:?l00?l4ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooooooo;@000?mA0?l002l0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooolYo`00oe/0o`00:?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo;P000?m?0?l00300003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolZo`00oeT0o`00:Ol00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;`000?m=0?l00340003o0oooool00ol0
003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool[o`00oeL0o`00:_l00?l4oooo
o`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<@000?m80?l003@0003o0oooool0
0ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool/o`00oeD0o`00:ol00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<P000?m60?l003D0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool]o`00oe80o`00;Ol0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<P000?m60?l003D0003o
0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool^o`00oe00o`00
;_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=@000?m20?l003H0
003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool_o`00odh0
o`00;ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=P000?lo0?l0
03P0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003oooooooooooooool`o`00
od`0o`00<?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>0000?lk
0?l003X0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooolb
o`00odT0o`00<Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>P00
0?lf0?l003d0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooo
oolco`00odL0o`00<_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
?P000?l^0?l00440003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
ooooooleo`00od<0o`00=?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo
oooo@@000?lU0?l004L0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooo
oooooooooolgo`00ocl0o`00=_l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
ooooooooA@000?lH0?l00500003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooolho`00ocd0o`00=ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
ooooooooooooA@000?lH0?l00500003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003oooooooooooooooljo`00ocT0o`00>Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooCP000?l40?l005/0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool0
1?l0003ooooooooooooooollo`00oc@0o`00??l00?l4ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oo
ooooooooooooocgo003o<P3o000mo`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo@?l00?l]0?l003oo003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooom3o`00
obP0o`00@Ol00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooodGo003o8`3o0014
o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o
0000ooooooooool02Oooool000[ooooo00Co0000ooooooooooooooooBol00?lG0?l004[o003o1?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003ooooo
ooooo`09ooooo`002_ooool01?l0003ooooooooooooooomAo`00o`/0o`00D?l00?l4ooooo`03o`00
0?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04
o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003o
oooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]
0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooooooo
o`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_oo
ool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooo
oooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooo
oooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09
ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000
oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo
[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o
1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003o
ooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000oooooooo
ool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[o
oooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`000?oooooooooo
ooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0ooo
ool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o
0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000ooooooooool0
2Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:ooooo`04o`00
0?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooo
ojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooooooooon/o`00
o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?ooooo00?o0000
ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0003ooooooooo
oooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon]0000o`?o
oooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l00?l4ooooo`03
o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003oooooooooo`0?oooo
o`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`002_ooool01?l0
003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00Co0000oooooooooooooooo[?l0
0?l4ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo[@000?l3ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`04o`000?ooooooooooooooojco003o1?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooooooojd0003o0oooool00ol0003oooooooooo`09ooooo`00
2_ooool01?l0003ooooooooooooooon/o`00o`Cooooo00?o0000ooooooooool03oooool01?l0003o
oooooooooooooon]0000o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0/Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Ooo
ool000[ooooo]Ol0000AoooookGo00002oooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom>0000o`h0o`00D@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooc[o003o>@3o000io`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom90000oaP0o`00C0000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocWo003o>`3o000h
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom50000ob40o`00A`00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocOo003o?`3o
000fo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom50000ob40o`00
A`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocGo003o
@`3o000do`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom20000obL0
o`00A0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocCo
003oA@3o000co`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom00000
obd0o`00@0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oc;o003oB03o000bo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oooln
0000oc40o`00?P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooc7o003oBP3o000ao`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
ooll0000ocL0o`00>P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?oooc3o003oC03o000`o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolj0000ocX0o`00>@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooboo003oCP3o000_o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3oooli0000ocd0o`00=`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooobko003oD@3o000]o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooolg0000od40o`00=@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooobgo003oD`3o000/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolg0000od40o`00=@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?ooobco003oE@3o000[o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolf0000od<0o`00=0000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooob_o003oE`3o000Zo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooole0000odH0o`00<P000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooob[o003oF@3o000Yo`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooold0000odP0o`00<@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooobWo003oF`3o000Xo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolb0000od/0o`00<0000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobSo003oG03o000Xo`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooola0000odd0o`00;`000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobSo003oG@3o000Wo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool`0000odl0o`00;P000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobOo003oG`3o000Vo`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool_0000oe40o`00;@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobKo003oH03o000Vo`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool_0000oe40o`00;@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobGo003oHP3o000Uo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool^0000oe<0o`00;0000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobCo003oH`3o000Uo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool]0000oeH0o`00:P000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobCo003oI03o000T
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool/0000oeL0o`00:P00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003oIP3o
000So`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000oeX0o`00
:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003o
IP3o000So`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000oe`0
o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob;o
003oJ03o000Ro`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000
oe`0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ob7o003oJ@3o000Ro`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX
0000oeh0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooob7o003oJP3o000Qo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oolX0000oeh0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolW0000oel0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolW0000obl0o`002@000?lX0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolOo`00ofh0o`007ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo9P000?l/0?l000l0003o9P3o000V0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7_l00?m_0?l001oo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o:@3o000D0000ob@0o`009P000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000O
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000obL0o`006000
0?lT0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolMo`00og40o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
9@000?lR0?l001h0003o8`3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo7Ol00?le0?l000L0003o=@3o000No`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolT0000ob00o`008P000?lR0?l002D0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolMo`00oc40o`003`000?lb0?l001go
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o803o000R0000
ob80o`009@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oaco003o<03o000D0000obl0o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo90000?lM0?l002H0003o8@3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo7?l00?l_0?l001H0003o;P3o000Mo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolT0000oa/0o`00:0000?lR0?l002@0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00obd0o`006P00
0?l]0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob80003o
703o000Z0000ob40o`0090000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooaco003o;03o000L0000ob`0o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo8P000?lL0?l002/0003o803o000T0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l/0?l001d0003o:`3o000Lo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oa/0o`00;P000?lN0?l0
02@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00
obX0o`0080000?l[0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooob80003o6`3o000_0000oad0o`0090000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa_o003o:P3o000R0000obX0o`006ol00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo8@000?lL0?l00300003o703o000T0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?lZ0?l00280003o:P3o
000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolQ0000oa`0o`00
<0000?lL0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolKo`00obT0o`0090000?lY0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooob40003o703o000a0000oad0o`008P000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:P3o000T0000obT0o`006ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8@000?lL0?l00380003o703o000R0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l0
02H0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolQ
0000oa`0o`00<P000?lL0?l00280003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooob40003o703o000c0000oa/0o`008P000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000W0000obP0o`006ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8@000?lL0?l003<0003o
6`3o000R0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
6_l00?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolQ0000oa`0o`00=0000?lJ0?l00280003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00:0000?lX0?l001[o003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40003o703o000d0000oaX0o`008P000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000X0000
obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8@000?lL
0?l003@0003o6P3o000R0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolQ0000oa`0o`00=0000?lJ0?l00280003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40003o703o000d0000oaX0o`00
8P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o
9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo8@000?lL0?l003@0003o6P3o000R0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolQ0000oa`0o`00=0000?lJ0?l00280003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l0
01[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40003o703o000c
0000oa/0o`008P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo8@000?lL0?l003<0003o6`3o000R0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolQ0000oa`0o`00<`000?lK0?l00280003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00
:0000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40
003o703o000b0000oa`0o`008P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooa[o003o:03o000X0000obL0o`006ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo8@000?lL0?l00380003o703o000R0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002L0003o:03o000Ko`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolQ0000oa`0o`00<@000?lM
0?l00280003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJ
o`00obP0o`009`000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooob80003o6`3o000`0000oah0o`008P000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooa[o003o:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lK0?l00300003o7P3o000R0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o
:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oa/0
o`00;`000?lM0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolKo`00obT0o`0090000?lY0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooob80003o6`3o000^0000oah0o`0090000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:P3o000R0000obX0o`006ol00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lK0?l002h0003o7P3o000T
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?l[
0?l00240003o:P3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oolR0000oa/0o`00;P000?lN0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooolLo`00ob/0o`007`000?l[0?l001_o003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooob@0003o6P3o000[0000ob00o`0090000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;03o000M0000ob/0o`00
7?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lJ0?l002/0
003o803o000T0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo7?l00?l]0?l001/0003o;03o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooolT0000oaX0o`00:P000?lQ0?l002@0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolLo`00obh0o`0060000?l^0?l001co003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o6`3o000Y0000ob00o`009@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;`3o000E
0000obl0o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@00
0?lK0?l002L0003o8@3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo7?l00?la0?l00140003o<@3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooolU0000oa`0o`009P000?lQ0?l002D0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolMo`00oc@0o`002`000?lc0?l001go003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o703o000V0000ob40
o`009@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooago
003oL@3o000No`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000
oad0o`0090000?lR0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolNo`00og00o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo9P000?lO0?l00240003o8@3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo7_l00?m_0?l001oo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobH0003o8@3o000N0000ob80o`009P000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000ob<0o`0070000?lQ0?l002L0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolOo`00ofh0o`00
7ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lV0?l001P0
003o8P3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo8?l00?m/0?l0023o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
obL0003o9`3o000F0000ob80o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolW0000obX0o`004P000?lR0?l002P0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolQo`00of/0o`008?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo9`000?lZ0?l00180003o8P3o000X0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ0?l0027o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o;@3o000?0000ob40o`00
:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob;o003o
J03o000Ro`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX0000obh0
o`002`000?lS0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolSo`00ofL0o`008_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo:0000?l`0?l000P0003o8`3o000Z0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo8ol00?mV0?l002?o003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobT0003oFP3o000Z0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo9?l00?mU0?l002?o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobX0003oE`3o000/0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo9?l00?mT0?l002Co003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooobX0003oEP3o000]0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo9Ol00?mR0?l002Go003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0003oD`3o000^0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9_l00?mQ0?l002Go003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0003oD`3o000^0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9ol00?mO0?l002Ko003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0003oDP3o000^0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mM0?l002Oo003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003oD03o000_0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mL0?l002So003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003oCP3o000`0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:Ol00?mK0?l002So003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc00003oB`3o000b0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:_l00?mI0?l002Wo
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc40003oB03o000d0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:ol00?mG0?l0
02[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc80003oAP3o000e
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;?l00?mE
0?l002_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocD0003o@@3o
000g0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;Ol0
0?mB0?l002go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocD0003o
@@3o000g0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
;_l00?m@0?l002ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocH0
003o?`3o000h0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo;ol00?m>0?l002oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ocP0003o>`3o000j0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo<?l00?m<0?l0033o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooocX0003o=@3o000n0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo<_l00?m90?l0037o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooocd0003o;P3o00120000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo<ol00?m70?l003;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?oood00003o803o001=0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo=Ol00?m30?l003Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooodD0003o5P3o001B0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo=ol00?lo0?l003Ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooodX0003o2P3o001I0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo>?l00?lm0?l003Oo003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooodX0003o2P3o001I0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooollo`00oc@0o`00??l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooocgo003o<P3o000mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo@?l00?l]0?l003oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooom3o`00
obP0o`00@Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooodGo003o8`3o0014
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0ooooBol00?lG0?l004[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooomAo`00o`/0o`00D?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3o
ool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool02@3o
ool000X0oooo]Ol0000A0?oookGo00002`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooodd0003o3`3o001A0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>Ol00?lk0?l003So003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooodL0003o6P3o001<0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo=ol00?lo0?l003Ko003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooodL0003o6P3o001<0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo=Ol00?m30?l003Co003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooodD0003o8@3o00170000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo=?l00?m50?l003?o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oood40003o:03o00140000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo<_l00?m80?l0
03;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocl0003o;P3o0010
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo<Ol00?m:
0?l0037o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooch0003o<P3o
000m0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo<?l0
0?m<0?l0033o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc`0003o
=`3o000j0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
;ol00?m>0?l002oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocX0
003o>`3o000h0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo;_l00?mA0?l002go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ocT0003o?@3o000g0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo;Ol00?mC0?l002co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooocT0003o?@3o000g0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo;?l00?mE0?l002_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooocL0003o@@3o000e0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo:ol00?mG0?l002[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooocH0003o@`3o000d0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo:_l00?mI0?l002Wo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooocD0003oAP3o000b0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo:Ol00?mK0?l002So003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?oooc@0003oB03o000a0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo:?l00?mL0?l002So003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?oooc80003oB`3o000`0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo:?l00?mM0?l002Oo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oooc40003oC@3o000_0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo9ol00?mO0?l002Ko003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?oooc00003oC`3o000^0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo9_l00?mP0?l002Ko003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc00003oC`3o000^0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9Ol00?mR0?l002Go003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003oD@3o000]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l00?mS0?l002Go003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003oD`3o000/0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l00?mT0?l002Co003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003oD`3o000/0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8ol00?mV0?l002?o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0003oEP3o000Z0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8ol00?mV0?l002?o003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0003oF03o000Y0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8_l00?mX0?l002;o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobX0003oFP3o000Y0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mY0?l0
02;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003oG03o000X
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ
0?l0027o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003oG03o
000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8?l0
0?m/0?l0023o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003o
;@3o00090000obH0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolX0000obX0o`003`000?lU0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolOo`00ofh0o`007ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo9`000?lY0?l001<0003o8`3o000W0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7_l00?m_0?l001oo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o9P3o000G0000ob80o`009`000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000O
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000ob80o`007@00
0?lR0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolMo`00og40o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
9P000?lN0?l00280003o8@3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo7Ol00?le0?l000L0003o=@3o000No`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolU0000oa`0o`009P000?lP0?l002H0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolMo`00oc40o`003`000?lb0?l001go
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o703o000V0000
ob00o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oaco003o<03o000D0000obl0o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo9@000?lJ0?l002P0003o8@3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo7?l00?l_0?l001H0003o;P3o000Mo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oaT0o`00:P000?lP0?l002D0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00obd0o`006P00
0?l]0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o
6@3o000/0000oal0o`009@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooaco003o;03o000L0000ob`0o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo90000?lI0?l002h0003o7@3o000U0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l/0?l001d0003o:`3o000Lo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolT0000oaP0o`00<0000?lL0?l0
02D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00
obX0o`0080000?l[0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooob80003o6P3o000a0000oa/0o`009@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa_o003o:P3o000R0000obX0o`006ol00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lJ0?l00380003o6P3o000U0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?lZ0?l00280003o:P3o
000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaX0o`00
<P000?lJ0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolKo`00obT0o`0090000?lY0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooob80003o6P3o000c0000oaT0o`009@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:P3o000T0000obT0o`006ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lJ0?l003@0003o6@3o000T0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l0
02H0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR
0000oaX0o`00=0000?lI0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooob80003o6P3o000e0000oaP0o`0090000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000W0000obP0o`006ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lJ0?l003L0003o
5P3o000T0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
6_l00?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolQ0000oa/0o`00=`000?lF0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00:0000?lX0?l001[o003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40003o6`3o000g0000oaH0o`0090000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000X0000
obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8@000?lK
0?l003L0003o5P3o000T0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolQ0000oa/0o`00=`000?lF0?l002@0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob40003o6`3o000g0000oaH0o`00
90000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o
9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo8P000?lJ0?l003L0003o5P3o000T0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolR0000oaX0o`00=`000?lF0?l002@0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l0
01[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob80003o6P3o000e
0000oaP0o`0090000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo8P000?lJ0?l003D0003o603o000T0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaX0o`00=@000?lH0?l002@0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00
:0000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob80
003o6P3o000d0000oaT0o`0090000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooa[o003o:03o000X0000obL0o`006ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo8P000?lJ0?l003@0003o6@3o000T0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002L0003o:03o000Ko`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaX0o`00<`000?lJ
0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJ
o`00obP0o`009`000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooob80003o6P3o000b0000oa/0o`0090000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooa[o003o:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lH0?l00380003o6`3o000T0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o
:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolT0000oaP0
o`00<@000?lL0?l002@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolKo`00obT0o`0090000?lY0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooob@0003o603o000`0000oa`0o`009@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:P3o000R0000obX0o`006ol00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lH0?l00300003o703o000U
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?l[
0?l00240003o:P3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oolT0000oaT0o`00;`000?lL0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooolLo`00ob/0o`007`000?l[0?l001_o003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooobD0003o603o000^0000oad0o`009@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;03o000M0000ob/0o`00
7?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lH0?l002h0
003o7@3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo7?l00?l]0?l001/0003o;03o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooolU0000oaP0o`00;0000?lO0?l002D0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolLo`00obh0o`0060000?l^0?l001co003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o6@3o000[0000oal0o`009@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;`3o000E
0000obl0o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P00
0?lI0?l002T0003o7`3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo7?l00?la0?l00140003o<@3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooolV0000oaT0o`00:@000?lO0?l002H0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolMo`00oc@0o`002`000?lc0?l001go003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o6@3o000Y0000oal0
o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooago
003oL@3o000No`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000
oa/0o`009P000?lP0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolNo`00og00o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo9`000?lK0?l002D0003o7`3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo7_l00?m_0?l001oo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobL0003o7P3o000Q0000ob00o`009`000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolW0000ob00o`007`000?lP0?l002L0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolOo`00ofh0o`00
7ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9`000?lR0?l001`0
003o803o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo8?l00?m/0?l0023o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
obP0003o9@3o000H0000ob00o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolX0000obL0o`005@000?lP0?l002T0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolQo`00of/0o`008?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo:0000?lW0?l001D0003o803o000Y0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ0?l0027o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003o:03o000C0000ob00o`00
:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob;o003o
J03o000Ro`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000ob/0
o`003`000?lP0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolSo`00ofL0o`008_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo:P000?l/0?l000d0003o7P3o000/0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo8ol00?mV0?l002?o003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobX0003o;P3o00090000ob00o`00;0000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobCo003oI@3o000So`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool/0000obl0o`0010000?lQ0?l002d0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00of@0o`009?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;0000?mC0?l002h0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolUo`00of80o`00
9Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?mA0?l002l0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolVo`00of40
o`009Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?mA0?l0
02l0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolWo`00
oel0o`009_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;P000?m?
0?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolX
o`00oed0o`009ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;`00
0?m=0?l00340003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolXo`00oe`0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
<0000?m;0?l00380003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolYo`00oe/0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo<@000?m80?l003@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolZo`00oeT0o`00:Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo<P000?m60?l003D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3oool[o`00oeL0o`00:_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo=@000?m10?l003L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3oool/o`00oeD0o`00:ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo=P000?lo0?l003P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3oool]o`00oe80o`00;Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo=P000?lo0?l003P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3oool^o`00oe00o`00;_l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo>0000?li0?l003`0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3oool_o`00odh0o`00;ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo>P000?ld0?l003l0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3oool`o`00od`0o`00<?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo?@000?lW0?l004T0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolbo`00odT0o`00<Ol00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo@0000?lN0?l004l0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolco`00odL0o`00<_l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0ooooA0000?lE0?l005@0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooleo`00od<0o`00=?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooB@000?l;0?l005T0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocSo003o?@3o000go`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooollo`00oc@0o`00??l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooocgo003o<P3o000mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo@?l00?l]0?l003oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooom3o`00
obP0o`00@Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooodGo003o8`3o0014
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0ooooBol00?lG0?l004[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooomAo`00o`/0o`00D?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3o
ool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool02@3o
ool000X0oooo]Ol0000A0?oookGo00002`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolio`00oc/0o`00>?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooBP000?lC0?l00500003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0ooooBP000?lC0?l00500003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooleo`00od<0o`00=?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooA`000?lJ0?l004`0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooldo`00odD0o`00<ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooA0000?lR0?l004L0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolbo`00odP0o`00<_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo@@000?lZ0?l00480003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolao`00odX0o`00<Ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?`000?l_0?l003l0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool`o`00od`0o`00<?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?P000?lb0?l003d0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool_o`00odh0o`00
;ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lg0?l003X0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool^o`00oe40
o`00;Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>P000?lk0?l0
03P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool]o`00
oe<0o`00;?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>P000?lk
0?l003P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool/
o`00oeD0o`00:ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>@00
0?lm0?l003L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
ool[o`00oeL0o`00:_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
=`000?m10?l003D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolZo`00oeT0o`00:Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo=P000?m30?l003@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolYo`00oe/0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo=@000?m60?l00380003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolXo`00oe`0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo=@000?m70?l00340003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolXo`00oed0o`009ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo=0000?m90?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooolWo`00oel0o`009_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo<P000?m<0?l002l0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolVo`00of00o`009_l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo<P000?m<0?l002l0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolUo`00of80o`009Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo<@000?m>0?l002h0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolTo`00of<0o`009Ol00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo<0000?m@0?l002d0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00of@0o`009?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo;`000?mB0?l002`0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolSo`00ofH0o`008ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo;P000?mC0?l002`0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolSo`00ofH0o`008ol00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?mF0?l002X0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolRo`00ofP0o`008_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?mF0?l002X0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolQo`00ofT0o`008_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;0000?l[0?l000P0003o9@3o000Y
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ
0?l0027o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0003o:`3o
00080000obD0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolZ0000obX0o`003@000?lS0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo:@000?lW0?l001<0003o8P3o000X0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7ol00?m^0?l001oo003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003o9@3o000F0000ob40o`00:0000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX0000ob40o`0070000?lQ
0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolN
o`00ofl0o`007ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9`00
0?lN0?l00240003o803o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo7Ol00?ma0?l001ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooobL0003o6P3o000V0000oal0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?oooago003o=@3o00070000ocD0o`007_l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lI0?l002T0003o7`3o000V0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000
oaT0o`00:@000?lO0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolLo`00oc00o`0050000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobH0003o5`3o000[0000oal0o`009P000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;`3o000F0000obh0o`007Ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lF0?l002d0003o7P3o
000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l0
0?l]0?l001X0003o;@3o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolU0000oaL0o`00;`000?lL0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolLo`00ob`0o`0070000?l/0?l001co003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o5@3o000b0000oa/0o`009P000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;03o000M0000ob/0
o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lE0?l0
03<0003o6P3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo7?l00?lZ0?l00200003o:`3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolT0000oaH0o`00=0000?lI0?l002H0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l001_o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000e0000oaP0o`009P00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:P3o
000R0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
90000?lF0?l003D0003o603o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolT0000oaH0o`00=P000?lG0?l002H0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obX0o`0090000?lY0?l001_o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000g0000
oaH0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oa[o003o:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo90000?lF0?l003L0003o5P3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o:03o000Ko`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaP0o`00>@000?lD0?l002H0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`009`00
0?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob80003o
603o000j0000oa<0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooa[o003o:03o000W0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo8P000?lH0?l003X0003o4`3o000V0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002P0003o:03o000Jo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaP0o`00>P000?lC0?l0
02H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00
obP0o`00:0000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooob80003o603o000j0000oa<0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lH0?l003/0003o4P3o000V0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o
000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR0000oaP0o`00
>P000?lD0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooob80003o603o000j0000oa@0o`009@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo8P000?lH0?l003X0003o503o000U0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l0
02T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolR
0000oaP0o`00>@000?lE0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000i0000oaD0o`009@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lF0?l003T0003o
5@3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
6_l00?lX0?l002P0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolT0000oaH0o`00=`000?lG0?l002D0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00:0000?lW0?l001_o003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000g0000oaL0o`009@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000W0000
obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lF
0?l003H0003o603o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo6_l00?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolT0000oaH0o`00=@000?lI0?l002D0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000e0000oaT0o`00
9@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o
:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo9@000?lE0?l003@0003o6P3o000U0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolU0000oaD0o`00<`000?lK0?l002D0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l0
01_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o5@3o000c
0000oa/0o`009@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooa_o003o:`3o000Q0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo9@000?lG0?l00340003o6P3o000V0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l[0?l001l0003o:`3o000Ko`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oaL0o`00<0000?lK0?l002H0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00ob`0o`00
7@000?l[0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0
003o5P3o000_0000oa`0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooaco003o;@3o000K0000ob`0o`007?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo9P000?lF0?l002l0003o703o000V0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l^0?l001P0003o;P3o000Lo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000oaL0o`00;0000?lN
0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolL
o`00obl0o`005@000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobL0003o5P3o000/0000oah0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooaco003o<@3o000A0000oc40o`007Ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo9`000?lG0?l002X0003o7P3o000W0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?ld0?l000/0003o
<`3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolW0000oaL0
o`00:P000?lN0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolMo`00og40o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo9`000?lH0?l002T0003o7P3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo7_l00?m`0?l001ko003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobP0003o603o000X0000oah0o`009`000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX0000oaX0o`009@000?lN0?l002P0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolNo`00ofl0o`007ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:0000?lM0?l00280003o
7P3o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
7ol00?m^0?l001oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0
003o7P3o000O0000oah0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooolY0000ob40o`0070000?lN0?l002T0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo:@000?lT0?l001T0003o7@3o000Z0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?m[0?l0023o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003o903o000I0000oad0o`00:P00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob7o003oJP3o
000Qo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000obD0o`00
5P000?lN0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolRo`00ofP0o`008_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo:P000?lW0?l001@0003o703o000/0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo8ol00?mW0?l002;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooob`0003o:03o000@0000oad0o`00;0000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003oIP3o000So`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3oool/0000obT0o`003`000?lL0?l002d0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00ofD0o`008ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?lZ0?l000`0003o703o
000^0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l0
0?mT0?l002Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003o
:`3o00080000oad0o`00;`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooobGo003oHP3o000Uo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3oool^0000obh0o`0010000?lM0?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolVo`00of40o`009Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo;P000?l^0?l000@0003o7@3o000`0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9ol00?mO0?l002Ko003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003oC@3o000a0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mM0?l002Oo003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc00003oB`3o000b0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mL0?l002So003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc40003oB03o000d0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:Ol00?mK0?l002So003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc80003oAP3o000e0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:_l00?mI0?l002Wo
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocD0003o@@3o000g0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:ol00?mG0?l0
02[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocH0003o?`3o000h
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;?l00?mE
0?l002_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocP0003o>@3o
000l0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;Ol0
0?mB0?l002go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocP0003o
>@3o000l0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
;_l00?m@0?l002ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocT0
003o=03o00100000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo;ol00?m>0?l002oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ocd0003o8@3o001?0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo<?l00?m<0?l0033o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooocl0003o7@3o001A0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo<_l00?m90?l0037o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oood80003o5P3o001E0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo<ol00?m70?l003;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooodL0003o3@3o001I0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo=Ol00?m30?l003Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ocSo003o?@3o000go`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li
0?l003Wo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooollo`00oc@0o`00??l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocgo003o<P3o000mo`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@?l00?l]0?l003oo003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooom3o`00obP0o`00@Ol00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?ooodGo003o8`3o0014o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0ooooBol00?lG0?l004[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooomAo`00o`/0o`00D?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0
/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo]Ol0000A0?oookGo00002`3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolio`00oc/0o`00>?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0ooooC`000?l70?l005L0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0ooooC`000?l70?l005L0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooleo`00od<0o`00=?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooB@000?lD0?l00500003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooldo`00odD0o`00<ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooAP000?lM0?l004X0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolbo`00odP0o`00<_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo@P000?lT0?l004L0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolao`00odX0o`00<Ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo@0000?l[0?l00480003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool`o`00od`0o`00<?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?`000?l_0?l003l0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool_o`00odh0o`00
;ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?@000?lc0?l003d0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool^o`00oe40
o`00;Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lg0?l0
03X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool]o`00
oe<0o`00;?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lg
0?l003X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool/
o`00oeD0o`00:ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>P00
0?lk0?l003P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
ool[o`00oeL0o`00:_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
>@000?ln0?l003H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolZo`00oeT0o`00:Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo>0000?m00?l003D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolYo`00oe/0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo=`000?m20?l003@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolXo`00oe`0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo=P000?m60?l00340003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolXo`00oed0o`009ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo=@000?m80?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooolWo`00oel0o`009_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo=0000?m90?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolVo`00of00o`009_l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo=0000?m90?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolUo`00of80o`009Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo<P000?m<0?l002l0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolTo`00of<0o`009Ol00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo<@000?m>0?l002h0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00of@0o`009?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo<@000?m?0?l002d0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolSo`00ofH0o`008ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo<0000?mA0?l002`0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolSo`00ofH0o`008ol00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;`000?mB0?l002`0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolRo`00ofP0o`008_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;P000?lZ0?l000P0003o8`3o000Z0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mY0?l0
02;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0003o:03o000<
0000ob80o`00:P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooob7o003oJP3o000Qo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
ool]0000obP0o`0030000?lR0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo;@000?lT0?l00180003o8@3o000Y0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo8?l00?m/0?l0023o003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0003o8`3o000E0000ob00o`00:@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaoo003oKP3o000Oo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000ob00o`006`000?lP0?l0
02P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolNo`00
ofl0o`007ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:@000?lM
0?l00200003o7`3o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo7_l00?m_0?l001oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobT0003o603o000V0000oah0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooago003oL@3o000No`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooolX0000oaH0o`00:P000?lM0?l002P0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolMo`00ocD0o`001`000?le0?l001ko003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobP0003o5@3o000[0000oah0
o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooago
003o<@3o000?0000oc80o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo:0000?lE0?l002/0003o7P3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo7?l00?l`0?l001@0003o;`3o000Mo`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooolW0000oaD0o`00;@000?lM0?l002L0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00obl0o`005P000?l^
0?l001go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o4`3o
000a0000oa/0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?oooaco003o;@3o000J0000obd0o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo9P000?lD0?l00380003o6P3o000W0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l/0?l001`0003o;03o000Lo`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000oa<0o`00=0000?lI0?l002L0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00ob`0
o`007@000?l[0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
obD0003o503o000e0000oaP0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?oooaco003o:P3o000P0000ob/0o`006ol00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo9@000?lD0?l003H0003o5`3o000W0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?lZ0?l00280003o:P3o000K
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oa@0o`00=`00
0?lF0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolKo`00obX0o`008P000?lZ0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooobD0003o503o000g0000oaH0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?oooa_o003o:@3o000T0000obT0o`006ol00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lD0?l003P0003o5@3o000W0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lZ0?l002@0
003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolT0000
oaD0o`00>P000?lC0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooob@0003o5@3o000k0000oa80o`009`000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:@3o000V0000obP0o`006ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lE0?l003/0003o4P3o
000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l0
0?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolT0000oaD0o`00?0000?lA0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolJo`00obP0o`009`000?lX0?l001_o003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5@3o000l0000oa40o`009`000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000X0000obP0
o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo90000?lE0?l0
03d0003o403o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo6_l00?lX0?l002P0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolT0000oaD0o`00?@000?l@0?l002L0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000l0000oa00o`009`00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o
000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
90000?lF0?l003`0003o403o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolT0000oaH0o`00>`000?lA0?l002L0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o5P3o000k0000
oa40o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo90000?lF0?l003/0003o4P3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o000Jo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolT0000oaH0o`00>P000?lC0?l002H0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obL0o`00:@00
0?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob@0003o
5P3o000j0000oa<0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooa[o003o:03o000X0000obP0o`006_l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo90000?lF0?l003T0003o503o000V0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002P0003o9`3o000Ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oaD0o`00>@000?lD0?l0
02H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00
obP0o`009`000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooobD0003o5@3o000g0000oaH0o`009P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa[o003o:03o000W0000obP0o`006ol00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lE0?l003H0003o5`3o000V0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o:03o
000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oaD0o`00
=@000?lH0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolJo`00obT0o`009P000?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooobH0003o503o000e0000oaP0o`009P000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:@3o000T0000obT0o`006ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lD0?l003@0003o6@3o000V0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6ol00?lZ0?l0
0280003o:P3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV
0000oa@0o`00=0000?lI0?l002H0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolKo`00ob/0o`008@000?lZ0?l001_o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobH0003o503o000c0000oaX0o`009P000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o:`3o000O0000ob/0o`006ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lD0?l003<0003o
6P3o000V0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
7?l00?l/0?l001d0003o:`3o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolW0000oa<0o`00<P000?lJ0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolLo`00obd0o`006`000?l/0?l001co003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o4`3o000b0000oaX0o`009`000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;P3o000H0000
obh0o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9`000?lE
0?l002l0003o6`3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo7?l00?l_0?l001D0003o;`3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolX0000oa@0o`00;`000?lK0?l002L0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00oc40o`004@000?la0?l001go003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobP0003o5@3o000/0000oad0o`00
9`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooago003o
=03o000;0000oc<0o`007Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo:0000?lE0?l002`0003o7@3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo7Ol00?ma0?l001ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooobP0003o5P3o000[0000oa`0o`00:0000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oL03o000No`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000oaH0o`00:@000?lM0?l002P0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolNo`00ofl0o`007ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:@000?lG0?l002P0003o703o
000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7_l0
0?m_0?l001oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0003o
6@3o000V0000oa`0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooaoo003oKP3o000Oo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolZ0000oa/0o`008P000?lM0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo:P000?lN0?l001l0003o703o000Z0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8?l00?m/0?l0023o003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobX0003o803o000M0000oa`0o`00:P000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob7o003oJ`3o000P
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000ob00o`007@00
0?lL0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolQo`00ofX0o`008Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
;0000?lQ0?l001T0003o6`3o000/0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo8_l00?mX0?l002;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooob`0003o8`3o000G0000oaX0o`00;@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003oI`3o000Ro`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3oool]0000ob@0o`0050000?lK0?l002d0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolSo`00ofH0o`008ol00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?lW0?l00140003o6P3o000^
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l00?mU
0?l002?o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003o9`3o
000@0000oaT0o`00;`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooobCo003oI03o000To`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3oool_0000obP0o`003@000?lI0?l00300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolUo`00of80o`009Ol00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo;`000?lY0?l000`0003o603o000a0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9_l00?mQ0?l002Go003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003o:@3o000<0000oaP0o`00<@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobOo003oG`3o000Vo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool`0000ob/0o`002@000?lG
0?l00380003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolX
o`00oed0o`009ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo<@00
0?l[0?l000L0003o5P3o000d0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo:?l00?mL0?l002So003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?oooc80003o:`3o00060000oaD0o`00=@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooobWo003oF`3o000Xo`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooole0000obT0o`001@000?lC0?l003L0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolZo`00oeT0o`00:Ol00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=P000?lX0?l000H0003o403o000i0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:ol00?mG0?l0
02[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocP0003o9P3o0008
0000o`/0o`00?0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooobco003oE@3o000[o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
ooli0000ob@0o`00D0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooobgo003oDP3o000]o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3oooli0000ob@0o`00D0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooobko003oD03o000^o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3oooll0000ob00o`00D@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooboo003oCP3o000_o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3oooln0000oa/0o`00E0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?oooc3o003oC03o000`o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooom10000oaH0o`00EP000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooc;o003oB@3o000ao`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooom60000o`h0o`00F@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooc?o003oA`3o000bo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo=Ol00?m30?l003Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ocSo003o?@3o000go`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li
0?l003Wo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooollo`00oc@0o`00??l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocgo003o<P3o000mo`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@?l00?l]0?l003oo003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooom3o`00obP0o`00@Ol00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?ooodGo003o8`3o0014o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0ooooBol00?lG0?l004[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooomAo`00o`/0o`00D?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03
o`00003oool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0
/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003o
ool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo]Ol0000A0?oookGo00002`3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolio`00oc/0o`00>?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooocOo003o?`3o000fo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo=Ol00?m30?l003Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooodd0003o2`3o001E0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo=?l00?m50?l003?o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooodL0003o5`3o001?0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo<_l00?m80?l003;o003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooodD0003o703o001<0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo<Ol00?m:0?l0037o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?oood80003o903o00170000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo<?l00?m<0?l0033o003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?oood00003o:`3o00120000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo;ol00?m>0?l002oo003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?oooch0003o<03o000o0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;_l00?mA0?l002go003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocd0003o=03o000l0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;Ol00?mC0?l002co003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocd0003o=03o000l0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo;?l00?mE0?l002_o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc`0003o>03o000i0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:ol00?mG0?l002[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocX0003o?03o000g0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:_l00?mI0?l002Wo003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocT0003o?P3o000f0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:Ol00?mK0?l002So
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocP0003o@03o000e0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mL0?l0
02So003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocL0003oA03o000b
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo:?l00?mM
0?l002Oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocH0003oAP3o
000a0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9ol0
0?mO0?l002Ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocD0003o
B03o000`0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
9_l00?mP0?l002Ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooocD0
003oB03o000`0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo9Ol00?mR0?l002Go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ocD0003oB@3o000_0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo9?l00?mS0?l002Go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?oooc@0003oBP3o000_0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo9?l00?mT0?l002Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?oooc80003oC@3o000^0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo8ol00?mV0?l002?o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?oooc40003oC`3o000]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo8ol00?mV0?l002?o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?oooc40003o9`3o00080000ob00o`00;@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooob;o003oJ03o000Ro`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3oool`0000obH0o`002`000?lP0?l002`0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolQo`00ofT0o`008_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;`000?lS0?l00140003o803o000Z
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ
0?l0027o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003o8`3o
000A0000ob00o`00:P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3oool^0000ob80o`0050000?lO0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo;P000?lO0?l001P0003o7P3o000Z0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7ol00?m^0?l001oo003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0003o6`3o000N0000oah0o`00:@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool/0000oaH0o`009@000?lM
0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolN
o`00ofl0o`007ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:P00
0?lD0?l002X0003o703o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo7Ol00?ma0?l001ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooobT0003o4`3o000/0000oad0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?oooago003o=@3o00070000ocD0o`007_l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:@000?lA0?l002l0003o703o000X0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000
oa40o`00;`000?lL0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolLo`00oc00o`0050000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobP0003o4@3o000b0000oaX0o`00:0000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;`3o000F0000obh0o`007Ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:0000?lA0?l003<0003o6@3o
000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l0
0?l]0?l001X0003o;@3o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolW0000oa40o`00=@000?lH0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolLo`00ob`0o`0070000?l/0?l001co003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o4@3o000f0000oaL0o`00:0000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;03o000M0000ob/0
o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lB0?l0
03L0003o5P3o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo7?l00?lZ0?l00200003o:`3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolV0000oa80o`00>0000?lE0?l002P0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l001_o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o4P3o000i0000oa@0o`00:000
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:P3o
000R0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
9P000?lB0?l003T0003o503o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolV0000oa80o`00>`000?lB0?l002P0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obX0o`0090000?lY0?l001_o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o4`3o000l0000
oa40o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oa[o003o:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo9@000?lC0?l003d0003o403o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o:03o000Ko`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oa<0o`00?P000?l?0?l002P0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`009`00
0?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o
4`3o000n0000o`l0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooa[o003o:03o000W0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo9@000?lD0?l003h0003o3P3o000X0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002P0003o:03o000Jo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oa@0o`00?P000?l>0?l0
02P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00
obP0o`00:0000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooobD0003o503o000n0000o`h0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lD0?l003h0003o3P3o000X0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o
000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU0000oa@0o`00
?P000?l>0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooobD0003o503o000n0000o`h0o`00:0000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lD0?l003d0003o3`3o000X0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l0
02T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolU
0000oa@0o`00?@000?l?0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobD0003o503o000l0000oa00o`00:0000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lD0?l003`0003o
403o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
6_l00?lX0?l002P0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolU0000oa@0o`00>`000?lB0?l002L0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00:0000?lW0?l001_o003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobD0003o503o000k0000oa80o`009`000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000W0000
obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lC
0?l003X0003o4`3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo6_l00?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolV0000oa<0o`00>0000?lE0?l002L0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o4`3o000g0000oaH0o`00
9`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o
:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo9P000?lC0?l003L0003o5P3o000W0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolW0000oa80o`00=P000?lG0?l002L0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l0
01_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o4P3o000f
0000oaL0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooa_o003o:`3o000Q0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo9`000?lB0?l003D0003o603o000W0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l[0?l001l0003o:`3o000Ko`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolW0000oa80o`00=@000?lH0?l002L0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00ob`0o`00
7@000?l[0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobP0
003o4@3o000d0000oaT0o`009`000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooaco003o;@3o000K0000ob`0o`007?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo:0000?lA0?l003<0003o6@3o000X0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l^0?l001P0003o;P3o000Lo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX0000oa40o`00<`000?lI
0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolL
o`00obl0o`005@000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobT0003o4@3o000a0000oaX0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooaco003o<@3o000A0000oc40o`007Ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo:@000?lA0?l00340003o6P3o000X0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?ld0?l000/0003o
<`3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000oa40
o`00<@000?lJ0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolMo`00og40o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo:@000?lC0?l002d0003o6`3o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo7_l00?m`0?l001ko003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobX0003o4`3o000/0000oa/0o`00:@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000oaD0o`00:P000?lK0?l002T0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolNo`00ofl0o`007ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:P000?lF0?l002P0003o
6`3o000Z0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
7ol00?m^0?l001oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooob`0
003o5P3o000V0000oa/0o`00:P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3oool/0000oaX0o`008P000?lI0?l002`0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo;@000?lK0?l001l0003o6P3o000/0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?m[0?l0023o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0003o6`3o000O0000oaX0o`00;000
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob7o003oJP3o
000Qo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool]0000oal0o`00
6`000?lI0?l002d0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolRo`00ofP0o`008_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo;@000?lQ0?l001T0003o6@3o000]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo8ol00?mW0?l002;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooobh0003o8@3o000H0000oaP0o`00;P000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003oIP3o000So`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3oool_0000ob80o`005@000?lH0?l002l0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00ofD0o`008ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;`000?lU0?l00180003o5`3o
000`0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l0
0?mT0?l002Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc00003o
9@3o000A0000oaH0o`00<@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooobGo003oHP3o000Uo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooola0000obD0o`0040000?lE0?l00380003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolVo`00of40o`009Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo<@000?lU0?l00100003o5@3o000b0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9ol00?mO0?l002Ko003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc80003o9@3o000?0000oa<0o`00=0000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobSo003oG@3o000W
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooold0000ob@0o`003P00
0?lB0?l003D0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolXo`00oe`0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
=@000?lT0?l000h0003o3`3o000g0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo:Ol00?mK0?l002So003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooocH0003o8`3o000>0000o`d0o`00>@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooob[o003oF@3o000Yo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolg0000ob80o`0040000?l80?l003`0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool[o`00oeL0o`00:_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>@000?lP0?l005@0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool/o`00oeD0o`00:ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lM0?l005@0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool]o`00oe80o`00;Ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lM0?l005@0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool^o`00oe00o`00
;_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo?P000?lJ0?l005D0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool_o`00odh0
o`00;ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo@0000?lF0?l0
05L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oool`o`00
od`0o`00<?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0ooooA@000?l?
0?l005T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolb
o`00odT0o`00<Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooc?o003oA`3o
000bo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo=Ol00?m30?l003Co003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolgo`00ocl0o`00=_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocSo003o?@3o000go`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooollo`00oc@0o`00??l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooocgo003o<P3o000mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo@?l00?l]0?l003oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooom3o`00
obP0o`00@Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooodGo003o8`3o0014
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0ooooBol00?lG0?l004[o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooomAo`00o`/0o`00D?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3o
ool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`0?0?ooo`03o`00
003oool0oooo0;40oooo00?o00000?ooo`3oool02@3oool000X0oooo00?o00000?ooo`3oool0/@3o
ool00ol00000oooo0?ooo`0?0?ooo`03o`00003oool0oooo0;40oooo00?o00000?ooo`3oool02@3o
ool000X0oooo]Ol0000A0?oookGo00002`3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
1 0 0 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
0 0 1 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF00000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF0000FF00000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo
00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000
oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000
oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo
00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?oo
o`2a0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04
o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0ooooCOl00?lC0?l004co003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooom7o`00oal0o`00A_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooodGo003o903o0013o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3o
oon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo@_l0
0?lZ0?l0043o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooloo`00obl0o`00
?_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooocco003o=@3o000ko`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo>_l00?li0?l003Wo003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolio`00oc/0o`00>?l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?ooocOo003o?`3o000fo`00o`@0oooo00?o00000?ooo`3oool03`3o
ool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo=Ol00?m30?l003Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3oooldo`00odD0o`00<ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0ooooBP000?l?0?l005@0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolbo`00odP0o`00<_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0ooooAP000?lH0?l004l0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolao`00odX0o`00<Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0ooooA0000?lM0?l004`0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool0
1?l00000oooo0?ooo`3oool`o`00od`0o`00<?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo@@000?lU0?l004L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3oool_o`00odh0o`00;ol00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo@0000?l[0?l00480003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3oool^o`00oe40o`00;Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo?P000?la0?l003h0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3oool]o`00oe<0o`00;?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo?P000?la0?l003h0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3oool/o`00oeD0o`00:ol00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo?@000?ld0?l003`0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3oool[o`00oeL0o`00:_l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo?0000?lh0?l003T0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolZo`00oeT0o`00:Ol00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>P000?ll0?l003L0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolYo`00oe/0o`00:?l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>@000?ln0?l003H0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolXo`00oe`0o`00:?l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo>0000?m10?l003@0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolXo`00oed0o`009ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=`000?m40?l00380003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolWo`00oel0o`009_l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=`000?m50?l00340003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolVo`00of00o`00
9_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=`000?m50?l00340
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolUo`00of80
o`009Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=P000?m70?l0
0300003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00
of<0o`009Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=@000?m9
0?l002l0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolT
o`00of@0o`009?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo=@00
0?m90?l002l0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolSo`00ofH0o`008ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
=0000?lU0?l000L0003o7`3o000^0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo8ol00?mV0?l002?o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?oooc@0003o8P3o000=0000oad0o`00;@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooob;o003oJ03o000Ro`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolb0000ob80o`0040000?lL0?l002d0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolQo`00ofT0o`008_l00?l40?oo
o`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo<@000?lO0?l001D0003o703o000/
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?mZ
0?l0027o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc40003o7`3o
000E0000oa`0o`00;0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooola0000oad0o`005`000?lL0?l002`0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo<0000?lI0?l001d0003o7@3o000Z0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7ol00?m^0?l001oo003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobl0003o5@3o000S0000oa`0o`00:P000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool^0000o`l0o`00:`000?lK
0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolN
o`00ofl0o`007ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@00
0?l=0?l002h0003o703o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo7Ol00?ma0?l001ko003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003o
ool0oooo0?ooob`0003o303o000a0000oa/0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?oooago003o=@3o00070000ocD0o`007_l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:P000?l>0?l003<0003o6@3o000Y0000o`<0
oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?la0?l000l0
003o<P3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000
o`h0o`00<`000?lI0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooolLo`00oc00o`0050000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooobX0003o3@3o000e0000oaP0o`00:@000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;`3o000F0000obh0o`007Ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo:@000?l>0?l003H0003o5`3o
000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l0
0?l]0?l001X0003o;@3o000Lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooolX0000o`l0o`00=`000?lF0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooolLo`00ob`0o`0070000?l/0?l001co003o103oool00ol00000oooo
0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobP0003o3`3o000h0000oaD0o`00:@000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooaco003o;03o000M0000ob/0
o`007?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9`000?l@0?l0
03T0003o503o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3o
ool0oooo7?l00?lZ0?l00200003o:`3o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l0
0000oooo0?ooo`3ooolW0000oa00o`00>P000?lC0?l002T0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l001_o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o403o000l0000oa40o`00:@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa_o003o:P3o
000R0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
9`000?l@0?l003`0003o4@3o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooolV0000oa40o`00?@000?l@0?l002T0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obX0o`0090000?lY0?l001_o
003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o4@3o000n0000
o`l0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
oa[o003o:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo9P000?lA0?l003l0003o3P3o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool0
00X0oooo00Co00000?ooo`3oool0oooo6_l00?lY0?l002H0003o:03o000Ko`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000oa80o`00?`000?l=0?l002T0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`009`00
0?lX0?l001_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o
4P3o00100000o`/0o`00:P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?oooa[o003o:03o000W0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo9P000?lB0?l00400003o2`3o000Z0000o`<0oooo00?o00000?ooo`3o
ool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lX0?l002P0003o:03o000Jo`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000oa80o`00@@000?l:0?l0
02X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00
obP0o`00:0000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo
0?ooobH0003o4P3o00110000o`X0o`00:P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03o`00003oool0
oooo00l0oooo00Co00000?ooo`3oool0oooo9@000?lC0?l00440003o2P3o000Z0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l002T0003o:03o
000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV0000oa80o`00
@@000?l:0?l002X0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooobH0003o4P3o00100000o``0o`00:@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l00?l40?ooo`03
o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lB0?l00400003o303o000Y0000
o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo6_l00?lW0?l0
02T0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolV
0000oa80o`00?`000?l=0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3ooolJo`00obL0o`00:@000?lX0?l001[o003o103oool00ol00000oooo0?ooo`0?
0?ooo`04o`00003oool0oooo0?ooobH0003o4P3o000n0000o`h0o`00:@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o9`3o000Y0000obP0o`006_l0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lB0?l003h0003o
3P3o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
6_l00?lX0?l002P0003o:03o000Jo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolV0000oa80o`00?P000?l>0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolJo`00obP0o`00:0000?lW0?l001_o003o103oool00ol00000
oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobH0003o4P3o000m0000oa00o`00:0000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o:03o000W0000
obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo9P000?lB
0?l003`0003o4@3o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?oo
o`3oool0oooo6_l00?lX0?l002L0003o:03o000Ko`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooolW0000oa40o`00>`000?lB0?l002P0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolJo`00obT0o`009P000?lX0?l001_o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobL0003o4@3o000i0000oa@0o`00
:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooa[o003o
:@3o000V0000obP0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo9`000?lA0?l003P0003o5@3o000X0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo6ol00?lY0?l002@0003o:@3o000Ko`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooolX0000oa00o`00>0000?lE0?l002P0003o0`3oool00ol0
0000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolKo`00obX0o`008P000?lZ0?l0
01_o003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobP0003o403o000h
0000oaD0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?oooa_o003o:`3o000Q0000obX0o`006ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo:0000?l@0?l003L0003o5P3o000X0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l[0?l001l0003o:`3o000Ko`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolX0000oa00o`00=P000?lG0?l002P0003o
0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolLo`00ob`0o`00
7@000?l[0?l001co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobT0
003o3`3o000f0000oaL0o`00:0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?oooaco003o;@3o000K0000ob`0o`007?l00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo:@000?l?0?l003D0003o603o000X0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7?l00?l^0?l001P0003o;P3o000Lo`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolY0000o`l0o`00=@000?lH
0?l002P0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolL
o`00obl0o`005@000?l_0?l001go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooobX0003o3`3o000c0000oaP0o`00:@000?l30?ooo`03o`00003oool0oooo00T0oooo000:
0?ooo`04o`00003oool0oooo0?oooaco003o<@3o000A0000oc40o`007Ol00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo:P000?l?0?l003<0003o603o000Y0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo7Ol00?ld0?l000/0003o
<`3o000Mo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooolZ0000o`l0
o`00<`000?lH0?l002T0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo
0?ooo`3ooolMo`00og40o`007_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo;0000?l>0?l00340003o6@3o000Y0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo7_l00?m`0?l001ko003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooob`0003o403o000_0000oaP0o`00:P000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooako003oK`3o000Oo`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool/0000oa40o`00;0000?lJ0?l002X0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolNo`00ofl0o`007ol0
0?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo;@000?lA0?l002/0003o
6P3o000Z0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
7ol00?m^0?l001oo003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobd0
003o4`3o000Y0000oaP0o`00;0000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooob3o003oK03o000Po`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000
oooo0?ooo`3oool]0000oaL0o`009@000?lH0?l002`0003o0`3oool00ol00000oooo0?ooo`090?oo
o`002P3oool01?l00000oooo0?ooo`3ooolPo`00of`0o`008?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo;P000?lH0?l00280003o603o000]0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo8Ol00?m[0?l0023o003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooobh0003o603o000R0000oaP0o`00;@00
0?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob7o003oJP3o
000Qo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oool^0000oa/0o`00
7`000?lG0?l002h0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?oo
o`3ooolRo`00ofP0o`008_l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0
oooo;`000?lM0?l001`0003o5`3o000^0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo8ol00?mW0?l002;o003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooobl0003o7`3o000J0000oaH0o`00;`000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob?o003oIP3o000So`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3oool`0000ob00o`0060000?lE0?l00300003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooolTo`00ofD0o`008ol00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo<0000?lQ0?l001L0003o503o
000a0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9?l0
0?mT0?l002Co003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc40003o
8@3o000F0000oa<0o`00<P000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooobGo003oHP3o000Uo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooolb0000ob<0o`004`000?lA0?l003@0003o0`3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool01?l00000oooo0?ooo`3ooolVo`00of40o`009Ol00?l40?ooo`03o`00003oool0oooo00l0
oooo00Co00000?ooo`3oool0oooo<P000?lS0?l001<0003o4@3o000d0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo9ol00?mO0?l002Ko003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oooc@0003o8@3o000C0000oa00o`00=@000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobSo003oG@3o000W
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooole0000ob40o`004P00
0?l>0?l003L0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oolXo`00oe`0o`00:?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
=P000?lQ0?l00180003o2`3o000i0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co
00000?ooo`3oool0oooo:Ol00?mK0?l002So003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00
003oool0oooo0?ooocL0003o803o000F0000o`<0o`00?@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooob[o003oF@3o000Yo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3oooli0000oah0o`00EP000?l30?ooo`03o`00003oool0oooo
00T0oooo000:0?ooo`04o`00003oool0oooo0?ooob_o003oE`3o000Zo`00o`@0oooo00?o00000?oo
o`3oool03`3oool01?l00000oooo0?ooo`3oooll0000oa/0o`00EP000?l30?ooo`03o`00003oool0
oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobco003oE@3o000[o`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3oooln0000oaP0o`00E`000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobgo003oDP3o000]o`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3oooln0000oaP0o`00E`000?l30?ooo`03o`00
003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooobko003oD03o000^o`00o`@0oooo
00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom00000oaD0o`00F0000?l30?ooo`03
o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooboo003oCP3o000_o`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom40000o`h0o`00F`000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooc3o003oC03o000`o`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooom:0000o`<0o`00H0000?l3
0?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oooc;o003oB@3o000a
o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o
00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo<ol00?m70?l003;o003o103o
ool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo
0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3oooleo`00od<0o`00=?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooocOo003o?`3o000fo`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo>?l00?lm0?l003Oo003o103oool00ol00000oooo0?ooo`0?0?oo
o`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l0
0000oooo0?ooo`3oooljo`00ocT0o`00>Ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co0000
0?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0
oooo0?ooocco003o=03o000lo`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?oo
o`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo
?Ol00?lb0?l003go003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooom0o`00obd0
o`00?ol00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oood?o003o:03o0011o`00
o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o0000
0?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0ooooAOl00?lS0?l004Co003o103oool0
0ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?oo
o`090?ooo`002P3oool01?l00000oooo0?ooo`3ooom;o`00oaL0o`00B_l00?l40?ooo`03o`00003o
ool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo
000:0?ooo`04o`00003oool0oooo0?oooe7o003o2`3o001@o`00o`@0oooo00?o00000?ooo`3oool0
3`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo
00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3o
ool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?oo
ojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool0
0ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o0000
0?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3o
ool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co
00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003o
ool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0
003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0
oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?oo
o`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo
00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?oo
o`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0
oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3o
oon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo
00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00
003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0
oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04
o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000
oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]
0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l4
0?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003o
ool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol00000oooo0?oo
o`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3o
ool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool01?l00000oooo
0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co00000?ooo`3oool0
oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo[@000?l30?oo
o`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o103oool00ol0
0000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000oooo0?ooo`09
0?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3oool03`3oool0
1?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0oooo00Co0000
0?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?ooo`3oool0oooo
[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo0?ooojco003o
103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3oool00ol00000
oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o00000?ooo`3o
ool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool02@3oool000X0
oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo00Co00000?oo
o`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00003oool0oooo
0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?ooojd0003o0`3o
ool00ol00000oooo0?ooo`090?ooo`002P3oool01?l00000oooo0?ooo`3ooon/o`00o`@0oooo00?o
00000?ooo`3oool03`3oool01?l00000oooo0?ooo`3ooon]0000o`<0oooo00?o00000?ooo`3oool0
2@3oool000X0oooo00Co00000?ooo`3oool0oooo[?l00?l40?ooo`03o`00003oool0oooo00l0oooo
00Co00000?ooo`3oool0oooo[@000?l30?ooo`03o`00003oool0oooo00T0oooo000:0?ooo`04o`00
003oool0oooo0?ooojco003o103oool00ol00000oooo0?ooo`0?0?ooo`04o`00003oool0oooo0?oo
ojd0003o0`3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03
o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`00
2P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003oool0oooo00l0oooo00?o00000?ooo`3oool0
/@3oool00ol00000oooo0?ooo`090?ooo`002P3oool00ol00000oooo0?ooo`2a0?ooo`03o`00003o
ool0oooo00l0oooo00?o00000?ooo`3oool0/@3oool00ol00000oooo0?ooo`090?ooo`002P3ooone
o`000140oooo]Ol0000;0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0843917, \
-0.0523303, 0.00582934, 0.00582934}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-1.22415, -0.0468803, 0.00577183, 0.00577183}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{686, 714},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 97, 3, 108, "Title"],
Cell[1854, 56, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2154, 66, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2221, 70, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2299, 74, 36, 0, 43, "Subsubsection"],
Cell[2338, 76, 166, 4, 63, "Input"],
Cell[2507, 82, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2718, 90, 53, 0, 43, "Subsubsection"],
Cell[2774, 92, 207, 4, 63, "Input"],
Cell[2984, 98, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3117, 105, 40, 0, 49, "Subsection"],
Cell[3160, 107, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3260, 113, 36, 0, 49, "Subsection"],
Cell[3299, 115, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3478, 123, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3539, 127, 77, 0, 49, "Subsection"],
Cell[3619, 129, 893, 17, 255, "Input"],
Cell[4515, 148, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5397, 169, 43, 0, 43, "Subsubsection"],
Cell[5443, 171, 299, 6, 79, "Input"],
Cell[5745, 179, 628, 10, 175, "Input"],
Cell[6376, 191, 296, 5, 95, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6721, 202, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6798, 206, 50, 0, 43, "Subsubsection"],
Cell[6851, 208, 613, 9, 159, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7501, 222, 65, 0, 43, "Subsubsection"],
Cell[7569, 224, 1145, 19, 223, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8763, 249, 46, 0, 49, "Subsection"],
Cell[8812, 251, 987, 17, 223, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9848, 274, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[9925, 278, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[9994, 282, 70, 1, 47, "Input"],
Cell[10067, 285, 21391, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31507, 618, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[31592, 622, 55, 0, 43, "Subsubsection"],
Cell[31650, 624, 159, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31846, 633, 39, 0, 43, "Subsubsection"],
Cell[31888, 635, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32085, 642, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[32149, 646, 251, 5, 79, "Input"],
Cell[32403, 653, 130184, 3197, 296, 38258, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[162660, 3858, 61, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[162746, 3862, 75, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[162846, 3866, 68, 0, 43, "Subsubsection"],
Cell[162917, 3868, 97, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163051, 3876, 57, 0, 43, "Subsubsection"],
Cell[163111, 3878, 83, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163243, 3885, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[163310, 3889, 81, 1, 47, "Input"],
Cell[163394, 3892, 70, 1, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163513, 3899, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[163573, 3903, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[163636, 3907, 79, 1, 47, "Input"],
Cell[163718, 3910, 480597, 11793, 408, 256248, 9020, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[644364, 15709, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[644425, 15713, 78, 1, 47, "Input"],
Cell[644506, 15716, 460606, 12280, 408, 269633, 9919, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1105173, 28003, 35, 0, 49, "Subsection"],
Cell[1105211, 28005, 64, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1105312, 28011, 36, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1105373, 28015, 50, 0, 43, "Subsubsection"],
Cell[1105426, 28017, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1105610, 28024, 100, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1105735, 28031, 92, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[1105852, 28036, 170676, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276531, 30527, 170664, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1447198, 33018, 170651, 2488, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1617852, 35508, 170664, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1788519, 37999, 170664, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1959186, 40490, 170651, 2488, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2129840, 42980, 170651, 2488, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2300494, 45470, 170692, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2471189, 47961, 170692, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2641884, 50452, 170692, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2812579, 52943, 170692, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2983274, 55434, 170732, 2489, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3154009, 57925, 170813, 2490, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3324825, 60417, 170773, 2490, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3495601, 62909, 170757, 2490, 199, 140901, 2118, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

