(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4844199,     110270]*)
(*NotebookOutlinePosition[   4844936,     110296]*)
(*  CellTagsIndexPosition[   4844892,     110292]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Texture-based classification experiments", "Title"],

Cell[TextData[{
  "This notebook  assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Turn off integration warning message", "Subsection"],

Cell[BoxData[{
    \(\(Off[NIntegrate::ncvb];\)\), "\[IndentingNewLine]", 
    \(\(Off[NIntegrate::slwcon];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Read whole image", "Subsection"],

Cell[BoxData[
    \(\(ReadWholeImage[file_, \ 
          dir_: "\<.\>"] := \[IndentingNewLine]Module[{im, 
            d}, \[IndentingNewLine]im = 
            Import[dir <> "\</\>" <> 
                file <> "\<.ppm\>", \ "\<PPM\>"]; \[IndentingNewLine]im\
\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute 1D pdfs", "Subsection"],

Cell[BoxData[
    \(\(ComputePDF1D[
          data_] := \[IndentingNewLine]Module[{stats}, \
\[IndentingNewLine]stats = {Mean[data\  // \ N], 
              StandardDeviation[data\  // \ N]}; \[IndentingNewLine]pdf1D[
            stats, x]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["One-dimensional decision boundary", "Subsection"],

Cell[BoxData[
    \(\(ComputeDecisionBoundary1D[pdf1_, pdf2_, 
          x_:  x] := \[IndentingNewLine]Module[{sol, lpdf1, 
            lpdf2}, \[IndentingNewLine]lpdf1 = 
            Log[pdf1] // PowerExpand; \[IndentingNewLine]lpdf2 = 
            Log[pdf2] // 
              PowerExpand; \[IndentingNewLine]sol = \(\((#[\([2]\)])\) &\) /@ \
\((Solve[lpdf1\  \[Equal] \ lpdf2, x]\  // \ 
                  Flatten)\); \[IndentingNewLine]If[
            Length[sol] \[Equal] 
              1, \ \[IndentingNewLine]{sol\  // \ 
                First}, \[IndentingNewLine]{sol\  // \ First, \ 
              sol\  // \ Last}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expected error (1d)", "Subsection"],

Cell[BoxData[
    \(\(ExpectedError1D[pdf1_, \ pdf2_, \ 
          x_:  x] := \[IndentingNewLine]NIntegrate[
            Min[pdf1, pdf2], {x, 0, 255}]*100;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expected error (2d)", "Subsection"],

Cell[BoxData[
    \(\(ExpectedError2D[pdf1_, \ pdf2_, \ x_:  x, \ 
          y_:  y] := \[IndentingNewLine]NIntegrate[
            Min[pdf1, pdf2], {x, 0, 255}, {y, 0, 255}]*100;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (1d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage1D[im_, 
          db_] := \[IndentingNewLine]Module[{class, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ 
                  Orange)\)*255; \[IndentingNewLine]bl = \((List @@ 
                  Blue)\)*255; \[IndentingNewLine]If[
            Length[db] \[Equal] 1, \[IndentingNewLine]class = 
              Map[If[# < db[\([1]\)], gr, bl] &, 
                im[\([1, 1]\)], {2}], \[IndentingNewLine]class = 
              Map[If[# < db[\([1]\)]\  || \ #\  > \ db[\([2]\)], gr, bl] &, \ 
                im[\([1, 1]\)], {2}]]; \[IndentingNewLine]ReplacePart[
            ReplacePart[im, class, {1, 1}], 
            ColorFunction -> \ RGBColor, {1, 
              4}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (2d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage2D[feat_, pdf1_, 
          pdf2_] := \[IndentingNewLine]Module[{class, lpdf, gr, bl, 
            size}, \[IndentingNewLine]size = 
            Dimensions[feat]\  // \ 
              First; \[IndentingNewLine]gr = \((List @@ 
                  Orange)\)*255; \[IndentingNewLine]bl = \((List @@ 
                  Blue)\)*255; \[IndentingNewLine]lpdf\  = \ \((Log[pdf1]\  // 
                  PowerExpand)\)\  - \ \((Log[pdf2]\  // \ 
                  PowerExpand)\); \[IndentingNewLine]class\  = \ 
            Map[If[\((lpdf\  /. \ {x \[Rule] #[\([1]\)], 
                          y \[Rule] #[\([2]\)]})\)\  > \ 0, \ gr, \ bl] &, \ 
              feat, {2}]; \[IndentingNewLine]Graphics[
            Raster[class, {{0, 0}, {size, size}}, {0, 255}, 
              ColorFunction \[Rule] RGBColor], 
            ImageSize \[Rule] {size, size}, \ 
            AspectRatio \[Rule] Automatic]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Green;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Image file names", "Section"],

Cell[CellGroupData[{

Cell["Image file names", "Subsection"],

Cell[BoxData[{
    \(\(BrickFile = "\<brick\>";\)\), "\n", 
    \(\(WoodFile = "\<wood\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set directory", "Subsection"],

Cell[BoxData[
    \(\(SetDirectory["\</Users/nechyba/www/eel6825/course_materials/t6.odds_\
and_ends/texture_data/\>"];\)\)], "Input",
  Background->RGBColor[1, 1, 0]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Intensity-based classification (1D)", "Section"],

Cell[CellGroupData[{

Cell["Read in image files", "Subsection"],

Cell[BoxData[{
    \(\(brick = ReadWholeImage[BrickFile];\)\ \), "\[IndentingNewLine]", 
    \(\(brickIm = brick;\)\), "\[IndentingNewLine]", 
    \(wood = ReadWholeImage[WoodFile]; woodIm = wood;\)}], "Input"],

Cell[BoxData[{
    \(\(d1 = brick[\([1, 1]\)]\  // \ Flatten;\)\), "\[IndentingNewLine]", 
    \(\(d2 = wood[\([1, 1]\)]\  // \ Flatten;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show image files", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{brick, wood}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A8393A1AF9E5037B3B9BCB8B67D2F7F757780858147ADB1AAA9AB951E788F94999E9326
556269696E733D7E929DA4AAA9B0B4579FB2B2B0B0713A9DABAFABB06E338380929CA96C
2546495568754F6EB9B2AFADAE539AB8B8BABCB664B4B8BCB9B85B84B2ADB4B48689B2AF
ADACA95388A5ACB1AD8683C3C7C0BEAD52ACB0AE
5E91A1B5B9B37239AEBCBCBCB97E38756D6E7884883AA8B0AEAAAD91268C9BA5A4A19522
647E836D68593180969FA3AAAEB3B555A1ABAFAEB0762C87A0A0AAAD6C369C979CA3A977
3D65434E67704973B3ABADB0AC5196B3AFB0BAAB6BB7B9BFB9B96A8FB3ABB3B5A6A1BDB6
B8B6B25C869EAAABB5938DBBBBBBBFC36FAAAAAA
5E97AAADA8A5662D9EB5B4B9B89D5571696A75859138839DA3A397623F8392A19E98842E
57796F6E60502C8AA3ABA1A7AEB0B05398ABADAFB0742AAA9F90A0AB703B9F9DA2A6AC78
4795535E6F734561B3A8A6AEB04E95B6B2B1B1B064B6BFB8BCB96B8EB4B5B3B6A498B7B8
B6B2B1579CB0AEB5B89286B0B0AEB3BC72ADA39E
3C40463D393829242F2F202826221E282328292D322D3D4E34291D151F3D3E3A35374932
383E3937342D2346494E4E575D66612E4E686C6E7145176D63575E755A216D6E6B7A7B52
3044372E2C363B629E98938590456A9EA4B1B5AA61B3BCB6BCAE4E65A0A3A2A88E8FBEBA
B5B8B75C8DAEACAEB0867FA5A698A5B7659EA6AA
A5A5ABA85F7F9088A0A4A8ACA3A6A49C948A6B66A49FA29E9A8D8C8F868F8C88824A6B79
6B70767877777878745E4732526665655E46564C4539392F2217212F34382F352B232A29
2A2B2D1F222F35373E3C3C3C2D1F171B2630231F10242C212A1803112724272E221C3643
45494D192E4B494D512D335161636D743B414A4C
AEAEB3B5589288809BADAFB2B5B1B3B0B1B16D6AAFABADACA8A5A8ABAEB1B7B3B55A7B86
858A8F9EA09C8E85858F9F4B7BACAAA9A68D969F7F7E656D6147887F72AAAAAD917085B4
B4B2B7677CADB3B2AEB2B1B0AEAAAAAB9357879B9FA09A999E9A8B878C8B7F668E8B877D
757A77696A6F726C60456B5D55515457686C6D66
AEA8ACB2529D8C90A1A4A5A0A6A7A6ACADB06F6AAAABACACAAA4A6A7A8ACAFB6B34CA49C
95A4A5A6A7A49A898298A24681A1AFB3AA9696987476788382568A8C8CACABAC94776FB1
B8B6BA6179ADADA8A6A7A7A7A9A5ABACA75F8AAAADADAEB5BAB0A6A8ADABAF67BAC5C4C1
B6C2A78568B2BEB98A8FB8B3AAB3B7BCBDB3BCBB
B1AEB3B353A89795A7A3A6A3AAA3A5A4ADB16767AAABACABA8A6A9A6A5A6A6AEAB43A8A1
989BA3A7A6A09D948EA09B4B81A1AFB1B0AC9E9B9F94A0A48C538C9194A9A8AF8F7785B2
B5B3B95C76A9A8A5A4A9A9A8A7AAADADA4578AA9ABA9AAB2B6B2A5B0B4B2B34AA5C4C5C7
B9BB805340A7BEBD8B8AB9B7ACB6BABCBCBDC1BE
A9ACA49652808487878C909198928D9A9FA1695A888B9A9E8C938D948D8E8F9B9446A8A7
99A09DA1A1989A928B979B4579A59F9DB1B3ADABA9ACAAAB8750889B9FAAABB39A7E81B6
B9BAB9617FAFACA3A29F9FA3A6A7ACA6A26A96A8A6A19FA5AEB09DA0ACADAB4098BFBEB2
AAA46137449DB2B0718BBAB5ADB6BABFBDBABCBD
9A97938F8D877D787968356668757E797A777C65797E71583F5473767375786F6F6E6F62
5754405E7F7C798181877D767B7C6257534E4D4C5151555B4D444C6060695E5846495568
787578504E78796967657A7C82886D7382497A8C8575848F989D9C8D979D9F3884A69B7E
8079554A6B798C96738DAFB2ACB3BBBBB9B8BDB4
BBB7BABAB7B5B2AFA9AC4E9CA19FA3A5ABA8ADB1B4B3ACA160A1AFAEADB5B4B4BBB9BCBF
C0BA65ADAFA9A6A6A5AAADADAEB1B3B36B8EB2B0A7A4B4B7B4B8B6B1AFA56789979C9A97
9695969EA8A99A835A7B83777471797E7E887869653F49656A6A5A5B62615F645F6C6A44
61686264655C5F5B574B393B3B3A3E4C474F4A4B
B7B0B3B0AFACA9ACABAC50A2A5A59D98909DA8AAAFAEA9A75CA4ABACA9ABA9A9A7A9B1B7
BBBF76A7ADA49B9DA2A1A9AEAEADB0AE7B8CAAA7A6A5ACAEB0B0B0ACAAAA88B6BBC2BCBB
BEC2BFC1C1C5BEB589B8BAB8B4AFB6B7B3B3B4B6B35F89BABCBCBAB8B2B4B8B4BAC0BC69
AFB7B1ACAFB4B4B7B4A8A9AD9664A0AEB3AFA4A0
B1AFAFAAA9A9A6ABADAF608E899A9CA19F9FACADACABAAAC72B3AAA8A7A8AAA8ABA9ADB4
BBBA78B3AE9D9A95A6A0A4A2A5ABAFAD73819B96979FA8A7AAA9AEABA79D8BB5B8BCBBB7
B5BFC6BDBFC7C3B57AB5B7B8B5B1BBB8B5B2ABACAD5A7DB8BCBAB9B9B4B4B4B8B9BBB964
9BB3ACA9AFB3B2B0AFAAADAE9064ABB4B2B3ABB1
B3B1B1B6B09FA1A3A9A9578698A8B1B1AEA8ACB1B3B9B6B270A2A8A8A7AAADAAB3B0B5B7
BCBB7CB9B5B0AEA9A296A0ABB0B6B5B3637A8E8B8F94A1999DA2A2A89E7C81B1B4B6B7B9
BABDBDB7B8BEBBB183B3B1B6B9B7B2B1ADACABA6A3578BB4B7B9B8B6B1B3B2B1B7B9B456
94AFA8A7ADB1B0AEADAAACAB8E77AAB7B4B3A9AF
665D483931363431413C3432403B3C39423D30363C3E3B3A263E4C4B4D3D3B34352A3A43
463A3B595E61566061605D616A75736B344E5B5C666263646B6C6E6E6765487B80817C6C
667081858A908F65618E7FA3A1A49EA09C97989B924E85B1B3B8B6B4AFAEAEB3B2B3AD4A
9EB0AEAEB0B1B2B2AB9FAAB08C77A2A4B1A9A9B1
B7B6AB7279AEAFB3B3B3B4BCB8B4ADACA99352B3B6B7B3B2AAA59D948C8D9187499EACAD
A4A4A7A7A6A09B9791834F7D8182807E776C68656969767036525F595E656E6C67625B5D
563D2F4A4A4F4A493E2F463F403B354C525155484953544441483B2C2E373A43474D372D
414E4B50545A5E62666C6A685235535D6A656276
B1B2A87689ADB1B5B5B9BABBC0BBAEA6ABAC5AADAFB5A7AEADA9A29D8C90979B51AEB0A9
A9AEAFB5B4AFAAA4A3A16AA9B8BBBDBEBCB9BAB9B5B9BCBC69B2B2AAA7B4B4B4B3B8B8B4
B29557B098B3BBBDBEBEBFBFBB6B64B4B6B8B7B3B3B7BBBBC1BFB86D7DA5A9A0B0BCBBBA
AFAB9A968C4E72857E807F726D747B7078818462
B0B0AD778AAEAEB2B8B3B4B2B3B4AD9EAC9E5BAEB3B3A4A8A8A5A79E9B9E9CA049ACAEAB
A4A0AEB7B5B1AEA99F9E67AFB6B7BBBBBBBBBCB9B7B9BBBE65B3ACA9A7ABB2B4B2B2B0AD
AD9C78B39AAABFBEBDBCC2C3BD6869B7B1B6B5B4B6B9B5BCBEBEB8828EAFACA8B3BABABF
B8BCB9B7B056A3BEBEC0BDBBB8BBBDC0C2C1BC94
AEAFA96983B0A9ADB5A8AAA5A9ACAC99A5A162B5B4B4AFACA7A8A9A59F9F9BA342A0B2A4
A6A9ACB5AEADACA9A69E5FAFB4B3B5B7B6B6BBBBB6B3B2A562B2AA98A1AEB7BCB7B3B1AE
AE9672AEA8ADB1B8B6BBBDBAB77565B3B2B6B3B3B4B7B8B8BEBDB9748BADAB9BAFB7BBB7
B2B3B4BAB147B0C3C5C3BBB7B2B7BBBEC3C0B98F
887E6B485F7B7981867E7678736E716A666449888488806265666B6D5B5F535723406572
777E92918976817D84803B909EABAB8C96A1B6A298B4B5A66FB2A6899FACB0B4B2B5B0B5
B28D5999ADB2B3B4B6B1B4B2AB7173B4B0ABADB0B0B3B5B7B9B6B46B8DA9A9A0ADB7B8B7
AEB1B4B8AF47ADBFBEBCB7B5A8B3B8BDBBBCA881
A4998D909088858484576470717378796E6F7D777B80795542656E6C727173716C6C7A75
655B3053555758565C5A6454585B573E24414842423C3F4D464838424F333D5045575745
4F502F3B4553564C4E4E4E57634336494952555B575A5E63626166323260697172787D7C
777D6F786E2F6B9497949B98949191A3A6AD7962
B9B7B8BCBCBCB9B7B56E92B2A8B7B8B9B8B4B9B8B7B8B87A6BADA7A7AFB1B8B7B8B4B3AD
AA933DA3B0A49A928C84949CA2A6ABAB529AA4A3A7A9A9A6B1B2B1ABACAF69A6A8A4A6AA
ABA7ACA7AAA9A78677A6A6A7ACABA2A3A199988F7D3D55706D696A7679777A706D656440
5F63676665636463626467533F3D60636668665D
B8B7BDBEBFBCB8B8B56D91AD9AA9AEACABADAFB7B7B1AA826BA4A5A2A1A6A8A9AFAEB1AF
B2A149ACAFA79897948E8A8C94A3AEA741939D9D9DA5A1A4AEB1ABADB5B379ABA7A7A7A7
A8A8A7AAAAA9AA8381B0B0AEB3B4B2B0B2B4AAABA95F80A0AAB2B0AEAAADA7A4A8ADA861
A6AEAFB0B1B4B3B1AEA9AA947D6595A1ACB6B6B4
B7B5B7B8B5B5B4B7B0698AA998A9A9AEA6A9ABAEAEAFAB7D659A929FA2A5A7A7A9A7AEAD
B1AE48A5A89B9194838482858598A8963F8E96979A9C9C9BADACAAAAB3B16FA79FA09FA5
9FA1A3A5A4A5A7828BACADADAAA8A6ACABB0ABADA74E769EACA9ABAAA7A3A39CA29FA95C
9EACA8AAA9ACAEB3AFA8A7A79B679595A7AAAFAE
87827D7B7D848D8A8C5A7C907292949C9C9BA0A1A9A8A6774F8C9298A0A1A0A49AACB2AE
ACB04CA7A08F8C9183827B807F84948E578B8E84878EA09FAEADADABAFAA669997939191
969E9FA89E9FA27A80A9A8A7A8A6A5A4A6A3A3A6A15C7997AAABA9A49D9E9E9394969D59
A0A6ABABA7A7ACAFAE9898A5986B8B7896A5A7A7
695F51304D504942394B4F464946474F39293F464B413D392B302A232F2623232A4C5A60
5D494169726A554F5B5D57626B55585737394440424D51524C585658524D4265676D6D6B
6667645C63656251577A8072757F81817F70797E7F4A636776787D7162594E5D5B596348
7A828A70758B928F8F8378896859736E8AA09D9C
BAB9B16FB9B5B0B4ADB2B3B7BABEBFBAA65A7C88B3BAB9BEB5B2AEA5ACACA74AAAB4B3B0
ADB0A2AFAFACA19B8D509EACA7A4A8A8A29D9D959F9B7C457F8A85878C8F848B8E8E9195
8C56707A797B76736D68645859572C375E5A55585E645C56615A483C5C656559555B6468
5F544E432638473E413F3F3C4542494D58533E44
B5B4AE71B3B4B7B2AEB1ADB7BBBAB7B1AE4E8E95ABAFB7B4B1ABA8A5A8A49E53AFAEB0AE
A7B0AEAEABA5ABABAC60ACB1B2B6B5B4B0AB9B9DACB2A4539FA59C9BA4A7A6A5A3A6ACAE
B276B9BDBDBDBFBFC0BFBCB6B3BB3F8CA7A8AAAAAFB4B8BBBBB86D6EA4A9B2B8BDBBBDBB
B8B1AF9E5194AEA9ACB4B3B0B9B7BEBDBDAC6AAE
B5B1A66EB3B8B9B4B1AEABB2B7B5B2ACAD5DA9A3ADA9A6A9A7A3A3A7AAA08A5FAEACAAA9
9EA6AAA4A6A7A6AAB071B1ADB4B1ADA5A29DA2A3AAACA64B9E9E8F97929E9C9EA4A2A9AD
B071B9BEBFC1C2BEAFB2B6B5B8B94DA4A7ABA9AAAFB2B5B4B7B66970A7AEB3B7BBBDBABA
B5B2AC8C4A9BAAAEAEAFB0B2BAB8BBBAB9AF74B1
AFAAA777B5B7B8ADA1A4A9B3B4B2ADA9A758ADAAACAEA4A2A59AA0A3A7AA8F5AAEA8A9A7
9299989599A8AAA7AF64AEAEACAEA4A5A6A5A6A3A1A5AF4D9D9B837F7C8A9194A3A0AAAA
AA72BDC1C0BDBDBBB9B3BBB7BCBA589A9A8E94A0A7B0B5B9B9AE4E6DABABACABADB7B5AE
AAA3A8944B99A1A6A6A697A5A0A1A9B1A8A37DB4
4D443027404338363320303B3E413D3E322C3A484C4848413B484E505546421D5C646667
6B67706C6A766E6B6F3D7277797B737373716C76787C793A7D77787166787E81818B8B87
8C568D8A9088879091859599A2B14B99A8988B979298A6ADB8B04E6D9D9C9EA2ABA8A9A4
A08B9A8E599F94949EA19691898B9AA4AEA376B0
6B4483908B88722C638A8B817E67305F828383777436696E62575E55283A444D66623928
5E776F6668672B3E60635749513758544A3C403A2A5C5858483029232B2F38362B273A45
49423A3633413D38342219262D312A2D3A45414445413D3942574B4C4C53534D494E5759
58525255362A3B414545555748474C4C5C4E3045
9E3DBCC8C9CABD2B81B4B7B7B89E288CB9B9B9AC974D919D8C8A8E804D565565838F8233
8DAE9D97A19C4375A9B1B0B3B855A18D645D565148B7B9B8B6B2695BA7B6B7BCAB4289B5
B4B4BAAE43BABFC4C58B83BAB2A8A48C52A1AAA5ABAAA456AFB4BCB9B34C6CA093909096
5F488891A3A1893B6E8D9998998F36618E99A29C
AF45BEC5C9CAB42485AFADB2B4A72692B7B3B4A5933A93B3B1B3A9A9553D3D4B6D7B7E42
88B2A597A3A03B83B7B7BABFBF63A6A690705F4B56B5B8B9BCB86874B0B4B9C0B84B94B4
AAAEB8BC68BDC1C2C8B36FA8A89DA3A760A7ABA5A29C8D52B7BBBBB7B86D74959C908790
5985AEB6B7B3AE419FB9B8B8B3AD3EA1A8ACB0B0
B255B8C1C0C6A82D8FA9A8ABA893218EB3B2AC97803F98B4ABACB0AE4F3717191E414533
849F7F7A939A497FA9AFB0BBBE639CABA983725F4EB3AEACB2B4657FAFB4B5B7AA3A96B1
ACB2B7B560BABDBDC6AF71A6A1A7A5976299A59D95848647B2B5B3AEB063648A827F7B75
4888B2B6B8B7B036A4B3B8B6B1A83798A5ADABA7
84337C857E82763D5C7F7A76877B2A5F6D715B535F4562788282868D463E2C3B3C415440
63644B55606947617C72708087489A977464436147938B7E7B885669808393A082378894
9FA0ABA45A9799B5B6A06CA8A7A4A79C5A969F9893857F4FAAAFAAA4A7544E89887C796D
4E92B8C4BCB9B32BA0B6BBBAB9B139A4A6A8B0AE
887B7872415B70797E6F6D70796A685855583E47686F685E5C4B555B5A595E503C49636A
6B625C5C5F5F625F585E463A5157555C5C5B5D62605F69624E555B5B564D464C46526262
66614D4A423B444C483E4B564A4F515B536664615A645B537C736D6A664C405F665C5D59
4C6A7885837678416F7B817577713F787C79837E
B4B0A79F4294ABABACA5B2B4B5B0AAA4959D6A7EB4ABA6A0ADADACACA8AAAEB0738BB1B1
B1ABAEA6A6A9A6ACA9AB7870B9BDBCB5B8B7B5B1B4B3B9B569AEB6B6B7B3A6AAB0BEB9B6
C2C45252A8A9B4B4B1AAA59E8B7B41A5AFA182938C969B9E9F99896256959A8E9AA2A081
98A197969552809C90846F51556E896A63614F4F
B4AEABA73897A7A5A29BA6ACA8A5A5A3A29C6881AFB1A789A5A2A4A79CA1ADB27D8EB6B4
B2B6B0A7A6A7A7ABA7A18C91B2B1B0AEB3B5B4B2B1B6B7B657A6B4B0B1B0A1A2A7BFC0C0
BDAE447AA9AFB6B8ADA8A6A3A38145B8B8BCB9B9B7B6AB94A9B3B59175B1B2ADB4BBBEBA
BCBBB7ACB46FA8B2A99C9FB5B8B3B4ADB1B87A6D
A8A3A69F379AA3A3A29E9FA5A8A9A39DA3A06E86B0B8B397A69DA0A9A3A5B4B48C84B9B6
B4B3AFA6A5AAAAAAA8AD766FAAAEB1ADB0ADB0AFB1B0B5B761A4ABAEAAADA5A5A6B4BBBF
BEA0397FAAADACAEAAA2A5A3948449B7BBC3BEC2BDBAA593AFBCBB9380B2B4B5B9B9B9B4
BCBBB8B0B267A6B3AA9094B6BAB9B7B5B9BB7C76
B1B3B0B257A2A2A3A2929A99A8ACA7A1A3A06280A9AFB09BADA1A6A9A29CA2AF7F7EAFB1
B6B4B3ACA5ADABACA89F595BA2AAAAA8A7A8A5A9AAAEB3B66EA3A3A6A7A8A9ADAAB4B9BA
BBAF4D76A8A7ADABADA9A58F88835DB1B6B8B6BCB7BCA8A8B8C1BD9783B2B3B8B9BAB9B3
B5B9B3ADB05DA3B3A98275A3AFB2ADB4B4B78A80
6557484831404B51524A3E294B635B4D473F3E4B556A605444383839313845403B4A595A
656757423C53514D413F362B5451523E4339354941524D4D37626761636D6D716A70666B
68532C4866615B665D584C5D656139606B73717B757C6F7780858369557A7C8380817D81
7A827E78794A7B7962535461717A7A828D886562
B18A799AA2A9AC9E928D8126A6A7A1A09B9A9A979E9E8B8F9254919CA1AEB1B3B4B4B6AF
AFA98959A6A1A7A8A1A39F959AA2A8AA633A8E989EA6A9A9A09094A3ADA778669DA6A4AF
B1AFAEA69AACB6B268709B9D97969D9E9D9998989B85436B787A7473767467585C523762
6A6969666C6F575E6C6B735F4A6C6B6967696864
B4A29093A4A8B1958BA29C2C9BA2938D8C86808B89856990973E848C8D9EA09DA6A7A8A7
A3A0936DA2A0A0A3A1A09B8B989FA4AA7451A5A1A5A9AAA6A398A0A5AEB06F79A8A9ABB5
B2AFB9B9B6B4B6B86F7BB7B7B1ACB9B9B3AEB7BCC0B23D7DA7B3AFA49C9A8CA1B0BB6895
B9B1B2B0B3A581A2ADAAB08582B9C0BEC1B8B9B8
ABA5948DA0A6A78E899F932C9E9F98888479848A868F7E939137829286919FA0A1A6A9A4
A0A07F6B919D979C9F9B9C9496A0A3A57156A4A6A4A5A5A7A39A9EA5A8A56A60A1A4ACB3
B4AEB5BBB7B5B6B66C83B8B4A8A9B6B7B3AAB7BCBCBA4893B7B3AC9B99A6ABACAFB86A97
B5B4B1B3B2ADA2AAABA7AF787CB6BBC4BDADB7B5
A5A1A39DA09E9C8F8F857D399EA0A6A49B84888189909B96983E8083839296908D91A1A3
A09E71576783918D9C999C8692A0A19F85669DA8A7A3A1A39B8F8C93939175618B95A0A7
A3A1AAB1B0B4B7B57295B7B29AA9B4B2AEA8B6B9B9B8419BBAB9AE9BA7AEAEAEAFB9689A
B1B1B1B4AFA6A8A5ABA8AE7D82B9BBC1BAABB0B4
7366675C4046423A392627294553525342483D494F5C4C43343E53494E5D66534A474F59
50614D49455045474B5E574F56565A554A46716B6E6A6866646D63606A64564F4E5B7073
75736965716F706E3B63807B7581847D837A7C777C76357285847D5C747E848C90925F75
878A857E78707E8088818265619AA2A09D7B9197
AFA4A5974C809299978B9295A1A3A8A7A9954D57A39980A0A29F9B989A9EA0A77968999A
8B8492868E94959098915D769CA8A594919093908B8BA0A45F7488877F838D868D8A8983
867946858081888C897464635F5C2B628A8F8C918E8C8C837F827F753A667B7B75737772
70696C66673740565A4F575A5A5D5D5E625D5F3B
B6B1ACAA4C88A9AFAFB1B2B6B4B4A6A3AC9957589C978999908A838B939BA1A6826EACA6
A0A39B9F9F9BA1A49A8C5A7FB8B9B8A1AFAFADA6A7A5A8AB74A7B0AFB0B0B4B8B6B9BABE
BEB45EBAAFAAB2B3B9B4B1A69AA0308AB0ACA9B0B5B5ADACB1B6BCA537A6B3B1B2B5B6AC
ADAEB2AEAA6479B6B7B7BAB4A8A4B0AEB2B1B162
B3AEACA93B87AEAFAAADAEB7B7B7A4A1A6A56854A5A197978C837B7C8F9EA09F8271A7A7
A79B899CA195A2A594834C7CB4B4B49DB5AFAAA9A7AEADAB7198ACB1AEB0B7B8B9BCC1C4
BFA862B7B0ABABADB6B2ABA39F913076ADACAEAFB3B2B4AFB5BBBB9E35A6A8ADA8ADA5A8
ACB0B0A8AB6F76B0AEB0B5AB999FABB2B1B4B16A
B0AAA8AA5175A6A8A2A1A6ABB0A7A2A09AA16752A29A9798877D7D7A7B848A947976A4A8
A69B97A4A9A0A0A397885184AEAEAC9FAFACACA2A1ABA6A56389AFAFABACA89FBCBDC3C2
C19C5DB5B3B2A39FAAABA9A4877C3D68A7AAACAFB4B2B6B6B3B0AFAC3FADADAAB2B3ADB0
AEB7BBB8B97C77ADB0B3B4AFABA7AAB4B7BAB267
75716963345C6E676A6A6B61696763544E4C30346D757070645A595B535A61683C4E7670
6F646166705F5E61544C32517375726F707A756A5F5F564F314755656E67675E79838A86
834A3F88828C7F878280877A676E44618F9997A19E908295909A938036819D909494979C
A0A4A8ABAC806495A4AAA6AAA59DA1A2A4AAA964
9798959095908484949CA058688F8D8182899093908983847F54395E60646B6960606C6A
6E6D6A465F666C666E737E767A766B7162466F6F696A676B74776C7678764B3965706B65
6B6F776C6E716F67546C6D6A72787874706C68625F3924313C3D4A475152574B4F473F3A
5F6162605E6463585F5C56503543615D625B605B
BEB9B5B6B8B2B1ADAEB0B4617BA9A49E969E9EA6A2A1A4A7A363518C8994979AAAAAADA9
AAA9B16286AEB7B8AEACADAEAEACB0ACA469AAA39893909FA5A4A5A9A6A67260AAB0B3B3
B1B8B7B9B6B9B3AB83A7B1B7B6B3B4AEAEB7B9B7B870667F80A0A291775A7A8485835F4D
A5ACAEB4B9B6AAB7B9BFBBB94392AAA9B2B7B5B1
BEBAB0B0B6AFAFACAFADB16D85ACA19B959B999DA0A3A5A69A60508D928F9995A2A3AAA8
A39FA56C83ACADB0A2A0ABADACA9A8A99D56A7A398868EA4A69BA3A8AAA76E69ABAFB4AF
AEB0B3B5BBBDB8A486A0AEB4B1AFAFA6ACAFB5B8B36794AA90A19699865696A7AAAC775C
ACA5A7ACB2AE8F9EB8BBB6B95C93ADB0B1B5B1AD
B3B0ACA8A9ACABACADAEAD7884A29472707F97A093A1A39F90554E7F818D91868A899DA0
9B9DA2657F91A4ACA29698A5A4A7A6A5985EA092938885A0A3A2A5A6ABAB7682A6A9ACA6
A8A2AFAFB5B5B1A58799B2AFAEAEA9A0A7A8ACB0A8608B9E8F9D8B8D8E59949DA7AA7A59
AA9DABA8AFA89BB1B9BAB8B96F9BA8AFAFAEAEAB
8677727570706D676B686A38607D827A4B5D5E6F756D7181783E5672727573675A4F6276
71716B466D778980715E546F797673777A4D6D6A746E656A5F5F6B6E6F645469676A7A7D
738A8A898F827F8472668C8D8F9394949C90909686598582807F6F796B4B7F9191A06B66
7B7C9D9C9C927CA8A4958771566598ABA5A3AAB1
7E6F634630717375798289898478707B77552E5D67655F58585657544F5050331E546D65
65616263645C64605D48325D625F6561605E5B605E565033283D4642445A5F5C5C5F6161
593A47636A665F72706D7573757A71344F5E5C4A5A57575355463A221D27263A46585D62
666D6C615037254A3F413E4048526873757F7663
A48773743EA8A9AFAAABA6ADA8AA9FA7A17F59ADABA8AAA7ABA4988F9EA3A16C3DAEABA9
A39FA3A0A2A6A2928D7E3C88A1ABAFB4B5B5B3B7B2A6AE6145737B797993988F81929288
8A5A95B0B3B5B4B0B6B6B9B5B0AEAE318FAFB3C1B6BEB7B8BEC1BAAB304386ABAFB4BBBC
BBB4B0B1A99D74B2B2A4A4B6B7B8BCC0C5D2D076
AE95687357B0AEACAAA5A6A4A9857D999A905CABAEAEAAAAABA2A1969CA19E783DAAADA8
A19E9C9DA2A1A2A2A07E3F9DA4A9ABADA9AFAEB0ACA7AD7157756E6E6A776E6963768984
845587B2B5B39F96AFB3B3AFB0AEA83694A9A8B1AFB7B8B5B8B8BAB54676ADA39099ABB1
B2B3AEADAAA972B7B4B1B0B6B2B4BBB7BBC2C071
AC9A735B67B5B5AAADB0B3B0AB6A7CAEAA8F61ACACACAAA8AC999999998F916C3FB0B0A4
A8A0A8A7ABA7A0A3A07E2F9D979CA5AAA7A9ACAFAAA9AE714365666A6B6A68584F5E7575
734883AFB1AEA39C9DB3B4ACAFB3AF3792AAACACB2B6BCB9C0BBC0B6527DABA599A5ACB4
B1B2B0AEACAA6DB1B1AFADB2B3B3B6B5B8B8B874
91886C4E4F8B8573778275777F5C678186654C8175777E868883856872616248408B9190
8B847D79728874716C5E2F7D7B71818388867D787271704D31302D3637443E40404C4554
4E487E918F9585877E8D8A8B8C938538588286897E7D81807F71717739609AA6A4A3A8AE
ADA9A3AC9E7B639196949093999B9DA4A9A59854
41425E666D665D36495950555951243757516062614640374753544F2B233846504D3121
38454C515744313E63696A5B5E261D4D52514E522C3E4E5A625C51293E585058623F2753
6768615F5F365C66575C5E5426496262655E4745626462535E39555D5946483729313A30
38362A2B374139413A242F3D424E4941334D4C48
7A5BA4A5AAB1B75E7B918898A1972A4D9499939CA94F63969A948D7C3B3B61735778923D
7BA3A0A3AE8D40698F9B9E9192396AACA388859E4A6EABA2A69DA2498EAFB1B5BDA72690
B1B4B6B8BE3AA3C1B9B1AE9F2F82889298907578AFAEACAFB75D96A0A5AAA974269AC5C1
BCAF5B3FA8A8A7A3984C688EAEAEB6A041B0B8B8
8B6EA0A5A8B5BB635AA38F9FA8B049538E95908D985A619B9A8E7D733A395D7E6477864C
78959995A8904C6F9BA8A09A9C4E72AFAAA09E9B4B6EAAA8A69B9D4996B8B6B9BEB6539E
B1ACB0BABB3DA9BFBCB5B299327D8D8F9181626AAEB3B7C1C055869FA2A5A07238B5B6B7
B5B76475AFA7A9ADA7477A99A2A6AFB24FB3B8B8
8F77AAA6B1BEBF5A73A88EA7B4AD44699C908D8EA152668F7F6F6D61343951595B61753E
7B9BA1A7A897477A9F97948793527AADA89C929D4A72A2A5A4A7973F98B8B7B7B8B24D99
A9A7AAB3B93BA8BDBAB8B9A43780887F7B866872B2B8B9C0BB589EA9A7A6A16B4BB5B2AF
B4B37076B0AAAAB1AD3C7C96A5A59B6649B2BAB7
8D629CA0A0A59C4F448698AEB1A1345CA192908D99472C888A757C7D4E597775655C804B
859AABB2A9A04360A79F9082885470999D92867743749D8782989B669BB2B2B5AB8D4299
A3AAB1B8B84CA3B5B0A8A490324B5E6C83835C568C979698A291ADB2B1ABA67264B6B4B4
B9BB7283B0ABACB0AE467BAEA8A0927D52B2B3B4
6958503F323435333B494F4E53504B55563F39484D514B50535A51463A323E242A4C443A
4B4E696B6F62535F582D535A4548476872785058574A38244C595E585B6667675A53494B
472F4B5A62596D716866645A595441374B574245565A50586E7F796E425765616683847E
7C7C585E5C5257625D4B5D625D5654423B4D5356
AAA79D6E378B9CA0A7A7A7ACAEAEAAACA87663908C9C83849A9D958D788B8D6162A1A6A7
A5A2A6ABAEB1B1B1B24C93A89F9F99ABAEACA6A2AAA0A43CA6AAAFA8A5A5ACABAEB0B1B2
B2429FA8B2AFB1B8B1B2ACA5A8AC9C85B4B8AAA5B1AEB6B3BCBAB1AE56ABB3B9B7BABBBA
B8B1A7A4AE70648D97A2ACB0AEAEB2B1B3B7AE61
ABA4AA6661A89E8A98A09D9EA1A49FA4A38868999AA28C898F9A8F8E8D97916884A4A9A5
A19E9C9D9FA3A6AAB26899A99E978DA6AAA7A999A6A1A45FA0A4A6A4909AA4A2A5A6AAAD
AD3FA4A8AEB2B1ADA49FAAADB2B1A086B8B8ADABBAB5BCB7C1BFB9B35EAEB4B6BEBDC0C0
BEB2A6A7B57678A8ABA8ABADA7A9A7A7AAABAD66
AFA9AC5D47A59F8D91A2A6A7A4A09EA7A48C65A1A2A59F9A8C8C998278878D6984A39BA1
9E9986899B9F9BA6AC6A9CA8A3A391A2A1A5ABA2A5A39D5DA29D9A9A949A978DA0A4A6A8
AD4EA4A2A4ADACAEA5A2AFB0ADADA084B8BCB2AEB6B6BEBBC2BDBCB76FB2B2BBC2BCBEBD
BBABA1A9B36871A0A6AAA9A69E9DA0A1A8A3A877
B8B8B672419DA3A0A39D9FA5A8AEACA7A1846393A1A6A4A19F9D9A89757B996584A29C9F
9DA18C847E888AA29545969884989BAAA8A7A69D9F9E9A4781857C7C798486939A9FA7A8
AA4E9F9FA6ACAAA59A95989EA19C7E78B0B2A4A1B4B9BBB7B9BDB9B571A0A3B3B7B8B8B3
B2A397A3AF5B64ABA5A5A6A39C9F9F999EA6A083
666964543F505E5B675E44414A4B4B2C2B2E2F33414B5A4F3D343A39595062445B69675B
4D40373C494F515135283C403E3D404D39313E3F40423C34303B30362F2E24323B53484F
492E484D55594C51324446595B5F6C6660645B463F34324D4A5250534A49525D585B5566
5F61586A6B4A334C4B4342414E574F5F534E4839
A8A3A3A1A0A3A59E9C955662B0ABA2AAA5A7A8A9B0B3B3B05255909495A0A6AFB0A29D9A
A69D5C48A8A3A0A8AAA4A4A1A4ACAFB17D2C808993959D9698939B95A4953D5F656C6D76
8593999289859B644CB2B5B3ABB3BBBDBDC2B6977C5A82CBC3BDB7B5B7B3B2B6B69870B6
BABAB1B0B5B8B3AEB0AF843CA59EA2B2B5B3AEAE
A69D9A908C8C9D968E8F5D6BADAEA2A3A1A2A2A7A9B3B4AF7F67977B799CA09F99998C8F
8A88613696A0999DA19D9E88A3AAAEAE8145A7A3A6A4A6A6A8A6A78BA2A95A657276837B
717C85847B817A613F9EAEAEA3ADB1B2B4B6B4B4B56D92BBB8B8B4B1B1ADB1B0A96F6FB7
B6B5B4B7B5B7B4AFADAE9D52A2A3A6B3B1AEADB2
A8A3A092928294958B846166ABACA29D9D9AA4A0A6AAB1AB80689381868A8DACA9AEABAC
A7986A2D9AA7A4AAA6A39F90A4ADB3AE8848A9B4B4AAA3A7A4A6A07EA0AB5D667F8B897F
7D7D7F878588796842827C696D9FAAAEABAFAFADAD5F92B3B1B2AAABAAA9A5A4A5597ECA
C4BDB4B6B4B6B8B3B3B3A85E9EA1A7ADAFA8ACAE
A5A3999B8F8D91888F936A5CAAA7A3A49D9A9FA0A9AAAEA56A718C8A7881839EA7ABADA9
A9A26A3298AEADB1ACACA5A1A9ACB0A79840A5A2A7A7A19299A2A08A8DA56A779F9F987A
6E767C8F9285867369A09E9E6C808AA1A39B9D938B3E809F999896A19CA09B99996072BC
BCBCB5AFA9A1A8B0A09E9A559C9EA5AAADA5A3A8
655847393B424848493F262C607178746947494D494F4A3E2C3C434B4343464C524E5361
5E3E242B49545C4F4F4246474348442F39374D504C3F41313033414242434040464C493F
3038343B37393F323B3F354047432D21383B413D3B39404B433F443C233336353C443D44
48494833321C2E3C3736444A5459635D4E4E465B
B2A8A35A7C92747D9794A4AA8FACAAA7A5396888A2ADAFAEACAAA2A1A2A0A9587AA6A8AB
A3A7A0A5AAA1A8AF9E4670818D9A9BA09CA1A1A19A9A97499FADAFB4C0B7B0ADB0AEB3B4
9569A4AEABAEB7BABBB7B6B4B0B34761B9BCBAAFB4BBBDBABDBCBAA73DBBB7BABABAB6B4
B1B1B2ADA568A2B4B0B4B1B0B0AAA4A6A4AA71A0
AAA7A56478945C7A897B9295659E9E9E9D2D657A809D9A96989791949297A86688AAAAA6
A5A49CA1A09EA6AAAB5A7999989FA3A5A09A908E8D8F8A3FA3B2B8B5BBB4B0AFACAEABB0
97699DA3ACB3AFB3B8B6B2ABACAE4D82BDC5BFB4B7C0BFC4C5C6BEAD45B4B1B4B3B4A7A6
A6AEAFAFA960ADB5ADB0B1B0B6ACA8B0B1B279AC
A19D9F5D738A5489917F9381669A98989F375E79799E9C97918188909292945273A1A3A1
A1A093969293A0A4A14A69999AA19D8E8A8985848E8C89419BADADAEB4B0A9A7A4A3A5A9
A3659296A0A8A1ACAEACA8A4A7AA4C8DBFC2BFBBBABEC3C9C5BDBBB24AB3B1B5B6B1A79F
99989FA9A356ADB2ADACAEAFB1ADADB4B6AF76A9
A19C9B65718F6F9F9B9AA4807DA1A09D93435E838C9CA39F9A91908E8D938234759E9E9D
97A0988D88939799994F6388959A998F837F7E80858877428A9EA49DA4A69F9794919D9A
975B9786899D99999E9996979E9A3980A7A4B0AEAFACA3B4A6A7AF99518C8D99AAA79286
87888494985BA3A3A4A4A99A9F96A3A4A09A5D95
594B4A393B4B3F44484F4E3B4A5047443A1B243C3C383842382D3A4C4F533C1F465E595F
55554E4A4746504D4821374B5253524D51454843423A37202C2F2E263D4238372F293033
29264E413C3B3A41463630312D231F1E24252A2C26283A4041494C4D423E3A2327281220
27261F26261619201B221A0D162731312F292222
938887817D797474797D8430486B7A757B80767E7E7C726E68247C8A868F9DA69A989B95
888D832F5D7D8983797774646A6E6B6C75336F7067747880848A8E969690746E988C949D
999C9797A8A9AB65839A938E8E939A999FA29FA17A68989EB0B5A8AE9D9BA09A89A4548A
5E7C97A29C737B7D8BA2A06081A1A4A5A7A79C86
AFA1A1A19DA5A6A3A29BA13C8A97A0A49D968D9FA4A3938D822D8A9B989D9CA4A4A3A499
8C8B894B9B939DA1A6A39A9383867680963489898A87979D92908FA1A29277538A8D9399
9B9FA0A0A9AAAA4D9BA69EA09EA8AAA5AAACABA3825AA3A2ABAB92A3828E968F869A5A84
47909A9F99706D687093A66C7B939EA0A4A7A3A6
B1A4A19E96919CA19483853A69838F9A908883909E928577772E818F908F7E797F8B9E7E
6D76703D8E9FA2A5A4A1968B72837D8F9D309A9C9E9195938388819AA1946F5F96919C9D
90948F9EA7ADAB64A0A5A7A7A7A6A9A5A7A9A6A48D609FA3AF96AC9D82949A99929C3F4C
51868688895B68537499A15B7C81979CA5A09FA3
ABA5A59F9A919B9D8D848941788C858B8A878883978A6A61712F86939988797A7987A48B
6965563081899497938C8979768093968C4093978E838987899A8F938F8F69526562686E
6F7471798D95784F7E9795A1A5A5A7A397A6999B85689696B0B5AA959C8B979A979E3950
6492898B63485A507983833E6997A299919EA1A0
70676B6862636466535861364656545452534D474C4E373A401E515B646164625D636460
4F45372C56595A5F5B4A445146484B4B431C625E645E58525966525F5D45382F44433A32
3542505353552A251E49565848494B3D4054483B21252D162530293521202625291F0C11
1E25251B1C18191D27272D24262A322424404144
6755433918315C404F534D5C655E5D5D5A56494E7B726A67686D6B6E786D736C40606961
5F595E606061625B645E426566634B4D616E5E56595E653B426C7B787B7872757163676B
6A294A6675717E8886848A797882722B7B8594888EA69EA2A0A29F9C3E7A858F97979AA2
A39F9F98936774928E8681616A8A948D8D958B64
AFB1B4AA3E5D9353557F858F888C85847E775585BCBCBBB5B6B6B4B0B3B0B2AF5C7D8679
7169676561646B6C777D5C9A9497A3A9A8AAA4A1A2A4A9746AA5A8ABAAA3A5A4A3A4A39F
A03773A0A3A6A7A6A4A2A58F939A7F5395A29B98A0A2A7A6A5A7A99A369CA0A8AFA8A2A5
A6A59C96985C809E9A88909899878A8C8DA08B75
B3B0AFA8415988495479777F7A7C80777C734F88B6B8B3ABADA9A0A3A59AA7A562768785
637368615B53566162685595A19DA1A5A6AEA69BA0A0A5666AA7A7ACA4A1A4A2A1A2A4A2
9C3C718FA3A4A499A0A3A07E94996D52989A9B9FA5A0A3909FAAA1702593A0AAB0ADAEAB
A19E9E988B5476959A9F8B889F8A7A8EA4AA8C71
ADA8A49240487E4557827A7B7E707A797A78467EB0AA9E9E9FA09A8C90839392686F8683
6B7278858C9192867573588F96939D9EA1A2988E898B965A6AA3A1A199989D9990A3A5A2
9F35547D99A297949CA39D677A706663A3A1A2A5A6A0977780907C713E929EABA9A6A8A4
9F9E979E843F758B8B95847C91777A9F9FA8836B
806A48553D556B4D625D667767596C6F6554375697949089817675736A6450443326554F
4A514F655A5A6756514F25505A56686C606670675A525E414D7871646862665751636D6C
662F3D575C6D726F7272664B513928405659555E5E5F5A5E5B67574D2146556058575F5E
5B54544A3E2A43504553575354484448484C3238
603028545B51443E1C2253534B49361C0A515C6D686A42213B484C515B44295B5B5E5E61
4826576A71737A3F255A5A5F635C283765718177722B2B45454F53202A656C5D625F4049
686864613F1E4663626B732A477885887B662B6A818789884A426B848E8B5A0733544438
625319647B888A7D4A366D6D707C7E3E64828E94
BC6954AA94878990384997A4B0B3A3502AB2B3B8BBBC7D1A96A59B9A9A7834868475817B
5344838D948C905735A29B96A0A25561A5A6A9A9913E7C8B888C7E7951A2A2A9AB886374
A09687989E429D9B95A09E5679A0A6A7A698398CA8AAA5A45773AEB4B3B485157BA6A2A5
AB921E8B8F919CA4583597A0ADB4B44690AAB2B8
BB624DA3A6A0937F3149A49F9EABA85629AEB9BCB7B9741FA2A5908D8F722D889098907B
4733779199919A542C9DA29C9C9F5368A5A9A8A09443787B90946D4C56929AA6AEAA5877
9583848C824DA1A08E86965A7EACAAA99A9044A0B0B3B1AE6879ADB6B8B6890F6FA1A7AA
ADA61D81959DA09B4C41A7A9ABACA5438BABADB4
B76755A4A5A39D823C4C9F9E9AA4A45828ADB8B2AFB475229EA29C98946D378D99858B90
5F3D8EA4AAA4A47746A1A2A2919D5E67A7AEAFA2933B8E9F9186623A41767F8A93885179
8C7F838A8D478F9F988B9A6071A8A8A79C933AADB8B4B3B25C8BB7B9B6AA864481A5ABB1
B09F228A95A0A3A75F5CABA4917D7C378BA6AAAB
8952599B8A9A9B8C4724478A8E8B85491C4376969B625C2187878781783B274A59667685
5347788C92939049296E7A7B798C52516F7C797B6D2E75856853444833686D6369662F4C
6166636B6216004053596C44223D6E6C695A30555855484425555B66655E32155A747777
6C61284B5D69696F401C67695D4B4A3362696460
5F5A4E201325223D3F3F2C232C313A424916081521232A2D3233313C3D4040220A424942
392B3D454C4D4F56573D172E3D3A404A564D40363B51522D2144424C4143484E4E526263
5E223C556675838684787283868D6A37655164686C6E67556B7E81622C507E8886737276
726479796A414D6A6E818580735949698C883A51
A49DA0544A706A9AA1A0826D818BABAFA6400C9AA8A7A8A2A59F90889B989C6316A8A59E
947F92AEAEB0ADAFB49B21989F938A8391928E7482A3AB804DAA9B98808693959D9EA7A7
A33F5D85839595939698939E9FA2A26D9E8789A2A0A3928F8FAEB4B047ABA8A2A7A6A4A7
A2A29C96A3688AA19A919FA1997B52849EA93C68
9D94985260907494909486697E8FA6A6AA4B36A2A6A7AAAAA69F90819393966318A0A39C
967D85A6A6ACAFAFB1A1289998998A7789908F85849AA47E47A6A5897B78828E989AA6A8
A54767808B8C878489878590948C9771ADA0929C969D9C9195A5AAAF4C94A0AAAAA79EA3
A49F9DA1A34F8A9E9283969B98835184A0A44673
A9A39E5A5C9F799C9D9B98749897A5ACA85731A3ADAFAEABA7A2937D8D8D8E75189C999C
A1867CA2ABAEAFB0ACA1379B9DA29F85969A9C87849D987D5096A58B7E7C8A9A9CA3A5A8
A44958788E98857C7875828889948D6EA8A48B9F9FA4978D9AA9ABAB419AA7ACAEAFADAA
ABA999959453919B9D9D9C9CA3835C89A1A35580
9E93862D5198768E90969466817C91909C4E148B928B8987807D76685B645A480E6D7178
75745F817D7D74736D582A60707D646174726E625560653A3D737778706B606768605861
613A3B4F5672725E665C4D4437254D1B565B4F635F66544A5E5D6369225F706D70586970
686954383D4C505A6163605E5B463A4150492C34
3D33312D34383E383C200F12131310182535322A2D35313311312E2925221B22231F2327
241D13292D2231312B313F3F342A301D1D352821252F36393E33242619111E2D2F3F473E
392D3A36493D2D234F4D4F505D66665D473B4A4924475B5D5E58615A605B585457264560
6D7077788880746A6B8055306474788394999E9B
9499A7A7ABAAAFABA55B10777D7D7B8A91898B939C9AA1992F9D9495867C7F8794878F95
94752B989AA5A7A487A2A6A9AA9EA57266A6A6A49CA3A2A7A4A3A4A99147729A9B9B939C
96889693A1AC9759ADAAA3A8ADACB1AFA7AEADA75298B0A7A5A3A7A2A38D7C83A95580AF
AFADA698A69DA1A086A7764D998A9AA5AFB3B5B2
A085909C9CA1A5A59D8B2283909D9686877F8490929C9A983C92A6A3A188808B9494958E
9D8B356C727C76898A9A97A4A0A2A37F4E81887E84838B94908E9091925B5F8B8F9C9390
87848F979AA89068ABADA7A8AAABA8ACADB5B0A85BAAAEA49BA2AAABAC9B99A3A96087AD
ADADA79DA4A29EA093A8735F958894959AA5AEB1
A0878A95939E99968B7C3586959E9E8C8E7C6D8E9CA49E874298A3AAAA9889A1A3A4A6A2
A68536999FA69D80919884898C9BA2834D838784797C7F868E858D807E4F6E929098A69F
8B8F9C9D98A38C58B1B3ADB0ADACAEB2B4B7B5AD489EB0AAADAFB5AEB5ACA1A9AC5985AE
ACACA7A2A8A8A8A7A1B68568887B888186A1A8A8
A2929A9E8A8D91897B762780989DA69C9D998D80949A8365479EA2A6AB9F979DA0A49E96
927B308A999DA2837B7F6D6C6D8981554572777B796969736C6E7C76804C5E798285888D
8D7B8B8585815A2986938E8F83818285878A867F2D68827F8E898A70767E736E69314970
716F6B6555555A56534423293C373C4456625F5B
2C251A1E1211130B0D090A161A181F201D1D19131519141E382F29262525211B1A272824
1E1E171C10151A200F1D241621242D30343324231F1A132B343339352E384045413D3A22
20263339464B474D4436342F311F283326372E3C46474D4A4D4F23375C625E61636A6D67
68676E623A6D737A7F7A74716B70747A7D27668D
9B958A53AFA78484919D9DA3ADA8B5B2763C90A1A6ACA4A29E9689868B9D395C969DA997
908F8888879C9F9A2A82938C909098A09FA0A29E9E6F3AA7A5A7A19597A1A2A5A6A5A14E
6B989894A2A7ACAEAEAAA37B9144A0BBBEBCBAB9B9BFC4C3C5C74F7AB3B8B2AFB0ACACA5
8E9298844D88888B928F898B889397A09D3BA0B4
ABA7A94CAAAA9F9899A1A5A5A7ADACAE913E8D99989A9191928F93848098496F9EA6A694
8887847E83979A9124717579818E9A8E9593A4A8A6653CA4A29E9EA19A9594958E94A15C
638E9298878D9E97918D898B7F43B0BDBAB7B3BAB3B4BBBABFC16382ACACA1A3A19C9A99
7470776D4980808782847F7D7F7B859398379CA9
A69FA94DA7A7A5A2989F9E9798A7AFAC8D3F8C9BA5A7A49DA1A79F868E954666A3A8A498
8F877B787284999132747C8D8B8AA1A19F989BA39B2340A7A8A2A39D9395939E9E9EA663
567E8A99999EA49DA0A4948A9949B0C0B8B7B4B4ADA8A8ADBDCA6584A9A39C9898949291
7C7571675195989288847882807F899699298A96
ACA6984BABA79FA09897849081979B8F7940869CA8A9ACAEA9A59B9A9C8B256DA193A193
7574756E707F9994397F828A9488969B9B918D9D945542A4A9AAAAA39586799698989A68
4D788BA1A5A6949D97908B7C98539C9AACBEB0A498A095918D9E4D727E767E7572777372
5D574938335C63655B494349534D5353461C5E6A
5D473826373C383A37332C1C2126242A22103F474146484B59463633391A060D13131B19
1C1D1E191E201D1F1D171B1F201A2023192723252020212B3E3F39342C2308172B323130
2C3A3840535137241F2629373E3B3A37444B4E4C351E3B3D42434D4644443D4749491C3B
605F616B6A6270817D7C66397F797B80848C7A6F
989496999A988D98A0A0932269898596938C7E7C80919AA19E3264858688A4A398A3A09C
9C987E36879C9A9BA09DA29FA0A2A3A535817E80776E7591969391838271327B8693989C
9A9594A1A0A7A4567CAAA5A4A6A4A5A3A89A73726F50B6AB9EA3B3B3AA9E8FA5AAA452A1
9B8B7C7484767C94999472359A9A989BA08A8479
B7B0AEAEB0AEA7A5A4AAAB368FA9A9A48A77869B868BA1A49F3992A093A6A6A2928D8497
A08E794188A19DA2999D99898C98A5A939667E7E796C71777D7D7D7C7B8043817F7A8586
83908A939AA0AC607FA8A28B8682848D9B967E786344ADA8A7A2A5ABA6A4A1A4A39B469D
8D85776E7A75728993A178318C8D898FA0867A83
B7AEB1ADB4AFAAA7AAB2992A8BA4A7A2827881817E8C98A4A0379B988F9D969D9690848C
978B7E3D91A1A19F959B95979092A3A53362737F8668677278808288867F487F766E7881
7C787F7C9293AB6C7BA6A29A91939093A28C83846855AAA8B0ACAFA9A8A7A0A29D8C249C
A5866F695E6966909B9E7D48A29FA6A6AFA6A0A3
B8B3B4AAA9AEA9AAA3A09F499FA0A197897C7D78919A9BA3973D9B9992A4A0A58C907687
85837545939C93919E9E99978F949E9D456A6D817B80667475716B7C76774B6160636B71
6A737B888F969A697F8676838C8891968B7D6A664B4B8F8C8F8A8C897D7F7A7A7B5E176A
74664E3C363E364C5C5C462E444D4F41475A6664
6157614C45383E403D34291551504F43474951493C4447453F1A40493F3A3336362A1F17
18160F122A3335343A34302C1D2F311C2A241D1E211B1B232F29222E2B2C2E3432322B28
24295458523E2E393C3B3C3A343319304950574E585D5D5D5E4E4F2E2A404049484D5352
4B4F484E2E66708A9896A29A938B979685418590
857B863D56998C8F7D848796A8A39EA9A9343C7F7C83838385868E868F97945353679BA1
A4A89CA5A8A9A48EAA3C6B9A837B878F91827E7682837B167EA39CA793A0A2A7879092AB
7F5BA786A3ADB2AEA7A59C95999B4091B6B4B1ACAFB5BCBEC5C2C57397B9B5B8BABBBDC2
C1C1BCB45496B2B3B1A8A6ABACABABAEA3579CA4
ABB2B04A6B9F9B9085858A97A29EA8A8B05F5B9781827F7B77737E8179869851626491A7
A6A1839A9DA4A48EAC43718E7B797A7D7E7E7C7E7E857F208BA0A1A3979DA6A4797A86AC
975E96969D9EA2A39A9F9B919A933FB2BDB8B8B8BCBEC1C1BBC0BE6986AAAFA6A198A2A8
B7AEAEA857A3A6A3A5A4A4A4A2A5A7AB984F8B9D
AAACAA4664989C968B888B878F8D989FA758477D8A8A847A7875868678788B58625A83A5
9F9B77969B9E9F7CA13E647E74746F6F7578787D7879762E8C8A9791969EA4A687838BA4
8F4C9B999FA29FA39F9F8E9392933EB0BEBDBDBDB9BAB9B7B3B1AC54799A917675899764
A792948F5694A19F9C99989898A2A2A484368B99
AEADA341579B9F9F9A99A29F957C8C95A54E2E717784827D8A8D8B8B86868F5A4D648C96
8E926B7582918B6A692C437B7A786D717B8081786D67623E868B868686929AA79B94898B
5317858F85838B8C8784838D7F7938879C928F938782918F8E8C79406D58493B45494145
48363F3731464C554B4D484B4E49413A22132337
666C6133326066615B5C5C5A605B645A62353143433B4437352C3730372D2B2322282F31
22151612152E271E1711152B2B31493E4346483232433B121B23303F3C2C32403B322C19
1E2F372A1425353B4142162132312D33371B2F494E4E4E364B50657B8A665171706F6B64
236E746A6863292B6069767E761C73737A8F874A
76507C7A767E823536737B7A8C8B28519C9BA8AC943E6F999C9C91772895AAADA8AE5C2B
8D948F8A8A4622435A5D73833D356A6571706F302E6A79776F642F6D82758194580C7A95
928C9E7535AAAFADA49E2776ADAFB3BDB62EA5BBB9BBB7569DB8B9B6B28471A9B5B6B4A8
35A9AFA8A7A7416CA9B1B1B4A11F8077616B6C40
9354ABB0ABB0B15D70B5B7B8BCBD3662AEB3B9B7B74783B5B3AFB0832099A1A7A6A86542
A4ABA9AEAC59365A676B6E6C35357575776963282E5E6A6E686522667A72718C5C0D7A9C
9C9A946256AFB1A4958D2675A9A8B3BBB12DB0BCB9BBB95499B7BABBB98571B0B1ACA8A2
3CA8AFAAA4A44283B4B0B0B39C22877A677C864D
9456A4ABAAA49F4F79B9BCB9BABA4B68A4B4B8B9B73F86AFB0ACAF9837ABB1B1B0AB6136
99AAADAFAE5531595E5B4B673F468C87807267282F575861636125748B847E925F0D93B5
AEA4A16763B1B2B1B1AD337FA9AFB4BAB534B7B7BFBFBA549BBDBAB6B58973A09D9C927F
36A6ACABA8A33F80AEAEB0ACA637AB8B8791874A
945AA4ABA7A7A25277AFB0B0B2B85364818C9FA09A3188ADAAA6AB863BA5A7ADAD9B5A58
A3ABABB0B05E706573546073596FA499877D6F2C2E434A4A3E411C8B99908D95551C96AA
ABA3976F539FA9A9A5A338687473A8B3B23685828881753276837F7F6D41516D69665C56
285A62625B46234351524943321E3F323531301B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
78668C7A9191A8888F6B458C5E8B6D57667A7A4D647256946997954C904D717172D7845F
4675ACCAA4B2A5A9A49B7D656B7CA6BF719B95A5CD8FB1BFAAC34C89638B837574A0A97A
7654ABC2ACA47851E1A07C756360A9B799518A938E8992C4774B423E7583575B777E7082
5C675F7B938D8E9A9BBC7B9CA66D465C5F8D8275
71547B77868EAF7A887653885B7964536C868C505A65518069948D488D58818678D08D68
4B77AAC0A6AEA0A5A0987B687176A2C277959FA9BF78B9B3A2C35582618F87726EB0B17A
8A6998BFB6A5755BDC9C6A76746EB8B9A3618A9D939094D47F4943386A745C585E61658F
6B695B829594A29C9CB191A4AF7A50665F74817A
7F6081708579875D74663D745D8860564D63985D565D487E739B8E4B955C77767ED18369
5371A1B39CA59AAD98998E7D8585B1CA71AB95A2BB7CBDAEA5CF5C805F7E7B686CA4A276
7E7187C6BEAC735FD1945D837977A2B9AD6A7FA18B8494D783444431648D65655D677076
53675E788E7F9696A5BDA2BEA96B4F7A6F6E7E72
6B567D707E75A469856143815E75515958727B5D49573D7A72998C4A8A5C787677C08B6B
4A7CA7ACABB89E9D91997D6E6A6F98BD71A08F9DB976B9A19ABF5D8267867D5F5CA2BB71
868581C3B5AE6976BC8C5E78766D95C8A963819368707FBD783B3E3058806D7079856B7E
5A5F4C6F7F77A8657E756A7F996E575A73827A7F
7767878194889D5F88764F8B62966475647C8367505F427E6B908B4B825F777177D09A68
477AB4BFBFB79C9D9798867C767098AC6C9995A8B47EC4ACA3C55A80637F7C6C6F9FBD93
88848DBCB2A76671BB8A5B85897AA0C6A1706C9461827DAE713634314E70736C89817997
6A755B786E79A27AA4A280A7B47B5C526B7B8976
80608A748F81B26B8D7955886591515D6484926E5D59547D6A9C9A4A8356716781CC7D5D
417CAEBCBCBA9A959AA2847C6F789AB8799E74BEB983B9ACA8C05682607D8C545D95C27E
807484C3BBC8797EC583578B867AA7C9B76F8A9A71968DB97D423C3C53797C6E8B8B8295
6969787B9795B287AC90889DAF7C505F64798368
866E8B6C7F7BAC5E706A43806A803E5E54778F6A6159477965949E4A885B8D7C7FD2845A
376494A69BAC9FA09DA6837571719AA66AA277B1C57FB7AB9FB54E755D74786F659DB27B
7F8599BDA9B37577BA92638C8175A2C79F53B6A96D8F92CA7F45373D4A737A7088907C97
69776B737F7A96729A89879FB18651676981667C
7F5C80677E8DC169936641855D8E4A5F686A837E5E5845676F9E99498360867580D48C64
4186C1CAAFB69A989F93777464749AB05E8E91A9C97FAEB09BB24B76607C7F5D6B92BF7C
838397C1B1C0777EB887608E6A759CC7A86380A063828BC27C443E42426E7C6F6C856F8D
656763797483BB86BF818BA5AE7E516970868E7D
8976986D827FB064736C4A8D6295505D788C936D544E5265739E9F50825F7C6F7CC67E5B
3E77B6C6B5B7A4989B8474747591AEC6779A99A8CA82B7BEA1B14E84678283636392BF86
7E7680AEC1B17A7BA9885D84717091BCB0738095667A8AC4814A3A3F3F697276868A708C
675C5F839891C57CBB7380928F6751526D959479
7B5E8053878CBA7782724F935F9C4D5A7B7E92755C4C47636F949C457F4D718183D6875F
426B97A8A3A28B9191808167698398A5789898AABF7AABB49EBF37716383856963A8C49A
79807FB0B6B590849B8B7A89787196CAAD647B975F5A77C57E4638393D5A4F5B5E7C6091
646965768069966DB773929D92774B4C657A8783
7D648F5F866F7A757265437F609A4C568E858E644B464A5F78999D4989596D736DBB7B54
3D6B9CACA3B09B9D978E8A6B707B99C2809B90A9C083A69C98BA39654E67655E6594AA8D
5C6F7EA7C2B4847D9A9E8D7B7B638DB6A4588F84755B70B5934C3A384F636C6A76726072
5D4E5C7C8886AB92CF6D878C7C67505D5F657070
82718F5276738E68716745785B8E49529682997060575D64718C9B3F854F67747ACB8B6B
467DB8BBADAA8B9796868562717A9BCB779987A6BB9BABB39EC341807189835D5BB7B589
5D6188ACD3AF87778C9BA370605A73B19D639BA0795876C3A9554939577B70796F746E70
7963776E7F9A9B90AB487895968166596A698B84
8472955F7D778A5266624774679048488B7A926855484B4F7D968C437B5162687DC6915D
3E72B8B6A4B39B90988D7B5466758BA6638789B4C1A0AAC0AEB03F725C64736D4E9BB8A8
745F8CB7C8B18C7291B19B6A6F6398C7A07894968D6773C6B05B463C4D776C7A5A685F67
8A6368738B98878CAC508EA0977E7C6C646B7B72
766A835884819261715B436B697D484890718A716349615E829A954C7F546B6387BB8758
3467A6A6A3ADA1969A8B6B536D7994BB648F88B3C7A69BB8B9C44F917B7479736C8BAF9F
7E588DAEDABC70659BBE996B7173A8C2AB79A8A69A6978B2B6523E4A4681736F67736562
796A5563727E8D9EA94A888D8477625A7567877A
647E8446887E9158705A4F73707A464D877881714F47474B7A8F915682506E5E8BCB9E4D
2D64A2A7AEB39592A1957970717B95AB559587BACAAD93B1B6BA468A8488828D6D8ECC8C
6F4D7F84DAAD735D9FC581696170A1A8A185A19E855B6AA3B2603E4C415F747F70695D77
5F67636E899088939D5299A4A18C7A5F5E686765
6A747746937D815D726D5C9072794541907978855949455C73949C557E48606193CBA55C
3B739DB5AEAE939BA6A47E5C7C7D97AD609480B7C8B296B2B5B749807B7B7E8B6D7AC58A
7A589596BAA07A658FC77A6E6D6F9DADA9858E8D7F7690A5AE5F3E5444606C76727A6677
726E5C75859E8C819B5486B29D8D8B6A757A6E68
7A8A894B7F7A7C547B716A877D7758465A6570794246525A658F92558F5D786089CDA765
4B7EAEB1BBB18F7F8C7F644F78849EB76EB07BB8D0B398AFD0C15E86877E78946D74D886
715494AECDB8898E97CA6471776795B5A28286A383618BA3A1654D454164736F6F787880
77605B626A9A867C904971909880745A7C78626A
7C8E87458185764C6C687276837E6D4D7371866A48413D616D927C427753735D88CBA16E
5185A0BAB4A68D989A7F70586F7C9AA561A080B6C4BD9BB1D5C15F8B8E797F997862D396
7A53819CBAB4807E95D86B847C74939ABE9488897B7391A697714F3C4F69616B6D7B7876
6F7A646A5C938492B25B8CA69F756C5A74687169
7FA386467F8B7456816B78797E7A644B88828E6F4B4E566D6E978D3F894B73538DCBA356
416AA6B0AEA1848593826A546C7291AC5C9885BFC9D0A1A5C3BB6584917874967D56E38B
77556C93C5AF948CA0D6666D736E809DC0908BA982607FA19B744A334B635B7D6686787D
6B71677778AD949DAE5E7EA0A2897057645C7266
7AA97D5077816E54735A6B6C776E57467B8594715B4B546B769682557D426E4986BE8060
3C74B6B7A7AE9983998D755F6F7AA0B564A087BBC7CC9697B9B97C7994757B95714FD08D
7A6A7F9BBCB58B8A89D95F757F7275A7BF8D759C755B699BA2724533395E64785B786C7F
64745E6D729B90A1AE5E97A8AC84746B626B7972
74A17643788C73618668787378694D457F8196736A5550606C9F956E90577E5187CD915B
3A67A6A897AB9B759589735969778BB9649E90BEC8C5888BBBB07771906F70926C5FD075
7E6F728CB5C4878A79D36C9C7B78759CC8956F877C5A63A6A765433836617D696A6B787F
6469597476939193A5559CAEAF8A705870686A5C
6B936C406C6C685471697A6B716A47437180976756564C5F6C9A8661935F825F7FC39B5D
4069959DB1C0A29BA088775A6C7A92C468A992B8C7CC898AB6AE7A798E767A975F60D27D
8872719EB0C5999276CA5897777374A6CA95699C775F78B1B5724A434167755B6368778E
786A52787398AE8FAC68829B99735E67696C806F
71A7774A7C856D58805C76737E63545E7376896D5C44475E74A08B558C567E668CC78A59
2B5EB8B7B2BA9B97A588795A747E9DC964AA96BFCDD48F8FC4B581938A7A7D9D666BCF82
8887719A9FB8927C69D969886A808FBBD6996AA87A6F7EA2B56D3E393F5D705A5B626E85
87594D6D7999A38EAF84829AAC7C654D59597356
6298643B6E78695D84597B6C7B604653758C8F7066584E6174998A59995481707ABF854A
5259A9B3BEB98A9E998B7558677C8FAF549484AEC7D99393C5AF868973726D92606ED790
8F946EB6A3C9AC8170DF6F927B787CA7D09E67A589767A97BC74414040608A5E4E5D6766
754F547E7995B695B08085A0AC85625A626B8471
62A9754C7A85765C887C97787064435F697F857358463C5D728F92809E5A7F8282D18763
7464B4B8C0B8A6889F8B7559708793C45E9785ABBBC98484BBBD82867C7B7D9B5768CBA8
899067B8ACC69A6C52D97F90879395BFDCA175B48D8A739ACA6C45433C5684535D686D5B
7F4455706E8AAA80B78D8898AE7D545C6A577A62
679D7244707B654D6B68796C735B3C5C7C877E6D5058567C6F988B7A944E706676B16C5D
5960A09B9B9696879189755A818097C761A085B7BFD38C91BEB784786F7B798C5C6EC39F
768F5EB5AABC996050D67387838690ACD3A26DB39C987894CF68403A384C7D546859695D
6E4F616A79A9AC9BC09791B1AF7E5F606954765A
6AA96C426D7565597F69808C8A5A395E63818D795E584979609FA483AA5D776E6EBE8D5B
5973BAC4B6AEB29CA48B745670839EC35EAC8DBAC0D69389B1B38D767077768C6373C099
6F8760BEACAEAF714BD67393757B719DCE8862BDA496798CC76C413737536F65686F6875
7951685C889BAB94B79F5B7C987B6B5E625B9160
6EA47146768373667F759284805B426D5B727A6D4C434D5E5082897D95566F7980D59064
5C70A8B5BBAFAA9B938777637A7581AF57A69AB8C2CA9185B6B3986F736E848A7475C5A3
627152BBAEC6B37A47E08190828C8BB4DD936BB8A993717DC4764839394062785F83777C
6A5E6A6380AAAB85B7BC748FA3845B6B6A678A77
5F967B4C7376735E7F768B65664E387169878B745A55407255928E7E9C6476757BCC8B60
516EA9B2B2A2A690917E6E596C7993BD5D8C8FB5BDC58C79ABA197786D7793847788B89F
577250C3BAB6A96A40D07A9E81776897C79073BEB7826E8ACA8F4F3E2E4471956880767D
765978607FAAA691BEB67096A69168765F748D79
678C7B467581745777697F787B434560537E816853504477609A8E879D7678767DCD9762
6272A3B9B8B3B09AA58C7E617E8390BC619587B6BCC28F92AFB89071727892817D91BCA6
627A59C2B3A9AC7C4BDB768F758482ADC67F679EB2746986CC955A4716378A8E5E7D7E8C
806264508EB3A29FA09F6486888A5B7B74819976
5D8B7A517785805E807C7971764F4D5955799061535A447B639EA7849570737673C47F5A
737395B8C1B69D798E807556727C9CB76D9481B2BDC3907DAFAF8E757081927E7B8EB794
59775AC6C29AAD8148DE88897B8389AED5977DACB8677C71B3995C4133246F69536C7385
7956684260949B8881B8738C9B895170697B9D84
65A3744A7D9E875E7C7D94827C5C4765677B704B5D4E426F5896A78C9E7673796ABD7956
605A7AA0A7A6957A8C7D7257787F9ABA73988BA2BAC59578B8BA9D7E647793848592BAA0
5C745EBEC7B7AB8444D7958C847B7EABD59084A1BE67745BC0994C433534686152587F73
725A67516A89969594AD69A098985759485D8A78
5E936B4876896F56817D94817B6258686889A5525055497A52979D94A373757C72CC845E
71697FA9ACB18A8192838153739699BF8E9E95A2C4C29C74A9AEAD797194A67E8886BDAB
636A78A2B0A4967642C986907E706E9DC58487ACAE6E825DA19C51434A51636C64475C56
73506C4C5F7BA18599AB648E7F9C59725D7D8E6F
649E6A446C9E8F759A8BA28E79535B67688F9D5F5D5A467D55A09587AC7776816FD39C64
796B9DC5C0C78F8C8E77785B86919FB29CA58E99D5B4A98EAEA38F7D7B94AA869891BFBB
79597CABC4AB9A6F3ECA858981706EA5C787819B8B744C569A894B33344B63616A4A685D
6C57664E59959C928B9A63A690A55B66677E8574
659172466C7E88859B808F826D5B4F694F758C595951436353968B83A3715F736DCA836A
865D88BDB7C1929B908181558081AB9A98938E81DAB5BA8FC2C29E7F737991819A8EB7B6
725694AABDBFA07943D68D8D7D6E6C9EB88C8B9E87936A5D9297543E3B5B5A59664C675C
84455D604578A08F859C6FA985AA555F74878D8D
69AE7C558AA593779C7E917F80513F5C5E7378545D4F417F629F8D90A36B65605DC58D66
7B5A73ADB5B1848E8A7E8B708F88B0A396909979DFA9AC85C1BE977773849681AE87AFBD
765891ACB9A37A6B3FCF978A89787EB8CD9596A485A4628DA29E4E37354F564A6B596253
8943505E4F768C998A887CB79992625C798A8473
549365447AA0A084958D7D7E6F57465C5E8084486559478276A28D95AD7A6F6A5DBC8575
7B618EB9C5BB899D908390787A77A799996C915ED8A5A696BBBD816C617B8575A06D99A0
72518CADBBA68F6B43D2967F806F72AEC39F9AB28FB574929E8C463533434C466E6A544F
83484A74567A928A8A8B88AA9D9E5E557C6A696B
66A079517FA39F806C7E66736D5F3A555E6D6A466B5944685A9393A0A37C6F6C5AB3897C
775A7BAEC6B5898D908291857B80B29699839B6CC6A59FA4ADC19179768780738661A1A9
6B5080ADB79A956A4FDD7E7B6D656DB5B89A80A792AA5C8F9E894D3929414A3E7D6C5B6C
75674F78797B99998E84919A9A9F585D6453746F
67917266819B9C897B956D7D77664D5A837A622F52464987548994A3A47B6E7065C08782
6F5B84B8D6AE6D80897894806D65A273AB99A75FD49E94A19AB692777E8D8E828C739EA7
766D779DA696936151DA9073796678C0B5A587A380AB63838F9060342B3F413459665A67
6A60516270789D95887B8BA5A689706A7B5C7365
749A7C5D7A909EA16B7F667673604E648F97833970725F7D558F8D9BA27A6B725AC28881
7F5D93BBDAAB534D806D8476666EB183AD96A159DFA29BB897C98D7C81938B9FA280A7BB
79817F9EA9AF8B5850D288636E5671CBBEA9839B8DB5637E9FA476433E5352427B4C4F6B
66564544507FA19789918E7F957E6E7286637177
658D764A83A09D80787A5674735B333B687F74335A6352765A9194ABB491746C4DBA8B80
845A8FB4D19E7A5C7D7185935F6CB18BA695AB5CCB9492A689BC8773667973889777A5A9
72817C90A0B9967162E1936487677FD5C0B57D9E81B7727D9DA7773B3A464E407A5D5057
505B635B506BA2899DA59298BC897D6C77517F71
678574468EA19B8F967D66857F61454F6B916B315F6A658A619799A6B08B6B6C57C3887C
8C4F90BCD69F7261847A878A5B6AA283A1939967DFA39CB39BCE8E847B8679A3875EA3B4
7D7E7789A0AC806E62DC986F7B6A77C5BBB9819F7FA97F83A2B17E4440606A5A8A746364
5A625E4741809BA28FA37E84B1809669775C7A7B
688D7E4D9499968A948077858262535F6E937735596E65755C8D95A6B19674705DCA8986
8F4999C3D3A16D668D85868855689B8C8F84A06ED9B297BE96BE777471816DA07F5BA4AD
7987757FA5AD7C7355E08C6C746986C3BAB76FA9809A857B98B976403C576E5F6E6D685E
576B62594663919E96B6778FAC80825D74728875
7A8D84529C9C8E8C8F706D686A5D4E5C6A906D3254595476569695A5A69370755CC69C7D
764694B5D49374689F927C9C666FB1ADB0A2AF76D8AAA0C0ABC77976736F4E7C7265A6B6
90867486A7BD6F8058DE9977826E8FCDC3B36DA1899A787D87BC67382E455C605B6A5A59
585F6E72567998A58DBF6F87AA7E6F544C5A5C5B
71887C528E9B74828E6C70795B594A557698853C6659537B589E9DACAB976E725BCFA98B
7B60788DC39A775E8D95779F5E66CBBAAB9CB17DE0B1AAACABBF7C856E7B4F987872B7C3
A4967E8BA9BA607D5CDD996F756573B9B3AF7E838096838C87C159372B475B59514E5455
4A766980646990AE9BD65F8CA5946C47516F5F54
7D9B8D4F929E808A9F797B7E5C5D395983926A31453B566D4D998FB2A38F595B56C99685
736F87AAD3908F709CA185A2635DB6A7988B9B7BD0B1949694AF8478757C519C7584B6C1
8D9A6B7F98D6648263E193697B6B6BB0BDA95E8C919A7C8B85BF4D3A2A485D6E4E5A5052
5A726C92546991A172C1569FA18E7E5A60857468
6D877F4787997B88937165735561665E667954214455556B608E88AAA69B6A625ABA977D
85587EA9D3839075A4A28A8D6052A8A69B90A189D7CB989998B28C886574527B6A8FA4CE
8380638294CF537B66DC8F6B715C6CB5BBB4689A9E98818E8FCA54412A4C75645B69665A
4C7B5877485277868DCB609B999D5E5764846A5B
7F91804B8A997D7B896168775A605B6770746132545B577C448C88ABA89B68655FC09A8A
6D438CA9CC8A966FA6A28B8B6D6AA7AB9A92A897C9CA8E9396AC958C6E745699788FA3C4
7580597B9DDC587F70E299717A5B67A5A9AE658E92958E9899CC57432C3B655757716659
596960882E5D858D6EA6698EA0A15B5D6D7C5462
7394864C91A38683947264705E5C6163849A7F3C6E705C894BA094ABA89E5E6462BB9787
67437CABCA90966CA1B08484656BAFBCA3A4AA96C7D9978FA6A8A78F73765E9B7C978FB1
6F875E6F91D24E675BB67D65746076C7CFBC71868891827C85C15440273A5A5357736369
5C5F51833A3A627E81B67D8398AB4F5C6A6B5363
6388774F929B84898D64686E565162607A8D713A6761537F5C8295B4A99D65696EC6B598
735B7D90C2A48E6B969F7B6D6864A9BEA5A2AF94C6D08E8FAEA1A5826B6E5899729289C9
6A7C5571BCBA58766FE2956A6B5F6EB4CCAE64999C8C857B74A94A3C2635494C48716861
5F6B6675416BAA9CA8C59D98AAC07E7B7B6F677E
5E897A518FA28D898D7069747B4D4E56707069416263648A9DA392B49F95746067C1AB89
5D607699B3928B709491715372749FAF9395B097BFC1838AA998AF7D867B609C719686CB
867E557998DD6C6E69E3937273637BC6CDAF747B928C928186BD5E3B332D4E5F59738C81
70695C68374CA18884B99E658A926A80A76A6378
5C927A487B8F7789805E4968665A5B6E91967D42616C5F96A7B399B9AC935E526CBDB191
6963778CAB998E6F9F867C54876F99A293A1BA869EBF9894B1B5C0808D81699E89AD81D4
87825878A3E1736464DF91776D6871BCCBAE768A917A736C82A16439323050594E6A8478
7A6E7060523F919F8CB0A061889A825D5D37546C
609973447C81757D7E7955706049546689887A41675B628A97AC99BAA598745474C0C196
686D8598CEAD9B81B9897D6192809AB1B0B5CB8EA6B69483ABACC2768884779483986EDC
7E6D63899FDA655168E098767A7D7ACCD7BB909CA58F9A829EC97B3A342F4C5957767579
67656E4B5B568B9788BBA5658798886A634C6B86
5D7D6F45869C8588907A557C7353466A8767583A5E6D61828AA182B2A19B73497ACDC48A
616C8299C3AC9A71B686876E9579A0B2C4B7C48EA9CCA593B4AAC5607D8587A68F906CD9
8464617AA1D45D5358C7926D787C76C3CBA27CA8A8919788A4C574393C3151545A756573
6758504B5E4C5F987995867479849870705D718A
6D907C4B8D8E85899B6A486B7A6244708A827341536B7186A49E87B09C926D4B77C6B982
62657F9EC5AD9E6CAC7B81729E728AA5BCA1A7819CBEB1ACB8BCCA5787968A8C828672DD
7B637387ACDC614864D7865D746F79BDC7A16C89A07E8D8798C2793B3D364A6165806C77
70755A616A5B669C7A987363718F926668706C8A
708D7D4991B29D9597684C72675D4A6C7A8571475D6F5E7490A991B7A18C6D577BCEBF85
61799CB0D8C0AB75B072837A9B6C7DA0B58B8F8686ABA3A4A8B0B7568E8B878479826BDB
7B5D7994ABDC80576DE69A68816E83C5D0BA7A8EA88D8E8CA3C38043473F55687E887983
718260647662537D91AA846F908091716D728188
72917F52849F8B9191774E7D7B52405D6F6D5F5163695D687F8E85A4936F5C4863B3A46D
566F94ADD7BEA574B1778A818E5F8DAAB783A19697BFA7B1A5BBB55F8E849B819E7B6DDB
8C5B7B929CDF8C566CE4A26C866A80C0C2A16F85A28C8E97AAC3855246464F618C857A77
6C8C66657C676E828A97837C96967F676C928CA6
78A67E5E81A6939682644A6D6F5D435D817173585D6962788DA293ADA482623E60BEBA72
5B72829CC2AC8E629B647B7A7A5A82A4BA8C9999A1B1AABE92BFB267A58AA27B9E886DDB
9B5F8EA68ED47F4F5ADB99657D6A7BBEC8AB6C8AA5898C98A4C38644414D4A527E8E706C
6A8A676B61519B9F9B91716C9B936D56587E83A1
6D907662819B8F8D7B6B557A7057536C93807250516A677984B19FA39178674B65ABA466
52638A93C9CA966CAD6E908571657EA2C183998B9DBAA7CE88ADB463996B7576946A65D6
AD5E928C8BDE955957E3AA66886E86C4CEAC6A87A184889194AB77453E4B44486E7B5A52
617E767364576C7B9C968C82A5A67E706F80807C
6A8573508A9D8C90756C4D827857505E71706D4257796A7788B8A6A39E745F576BB5B872
5D5C7687BDB88C539368818660627A9FB47B90889DA995AF73A197547463837989695FD1
9E538E7B87CC955150E1BC738C6578B3C1B372949E878191B1C8764142464957737B685E
65786B777463A392AAA08184A0A6615E72847E91
748184487A7C6F757F62426C7256437C876B62425275595C81AE998C8671605571B0B779
68758A8BD5D3973E997F8D8F5B6A7DA5A984A390A0AFA1C57AB2AE6C91758495A57A78D2
C159898BA1D998444FD5A86F8463729DB19E6381957B788AB7C57E4646424D5F828B7A61
627C7160616B9795B1A48291AAB2806C65675B76
7C85955EA3AA88919A8256888B553D6394755B5A505E616485C0A29DA778665C639E9462
6373858DCCC99140A88F9A8F586E79ABAE99ABA8A2B6A39C72BBBC758D7579899A7875CB
B65B778D8FD4AD3A54DE9277896982BCC5AA61868C897A84BCC987494E48505B8072795C
63876F70664D70829EA68687AAB6868C7D655E63
6F6F7F4CA9B0968E977253686C593E71988A6F594C52656176C3A089AF7D6D7171A1A887
6F7B8487C6C08947A590A28B54727EA9B39AA99AA1C0978666A2A759746E7E83897578CC
B77B8A90A5D1BF645DE1B37B866B88CAC2B56E909D9B8E91BD9DA4545252555D85876E63
5B88717D64406C777E8A8480909D87A167696A6F
7077954EA1A1938FA3676781644A32576E755E4E4F51775986C8A688AB7974718EABB585
7E8491AECEC39448AC969F944A7D90B2BDA5B98994C1AF9F79BFC07B9A718298AD6F7CBC
B69B74829BC4BA5A60DF9E8089647DC4BCBA76989CA58992B7949B5D52494B566674616B
4F7F755F744D6D7BAE98807DA2967BA568586758
7C8698519AA997929B6C5F807B5B44667F8273706E5A906886BB9D84B578787D8EB4C990
8D8089A1CCBC934499898F89497C8BB8CEA4BD9390CAAB9F72A8BD7C916D7D7D9C828AC1
AD9B6D7FA6BA9B415BC39882766179BEB6BC729B90A86A98A4A08A6959514B5174847B78
568A87697850868A8B959474757A8395525B665A
6E7385448A908087906C57727057497281856F7B6D55835A84B79888AE7B7B817BB2BC83
837D9099D4BB934093889282467B82A3B9A9B09589C9B5A176BFC47F866F78869B7889BB
A38A6979A4B8B9516AE28586756671B8ABB2768C74AB5F97AC9C91564E4E4955667A706A
568B91686652728A999AA77C757E928045646965
7680864A8E988A969879557C674A416C9188716F504F5D5468A28F82A4737F7B67ACA76E
7F72809EDAC5925DA9989D87487A8AABC3B7AD9180C4B3A286C2C489897C8088988377AE
B491777CBBB8B05263DD928A7D797EBBB4A56E7D7491598C936797574B41445B707C6E5A
577F85595D4F6D8060709C647D768D7741647273
7183864F899588949673538B74514166777B6D7249505F607DB8A783BA80878F70AAB076
9361719AD3B69A62A19A96874B7C91ADACAFA3888AC8AE9A8BC7CC8F88766F91A59289C2
B0918073B8B4AE3B65DC9995906F7CC0BFA577888382779BA66E924E523D46607987745C
69878E595C4A56758685A96F767D946341635564
627C7D4A859A9199947A517C6E604C708D8F7A7949576B6885B39D7FBF8B8F82709FA47E
86636CA2D5A9A1679AA780834E8195A5A6BCA2926CBAA78E83BFBF8178746A83928E88BD
A9827B66BAAEA9266DDE84A2826970ACA69A857F8C796C83A071995E6C404F6186947561
628CA1545D56687E7D83AF757A838975566E655E
5D817F53728C8E8E7E6A527D5F66577B889776805C5F76678AB1A18ABB828181709CB589
9C4E6198C8A9987097B182705272978FA4BAAA967DBC928F8DB7C78C747D6E929B9C86BE
AC82745FB7A3A82E6DD47B97816D73BEBFA7B9758E8A8180838B986C5E3D505A688B8667
5D877E5855475C6F798BAE7C7F797979485F5F6D
658C84527CA09D938879617C6A665A6B73834F805A4D6F638AAD9A86B083907F658FAC96
9F566DAFCDB7B57798C07F775084A39BB3C4B0AC82C99E8D92AABC886073697D91998FC2
A67D7A58BAA7B03E6DDC85A1777171BCB9A7B28B9E84677E7496946A4935485A56797E6A
5D8B8D6568706F7C9493B387838386694D61576B
708D7C5170929299927D5F786565505443826B7842386A5D73A69D7BAD8382816D94B18B
96515490A696956E7EA27879538BB695AFC5A49C87D8AD8F90B9D0A37B7F768C7A8F83A8
9673654DAAB6AE436FDA7997756C6BB3BFA493928A956F966FA6977A593B514F616D6C6F
648A84716D6284818C87B6808386946B42576054
708893597F9696978D7D5B6E706F768369806C69453672738CA78C70B4948888638FB391
985F63ACB5B3A58486B1807A50849F8DBEC5A29781D8AD989BBACFAA7677669381998EAE
A6906E56C6BAAF4C6BDE76AB896C68A9C6AB7C908D92729368A9A3734A374C4B7965686B
66827A696C72838DA3A8BA8C8578937E565A5B59
7793985A889EA19C8E75596B686269756C826673584A66788EAA897DA37B67775A87B897
946462BFB5C4A7937FA7857E558DA99AC3C9A49980E0AFA1A0BFD29A758565A5839B8DB0
A98E674EB7ABA5535AD06EA4806E61B2CDB2838A8C86799C629FA2734838474880527F78
68886E6E637598968B96C0938C8FA3946B6A6565
7287804D889A978F92775E6B706B63795C807D512D51647786B28C86AF957C6F4A6FA28E
825D50ADAEBA9BA2789B84745B80AC97BDC1A99B7DDDAB989EB7D09F6D6B569782998BB1
AD9C654BBEB7C1535CD46AA27C656399AF9E8782809579A460A99B6C4035484E765B7175
79967579626980717B799A747F79968D71777A79
6B917D4E839A9A9A917760746E52706D5D807545564F547B89AD8F72ACA0866D5795BA92
836746A7A0BDA5A37A968A79728BA1A5B4B8A9927CD4ABA3A6C8D59C78805C9287A188B7
A4935F50BDB7CF556FDD75B07C616FABC29D78859A9875A05DAA9F623C385953575B666D
5C8E6D51737D99958B88B6838586887E565E5D73
77A07D4F919CA0958D7F5F6B763D6B7B69A185777C5D518387B28F6CAEA289725486B59F
757549C1B9C6ACA47D9897767589A5ACBCCEB0937CD7B09F9DB8D6917280619987987CB2
9A8D5B55C5A7A63E60D774B97F7876B3D7A57391A4977A995CAF996E3A4467745B6A747A
749575787A709F85A69EB0747586787374784B71
66997B4B939C9EA18C7B5B7679847977629D7B6770574E7C86B38F7AA9A58B736CA5CCA7
7E7B4BBCAEC7A7948580736A7582929C9FBEA28B7EDAB4989EB0DA9477856692859C7FA4
A2A9645FC9B7C64670D776A67C8071AFD0A67CB0AF9F86AD5CB4A1833940636D4B6D6773
829873757D81A1A59E88AE6D70837F8C746D5E82
6DA27B4B95999EA48B79577F7C777066589578566B5B557A7AB28D87A8A58C645899CEA2
7A7946BCA4BEA67F7B7E8078888D8C92B6CCB59978DBB697A0B8D4A2768C679687A18BAF
A791595EABAEBB3A7AD479B577847EADDBA57A92A89984935ABE957E353D5C5B4C53505A
5D77566B626C899E9F88B4888787728F70736A7D
6A967C458A9496A6837459847775636D588C7E4A5C574C7571AB868FA2A083665789C79D
6A6242B49BB9A6867C7E735F807C9489B5BDB1947FD2B8AAA1BACCA1797E619590A091AB
A68A536197A9D13F91E47EAC7A837AADDAA49A8BAE8F979073C4A27F3D4063625F676875
6D7E60656B5C79968B8AB5847E9280857477778F
7E9C804D8E9699B1937E598B7B7F7887619270626E524A7986AE8A88A099735B578EB597
667547A79BC2AC89778586758F739B93B3C1B39B81E0B2A19DBACEA8758E68998CA191AA
AE975C77A6AECF2F8DDD7EB2887F76B4D59E9696B0939E8B7ABFA0744B436062546E7575
717671726C8597A3898AB196869E7988756B6B8A
769781559EA3A2B797775A93797272775C8F845A7769608F90B1989BB8AC846A5FA6D0B1
6E7853A093C4B1806B7888769B658B91A3A4A78E78D5B3A5ABBAD8AD7B86609686A48B9C
9974526F8FA6C0329CD87CA0837A73B9D19A7AB1ADA2A98F81BE8963513D615F4B617D6B
69736E6B737F8AA1969BB28E7E825E656C5A5C7F
7296825798969FAD756F59826B77797376A08253636D5C7178A68991ABA1766B5FABDDBB
687F509F9AC0BC826E81917E9A678B9BB5C2B39E73B8A59BAAA7CA80727C69A68EA78CAA
A38B597BA6B1C43BA7E082977D7262A2BC8B68AF9D8F8E8CA0C88A5B5A4368645971847B
74666C6B7F869EA87993B38F7F8B8B594C64666A
5A83794A979B9D969C7654797C66554753896D425A4C56737E9C8997ABA873715C94D199
637D579598C4B07A6D718B7398739099B5C3B49D77D5C0B2B9A9DA8E7F886A9B86A87EA6
8F825C7E9BAEC73FA3E08D9B7F7F6FB2CB9E625C87A18E8D8FAA8453473C525856687975
6A765D6A6C6B828C567B9B74708983626F727A9C
6C957E528E90978D8C6F4A6C73686A67538C72416547496A79A27E9BA194646C608EC096
5E80589CA7C6A977716D8271916E8794B4A2A39165D2BB92AFB0E0948982609D85A87DAC
A48C5E7F9A9ED246A3E3818E7E8573AFCFA5555D869989969CBB794044365C5A626C7970
696D685C6C77928B627C98837E766F636E6F6C78
67A67954919CA0A28277577A7558726470886D3E6A565478729B7F99ACA36566618BC390
557A537D93C8AF7D6F637F728870878CB5AB98956DDAC59C7A8CA67C77725B9082A67DB2
AD866485ADAECA40A5E48493838674B8D0A75F919092839B8BB86C4D4437575A62677C69
6D755162575B779A6A8B91615E67675260636E80
6DAD7D67879FA7B48E7C60898F5B77667D906F485740476570B48894A6985C64779BD09D
5C80588795CBB582795F7C7484647E8AAA98868F71D6BFB365C797667678639280A386AA
AE8B6287A7AFBD40A2E28F997D7F7BB0D0A664B092A48FA890A86B593A4B8265707B8273
846D707376779ABF7EAEB18C75857E745166727A
7ABE866584A0A6AE8E7F5C839366635B727A41447D5C586767AB8790B4A4626971A8CCA3
6A8D5C81A2CAB27C785F83728564788EB3A38CA375C4B7B58BBCB388827952807D9986A5
AD825E889AB1C142A1D8858E767F74AFD19F69B68C9780A882AF71503C5C846293707579
7E8372766D7E99B16193A9908E967F847D6F7A84
80B6886B8C9EB2AD8C836686927169486F893A567D676D7470AF938F9D9B685A6398C395
5E7F6488B2D2B28A83638E7D916F607EA197788577D1C3B8959DB28C867D5E8B7C9378A4
B1865A87A1AFCA4AA7DB7584808573B1CA946BBE8E9684AC80BA6E4F3C5E83688A667069
7D796B6F5E73829A5B949E79677C697C69637882
6EAA846381A8C0A48C896C839E8272547F9D605A8B7C707D78B5979DB2BB71616EA4D2A4
65817D95B4DDB58F87618E75846C76A6B4A7939782C8B9B69597AD837C785C9692986FA1
AD785D868EB3C84BA7E37396858F83B8D99A69B6978C81A766BB693E2C517B58916E6E68
64716B5157688BAB688F876A5D646D69665D8A8B
6E836E5D8099A6867D7A6A8E9878484D6C8169558E69677671B8909DB1B2675F71A4C8AB
5F826F88BCDCB181815D8C8284655F8CA29B848F7FC6B6BA99A69A847172559998987EA4
AA715B869EAEC449ADDF649478757FAEC38566AC9587848E5BC16E442D5379538A716969
74746D65708C9CA27995917861706A557151728C
82B0847E9AB2A58A7789735C7B7E6E85838758498A67597767A38095AEA05E597599D8B6
5B858B88C0D7B686895D8A817D7663A2A0B097948ECDC0C2A4B0A08A7276509D90A584A0
A66E627B98ADD74898E27CA0888881B2D5A4689E86908D8C53B1815E3E54895C8F756159
6D7E7E54648691A383938C776F896B585C516F6E
86B389929BABA9968D8C7C7B8787635E749F654F8367516F6FA594A2A89B614D719ECA95
5580878BBAD4A6828E638189868A6EC4A4B49E9687C1C5B99BB1A68D858058A0909D849F
A57263829D98D04689DA8F9784767BA7D1A399A8A29DA29D558F8F5538507850856F6C52
647E7469537C779D809F936E749D73615B56686F
7DA9829D94A6AB9385787C7783837B7B7793604D865B59676DAB97A4AA9E655C7FA6D2A3
608D967DA6CA886C866582806F775EC0A2A594917BC9C4BCA8BEA88B7E7E5D968BA98BA3
B77D6C8DB5AFD5469FD4AC99897087A4CC8C86A1A6879C9E62AA8C57395D7E5481666054
66846F5E537C81B880A591768AA076656A667484
87AC838B81A8A2998C82776B8590888184966F557971617C6DAD9CA1B0A3666989AFD69E
5D838784AAD7B3879D5A847B7D8570C2B0B198A088CAC3A399BE9E8E807E679296A189A8
AA6F677EA5B4CE44A4E3AF928C86A2BCD39781ADAC7F9A9F62AA944830608A5F78665951
6A86848B568095AD759A797C8CBC905C4E60717D
7AA585868AAFAE958D8D72637A84737E87A9775289796A867FB8998AAAA0666468A2D099
5E898D89B1D3A7777547737A7864587DA09B9A9E88C6BCB089BE98888B7977909EA18CAE
B070687497B1CB4399E3B595898BA8BED59C83B2AD87A29E5BAB94603872A1878472704E
647370814B7283AD8DAD8F7F94AD955E665B6976
8AA68B829DACAF9E828A73617D8B70857A9B7B567F61607B6DB49485B1A86C68619AD7A7
6984848FB6D5AF7D845F9279956579B1B7B2959E87D0C4AB88B58B7C81757E8BA3A182BC
A4806A679DB7CA4B9EE4B1867080A7B2CE9D7EB0A67F94946FC2914F2C739C7B72757868
6F72778A4E7B9FA49EB98C92A6B498595F5D5F80
839379769AA6B39F8293826C7C89738C709970547A584D7378A68676A19A6E69659FDDB3
718985A0C1D7BB8F866392858B677CBCB4B4979D8FD5C6A88FC8988D9173828CA69980C4
B192656C9EABD34697E0A7776577A6B0D19369A9998C89958CC3853F297989736A685861
7385879459739E9F8AB08A95A6B1936272616070
7891836FA4A3A29A8C9C7B7F7E8D7876599268556F4D577E78AD9079ABA068665F97CFA5
60816497A5CBAA8082618D80875E6E999F9F909575D9D2A284C3A08580698074948780D1
A39D6F68A7A2CB4B91DC8D79697BB5BACF975DAF8F936681A4BF78383184905173776071
5A7C7885567AA59783AD7C8DB5B08A5E756A6167
66807C937197A08B8D9373858180849E699D69637E54618179A38675A4977D6F5FA8D8AD
5E825AB0A7D5BA83826B957D8A68709F9E99889264C8B28D7FC4AE80896E897F95757BD4
9CA27363B2ADBF449ADEB26F6A7DB9C7D0BA61AC88886188B7927D4434757C3C7C7C7A74
628483935970A09985C78A91A7AA7B667C706674
84938CB78DA5B891899269838266848D65A3706F856C697B6CA29376A88E7875559BD49B
707A4CAAA6D4C4807D6F957C974D66959B98908F6BDABD9B7AC09C769275918099746ED4
97906C58B6A7CC469CDFBF806B75B3CDD0B76F9B8B62757CAF768C5B3A857C6267727580
6285758F5E8BAC9077C58597AFA9825C6C564E6C
7D8F80B082A9BA918395728582558BA262A16F73816A5B7A7BBC8B77A59B796F508AC9A3
707B48B9ABDAD38C8B7D917F9D6777AEB49D9E9375E0C4A07DBB946E9A7BA38CA57B6BD2
9E977658B8A9C0399BE2B8716B75ACC7BBAB798E9A618A839694656C3F8C708E726B748C
5D7A72987087A88C79CC92A1B29E8967685E6EA5
7F92819A79A1B7928B967B818D5B85A26FA46F69755A5A7F79B89382AD9D7C7C5992CFAA
797D48BC99D3C985746D8877946D6EA2B2A09D987AD9B99888AF97689D8B9F8CA67864D3
A0837F58C0ABC534A1E3BC6A6874A7BBC6967C899976788068BD66532C6A65888A726E7E
5D735D8373819F836DC5908FB09BA27162697DA3
848D798A86B6B292849B75758D5A869976886A62825B5B737FB0847CA3A3847E5EA0CCA8
7D8444B89DDAD29187648C7E967F76A9B3A2A08F79D4B18F7EA98760968DA68BA4755ECD
9A888658C2ABC628B0E4B06F75729EC3CDA1928FA67A8F807CA46D4932716671907A7973
6F6B6E77717AA27467C49687AD876C7A726B796E
8296839288B5A99586A77F6C89538591759D806B7352507A78B3877EA79E8486658AC7A9
828948B7A5DDD492835F8D6D8C8368A4A59DA18D81D3A4917DAC886694838B7D947661CD
98707D57CAAAC21AB7E2937E7975A3BEBC8BA28EAA7B9A6CA9916C472F7C6259986C675F
926F7168837F998365C19F7DA18D845E66598164
8B896C787CAFAD9880A6867A8C57877D6EA171606F4B4C7075AA8176A79C7B85699ACAA4
7A824AB8A5DBCA8D7B61876E906A629B6685978F7FD9AE8B6DA68E6F99999A90A07B62CC
996D7E51BBA2C33EA5E39085857B98CCC87AA789A67F946C9D96665240715C6092947C6F
9D6967508183938468BA9E748D977D5B59749486
7D8574948FB0B991809E7B80955D8D956D9C6E5F624B4A77669C7A81AAA5867B598EC4AB
787C4DAE8FD3CB8B7F6C8E6D8F676AAE8E979D8B77D4A38D85AE99798E9E918DA4825ED4
9E728C5BBBA1BE559FE28E7F8B8A9BC1BD83A98E9C8A9474A4966E554C7A64697587767B
916F58486779939064A3977C8B9A718258648E79
897B849287A8A8908D987A8B8E649098779D7E6F7249527A7CB1868BA69F8583599CCAAF
7B8355C3A8DED0908B748D7A9F6270BC8DAFA08B83D5A18D80B1A8798A9E8D95A08267DD
9D6C8F60C3A9B62FA5E48881767A99CFC6909E9F9E889477B98F6F43316C5E7C6379607B
837F647582868C9864BDA67F8B8F62834F4E736F
937A7F8E89B5B19894A37C7C8D708088638676696F4752767EAB8482B1A0878B578DC4A2
797F52BE9BD9C993896B7770946666AA83BAA69B7FE4AF9376A29C7181888889A28559D0
8C759C79BDA29C25E0E69085887B91C2BB8DAB9EAD949984A98267383F8D508358845F74
8E7D6F8B7E8B98A073C8BC72929D5F743F3F615E
8B727D877B9BAEA09798808F855B7790536B49495C55627B88B48D80AF9D81935E8DC6A7
7C824DBE91D6C39A817281789B716FA997C5A3A57CD7A69B87ABA57A7B8D8491BC9186A0
A672A080BFB3A92ADCE3857D7B7994CDBC7EA18F958B7C91C08B68483E804D8A64837970
8871776176857E8C72BAC0668FBD6385594E715F
8F788A9D8CADC0AC8F9B6987946286986B9B7C6C664D5A7E89AF8E80B09D857F4F8FBBA5
768B4BC69EE0BEA7846F8680A17E7B9AB2BB959F92D4A8B489A49F807C7F6A75A79A7ACE
97629681A2AF993AE1E5787B888CA8C5B972A89483768288B77677433E7B587962778085
976D7E666C7E8CA979B9C0618EC55B6C60676D6D
8E7889AD93ADC0AD989C7A8D8E62819685AC76747F5862867BB59C7CB4A3858F6490C0A6
7A8A4BC596D2BCAD826D887B95797D889BBB7E8BADC5A5BA85ACA18D8087687F889F81CD
96668882AEB2843BDDE1657874749DC4B86DA0887E766987AE676E463C735865858D7274
815D766C6984818C6FB1A36D8AA751566B566E72
8D7C94AB8DAFC0A3979C788694597C987EA66A627B4F647D92B39E7DBEA4888C6893C7AA
7D894AC799C9B9AB88818B7D9686949CB0BE8F9FABD3A1C681AEA37E7B8562958CA3A7DD
8D6E899297BB7F31D6DD62738482B1C5B86AA28F8B79726BB869644138786A6780876E8F
80746D63616B7F9576AD88738DAC5A4F59566760
917B95AC90A8BEA6869274869150839E8AA460647C5478808EC09780BEA086906E90BBAD
869651BA96D3B9AA85668D808E8C9F94A4B19293B6D09FB8798E8D758181518F7198A8D6
898283B39FCF774DE2DC6A81746BBDC1BB7F9D92956C8D5EA87161503D76695C787E6584
707777676C76869474C37D7F91A96257594D6B63
917C8E9B8FA8B8AC869B688E95607D9C87986B64714D767087B79875BD9B89956995C0AB
8E944AC2A4CEB4A28B668073797E97B0A8A89296999EA6B77FA89B838C82509C7F92B1D5
91876DABA1DA6A4ADEDE79697759C9A8B088968D947591687F935D4C3D7F60576D7B5C7A
73707A6D727F968D7DD572929AA26D636352746B
90838F998EAFA8B5868F5B918866928D889A6F5E705C6E7487B59288CAA090936691C0A8
89854ABBADCBB0997F6D8D6C73878B9599AA8E88B7ABAAB48FB68987927D568D8780AFD2
8A8F60ABA1DC624DD8D17B697751CEBAB894756C896A7F7A769754405085796260828587
6B656979838BB18479D774959E9559685D4E6B6C
887E888685B3A1BE8F8B5B948A6985958195765F705866758AC49386BF8E857D6290B197
8C804EBC9BBCB29F7D6E88756F8D8FB3AAA6A490AAC6A29F85BB7F8B8F8B719A8873B0C7
809E5EA097DF575DE1C199787D5BC2CBAB9B9C89A6778093939A784154807D7F708A6273
6B6A65818E8EBA7A89DC579C958983756A547279
988A87807EAFB3B483865A9F92606D98879288676E505E7A88AE927DC083818D6895B498
998057B6A2C8ADA978718779528091BCA4949D7FADD4A3A689C27B768592808E9D65A6BA
84A7589195DF5073E4BD977A776BABD79F819B8E9B7B89A0A89D7D405A9156A072786872
716E6D7D9791B36E94D2538A908B924E6C4E716A
8D8D867E7FB5C9C596895F997E5E749789898465674C527E80AC947ABF8B84856E88C1A0
A98459BEB1CFB1B57B7D8E895F8FA6ACA193A28BA6CCA4A48EB77673818E929AB86EA9B5
91A6688AAAE54F77E3AE9985707BBDDE9865A097807A6B91B98F7149638A49A2766A786B
7E6A6E758A91A06F8DD0567B8C8491695A5B7B79
8CA87F7980B8C8C299865FA0905D6A868A8E836F684B5A8281AC988AC38D8A8F6786C09D
A97B58AEA7CEABAC797B84885085AAC09A96A7A1A5CFAC9D94C27174818A9991B673A2A4
879F7286A6DD4C88E59C8F8F8685B2DB91629F9A8D9F7F87B27D875A617B429A78627973
90669969A098A0658AC0657A9F83787C5B5A8475
8BA67D737EAEC3A7937C5D9C8D63727F9886867469424E7E76B99C86B88D8A8B5D79B297
A0835BBAABCBA6A47A8385884D80A3B3A397A19AA0C8A3998DBE7672828F969CC07CA4A8
8E957F98AAE03C93E3967E82919CC6DA89579499848E84A3BF8E7F465E814B89767C8A85
8A77B4638D8BAE6D9BA77173AC8A7C6153537B6C
89A9806E7BAEBFA2A07D65958C67797EA5898A7A634A568061B9B194C9938F936E81CEA1
A97B55B2AAC6ACAC7F7B87864C7DA6B4B080A4A5B1DAA3A09CC4777B7B938EABAD8BA9B2
91869997B1DD3B9DE39B7B73869CCDC094549D8F798F8A94B18981305A764A757C7F798C
7382BC739196AC7DA9A987769C9B885F50509080
88B3877A89B8C59E9F826D867D67645CAB868A7D664555315AB1A196BF8D89877186C097
9D6F61C4B6C6ACB57D7E90924972A9A6B47CB1B6B8D99B969CC37B7F7B8D8D9E9C9EB0AB
9575A5A5B9D642ABE6A97965819CB694AB64B0998B9C8C8DA88D7D366E834768736A6E91
828CBD758B899C81939D86A6A8A9795B4D5C766C
899D8C6D8FB0C6A2A8907594786A655FA57E767B6350563E7BA9A092BD928F8A7893BA98
A07070C2BAC4B0A9837D8F954674A7B5B973ABB7C3DF999C9CBA858B738C7A9E92A3B4B0
8171A8B0C2D539AEEBB679578091BABAAC6AAA878A9A908CB58A893D7D7E50786C6B6B80
8089A46D7D879882928B828FA4B37A6A4E697864
7993875598A5BC9BAC82799583747178B1897C876F64586482B09B94AE8C8D868798C39D
9F6B73ACC3C2AA9A8178869E4D67A6ADAE77A6A4C9DB959D8FAB808A7A8C839985A2B3AF
7A64A0B2C7D332AFE6BD7C5D7E98B7BCAF739A818F818D7DC4807D2D685F5183647B7D8A
837989798396968DAA7F8F97A9A47780636B7D72
7D998B5BA099A796AA846D8685817669AC977E936E5D473E84B89EA0BD8E93897FA3C39B
9C747AA5D8D1B897867C7D9B6268A0B39B74A3A3D5D3A1A987AA8F8786857F967F93B4B3
83629EAAC2C22CB5EAC07262568CA1B8B187A990A079976CB7867F397F7162935F796F8D
777A7F83879E8F90A18A9B969A986C755C6D7D70
81988B639E98B89AAF899191756E6C589E84698F6F52684486B9968FA286788183B6C4A0
946C7BA3D0C2B18881898098747392AC9A7AA19DE1D2ADA089A3978594797490889CB1A3
6D6498A5C4C726BEE7BC7276609DA6BD9595AC9297669E71A2A5693D6E58629657717086
70806C8982B99796A7909B949A9274716669787B
879590559D9AB494B592A490777C6C72A68285A085506C4488BA8C98A474657273B2BF93
8F706DA1DDC7B2858F6E848E797491AC88739193E3C5B2A990AC8E82AE817FA88499B5AE
858394C7CAA934C4E7AA7B844C94A0D195A37FA49768888384B95338966473915B715B72
636F638B99B7A48FB1ACA3B69877806E5D6B806E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002P3oool0101JFUX0Ph>308>3
P`2CTi<20:6QX@050:n_[`2NWYh0D51@051@D00g=cL00P2c/k<01@2i^KT0_;bl0;bl_02h^;P0][Jf
0080OGem00D0;bl_07moO`1oOgl0MGEe07MgM`020820P00408F5Q@21PH40PH6104M7A`80[Jf]00D0
/K6a0:ZZZP2YZJT0ZJVY0:^[Z`0209FEU@0501hN7P1hN7P0Shn?08n?S`2DU9@00P2IVIT01@2NWYh0
Ti>C02HV9P0V9RH0EEEE0080HV9R0`1YJFT01@1^KVh0Lg=c03dm?@0m?Cd0OWin0080TY:B00D0WIfM
0:BTY02ZZZX0ZZZZ0:VYZ@020;2`/0040;Bd]01GEeL0EeMG09nOW`<0/[:b0`2`/;001@1aLG40>SXj
09fMW@2MWId0Zj^[0080[jn_00D0Zj^[0;2`/02`/;00KVi^03<c<`0208>3P`050820P02BTY80TY:B
09bLW02YZJT00P1/K6`01@0U9BD0ATI604I6AP19BDT0EEEE0080J6QX00@0MGEe04m?C`1?Cdl0KVi^
0P2i^KT01@2b/[80[jn_0:f][@2][Jd0[Zj^0080De=C00D0VYZJ0;Rh^02h^;P0^;Rh0;Zj^P020;bl
_0050;Jf]P1TI6@0I6AT0;Bd]02h^;P00P2l_;`01@2i^KT0^;Rh0;Rh^01KFe/0Q8B40080/[:b00D0
[Jf]0;Bd]02d];@0];Bd08J6QP0208V9R@040;:b/P2_[jl0[jn_0:f][@80[:b/00D0ZJVY05=CD`28
R8P0R8R80:FUY@020:b/[0050;6a/@2][Jd0QXJ608J6QP23Ph<00P33`l<01@37alL0`<300<30`02n
_[h0[Jf]0080DU9B00@0[:b/0;2`/02`/;00[Zj^4@3oool0101hN7P0IVIV06IVIP2<S8`207YjNP<0
TI6A00D0Z:RX08R8R02?Shl0Shn?06][J`0204E5A@0508b<S01NGUh0Rh^;08^;R`1]KFd00P1GEeL0
1@1VIVH0NWYj07YjNP1jNWX0CDe=0080I6AT00@0LW9b05IFEP1FEUH0U9BD0P1YJFT01@2GUiL0UIFE
04a<C01<C4`0T92@0080CDe=0`1aLG401@1bLW80emOG08B4Q024Q8@0GemO0080ATI600D0MGEe0:b/
[03:b/X0b/[:0:BTY0020;:b/P050:FUY@2YZJT0ZJVY0:BTY02KVi/00P1mOGd0101UIFD0Jf][06][
J`1lO7`20:JVYP050;no_`1aLG40Vi^K09^KV`2EUID00P2UYJD01@3=cLd0Shn?0;6a/@2a/K40_kno
0080ZZZZ00D0`l?304a<C01<C4`0RHV906=SH`0208^;R`0408>3P`1eMGD0MGEe07AdM080X:2P00D0
ZJVY07YjNP1fMWH0MWIf05ADE0020:^[Z`050<;2`P2/[:`0Y:BT0:BTY01hN7P00P1ADE401@3QhN40
X:2P0:2PX01lO7`0MGEe0080Hf=S00@0H61P0:VYZ@2YZJT0]kNg0P2IVIT01@1ADE40RXZ:09>CT`2C
Ti<0SXj>0080RHV900D0TY:B0<C4a034a<@0MgMg04];B`020492@P0503hn?P1eMGD0MGEe08>3P`1G
EeL00P1KFe/0101gMgL0OWin07inOP1`L70208:2PP0505aLG01WIfL0GemO05mOG`1kNg/00P2CTi<0
1@2=SHd0SXj>08j>SP2JVYX0Vi^K0080_;bl00D0Ng]k09bLW02LW9`0YZJV06e]K@0204I6AP0405aL
G01OGel0GemO08f=S@80PX:200<0MGEe0?ooo`3oool0203oool000X0oooo00@0GUiN096AT@2ATI40
XJ6Q0P2e]KD01@2i^KT0/k>c079bLP1bLW80>CTi0080[Zj^102l_;`0102i^KT0OWin07inOP0h>3P2
07EeM@0506e]K@1^KVh0N7Qh07QhN024Q8@00P28R8P01@0j>SX0Z:RX0:RXZ02`/;00[Zj^0080ZZZZ
00D0[Jf]096AT@2ATI409RHV08b<S00209^KV`050:FUY@2TY:@0Y:BT0:6QX@2EUID00P0R8R80101T
I6@0OWin07inOP23Ph<206e]K@0506QXJ01IFET0<C4a034a<@20P8000P2FUYH01@2OWil0Xj>S0:ZZ
ZP2ZZZX0[Zj^0080/k>c00D0]KFe05EEE@1EEED0XJ6Q0:^[Z`020:n_[`050:j^[P2`/;00/;2`07If
MP0/;2`00P27QhL30:2PX0050:ZZZP2][Jd0[Jf]06a/K00f=SH00P2LW9`01@2GUiL0W9bL09bLW02S
Xj<0ZJVY0080MgMg00D0?Cdm06EUI@1UIFD0@d=304i>CP0206MWI`04071`L019BDT0BDU907=cL`80
/k>c00D0Zj^[0:f][@2`/;00/;2`0:b/[002055AD@0509JFUP2c/k<0[jn_0:n_[`2`/;000P2j^[X0
1@2[Zj/0Jf][06][J`2g]kL0^KVi0080_kno0`2i^KT01@1ZJVX0Shn?0;>c/`2c/k<0Zj^[0080/k>c
00D0]KFe0:JVYP2QXJ40XJ6Q0;fm_@020;Jf]P050;Rh^02f][H0][Jf0;:b/P1LG5`00P26QXH01@2N
WYh0ZZZZ0:ZZZP2[Zj/0]KFe0080Ti>C00<0SHf=0;^k^`2k^k/00`2k^k/0102o_kl0`l?306m_K`1_
Kfl40:ZZZQ40oooo00@0LG5a05ADE01DE5@0Ng]k0P1gMgL01@26QXH0SXj>08j>SP2_[jl0NWYj0080
R8R800D0MWIf05=CD`1CDe<0R8R805]KF`0207UiN@0406ATI01CDe<0De=C06a/K080QXJ600D0S8b<
051@D01JFUX0FUYJ06EUI@02055AD@050820P01YJFT0JFUY09BDU02=SHd00P18B4P0102=SHd0F5QH
05QHF021PH4208J6QP0507QhN03@d=00SHf=08f=S@1XJ6P00P1;Bd/01@1gMgL0ZZZZ0<30`030`<00
YZJV0080[Zj^00D0X:2P0:FUY@2UYJD0X:2P09RHV00207]kN`0406QXJ01aLG40LG5a07IfMP80XZ:R
00D0`/;207MgM`2EUID0UIFE09nOW`020:VYZ@050;no_`1hN7P0^KVi0;Vi^@2c/k<00P2RXZ801@33
`l<0EEEE05EEE@22PX80HF5Q0080Shn?00@0QhN7079bLP1bLW80KVi^0P2`/;001@2a/K40NWYj08Z:
RP2:RXX0JFUY0080V9RH00D0_kno0;Jf]P2UYJD0YJFU07EeM@0205]KF`050=cLg02LW9`0W9bL06YZ
JP1fMWH00P1dM7@0101^KVh0^;Rh0;Rh^02i^KT20:>SX`05065QH@2:RXX0WIfM09fMW@2CTi<00P2@
T9001@2DU9@0e=CD0=CDe01oOgl0BDU90080@d=300D0>3Ph06YZJP1ZJVX0M7Ad05aLG00205QHF004
05iNGP1QHF40HF5Q06EUI@80Shn?00D0Jf][06UYJ@1KFe/0Fe]K08:2PP0209FEU@0309BDU02RXZ80
XZ:R0080W9bL0P2a/K401@2ATI40Y:BT0:BTY02_[jl0NWYj0080D51@00@0IVIV05mOG`1OGel0M7Ad
0P21PH400`1jNWX0oooo0?ooo`080?ooo`002P3oool0101NGUh0TI6A096AT@2QXJ420;Fe]@050;Vi
^@2c/k<0LW9b079bLP0i>CT00P2^[Zh40;bl_0040;Vi^@1nOWh0OWin03Ph>080MGEe00D0KFe]06i^
KP1hN7P0N7Qh08B4Q00208R8R00503Xj>P2XZ:P0Z:RX0;2`/02^[Zh00P2ZZZX01@2][Jd0TI6A096A
T@0V9RH0S8b<0080Vi^K00D0YJFU0:BTY02TY:@0XJ6Q09FEU@02028R8P0406ATI01nOWh0OWin08>3
P`80KFe]00D0J6QX05UIF@0a<C40<C4a0820P00209JFUP0509nOW`2SXj<0ZZZZ0:ZZZP2^[Zh00P2c
/k<01@2e]KD0EEEE05EEE@2QXJ40Zj^[0080[jn_00D0[Zj^0;2`/02`/;00MWIf02`/;00208N7Q`<0
X:2P00D0ZZZZ0:f][@2][Jd0K6a/03Hf=P0209bLW00509NGU`2LW9`0W9bL0:>SX`2YZJT00P1gMgL0
1@0m?Cd0IFEU06EUI@13@d<0CTi>0080IfMW00@0L71`04U9B@19BDT0Lg=c0P2c/k<01@2[Zj/0[Jf]
0;2`/02`/;00[:b/0080DE5A00D0UYJF0;>c/`2_[jl0[jn_0;2`/0020;Zj^P050:^[Z`1[Jf/0Jf][
0;Ng]`2i^KT00P2o_kl30;Vi^@0506YZJP2?Shl0/k>c0;>c/`2[Zj/00P2c/k<01@2e]KD0YZJV0:6Q
X@2QXJ40_Kfm0080][Jf00D0^;Rh0;Jf]P2f][H0/[:b05aLG00208J6QP0509jNWP2ZZZX0ZZZZ0:^[
Z`2e]KD00P2CTi<00`2=SHd0^k^k0;^k^`030;^k^`040;no_`33`l<0Kfm_06m_K`@0ZZZZ4@3oool0
101aLG40E5AD05ADE01kNg/207MgM`0508J6QP2>SXh0SXj>0:n_[`1jNWX00P28R8P01@1fMWH0De=C
05=CD`28R8P0Fe]K0080NGUi00@0I6AT05=CD`1CDe<0K6a/0P26QXH01@2<S8`0D51@05YJFP1JFUX0
IFEU0080DE5A00D0P82006UYJ@1YJFT0U9BD08f=S@0204Q8B00408f=S@1HF5P0F5QH0861P@80QXJ6
00D0N7Qh0=3@d02=SHd0SHf=06QXJ00204];B`0507MgM`2ZZZX0`<300<30`02VYZH00P2^[Zh01@2P
X:00YJFU0:FUY@2PX:00V9RH0080Ng]k00@0J6QX075aL@1aLG40MWIf0P2RXZ801@32`/80MgMg09FE
U@2EUID0WinO0080ZJVY00D0_kno07QhN02i^KT0^KVi0;>c/`020::RXP050<?3``1EEED0EEEE08:2
PP1QHF400P2?Shl01027QhL0LW9b079bLP1^KVh20;2`/0050;6a/@1jNWX0RXZ:08Z:RP1YJFT00P2H
V9P01@2o_kl0][Jf0:FUY@2UYJD0MGEe0080Fe]K00D0g=cL09bLW02LW9`0JVYZ07IfMP0207AdM004
06i^KP2h^;P0^;Rh0;Vi^@80Xj>S00D0HF5Q08Z:RP2MWId0WIfM09>CT`02092@T00509BDU03De=@0
e=CD07moO`19BDT00P13@d<01@0h>3P0JVYZ06YZJP1dM7@0G5aL0080F5QH00@0GUiN065QH@1QHF40
IFEU0P2?Shl01@1[Jf/0JFUY05]KF`1KFe/0PX:20080UIFE00<0U9BD0::RXP2RXZ800P2LW9`20;6a
/@05096AT@2TY:@0Y:BT0:n_[`1jNWX00P1@D500101VIVH0GemO05mOG`1dM7@20861P@0307YjNP3o
ool0oooo00P0oooo000:0?ooo`0405iNGP2GUiL0UiNG0:ZZZP80[Jf]00D0Z:RX0:FUY@1VIVH0IVIV
02d];@0209jNWP050;Fe]@2d];@0];Bd0;Vi^@2h^;P00P2MWId01@1EEED0LG5a075aL@1YJFT0JVYZ
0080MGEe00@0QHF5096AT@2ATI40>3Ph0P23Ph<01@2MWId0Xj>S0:>SX`2SXj<0UiNG0080HV9R00D0
?clo08>3P`2BTY80TY:B0:6QX@0209jNWP0509RHV024Q8@0;Rh^02h^;P1GEeL00P1iNGT01@1_Kfl0
KVi^06i^KP1PH600D51@0080;2`/00D0RXZ:0:>SX`2SXj<0Zj^[0:6QX@020:NWY`040:j^[P2`/;00
/;2`0;2`/080De=C00D0V9RH0:^[Z`2][Jd0[Jf]0:n_[`020;2`/00507AdM00Z:RX0ZZZZ0:ZZZP2O
Wil00P2@T9001@2PX:00Zj^[0:^[Z`1`L700>c/k0080WinO00D0WIfM0::RXP2RXZ80YZJV0:b/[002
07QhN00504M7A`2EUID0UIFE05=CD`1NGUh00P1_Kfl0101cLg<0ADE504E5A@1QHF420;>c/`050:RX
Z02VYZH0[Zj^0:j^[P2`/;000P1>CTh0102EUID0][Jf0;:b/P2b/[830;6a/@050;2`/01TI6@0I6AT
0;Jf]P2o_kl00P2h^;P01@2l_;`0^KVi0;Vi^@1[Jf/0SXj>0080];Bd00D0]KFe0;>c/`2c/k<0][Jf
0:BTY00209RHV0040;Ng]`2h^;P0^;Rh0;Jf]P80/[:b00D0/K6a05MGE`2LW9`0W9bL0;2`/0020:j^
[P050;Fe]@2h^;P0TY:B09:BTP26QXH00`2`/;020:j^[P050;>c/`2l_;`0LW9b079bLP2][Jd00P2S
Xj<00`2NWYh0oooo0?ooo`0?0?ooo`0407moO`1PH600H61P0861P@80L71`00D0QHF507UiN@1iNGT0
QhN705eMG@0207AdM00506IVIP0m?Cd0?Cdm07AdM01MGEd00P28R8P0101PH600EUIF05IFEP1=CDd2
06=SH`0509RHV01MGEd0EUIF05IFEP1MGEd00P18B4P01@1nOWh0Lg=c07=cL`2KVi/0SXj>0080Bd];
00@0UIFE05aLG01LG5`0MgMg0P1fMWH01@1nOWh0dM7A08>3P`23Ph<0JFUY0080De=C00D0LG5a0:6Q
X@2c/k<0/k>c09bLW0020:FUY@0509ZJVP2][Jd0[Jf]09RHV02IVIT00P2>SXh0101mOGd0QHF508F5
Q@25QHD20;6a/@050<[:bP1aLG40Zj^[0:^[Z`2EUID00P2RXZ801@2k^k/0O7al0;fm_@2m_Kd0[Zj^
0080YJFU00D0clo?05aLG01LG5`0P82005mOG`0207inOP0407]kN`1XJ6P0J6QX06a/K080Y:BT00D0
XZ:R07IfMP1nOWh0OWin075aL@0208N7Q`050<K6aP2n_[h0[:b/0:b/[01cLg<00P1OGel01@3AdM40
U9BD09BDU01MGEd0Ph>30080NGUi00@0MgMg0::RXP2RXZ80^KVi0P2][Jd01@1ZJVX0Ogmo0:6QX@2Q
XJ40Rh^;0080Q8B400@0U9BD0=OGe`3GemL0Ph>30`14A4@0100a<C40I6AT06ATI02=SHd306EUI@04
05eMG@1WIfL0IfMW071`L080MWIf00D0De=C06MWI`1NGUh0GUiN07QhN00208j>SP0507moO`2FUYH0
UYJF09JFUP2UYJD00P2m_Kd01@2RXZ80_[jn0;jn_P2YZJT0Jf][0080Cdm?00@0NWYj06m_K`1_Kfl0
KVi^0P1nOWh00`1bLW80oooo0?ooo`080?ooo`002P3oool0100l?3`0@4100410@016ATH203dm?@05
03Ti>@0h>3P0:BTY02TY:@0T92@00`0_;bl2020P800502PX:00V9RH08R8R028R8P0N7Qh00P0X:2P0
1@0S8b<0:2PX02TY:@0Y:BT0;Bd]0080<S8b00D0;Bd]03dm?@0m?Cd0CTi>03@d=00202TY:@0501dM
7@0E5AD05ADE01lO7`0m?Cd00P0n?Sh01@0j>SX0=CDe03De=@0g=cL0BDU90080<S8b00@0>3Ph03hn
?P0n?Sh0>CTi0P0g=cL01@0d=3@0;Bd]02<S8`0S8b<0ATI60080BDU90P1>CTh205MGE`0405eMG@1V
IVH0IVIV065QH@80;Rh^00D0CTi>06QXJ01/K6`0K6a/06i^KP02075aL@0504E5A@0G5aL0KFe]06e]
K@1SHf<00P1GEeL01@1NGUh0MGEe07EeM@1JFUX08B4Q0080KFe]00D0KVi^06][J`1[Jf/0NWYj07]k
N`02059BDP05030`<014A4@0A4A403Lg=`0^;Rh00P0/;2`0100f=SH0>c/k03/k>`1RHV8209jNWP05
09RHV02CTi<0QHF508F5Q@2@T9000P15ADD01@1ZJVX0WYjN0:BTY02TY:@0/K6a0080]KFe00D0ZZZZ
065QH@1QHF40/k>c0;bl_0020;Jf]P050;bl_02^[Zh0[Zj^04i>CP1UIFD00P2PX:001@2SXj<0XZ:R
0::RXP2XZ:P0SXj>0080Shn?00@0_[jn0;Zj^P2j^[X0]KFe0P2h^;P01@2g]kL0G5aL08f=S@2=SHd0
[Zj^0080[:b/00D0[Zj^0;2`/026QXH0QXJ607moO`020:FUY@050:JVYP2HV9P0V9RH0:FUY@2g]kL0
0P1UIFD0102NWYh0YZJV0:JVYP2ZZZXA0?ooo`0406][J`1FEUH0EUIF07emO@80L71`00D0OWin07Ee
M@1eMGD0Y:BT06UYJ@0208F5Q@05065QH@13@d<0@d=30861P@1NGUh00P1eMGD0101ADE40FEUI05UI
F@1HF5P2079bLP0507]kN`1MGEd0BDU904U9B@1GEeL00P0m?Cd01@1jNWX0LW9b079bLP2IVIT0S8b<
0080BTY:00@0RXZ:05aLG01LG5`0N7Qh0P1fMWH01@1gMgL0`<3008^;R`2;Rh/0Jf][0080BTY:00D0
O7al0:NWY`2/[:`0[:b/0:^[Z`020;Rh^00509jNWP2MWId0WIfM096AT@2IVIT00P1mOGd0101^KVh0
JVYZ06YZJP1_Kfl209RHV0050;fm_@1aLG40X:2P0:2PX02?Shl00P2MWId01@2i^KT0MWIf0;Vi^@2i
^KT0XJ6Q0080VYZJ00D0_kno05eMG@1MGEd0PX:206MWI`0208J6QP0407emO@1OGel0GemO05aLG080
XZ:R00D0^k^k075aL@26QXH0QXJ608F5Q@020861P@050<?3``2e]KD0[Zj^0:j^[P1YJFT00P1fMWH0
1@2l_;`0S8b<08b<S01NGUh0N7Qh0080MWIf00@0KFe]09FEU@2EUID0b<S80P2YZJT01@1SHf<0PH61
09>CT`2CTi<0J6QX0080L71`00D0Ogmo0;fm_@2m_Kd0N7Qh03/k>`0203hn?P05030`<01HF5P0F5QH
0820P01]KFd00P1`L700101iNGT0QHF508F5Q@1[Jf/207inOP0505YJFP1OGel0C4a<04a<C01_Kfl0
0P1oOgl01@1gMgL0Z:RX0:RXZ01UIFD0OWin0080MGEe00D0JVYZ07moO`1oOgl0VIVI06i^KP0205MG
E`0405YJFP1cLg<0Lg=c08:2PP80NWYj00<0Ogmo0?ooo`3oool0203oool000X0oooo00@0?3`l0410
@010@400ATI60P0m?Cd01@0i>CT0>3Ph02TY:@0Y:BT092@T00<0;bl_0P0P82001@0X:2P09RHV028R
8P0R8R807QhN0080:2PX00D08b<S02PX:00Y:BT0:BTY02d];@02038b<P0502d];@0m?Cd0?Cdm04i>
CP0d=3@00P0Y:BT01@0M7Ad05ADE01DE5@0O7al0?Cdm0080?Shn00D0>SXj03De=@0e=CD0=cLg04U9
B@02038b<P0403Ph>00n?Sh0?Shn03Ti>@80=cLg00D0=3@d02d];@0S8b<08b<S04I6AP0204U9B@80
CTi>0P1GEeL0101MGEd0IVIV06IVIP1QHF4202h^;P0504i>CP1XJ6P0K6a/06a/K01^KVh00P1aLG40
1@15ADD05aLG06e]K@1]KFd0Hf=S0080EeMG00D0GUiN07EeM@1eMGD0FUYJ024Q8@0206e]K@0506i^
KP1[Jf/0Jf][07YjNP1kNg/00P1BDU801@0`<300A4A404A4A00g=cL0;Rh^0080;2`/00@0=SHf03/k
>`0k>c/0HV9R0P2NWYh01@2HV9P0Ti>C08F5Q@25QHD0T92@0080ADE500D0JVYZ09jNWP2TY:@0Y:BT
0;6a/@020;Fe]@050:ZZZP1QHF40HF5Q0;>c/`2l_;`00P2f][H01@2l_;`0[Zj^0:j^[P1>CTh0IFEU
0080X:2P00D0Xj>S0::RXP2RXZ80Z:RX08j>SP0208n?S`040;jn_P2j^[X0^[Zj0;Fe]@80^;Rh00D0
]kNg05aLG02=SHd0SHf=0:j^[P020:b/[0050:j^[P2`/;00QXJ608J6QP1oOgl00P2UYJD01@2VYZH0
V9RH09RHV02UYJD0]kNg0080IFEU00@0WYjN0:JVYP2VYZH0ZZZZ4@3oool0101[Jf/0EUIF05IFEP1m
OGd2071`L00507inOP1eMGD0MGEe0:BTY01YJFT00P25QHD01@1QHF40@d=304=3@`21PH40GUiN0080
MGEe00@0DE5A05UIF@1IFET0F5QH0P1bLW801@1kNg/0GEeM04U9B@19BDT0EeMG0080?Cdm00D0NWYj
079bLP1bLW80VIVI08b<S00204Y:BP0408Z:RP1LG5`0G5aL07QhN080MWIf00D0MgMg0<30`02;Rh/0
Rh^;06][J`0204Y:BP0507alO02WYjL0[:b/0:b/[02[Zj/00P2h^;P01@2NWYh0WIfM09fMW@2ATI40
VIVI0080OGem00@0KVi^06YZJP1ZJVX0Kfm_0P2HV9P01@2m_Kd0LG5a0:2PX02PX:00Shn?0080WIfM
00D0^KVi07IfMP2i^KT0^KVi0:6QX@0209ZJVP050;no_`1MGEd0GEeM08:2PP1WIfL00P26QXH0101m
OGd0GemO05mOG`1LG5`20::RXP050;^k^`1aLG40QXJ608J6QP25QHD00P21PH401@33`l<0]KFe0:j^
[P2^[Zh0JFUY0080MWIf00D0_;bl08b<S02<S8`0GUiN07QhN00207IfMP0406e]K@2EUID0UIFE0<S8
b080ZJVY00D0Hf=S0861P@2CTi<0Ti>C06QXJ002071`L00507moO`2m_Kd0_Kfm07QhN00k>c/00P0n
?Sh01@0`<300F5QH05QHF020P800KFe]0080L71`00@0NGUi08F5Q@25QHD0Jf][0P1nOWh01@1JFUX0
GemO04a<C01<C4`0Kfm_0080Ogmo00D0MgMg0:RXZ02XZ:P0IFEU07inOP0207EeM@0506YZJP1oOgl0
Ogmo09VIV@1^KVh00P1GEeL0101JFUX0Lg=c07=cL`22PX8207YjNP0307moO`3oool0oooo00P0oooo
000:0?ooo`<0YJFU00D0Zj^[0:RXZ02XZ:P0GemO07moO`02092@T00408R8R02PX:00X:2P0:BTY080
Z:RX00D0[:b/0:>SX`2VYZH0YZJV0:BTY00209bLW00509BDU02:RXX0Jf][06][J`1VIVH00P2TY:@0
1@2OWil0XZ:R0::RXP2NWYh0VYZJ0080SHf=00D0S8b<08n?S`2?Shl0QXJ608n?S`0208b<S00508R8
R022PX80PX:204Y:BP1[Jf/00P1iNGT0101[Jf/0L71`071`L01fMWH207QhN080MgMg0`1hN7P207Ad
M00505iNGP17AdL0<S8b038b<P1BDU800P1VIVH306EUI@0505iNGP16ATH0EUIF05IFEP1<C4`00P15
ADD203Ti>@80;bl_00@08R8R01LG5`0G5aL08B4Q0P0_;bl01@0d=3@0>3Ph02l_;`0_;bl0=CDe0080
:b/[00D08b<S02XZ:P0Y:BT0:BTY02XZ:P0202/[:`0502d];@0O7al08R8R028R8P0_;bl00P0e=CD0
0`0g=cL0?Shn03hn?P0403`l?00502d];@0O7al07alO01LG5`0K6a/00P0V9RH0100`<3008b<S02<S
8`0O7al2010@400502@T900/;2`08B4Q024Q8@0Z:RX00P0H61P01@030`<04A4A02LW9`0W9bL092@T
00809bLW00D0;Rh^028R8P0L71`071`L03Hf=P0204=3@`0504E5A@19BDT0BDU904e=C@0I6AT00P0^
;Rh01@1;Bd/0BDU904U9B@1=CDd0DE5A0080;Bd]00@0<c<c055AD@1ADE40HF5Q0P1SHf<01@1]KFd0
M7Ad03/k>`0k>c/0@D510080BTY:00<0C4a<0?ooo`3oool03`3oool0101gMgL0IfMW06MWI`27QhL2
0861P@0509BDU028R8P0R8R809fMW@1OGel00P28R8P01@1fMWH0Cdm?04m?C`2;Rh/0HV9R0080UYJF
00@0I6AT07EeM@1eMGD0I6AT0P1lO7`01@23Ph<0IfMW051@D01@D500GemO0080@T9200D0OWin06][
J`1[Jf/0T92@08^;R`0204];B`0408:2PP1OGel0GemO07MgM`80LG5a00D0MgMg0=3@d02JVYX0VYZJ
06QXJ00204M7A`0307YjNP2d];@0_kno0080_kno0P2g]kL01@2LW9`0WIfM09fMW@2GUiL0V9RH0080
QXJ600@0O7al07IfMP1fMWH0L71`0P2HV9P01@2/[:`0K6a/09VIV@2IVIT0UIFE0080Z:RX00D0];Bd
07inOP34a<@0a<C40:b/[0020:>SX`050<G5a@1JFUX0FUYJ0820P01SHf<00P1oOgl0101lO7`0K6a/
06a/K01_Kfl209nOW`050;fm_@2CTi<0R8R808R8R024Q8@00P2=SHd01@2l_;`0/[:b0:NWY`2WYjL0
IVIV0080LG5a00D0^k^k08Z:RP2:RXX0Fe]K08F5Q@0208V9R@0407YjNP2PX:00X:2P0<K6aP80XJ6Q
00D0L71`06a/K02DU9@0U9BD065QH@0208:2PP0507emO@2^[Zh0[Zj^075aL@0f=SH00P0d=3@01@0a
<C40CTi>04i>CP1`L700Lg=c0080K6a/00@0RHV90861P@21PH40NGUi0P2GUiL01@1ZJVX0MGEe05]K
F`1KFe/0N7Qh0080KVi^00D0NGUi0::RXP2RXZ80NWYj0:BTY0020::RXP050820P02WYjL0YjNW0;Bd
]01kNg/00P1LG5`0101BDU80Jf][06][J`1kNg/208V9R@0307IfMP3oool0oooo00P0oooo000:0?oo
o`<0[Zj^00D0/k>c0;Fe]@2e]KD0F5QH09:BTP0208R8R0040820P02KVi/0Vi^K0:f][@80[jn_00D0
/[:b0;Fe]@2a/K40/K6a0;>c/`020;2`/080/K6a0P1]KFd0101ZJVX0[jn_0:n_[`2[Zj/20:f][@05
0:b/[02XZ:P0YJFU0:FUY@2XZ:P00P2[Zj/01@2^[Zh0/K6a0;Ng]`2g]kL0/k>c0080]KFe00D0FUYJ
07]kN`26QXH0QXJ608F5Q@0208Z:RP0508n?S`2NWYh0WYjN0:2PX02LW9`00P2>SXh308F5Q@0508n?
S`2OWil0Bd];04];B`1kNg/00P2/[:`01@2ZZZX0ZJVY0:VYZ@2VYZH0SHf=0080UYJF00D0WinO07mo
O`1oOgl0OWin06EUI@0206e]K@04065QH@17AdL0AdM708R8R080Ogmo00D0LW9b0:ZZZP2ZZZX0ZZZZ
0:f][@02096AT@03071`L025QHD0];Bd0080];Bd0P2b/[801@2g]kL0IfMW07alO01lO7`0[Jf]0080
/k>c00D0/[:b0:j^[P2^[Zh0/[:b0;6a/@020;2`/0050:j^[P2ZZZX0ZZZZ0:ZZZP2[Zj/00P2CTi<0
101GEeL0QhN708N7Q`2KVi/209nOW`050:2PX02JVYX0VIVI09VIV@2NWYh00P2JVYX01@2;Rh/0QhN7
08b<S02<S8`0Rh^;0080Ogmo00D0IVIV08j>SP2;Rh/0Rh^;08N7Q`0207emO@0507EeM@1jNWX0NWYj
07MgM`1YJFT00P1ZJVX01@1_Kfl0LW9b079bLP1/K6`0H61P0080ADE500@0Jf][05eMG@1MGEd0EEEE
0P1ADE401@1DE5@0EeMG06QXJ01XJ6P0K6a/0080KFe]00<0IVIV0?ooo`3oool03`3oool01020P800
H61P061PH02:RXX207AdM00508n?S`21PH40PH610;:b/P1[Jf/00P2=SHd01@1iNGT0EEEE05EEE@28
R8P0IFEU0080TI6A00@0DE5A05eMG@1MGEd0I6AT0P24Q8@01@2BTY80KVi^05eMG@1MGEd0FEUI0080
E5AD00D0OGem06YZJP1ZJVX0W9bL09ZJVP0204Y:BP0408>3P`1FEUH0EUIF075aL@80IfMW00D0PH61
0<c<c01mOGd0OGem05eMG@020451@@0307alO02^[Zh0_;bl0080_;bl0P2j^[X01@2JVYX0UIFE09FE
U@2JVYX0XZ:R0080Q8B400@0O7al06m_K`1_Kfl0N7Qh0P2JVYX01@2h^;P0NGUi09jNWP2NWYh0M7Ad
0080_[jn00D0^KVi08>3P`2i^KT0^KVi0:b/[0020:RXZ0050<30`01FEUH0EUIF08:2PP1PH6000P1m
OGd0102<S8`0E5AD05ADE01MGEd209FEU@050<;2`P1nOWh0P8200820P01dM7@00P24Q8@01@33`l<0
^k^k0<S8b038b<P0NGUi0080OWin00D0aLG508>3P`23Ph<0EeMG08^;R`0208J6QP0407YjNP2WYjL0
YjNW0<W9b@80]kNg00D0Kfm_08Z:RP2JVYX0VYZJ075aL@0209JFUP0508f=S@2i^KT0^KVi07emO@12
@T800`0l?3`205=CD`0407UiN@1lO7`0KVi^06i^KP<0Rh^;00<0PX:209FEU@2EUID00P1YJFT207Qh
N00407]kN`2GUiL0UiNG09FEU@80/[:b00D0QhN70:b/[02@T900T92@08R8R00209fMW@050:n_[`1l
O7`0D51@051@D01OGel00P1TI6@0101iNGT0Ph>308>3P`1XJ6P:0?ooo`002P3oool30:j^[P050;>c
/`2e]KD0]KFe05QHF02BTY800P28R8P01020P800Vi^K09^KV`2][Jd20:n_[`050;:b/P2e]KD0/K6a
0;6a/@2c/k<00P2`/;020;6a/@80KFe]00@0JVYZ0:n_[`2_[jl0Zj^[0P2][Jd01@2/[:`0Z:RX0:FU
Y@2UYJD0Z:RX0080Zj^[00D0[Zj^0;6a/@2g]kL0]kNg0;>c/`020;Fe]@0505YJFP1kNg/0QXJ608J6
QP25QHD00P2:RXX01@2?Shl0WYjN09jNWP2PX:00W9bL0080SXj>0`25QHD01@2?Shl0WinO04];B`1;
Bd/0Ng]k0080[:b/00D0ZZZZ0:VYZ@2YZJT0YZJV08f=S@0209JFUP0509nOW`1oOgl0Ogmo07inOP1U
IFD00P1]KFd0101QHF40AdM704M7A`28R8P207moO`05079bLP2ZZZX0ZZZZ0:ZZZP2][Jd00P2ATI40
0`1`L700QHF50;Bd]0020;Bd]080/[:b00D0]kNg06MWI`1lO7`0O7al0:f][@020;>c/`050;:b/P2^
[Zh0[Zj^0;:b/P2a/K400P2`/;001@2^[Zh0ZZZZ0:ZZZP2ZZZX0Zj^[0080Ti>C00@0EeMG08N7Q`27
QhL0Vi^K0P2OWil01@2PX:00VYZJ09VIV@2IVIT0WYjN0080VYZJ00D0Rh^;08N7Q`2<S8`0S8b<08^;
R`0207moO`0506IVIP2>SXh0Rh^;08^;R`27QhL00P1mOGd01@1eMGD0NWYj07YjNP1gMgL0JFUY0080
JVYZ00D0Kfm_079bLP1bLW80K6a/061PH00204E5A@0406][J`1MGEd0GEeM05EEE@80DE5A00D0E5AD
05MGE`1XJ6P0J6QX06a/K00206e]K@0306IVIP3oool0oooo00l0oooo00@0P820061PH01PH600RXZ:
0P1dM7@01@2?Shl0PH610861P@2b/[80Jf][0080SHf=00D0NGUi05EEE@1EEED0R8R806EUI@02096A
T@04055AD@1MGEd0GEeM06ATI080Q8B400D0TY:B06i^KP1MGEd0GEeM05UIF@0205ADE00507emO@1Z
JVX0JVYZ09bLW02JVYX00P1:BTX01023Ph<0EUIF05IFEP1aLG4206MWI`050861P@3<c<`0OGem07em
O@1MGEd00P11@D400`1lO7`0[Zj^0;bl_0020;bl_080^[Zj00D0VYZJ09FEU@2EUID0VYZJ0::RXP02
08B4Q00407alO01_Kfl0Kfm_07QhN080VYZJ00D0^;Rh07UiN@2NWYh0WYjN07AdM0020;jn_P050;Vi
^@23Ph<0^KVi0;Vi^@2/[:`00P2XZ:P01@30`<00EUIF05IFEP22PX80H61P0080OGem00@0S8b<05AD
E01DE5@0GEeM0P2EUID01@32`/80OWin0820P020P800M7Ad0080Q8B400D0`l?30;^k^`38b<P0b<S8
07UiN@0207inOP050<G5a@23Ph<0Ph>305MGE`2;Rh/00P26QXH0101jNWX0YjNW0:NWY`39bLT20;Ng
]`0506m_K`2:RXX0VYZJ09ZJVP1aLG400P2FUYH01@2=SHd0^KVi0;Vi^@1mOGd0@T9200<0?3`l0P1C
De<0101iNGT0O7al06i^KP1^KVh308^;R`0308:2PP2EUID0UIFE0080JFUY0P1hN7P0101kNg/0UiNG
09NGU`2EUID20;:b/P0508N7Q`2/[:`0T92@092@T028R8P00P2MWId01@2_[jl0O7al051@D01@D500
GemO0080I6AT00@0NGUi08>3P`23Ph<0J6QX2P3oool000X0oooo00@0[Zj^0:RXZ02XZ:P0[:b/0P2b
/[801@1BDU80WIfM08b<S02<S8`0T92@0080XJ6Q00D0Y:BT0:FUY@2UYJD0X:2P0:JVYP020:NWY`05
0:JVYP2/[:`0[:b/0:f][@2`/;000P1_Kfl0101ZJVX0ZZZZ0:ZZZP2[Zj/30:b/[0040:ZZZP2TY:@0
Y:BT0:JVYP80YjNW00D0Z:RX0:b/[02_[jl0[jn_0;Jf]P020;>c/`0504a<C02TY:@0W9bL09bLW02E
UID00P2TY:@01@2UYJD0YZJV0:JVYP2WYjL0Y:BT0080VYZJ00D0RHV908:2PP22PX80V9RH0::RXP02
04I6AP040861P@2QXJ40XJ6Q0:n_[`80/k>c00D0ZZZZ09JFUP2FUYH0UYJF09RHV00207AdM00507If
MP1hN7P0Ph>308>3P`22PX800P1FEUH01@2:RXX0S8b<08b<S02<S8`0[:b/0080Zj^[00D0[:b/09BD
U02DU9@0MgMg06m_K`020;6a/@050;Rh^02f][H0][Jf0;Zj^P1QHF400P1iNGT30:f][@030:RXZ02V
YZH0YZJV00@0YjNW00D0ZJVY0:FUY@2UYJD0Zj^[0:b/[0020:NWY`0405mOG`2:RXX0RXZ:0:ZZZP<0
[Jf]00@0[Zj^0;Fe]@2e]KD0^[Zj0P2`/;001@2VYZH0Z:RX0:f][@2][Jd0Zj^[0080[jn_00D0IfMW
0;Zj^P35aLD0aLG50<C4a0020<71`@050;Jf]P32`/80`/;20:NWY`25QHD00P1XJ6P01@2b/[80_[jn
0;jn_P2i^KT0RXZ:0080Shn?00@0^;Rh0;>c/`2c/k<0ZZZZ0P2c/k<01@2g]kL0_;bl0;fm_@2m_Kd0
/k>c0080_;bl00<0^k^k0?ooo`3oool03`3oool01026QXH0KVi^06i^KP2;Rh/206a/K00507moO`1k
Ng/0Ng]k0:b/[01NGUh00P1`L7001@1ZJVX0@d=304=3@`20P800JVYZ0080P82000@0?Shn05iNGP1N
GUh0E5AD0P1gMgL01@2?Shl0JVYZ065QH@1QHF40FEUI0080AdM700D0NGUi06EUI@1UIFD0U9BD09jN
WP0204Y:BP0408R8R01KFe/0Fe]K08f=S@80O7al00D0Ogmo0=;BdP24Q8@0Q8B405YJFP0203Lg=`05
06ATI02DU9@0YZJV0:JVYP2KVi/00P2/[:`01@2OWil0X:2P0:2PX02MWId0YZJV0080Ph>300@0MGEe
075aL@1aLG40LG5a0P2JVYX01@2VYZH0JVYZ0::RXP2RXZ80MgMg0080/K6a00D0aLG507moO`2g]kL0
]kNg0:^[Z`0209nOW`050;Fe]@1>CTh0CTi>07EeM@1MGEd00P1dM7@0101hN7P0Kfm_06m_K`1UIFD2
09fMW@050;:b/P1kNg/0Ogmo07moO`25QHD00P2IVIT01@2m_Kd0ZJVY0;>c/`2c/k<0MGEe0080MgMg
00D0^[Zj09:BTP2BTY80Hf=S08b<S0020861P@0407EeM@2RXZ80XZ:R0<O7a`80WinO00D0De=C0;Jf
]P2YZJT0ZJVY06e]K@0208n?S`0509:BTP3:b/X0b/[:07moO`15ADD00P0g=cL01@0m?Cd0BTY:04Y:
BP1cLg<0NWYj0080L71`00@0R8R8092@T02@T900O7al0P2GUiL01@1YJFT0MgMg06][J`1[Jf/0Lg=c
0080Ogmo00D0NWYj09JFUP2FUYH0LW9b09ZJVP0208V9R@0508N7Q`2OWil0WinO0;6a/@26QXH00P1A
DE40101WIfL0JFUY06UYJ@21PH4206IVIP0307alO03oool0oooo00P0oooo000:0?ooo`030;6a/@2^
[Zh0[Zj^00<0/k>c00D0De=C0:RXZ02GUiL0UiNG09FEU@020:NWY`050:>SX`2VYZH0YZJV0:>SX`2Z
ZZX00P2SXj<01@2UYJD0Y:BT0:BTY02][Jd0/K6a00<0IfMW0P2ZZZX01@2[Zj/0[:b/0:b/[02[Zj/0
Z:RX0080YZJV00@0ZJVY0:JVYP2VYZH0YJFU0`2VYZH01@2^[Zh0Zj^[0:^[Z`13@d<0Z:RX0080XJ6Q
00@0V9RH09^KV`2KVi/0Xj>S0P2WYjL01@2VYZH0X:2P09fMW@2MWId0U9BD0080SXj>00D0X:2P09^K
V`1;Bd/0Bd];0861P@020:6QX@050:n_[`2a/K40/K6a0;2`/02/[:`00P2NWYh01@2KVi/0WinO09nO
W`2DU9@0X:2P0080Y:BT00@0S8b<05=CD`1CDe<0S8b<0P2ATI401@2DU9@0ZJVY0:RXZ02XZ:P0[jn_
0080Shn?00D0MgMg08F5Q@2b/[80/[:b0;Fe]@020;>c/`050;Vi^@1LG5`0MWIf07IfMP2YZJT00P2X
Z:P00`2UYJD0Y:BT0:BTY0020:VYZ@80Z:RX00<0YjNW0:ZZZP2ZZZX00P2][Jd20:BTY00405MGE`2:
RXX0RXZ:0:VYZ@80Zj^[00D0ZJVY0:ZZZP2b/[80/[:b0;Jf]P020;:b/P050:FUY@2`/;00];Bd0;Bd
]02b/[800P2c/k<01@1:BTX0YJFU0<C4a034a<@0aLG50080alO700D0^KVi0;^k^`2k^k/0P82005=C
D`020410@0050:NWY`2n_[h0_[jn0;fm_@2;Rh/00P2:RXX0102i^KT0]kNg0;Ng]`2/[:`20;Jf]P05
0;Zj^P2l_;`0_;bl0;bl_02m_Kd00P31`L400`2n_[h0oooo0?ooo`0?0?ooo`0407moO`1LG5`0G5aL
0820P080IfMW00D0OWin08f=S@2=SHd0`L7106UYJ@0209>CT`0506IVIP11@D40@D5108F5Q@1MGEd0
0P2>SXh0101:BTX0GemO05mOG`1XJ6P206YZJP0508>3P`1nOWh0GUiN05iNGP1HF5P00P15ADD01@1W
IfL0Kfm_06m_K`2NWYh0VIVI0080BDU900@0Ph>3061PH01PH600QXJ60P1eMGD01@20P800e=CD08b<
S02<S8`0I6AT0080@D5100D0QXJ60<71`@3:b/X0b/[:0:n_[`020;Jf]P0509ZJVP2HV9P0V9RH09nO
W`2CTi<00P1gMgL0101dM7@0I6AT06ATI01dM7@209ZJVP050;2`/01NGUh0SXj>08j>SP2ATI400P2Y
ZJT01@39bLT0Ogmo0:j^[P2^[Zh0/;2`0080Vi^K00D0/[:b04];B`1;Bd/0MWIf061PH00207alO004
07moO`1MGEd0GEeM06][J`80TY:B00<0_kno07alO023Ph<00P23Ph<209NGU`050<71`@2a/K40`<30
0<30`01gMgL00P1nOWh01@2h^;P0QhN708N7Q`1PH600SXj>0080JVYZ00@0MGEe09bLW02LW9`0alO7
0P2XZ:P01@1SHf<0P8200:2PX02PX:00Hf=S0080PX:200D0Rh^;0<;2`P32`/80O7al04A4A00203hn
?P<0@T9200D0KVi^07alO01_Kfl0Kfm_06a/K00208F5Q@0506m_K`2=SHd0SHf=06EUI@1WIfL00P1S
Hf<0101iNGT0M7Ad07AdM023Ph<20;^k^`0508J6QP2o_kl0PH610861P@2;Rh/00P2UYJD01@2^[Zh0
OWin055AD@1ADE40JFUY0080L71`00@0QXJ608j>SP2>SXh0OGem2P3oool000X0oooo00@0ZJVY0:b/
[02/[:`0Y:BT0P2FUYH0101BDU80P82008B4Q024Q8@308N7Q`0508b<S02@T900T92@096AT@2HV9P0
0P2BTY801@2=SHd0VYZJ09ZJVP2OWil0XJ6Q0080JFUY00@0FUYJ08R8R028R8P0Rh^;0P2JVYX01@2N
WYh0S8b<09>CT`2CTi<0SHf=0080U9BD00D0SHf=08j>SP2?Shl0Shn?09^KV`0209BDU00504I6AP2X
Z:P0YjNW0:NWY`2IVIT00P2PX:001@2MWId0XJ6Q0:6QX@2QXJ40V9RH0080VYZJ00D0TY:B08^;R`2;
Rh/0UiNG09^KV`0204E5A@0407UiN@2UYJD0YJFU09nOW`80WIfM00D0/K6a0;>c/`2][Jd0[Jf]0:^[
Z`020:VYZ@050:b/[02ZZZX0Zj^[0:^[Z`27QhL00P1@D5001@28R8P0Vi^K09^KV`2OWil0ZZZZ0080
Zj^[00D0/k>c09ZJVP2JVYX0OWin0861P@020;Jf]P050;Vi^@2j^[X0^[Zj0;Vi^@1QHF400P1oOgl0
102_[jl0[:b/0:b/[02SXj<20::RXP80WinO0P2SXj<01@2VYZH0YjNW0:NWY`2/[:`0YZJV0080XZ:R
00@0JVYZ09JFUP2FUYH0Z:RX0P2VYZH01@2QXJ40WinO0:FUY@2UYJD0[Zj^0080/;2`00D0WIfM0:2P
X02/[:`0[:b/0:f][@020:^[Z`050410@02HV9P0_kno0;no_`2n_[h00P2b/[801@2ZZZX0Y:BT0:BT
Y01QHF40=cLg0080A4A400D0WIfM0;:b/P2b/[80/;2`075aL@0208^;R`040;Zj^P2e]KD0]KFe0:f]
[@80][Jf00D0^[Zj0;no_`2m_Kd0_Kfm0;Zj^P020;bl_0030;fm_@3oool0oooo00l0oooo00@0RHV9
07IfMP1fMWH0V9RH0P1]KFd01@22PX80Ogmo07moO`2`/;00I6AT0080Lg=c00D0K6a/04Y:BP1:BTX0
SHf=069RHP0209FEU@04051@D01MGEd0GEeM07QhN080S8b<00D0Ti>C06e]K@1DE5@0E5AD04i>CP02
059BDP0506EUI@1cLg<0Lg=c09jNWP2OWil00P1@D5001022PX80GemO05mOG`1lO7`206m_K`0507al
O036a/H0OWin07inOP1KFe/00P0n?Sh01@1gMgL0][Jf0<K6aP36a/H0]KFe0080]kNg00D0Y:BT09RH
V02HV9P0Vi^K08B4Q00307AdM080MGEe00D0TI6A0:j^[P2^[Zh0a/K607MgM`0209ZJVP0509VIV@2X
Z:P0Z:RX0<[:bP22PX800P2g]kL0102n_[h0XJ6Q0:6QX@2a/K4204i>CP0508B4Q01WIfL0PX:208:2
PP23Ph<00`1SHf<209:BTP050;no_`26QXH0OWin07inOP1fMWH00P20P8001@2^[Zh0`L710;6a/@2a
/K40NWYj0080Ng]k00D0ZJVY08R8R028R8P0GEeM08B4Q002075aL@04071`L02ATI40TI6A0;bl_080
/;2`00D0Lg=c0820P02EUID0UIFE06IVIP0207YjNP0508Z:RP34a<@0a<C40861P@1:BTX00P0j>SX3
03lo?`0506UYJ@1bLW80MWIf07IfMP26QXH00P2:RXX01@1`L700S8b<08b<S01WIfL0G5aL0080GemO
00@0Ph>309RHV02HV9P0TI6A0P35aLD01@1lO7`0^k^k07=cL`1cLg<0P8200080TY:B00D0Shn?06MW
I`1ADE40DE5A059BDP0206e]K@0409FEU@2DU9@0U9BD07UiN@X0oooo000:0?ooo`040:VYZ@2/[:`0
[:b/0:BTY080UYJF00@0DU9B0820P024Q8@0Q8B40`27QhL01@2<S8`0T92@092@T02ATI40V9RH0080
TY:B00D0SHf=09ZJVP2JVYX0WinO0:6QX@0206UYJ@0405YJFP28R8P0R8R808^;R`80VYZJ00D0WYjN
08b<S02CTi<0Ti>C08f=S@0209BDU00508f=S@2>SXh0Shn?08n?S`2KVi/00P2DU9@01@16ATH0Z:RX
0:NWY`2WYjL0VIVI0080X:2P00D0WIfM0:6QX@2QXJ40XJ6Q09RHV00209ZJVP0509:BTP2;Rh/0Rh^;
09NGU`2KVi/00P15ADD0101iNGT0YJFU0:FUY@2OWil209fMW@050;6a/@2c/k<0[Jf]0:f][@2[Zj/0
0P2YZJT01@2/[:`0ZZZZ0:^[Z`2[Zj/0QhN70080D51@00D0R8R809^KV`2KVi/0WinO0:ZZZP020:^[
Z`050;>c/`2JVYX0VYZJ07inOP21PH400P2f][H01@2i^KT0^[Zj0;Zj^P2i^KT0HF5Q0080Ogmo00@0
[jn_0:b/[02/[:`0Xj>S0P2RXZ8209nOW`80Xj>S00D0YZJV0:NWY`2WYjL0[:b/0:JVYP020::RXP04
06YZJP2FUYH0UYJF0:RXZ080YZJV00D0XJ6Q09nOW`2UYJD0YJFU0:j^[P020;2`/00509fMW@2PX:00
[:b/0:b/[02][Jd00P2[Zj/01@10@400V9RH0;no_`2o_kl0_[jn0080/[:b00D0ZZZZ0:BTY02TY:@0
HF5Q03Lg=`0204A4A00509fMW@2b/[80/[:b0;2`/01aLG400P2;Rh/0102j^[X0]KFe0;Fe]@2][Jd2
0;Jf]P050;Zj^P2o_kl0_Kfm0;fm_@2j^[X00P2l_;`00`2m_Kd0oooo0?ooo`0?0?ooo`0408V9R@1f
MWH0MWIf09RHV080KFe]00D0PX:207moO`1oOgl0/;2`06ATI00207=cL`0506a/K01:BTX0BTY:08f=
S@1RHV800P2EUID0101@D500GEeM05eMG@1hN7P208b<S00509>CT`1]KFd0E5AD05ADE01>CTh00P1B
DU801@1UIFD0Lg=c07=cL`2NWYh0WinO0080D51@00@0PX:205mOG`1OGel0O7al0P1_Kfl01@1lO7`0
a/K607inOP1nOWh0Fe]K0080?Shn00D0MgMg0;Jf]P36a/H0a/K60;Fe]@020;Ng]`050:BTY02HV9P0
V9RH09^KV`24Q8@00`1dM7@207EeM@05096AT@2^[Zh0[Zj^0<K6aP1gMgL00P2JVYX01@2IVIT0Z:RX
0:RXZ03:b/X0PX:20080]kNg00@0_[jn0:6QX@2QXJ40/K6a0P1>CTh01@24Q8@0IfMW08:2PP22PX80
Ph>300<0Hf=S0P2BTY801@2o_kl0QXJ607inOP1nOWh0MWIf0080P82000D0[Zj^0<71`@2a/K40/K6a
07YjNP0207]kN`050:VYZ@28R8P0R8R805eMG@24Q8@00P1aLG40101`L700TI6A096AT@2l_;`20;2`
/00507=cL`20P800UIFE09FEU@1VIVH00P1jNWX01@2:RXX0a<C40<C4a021PH40BTY:0080>SXj0`0o
?cl01@1YJFT0LW9b07IfMP1fMWH0QXJ60080RXZ:00D0L71`08b<S02<S8`0IfMW05aLG00205mOG`04
08>3P`2HV9P0V9RH096AT@80aLG500D0O7al0;^k^`1cLg<0Lg=c0820P00209:BTP0508n?S`1WIfL0
DE5A055AD@1BDU800P1]KFd0102EUID0U9BD09BDU01iNGT:0?ooo`002P3oool0102JVYX0UiNG09NG
U`2CTi<208n?S`0508f=S@27QhL0OGem07emO@1hN7P00P1iNGT01@1XJ6P0=CDe03De=@1VIVH0J6QX
0080MGEe00D0OWin07UiN@1iNGT0NWYj07MgM`0207alO00406EUI@1iNGT0NGUi07inOP80LG5a00D0
F5QH03lo?`1DE5@0E5AD07=cL`0207IfMP0407=cL`1eMGD0N7Qh07QhN0<0Kfm_00D0KVi^06m_K`1R
HV80HV9R05MGE`0205ADE0050410@01NGUh0GUiN07moO`1lO7`00P1iNGT30861P@0508N7Q`1mOGd0
MWIf07IfMP1kNg/00P1lO7`01@1RHV80EeMG05MGE`1CDe<0CTi>0080CDe=00D0C4a<055AD@1ADE40
DE5A05EEE@0205]KF`0404e=C@14A4@0A4A404a<C0<0H61P00@0JFUY05iNGP1NGUh0F5QH0P16ATH0
1@19BDT0EEEE06QXJ01XJ6P0N7Qh0080MGEe00D0N7Qh051@D01>CTh0CTi>07QhN00207UiN@0506UY
J@1WIfL0IfMW06EUI@1jNWX00P1lO7`01@22PX80R8R808R8R01]KFd0Lg=c0080PX:200@0BDU907Yj
NP1jNWX0S8b<0P25QHD01@1eMGD0Q8B408n?S`2?Shl0V9RH0080WIfM00D0W9bL08f=S@2GUiL0UiNG
09fMW@0209nOW`0503Ph>024Q8@0YZJV0:JVYP2KVi/00P1nOWh01@20P800NGUi07UiN@1EEED0BTY:
0080Jf][00D0NGUi08b<S02<S8`0UYJF07=cL`0208f=S@040:n_[`2b/[80/[:b0:b/[080/k>c0P2k
^k/20;Vi^@040;Rh^02m_Kd0_Kfm0;Bd]140oooo00@0Ng]k05iNGP1NGUh0P8200P1CDe<01@27QhL0
S8b<08b<S02j^[X0MgMg0080PX:200D0LW9b04m?C`1?Cdl0Ti>C05mOG`0209bLW00404e=C@1JFUX0
FUYJ07]kN`80OWin00D0TY:B07EeM@1LG5`0G5aL04a<C00204M7A`0506=SH`1_Kfl0Kfm_09BDU02L
W9`00P15ADD0101oOgl0CDe=04e=C@1aLG420861P@0508>3P`3Fe]H0QhN708N7Q`1OGel00P12@T80
1@1[Jf/0UiNG0:RXZ02XZ:P0Xj>S0080XZ:R00D0Rh^;096AT@2ATI40TI6A0820P0020861P@0406MW
I`1YJFT0JFUY08>3P`80V9RH00<0YJFU07QhN02HV9P00P2HV9P20:ZZZP050;no_`1jNWX0Zj^[0:^[
Z`2d];@00P2NWYh01@2o_kl0=cLg03Lg=`1aLG40Hf=S0080Ph>300@0QHF506UYJ@1YJFT0Hf=S0P2X
Z:P01@34a<@0VYZJ07UiN@1iNGT0P8200080Ogmo00D0/;2`0;Jf]P2e]KD0]KFe092@T00208B4Q005
09^KV`2;Rh/0Rh^;07YjNP29RHT00P1hN7P0101aLG40UYJF09JFUP3:b/X20:f][@0506ATI01kNg/0
UiNG09NGU`1OGel00P1JFUX01@1gMgL0aLG50<G5a@1nOWh0ATI60080>3Ph00D0>CTi03dm?@0m?Cd0
FUYJ04m?C`0205]KF`0405iNGP1lO7`0O7al061PH080TI6A00D0I6AT06UYJ@1UIFD0IFEU07IfMP02
0820P00506UYJ@2FUYH0UYJF06e]K@2g]kL00P1cLg<01@2BTY80WIfM09fMW@2BTY80MgMg0080Bd];
00@0C4a<06EUI@1UIFD0NWYj0P27QhL00`23Ph<0oooo0?ooo`080?ooo`002P3oool00`2k^k/0]kNg
0;Ng]`030;Zj^P050;Ng]`2e]KD0/[:b0;:b/P2_[jl00P2YZJT01@2/[:`0CTi>04i>CP2LW9`0XJ6Q
0080WinO00D0Xj>S0:FUY@2UYJD0Zj^[0:RXZ0020:f][@040;6a/@2d];@0];Bd0;>c/`80[:b/00D0
XJ6Q061PH02QXJ40XJ6Q0:n_[`020:j^[P030:f][@2e]KD0];Bd0080];Bd0P2k^k/01@2i^KT0_;bl
0;no_`2o_kl0`<300080^[Zj00D0IFEU0:f][@2][Jd0[jn_0:VYZ@030:JVYP80YJFU00D0ZZZZ0:f]
[@2][Jd0[Jf]0:j^[P020;6a/@<0/k>c00D0Jf][08j>SP2b/[80/[:b0;2`/0020:NWY`050:BTY02d
];@0]kNg0;Ng]`2d];@00P2h^;P01@2f][H0/K6a0;6a/@2_[jl0YJFU0080IfMW00D0RHV909NGU`2G
UiL0W9bL09ZJVP0209NGU`0509JFUP2EUID0UIFE09JFUP2NWYh00P2XZ:P0102YZJT0VYZJ09ZJVP23
Ph<205YJFP0507]kN`23Ph<0MgMg07MgM`1dM7@00P1aLG401@1iNGT0OWin07inOP1nOWh0R8R80080
N7Qh00D0JFUY06EUI@1UIFD0?clo04U9B@0206EUI@<0JVYZ00D0FUYJ05]KF`1RHV80HV9R065QH@02
05mOG`0506ATI01OGel0K6a/06a/K01ZJVX00P14A4@01@1QHF40J6QX06QXJ01RHV80I6AT0080IFEU
00D0G5aL05mOG`1OGel0Fe]K05MGE`0204];B`0403Ti>@0k>c/0>c/k03/k>`80>SXj00D0?Shn04a<
C017AdL0AdM704m?C`0204Y:BP0304];B`3oool0oooo00l0oooo00@0OGem06ATI01TI6@0Shn?0P1O
Gel01@26QXH0Kfm_06m_K`1jNWX0MGEe0080LW9b00D0IFEU04=3@`13@d<0Ogmo061PH00209ZJVP04
04a<C01FEUH0EUIF08j>SP80QHF500D0SXj>06ATI01;Bd/0Bd];04I6AP0204Y:BP0505mOG`1hN7P0
N7Qh09VIV@2MWId00P19BDT01029RHT0FEUI05UIF@1]KFd207=cL`0506e]K@2k^k/0Ng]k07]kN`1D
E5@00P0m?Cd01@1[Jf/0W9bL0:b/[02/[:`0Xj>S0080/;2`00D0Vi^K09fMW@2MWId0UiNG08j>SP02
08Z:RP0406][J`1`L700L71`07]kN`80VIVI00D0`/;20820P02KVi/0Vi^K092@T0020:VYZ@050<30
`023Ph<0YZJV0:JVYP2LW9`00P2HV9P01@2j^[X0>CTi03Ti>@1UIFD0CTi>0080IfMW00@0IFEU05iN
GP1NGUh0IFEU0P2DU9@01@2ZZZX0SHf=05aLG01LG5`0Kfm_0080OWin00D0YjNW0<;2`P2d];@0];Bd
08B4Q00207emO@0409ZJVP2NWYh0WYjN08f=S@<0Ng]k00@0Hf=S08f=S@2=SHd0][Jf0P2TY:@01@1H
F5P0Shn?08B4Q024Q8@0MGEe0080Fe]K00D0L71`0;Fe]@2e]KD0Ti>C04a<C00203Xj>P0503Ph>01?
Cdl0Cdm?06=SH`1/K6`00P1ZJVX0101fMWH0LW9b079bLP1PH602079bLP0505eMG@1>CTh0G5aL05aL
G01lO7`00P28R8P01@26QXH0Zj^[0:^[Z`2BTY80clo?0080KFe]00D0QhN708b<S02<S8`0O7al06MW
I`02051@D00405eMG@1OGel0GemO06EUI@<0L71`2P3oool000X0oooo00<0^k^k0;Ng]`2g]kL00`2j
^[X01@2g]kL0]KFe0;:b/P2b/[80[jn_0080ZJVY00D0[:b/04i>CP1>CTh0W9bL0:6QX@0209nOW`05
0:>SX`2UYJD0YJFU0:^[Z`2XZ:P00P2][Jd0102a/K40];Bd0;Bd]02c/k<20:b/[0050:6QX@1PH600
XJ6Q0:6QX@2_[jl00P2^[Zh00`2][Jd0]KFe0;Bd]0020;Bd]080^k^k00D0^KVi0;bl_02o_kl0_kno
0<30`0020;Zj^P0506EUI@2][Jd0[Jf]0:n_[`2YZJT00`2VYZH20:FUY@050:ZZZP2][Jd0[Jf]0:f]
[@2^[Zh00P2a/K430;>c/`0506][J`2>SXh0/[:b0;:b/P2`/;000P2WYjL01@2TY:@0];Bd0;Ng]`2g
]kL0];Bd0080^;Rh00D0][Jf0;6a/@2a/K40[jn_0:FUY@0206MWI`0508V9R@2GUiL0UiNG09bLW02J
VYX00P2GUiL01@2FUYH0UIFE09FEU@2FUYH0WYjN0080Z:RX00@0ZJVY09ZJVP2JVYX0Ph>30P1JFUX0
1@1kNg/0Ph>307MgM`1gMgL0M7Ad0080LG5a00D0NGUi07inOP1nOWh0OWin08R8R00207QhN00506UY
J@1UIFD0IFEU03lo?`19BDT00P1UIFD306YZJP0505YJFP1KFe/0HV9R069RHP1QHF400P1OGel01@1T
I6@0GemO06a/K01/K6`0JVYZ0080A4A400D0HF5Q06QXJ01XJ6P0HV9R06ATI00206EUI@0505aLG01O
Gel0GemO05]KF`1GEeL00P1;Bd/0100i>CT0>c/k03/k>`0k>c/203Xj>P0503hn?P1<C4`0AdM704M7
A`1?Cdl00P1:BTX00`1;Bd/0oooo0?ooo`0?0?ooo`0407emO@1TI6@0I6AT08n?S`80GemO00D0QXJ6
06m_K`1_Kfl0NWYj07EeM@02079bLP0506EUI@13@d<0@d=307moO`1PH6000P2JVYX0101<C4`0EUIF
05IFEP2>SXh208F5Q@0508j>SP1TI6@0Bd];04];B`16ATH00P1:BTX01@1OGel0N7Qh07QhN02IVIT0
WIfM0080BDU900@0RHV905UIF@1IFET0KFe]0P1cLg<01@1]KFd0^k^k07]kN`1kNg/0E5AD0080?Cdm
00D0Jf][09bLW02/[:`0[:b/0:>SX`020;2`/00509^KV`2MWId0WIfM09NGU`2>SXh00P2:RXX0101[
Jf/0L71`071`L01kNg/209VIV@050<;2`P20P800Vi^K09^KV`2@T9000P2YZJT01@30`<00Ph>30:JV
YP2VYZH0W9bL0080V9RH00D0^[Zj03Ti>@0i>CT0IFEU04i>CP0206MWI`0406EUI@1NGUh0GUiN06EU
I@80U9BD00D0ZZZZ08f=S@1LG5`0G5aL06m_K`0207inOP050:NWY`32`/80];Bd0;Bd]024Q8@00P1m
OGd0102JVYX0WYjN09jNWP2=SHd307]kN`0406=SH`2=SHd0SHf=0;Jf]P80Y:BT00D0F5QH08n?S`24
Q8@0Q8B407EeM@0205]KF`05071`L02e]KD0]KFe09>CT`1<C4`00P0j>SX01@0h>3P0Cdm?04m?C`1S
Hf<0K6a/0080JVYZ00@0MWIf079bLP1bLW80H61P0P1bLW801@1MGEd0CTi>05aLG01LG5`0O7al0080
R8R800D0QXJ60:^[Z`2[Zj/0TY:B0<o?c`0206e]K@0508N7Q`2<S8`0S8b<07alO01WIfL00P1@D500
101MGEd0GemO05mOG`1UIFD3071`L0X0oooo000:0?ooo`040;Ng]`2`/;00/;2`0;>c/`80/;2`00D0
[jn_0:b/[02YZJT0ZJVY0:b/[0020:^[Z`040:b/[01@D500D51@0::RXP<0YJFU00D0WIfM09RHV02H
V9P0T92@09fMW@020:RXZ0040:ZZZP2_[jl0[jn_0:j^[P80ZJVY00D0YjNW05aLG02TY:@0Y:BT0:^[
Z`020:b/[0030:VYZ@2[Zj/0ZJVY0080ZJVY0P2WYjL01@2YZJT0/K6a0;Ng]`2g]kL0^k^k0080_kno
00D0MWIf0:NWY`2WYjL0[Jf]0:BTY00209^KV`0509fMW@2RXZ80XZ:R0:6QX@2YZJT00`2^[Zh20:f]
[@050;2`/02^[Zh0[Zj^07]kN`2<S8`00P2ZZZX01@2WYjL0YZJV0:JVYP2UYJD0[:b/0080[Zj^102`
/;020:b/[080ZZZZ0P28R8P01@2f][H0^k^k0;^k^`32`/80_;bl0080^k^k00@0_[jn0<;2`P32`/80
_kno0`31`L401035aLD0_[jn0;jn_P2e]KD208V9R@050;Rh^02j^[X0^;Rh0;Rh^02d];@00P2_[jl0
0`2f][H0]kNg0;>c/`020;>c/`80];Bd00D0][Jf0;>c/`2c/k<0GemO08V9R@020;Zj^P<0_;bl00D0
^[Zj0;Rh^02b/[80/[:b0;Bd]0020;Rh^0050;Bd]02j^[X0`<300<30`02l_;`00P1YJFT01@2_[jl0
]kNg0;Ng]`2a/K40[:b/0080[jn_0`2d];@01@2g]kL0];Bd0:RXZ02XZ:P0ZJVY0080[Jf]00D0UYJF
06ATI01TI6@0X:2P0:j^[P020;>c/`040:n_[`2TY:@0Y:BT0:2PX140oooo00@0PX:2075aL@1aLG40
Shn?0P1BDU801@1fMWH0Lg=c07=cL`2>SXh0J6QX0080LG5a00D0IfMW04E5A@15ADD0N7Qh05]KF`02
08j>SP0404U9B@1BDU80DU9B09JFUP80PX:200D0VIVI071`L01PH600H61P05MGE`0205eMG@0506AT
I01aLG40LG5a08b<S02KVi/00P0o?cl01025QHD0Cdm?04m?C`1WIfL207AdM00507YjNP3;bl/0Rh^;
08^;R`1[Jf/00P16ATH01@1mOGd0^;Rh0;^k^`2k^k/0[Jf]0080ZZZZ00D0Rh^;09NGU`2GUiL0UYJF
08J6QP0208F5Q@04069RHP1aLG40LG5a07YjNP80Vi^K00D0bl_;07MgM`2IVIT0VIVI08N7Q`020:JV
YP050;^k^`2KVi/0Zj^[0:^[Z`2c/k<00P2NWYh01@33`l<0@D510451@@20P800LG5a0080RHV900@0
Ph>305eMG@1MGEd0Fe]K0P2g]kL01@2e]KD0RHV905eMG@1MGEd0HF5Q0080R8R800D0[:b/0=?Cd`2_
[jl0[jn_08N7Q`0207MgM`0508b<S02KVi/0Vi^K0:>SX`1`L7000P1PH600101JFUX0Lg=c07=cL`2a
/K4209fMW@0506=SH`2KVi/0X:2P0:2PX01iNGT00P1HF5P01@1fMWH0`l?30<?3``2YZJT0EEEE0080
BDU900D0>CTi05MGE`1GEeL0Ng]k071`L00207UiN@0406m_K`1dM7@0M7Ad06i^KP80L71`00D0NGUi
06=SH`1gMgL0MgMg06i^KP0207moO`0509ZJVP2KVi/0Vi^K092@T02[Zj/00P18B4P01@1hN7P0UIFE
09FEU@2FUYH0PH610080IVIV00@0FEUI06YZJP1ZJVX0JFUY0P2;Rh/00`24Q8@0oooo0?ooo`080?oo
o`002P3oool0102a/K40[jn_0:n_[`2_[jl20:ZZZP80ZJVY0P2VYZH0102[Zj/0[Jf]0:f][@2_[jl2
061PH00508j>SP29RHT0VYZJ09ZJVP2LW9`00P2QXJ4209nOW`80[:b/00@0[Jf]0:b/[02/[:`0Zj^[
0P2ZZZX01@2/[:`0LW9b0;>c/`2c/k<0ZZZZ0080Z:RX00D0YjNW0:RXZ02ZZZX0ZZZZ0:RXZ0020:^[
Z`050:VYZ@2][Jd0];Bd0;Bd]02k^k/00P2j^[X01@1hN7P0/k>c0;>c/`2^[Zh0WIfM0080VYZJ00D0
UIFE0:JVYP2VYZH0X:2P0:BTY0020::RXP040:FUY@2[Zj/0Zj^[0:n_[`80[Jf]00D0Lg=c0861P@2K
Vi/0Vi^K09JFUP0209NGU`0509nOW`2XZ:P0YjNW0:NWY`2ZZZX00P2YZJT01@2^[Zh0Zj^[0:^[Z`2W
YjL0WIfM0080Rh^;00D0]KFe0;Rh^02h^;P0_;bl0;^k^`020;Ng]`050;Fe]@2o_kl0_kno0<K6aP2m
_Kd00P2o_kl01037alL0`l?30<?3``2e]KD207YjNP050;Fe]@2g]kL0^;Rh0;Rh^02e]KD00P2a/K40
1@2k^k/0^;Rh0;Fe]@2e]KD0/[:b0080Zj^[00D0[:b/0:f][@2][Jd0FUYJ07emO@020;Rh^0030;bl
_02j^[X0^[Zj0080^KVi1@2d];@01@2h^;P0^KVi0;^k^`2k^k/0^KVi0080I6AT00D0Vi^K0;>c/`2c
/k<0[:b/0:VYZ@020:n_[`050;>c/`2b/[80/[:b0;2`/02_[jl00P2ZZZX0102][Jd0[Zj^0:j^[P2@
T90206ATI0050:^[Z`2d];@0/[:b0;:b/P2c/k<00P2[Zj/00`2a/K40oooo0?ooo`0?0?ooo`0408B4
Q01bLW80LW9b09FEU@80GemO00D0OGem07MgM`1gMgL0RXZ:059BDP0206IVIP05069RHP17AdL0AdM7
07AdM01WIfL00P2@T90304Q8B00508^;R`1jNWX0NWYj09:BTP1XJ6P00P1EEED01018B4P0Bd];04];
B`1?Cdl207emO@0509JFUP2<S8`0@d=304=3@`1kNg/00P1ADE401@1RHV80J6QX06QXJ01mOGd0a/K6
0080TI6A00D0GEeM03hn?P0n?Sh0LW9b0;Rh^0020;Jf]P040:BTY02c/k<0/k>c09^KV`80T92@00D0
V9RH08f=S@1kNg/0Ng]k05ADE00206IVIP0507EeM@2;Rh/0Rh^;0:JVYP1SHf<00P27QhL01@29RHT0
];Bd0;Bd]031`L40X:2P0080ZZZZ00@0`<300:j^[P2^[Zh0/;2`0P0o?cl01@1bLW80G5aL06ATI01T
I6@0Lg=c0080KFe]00D0CTi>09^KV`2KVi/0^;Rh0:RXZ00207AdM00505mOG`2<S8`0S8b<0;Ng]`38
b<P00P2a/K40102<S8`0LW9b079bLP2ATI420;6a/@0509^KV`1ZJVX0Kfm_06m_K`1SHf<00P2HV9P0
1@37alL0X:2P0:2PX01hN7P0U9BD0080UYJF00@0SHf=06MWI`1WIfL0Lg=c0P36a/H01@2`/;00Fe]K
04I6AP16ATH0?3`l0080CDe=00D0MgMg06a/K01jNWX0NWYj05YJFP0206QXJ00505mOG`1WIfL0IfMW
08Z:RP1SHf<00P1XJ6P0101cLg<0Rh^;08^;R`2HV9P208N7Q`0508b<S02/[:`0D51@051@D02>SXh0
0P2PX:001@2GUiL0OWin07alO01lO7`0K6a/0080I6AT00@0Jf][07]kN`1kNg/0LW9b2P3oool000X0
oooo00@0/k>c0;6a/@2a/K40/K6a0P2f][H01@2`/;00WinO0:6QX@2QXJ40Xj>S00<0ZJVY0P1GEeL0
1026QXH0V9RH0:RXZ02XZ:P30;6a/@050:j^[P2XZ:P0[:b/0:b/[02a/K400P2c/k<01@2i^KT0][Jf
0;Jf]P2b/[80L71`0080XZ:R0`2XZ:P01@2WYjL0ZZZZ0:f][@2][Jd0ZZZZ0080/k>c00D0/;2`0;Fe
]@2g]kL0]kNg0;bl_0020;^k^`0507alO02i^KT0^KVi0;Fe]@2`/;000P2^[Zh01@2YZJT0XZ:R0::R
XP2FUYH0X:2P0080Zj^[00@0/;2`0;Jf]P2f][H0]KFe0P2c/k<01@1SHf<0NWYj08j>SP2>SXh0Rh^;
0080Shn?00D0U9BD0:6QX@2IVIT0VIVI09fMW@030::RXP80Z:RX00D0WYjN07alO021PH40PH610;6a
/@020;Bd]0050;Jf]P2g]kL0^KVi0;Vi^@2j^[X00`2m_Kd0102g]kL0^;Rh0;Rh^02n_[h20;^k^`05
0;6a/@23Ph<0Ph>30;>c/`2a/K400P2f][H01@2i^KT0]kNg0;Ng]`2b/[80/K6a0080[Jf]00@0[:b/
0:^[Z`2[Zj/0YZJV0P2SXj<01@1GEeL0Rh^;0;Bd]02d];@0]kNg0080^KVi00D0^;Rh0;Jf]P2a/K40
/K6a0;>c/`020;:b/P050;6a/@2g]kL0^KVi0;Vi^@2d];@00P1FEUH01@2DU9@0[jn_0:n_[`2XZ:P0
YjNW0080[Jf]00D0/K6a0;2`/02`/;00[Zj^0:f][@020:ZZZP040:b/[02[Zj/0Zj^[08j>SP80MgMg
00D0ZZZZ0;Ng]`2d];@0];Bd0;>c/`020:VYZ@030:n_[`3oool0oooo00l0oooo00@0MWIf06YZJP1Z
JVX0Ph>30P1HF5P01@24Q8@0PH610861P@2BTY80HF5Q0080LG5a00D0Fe]K04=3@`13@d<0Jf][06UY
J@0207emO@<0B4Q800D0T92@075aL@1aLG40RXZ:075aL@0206=SH`0404U9B@1QHF40HF5Q05iNGP80
PX:200D0VYZJ09FEU@1<C4`0C4a<07moO`0205ADE00506][J`1SHf<0Hf=S08N7Q`2k^k/00P27QhL0
101HF5P0=3@d03@d=01WIfL30:JVYP040:>SX`2][Jd0[Jf]0:6QX@80UYJF00D0VYZJ08^;R`1[Jf/0
Jf][05=CD`0206e]K@0507UiN@2DU9@0U9BD0;^k^`1TI6@00P2?Shl01@28R8P0/k>c0;>c/`37alL0
YZJV0080Vi^K00@0^;Rh0;Vi^@2i^KT0a<C40P1?Cdl01@2ATI40Ng]k07AdM01dM7@0NGUi0080Lg=c
00D0K6a/08^;R`2;Rh/0[jn_09nOW`0207inOP0505QHF02=SHd0SHf=0:j^[P3Jf]X00P2l_;`0101`
L700IFEU06EUI@2KVi/20;jn_P0509VIV@1[Jf/0LG5a075aL@1cLg<00P2XZ:P01@32`/80Zj^[0:^[
Z`1iNGT0Z:RX0080YZJV00@0VYZJ06UYJ@1YJFT0N7Qh0P2b/[801@2f][H0DU9B03hn?P0n?Sh0BTY:
0080ATI600D0PH6107=cL`1_Kfl0Kfm_06MWI`0207=cL`0506EUI@1RHV80HV9R07UiN@1ZJVX00P1E
EED0101SHf<0LW9b079bLP1nOWh208f=S@0509jNWP2YZJT0BTY:04Y:BP28R8P00P2=SHd01@24Q8@0
MgMg069RHP1RHV80FUYJ0080MGEe00@0IfMW08N7Q`27QhL0NWYj2P3oool000X0oooo00@0/k>c0;6a
/@2a/K40/K6a0P2f][H01@2`/;00WinO0:6QX@2QXJ40Xj>S00<0ZJVY0P1GEeL01026QXH0V9RH0:RX
Z02XZ:P30;6a/@050:j^[P2XZ:P0[:b/0:b/[02a/K400P2c/k<01@2i^KT0][Jf0;Jf]P2b/[80L71`
0080XZ:R0`2XZ:P01@2WYjL0ZZZZ0:f][@2][Jd0ZZZZ0080/k>c00D0/;2`0;Fe]@2g]kL0]kNg0;bl
_0020;^k^`0507alO02i^KT0^KVi0;Fe]@2`/;000P2^[Zh01@2YZJT0XZ:R0::RXP2FUYH0X:2P0080
Zj^[00@0/;2`0;Jf]P2f][H0]KFe0P2c/k<01@1SHf<0NWYj08j>SP2>SXh0Rh^;0080Shn?00D0U9BD
0:6QX@2IVIT0VIVI09fMW@030::RXP80Z:RX00D0WYjN07alO021PH40PH610;6a/@020;Bd]0050;Jf
]P2g]kL0^KVi0;Vi^@2j^[X00`2m_Kd0102g]kL0^;Rh0;Rh^02n_[h20;^k^`050;6a/@23Ph<0Ph>3
0;>c/`2a/K400P2f][H01@2i^KT0]kNg0;Ng]`2b/[80/K6a0080[Jf]00@0[:b/0:^[Z`2[Zj/0YZJV
0P2SXj<01@1GEeL0Rh^;0;Bd]02d];@0]kNg0080^KVi00D0^;Rh0;Jf]P2a/K40/K6a0;>c/`020;:b
/P050;6a/@2g]kL0^KVi0;Vi^@2d];@00P1FEUH01@2DU9@0[jn_0:n_[`2XZ:P0YjNW0080[Jf]00D0
/K6a0;2`/02`/;00[Zj^0:f][@020:ZZZP040:b/[02[Zj/0Zj^[08j>SP80MgMg00D0ZZZZ0;Ng]`2d
];@0];Bd0;>c/`020:VYZ@030:n_[`3oool0oooo00l0oooo00@0MWIf06YZJP1ZJVX0Ph>30P1HF5P0
1@24Q8@0PH610861P@2BTY80HF5Q0080LG5a00D0Fe]K04=3@`13@d<0Jf][06UYJ@0207emO@<0B4Q8
00D0T92@075aL@1aLG40RXZ:075aL@0206=SH`0404U9B@1QHF40HF5Q05iNGP80PX:200D0VYZJ09FE
U@1<C4`0C4a<07moO`0205ADE00506][J`1SHf<0Hf=S08N7Q`2k^k/00P27QhL0101HF5P0=3@d03@d
=01WIfL30:JVYP040:>SX`2][Jd0[Jf]0:6QX@80UYJF00D0VYZJ08^;R`1[Jf/0Jf][05=CD`0206e]
K@0507UiN@2DU9@0U9BD0;^k^`1TI6@00P2?Shl01@28R8P0/k>c0;>c/`37alL0YZJV0080Vi^K00@0
^;Rh0;Vi^@2i^KT0a<C40P1?Cdl01@2ATI40Ng]k07AdM01dM7@0NGUi0080Lg=c00D0K6a/08^;R`2;
Rh/0[jn_09nOW`0207inOP0505QHF02=SHd0SHf=0:j^[P3Jf]X00P2l_;`0101`L700IFEU06EUI@2K
Vi/20;jn_P0509VIV@1[Jf/0LG5a075aL@1cLg<00P2XZ:P01@32`/80Zj^[0:^[Z`1iNGT0Z:RX0080
YZJV00@0VYZJ06UYJ@1YJFT0N7Qh0P2b/[801@2f][H0DU9B03hn?P0n?Sh0BTY:0080ATI600D0PH61
07=cL`1_Kfl0Kfm_06MWI`0207=cL`0506EUI@1RHV80HV9R07UiN@1ZJVX00P1EEED0101SHf<0LW9b
079bLP1nOWh208f=S@0509jNWP2YZJT0BTY:04Y:BP28R8P00P2=SHd01@24Q8@0MgMg069RHP1RHV80
FUYJ0080MGEe00@0IfMW08N7Q`27QhL0NWYj2P3oool000X0oooo00@0IVIV05eMG@1MGEd0B4Q80P0i
>CT01@0a<C40=SHf03@d=00d=3@0<C4a0080@D5100D0?3`l03@d=00d=3@0<S8b0410@00203/k>`05
03`l?00i>CT0>CTi0492@P0m?Cd00P0`<300100f=SH0?3`l03`l?00n?Sh203/k>`0503Xj>P0V9RH0
?Shn03hn?P1<C4`00P1;Bd/01@1=CDd0?Cdm03/k>`0k>c/0=3@d0080=CDe00D0:RXZ03Xj>P13@d<0
@d=304I6AP0203Xj>P0503/k>`1IFET0FEUI05iNGP1QHF400P1FEUH01@1PH600HF5Q065QH@1PH600
GEeM0080HF5Q00@0JVYZ07EeM@1eMGD0Lg=c0P1[Jf/01@0d=3@0CTi>05]KF`1KFe/0G5aL0080IVIV
00D0HV9R06=SH`1TI6@0I6AT06][J`0206a/K0<0KVi^00D0IfMW06EUI@18B4P0B4Q807]kN`020820
P0050861P@1lO7`0K6a/06a/K01VIVH00P1`L7001@21PH40QHF508Z:RP2:RXX0T92@0080Shn?00D0
IFEU065QH@1QHF40SXj>07moO`020:>SX`050:6QX@2TY:@0Y:BT09jNWP2PX:000P2LW9`0102GUiL0
V9RH09RHV02KVi/209:BTP0504i>CP25QHD0/K6a0;6a/@2c/k<00P2h^;P0102f][H0];Bd0:n_[`2_
[jl30:j^[P050;>c/`2b/[80/k>c0;>c/`2][Jd00P1:BTX00`2NWYh0/;2`0;2`/0020:j^[P80/;2`
00D0/K6a0;:b/P2b/[80/[:b0:^[Z`0209nOW`040:ZZZP2`/;00/;2`08b<S080MgMg00@0XZ:R0:BT
Y02a/K40/K6a0`2YZJT00`2a/K40oooo0?ooo`0?0?ooo`0406ATI01nOWh0OWin08B4Q080ATI600D0
R8R807inOP1nOWh0TI6A05QHF002071`L00505YJFP1?Cdl0Cdm?07=cL`1`L7000P1jNWX01016ATH0
CDe=04e=C@27QhL207QhN0040861P@1aLG40Cdm?04m?C`<0AdM700D0Bd];07YjNP1jNWX0Shn?096A
T@0205IFEP0408:2PP1@D500D51@06i^KP80GUiN00D0Rh^;0<_;b`2NWYh0WYjN04e=C@0202d];@05
06ATI02RXZ80YjNW0:NWY`2^[Zh00P2c/k<01@2EUID0TY:B09:BTP2QXJ40UIFE0080NGUi00@0L71`
075aL@1aLG40Ng]k0P2EUID01@2[Zj/0EEEE09FEU@2EUID0QhN70080^[Zj00D0b/[:0:f][@2CTi<0
Ti>C0;6a/@020;Jf]P050;Zj^P16ATH0ATI608Z:RP24Q8@00P28R8P01022PX80SHf=08f=S@1]KFd2
08j>SP050<c<c02<S8`0Kfm_06m_K`1=CDd00P1oOgl01@24Q8@0f][J0:f][@2][Jd0Lg=c0080GEeM
00D0WinO0<G5a@35aLD0PH6106UYJ@02065QH@04071`L02QXJ40XJ6Q0:RXZ080XJ6Q00D0QHF50:6Q
X@2NWYh0WYjN08F5Q@0205]KF`0506YZJP2SXj<0Xj>S0;:b/P1PH6000P0n?Sh01@1<C4`0@D510451
@@1OGel0M7Ad0080Ogmo00@0L71`06UYJ@1YJFT0GEeM0P1gMgL01@1OGel0IfMW06=SH`1SHf<0KVi^
0080RHV900D0T92@08R8R028R8P0Ti>C09fMW@02059BDP0509VIV@2TY:@0Y:BT0:6QX@2<S8`00P1j
NWX0101OGel0GUiN05iNGP1XJ6P206MWI`0306EUI@3oool0oooo00P0oooo000:0?ooo`040;Ng]`2f
][H0][Jf0:^[Z`80LW9b00@0NGUi0:j^[P2_[jl0[jn_102c/k<20;Bd]0050;bl_02h^;P0];Bd0;Bd
]02][Jd00P2/[:`01@2YZJT0Ti>C059BDP1BDU80/k>c0080][Jf00D0]kNg0;>c/`2c/k<0/[:b0:ZZ
ZP020:FUY@0509fMW@2DU9@0U9BD08b<S02=SHd00P2ATI401@27QhL0BDU904U9B@2NWYh0[:b/0080
[Jf]0`2TY:@30:NWY`050:JVYP2PX:00Vi^K09^KV`2GUiL00P2ATI401@23Ph<0Cdm?07emO@1mOGd0
PH610080PX:200D0P82007inOP1nOWh0MgMg06a/K00206QXJ00506EUI@1YJFT0JFUY06UYJ@1fMWH0
0P1`L700100f=SH0DU9B059BDP1OGel205UIF@0505iNGP1UIFD0KVi^06i^KP1/K6`00P1WIfL01@1R
HV80Fe]K05eMG@1MGEd0EUIF0080?Cdm00D0;bl_04Y:BP1:BTX0BTY:04m?C`0204Y:BP0504U9B@0n
?Sh0?Shn02l_;`16ATH00P0o?cl01@10@400>c/k03/k>`0e=CD0C4a<0080DU9B00@0DE5A05EEE@1E
EED0B4Q80P19BDT01@1CDe<0E5AD04A4A014A4@0@D510080B4Q800D0>c/k02`/;00^;Rh0;Rh^03Lg
=`0203Xj>P0504=3@`17AdL0CDe=04e=C@0g=cL00P0];Bd01@11@D40CTi>04i>CP1;Bd/0D51@0080
E5AD00D0FUYJ05iNGP1NGUh0HV9R06IVIP0206a/K00406YZJP1XJ6P0J6QX059BDP80=CDe00D0De=C
05eMG@1ZJVX0JVYZ06EUI@02069RHP0307IfMP3oool0oooo00l0oooo00@0JVYZ07AdM01dM7@0MgMg
0P16ATH01@2CTi<0OGem07emO@21PH40GEeM0080LW9b00D0KFe]05aLG01LG5`0T92@079bLP0207Ui
N@0404E5A@11@D40@D51092@T080NGUi00D0N7Qh08F5Q@1IFET0FEUI04U9B@0204E5A@0505aLG01c
Lg<0Lg=c09BDU02LW9`00P1EEED0101nOWh0B4Q804Q8B01PH602065QH@0509>CT`3;bl/0YJFU0:FU
Y@1LG5`00P0k>c/0101cLg<0WIfM0;Fe]@2e]KD30:j^[P0509>CT`2KVi/0Vi^K0:JVYP2TY:@00P1n
OWh0101LG5`0O7al07alO01mOGd209NGU`050:f][@1PH600U9BD09BDU020P8000P2g]kL01@38b<P0
/[:b09JFUP2FUYH0/[:b0080]KFe00@0]kNg04U9B@19BDT0P8200`1kNg/0101nOWh0Rh^;08^;R`1]
KFd207YjNP050<G5a@2:RXX0NWYj07YjNP1HF5P00P2EUID01@2FUYH0^[Zj0:2PX02PX:00NWYj0080
IFEU00D0Shn?0<O7a`37alL0NWYj06i^KP0206e]K@0406m_K`2MWId0WIfM0:f][@80ZJVY00D0QHF5
08j>SP2=SHd0SHf=07moO`0207IfMP05092@T02UYJD0YJFU0:j^[P1OGel00P0n?Sh01@1DE5@0A4A4
04A4A01PH600K6a/0080MWIf00@0LW9b07YjNP1jNWX0IVIV0P1gMgL01@1bLW80KVi^05aLG01LG5`0
MGEe0080QHF500D0WYjN08b<S02<S8`0PH6109^KV`0205ADE00508J6QP2b/[80/[:b09fMW@2=SHd0
0P2;Rh/0101ZJVX0MGEe07EeM@1jNWX206i^KP0306QXJ03oool0oooo00P0oooo000:0?ooo`040;Ng
]`2f][H0][Jf0:^[Z`80LW9b00@0NGUi0:j^[P2_[jl0[jn_102c/k<20;Bd]0050;bl_02h^;P0];Bd
0;Bd]02][Jd00P2/[:`01@2YZJT0Ti>C059BDP1BDU80/k>c0080][Jf00D0]kNg0;>c/`2c/k<0/[:b
0:ZZZP020:FUY@0509fMW@2DU9@0U9BD08b<S02=SHd00P2ATI401@27QhL0BDU904U9B@2NWYh0[:b/
0080[Jf]0`2TY:@30:NWY`050:JVYP2PX:00Vi^K09^KV`2GUiL00P2ATI401@23Ph<0Cdm?07emO@1m
OGd0PH610080PX:200D0P82007inOP1nOWh0MgMg06a/K00206QXJ00506EUI@1YJFT0JFUY06UYJ@1f
MWH00P1`L700100f=SH0DU9B059BDP1OGel205UIF@0505iNGP1UIFD0KVi^06i^KP1/K6`00P1WIfL0
1@1RHV80Fe]K05eMG@1MGEd0EUIF0080?Cdm00D0;bl_04Y:BP1:BTX0BTY:04m?C`0204Y:BP0504U9
B@0n?Sh0?Shn02l_;`16ATH00P0o?cl01@10@400>c/k03/k>`0e=CD0C4a<0080DU9B00@0DE5A05EE
E@1EEED0B4Q80P19BDT01@1CDe<0E5AD04A4A014A4@0@D510080B4Q800D0>c/k02`/;00^;Rh0;Rh^
03Lg=`0203Xj>P0504=3@`17AdL0CDe=04e=C@0g=cL00P0];Bd01@11@D40CTi>04i>CP1;Bd/0D51@
0080E5AD00D0FUYJ05iNGP1NGUh0HV9R06IVIP0206a/K00406YZJP1XJ6P0J6QX059BDP80=CDe00D0
De=C05eMG@1ZJVX0JVYZ06EUI@02069RHP0307IfMP3oool0oooo00l0oooo00@0JVYZ07AdM01dM7@0
MgMg0P16ATH01@2CTi<0OGem07emO@21PH40GEeM0080LW9b00D0KFe]05aLG01LG5`0T92@079bLP02
07UiN@0404E5A@11@D40@D51092@T080NGUi00D0N7Qh08F5Q@1IFET0FEUI04U9B@0204E5A@0505aL
G01cLg<0Lg=c09BDU02LW9`00P1EEED0101nOWh0B4Q804Q8B01PH602065QH@0509>CT`3;bl/0YJFU
0:FUY@1LG5`00P0k>c/0101cLg<0WIfM0;Fe]@2e]KD30:j^[P0509>CT`2KVi/0Vi^K0:JVYP2TY:@0
0P1nOWh0101LG5`0O7al07alO01mOGd209NGU`050:f][@1PH600U9BD09BDU020P8000P2g]kL01@38
b<P0/[:b09JFUP2FUYH0/[:b0080]KFe00@0]kNg04U9B@19BDT0P8200`1kNg/0101nOWh0Rh^;08^;
R`1]KFd207YjNP050<G5a@2:RXX0NWYj07YjNP1HF5P00P2EUID01@2FUYH0^[Zj0:2PX02PX:00NWYj
0080IFEU00D0Shn?0<O7a`37alL0NWYj06i^KP0206e]K@0406m_K`2MWId0WIfM0:f][@80ZJVY00D0
QHF508j>SP2=SHd0SHf=07moO`0207IfMP05092@T02UYJD0YJFU0:j^[P1OGel00P0n?Sh01@1DE5@0
A4A404A4A01PH600K6a/0080MWIf00@0LW9b07YjNP1jNWX0IVIV0P1gMgL01@1bLW80KVi^05aLG01L
G5`0MGEe0080QHF500D0WYjN08b<S02<S8`0PH6109^KV`0205ADE00508J6QP2b/[80/[:b09fMW@2=
SHd00P2;Rh/0101ZJVX0MGEe07EeM@1jNWX206i^KP0306QXJ03oool0oooo00P0oooo000:0?ooo`04
0;6a/@2b/[80/[:b0:RXZ080MWIf00@0RHV90:f][@2a/K40/K6a0`2e]KD01@2i^KT0^[Zj0;Zj^P2k
^k/0`<300080^k^k00D0[Zj^0:JVYP2VYZH0Zj^[0:b/[00205YJFP040:f][@2_[jl0[jn_0;Fe]@80
YjNW00D0[Zj^0:f][@2YZJT0ZJVY0::RXP0209fMW@0508b<S02@T900UiNG09NGU`2KVi/00P1ADE40
0`2^[Zh0/;2`0:VYZ@020:VYZ@80[Zj^00D0[jn_0;Fe]@2e]KD0];Bd0:n_[`020:ZZZP050:BTY02S
Xj<0Xj>S0:6QX@1ZJVX00P2YZJT0102h^;P0^k^k0;^k^`2m_Kd20;jn_P050;bl_02i^KT0^[Zj0;Zj
^P2i^KT00P2e]KD01@2i^KT0_;bl0;bl_02l_;`0JFUY00<0/[:b0P2ZZZX00`2WYjL0];Bd0;Bd]002
0;Bd]080/k>c0P2h^;P20;Bd]0050;:b/P2EUID0UIFE05MGE`2`/;000P2HV9P0102c/k<0^k^k0;^k
^`2m_Kd30;jn_P<0_kno00D0^k^k06][J`1[Jf/0I6AT0;Bd]0020;Jf]P030;Rh^02g]kL0]kNg00<0
/k>c00D0]kNg0;^k^`2k^k/0^k^k0<71`@020;no_`050;Rh^01]KFd0OGem07emO@2UYJD00P2YZJT0
1@2PX:00/;2`0;bl_02l_;`0^k^k0080^[Zj00D0[jn_0:^[Z`2[Zj/0VYZJ09JFUP0208b<S00504i>
CP1bLW80LW9b08F5Q@1nOWh00P20P800101oOgl0LW9b079bLP1]KFd207AdM00507]kN`1`L700N7Qh
07QhN021PH400P24Q8@00`1RHV80oooo0?ooo`0?0?ooo`0407YjNP2:RXX0RXZ:08V9R@80Bd];00D0
Ogmo07YjNP1jNWX0O7al05ADE00207]kN`05075aL@1ZJVX0JVYZ08N7Q`1mOGd00P1gMgL0101HF5P0
ATI604I6AP1JFUX206EUI@05071`L01iNGT0@T920492@P16ATH00P1BDU801@1JFUX0IFEU06EUI@2?
Shl0TY:B0080EEEE00@0Shn?05eMG@1MGEd0N7Qh0P1PH6001@29RHT0cLg=0:NWY`2WYjL0IFEU0080
Bd];00D0OWin0:j^[P2a/K40/K6a0;^k^`020;6a/@0508n?S`1oOgl0Ogmo08b<S01oOgl00P1TI6@0
101?Cdl0N7Qh07QhN024Q8@209jNWP050;Ng]`1^KVh0/;2`0;2`/01kNg/00P2h^;P01@3@d=00/k>c
09RHV02HV9P0[jn_0080d=3@00D0`L7105iNGP1NGUh0QXJ608N7Q`0207inOP0407QhN02DU9@0U9BD
06e]K@80M7Ad00D0f=SH08J6QP1aLG40LG5a05ADE00209BDU0050:j^[P3=cLd0^;Rh0;Rh^029RHT0
0P2>SXh01@2GUiL0b/[:0<[:bP1TI6@0LG5a0080MgMg00@0IfMW09FEU@2EUID0]KFe0P2RXZ801@22
PX80QXJ60:>SX`2SXj<0Ph>30080HF5Q00D0Rh^;0:>SX`2SXj<0XJ6Q06EUI@0204e=C@0504E5A@11
@D40@D5106ATI01cLg<00`1_Kfl307QhN080P82000D0MgMg061PH01KFe/0Fe]K069RHP0206YZJP05
09ZJVP26QXH0QXJ607alO02@T9000P19BDT01@1aLG40T92@092@T02HV9P0P8200080M7Ad00@0FUYJ
07alO01lO7`0N7Qh0P1RHV800`1ZJVX0oooo0?ooo`080?ooo`002P3oool30;2`/0040:f][@1gMgL0
MgMg08Z:RP<0[Zj^00@0/[:b0;Rh^02h^;P0/k>c0P2d];@01@2b/[80/k>c0;Bd]02d];@0[Jf]0080
WYjN00D0[:b/09jNWP1KFe/0Fe]K0:j^[P030;>c/`80Y:BT0P2XZ:P20:FUY@050:NWY`2NWYh0WYjN
09^KV`2NWYh00P2LW9`01@2PX:00BDU904U9B@2/[:`0[Zj^0080Zj^[00@0Y:BT0:2PX02PX:00[Zj^
0P2g]kL01@2e]KD0/K6a0:j^[P2^[Zh0ZJVY0080WinO00D0WYjN06MWI`2_[jl0[jn_0;Jf]P020;Ng
]`D0^k^k0P2l_;`01@2i^KT0]kNg0;Ng]`2i^KT0^k^k0080_[jn00@0IFEU0;>c/`2c/k<0[:b/0P2Y
ZJT01@2WYjL0Zj^[0;:b/P2b/[80];Bd00<0/[:b00@0/;2`0:f][@2][Jd0[Jf]0P2LW9`01@1hN7P0
/k>c09ZJVP2JVYX0ZZZZ0080_kno00D0_[jn0;fm_@2m_Kd0_;bl0<;2`P020<?3``050;fm_@1XJ6P0
J6QX06UYJ@2g]kL00P2a/K40102f][H0]KFe0;Fe]@2d];@20;Jf]P040;Vi^@2e]KD0_;bl0;bl_0<0
_[jn00D0^;Rh08:2PP2>SXh0SXj>0:n_[`020:b/[0030:RXZ02c/k<0^[Zj0080^[Zj0P2o_kl01@2h
^;P0_;bl0;bl_02i^KT0]kNg0080/;2`00<0EUIF0:>SX`2SXj<00P2n_[h20<30`0040;fm_@2k^k/0
^k^k0;Rh^080^k^k00D0_Kfm0<30`032`/80`/;20<71`@020;bl_00309BDU03oool0oooo00l0oooo
00@0O7al08j>SP2>SXh0QhN70P15ADD01@21PH40QHF508F5Q@1fMWH0C4a<0080K6a/00D0J6QX079b
LP1bLW80MWIf08>3P`0207inOP0406e]K@1=CDd0CDe=07=cL`80LG5a00D0QXJ606YZJP18B4P0B4Q8
0451@@0203dm?@05065QH@1]KFd0KFe]09:BTP1lO7`00P12@T80101gMgL0De=C05=CD`1cLg<205eM
G@0508R8R03;bl/0XJ6Q0:6QX@1^KVh00P1ADE401@25QHD0X:2P0;Zj^P2j^[X0];Bd0080YZJV00D0
SHf=09RHV02HV9P0VYZJ07moO`02071`L00405QHF01_Kfl0Kfm_07alO080VYZJ00D0YJFU065QH@2P
X:00X:2P0820P0020;Jf]P050<C4a02m_Kd0Vi^K09^KV`2a/K400P3EeMD01@31`L40GemO05mOG`2;
Rh/0SXj>0080NGUi00@0Ogmo09VIV@2IVIT0N7Qh0P1RHV801@3Cdm<0UYJF07YjNP1jNWX0De=C0080
PH6100D0W9bL0;Zj^P2d];@0];Bd0820P00207inOP0509FEU@3Hf=P0f=SH06][J`24Q8@00P1lO7`0
101dM7@0Ti>C09>CT`2JVYX20;jn_P0509BDU028R8P0RHV908V9R@1kNg/00P1cLg<01@2ATI40YZJV
0:JVYP2GUiL0LG5a0080Cdm?00D0?3`l04m?C`1?Cdl0JFUY065QH@0206][J`0406e]K@1kNg/0Ng]k
07QhN080MWIf00D0Kfm_07YjNP1TI6@0I6AT06YZJP0205aLG00509>CT`24Q8@0Q8B409:BTP2b/[80
0P1KFe/01@2<S8`0YZJV0:JVYP2OWil0MGEe0080K6a/00@0FUYJ07AdM01dM7@0J6QX0P1aLG400`1Y
JFT0oooo0?ooo`080?ooo`002P3oool30;2`/0040:f][@1gMgL0MgMg08Z:RP<0[Zj^00@0/[:b0;Rh
^02h^;P0/k>c0P2d];@01@2b/[80/k>c0;Bd]02d];@0[Jf]0080WYjN00D0[:b/09jNWP1KFe/0Fe]K
0:j^[P030;>c/`80Y:BT0P2XZ:P20:FUY@050:NWY`2NWYh0WYjN09^KV`2NWYh00P2LW9`01@2PX:00
BDU904U9B@2/[:`0[Zj^0080Zj^[00@0Y:BT0:2PX02PX:00[Zj^0P2g]kL01@2e]KD0/K6a0:j^[P2^
[Zh0ZJVY0080WinO00D0WYjN06MWI`2_[jl0[jn_0;Jf]P020;Ng]`D0^k^k0P2l_;`01@2i^KT0]kNg
0;Ng]`2i^KT0^k^k0080_[jn00@0IFEU0;>c/`2c/k<0[:b/0P2YZJT01@2WYjL0Zj^[0;:b/P2b/[80
];Bd00<0/[:b00@0/;2`0:f][@2][Jd0[Jf]0P2LW9`01@1hN7P0/k>c09ZJVP2JVYX0ZZZZ0080_kno
00D0_[jn0;fm_@2m_Kd0_;bl0<;2`P020<?3``050;fm_@1XJ6P0J6QX06UYJ@2g]kL00P2a/K40102f
][H0]KFe0;Fe]@2d];@20;Jf]P040;Vi^@2e]KD0_;bl0;bl_0<0_[jn00D0^;Rh08:2PP2>SXh0SXj>
0:n_[`020:b/[0030:RXZ02c/k<0^[Zj0080^[Zj0P2o_kl01@2h^;P0_;bl0;bl_02i^KT0]kNg0080
/;2`00<0EUIF0:>SX`2SXj<00P2n_[h20<30`0040;fm_@2k^k/0^k^k0;Rh^080^k^k00D0_Kfm0<30
`032`/80`/;20<71`@020;bl_00309BDU03oool0oooo00l0oooo00@0O7al08j>SP2>SXh0QhN70P15
ADD01@21PH40QHF508F5Q@1fMWH0C4a<0080K6a/00D0J6QX079bLP1bLW80MWIf08>3P`0207inOP04
06e]K@1=CDd0CDe=07=cL`80LG5a00D0QXJ606YZJP18B4P0B4Q80451@@0203dm?@05065QH@1]KFd0
KFe]09:BTP1lO7`00P12@T80101gMgL0De=C05=CD`1cLg<205eMG@0508R8R03;bl/0XJ6Q0:6QX@1^
KVh00P1ADE401@25QHD0X:2P0;Zj^P2j^[X0];Bd0080YZJV00D0SHf=09RHV02HV9P0VYZJ07moO`02
071`L00405QHF01_Kfl0Kfm_07alO080VYZJ00D0YJFU065QH@2PX:00X:2P0820P0020;Jf]P050<C4
a02m_Kd0Vi^K09^KV`2a/K400P3EeMD01@31`L40GemO05mOG`2;Rh/0SXj>0080NGUi00@0Ogmo09VI
V@2IVIT0N7Qh0P1RHV801@3Cdm<0UYJF07YjNP1jNWX0De=C0080PH6100D0W9bL0;Zj^P2d];@0];Bd
0820P00207inOP0509FEU@3Hf=P0f=SH06][J`24Q8@00P1lO7`0101dM7@0Ti>C09>CT`2JVYX20;jn
_P0509BDU028R8P0RHV908V9R@1kNg/00P1cLg<01@2ATI40YZJV0:JVYP2GUiL0LG5a0080Cdm?00D0
?3`l04m?C`1?Cdl0JFUY065QH@0206][J`0406e]K@1kNg/0Ng]k07QhN080MWIf00D0Kfm_07YjNP1T
I6@0I6AT06YZJP0205aLG00509>CT`24Q8@0Q8B409:BTP2b/[800P1KFe/01@2<S8`0YZJV0:JVYP2O
Wil0MGEe0080K6a/00@0FUYJ07AdM01dM7@0J6QX0P1aLG400`1YJFT0oooo0?ooo`080?ooo`002P3o
ool0102^[Zh0[jn_0:n_[`2YZJT206UYJ@0508>3P`2`/;00ZJVY0:VYZ@2][Jd00P2e]KD01@2XZ:P0
ZZZZ0:ZZZP2UYJD0ZJVY00<0[:b/0P2IVIT01@2UYJD0XJ6Q069RHP1RHV80]KFe00<0];Bd0P2_[jl0
1@2/[:`0YjNW0:RXZ02XZ:P0ZJVY0080YJFU0P2OWil209^KV`050:>SX`12@T80@T920:2PX02b/[80
0P2TY:@0102VYZH0ZJVY0:VYZ@2/[:`20;Fe]@050:j^[P2][Jd0[:b/0:b/[02YZJT00P2VYZH01@2N
WYh0GemO0:n_[`2_[jl0];Bd0080/k>c00<0]KFe0;Ng]`2g]kL00P2f][H30;^k^`80][Jf00D0/k>c
0;:b/P2UYJD0YJFU069RHP020;:b/P050:ZZZP2HV9P0V9RH0:6QX@2^[Zh00P2g]kL01@2l_;`0]kNg
0;Ng]`2c/k<0/K6a00<0[Zj^0P2FUYH01@1bLW80[Zj^0:RXZ02XZ:P0[Jf]0080/K6a00D0^;Rh0;Jf
]P2f][H0^k^k0;fm_@020;Zj^P050;Ng]`1eMGD0MGEe06EUI@2c/k<00P2b/[80102f][H0/k>c0;>c
/`2c/k<20;Bd]0050;Ng]`2h^;P0^;Rh0;Rh^02n_[h00P2m_Kd01@2i^KT0M7Ad08^;R`2;Rh/0[Jf]
0080Zj^[00D0Vi^K0:n_[`2g]kL0]kNg0;^k^`020;Ng]`050;:b/P2c/k<0/k>c0;Bd]02j^[X00P2a
/K401@17AdL0/;2`0;2`/033`l<0aLG50080`l?300@0^k^k0;Ng]`2g]kL0/[:b0P2g]kL01@2k^k/0
_[jn0<?3``33`l<0`<300080^KVi00<0Shn?0?ooo`3oool03`3oool0101oOgl0Xj>S0:>SX`26QXH2
04I6AP0507moO`2;Rh/0Rh^;07AdM01FEUH00P21PH401@1[Jf/0N7Qh07QhN01iNGT0OWin0080NWYj
00@0I6AT04];B`1;Bd/0R8R80P22PX801@2>SXh0Kfm_04];B`1;Bd/0CTi>0080EUIF00D0KFe]06i^
KP1^KVh0UiNG08f=S@0203lo?`0408V9R@1;Bd/0Bd];07=cL`80De=C00D0SHf=0<_;b`2SXj<0Xj>S
05IFEP020451@@0506YZJP2VYZH0/;2`0;2`/02^[Zh00P2QXJ401@24Q8@0QHF508F5Q@2CTi<0PX:2
0080JVYZ00@0E5AD06a/K01/K6`0LW9b0P2ATI401@2/[:`0G5aL09RHV02HV9P0QHF50080_kno00D0
bLW90=3@d02QXJ40XJ6Q0:FUY@020<?3``050;^k^`1UIFD0IFEU08B4Q02ATI400P1hN7P0101dM7@0
UYJF09JFUP1mOGd205IFEP050>?Sh`2;Rh/0MgMg07MgM`1EEED00P1/K6`01@2CTi<0aLG50:n_[`2_
[jl0U9BD0080S8b<00D0X:2P0=KFeP3Fe]H0IVIV06e]K@0207=cL`0406i^KP20P800P82009fMW@80
`<3000D0T92@08^;R`2YZJT0ZJVY08:2PP02061PH00507moO`2QXJ40XJ6Q09^KV`1dM7@00P1:BTX0
1@0c<c<0Bd];04];B`1SHf<0Fe]K0080OGem00@0IVIV08J6QP26QXH0N7Qh0P1mOGd01@1[Jf/0LG5a
06MWI`1WIfL0MgMg0080N7Qh00D0[Jf]09BDU02DU9@0WIfM0:j^[P0205iNGP0507inOP2PX:00X:2P
0::RXP29RHT00P1`L700101GEeL0I6AT06ATI01LG5`2079bLP0306IVIP3oool0oooo00P0oooo000:
0?ooo`0408R8R01nOWh0OWin06][J`80B4Q800D0GemO07]kN`1iNGT0NGUi0861P@0208J6QP0507in
OP1fMWH0MWIf07QhN01cLg<00P1^KVh01@1aLG40JVYZ06YZJP1VIVH0I6AT0080BDU900@0R8R808B4
Q024Q8@0R8R80P20P8001@1RHV80IFEU06IVIP1VIVH0Jf][0080KFe]00D0Fe]K05mOG`1CDe<0De=C
05MGE`0202<S8`050410@01UIFD0LW9b079bLP1gMgL00P1nOWh01@2BTY80TI6A096AT@29RHT0MWIf
0080PH6100D0OGem08B4Q024Q8@0P82003/k>`02092@T00409jNWP2[Zj/0Zj^[0:^[Z`80S8b<00D0
UYJF0:6QX@2f][H0][Jf0::RXP0209RHV0050;Bd]02e]KD0YZJV0:JVYP1_Kfl00P2b/[801@2VYZH0
RHV908V9R@2OWil0[:b/0080/;2`00D0];Bd0;:b/P2b/[80]KFe0;2`/0020;Fe]@050;:b/P2=SHd0
SHf=05UIF@2IVIT00P2][Jd0102b/[80/k>c0;>c/`2d];@20;Jf]P050;6a/@2d];@0/[:b0;:b/P2[
Zj/00P1aLG401@1cLg<0];Bd0;2`/02`/;00Zj^[0080[Jf]0`2`/;001@2c/k<0]KFe0;Ng]`2g]kL0
^KVi0080][Jf00@0];Bd06][J`2=SHd0SHf=0`2YZJT01@2PX:00[Jf]0;Ng]`2g]kL0^;Rh0080]kNg
00D0[Zj^0;6a/@2a/K40];Bd0;Rh^0020:n_[`0504M7A`2][Jd0[Jf]0;no_`2n_[h00P2l_;`0102g
]kL0]KFe0;Fe]@2XZ:P20;>c/`050;Rh^02m_Kd0^k^k0;^k^`2l_;`00P2XZ:P00`21PH40oooo0?oo
o`0?0?ooo`0407YjNP2YZJT0ZJVY07emO@80D51@00D0MgMg0861P@21PH40KVi^05ADE00207=cL`05
05YJFP1[Jf/0Jf][06a/K01gMgL00P1^KVh0101GEeL0ATI604I6AP1kNg/208F5Q@0509BDU01aLG40
Fe]K05]KF`1;Bd/00P1DE5@01@1[Jf/0MWIf07IfMP2FUYH0PX:20080EEEE00@0OGem0492@P12@T80
KVi^0P19BDT01@26QXH0_[jn0820P020P800H61P0080?3`l00D0M7Ad0;Jf]P2g]kL0]kNg0:NWY`02
0:j^[P0509VIV@23Ph<0Ph>309VIV@2=SHd00P1eMGD0101OGel0Kfm_06m_K`1jNWX20:2PX0050;Fe
]@1TI6@0X:2P0:2PX027QhL00P2k^k/01@37alL0c<c<09JFUP2FUYH0UiNG00<0^KVi0P1lO7`01@1i
NGT0U9BD07EeM@1eMGD0Ng]k0080UIFE00D0LG5a04m?C`1?Cdl0d=3@08f=S@0207YjNP0506YZJP1o
Ogl0Ogmo09^KV`2l_;`00P2e]KD0102;Rh/0RXZ:08Z:RP29RHT20=WIf@0505mOG`1eMGD0Ogmo07mo
O`1bLW800P1eMGD01@2WYjL0_kno0;no_`2=SHd0MGEe0080W9bL00@0MGEe05]KF`1KFe/0JFUY0P2K
Vi/01@2RXZ80LW9b04E5A@15ADD0<c<c0080>CTi00D0GUiN06ATI01hN7P0N7Qh05]KF`0207QhN005
06a/K01oOgl0Ogmo06ATI01dM7@00P1NGUh0101]KFd0LW9b079bLP2KVi/2092@T0050:6QX@2^[Zh0
GUiN05iNGP2GUiL00P2XZ:P01@2/[:`0Q8B407AdM01dM7@0Jf][0080HV9R00@0Jf][07UiN@1iNGT0
LW9b2P3oool000X0oooo00@0Y:BT09VIV@2IVIT0SHf=0`2@T9000`28R8P0QHF508F5Q@0308B4Q005
05MGE`1TI6@0I6AT071`L01aLG400P1cLg<01@1hN7P0NGUi07UiN@1^KVh0Kfm_0080OGem00@0MgMg
07]kN`1kNg/0P8200P1iNGT01@1EEED0@T9206EUI@1UIFD0KVi^0080K6a/00D0LW9b075aL@1cLg<0
Lg=c075aL@0306a/K00407YjNP1eMGD0MGEe06EUI@80Fe]K00D0<30`05=CD`1CDe<0EEEE05MGE`02
05QHF00505IFEP1LG5`0G5aL05YJFP1TI6@00P1DE5@0101HF5P0Fe]K05]KF`1GEeL203hn?P0402@T
9011@D40B4Q804Q8B0<0@T9200D0?3`l03lo?`1=CDd0CDe=04I6AP0204Q8B00503Ph>012@T80@T92
04m?C`0c<c<00P0m?Cd00`1@D500ADE504E5A@0205MGE`80ADE500D0Cdm?051@D01@D500;bl_03/k
>`0204E5A@0405=CD`1FEUH0EUIF04a<C0@0CTi>0P1GEeL0101SHf<0@d=304=3@`0f=SH304U9B@04
059BDP1EEED0EEEE05]KF`80EeMG00D0FUYJ05iNGP1SHf<0Hf=S069RHP02065QH@0506IVIP0b<S80
<S8b038b<P1PH6000P1YJFT01@1aLG40LW9b07QhN01hN7P0OGem0080O7al00D0MgMg07emO@1mOGd0
Kfm_07QhN00206i^KP0502l_;`1[Jf/0Jf][09BDU02GUiL00P2DU9@0102KVi/0V9RH09RHV02DU9@3
096AT@040:>SX`2VYZH0YZJV0:f][@80NGUi00<0HV9R0?ooo`3oool03`3oool0101dM7@0XJ6Q0:6Q
X@1fMWH204=3@`0507QhN02<S8`0S8b<07=cL`1QHF400P26QXH01@1XJ6P0N7Qh07QhN01cLg<0N7Qh
0080JFUY00@0CDe=04E5A@15ADD0Ogmo0P21PH401@2FUYH0Lg=c06YZJP1ZJVX0EEEE0080D51@00D0
H61P06a/K01/K6`0WinO09FEU@0206i^KP04092@T01GEeL0EeMG07inOP80DE5A00D0QhN70<g=c@2A
TI40TI6A05]KF`0203Xj>P0506MWI`2VYZH0Z:RX0:RXZ02GUiL00P2[Zj/01@2KVi/0MGEe07EeM@2E
UID0RHV90080Lg=c00@0FEUI06UYJ@1YJFT0MgMg0P2;Rh/01@2i^KT0I6AT09jNWP2NWYh0T92@0080
_[jn00D0b<S80<G5a@28R8P0R8R808^;R`020;^k^`050;2`/01gMgL0MgMg075aL@2@T9000P1_Kfl0
101`L700TY:B09:BTP1/K6`205mOG`050=3@d01eMGD0OWin07inOP1_Kfl00P1bLW801@2<S8`0]KFe
0<C4a034a<@0QhN70080RXZ:00D0NGUi0=?Cd`3Cdm<0K6a/09bLW00207]kN`0407QhN01eMGD0MGEe
09bLW080b<S800D0UIFE06m_K`27QhL0QhN707alO00205YJFP0506=SH`2VYZH0YZJV0:NWY`1UIFD0
0P13@d<01@0h>3P0=SHf03Hf=P1QHF40OGem0080JFUY00@0JVYZ06][J`1[Jf/0N7Qh0P1oOgl01@1T
I6@0JFUY05UIF@1IFET0M7Ad0080MWIf00D0Ti>C096AT@2ATI40Ti>C0:FUY@0205EEE@0509bLW02^
[Zh0[Zj^0:n_[`2:RXX00P1`L700101HF5P0L71`071`L01XJ6P206YZJP0305aLG03oool0oooo00P0
oooo000:0?ooo`040:BTY02IVIT0VIVI08f=S@<0T92@00<0R8R808F5Q@25QHD00`24Q8@01@1GEeL0
I6AT06ATI01`L700LG5a0080Lg=c00D0N7Qh07UiN@1iNGT0KVi^06m_K`0207emO@0407MgM`1kNg/0
Ng]k0820P080NGUi00D0EEEE0492@P1UIFD0IFEU06i^KP0206a/K005079bLP1aLG40Lg=c07=cL`1a
LG400`1/K6`0101jNWX0MGEe07EeM@1UIFD205]KF`05030`<01CDe<0De=C05EEE@1GEeL00P1HF5P0
1@1FEUH0G5aL05aLG01JFUX0I6AT0080E5AD00@0F5QH05]KF`1KFe/0EeMG0P0n?Sh0100T92@0@D51
04Q8B018B4P30492@P0503`l?00o?cl0CDe=04e=C@16ATH00P18B4P01@0h>3P0@T920492@P1?Cdl0
<c<c0080?Cdm00<0D51@04E5A@15ADD00P1GEeL204E5A@0504m?C`1@D500D51@02l_;`0k>c/00P15
ADD0101CDe<0EUIF05IFEP1<C4`404i>CP80EeMG00@0Hf=S04=3@`13@d<0=SHf0`19BDT0101BDU80
EEEE05EEE@1KFe/205MGE`0505YJFP1NGUh0Hf=S06=SH`1RHV800P1QHF401@1VIVH0<S8b038b<P0b
<S80H61P0080JFUY00D0LG5a079bLP1hN7P0N7Qh07emO@0207alO00507MgM`1mOGd0OGem06m_K`1h
N7P00P1^KVh01@0_;bl0Jf][06][J`2DU9@0UiNG0080U9BD00@0Vi^K09RHV02HV9P0U9BD0`2ATI40
102SXj<0YZJV0:JVYP2][Jd207UiN@03069RHP3oool0oooo00l0oooo00@0M7Ad0:6QX@2QXJ40MWIf
0P13@d<01@1hN7P0S8b<08b<S01cLg<0HF5Q0080QXJ600D0J6QX07QhN01hN7P0Lg=c07QhN00206UY
J@0404e=C@15ADD0ADE507moO`80PH6100D0UYJF07=cL`1ZJVX0JVYZ05EEE@02051@D005061PH01/
K6`0K6a/09nOW`2EUID00P1^KVh0102@T900EeMG05MGE`1nOWh2055AD@0508N7Q`3=cLd0TI6A096A
T@1KFe/00P0j>SX01@1WIfL0YZJV0:RXZ02XZ:P0UiNG0080Zj^[00D0Vi^K07EeM@1eMGD0UIFE08V9
R@0207=cL`0405UIF@1YJFT0JFUY07MgM`80Rh^;00D0^KVi06ATI02NWYh0WYjN092@T0020;jn_P05
0<S8b035aLD0R8R808R8R02;Rh/00P2k^k/01@2`/;00MgMg07MgM`1aLG40T92@0080Kfm_00@0L71`
09:BTP2BTY80K6a/0P1OGel01@3@d=00MGEe07inOP1nOWh0Kfm_0080LW9b00D0S8b<0;Fe]@34a<@0
a<C408N7Q`0208Z:RP0507UiN@3Cdm<0dm?C06a/K02LW9`00P1kNg/0101hN7P0MGEe07EeM@2LW9`2
0<S8b00509FEU@1_Kfl0QhN708N7Q`1lO7`00P1JFUX01@1SHf<0YZJV0:JVYP2WYjL0IFEU0080@d=3
00D0>3Ph03Hf=P0f=SH0HF5Q07emO@0206UYJ@0406YZJP1[Jf/0Jf][07QhN080Ogmo00D0I6AT06UY
J@1IFET0FEUI07AdM00207IfMP0509>CT`2ATI40TI6A09>CT`2UYJD00P1EEED01@2LW9`0[Zj^0:j^
[P2_[jl0RXZ:0080L71`00@0F5QH071`L01`L700J6QX0P1ZJVX00`1LG5`0oooo0?ooo`080?ooo`00
2P3oool0102i^KT0]kNg0;Ng]`2h^;P40;bl_080^KVi00@0]kNg0;Fe]@2e]KD0KVi^0P2BTY801@2b
/[80Z:RX0;Ng]`2g]kL0^;Rh0080^KVi00D0^;Rh0;Bd]02i^KT0^KVi0;Rh^0020;Ng]`<0^;Rh00@0
NWYj06][J`2][Jd0[Jf]0`2WYjL01@2_[jl0/K6a0;Rh^02h^;P0]kNg0080^;Rh00D0];Bd0;>c/`2]
[Jd0[Jf]0:ZZZP0209>CT`0503dm?@2SXj<0Xj>S0;2`/02TY:@00P2JVYX01@2BTY80S8b<08b<S024
Q8@0U9BD0080W9bL00<0XZ:R0:JVYP2VYZH00`2[Zj/01@1BDU80VYZJ0:BTY02TY:@0Xj>S0080YjNW
0P2YZJT20:JVYP040;6a/@2b/[80/[:b0;6a/@80Zj^[00D0[:b/0:n_[`1YJFT0JFUY0:JVYP020:RX
Z0050:BTY02VYZH0ZZZZ0:ZZZP2[Zj/00P2WYjL01@2/[:`0YjNW0:ZZZP2ZZZX0ZJVY0080YjNW00<0
QXJ607MgM`1gMgL00P2VYZH20:NWY`050:b/[02[Zj/0Zj^[0::RXP2SXj<00P2QXJ40102IVIT0V9RH
09RHV02?Shl207emO@0503dm?@1EEED0L71`071`L01]KFd00P1YJFT01@1ZJVX0MWIf07UiN@1iNGT0
MgMg0080NWYj00D0L71`06e]K@1UIFD0IFEU06ATI0020410@00505mOG`1SHf<0Hf=S06MWI`1VIVH0
0P1UIFD01@1SHf<0I6AT06ATI01SHf<0HV9R0080I6AT00@0IfMW05=CD`1CDe<0?clo0P0m?Cd01@1P
H600Hf=S06IVIP1VIVH0J6QX0080IVIV00<0GEeM0?ooo`3oool03`3oool0101[Jf/0Ti>C09>CT`1/
K6`20410@0<0K6a/00D0J6QX05ADE01aLG40LG5a06UYJ@0207YjNP0506][J`1aLG40JVYZ06YZJP17
AdL00P13@d<01@1aLG40P8200820P02GUiL0IfMW00<0EUIF0P1<C4`01@1OGel0K6a/06a/K02JVYX0
QXJ60080HF5Q00@0Ti>C05mOG`1OGel0PX:20P1OGel01@1oOgl0`l?309^KV`2KVi/0GEeM0080@410
00D0JFUY09FEU@2MWId0WIfM0;6a/@020<30`0050::RXP2KVi/0Vi^K0:2PX028R8P00P1gMgL0101J
FUX0K6a/06a/K01jNWX209:BTP050<C4a01XJ6P0ZJVY0:VYZ@2BTY800P2h^;P01@37alL0c<c<08V9
R@29RHT0RXZ:0080][Jf00D0[Zj^07YjNP1jNWX0NGUi08j>SP0207IfMP0407YjNP2GUiL0UiNG05mO
G`80H61P00D0d];B07emO@28R8P0R8R8079bLP02075aL@0509jNWP2`/;00aLG50<G5a@2IVIT00P2B
TY801@1fMWH0b/[:0<[:bP1HF5P0UiNG0080MgMg00@0Lg=c07AdM01dM7@0YZJV0P3:b/X01@2EUID0
JFUY09bLW02LW9`0MgMg0080GemO00D0N7Qh0;6a/@2a/K40]KFe079bLP0204Y:BP0504=3@`11@D40
@D5106MWI`1eMGD00P1KFe/0101SHf<0J6QX06QXJ01gMgL208j>SP0507QhN01ZJVX0DU9B059BDP1h
N7P00P1cLg<01@2HV9P0[Zj^0:j^[P2?Shl0[:b/0080J6QX00D0PX:209^KV`2KVi/0VIVI07=cL`02
05iNGP0406MWI`1YJFT0JFUY06a/K080P82000<0Kfm_0?ooo`3oool0203oool000X0oooo00@0^;Rh
0;Ng]`2g]kL0_Kfm0P2n_[h00`2o_kl0_;bl0;Rh^0020;Rh^080]KFe00D0KFe]096AT@2ATI40[Jf]
09ZJVP020:VYZ@050:j^[P2/[:`0[:b/0:^[Z`2][Jd00P2_[jl30;Ng]`050;6a/@2ZZZX0ZZZZ08:2
PP1[Jf/00P2TY:@01@2UYJD0XZ:R0::RXP2QXJ40YZJV0080Z:RX00D0ZJVY0:n_[`2_[jl0[Zj^0;6a
/@020:n_[`040;:b/P2QXJ40XJ6Q04U9B@80[:b/00D0[jn_0:NWY`2HV9P0V9RH09NGU`0209BDU005
08j>SP2:RXX0S8b<08b<S02DU9@00P2SXj<01@2^[Zh0YjNW0:NWY`11@D40Ti>C00D0WIfM00D0YJFU
0:6QX@2TY:@0Y:BT0:j^[P020;6a/@050:^[Z`2][Jd0[Jf]0;Fe]@2c/k<00P1iNGT00`2[Zj/0YjNW
0:NWY`040:NWY`<0Z:RX00D0YjNW0:ZZZP2ZZZX0ZZZZ0:VYZ@020:ZZZP0308>3P`21PH40PH610080
/;2`0P2^[Zh01@2c/k<0];Bd0;Bd]02b/[80/;2`0080/[:b00@0];Bd0:ZZZP2ZZZX0Zj^[0P2YZJT0
1@1OGel0P8200:2PX02PX:00ZZZZ0080/[:b00D0/;2`0:j^[P2ZZZX0ZZZZ0:f][@020:NWY`050:BT
Y02XZ:P0[Jf]0:f][@2XZ:P00P1QHF401@2VYZH0[Zj^0:j^[P2_[jl0/;2`0080/K6a00D0];Bd0;>c
/`2c/k<0/K6a0:j^[P020:VYZ@040:ZZZP2DU9@0U9BD07emO@80IFEU00@0UIFE0:6QX@2/[:`0[:b/
0`2f][H00`2d];@0oooo0?ooo`0?0?ooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25
QHD0KFe]05QHF0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1c
Lg<207IfMP0508V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080
EEEE00@0S8b<05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN
0;Rh^02g]kL0]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad
07AdM01nOWh209fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?
S`80a<C400D0]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0
clo?08:2PP28R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0
fMWI0=WIf@1YJFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02X
Z:P0NWYj0080Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`
L7000P1JFUX0101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT0
1@2IVIT0Xj>S0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=
C@1IFET0FEUI05UIF@80Lg=c00<0EUIF0?ooo`3oool0203oool000X0oooo00@0^;Rh0;Ng]`2g]kL0
_Kfm0P2n_[h00`2o_kl0_;bl0;Rh^0020;Rh^080]KFe00D0KFe]096AT@2ATI40[Jf]09ZJVP020:VY
Z@050:j^[P2/[:`0[:b/0:^[Z`2][Jd00P2_[jl30;Ng]`050;6a/@2ZZZX0ZZZZ08:2PP1[Jf/00P2T
Y:@01@2UYJD0XZ:R0::RXP2QXJ40YZJV0080Z:RX00D0ZJVY0:n_[`2_[jl0[Zj^0;6a/@020:n_[`04
0;:b/P2QXJ40XJ6Q04U9B@80[:b/00D0[jn_0:NWY`2HV9P0V9RH09NGU`0209BDU00508j>SP2:RXX0
S8b<08b<S02DU9@00P2SXj<01@2^[Zh0YjNW0:NWY`11@D40Ti>C00D0WIfM00D0YJFU0:6QX@2TY:@0
Y:BT0:j^[P020;6a/@050:^[Z`2][Jd0[Jf]0;Fe]@2c/k<00P1iNGT00`2[Zj/0YjNW0:NWY`040:NW
Y`<0Z:RX00D0YjNW0:ZZZP2ZZZX0ZZZZ0:VYZ@020:ZZZP0308>3P`21PH40PH610080/;2`0P2^[Zh0
1@2c/k<0];Bd0;Bd]02b/[80/;2`0080/[:b00@0];Bd0:ZZZP2ZZZX0Zj^[0P2YZJT01@1OGel0P820
0:2PX02PX:00ZZZZ0080/[:b00D0/;2`0:j^[P2ZZZX0ZZZZ0:f][@020:NWY`050:BTY02XZ:P0[Jf]
0:f][@2XZ:P00P1QHF401@2VYZH0[Zj^0:j^[P2_[jl0/;2`0080/K6a00D0];Bd0;>c/`2c/k<0/K6a
0:j^[P020:VYZ@040:ZZZP2DU9@0U9BD07emO@80IFEU00@0UIFE0:6QX@2/[:`0[:b/0`2f][H00`2d
];@0oooo0?ooo`0?0?ooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25QHD0KFe]05QH
F0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1cLg<207IfMP05
08V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080EEEE00@0S8b<
05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN0;Rh^02g]kL0
]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad07AdM01nOWh2
09fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?S`80a<C400D0
]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0clo?08:2PP28
R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0fMWI0=WIf@1Y
JFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02XZ:P0NWYj0080
Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`L7000P1JFUX0
101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT01@2IVIT0Xj>S
0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=C@1IFET0FEUI
05UIF@80Lg=c00<0EUIF0?ooo`3oool0203oool000X0oooo00@0]kNg0;Fe]@2e]KD0]kNg0P2h^;P2
0;Fe]@80];Bd00@0]kNg0;2`/02`/;00JFUY0P2:RXX00`2YZJT0V9RH0:VYZ@020:VYZ@80[Zj^00@0
YZJV0:VYZ@2[Zj/0Zj^[0`2^[Zh01@2_[jl0Zj^[0:^[Z`1mOGd0IFEU0080VYZJ00D0TY:B09nOW`2O
Wil0XZ:R0:FUY@030:NWY`80ZJVY00D0YjNW0:j^[P2][Jd0[Jf]0;6a/@020:j^[P0504Q8B02UYJD0
YJFU0:RXZ02KVi/00P2ATI401@2DU9@0Ph>308>3P`24Q8@0PX:200<0QHF50P2HV9P01@2XZ:P0UYJF
09JFUP0o?cl0SXj>0080UYJF00<0UiNG09ZJVP2JVYX00P2LW9`209^KV`030:f][@2/[:`0[:b/00<0
ZZZZ00D0/k>c0;6a/@1_Kfl0Kfm_0:NWY`0209nOW`050:2PX02OWil0YJFU0:FUY@2OWil00P2QXJ40
1@2SXj<0YJFU0:BTY02TY:@0YJFU0080YjNW00@0PX:208^;R`2;Rh/0[:b/0`2][Jd01@2ZZZX0Z:RX
0:RXZ02VYZH0[:b/0080Zj^[00@0/;2`0:^[Z`2[Zj/0[Jf]0P2WYjL01@1>CTh0MWIf09jNWP2NWYh0
[:b/0080ZJVY00@0Zj^[0:ZZZP2WYjL0YjNW0`2SXj<01@2LW9`0XZ:R09nOW`2OWil0ZJVY0080G5aL
00D0WYjN0:b/[02/[:`0Z:RX0:ZZZP020:VYZ@050:b/[02^[Zh0[Zj^0;>c/`2_[jl00P2XZ:P30:NW
Y`0309^KV`1WIfL0IfMW0080UIFE0P2WYjL0102ZZZX0[jn_0:n_[`2^[ZhA0?ooo`04069RHP2HV9P0
V9RH06ATI080>c/k00D0KVi^07QhN01hN7P0JFUY05eMG@0208B4Q00505UIF@1kNg/0Ng]k06a/K01k
Ng/00P1PH6001016ATH0De=C05=CD`1eMGD208b<S00508n?S`1`L700IVIV06IVIP1HF5P00P1>CTh0
1@1QHF40M7Ad07AdM02IVIT0RXZ:0080FEUI00@0VIVI05ADE01DE5@0PH610P1`L7001@1jNWX0_kno
08F5Q@25QHD0BTY:0080DU9B00D0FEUI0:VYZ@2c/k<0/k>c0;jn_P020;Vi^@0508Z:RP2NWYh0WYjN
09VIV@2;Rh/00P1eMGD0101HF5P0IfMW06MWI`1lO7`208n?S`050:n_[`1DE5@0U9BD09BDU024Q8@0
0P2^[Zh00`37alL0fMWI09>CT`0209>CT`80aLG500D0[jn_08J6QP26QXH0RHV907=cL`02079bLP04
06e]K@2BTY80TY:B061PH080KVi^00D0emOG092@T02?Shl0Shn?09BDU00206i^KP050;Jf]P2SXj<0
bLW90<W9b@2/[:`00P21PH401@1`L700gmoO0=oOg`1_Kfl0TY:B0080Ng]k00@0N7Qh07alO01lO7`0
YjNW0P3@d=001@2NWYh0IfMW0:FUY@2UYJD0RHV90080MWIf00D0NWYj09NGU`2GUiL0_;bl07AdM002
0451@@<0@41000D0H61P08Z:RP1NGUh0GUiN04i>CP0205eMG@0506MWI`1VIVH0IVIV07EeM@1?Cdl0
0P1DE5@0101nOWh0NGUi07UiN@2EUID20;Jf]P0509FEU@2`/;00P8200820P025QHD00P2PX:001@2/
[:`0QHF5069RHP1RHV80FUYJ0080HV9R00@0Jf][08B4Q024Q8@0LG5a2P3oool000X0oooo00@0QhN7
08:2PP22PX80OGem0P1kNg/01@1mOGd0Q8B408f=S@2=SHd0RXZ:0080S8b<00D0FUYJ07alO01lO7`0
T92@079bLP0209:BTP0509BDU02LW9`0W9bL09bLW02KVi/00P2PX:00102QXJ40ZJVY0:VYZ@2XZ:P2
0:JVYP0507MgM`1?Cdl0S8b<08b<S02BTY800P2HV9P01@2PX:00XJ6Q0:2PX02PX:00Y:BT0080VYZJ
00D0[:b/0;:b/P2^[Zh0[Zj^0:b/[0020;2`/00504a<C02WYjL0YjNW0:2PX02?Shl00P2<S8`01@2A
TI40Ph>308>3P`22PX80Ng]k0080P82000@0Ogmo08B4Q024Q8@0U9BD0P2>SXh01@1GEeL0Rh^;08j>
SP2>SXh0Q8B40080QhN700D0SXj>0:2PX02OWil0WinO0:j^[P030:f][@80Zj^[00D0[jn_0:ZZZP1V
IVH0IVIV09VIV@0209NGU`0509>CT`2ATI40TI6A096AT@2FUYH00P2NWYh01@2OWil0Z:RX09jNWP2N
WYh0WinO0080XZ:R00D0NWYj0820P020P800ZJVY0:RXZ0020:NWY`050:RXZ02VYZH0YZJV0:FUY@2T
Y:@00P2VYZH30:>SX`050:JVYP2QXJ40XJ6Q05aLG01iNGT00P2GUiL01@2ZZZX0Zj^[0:^[Z`2YZJT0
Y:BT0080WIfM0`2NWYh01@2CTi<0U9BD09JFUP2FUYH0WIfM0080FEUI00<0X:2P0:JVYP2VYZH00P2[
Zj/30:NWY`80[:b/00<0[jn_0:j^[P2HV9P00P2HV9P20:FUY@0509RHV01[Jf/0Jf][08^;R`1hN7P0
0P2FUYH0102UYJD0YjNW0:NWY`2WYjLA0?ooo`04069RHP2YZJT0ZJVY07EeM@80C4a<00D0NWYj08F5
Q@25QHD0MWIf05aLG00208R8R00507alO02GUiL0UiNG07QhN01`L7000P1TI6@01013@d<0GemO05mO
G`1YJFT207moO`0508F5Q@1cLg<0F5QH05QHF016ATH00P0l?3`01@1MGEd0LW9b079bLP2?Shl0TY:B
0080P82000@0WYjN05YJFP1JFUX0Ogmo0`22PX80103AdM40QhN708N7Q`1SHf<207AdM00506ATI02d
];@0^;Rh0;Rh^030`<000P2h^;P01@2VYZH0R8R808R8R02OWil0Rh^;0080MGEe00@0FEUI071`L01`
L700QhN70P2CTi<01@34a<@0GUiN09NGU`2GUiL0QHF50080Zj^[00<0^k^k0<W9b@24Q8@00P24Q8@2
0;^k^`050;fm_@22PX80PX:208J6QP1lO7`00P1kNg/0101mOGd0Vi^K09^KV`1GEeL206QXJ0050<_;
b`2XZ:P0RHV908V9R@2@T9000P1WIfL01@2h^;P0[:b/0<K6aP36a/H0VYZJ0080K6a/00D0DU9B0=WI
f@3IfMT0Ogmo092@T00208N7Q`0409>CT`2EUID0UIFE0;no_`80g=cL00D0XJ6Q07EeM@2d];@0];Bd
08f=S@0208Z:RP0507=cL`2JVYX0VYZJ0<[:bP1/K6`00P15ADD01@13@d<0?3`l03`l?01FEUH0Q8B4
0080De=C00@0GEeM06QXJ01XJ6P0KFe]0P1KFe/01@1oOgl0A4A405EEE@1EEED0L71`0080KVi^00D0
RXZ:0:ZZZP2ZZZX0P8200;Ng]`0208f=S@0508R8R02HV9P0V9RH0:j^[P1mOGd00P1DE5@0101LG5`0
JVYZ06YZJP1GEeL207YjNP03069RHP3oool0oooo00P0oooo000:0?ooo`0408N7Q`22PX80PX:207em
O@80Ng]k00D0OGem08B4Q02=SHd0SHf=08Z:RP0208b<S00505YJFP1lO7`0O7al092@T01bLW800P2B
TY801@2DU9@0W9bL09bLW02LW9`0Vi^K0080X:2P00@0XJ6Q0:VYZ@2YZJT0Z:RX0P2VYZH01@1gMgL0
Cdm?08b<S02<S8`0TY:B0080V9RH00D0X:2P0:6QX@2PX:00X:2P0:BTY00209ZJVP050:b/[02b/[80
[Zj^0:j^[P2/[:`00P2`/;001@1<C4`0YjNW0:NWY`2PX:00Shn?0080S8b<00D0TI6A08>3P`23Ph<0
PX:207]kN`020820P00407moO`24Q8@0Q8B409BDU080SXj>00D0EeMG08^;R`2>SXh0SXj>08B4Q002
08N7Q`0508j>SP2PX:00WinO09nOW`2^[Zh00`2][Jd20:^[Z`050:n_[`2ZZZX0IVIV06IVIP2IVIT0
0P2GUiL01@2CTi<0TI6A096AT@2ATI40UYJF0080WYjN00D0WinO0:RXZ02NWYh0WYjN09nOW`020::R
XP0507YjNP20P800P8200:VYZ@2XZ:P00P2WYjL01@2XZ:P0YZJV0:JVYP2UYJD0Y:BT0080YZJV0`2S
Xj<01@2VYZH0XJ6Q0:6QX@1LG5`0NGUi0080UiNG00D0ZZZZ0:^[Z`2[Zj/0ZJVY0:BTY00209fMW@<0
WYjN00D0Ti>C09BDU02FUYH0UYJF09fMW@0205UIF@030:2PX02VYZH0YZJV0080Zj^[0`2WYjL20:b/
[0030:n_[`2^[Zh0V9RH0080V9RH0P2UYJD01@2HV9P0Jf][06][J`2;Rh/0N7Qh0080UYJF00@0YJFU
0:NWY`2WYjL0YjNW4@3oool0101RHV80ZJVY0:VYZ@1eMGD204a<C00507YjNP25QHD0QHF507IfMP1L
G5`00P28R8P01@1lO7`0UiNG09NGU`1hN7P0L71`0080I6AT00@0@d=305mOG`1OGel0JFUY0P1oOgl0
1@25QHD0Lg=c05QHF01HF5P0ATI60080?3`l00D0GEeM079bLP1bLW80Shn?09:BTP020820P00409jN
WP1JFUX0FUYJ07moO`<0PX:200@0dM7A08N7Q`27QhL0Hf=S0P1dM7@01@1TI6@0];Bd0;Rh^02h^;P0
`<300080^;Rh00D0YZJV08R8R028R8P0WinO08^;R`0207EeM@0405UIF@1`L700L71`08N7Q`80Ti>C
00D0a<C405iNGP2GUiL0UiNG08F5Q@020:^[Z`030;^k^`39bLT0Q8B40080Q8B40P2k^k/01@2m_Kd0
PX:208:2PP26QXH0O7al0080Ng]k00@0OGem09^KV`2KVi/0EeMG0P1XJ6P01@3;bl/0Z:RX08V9R@29
RHT0T92@0080IfMW00D0^;Rh0:b/[036a/H0a/K609ZJVP0206a/K005059BDP3IfMT0fMWI07moO`2@
T9000P27QhL0102CTi<0UIFE09FEU@2o_kl20=cLg0050:6QX@1eMGD0];Bd0;Bd]02=SHd00P2:RXX0
1@1cLg<0VYZJ09ZJVP3:b/X0K6a/0080ADE500D0@d=303`l?00l?3`0EUIF08B4Q00205=CD`0405eM
G@1XJ6P0J6QX06e]K@80Fe]K00D0Ogmo04A4A01EEED0EEEE071`L00206i^KP0508Z:RP2ZZZX0ZZZZ
0820P02g]kL00P2=SHd01@28R8P0V9RH09RHV02^[Zh0OGem0080E5AD00@0G5aL06YZJP1ZJVX0EeMG
0P1jNWX00`1RHV80oooo0?ooo`080?ooo`002P3oool0101YJFT0GemO05mOG`1ADE42030`<00504e=
C@1@D500BDU904U9B@12@T800P0i>CT01@1;Bd/0Cdm?04m?C`16ATH0BDU90080ATI600D0AdM704m?
C`1?Cdl0>CTi02TY:@0203lo?`0404I6AP1;Bd/0Bd];0451@@80?Cdm00D0>CTi02/[:`0`<300<30`
02XZ:P0202<S8`0302l_;`0V9RH08b<S00808b<S0P0Z:RX01@1<C4`0FUYJ061PH01PH600GEeM0080
BDU900D0@D5106UYJ@1YJFT0LW9b06YZJP0205EEE@0504m?C`1KFe/0Fe]K05eMG@1GEeL00P1RHV80
101[Jf/0EEEE05EEE@1HF5P205MGE`0503Lg=`0i>CT0A4A404A4A010@4000P12@T801@1=CDd0DE5A
059BDP1BDU80C4a<0080F5QH00D0EUIF05QHF01HF5P0DU9B04e=C@020492@P0306EUI@1WIfL0IfMW
0080KFe]0P1[Jf/01@1VIVH0IfMW06MWI`1TI6@0G5aL0080Hf=S00@0IFEU069RHP1RHV80DE5A0P1G
EeL01@1jNWX0P820079bLP1bLW80MGEe0080Ogmo0P21PH4207moO`04071`L01iNGT0NGUi07inOP80
Ogmo00D0BTY:06=SH`1WIfL0IfMW07IfMP0207QhN00507emO@1aLG40HV9R069RHP1IFET00P1>CTh0
1@1MGEd0Fe]K05UIF@1IFET0Hf=S0080B4Q800D0NWYj08:2PP22PX80RXZ:071`L00207EeM@0308^;
R`2BTY80TY:B0080Shn?0P23Ph<0101hN7P0RHV908V9R@1XJ6P205UIF@0507=cL`1^KVh0RXZ:08Z:
RP2PX:000P2MWId00`2LW9`0oooo0?ooo`0?0?ooo`0406MWI`2MWId0WIfM079bLP80A4A400D0L71`
07]kN`1kNg/0IFEU04e=C@0206][J`0506QXJ01iNGT0NGUi06a/K01cLg<00P1KFe/0100l?3`0G5aL
05aLG01lO7`208N7Q`0507inOP1]KFd0D51@051@D01HF5P00P1FEUH01@1lO7`0Kfm_06m_K`2HV9P0
Rh^;0080NWYj00@0U9BD04i>CP1>CTh0L71`0P1VIVH01@1fMWH0/K6a06a/K01/K6`0GEeM0080FEUI
00<0H61P0:2PX02KVi/00P2KVi/309JFUP80QhN700D0TI6A08V9R@1eMGD0MGEe05YJFP020861P@05
0820P02GUiL0UiNG0<O7a`1QHF400P2PX:001@25QHD0]kNg0;Ng]`2o_kl0dm?C0080S8b<00@0TI6A
0;jn_P2n_[h0]kNg0P24Q8@01@1hN7P0Kfm_07]kN`1kNg/0NGUi0080S8b<00D0G5aL06i^KP1^KVh0
`l?309nOW`0207IfMP0508n?S`1NGUh0GUiN0;Fe]@2ZZZX00P2l_;`0102IVIT0H61P061PH01@D502
0=KFeP0507=cL`27QhL0Ph>308>3P`26QXH00P2@T9001@2/[:`0dm?C0=?Cd`2RXZ80KFe]0080/k>c
00@0W9bL09RHV02HV9P0N7Qh0P2DU9@01@3?cll0J6QX0410@010@400>SXj0080>3Ph00D0C4a<07em
O@1DE5@0E5AD06QXJ00205UIF@0506UYJ@1MGEd0GEeM06i^KP1?Cdl00P1QHF40101ZJVX0NGUi07Ui
N@2YZJT20:b/[00509^KV`30`<00UiNG09NGU`2ATI400P2a/K401@2_[jl0OWin05mOG`1OGel0H61P
0080JFUY00@0E5AD07IfMP1fMWH0FUYJ2P3oool000X0oooo00@0^[Zj0;Vi^@2i^KT0/K6a0P1_Kfl0
1@2i^KT0]KFe0;2`/02`/;00];Bd0080[Jf]00D0/[:b0;>c/`2c/k<0]kNg0;Zj^P020;jn_P050;no
_`2j^[X0^[Zj0:JVYP1JFUX00P1lO7`01028R8P0/k>c0;>c/`2j^[X20;Vi^@050;jn_P2e]KD0/[:b
0;:b/P2^[Zh00P2UYJD20:b/[080YjNW00D0BTY:0:ZZZP2ZZZX0];Bd0;>c/`020;2`/0040:f][@2`
/;00/;2`0::RXP<0[jn_00@0[:b/0:6QX@2QXJ40Vi^K0P2=SHd01@1@D500WYjN0:b/[02/[:`0YjNW
0080Y:BT0`2XZ:P01@2RXZ80WIfM09fMW@2MWId0UIFE0080WinO00D0Vi^K07alO015ADD0ADE507mo
O`0208Z:RP0508F5Q@27QhL0QhN708b<S02?Shl00P24Q8@01@2;Rh/0SXj>08j>SP2>SXh0TI6A0080
UIFE00D0S8b<05IFEP1FEUH0L71`07YjNP0207UiN@0407]kN`1fMWH0MWIf07=cL`80KFe]00D0J6QX
06ATI01HF5P0F5QH05UIF@0205MGE`0502`/;00g=cL0GUiN05iNGP1JFUX00P1EEED01@1HF5P0GUiN
05iNGP1TI6@0G5aL0080EUIF00D0HF5Q05YJFP1JFUX0B4Q803`l?00205aLG0<0IFEU00D0FEUI05EE
E@1KFe/0Fe]K06ATI00206QXJ00505mOG`1DE5@0E5AD04i>CP13@d<00P0V9RH01@0h>3P0AdM704M7
A`0n?Sh0@D5100<0?clo0P0l?3`01@15ADD0@T920492@P19BDT0CDe=0080F5QH00@0De=C03hn?P0n
?Sh0A4A44@3oool0101ZJVX0ZJVY0:VYZ@1/K6`20492@P0506e]K@1eMGD0MGEe06EUI@1IFET00P1o
Ogl01@1YJFT0P8200820P02<S8`0RXZ:0080FUYJ00@0>CTi05iNGP1NGUh0Hf=S0P21PH401@2=SHd0
NGUi05iNGP1NGUh0F5QH0080BDU900D0NGUi061PH01PH600WinO0:BTY00208>3P`040:ZZZP1MGEd0
GEeM07MgM`<0KVi^00@0_[jn08f=S@2=SHd0Fe]K0P1IFET01@1cLg<0^[Zj0<C4a034a<@0][Jf0080
[Zj^00D0/[:b09bLW02LW9`0Y:BT08^;R`0207AdM00405IFEP1`L700L71`08>3P`80WYjN00D0`l?3
05iNGP2/[:`0[:b/08f=S@020;Zj^P050<30`03Fe]H0Ti>C09>CT`29RHT00P2a/K401@2c/k<0SHf=
08f=S@1fMWH0L71`0080MgMg00@0MWIf08b<S02<S8`0Hf=S0P1cLg<01@30`<00VIVI06m_K`1_Kfl0
QhN70080H61P00D0_[jn0:b/[02^[Zh0[Zj^0:n_[`02075aL@0504];B`3Fe]H0e]KF07=cL`2CTi<0
0P1eMGD0101kNg/0LG5a075aL@2MWId20<k>cP0508R8R01RHV80_Kfm0;fm_@2TY:@00P2FUYH01@1i
NGT0S8b<08b<S037alL0K6a/0080@D510`0g=cL01@1CDe<0Kfm_06EUI@1UIFD0J6QX0080Kfm_00D0
J6QX07EeM@1eMGD0NGUi055AD@0206QXJ00405aLG028R8P0R8R809^KV`80Zj^[00D0U9BD0;Ng]`2O
Wil0WinO05]KF`0207alO00509RHV01kNg/0Jf][06][J`1NGUh00P1RHV80101KFe/0TI6A096AT@1P
H60:0?ooo`002P3oool0102e]KD0];Bd0;Bd]02^[Zh2075aL@050;>c/`2d];@0]kNg0;Ng]`2b/[80
0P2^[Zh01@2a/K40[Jf]0:f][@2g]kL0^k^k0080^[Zj00D0]kNg0;6a/@2a/K40[Zj^04i>CP0208j>
SP0409FEU@2[Zj/0Zj^[0:n_[`80]kNg00D0];Bd0;6a/@2[Zj/0Zj^[0:RXZ0020:FUY@050:RXZ02T
Y:@0WYjN09jNWP1CDe<00P2_[jl01@2^[Zh0/;2`0:j^[P2^[Zh0YjNW0080/;2`0`2^[Zh00`2[Zj/0
YJFU0:^[Z`020:^[Z`80[:b/00D0H61P0:b/[02a/K40/K6a0;:b/P020;Jf]P050;Fe]@2d];@0];Bd
0;2`/02[Zj/00P2KVi/01@2MWId0[:b/0:b/[02b/[80Y:BT0080De=C00@0WinO0:FUY@2UYJD0W9bL
0P2KVi/01@2TY:@0YjNW0:JVYP2VYZH0YJFU0080Xj>S00D0YZJV0:b/[02^[Zh0[Zj^0;:b/P0207If
MP030;Vi^@2m_Kd0_Kfm0080_Kfm0`2o_kl20<30`0050;no_`2l_;`0][Jf0;Jf]P2c/k<00P2k^k/0
1@0o?cl0S8b<0:NWY`2WYjL0Z:RX00<0ZZZZ0P2_[jl00`2d];@0^;Rh0;^k^`020;^k^`80^;Rh00D0
KFe]06i^KP2TY:@0Y:BT0:VYZ@020;:b/P050;Rh^02m_Kd0^k^k0;^k^`2m_Kd00P2k^k/01@2h^;P0
/K6a0;6a/@2_[jl0WYjN0080DE5A00D0U9BD0:j^[P2^[Zh0ZJVY0:b/[0020;Bd]0040;>c/`2`/;00
/;2`0;Vi^@80]kNg00D0_[jn0;fm_@2m_Kd0_Kfm0:b/[00206YZJP030:j^[P3oool0oooo00l0oooo
00@0KVi^0:BTY02TY:@0LG5a0P16ATH01@1fMWH0Ph>308>3P`1cLg<0IVIV0080Ogmo00D0MGEe09:B
TP2BTY80Q8B40820P00205]KF`040492@P1]KFd0KFe]05]KF`80LW9b00D0NWYj06e]K@1<C4`0C4a<
04=3@`0204e=C@0505iNGP1@D500D51@08:2PP29RHT00P1mOGd0102EUID0EUIF05IFEP1_Kfl207Ui
N@050820P03EeMD0T92@092@T01TI6@00P1LG5`01@1`L700Z:RX0;Fe]@2e]KD0^k^k0080[jn_00D0
ZZZZ09^KV`2KVi/0Ti>C08N7Q`0207MgM`0406=SH`1jNWX0NWYj07EeM@80PH6100D0[jn_05MGE`2V
YZH0YZJV09ZJVP020;Rh^0050<;2`P3:b/X0TI6A096AT@25QHD00P2f][H01@2c/k<0V9RH09RHV01_
Kfl0Lg=c0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01@35aLD0Xj>S069RHP1RHV80LG5a0080
DU9B00D0^k^k0:j^[P36a/H0a/K60;>c/`0207YjNP0504M7A`3Ph>00h>3P0861P@2@T9000P22PX80
102<S8`0Rh^;08^;R`2d];@20=gMg@0509>CT`1[Jf/0^;Rh0;Rh^02YZJT00P2CTi<01@1aLG40OGem
07emO@34a<@0MWIf0080B4Q80`0i>CT01@10@400HV9R07QhN01hN7P0GemO0080Ph>300D0MgMg07al
O01lO7`0JVYZ05iNGP0206YZJP0406=SH`20P800P8200:ZZZP80Zj^[00D0QHF50;Ng]`2l_;`0_;bl
07AdM00208n?S`050:>SX`24Q8@0Fe]K05]KF`1[Jf/00P1ZJVX0101WIfL0RXZ:08Z:RP1gMgL:0?oo
o`002P3oool0102e]KD0];Bd0;Bd]02^[Zh2075aL@050;>c/`2d];@0]kNg0;Ng]`2b/[800P2^[Zh0
1@2a/K40[Jf]0:f][@2g]kL0^k^k0080^[Zj00D0]kNg0;6a/@2a/K40[Zj^04i>CP0208j>SP0409FE
U@2[Zj/0Zj^[0:n_[`80]kNg00D0];Bd0;6a/@2[Zj/0Zj^[0:RXZ0020:FUY@050:RXZ02TY:@0WYjN
09jNWP1CDe<00P2_[jl01@2^[Zh0/;2`0:j^[P2^[Zh0YjNW0080/;2`0`2^[Zh00`2[Zj/0YJFU0:^[
Z`020:^[Z`80[:b/00D0H61P0:b/[02a/K40/K6a0;:b/P020;Jf]P050;Fe]@2d];@0];Bd0;2`/02[
Zj/00P2KVi/01@2MWId0[:b/0:b/[02b/[80Y:BT0080De=C00@0WinO0:FUY@2UYJD0W9bL0P2KVi/0
1@2TY:@0YjNW0:JVYP2VYZH0YJFU0080Xj>S00D0YZJV0:b/[02^[Zh0[Zj^0;:b/P0207IfMP030;Vi
^@2m_Kd0_Kfm0080_Kfm0`2o_kl20<30`0050;no_`2l_;`0][Jf0;Jf]P2c/k<00P2k^k/01@0o?cl0
S8b<0:NWY`2WYjL0Z:RX00<0ZZZZ0P2_[jl00`2d];@0^;Rh0;^k^`020;^k^`80^;Rh00D0KFe]06i^
KP2TY:@0Y:BT0:VYZ@020;:b/P050;Rh^02m_Kd0^k^k0;^k^`2m_Kd00P2k^k/01@2h^;P0/K6a0;6a
/@2_[jl0WYjN0080DE5A00D0U9BD0:j^[P2^[Zh0ZJVY0:b/[0020;Bd]0040;>c/`2`/;00/;2`0;Vi
^@80]kNg00D0_[jn0;fm_@2m_Kd0_Kfm0:b/[00206YZJP030:j^[P3oool0oooo00l0oooo00@0KVi^
0:BTY02TY:@0LG5a0P16ATH01@1fMWH0Ph>308>3P`1cLg<0IVIV0080Ogmo00D0MGEe09:BTP2BTY80
Q8B40820P00205]KF`040492@P1]KFd0KFe]05]KF`80LW9b00D0NWYj06e]K@1<C4`0C4a<04=3@`02
04e=C@0505iNGP1@D500D51@08:2PP29RHT00P1mOGd0102EUID0EUIF05IFEP1_Kfl207UiN@050820
P03EeMD0T92@092@T01TI6@00P1LG5`01@1`L700Z:RX0;Fe]@2e]KD0^k^k0080[jn_00D0ZZZZ09^K
V`2KVi/0Ti>C08N7Q`0207MgM`0406=SH`1jNWX0NWYj07EeM@80PH6100D0[jn_05MGE`2VYZH0YZJV
09ZJVP020;Rh^0050<;2`P3:b/X0TI6A096AT@25QHD00P2f][H01@2c/k<0V9RH09RHV01_Kfl0Lg=c
0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01@35aLD0Xj>S069RHP1RHV80LG5a0080DU9B00D0
^k^k0:j^[P36a/H0a/K60;>c/`0207YjNP0504M7A`3Ph>00h>3P0861P@2@T9000P22PX80102<S8`0
Rh^;08^;R`2d];@20=gMg@0509>CT`1[Jf/0^;Rh0;Rh^02YZJT00P2CTi<01@1aLG40OGem07emO@34
a<@0MWIf0080B4Q80`0i>CT01@10@400HV9R07QhN01hN7P0GemO0080Ph>300D0MgMg07alO01lO7`0
JVYZ05iNGP0206YZJP0406=SH`20P800P8200:ZZZP80Zj^[00D0QHF50;Ng]`2l_;`0_;bl07AdM002
08n?S`050:>SX`24Q8@0Fe]K05]KF`1[Jf/00P1ZJVX0101WIfL0RXZ:08Z:RP1gMgL:0?ooo`002P3o
ool0102e]KD0/K6a0;6a/@2VYZH206i^KP050;>c/`2h^;P0^KVi0;Vi^@2d];@00P2a/K401@2^[Zh0
Zj^[0:^[Z`2b/[80]kNg0080]KFe00D0/[:b0:b/[02/[:`0[Jf]05eMG@020:VYZ@040:>SX`2][Jd0
[Jf]0:VYZ@80YZJV00<0ZJVY0:NWY`2SXj<00P2SXj<20:NWY`050:ZZZP2PX:00RXZ:08Z:RP1OGel0
0P2^[Zh01@2/[:`0ZZZZ0:VYZ@2YZJT0WYjN0080YZJV00D0ZZZZ0:BTY02TY:@0YZJV0:NWY`020:JV
YP050:ZZZP2`/;00/;2`075aL@2a/K400P2][Jd0102d];@0/K6a0;6a/@2][Jd20:FUY@050::RXP2M
WId0XZ:R0::RXP2SXj<00P2ZZZX0102/[:`0YZJV04];B`1;Bd/309jNWP0508n?S`2GUiL0UiNG09:B
TP2NWYh00P2LW9`01@2NWYh0Y:BT0:BTY02RXZ80ZJVY0080[Jf]00D0/;2`075aL@1aLG40^KVi0;jn
_P020;no_`040<71`@32`/80`/;20;jn_P80[jn_00D0/[:b0;Jf]P2e]KD0]KFe0;Rh^0020;Vi^@05
04e=C@2TY:@0YjNW0:NWY`2[Zj/00P2YZJT01@2ZZZX0[jn_0:n_[`2b/[80]KFe0080];Bd00D0]kNg
0;Jf]P2f][H0JFUY071`L0020:NWY`050:j^[P2c/k<0/k>c0;Ng]`2k^k/00P2m_Kd30;Zj^P050;Fe
]@2b/[80/[:b0:b/[02<S8`00P1:BTX00`2KVi/0ZZZZ0:ZZZP020:j^[P80[jn_00@0/;2`0;:b/P2b
/[80^[Zj0P2h^;P01@2k^k/0^[Zj0;Vi^@2i^KT0[jn_0080M7Ad00<0/K6a0?ooo`3oool03`3oool0
101OGel0UYJF09JFUP1kNg/204a<C00507=cL`1fMWH0MWIf07=cL`1NGUh00P1oOgl01@1fMWH0Rh^;
08^;R`1UIFD0IVIV0080CTi>00@0>3Ph075aL@1aLG40JFUY0P27QhL01@2;Rh/0M7Ad05YJFP1JFUX0
EEEE0080@41000D0LW9b05EEE@1EEED0TY:B08j>SP0207inOP0409bLW01TI6@0I6AT07IfMP80MGEe
00D0Ng]k0<c<c02;Rh/0Rh^;061PH002055AD@0306i^KP2YZJT0/[:b0080/[:b0P2RXZ801@2VYZH0
T92@092@T02ATI40OWin0080KVi^00@0FEUI06a/K01/K6`0NGUi0P2CTi<01@2m_Kd0GEeM08b<S02<
S8`0Shn?0080]KFe00D0_Kfm0<G5a@2<S8`0S8b<07UiN@020:^[Z`050:6QX@2GUiL0UiNG07QhN01]
KFd00P1gMgL0102CTi<0Q8B408B4Q01gMgL208R8R0050;Rh^02OWil0EeMG05MGE`1bLW800P1@D500
1@33`l<0^[Zj0;Jf]P2f][H0ZJVY0080JVYZ00D0@4100=3@d03@d=00NWYj09jNWP020861P@0407Mg
M`1XJ6P0J6QX09NGU`80alO700D0T92@07=cL`2n_[h0_[jn0;Ng]`0208:2PP0506i^KP2:RXX0RXZ:
0<[:bP2?Shl00P1?Cdl01@0n?Sh0;Rh^02h^;P14A4@0LG5a0080UIFE00@0J6QX0820P020P800MWIf
0P1mOGd01@1fMWH0FEUI07QhN01hN7P0H61P0080Ogmo00D0ZZZZ0:JVYP2VYZH0TI6A0;jn_P020;Jf
]P05071`L02FUYH0UYJF0:JVYP2ATI400P1XJ6P0101fMWH0GemO05mOG`1dM7@208f=S@0307UiN@3o
ool0oooo00P0oooo000:0?ooo`040:n_[`2ZZZX0ZZZZ0:NWY`80MgMg00D0]KFe0;Ng]`2h^;P0^;Rh
0:f][@020:6QX@050:BTY02YZJT0ZJVY0;>c/`2d];@00P2b/[801@2][Jd0ZJVY0:VYZ@2WYjL0F5QH
0080[Jf]00@0ZZZZ0:b/[02/[:`0[Zj^0P2TY:@01@2RXZ80YJFU09ZJVP2JVYX0X:2P0080Xj>S00D0
YjNW0:ZZZP2?Shl0Shn?05YJFP020:j^[P050:RXZ02YZJT0YjNW0:NWY`2BTY800P2IVIT01@2HV9P0
UIFE09FEU@2IVIT0Z:RX0080ZZZZ00@0YjNW0:n_[`2_[jl0I6AT0`2^[Zh0102/[:`0[Zj^0:j^[P2T
Y:@20:FUY@050:JVYP2UYJD0YZJV0:JVYP2SXj<00P2QXJ401@2UYJD0[jn_04e=C@1=CDd0WIfM0080
Vi^K00D0Ph>307moO`1oOgl0O7al08Z:RP02096AT@0409BDU02SXj<0Xj>S0:2PX0@0ZZZZ0P1bLW80
102m_Kd0`L710<30`030`<030;fm_@050;^k^`2i^KT0^KVi0;>c/`2k^k/00P2g]kL0102l_;`0^[Zj
0;Zj^P1HF5P309ZJVP0408j>SP2DU9@0U9BD0:2PX080YjNW00<0/;2`0;Fe]@2i^KT00P2i^KT20:j^
[P0304i>CP1]KFd0Zj^[0080Zj^[0P2/[:`01@2[Zj/0[Jf]0;Ng]`2g]kL0]KFe0080[Zj^00D0ZZZZ
0:>SX`2SXj<0Z:RX09BDU00204];B`0309VIV@2QXJ40XJ6Q00@0YZJV00@0UiNG0:FUY@2UYJD0X:2P
0P2QXJ401@2YZJT0/K6a0:RXZ02XZ:P0Xj>S0080OGem00<0];Bd0?ooo`3oool03`3oool0101WIfL0
S8b<08b<S01kNg/204I6AP0507EeM@21PH40PH6107AdM01GEeL00P1gMgL01@1YJFT0Ogmo07moO`1h
N7P0Ng]k0080@d=300@0ADE5061PH01PH600De=C0P1nOWh01@21PH40J6QX05=CD`1CDe<0D51@0080
A4A400D0MgMg061PH01PH600VYZJ08j>SP0208N7Q`0409fMW@1fMWH0MWIf07QhN080MWIf00@0OGem
0<g=c@2GUiL0UiNG0`1RHV801@1bLW80Xj>S0;Vi^@2i^KT0^;Rh0080/k>c00D0/;2`09ZJVP2JVYX0
YJFU08b<S00207inOP04065QH@1nOWh0OWin08>3P`80T92@00D0_;bl065QH@2EUID0UIFE08N7Q`02
0;Jf]P050;bl_032`/80Shn?08n?S`2BTY800P2_[jl01@2h^;P0T92@092@T01aLG40LW9b0080N7Qh
00@0TY:B0861P@21PH40OGem0P2ATI401@2l_;`0YZJV069RHP1RHV80NWYj0080FEUI00D0`/;20;>c
/`2YZJT0ZJVY0:b/[00207alO00504];B`3Kfm/0fm_K07IfMP2?Shl00P1eMGD01024Q8@0PX:208:2
PP2][Jd20<K6aP0507moO`1WIfL0WYjN09jNWP2b/[800P1dM7@01@1YJFT0QXJ608J6QP3<c<`0UIFE
0080FUYJ00D0AdM701HF5P0F5QH0=cLg08Z:RP0208j>SP0405iNGP1mOGd0OGem07inOP80S8b<00D0
P820069RHP1TI6@0I6AT051@D00208j>SP050;>c/`2RXZ80XZ:R09nOW`2PX:000P2OWil01@1TI6@0
QXJ608J6QP28R8P0RXZ:0080Fe]K00@0Ng]k07AdM01dM7@0PH610P2IVIT00`1fMWH0oooo0?ooo`08
0?ooo`002P3oool0102_[jl0ZZZZ0:ZZZP2WYjL207MgM`050;Fe]@2g]kL0^;Rh0;Rh^02][Jd00P2Q
XJ401@2TY:@0ZJVY0:VYZ@2c/k<0];Bd0080/[:b00D0[Jf]0:VYZ@2YZJT0YjNW05QHF0020:f][@04
0:ZZZP2/[:`0[:b/0:j^[P80Y:BT00D0XZ:R0:FUY@2JVYX0VYZJ0:2PX0020:>SX`050:NWY`2ZZZX0
Shn?08n?S`1JFUX00P2^[Zh01@2XZ:P0ZJVY0:NWY`2WYjL0TY:B0080VIVI00D0V9RH09FEU@2EUID0
VIVI0:RXZ0020:ZZZP040:NWY`2_[jl0[jn_06ATI0<0[Zj^00@0[:b/0:j^[P2^[Zh0Y:BT0P2UYJD0
1@2VYZH0YJFU0:JVYP2VYZH0Xj>S0080XJ6Q00D0YJFU0:n_[`1=CDd0CDe=09fMW@0209^KV`0508>3
P`1oOgl0Ogmo07alO02:RXX00P2ATI40102DU9@0Xj>S0:>SX`2PX:040:ZZZP80LW9b00@0_Kfm0<71
`@30`<00`<300`2m_Kd01@2k^k/0^KVi0;Vi^@2c/k<0^k^k0080]kNg00@0_;bl0;Zj^P2j^[X0F5QH
0`2JVYX0102>SXh0U9BD09BDU02PX:020:NWY`030;2`/02e]KD0^KVi0080^KVi0P2^[Zh00`1>CTh0
KFe]0:^[Z`020:^[Z`80[:b/00D0Zj^[0:f][@2g]kL0]kNg0;Fe]@020:j^[P050:ZZZP2SXj<0Xj>S
0:RXZ02DU9@00P1;Bd/00`2IVIT0XJ6Q0:6QX@040:JVYP0409NGU`2UYJD0YJFU0:2PX080XJ6Q00D0
ZJVY0;6a/@2XZ:P0Z:RX0:>SX`0207emO@030;Bd]03oool0oooo00l0oooo00@0IfMW08b<S02<S8`0
Ng]k0P16ATH01@1eMGD0PH610861P@1dM7@0EeMG0080MgMg00D0JFUY07moO`1oOgl0N7Qh07]kN`02
04=3@`0404E5A@1PH600H61P05=CD`80OWin00D0PH6106QXJ01CDe<0De=C051@D00204A4A00507Mg
M`1PH600H61P09ZJVP2>SXh00P27QhL0102MWId0MWIf07IfMP1hN7P207IfMP0407emO@3=cLd0UiNG
09NGU`<0HV9R00D0LW9b0:>SX`2i^KT0^KVi0;Rh^0020;>c/`050;2`/02JVYX0VYZJ0:FUY@2<S8`0
0P1nOWh0101QHF40OWin07inOP23Ph<2092@T0050;bl_01QHF40UIFE09FEU@27QhL00P2f][H01@2l
_;`0`/;208n?S`2?Shl0TY:B0080[jn_00D0^;Rh092@T02@T900LG5a079bLP0207QhN00409:BTP21
PH40PH6107emO@80TI6A00D0_;bl0:JVYP1RHV80HV9R07YjNP0205UIF@050<;2`P2c/k<0ZJVY0:VY
Z@2/[:`00P1lO7`01@1;Bd/0fm_K0=_Kf`1fMWH0Shn?0080MGEe00@0Q8B408:2PP22PX80[Jf]0P36
a/H01@1oOgl0IfMW09jNWP2NWYh0/[:b0080M7Ad00D0JFUY08J6QP26QXH0c<c<09FEU@0205YJFP05
04M7A`0F5QH05QHF03Lg=`2:RXX00P2>SXh0101NGUh0OGem07emO@1nOWh208b<S0050820P01RHV80
I6AT06ATI01@D5000P2>SXh01@2c/k<0XZ:R0::RXP2OWil0X:2P0080WinO00D0I6AT08J6QP26QXH0
R8R808Z:RP0205]KF`0407]kN`1dM7@0M7Ad0861P@80VIVI00<0MWIf0?ooo`3oool0203oool000X0
oooo00@0CDe=04A4A014A4@0<30`0P0W9bL01@10@400@d=303Ph>00h>3P0=SHf0080<c<c00D0820P
030`<00`<300>c/k03hn?P020451@@0503dm?@0n?Sh0?Shn038b<P0/;2`00P0j>SX00`18B4P0C4a<
04a<C00304Q8B0050451@@0k>c/0B4Q804Q8B01>CTh00P1@D5001@1EEED0ATI60492@P12@T807AdM
0080G5aL00D0I6AT06IVIP1WIfL0IfMW06][J`0206MWI`05071`L01/K6`0K6a/06YZJP1fMWH00P1^
KVh01@1[Jf/0Kfm_06m_K`0m?Cd0LW9b0080MgMg00<0NGUi07]kN`1kNg/0101cLg<0101aLG40K6a/
06a/K01fMWH207QhN00507alO01iNGT0>SXj03Xj>P1mOGd00P1gMgL01@1hN7P0LG5a075aL@1VIVH0
N7Qh0080OWin0`21PH4208^;R`80QhN700D0S8b<05IFEP1FEUH0SHf=08Z:RP02092@T00408R8R027
QhL0QhN7092@T080TI6A00D0QHF509FEU@2IVIT0VIVI0::RXP020;6a/@0504];B`2IVIT0Z:RX0:RX
Z02HV9P00P2;Rh/01@2GUiL0TY:B09:BTP2HV9P0YZJV0080[Jf]00D0^;Rh0;2`/02`/;00CTi>06e]
K@0209fMW@0509bLW02NWYh0WYjN0::RXP2[Zj/00P2XZ:P0102YZJT0Y:BT0:BTY02PX:0208^;R`05
09ZJVP2>SXh0FEUI05UIF@2OWil00`2DU9@0102NWYh0XJ6Q0:6QX@2FUYH2096AT@0508V9R@2;Rh/0
Rh^;09ZJVP2TY:@00P2^[Zh0102SXj<0MWIf07IfMP2`/;0A0?ooo`0405eMG@2;Rh/0Rh^;07YjNP80
DE5A00D0MgMg08F5Q@25QHD0P82005iNGP020820P00507alO01iNGT0NGUi075aL@1fMWH00P1?Cdl0
101=CDd0FEUI05UIF@1EEED207UiN@05092@T01QHF40De=C05=CD`1JFUX00P14A4@01@1kNg/0Hf=S
06=SH`2NWYh0YjNW0080Q8B400@0UIFE071`L01`L700Lg=c0P1fMWH01@1cLg<0a<C407moO`1oOgl0
FUYJ00<0Lg=c00@0UIFE0;Rh^02h^;P0`L710P2f][H01@2MWId0NGUi07UiN@2>SXh0P8200080MGEe
00@0EUIF079bLP1bLW80O7al0P2LW9`01@2g]kL0KFe]09BDU02DU9@0PH610080/[:b00D0_Kfm0<?3
``2@T900T92@07emO@030:n_[`80SXj>00D0MGEe071`L021PH40PH6109:BTP0207inOP0507]kN`2>
SXh0SXj>0;Ng]`2DU9@00P1IFET01@1gMgL0FUYJ05YJFP36a/H0`/;20080VYZJ00@0[Jf]0861P@21
PH40B4Q80P3Ng]h01@28R8P0RHV907]kN`1kNg/0Ph>30080RHV900D0[Zj^0=GEe@3EeMD0UiNG07em
O@020:b/[0040;Rh^01WIfL0IfMW07alO080LG5a00D0/k>c09VIV@1LG5`0G5aL0451@@0203<c<`05
02@T901_Kfl0JFUY06UYJ@1CDe<00P1/K6`01@1cLg<0QHF508F5Q@1iNGT0EUIF0080J6QX00@0@T92
061PH01PH600U9BD0P2KVi/01@28R8P0PH610;Rh^02h^;P0Lg=c0080S8b<00D0Vi^K08V9R@1ADE40
DE5A071`L00206UYJ@0407]kN`2MWId0WIfM08B4Q0X0oooo000:0?ooo`0406][J`14A4@0A4A408>3
P`80T92@00D0Rh^;08R8R01bLW80LW9b02`/;00206=SH`0508Z:RP2;Rh/0Rh^;0861P@1nOWh00P1W
IfL0100`<300GemO05mOG`22PX8308>3P`0407MgM`1dM7@0M7Ad03Hf=P80JFUY00D0KVi^069RHP1G
EeL0EeMG05iNGP0205EEE@0502PX:00j>SX0A4A404A4A01=CDd00P1VIVH01@1RHV80>CTi02PX:00X
:2P0GUiN0080MgMg00D0Kfm_06IVIP1VIVH0J6QX06MWI`0202/[:`0503hn?P1PH600H61P06=SH`1G
EeL00P19BDT0101ADE40=cLg03Lg=`1HF5P205ADE00504Y:BP0l?3`0@4100410@00j>SX00P0Z:RX0
1@1LG5`0F5QH05QHF01HF5P0B4Q80080<30`00D0:BTY02<S8`0S8b<0:b/[02l_;`0203Ph>00503Hf
=P0[:b/0:b/[02LW9`0j>SX00P15ADD01@19BDT0@T920492@P0j>SX0=SHf0080<c<c00@0@D5103dm
?@0m?Cd0>3Ph0P0d=3@01@0R8R806ATI02HV9P0V9RH0;Bd]0080<C4a00D0:RXZ02d];@0j>SX0>SXj
04E5A@020451@@0504A4A015ADD0ADE50451@@0m?Cd00P0i>CT01012@T80EeMG05MGE`1;Bd/304a<
C0<0De=C00D0CDe=04U9B@1>CTh0CTi>05MGE`0205UIF@0505QHF01BDU80DU9B059BDP1EEED00P0f
=SH0100Z:RX0>c/k03/k>`11@D4304E5A@0405EEE@1GEeL0EeMG04Q8B080AdM70P1<C4`205aLG004
04i>CP0`<300<30`04E5AA40oooo00@0IFEU0:>SX`2SXj<0M7Ad0P1:BTX01@1mOGd0WYjN09jNWP27
QhL0GUiN0080O7al00D0OGem09BDU02DU9@0PX:207alO00205aLG00404M7A`1UIFD0IFEU06MWI`80
Ng]k00D0L71`04];B`1MGEd0GEeM04i>CP020492@P0506m_K`1HF5P0F5QH09JFUP2WYjL00P2<S8`0
102NWYh0MWIf07IfMP1cLg<207UiN@0506YZJP2m_Kd0NGUi07UiN@1FEUH00P1PH6001@1JFUX0NWYj
0:2PX02PX:00YjNW0080YZJV00D0UIFE07YjNP1jNWX0S8b<07emO@02079bLP0405MGE`1hN7P0N7Qh
07moO`80VYZJ00D0^[Zj07=cL`2HV9P0V9RH08^;R`020::RXP050;Zj^P35aLD0UIFE09FEU@1hN7P0
0P2h^;P01@2j^[X0WIfM09fMW@1nOWh0I6AT0080MgMg00@0Ti>C08B4Q024Q8@0QHF50P2BTY801@2j
^[X0X:2P05aLG01LG5`0M7Ad0080GUiN00D0_[jn0<O7a`2g]kL0]kNg0:^[Z`0208B4Q00504A4A03G
emL0emOG09FEU@2<S8`00P24Q8@0101kNg/0OWin07inOP2[Zj/20=GEe@05092@T024Q8@0XJ6Q0:6Q
X@2n_[h00P1WIfL01@1dM7@0Fe]K05]KF`30`<00VIVI0080C4a<00D0@d=303De=@0e=CD0=3@d06QX
J002065QH@04059BDP1HF5P0F5QH07moO`80Lg=c00D0LW9b05YJFP1WIfL0IfMW055AD@0206YZJP05
08V9R@2FUYH0UYJF09FEU@2DU9@00P2][Jd00`1YJFT0X:2P0:2PX00209RHV080EeMG00@0FEUI04Q8
B018B4P0GEeM0P2:RXX00`1hN7P0oooo0?ooo`080?ooo`002P3oool0102NWYh0?Cdm03dm?@2l_;`2
0<S8b0050<W9b@3:b/X0_Kfm0;fm_@0[:b/00P21PH401@2d];@0]kNg0;Ng]`2g]kL0^;Rh0080WYjN
00<0:2PX08b<S02<S8`0102i^KT0102/[:`0UiNG09NGU`1=CDd2096AT@0509fMW@2<S8`0RXZ:08Z:
RP2>SXh00P20P8001@1=CDd0EUIF05EEE@1EEED0IFEU0080Ph>300D0Shn?08:2PP0c<c<0<c<c08f=
S@020:j^[P0509fMW@2GUiL0UiNG0:6QX@2LW9`00P13@d<01@1eMGD0ZJVY0:VYZ@2a/K40/;2`0080
/k>c00@0^;Rh05EEE@1EEED0XJ6Q0P2=SHd01@1TI6@0GEeM05IFEP1FEUH0DE5A0080B4Q800D0]kNg
0;Vi^@2h^;P0^;Rh0;Jf]P020;:b/P0506UYJ@1KFe/0Fe]K0:NWY`2f][H00P2g]kL01@2l_;`0Zj^[
0:^[Z`12@T80RHV90080]KFe0`2d];@01@2j^[X0[Zj^04=3@`13@d<0^[Zj0080_kno00D0a<C40<G5
a@35aLD0Rh^;08>3P`020;Zj^P050;:b/P2XZ:P0Z:RX0:BTY02<S8`00P1BDU80102QXJ40ZZZZ0:ZZ
ZP2UYJD20:^[Z`050:ZZZP2TY:@0EUIF05IFEP2_[jl00P2d];@01@2l_;`0^KVi0;>c/`2c/k<0C4a<
0080K6a/00<0X:2P09>CT`2@T9000P2@T90209JFUP0505mOG`18B4P0B4Q808R8R02ATI400P2SXj<0
1@2QXJ40RHV908V9R@0k>c/0KVi^0080SHf=00@0VIVI09RHV02HV9P0VIVI0P2?Shl01@0f=SH0HF5Q
08j>SP2>SXh0VIVI0080XZ:R00<0W9bL0?ooo`3oool03`3oool0101NGUh0Ti>C09>CT`1[Jf/204Q8
B00507IfMP29RHT0RHV906m_K`1FEUH00P21PH401@1mOGd0U9BD09BDU021PH40Ng]k0080HV9R00@0
F5QH06QXJ01XJ6P0J6QX0P29RHT01@2UYJD0DU9B051@D01@D500EEEE0080BDU900D0NWYj059BDP1B
DU80UiNG09fMW@0209BDU0040:>SX`1cLg<0Lg=c07EeM@80O7al00D0LW9b0<c<c024Q8@0Q8B405iN
GP02075aL@0506UYJ@1oOgl0ZJVY0:VYZ@2/[:`00P2a/K401@2:RXX0PH610861P@2BTY80Ph>30080
PH6100@0De=C07=cL`1cLg<0UYJF0P2IVIT01@2o_kl0SXj>09jNWP2NWYh0UIFE0080XZ:R00D0a<C4
0<;2`P2LW9`0W9bL07AdM0020:VYZ@050:j^[P2][Jd0[Jf]07UiN@1aLG400P2DU9@0102VYZH0OWin
07inOP28R8P208J6QP050;fm_@2[Zj/0Hf=S06=SH`1ZJVX00P1hN7P01@2RXZ80/;2`0:BTY02TY:@0
UYJF0080MWIf00D0@T920<W9b@39bLT0QXJ6092@T00207inOP04071`L01^KVh0KVi^09fMW@80aLG5
00D0Q8B408N7Q`2/[:`0[:b/0:j^[P0206i^KP0508:2PP1MGEd0GEeM0:6QX@2LW9`00P1ADE401@13
@d<0BTY:04Y:BP1ADE40Hf=S0080K6a/00@0I6AT04M7A`17AdL0G5aL0P1FEUH01@1cLg<0D51@06a/
K01/K6`0C4a<0080GemO00D0Ng]k0:6QX@2QXJ40QHF509VIV@020:^[Z`0506ATI02>SXh0SXj>07mo
O`2LW9`00P1IFET0101bLW80GEeM05eMG@1mOGd208j>SP0306m_K`3oool0oooo00P0oooo000:0?oo
o`0409jNWP0m?Cd0?Cdm0;bl_080b<S800D0bLW90<[:bP2m_Kd0_Kfm02/[:`020861P@050;Bd]02g
]kL0]kNg0;Ng]`2h^;P00P2NWYh00`0X:2P0S8b<08b<S0040;Vi^@040:b/[02GUiL0UiNG04e=C@80
TI6A00D0WIfM08b<S02:RXX0RXZ:08j>SP020820P00504e=C@1FEUH0EEEE05EEE@1UIFD00P23Ph<0
1@2?Shl0PX:203<c<`0c<c<0SHf=0080[Zj^00D0WIfM09NGU`2GUiL0XJ6Q09bLW00204=3@`0507Ee
M@2YZJT0ZJVY0;6a/@2`/;000P2c/k<0102h^;P0EEEE05EEE@2QXJ4208f=S@0506ATI01MGEd0EUIF
05IFEP1ADE400P18B4P01@2g]kL0^KVi0;Rh^02h^;P0][Jf0080/[:b00D0JFUY05]KF`1KFe/0YjNW
0;Jf]P020;Ng]`050;bl_02[Zj/0Zj^[0492@P29RHT00P2e]KD30;Bd]0050;Zj^P2^[Zh0@d=304=3
@`2j^[X00P2o_kl01@34a<@0aLG50<G5a@2;Rh/0Ph>30080^[Zj00D0/[:b0:RXZ02XZ:P0Y:BT08b<
S002059BDP040:6QX@2ZZZX0ZZZZ0:FUY@80Zj^[00D0ZZZZ0:BTY01FEUH0EUIF0:n_[`020;Bd]005
0;bl_02i^KT0/k>c0;>c/`1<C4`00P1/K6`00`2PX:00Ti>C092@T002092@T080UYJF00D0GemO04Q8
B018B4P0R8R8096AT@020:>SX`050:6QX@29RHT0RHV903/k>`1^KVh00P2=SHd0102IVIT0V9RH09RH
V02IVIT208n?S`0503Hf=P1QHF40SXj>08j>SP2IVIT00P2RXZ800`2LW9`0oooo0?ooo`0?0?ooo`04
05iNGP2CTi<0Ti>C06][J`80B4Q800D0MWIf08V9R@29RHT0Kfm_05IFEP020861P@0507emO@2DU9@0
U9BD0861P@1kNg/00P1RHV80101HF5P0J6QX06QXJ01XJ6P208V9R@050:FUY@1BDU80D51@051@D01E
EED00P19BDT01@1jNWX0DU9B059BDP2GUiL0WIfM0080U9BD00@0Xj>S07=cL`1cLg<0MGEe0P1lO7`0
1@1bLW80c<c<08B4Q024Q8@0GUiN0080LG5a00D0JFUY07moO`2YZJT0ZJVY0:b/[0020;6a/@0508Z:
RP21PH40PH6109:BTP23Ph<00P21PH40101CDe<0Lg=c07=cL`2FUYH209VIV@050;no_`2>SXh0WYjN
09jNWP2EUID00P2RXZ801@34a<@0`/;209bLW02LW9`0M7Ad0080ZJVY00D0[Zj^0:f][@2][Jd0NGUi
075aL@0209BDU0040:JVYP1nOWh0OWin08R8R080QXJ600D0_Kfm0:^[Z`1SHf<0Hf=S06YZJP0207Qh
N0050::RXP2`/;00Y:BT0:BTY02FUYH00P1fMWH01@12@T80bLW90<W9b@26QXH0T92@0080OWin00@0
L71`06i^KP1^KVh0WIfM0P35aLD01@24Q8@0QhN70:b/[02/[:`0[Zj^0080KVi^00D0PX:205eMG@1M
GEd0XJ6Q09bLW002055AD@0504=3@`1:BTX0BTY:055AD@1SHf<00P1/K6`0101TI6@0AdM704M7A`1L
G5`205IFEP0507=cL`1@D500K6a/06a/K01<C4`00P1OGel01@1kNg/0XJ6Q0:6QX@25QHD0VIVI0080
Zj^[00D0I6AT08j>SP2>SXh0Ogmo09bLW00205UIF@04079bLP1MGEd0GEeM07emO@80SXj>00<0Kfm_
0?ooo`3oool0203oool000X0oooo00@0[jn_04E5A@15ADD0_[jn0P35aLD01@39bLT0b/[:0;Bd]02d
];@092@T0080QHF500D0[jn_0:f][@2][Jd0/[:b0;Bd]0020:NWY`0502HV9P2BTY80TY:B0;Ng]`2c
/k<00P2d];@0102UYJD0Ti>C09>CT`0j>SX209>CT`040;>c/`2a/K40/k>c0;>c/`<0ZJVY00D0EEEE
03dm?@0m?Cd0?Cdm04];B`0206e]K@0507]kN`1nOWh0@T920492@P28R8P00P2b/[801@2UYJD0UiNG
09NGU`2SXj<0X:2P0080>c/k00D0Ph>30;Ng]`2g]kL0]kNg0;Zj^P030;no_`80Hf=S0`2VYZH01@2@
T900L71`05mOG`1OGel0Bd];0080EUIF00D0]KFe0;Rh^02i^KT0^KVi0;bl_0020;Rh^00506QXJ01d
M7@0M7Ad0;2`/02d];@00P2i^KT01@30`<00^;Rh0;Rh^01;Bd/0U9BD0080];Bd00D0ZZZZ0:j^[P2^
[Zh0^;Rh0;bl_00206QXJ0040;fm_@31`L40`L710<;2`P80b<S800<0/k>c06m_K`2XZ:P00P2XZ:P2
09fMW@050:>SX`2WYjL0H61P061PH02WYjL00P2[Zj/01@2UYJD0XZ:R0::RXP2LW9`0SHf=0080DU9B
00D0]kNg0;^k^`2k^k/0^k^k0;Ng]`020;Rh^00506e]K@1dM7@0M7Ad09FEU@2LW9`00P2@T9001027
QhL0T92@092@T01IFET208F5Q@050:j^[P2f][H0]kNg0;Ng]`2c/k<00P2^[Zh01011@D40WinO0;Vi
^@2i^KT30;Rh^0050;>c/`2][Jd0[Jf]03hn?P2QXJ400P2XZ:P0102/[:`0/;2`0;2`/02`/;0A0?oo
o`0406ATI02NWYh0WYjN06YZJP80A4A400D0K6a/09jNWP2NWYh0Shn?07EeM@0209ZJVP0508^;R`2R
XZ80XZ:R08j>SP1iNGT00P1CDe<0101KFe/0IfMW06MWI`1XJ6P208n?S`0509fMW@1OGel0GEeM05eM
G@1JFUX00P16ATH01@1mOGd0EEEE05EEE@2PX:00UIFE0080QhN700@0[:b/07MgM`1gMgL0MWIf0P21
PH401@1_Kfl0dm?C09bLW02LW9`0I6AT0080NGUi00D0Jf][09fMW@35aLD0aLG50<30`0020<O7a`05
08n?S`2<S8`0S8b<08j>SP1gMgL00P1hN7P0101KFe/0QXJ608J6QP2ATI4209nOW`050;:b/P2LW9`0
YJFU0:FUY@2>SXh00P2IVIT01@3EeMD0];Bd0:VYZ@2YZJT0SXj>0080[Zj^00D0Xj>S08n?S`2?Shl0
OGem07]kN`0209BDU0040:ZZZP26QXH0QXJ609RHV080TI6A00D0_kno0;^k^`1iNGT0NGUi05UIF@02
07alO0050:^[Z`34a<@0Zj^[0:^[Z`2JVYX00P1_Kfl01@0n?Sh0b/[:0<[:bP25QHD0RHV90080PH61
00@0L71`06i^KP1^KVh0YJFU0P37alL01@27QhL0PH6109^KV`2KVi/0Rh^;0080M7Ad00D0C4a<05IF
EP1FEUH0VYZJ08V9R@0204];B`0503<c<`0d=3@0=3@d04];B`1SHf<00P1QHF40101ZJVX0BTY:04Y:
BP1XJ6P205eMG@0506a/K01GEeL0IVIV06IVIP1>CTh00P1IFET01@2EUID0W9bL09bLW02BTY80Rh^;
0080VYZJ00D0Hf=S0:JVYP2VYZH0T92@0:FUY@0205]KF`0406IVIP1WIfL0IfMW07inOP80QHF500<0
M7Ad0?ooo`3oool0203oool000X0oooo00@0/[:b05EEE@1EEED0^;Rh0P31`L401@30`<00a/K60:RX
Z02XZ:P0;Bd]0080Shn?00D0ZJVY0:RXZ02XZ:P0Zj^[0:RXZ00209>CT`05024Q8@2>SXh0SXj>0;>c
/`2b/[800P2/[:`0102GUiL0P8200820P00o?cl209RHV0050;Bd]02[Zj/0[:b/0:b/[02`/;000P2^
[Zh01@1?Cdl0=cLg01LG5`0G5aL06ATI00807QhN00D0@D5104E5A@0c<c<0<c<c08B4Q00209nOW`05
07moO`1jNWX0NWYj09>CT`2JVYX00P19BDT01@1oOgl0ZJVY0:VYZ@2_[jl0/;2`0080^k^k00@0_[jn
06=SH`1SHf<0W9bL0P2[Zj/01@2YZJT0Ph>3079bLP1bLW80GemO0080CTi>00D0/k>c0:j^[P2/[:`0
[:b/0;:b/P020;Bd]00506EUI@1oOgl0Ogmo0:n_[`2d];@00P2e]KD01@2g]kL0ZZZZ0:ZZZP0j>SX0
UYJF0080/K6a00D0[:b/0;:b/P2b/[80]kNg0;Fe]@02061PH0040;Zj^P2m_Kd0_Kfm0;fm_@80a/K6
00D0[jn_075aL@2VYZH0YZJV0:6QX@020:NWY`050:FUY@2GUiL0HV9R069RHP2IVIT00P2UYJD01@2M
WId0UIFE09FEU@24Q8@0QXJ60080AdM700D0/[:b0;Fe]@2e]KD0/k>c0:j^[P020;2`/00506=SH`1T
I6@0I6AT08Z:RP22PX800P1oOgl0101kNg/0MGEe07EeM@18B4P208R8R0050;:b/P2f][H0^;Rh0;Rh
^02g]kL00P2`/;001@0f=SH0Y:BT0;>c/`2c/k<0^;Rh0080][Jf00D0/K6a0:RXZ02XZ:P0=cLg09RH
V0020:FUY@040:f][@2[Zj/0Zj^[0:NWYa40oooo00@0IFEU096AT@2ATI40LW9b0P16ATH01@1/K6`0
OWin07inOP28R8P0QHF50080Vi^K00D0P82008n?S`2?Shl0PX:206e]K@0205]KF`0404m?C`1YJFT0
JFUY04m?C`80MGEe00D0S8b<05UIF@1IFET0FEUI055AD@0204=3@`0506=SH`1CDe<0De=C09JFUP2;
Rh/00P23Ph<0102SXj<0LG5a075aL@1OGel207=cL`0506e]K@3:b/X0Ph>308>3P`1ZJVX00P26QXH0
1@1MGEd0R8R80;fm_@2m_Kd0]kNg0080`L7100@0TY:B09^KV`2KVi/0T92@0`21PH40101EEED0P820
0820P021PH420:^[Z`0509ZJVP2HV9P0Ti>C09>CT`2>SXh00P21PH401@3Jf]X0]KFe0;Zj^P2j^[X0
Shn?00<0`/;20P2NWYh01@1oOgl0Lg=c07UiN@1iNGT0TI6A0080PH6100D0VYZJ08j>SP2>SXh0]kNg
0;Jf]P02079bLP0505IFEP2DU9@0U9BD0:ZZZP2m_Kd00P2o_kl0102PX:00NGUi07UiN@13@d<20=KF
eP80SHf=0P1mOGd0101^KVh0K6a/06a/K02NWYh20;Rh^00508b<S02;Rh/0WYjN09jNWP27QhL00P2C
Ti<01@1ZJVX0GEeM05eMG@2BTY80UiNG0080E5AD00D0?Shn03/k>`0k>c/0Fe]K05YJFP0205UIF@04
06IVIP1<C4`0C4a<06MWI`80G5aL00D0Q8B404E5A@1MGEd0GEeM061PH00204E5A@0507QhN02PX:00
X:2P08n?S`25QHD00P2LW9`01@1_Kfl0ZJVY0:VYZ@25QHD0ZZZZ0080EEEE00@0GemO07AdM01dM7@0
QhN70`2=SHd:0?ooo`002P3oool0102b/[80EEEE05EEE@2h^;P20<71`@050<30`036a/H0Z:RX0:RX
Z00];Bd00P2?Shl01@2YZJT0Z:RX0:RXZ02[Zj/0Z:RX0080Ti>C00D08B4Q08j>SP2>SXh0/k>c0;:b
/P020:b/[00409NGU`20P800P82003lo?`80V9RH00D0];Bd0:^[Z`2/[:`0[:b/0;2`/0020:j^[P05
04m?C`0g=cL05aLG01LG5`0I6AT00P0N7Qh01@11@D40ADE503<c<`0c<c<0Q8B40080WinO00D0Ogmo
07YjNP1jNWX0Ti>C09ZJVP0204U9B@0507moO`2YZJT0ZJVY0:n_[`2`/;000P2k^k/0102n_[h0Hf=S
06=SH`2LW9`20:^[Z`050:VYZ@23Ph<0LW9b079bLP1OGel00P1>CTh01@2c/k<0[Zj^0:b/[02/[:`0
/[:b0080];Bd00D0IFEU07moO`1oOgl0[jn_0;Bd]0020;Fe]@050;Ng]`2ZZZX0ZZZZ03Xj>P2FUYH0
0P2a/K401@2/[:`0/[:b0;:b/P2g]kL0]KFe0080H61P00@0^[Zj0;fm_@2m_Kd0_Kfm0P36a/H01@2_
[jl0LG5a0:JVYP2VYZH0XJ6Q0080YjNW00D0YJFU09NGU`1RHV80HV9R09VIV@020:FUY@0509fMW@2E
UID0UIFE08B4Q026QXH00P17AdL01@2b/[80]KFe0;Fe]@2c/k<0[Zj^0080/;2`00D0Hf=S06ATI01T
I6@0RXZ:08:2PP0207moO`0407]kN`1eMGD0MGEe04Q8B080R8R800D0/[:b0;Jf]P2h^;P0^;Rh0;Ng
]`020;2`/00503Hf=P2TY:@0/k>c0;>c/`2h^;P00P2f][H01@2a/K40Z:RX0:RXZ00g=cL0V9RH0080
YJFU00@0[Jf]0:^[Z`2[Zj/0YjNW4@3oool0101UIFD0TI6A096AT@1bLW8204I6AP0506a/K01nOWh0
OWin08R8R025QHD00P2KVi/01@20P800Shn?08n?S`22PX80KFe]0080Fe]K00@0Cdm?06UYJ@1YJFT0
Cdm?0P1eMGD01@2<S8`0FEUI05UIF@1IFET0DE5A0080@d=300D0Hf=S05=CD`1CDe<0UYJF08^;R`02
08>3P`040:>SX`1aLG40LG5a05mOG`80Lg=c00D0KFe]0<[:bP23Ph<0Ph>306YZJP0208J6QP0505eM
G@28R8P0_Kfm0;fm_@2g]kL00P31`L40102BTY80Vi^K09^KV`2@T9030861P@0405EEE@20P800P820
0861P@80Zj^[00D0VYZJ09RHV02CTi<0Ti>C08j>SP020861P@050=[JfP2e]KD0^[Zj0;Zj^P2?Shl0
0`32`/8209jNWP0507moO`1cLg<0NGUi07UiN@2ATI400P21PH401@2JVYX0SXj>08j>SP2g]kL0][Jf
0080LW9b00D0EUIF09BDU02DU9@0ZZZZ0;fm_@020;no_`040:2PX01iNGT0NGUi04=3@`80e]KF0P2=
SHd207emO@0406i^KP1/K6`0K6a/09jNWP80^;Rh00D0S8b<08^;R`2NWYh0WYjN08N7Q`0209>CT`05
06YZJP1MGEd0GEeM09:BTP2GUiL00P1DE5@01@0n?Sh0>c/k03/k>`1KFe/0FUYJ0080FEUI00@0IVIV
04a<C01<C4`0IfMW0P1LG5`01@24Q8@0ADE505eMG@1MGEd0H61P0080ADE500D0N7Qh0:2PX02PX:00
Shn?08F5Q@0209bLW00506m_K`2YZJT0ZJVY08F5Q@2ZZZX00P1EEED0101OGel0M7Ad07AdM027QhL3
08f=S@X0oooo000:0?ooo`0408B4Q00c<c<0<c<c07alO080QHF500D0OWin08:2PP1fMWH0MWIf03dm
?@0205aLG00507moO`1jNWX0NWYj07IfMP27QhL00P1kNg/01@0Z:RX0GemO05mOG`1]KFd0LG5a0080
Fe]K00@0De=C05mOG`1OGel0ADE50P1RHV801@1hN7P0PX:208:2PP22PX80QXJ60080SHf=00D0ATI6
03hn?P0/;2`0;2`/03/k>`0203`l?0050451@@1DE5@0@4100410@01SHf<00P1TI6@01@1;Bd/0EEEE
05EEE@1PH600JFUY0080AdM700D0HF5Q07alO01lO7`0LW9b071`L0020820P00408N7Q`18B4P0B4Q8
09ZJVP80UiNG00D0M7Ad06ATI013@d<0@d=3065QH@0204M7A`0509>CT`2;Rh/0OWin07inOP1kNg/0
0P28R8P01@1FEUH0JFUY06UYJ@20P800Ph>30080Ti>C00D0X:2P08:2PP22PX80=cLg08R8R00209BD
U00509nOW`2PX:00X:2P0:^[Z`2TY:@00P1JFUX0102GUiL0VIVI09VIV@2e]KD20;Jf]P050:2PX01/
K6`0Z:RX0:RXZ02WYjL00P2TY:@01@2WYjL0W9bL05YJFP1JFUX0UYJF0080WinO00D0V9RH09>CT`2C
Ti<0QHF507moO`0204m?C`050:ZZZP2_[jl0[jn_0:ZZZP2TY:@00P2WYjL01@1DE5@0CTi>04i>CP29
RHT0R8R80080O7al00@0NGUi06e]K@1]KFd0CTi>0P2BTY801@2h^;P0a<C40;bl_02l_;`0^KVi0080
/k>c00D0:b/[0:2PX02f][H0][Jf0;^k^`020;Zj^P050;Vi^@2a/K40/K6a03Ti>@2TY:@00P2VYZH0
102XZ:P0/;2`0;2`/02^[ZhA0?ooo`0406UYJ@2^[Zh0[Zj^07alO080EEEE00D0RXZ:0:FUY@2UYJD0
Ti>C07MgM`0209bLW00507inOP2ATI40TI6A07moO`20P8000P1ADE40100o?cl0G5aL05aLG01NGUh2
07=cL`0507QhN01DE5@0GEeM05eMG@1?Cdl00P11@D401@1oOgl0HV9R069RHP2OWil0SHf=0080T92@
00@0Xj>S06][J`1[Jf/0IFEU0P1PH6001@1MGEd0aLG508f=S@2=SHd0IVIV0080Ng]k00D0FUYJ07=c
L`2][Jd0[Jf]0;Fe]@020;6a/@0508B4Q02>SXh0SXj>08Z:RP1nOWh00P2;Rh/0101`L700Shn?08n?
S`28R8P20;2`/0050:>SX`2FUYH0T92@092@T02IVIT00P1iNGT01@3Ogml0ZJVY0:b/[02/[:`0QHF5
0080`L7100D0_[jn09NGU`2GUiL0MgMg07=cL`0208B4Q00409JFUP21PH40PH610:j^[P80QhN700D0
[jn_0;fm_@1fMWH0MWIf05QHF002096AT@050:b/[02i^KT0Xj>S0:>SX`1jNWX00P1[Jf/01@0o?cl0
clo?0<o?c`2GUiL0RXZ:0080RHV900@0N7Qh07inOP1nOWh0^;Rh0P3=cLd01@2EUID0UYJF0:BTY02T
Y:@0QHF50080Y:BT00D0HV9R08f=S@2=SHd0XZ:R09jNWP0204i>CP0503Lg=`0e=CD0=CDe04m?C`1F
EUH00P1:BTX0101[Jf/0FEUI05UIF@1RHV8205=CD`0508V9R@13@d<0D51@051@D01NGUh00P1?Cdl0
1@1fMWH0S8b<08b<S02IVIT0RXZ:0080R8R800D0O7al0;Ng]`2g]kL0VIVI09:BTP02069RHP0405aL
G01iNGT0NGUi08Z:RP80Q8B400<0Lg=c0?ooo`3oool0203oool000X0oooo00@0R8R807]kN`1kNg/0
N7Qh0P1bLW801@11@D40Fe]K071`L01`L700NGUi0080OWin00D0Kfm_06e]K@1]KFd0L71`07UiN@02
06YZJP0506QXJ01HF5P0F5QH05EEE@1HF5P00P0n?Sh01017AdL0J6QX06QXJ01_Kfl206QXJ00505iN
GP1LG5`0Bd];04];B`1EEED00P1KFe/01@1JFUX0FEUI05iNGP1NGUh0D51@0080?3`l00D0BDU906=S
H`1ZJVX0JVYZ06][J`02069RHP<0G5aL0P1OGel2069RHP0505mOG`1HF5P0F5QH05iNGP16ATH00P0j
>SX0101ADE40EeMG05MGE`1EEED305aLG00405]KF`1MGEd0GEeM069RHP80H61P00D0GemO06UYJ@1R
HV80HV9R04i>CP0205EEE@<0Fe]K00D0EUIF04e=C@16ATH0ATI604a<C00204I6AP05059BDP1RHV80
HV9R069RHP1VIVH00P1QHF401@1=CDd0BTY:0492@P12@T80>c/k0080A4A400D0C4a<04Q8B018B4P0
?Shn04];B`0205IFEP0504Y:BP1?Cdl0Cdm?055AD@1KFe/00P1CDe<0101VIVH0I6AT06ATI01QHF42
05YJFP0506ATI01KFe/0De=C05=CD`1lO7`00P1cLg<01@1]KFd0JVYZ06IVIP1VIVH0C4a<0080@410
00D0GemO06IVIP1LG5`0G5aL05eMG@0205UIF@0504a<C01ZJVX0JVYZ07QhN025QHD00P23Ph<01@1f
MWH0N7Qh07QhN011@D40Kfm_0080Ng]k00@0PH6107EeM@1eMGD0MgMg0P1aLG401@0o?cl0N7Qh07al
O01lO7`0NGUi0080Ph>300<0OWin0?ooo`3oool03`3oool0101DE5@0Ti>C09>CT`1UIFD204A4A005
07YjNP2PX:00X:2P0:2PX024Q8@00P2EUID01@2=SHd0OGem07emO@1nOWh0Kfm_0080EeMG00@0ATI6
05aLG01LG5`0GUiN0P20P8001@24Q8@0B4Q806EUI@1UIFD0FEUI0080AdM700D0PX:207IfMP1fMWH0
XZ:R08f=S@0209FEU@040:f][@1jNWX0NWYj06m_K`80JVYZ00D0GEeM0;bl_025QHD0QHF507EeM@02
07]kN`05065QH@2>SXh0^KVi0;Vi^@35aLD00P2k^k/01@29RHT0WIfM09fMW@2@T900Ph>30080T92@
00@0N7Qh07YjNP1jNWX0MgMg0P2WYjL209VIV@80K6a/00D0TI6A05iNGP1NGUh0f=SH0:FUY@020:JV
YP0409JFUP2k^k/0^k^k0;fm_@80PH6100D0K6a/065QH@1kNg/0Ng]k08F5Q@0207EeM@050:2PX01]
KFd0KFe]09VIV@2PX:000P1bLW801@1ADE40S8b<08b<S02][Jd0^k^k0080YZJV00@0Shn?06][J`1[
Jf/0@d=30P3Bd]801@2FUYH0Ogmo0820P020P800Kfm_0080LW9b00D0[Zj^0<?3``33`l<0WinO09ZJ
VP020;:b/P0408n?S`2e]KD0]KFe07AdM080TY:B00D0WYjN08b<S016ATH0ATI603De=@0203<c<`05
04=3@`1<C4`0ATI604I6AP1^KVh00P1ZJVX01@1DE5@0Cdm?04m?C`23Ph<0B4Q80080BTY:00@0M7Ad
05IFEP1FEUH0NWYj0P2BTY8208Z:RP80Rh^;00D0R8R80:ZZZP2ZZZX0WIfM09jNWP0205iNGP0405EE
E@1lO7`0O7al06YZJP80JFUY00<0Jf][0?ooo`3oool0203oool000X0oooo00@0R8R807]kN`1kNg/0
N7Qh0P1bLW801@11@D40Fe]K071`L01`L700NGUi0080OWin00D0Kfm_06e]K@1]KFd0L71`07UiN@02
06YZJP0506QXJ01HF5P0F5QH05EEE@1HF5P00P0n?Sh01017AdL0J6QX06QXJ01_Kfl206QXJ00505iN
GP1LG5`0Bd];04];B`1EEED00P1KFe/01@1JFUX0FEUI05iNGP1NGUh0D51@0080?3`l00D0BDU906=S
H`1ZJVX0JVYZ06][J`02069RHP<0G5aL0P1OGel2069RHP0505mOG`1HF5P0F5QH05iNGP16ATH00P0j
>SX0101ADE40EeMG05MGE`1EEED305aLG00405]KF`1MGEd0GEeM069RHP80H61P00D0GemO06UYJ@1R
HV80HV9R04i>CP0205EEE@<0Fe]K00D0EUIF04e=C@16ATH0ATI604a<C00204I6AP05059BDP1RHV80
HV9R069RHP1VIVH00P1QHF401@1=CDd0BTY:0492@P12@T80>c/k0080A4A400D0C4a<04Q8B018B4P0
?Shn04];B`0205IFEP0504Y:BP1?Cdl0Cdm?055AD@1KFe/00P1CDe<0101VIVH0I6AT06ATI01QHF42
05YJFP0506ATI01KFe/0De=C05=CD`1lO7`00P1cLg<01@1]KFd0JVYZ06IVIP1VIVH0C4a<0080@410
00D0GemO06IVIP1LG5`0G5aL05eMG@0205UIF@0504a<C01ZJVX0JVYZ07QhN025QHD00P23Ph<01@1f
MWH0N7Qh07QhN011@D40Kfm_0080Ng]k00@0PH6107EeM@1eMGD0MgMg0P1aLG401@0o?cl0N7Qh07al
O01lO7`0NGUi0080Ph>300<0OWin0?ooo`3oool03`3oool0101DE5@0Ti>C09>CT`1UIFD204A4A005
07YjNP2PX:00X:2P0:2PX024Q8@00P2EUID01@2=SHd0OGem07emO@1nOWh0Kfm_0080EeMG00@0ATI6
05aLG01LG5`0GUiN0P20P8001@24Q8@0B4Q806EUI@1UIFD0FEUI0080AdM700D0PX:207IfMP1fMWH0
XZ:R08f=S@0209FEU@040:f][@1jNWX0NWYj06m_K`80JVYZ00D0GEeM0;bl_025QHD0QHF507EeM@02
07]kN`05065QH@2>SXh0^KVi0;Vi^@35aLD00P2k^k/01@29RHT0WIfM09fMW@2@T900Ph>30080T92@
00@0N7Qh07YjNP1jNWX0MgMg0P2WYjL209VIV@80K6a/00D0TI6A05iNGP1NGUh0f=SH0:FUY@020:JV
YP0409JFUP2k^k/0^k^k0;fm_@80PH6100D0K6a/065QH@1kNg/0Ng]k08F5Q@0207EeM@050:2PX01]
KFd0KFe]09VIV@2PX:000P1bLW801@1ADE40S8b<08b<S02][Jd0^k^k0080YZJV00@0Shn?06][J`1[
Jf/0@d=30P3Bd]801@2FUYH0Ogmo0820P020P800Kfm_0080LW9b00D0[Zj^0<?3``33`l<0WinO09ZJ
VP020;:b/P0408n?S`2e]KD0]KFe07AdM080TY:B00D0WYjN08b<S016ATH0ATI603De=@0203<c<`05
04=3@`1<C4`0ATI604I6AP1^KVh00P1ZJVX01@1DE5@0Cdm?04m?C`23Ph<0B4Q80080BTY:00@0M7Ad
05IFEP1FEUH0NWYj0P2BTY8208Z:RP80Rh^;00D0R8R80:ZZZP2ZZZX0WIfM09jNWP0205iNGP0405EE
E@1lO7`0O7al06YZJP80JFUY00<0Jf][0?ooo`3oool0203oool000X0oooo00@0];Bd0;2`/02`/;00
YjNW0P2OWil00`12@T80U9BD0:^[Z`020:^[Z`80[:b/00D0YJFU0;:b/P2b/[80];Bd0;Fe]@020;2`
/0050:ZZZP2TY:@0Y:BT09FEU@2MWId00P1ZJVX0101nOWh0];Bd0;Bd]02[Zj/20:JVYP040:2PX02]
[Jd0[Jf]0:f][@<0[:b/00D0Z:RX0:ZZZP2^[Zh0[Zj^0;2`/00207=cL`0308^;R`2a/K40/K6a0080
/K6a0P2[Zj/01@2^[Zh0YZJV0:JVYP2VYZH0ZJVY0080YZJV00D0[:b/0:VYZ@2YZJT0Zj^[07QhN002
071`L0040;Vi^@2m_Kd0_Kfm0;bl_080]KFe00D0^;Rh0;Ng]`2e]KD0]KFe0;6a/@020;Bd]0050;>c
/`2i^KT0]KFe0;Fe]@1YJFT00P2^[Zh30;Jf]P050;Ng]`2c/k<0YZJV0:JVYP2ZZZX00P2`/;001@2n
_[h0^KVi0;Jf]P2f][H0`/;20080a<C40P1BDU820:RXZ0040:VYZ@2d];@0];Bd0;Bd]080/K6a00D0
ZZZZ0:FUY@2NWYh0WYjN08^;R`0207]kN`050451@@2UYJD0[jn_0:n_[`2QXJ400P22PX801@2CTi<0
S8b<08b<S02FUYH0Vi^K0080WYjN00D0WinO09VIV@2IVIT0RHV9069RHP0205IFEP0509FEU@2JVYX0
VYZJ08j>SP2JVYX00P2RXZ80102PX:00PH610861P@2HV9P20:6QX@0509NGU`2FUYH0UIFE09FEU@1B
DU800P20P8001@2LW9`0T92@08B4Q024Q8@0Kfm_0080DE5A00D0EEEE06i^KP1^KVh0RHV906YZJP02
06=SH`04065QH@1?Cdl0Cdm?04m?Ca40oooo00@0IVIV0:2PX02PX:00NGUi0P1ADE401@1oOgl0Xj>S
0:>SX`2OWil0P8200080K6a/00D0OWin06IVIP1VIVH0Lg=c06e]K@0205mOG`0403Xj>P1EEED0EEEE
05iNGP80KFe]00D0JVYZ04I6AP1[Jf/0Jf][05UIF@0204A4A00306QXJ01JFUX0FUYJ0080Ti>C0P2P
X:00102SXj<0O7al07alO01_Kfl206a/K00505YJFP2c/k<0RHV908V9R@1lO7`00P1gMgL01@1JFUX0
Ng]k0:j^[P2^[Zh0a/K60080]KFe00D0RHV908f=S@2=SHd0T92@08:2PP02096AT@0408F5Q@1kNg/0
Ng]k0820P080/[:b00D0UYJF09VIV@23Ph<0Ph>309^KV`0206a/K0050<K6aP2UYJD0WinO09nOW`2T
Y:@00P2][Jd01@31`L40TI6A096AT@1iNGT0MWIf0080QhN700@0P82007=cL`1cLg<0QXJ60P1QHF40
1@2QXJ40ZJVY06][J`1[Jf/0D51@0080P82000D0[Jf]0;Ng]`2JVYX0VYZJ09FEU@0206YZJP0504m?
C`3MgMd0gMgM07inOP1kNg/00P1]KFd0101UIFD0KFe]06e]K@2e]KD20;Rh^00509ZJVP20P800YjNW
0:NWY`2BTY800P2ZZZX01@1LG5`0Shn?08n?S`2NWYh0RHV90080CDe=00D0>CTi02TY:@0Y:BT0@D51
04Y:BP0203hn?P0407emO@1/K6`0K6a/05]KF`80K6a/00D0MGEe06MWI`1?Cdl0Cdm?07QhN00207Ui
N@0507]kN`2IVIT0VIVI09VIV@2>SXh00P24Q8@01@2ATI40VYZJ09ZJVP2JVYX0WinO0080F5QH00@0
GEeM06ATI01TI6@0De=C0P1dM7@00`1_Kfl0oooo0?ooo`080?ooo`002P3oool0102d];@0[Zj^0:j^
[P2[Zj/20:NWY`0503Ph>02GUiL0YjNW0:NWY`2UYJD00P2RXZ801@2KVi/0YZJV0:JVYP2/[:`0Z:RX
00<0YJFU0P2SXj<01@2RXZ80W9bL06QXJ01XJ6P0PH610080[jn_00D0/K6a0:NWY`2WYjL0RHV90:FU
Y@020::RXP050:BTY02WYjL0YjNW09bLW02QXJ400P2][Jd01@2b/[80OGem07emO@2>SXh0][Jf0080
];Bd00@0/[:b0;Jf]P2f][H0/;2`0P2WYjL01@2VYZH0YjNW0:NWY`2WYjL0Zj^[0080YjNW00D0XJ6Q
08b<S02ATI40TI6A0;:b/P020;6a/@050;2`/02^[Zh0[Zj^0;>c/`2e]KD00P2d];@01@2b/[80/K6a
0;6a/@2f][H0]kNg0080][Jf00@0EeMG0:JVYP2VYZH0];Bd0P2`/;001@2a/K40/;2`0:6QX@2QXJ40
XZ:R0080YjNW00D0_kno0<30`030`<00`<300;fm_@020:j^[P0504A4A01jNWX0ZJVY0:VYZ@2_[jl0
0P2f][H01@2h^;P0[Jf]0:f][@2XZ:P0YZJV00<0Xj>S0P21PH401@15ADD0^;Rh0;Rh^02h^;P0_;bl
00<0^KVi0P2g]kL01@2f][H0Zj^[09BDU02DU9@0ZJVY0080/k>c00D0]KFe096AT@1eMGD0MGEe0;6a
/@020;:b/P050:f][@2d];@0^k^k0;^k^`2n_[h00P2j^[X01@2l_;`0^k^k0;^k^`2g]kL0[:b/0080
];Bd00D0Kfm_0:RXZ02XZ:P0/[:b0:VYZ@0209bLW00409nOW`2e]KD0]KFe0;Rh^080/k>c00D0];Bd
0:f][@2a/K40/K6a0;Rh^00207YjNP0306e]K@3oool0oooo00l0oooo00@0IfMW096AT@2ATI40LW9b
0P1VIVH01@21PH40Vi^K09^KV`2LW9`0RHV90080Ng]k00D0UIFE06e]K@1]KFd0OGem07MgM`0206IV
IP0404e=C@1JFUX0FUYJ08>3P`80NWYj00D0HV9R02l_;`1BDU80DU9B04I6AP0204U9B@0508N7Q`1D
E5@0E5AD08V9R@2DU9@00P2SXj<0102TY:@0Ng]k07]kN`1^KVh2071`L00506EUI@30`<00QhN708N7
Q`22PX800P1_Kfl01@1KFe/0Q8B40;Rh^02h^;P0e]KF0080[Zj^00D0KFe]0820P020P800RHV907Qh
N00209BDU0040820P01]KFd0KFe]06EUI@80XZ:R00D0Lg=c0:^[Z`2IVIT0VIVI0:NWY`0205mOG`05
0=CDe02NWYh0U9BD09BDU02QXJ400P2JVYX01@2f][H0TY:B09:BTP1gMgL0OWin0080SHf=00@0SXj>
08:2PP22PX80S8b<0P1cLg<01@2NWYh0YjNW07IfMP1fMWH0KFe]0080MgMg00D0WIfM0:JVYP2FUYH0
UYJF09>CT`02065QH@05055AD@3Jf]X0f][J092@T01cLg<00P1iNGT0101VIVH0N7Qh07QhN030`<02
0;Fe]@050:FUY@27QhL0Xj>S0:>SX`20P8000P2[Zj/01@1SHf<0Ph>308>3P`2?Shl0T92@0080H61P
00D0=3@d02/[:`0[:b/0?clo0451@@0203@d=00405UIF@1VIVH0IVIV05YJFP80IfMW00D0JVYZ061P
H01ADE40DE5A069RHP02071`L00507QhN02MWId0WIfM09FEU@28R8P00P1kNg/01@2;Rh/0YJFU0:FU
Y@2VYZH0RHV90080L71`00@0JVYZ07]kN`1kNg/0G5aL0P1cLg<00`1UIFD0oooo0?ooo`080?ooo`00
2P3oool0102XZ:P0Xj>S0:>SX`2VYZH209nOW`0303Lg=`2JVYX0Xj>S0080Xj>S0P2RXZ801@2NWYh0
WinO09nOW`2UYJD0Z:RX0080ZJVY00D0Xj>S09fMW@2MWId0Xj>S0:2PX00206i^KP0408J6QP2`/;00
/;2`0;Rh^080/k>c00D0UiNG0:JVYP2MWId0WIfM0:2PX0020:VYZ@030:>SX`2UYJD0];Bd0080];Bd
0P2<S8`01@24Q8@0^KVi0;Jf]P2f][H0];Bd0080/k>c00@0[jn_0:JVYP2VYZH0YJFU102ZZZX20:RX
Z0050:f][@1fMWH0Kfm_06m_K`2ZZZX00P2^[Zh01@2a/K40[Jf]0:f][@2`/;00[Jf]0080/;2`00D0
[jn_0;6a/@2a/K40/;2`0;Fe]@020;Ng]`04065QH@2TY:@0Y:BT0:^[Z`80[Zj^00<0ZZZZ0:f][@2U
YJD00P2UYJD20:JVYP050;Bd]02k^k/0_kno0;no_`2n_[h00P2PX:001@0i>CT0Ogmo0:ZZZP2ZZZX0
[Jf]0080[:b/00D0[Zj^0:ZZZP2ZZZX0XZ:R0:FUY@020:>SX`0509BDU024Q8@0Q8B404U9B@2g]kL0
0P2k^k/01033`l<0_[jn0;jn_P32`/820;fm_@050;Zj^P2UYJD0Ti>C09>CT`2_[jl00P2l_;`01@2k
^k/0Ti>C0820P020P800/[:b0080];Bd00<0]KFe0;Vi^@2i^KT00P2i^KT20;Bd]0050;bl_02k^k/0
^k^k0;Rh^02`/;000P2b/[801@1WIfL0YZJV0:JVYP2c/k<0ZZZZ0080T92@00@0U9BD0;Jf]P2f][H0
^[Zj0P2i^KT01@2g]kL0]KFe0;Vi^@2i^KT0^k^k0080O7al00<0MWIf0?ooo`3oool03`3oool0101d
M7@0VYZJ09ZJVP1lO7`205eMG@0507YjNP2@T900T92@09jNWP2QXJ400P1[Jf/01@1oOgl0IVIV06IV
IP1fMWH0Lg=c0080H61P00@0CTi>06ATI01TI6@0Shn?0P2GUiL01@23Ph<0>CTi071`L01`L700LW9b
0080GemO00D0OGem05EEE@1EEED0Shn?08f=S@0209^KV`040::RXP1jNWX0NWYj06][J`80LW9b00D0
FUYJ0<;2`P28R8P0R8R80861P@0207moO`0505eMG@2CTi<0^k^k0;^k^`3Jf]X00P2[Zj/01@1CDe<0
CDe=04e=C@20P800KFe]0080Q8B400@0MWIf06IVIP1VIVH0KVi^0P2a/K401@23Ph<0[Jf]09JFUP2F
UYH0XJ6Q0080FEUI00D0gmoO0::RXP2KVi/0Vi^K0;Rh^00209NGU`050<W9b@2=SHd0SHf=07alO021
PH400P2CTi<0102;Rh/0WinO09nOW`2RXZ820820P0050:NWY`2k^k/0NGUi07UiN@21PH400P1oOgl0
1@2NWYh0ZJVY0:n_[`2_[jl0Rh^;0080F5QH00D0D51@0=;BdP3Bd]80R8R806=SH`0206i^KP0405IF
EP1aLG40LG5a0<_;b`80_[jn00D0ZJVY08>3P`2KVi/0Vi^K08f=S@020;Fe]@0506=SH`1nOWh0OWin
09nOW`2TY:@00P1fMWH01@13@d<0?Shn03hn?P1CDe<0DU9B0080@T9200@0Ng]k04a<C01<C4`0Cdm?
0P1[Jf/01@1VIVH0EUIF04E5A@15ADD0A4A40080D51@00D0Ogmo0:6QX@2QXJ40UiNG08V9R@02096A
T@0508j>SP1oOgl0Ogmo09FEU@1nOWh00P1^KVh0101bLW80QXJ608J6QP1SHf<2075aL@0307MgM`3o
ool0oooo00P0oooo000:0?ooo`040:RXZ02SXj<0Xj>S0:JVYP80WinO00<0=cLg09ZJVP2SXj<00P2S
Xj<20::RXP0509jNWP2OWil0WinO0:FUY@2XZ:P00P2YZJT01@2SXj<0WIfM09fMW@2SXj<0X:2P0080
KVi^00@0QXJ60;2`/02`/;00^;Rh0P2c/k<01@2GUiL0YZJV09fMW@2MWId0X:2P0080ZJVY00<0Xj>S
0:FUY@2d];@00P2d];@208b<S00508B4Q02i^KT0][Jf0;Jf]P2d];@00P2c/k<0102_[jl0YZJV0:JV
YP2UYJD40:ZZZP80Z:RX00D0[Jf]07IfMP1_Kfl0Kfm_0:ZZZP020:j^[P050;6a/@2][Jd0[Jf]0;2`
/02][Jd00P2`/;001@2_[jl0/K6a0;6a/@2`/;00]KFe0080]kNg00@0HF5Q0:BTY02TY:@0Zj^[0P2^
[Zh00`2ZZZX0[Jf]0:FUY@020:FUY@80YZJV00D0];Bd0;^k^`2o_kl0_kno0;jn_P020:2PX00503Ti
>@1oOgl0ZZZZ0:ZZZP2][Jd00P2/[:`01@2^[Zh0ZZZZ0:ZZZP2RXZ80YJFU0080Xj>S00D0U9BD08B4
Q024Q8@0BDU90;Ng]`020;^k^`040<?3``2n_[h0_[jn0<;2`P80_Kfm00D0^[Zj0:FUY@2CTi<0Ti>C
0:n_[`020;bl_0050;^k^`2CTi<0P8200820P02b/[800P2d];@00`2e]KD0^KVi0;Vi^@020;Vi^@80
];Bd00D0_;bl0;^k^`2k^k/0^;Rh0;2`/0020;:b/P0506MWI`2VYZH0YZJV0;>c/`2ZZZX00P2@T900
102DU9@0][Jf0;Jf]P2j^[X20;Vi^@050;Ng]`2e]KD0^KVi0;Vi^@2k^k/00P1lO7`00`1fMWH0oooo
0?ooo`0?0?ooo`0407AdM02JVYX0VYZJ07alO080GEeM00D0NWYj092@T02@T900WYjN0:6QX@0206][
J`0507moO`1VIVH0IVIV07IfMP1cLg<00P1PH600101>CTh0I6AT06ATI02?Shl209NGU`0508>3P`0i
>CT0L71`071`L01bLW800P1OGel01@1mOGd0EEEE05EEE@2?Shl0SHf=0080Vi^K00@0XZ:R07YjNP1j
NWX0Jf][0P1bLW801@1JFUX0`/;208R8R028R8P0PH610080Ogmo00D0GEeM09>CT`2k^k/0^k^k0=[J
fP020:^[Z`0505=CD`1=CDd0CDe=0820P01]KFd00P24Q8@0101fMWH0IVIV06IVIP1^KVh20;6a/@05
08>3P`2][Jd0UYJF09JFUP2QXJ400P1IFET01@3Ogml0XZ:R09^KV`2KVi/0^;Rh0080UiNG00D0bLW9
08f=S@2=SHd0O7al0861P@0209>CT`0408^;R`2OWil0WinO0::RXP80P82000D0YjNW0;^k^`1iNGT0
NGUi0861P@0207moO`0509jNWP2YZJT0[jn_0:n_[`2;Rh/00P1HF5P01@1@D500d];B0=;BdP28R8P0
Hf=S0080KVi^00@0EUIF075aL@1aLG40bl_;0P2n_[h01@2YZJT0Ph>309^KV`2KVi/0SHf=0080]KFe
00D0Hf=S07inOP1nOWh0WinO0:BTY00207IfMP0504=3@`0n?Sh0?Shn05=CD`1BDU800P12@T80101k
Ng/0C4a<04a<C01?Cdl206][J`0506IVIP1FEUH0ADE504E5A@14A4@00P1@D5001@1oOgl0XJ6Q0:6Q
X@2GUiL0RHV90080TI6A00D0SXj>07moO`1oOgl0UIFE07inOP0206i^KP04079bLP26QXH0QXJ606=S
H`80LG5a00<0MgMg0?ooo`3oool0203oool000X0oooo00@0/K6a0;>c/`2c/k<0/;2`0P2b/[801@1G
EeL0XZ:R0::RXP2RXZ80Xj>S0080XZ:R00D0TY:B09ZJVP2JVYX0VIVI0:RXZ0020:b/[0050:NWY`2Q
XJ40XJ6Q0:>SX`2PX:000P1RHV801020P800ZJVY0:VYZ@2_[jl20;2`/00509^KV`2][Jd0XJ6Q0:6Q
X@2VYZH00P2YZJT01@2RXZ80W9bL0::RXP2RXZ80[jn_0080Ogmo00D0OWin0:n_[`2a/K40/K6a0;Jf
]P020;Bd]0050;>c/`2/[:`0[:b/0:FUY@2][Jd00P2[Zj/01@2/[:`0Z:RX0:RXZ02OWil0FEUI0080
Fe]K00@0XZ:R0:ZZZP2ZZZX0ZZZZ0P2XZ:P01@2WYjL0Z:RX0:FUY@2UYJD0ZJVY0080ZZZZ00D0[Zj^
0;>c/`2f][H0][Jf06i^KP030:>SX`80YZJV00D0YjNW0:RXZ02YZJT0ZJVY0:f][@020:ZZZP050;Bd
]02i^KT0^[Zj0;Zj^P2k^k/00P2_[jl01@1=CDd0MWIf0:RXZ02XZ:P0YjNW0080[Jf]00D0Zj^[0:f]
[@2][Jd0ZJVY0:FUY@0208n?S`0508R8R023Ph<0Ph>305eMG@2a/K400P2f][H0102h^;P0][Jf0;Jf
]P2l_;`20;Ng]`050;bl_02XZ:P0Z:RX0:RXZ02h^;P00P31`L401@2m_Kd0UiNG08>3P`23Ph<0/[:b
0080/k>c00D0^;Rh0;Vi^@2j^[X0^[Zj0;Vi^@020;>c/`050;Fe]@2i^KT0^KVi0;>c/`2][Jd00P2`
/;001@1MGEd0Xj>S0:>SX`2c/k<0ZJVY0080PX:200@0MGEe0:>SX`2SXj<0[jn_0P2b/[801@2][Jd0
];Bd0;Bd]02d];@0]kNg0080RXZ:00<0P8200?ooo`3oool03`3oool0101UIFD0SHf=08f=S@1fMWH2
04Y:BP0508>3P`2PX:00X:2P09fMW@20P8000P1hN7P01@1jNWX0EUIF05IFEP1dM7@0Lg=c0080Fe]K
00@0<c<c03/k>`0k>c/0J6QX0P1oOgl01@1dM7@0<c<c05YJFP1JFUX0Hf=S0080DU9B00D0MWIf05YJ
FP1JFUX0TI6A09BDU0020:^[Z`040;Bd]02ATI40TI6A07AdM080K6a/00D0CDe=0;Zj^P2;Rh/0Rh^;
0820P00208B4Q00505YJFP2?Shl0];Bd0;Bd]03AdM400P2NWYh01@1jNWX0G5aL05aLG01mOGd0LG5a
0080QHF500@0Ti>C05mOG`1OGel0K6a/0P2a/K401@2;Rh/0YZJV09FEU@2EUID0Zj^[0080G5aL00D0
bl_;09BDU02BTY80TY:B0:JVYP0208V9R@050;bl_027QhL0QhN707=cL`1VIVH00P1iNGT0101cLg<0
R8R808R8R02GUiL207MgM`050:FUY@2YZJT0LW9b079bLP21PH400P1lO7`01@2@T900X:2P0;Vi^@2i
^KT0UYJF0080LG5a00D0HV9R0>7Qh@3QhN40Ti>C06ATI00208N7Q`0406MWI`1oOgl0Ogmo0=GEe@80
`<3000D0]KFe07emO@2NWYh0WYjN0861P@020;Ng]`05079bLP1mOGd0OGem09fMW@2WYjL00P1gMgL0
1@0k>c/0>SXj03Xj>P16ATH0CTi>0080@41000@0NWYj05eMG@1MGEd0D51@0P1GEeL01@1@D500Fe]K
06=SH`1SHf<0Fe]K0080D51@00D0Jf][0::RXP2RXZ80RHV909fMW@020:FUY@0509:BTP2HV9P0V9RH
0;bl_029RHT00P1mOGd0101/K6`0MgMg07MgM`1ADE4207moO`03075aL@3oool0oooo00P0oooo000:
0?ooo`0306EUI@1GEeL0EeMG00<0B4Q800D0<C4a0410@01;Bd/0Bd];055AD@02059BDP0504Y:BP0n
?Sh0?Shn02TY:@1;Bd/00P1SHf<01@1KFe/0CDe=04e=C@17AdL0?clo0080?Shn00@0Bd];05EEE@1E
EED0JVYZ0P1PH6000`1DE5@0A4A403Ph>00203Ph>080>CTi00D0<C4a03Ph>015ADD0ADE50410@002
03/k>`0504Y:BP1IFET0FUYJ05YJFP1UIFD00P1WIfL01@1GEeL0@T920492@P0l?3`0De=C0080DE5A
00D0CDe=0451@@11@D40?clo03Hf=P0202/[:`0405ADE01ADE40DE5A059BDP80?Shn00D0@d=303Ti
>@0e=CD0=CDe04U9B@020451@@05059BDP1=CDd0CDe=04e=C@0g=cL00P1RHV80101WIfL0HF5Q065Q
H@1SHf<306e]K@05075aL@1ZJVX0JVYZ071`L01VIVH00P1[Jf/01@1XJ6P0De=C05=CD`0/;2`0B4Q8
0080IVIV00@0HF5Q05]KF`1KFe/0IVIV0P1MGEd01@1HF5P0C4a<05eMG@1MGEd0IFEU0080HF5Q00D0
>CTi061PH01[Jf/0Jf][07=cL`02075aL@0507]kN`1eMGD0MGEe07alO01_Kfl00P1gMgL01@20P800
QHF508F5Q@23Ph<0JFUY0080EEEE00D0NWYj07alO01lO7`0Ph>30820P0020861P@0407emO@21PH40
PH6107YjNP80PX:200D0OWin07QhN01iNGT0NGUi04Y:BP0207]kN`0507UiN@1RHV80De=C05=CD`1D
E5@00P1QHF401@1aLG40NWYj07YjNP1jNWX0PX:20080SHf=00@0R8R806EUI@1UIFD0HV9R4@3oool0
101WIfL0QHF508F5Q@1dM7@204I6AP0508j>SP2QXJ40XJ6Q09^KV`2?Shl00P2FUYH01@1mOGd0IVIV
06IVIP25QHD0Ogmo0080HF5Q00@0ADE504m?C`1?Cdl0Jf][0P2ATI401@1[Jf/0<C4a05mOG`1OGel0
JVYZ0080IFEU00D0RXZ:065QH@1QHF40UiNG09VIV@020:JVYP040;2`/02;Rh/0Rh^;06][J`80K6a/
00D0EeMG0<?3``28R8P0R8R807alO00208b<S00504m?C`2@T900_;bl0;bl_03Fe]H00P2OWil01@1b
LW80HF5Q065QH@24Q8@0NWYj0080QhN700@0RXZ:05]KF`1KFe/0JVYZ0P2RXZ801@23Ph<0XJ6Q09>C
T`2CTi<0VIVI0080IfMW00D0gmoO0:>SX`2LW9`0W9bL0;>c/`0209^KV`050<k>cP2>SXh0SXj>08B4
Q01kNg/00P26QXH0101iNGT0Xj>S0:>SX`27QhL205iNGP050:>SX`2d];@0OGem07emO@1nOWh00P1g
MgL01@29RHT0X:2P0:b/[02/[:`0P8200080KVi^00D0HV9R0=cLg03Lg=`0V9RH06m_K`0207]kN`04
06YZJP1gMgL0MgMg0<G5a@80^k^k00D0^KVi0861P@2OWil0WinO07moO`020:VYZ@0507moO`23Ph<0
Ph>30::RXP2a/K400P1nOWh01@14A4@0@4100410@01PH600JVYZ0080FUYJ00@0RXZ:07AdM01dM7@0
Hf=S0P1TI6@01@1JFUX0HV9R05iNGP1NGUh0AdM70080@D5100D0P82009^KV`2KVi/0XZ:R08n?S`02
0:>SX`0507inOP24Q8@0Q8B40;6a/@20P8000P2FUYH0101YJFT0MgMg07MgM`1LG5`207YjNP0307]k
N`3oool0oooo00P0oooo000:0?ooo`0306EUI@1GEeL0EeMG00<0B4Q800D0<C4a0410@01;Bd/0Bd];
055AD@02059BDP0504Y:BP0n?Sh0?Shn02TY:@1;Bd/00P1SHf<01@1KFe/0CDe=04e=C@17AdL0?clo
0080?Shn00@0Bd];05EEE@1EEED0JVYZ0P1PH6000`1DE5@0A4A403Ph>00203Ph>080>CTi00D0<C4a
03Ph>015ADD0ADE50410@00203/k>`0504Y:BP1IFET0FUYJ05YJFP1UIFD00P1WIfL01@1GEeL0@T92
0492@P0l?3`0De=C0080DE5A00D0CDe=0451@@11@D40?clo03Hf=P0202/[:`0405ADE01ADE40DE5A
059BDP80?Shn00D0@d=303Ti>@0e=CD0=CDe04U9B@020451@@05059BDP1=CDd0CDe=04e=C@0g=cL0
0P1RHV80101WIfL0HF5Q065QH@1SHf<306e]K@05075aL@1ZJVX0JVYZ071`L01VIVH00P1[Jf/01@1X
J6P0De=C05=CD`0/;2`0B4Q80080IVIV00@0HF5Q05]KF`1KFe/0IVIV0P1MGEd01@1HF5P0C4a<05eM
G@1MGEd0IFEU0080HF5Q00D0>CTi061PH01[Jf/0Jf][07=cL`02075aL@0507]kN`1eMGD0MGEe07al
O01_Kfl00P1gMgL01@20P800QHF508F5Q@23Ph<0JFUY0080EEEE00D0NWYj07alO01lO7`0Ph>30820
P0020861P@0407emO@21PH40PH6107YjNP80PX:200D0OWin07QhN01iNGT0NGUi04Y:BP0207]kN`05
07UiN@1RHV80De=C05=CD`1DE5@00P1QHF401@1aLG40NWYj07YjNP1jNWX0PX:20080SHf=00@0R8R8
06EUI@1UIFD0HV9R4@3oool0101WIfL0QHF508F5Q@1dM7@204I6AP0508j>SP2QXJ40XJ6Q09^KV`2?
Shl00P2FUYH01@1mOGd0IVIV06IVIP25QHD0Ogmo0080HF5Q00@0ADE504m?C`1?Cdl0Jf][0P2ATI40
1@1[Jf/0<C4a05mOG`1OGel0JVYZ0080IFEU00D0RXZ:065QH@1QHF40UiNG09VIV@020:JVYP040;2`
/02;Rh/0Rh^;06][J`80K6a/00D0EeMG0<?3``28R8P0R8R807alO00208b<S00504m?C`2@T900_;bl
0;bl_03Fe]H00P2OWil01@1bLW80HF5Q065QH@24Q8@0NWYj0080QhN700@0RXZ:05]KF`1KFe/0JVYZ
0P2RXZ801@23Ph<0XJ6Q09>CT`2CTi<0VIVI0080IfMW00D0gmoO0:>SX`2LW9`0W9bL0;>c/`0209^K
V`050<k>cP2>SXh0SXj>08B4Q01kNg/00P26QXH0101iNGT0Xj>S0:>SX`27QhL205iNGP050:>SX`2d
];@0OGem07emO@1nOWh00P1gMgL01@29RHT0X:2P0:b/[02/[:`0P8200080KVi^00D0HV9R0=cLg03L
g=`0V9RH06m_K`0207]kN`0406YZJP1gMgL0MgMg0<G5a@80^k^k00D0^KVi0861P@2OWil0WinO07mo
O`020:VYZ@0507moO`23Ph<0Ph>30::RXP2a/K400P1nOWh01@14A4@0@4100410@01PH600JVYZ0080
FUYJ00@0RXZ:07AdM01dM7@0Hf=S0P1TI6@01@1JFUX0HV9R05iNGP1NGUh0AdM70080@D5100D0P820
09^KV`2KVi/0XZ:R08n?S`020:>SX`0507inOP24Q8@0Q8B40;6a/@20P8000P2FUYH0101YJFT0MgMg
07MgM`1LG5`207YjNP0307]kN`3oool0oooo00P0oooo000:0?ooo`040;6a/@2:RXX0RXZ:07UiN@80
VYZJ00D0XZ:R0:VYZ@2/[:`0[:b/09jNWP0209:BTP0508f=S@21PH40PH6102HV9P2VYZH00P2WYjL0
102QXJ40X:2P0:2PX02KVi/309ZJVP0409NGU`2NWYh0WYjN09jNWP80Rh^;00D0Shn?09:BTP1DE5@0
E5AD096AT@0209bLW0050:6QX@2^[Zh0/K6a0;6a/@2c/k<00`2d];@0102f][H0[jn_0:n_[`2_[jl2
0:VYZ@0508V9R@1IFET0FEUI0:JVYP2QXJ400P2WYjL01@2XZ:P0XJ6Q0:6QX@2SXj<0WinO0080UIFE
00@0VYZJ0::RXP2RXZ80Z:RX0P2ZZZX01@1SHf<0>SXj08j>SP2>SXh0V9RH0080WYjN00D0YZJV0:VY
Z@2YZJT0ZJVY0:2PX002092@T00509BDU02SXj<0Xj>S0:f][@2WYjL00P1hN7P01@1VIVH0WIfM09fM
W@2VYZH0Y:BT0080[jn_00D0/K6a0:n_[`2_[jl0[Zj^0:JVYP0209ZJVP040:b/[02f][H0][Jf0;:b
/P80J6QX00D0L71`09^KV`2MWId0WIfM09NGU`0209JFUP0509fMW@2NWYh0WIfM09fMW@2IVIT00`2H
V9P209^KV`0508F5Q@13@d<0Jf][06][J`1hN7P00P1jNWX01@1dM7@0Lg=c07IfMP1fMWH0M7Ad0080
IfMW00D0F5QH05aLG01BDU80DU9B03Lg=`02069RHP0506YZJP1YJFT0JFUY06UYJ@1VIVH00P1/K6`0
1@1_Kfl0EeMG05MGE`1NGUh0K6a/0080Jf][00@0Lg=c05mOG`1OGel0BTY:0P1/K6`01@1[Jf/0JFUY
06MWI`1WIfL0JFUY0080J6QX00<0I6AT0?ooo`3oool03`3oool0101XJ6P0SHf=08f=S@1nOWh204e=
C@0509BDU02IVIT0VIVI09JFUP2:RXX00P2DU9@01@20P800MgMg07MgM`25QHD0PX:20080HV9R00@0
De=C05mOG`1OGel0KVi^0P2CTi<01@1gMgL0=CDe05UIF@1IFET0KVi^0080IFEU00D0MGEe05aLG01L
G5`0SHf=09FEU@020:JVYP040;6a/@2FUYH0UYJF07AdM080L71`00D0GEeM0<[:bP29RHT0RHV908J6
QP0208n?S`0504U9B@2IVIT0`l?30<?3``3Cdm<00P2QXJ401@1]KFd0IVIV06IVIP2=SHd0QHF50080
QXJ600@0R8R805EEE@1EEED0J6QX0P2KVi/01@2<S8`0Shn?08B4Q024Q8@0X:2P0080KVi^00D0fMWI
0;:b/P2GUiL0UiNG0;jn_P0209JFUP050;jn_P1gMgL0MgMg07AdM01aLG400P21PH40101]KFd0X:2P
0:2PX01oOgl205]KF`050:BTY02][Jd0NGUi07UiN@27QhL00P1eMGD01@1oOgl0YJFU0:f][@2][Jd0
O7al0080Lg=c00D0EEEE0>3Ph03Ph>00S8b<06a/K00207AdM00406UYJ@26QXH0QXJ60<?3``80^[Zj
00D0]kNg06m_K`2YZJT0ZJVY0820P00209ZJVP0508F5Q@1kNg/0Ng]k09RHV02i^KT00P1fMWH01@10
@400?3`l03`l?01GEeL0KVi^0080GemO00@0KVi^06e]K@1]KFd0J6QX0P1NGUh01@1GEeL0Jf][069R
HP1RHV80FEUI0080ATI600D0Hf=S096AT@2ATI40WYjN09JFUP020;Jf]P0507MgM`2?Shl0Shn?0:b/
[020P8000P22PX80101MGEd0M7Ad07AdM01bLW8208R8R00307EeM@3oool0oooo00P0oooo000:0?oo
o`040;Bd]02RXZ80XZ:R092@T080Ti>C00D0Y:BT0:RXZ02a/K40/K6a09FEU@0208^;R`050::RXP2L
W9`0W9bL02`/;02KVi/00P2RXZ801@2CTi<0SHf=08f=S@2<S8`0QXJ60080P82000@0Rh^;08V9R@29
RHT0QHF50P1YJFT01@2@T900UiNG03hn?P0n?Sh0Q8B40080S8b<00D0SHf=09jNWP2PX:00X:2P09fM
W@020:JVYP050:NWY`2XZ:P0YjNW0:NWY`2SXj<00P2PX:00102CTi<0KFe]06e]K@2RXZ830:2PX005
0:>SX`2QXJ40XJ6Q0:2PX02KVi/00P2;Rh/0102HV9P0WinO09nOW`2TY:@20:ZZZP0507AdM01ADE40
YJFU0:FUY@2QXJ400P2UYJD01@2YZJT0ZZZZ0:JVYP2VYZH0Xj>S0080V9RH00D0X:2P0:FUY@2UYJD0
[Zj^0;2`/00206m_K`0507UiN@2XZ:P0Z:RX0:VYZ@2[Zj/00P2e]KD00`2b/[80[jn_0:n_[`020;Vi
^@80][Jf00@0];Bd0;Jf]P2f][H0^;Rh0P1_Kfl01@1kNg/0]kNg0;Ng]`2g]kL0/K6a0080[:b/0P2i
^KT20;>c/`040:j^[P2g]kL0]kNg0;bl_080`<3000D0/[:b03dm?@1mOGd0OGem0:NWY`020;>c/`05
0:n_[`2TY:@0W9bL09bLW02JVYX00P2<S8`01@2QXJ40/;2`0;^k^`2k^k/0J6QX0080UIFE00D0^KVi
0;6a/@2a/K40/[:b0;2`/0020;>c/`050:FUY@21PH40PH610::RXP2][Jd00P2ZZZX0102`/;00QHF5
08F5Q@22PX820;Vi^@050<30`02n_[h0`L710<71`@2h^;P00P2i^KT00`2h^;P0oooo0?ooo`0?0?oo
o`0407YjNP2=SHd0SHf=08B4Q080DU9B0`2LW9`01@2>SXh0S8b<08n?S`2?Shl0L71`0080KFe]00D0
J6QX06YZJP1MGEd0GEeM04i>CP0205aLG00506YZJP2@T900T92@06e]K@0b<S800P1DE5@0101IFET0
E5AD05ADE01fMWH205IFEP0509JFUP2EUID0YJFU0:FUY@2VYZH00P2CTi<01@1`L700MGEe07EeM@1L
G5`0a/K60080W9bL00D0OGem07IfMP1fMWH0ATI609BDU0020;Fe]@040=CDe02CTi<0Ti>C07AdM080
J6QX00D0WinO09:BTP1lO7`0O7al09bLW00206IVIP0506m_K`2a/K40/K6a0:f][@2`/;000P2RXZ80
1@2_[jl0MWIf07IfMP3Hf=P0ZZZZ0080X:2P00@0`<300:^[Z`2[Zj/0alO70P1iNGT01@1fMWH0Lg=c
06m_K`1_Kfl0CTi>0080O7al00D0LW9b06EUI@1UIFD0YZJV0;Jf]P02092@T00508J6QP1dM7@0M7Ad
08J6QP2WYjL00P2m_Kd0101_Kfl0P8200820P01HF5P20=kNgP0509VIV@1gMgL0PX:208:2PP1^KVh0
0P2?Shl01@3=cLd0`l?30<?3``2c/k<0KFe]0080XJ6Q00@0RHV909ZJVP2JVYX0N7Qh0P1mOGd01@27
QhL0_;bl06MWI`1WIfL0>3Ph0080;Rh^00D0ADE505aLG01PH600H61P05]KF`0206YZJP0505YJFP1I
FET0FEUI05QHF01OGel00P1^KVh0101bLW80EUIF05IFEP1iNGT209RHV0050:FUY@2=SHd0_kno0;no
_`1_Kfl00P27QhL01@2ZZZX0OWin06m_K`1_Kfl0E5AD0080C4a<00@0FUYJ05aLG01LG5`0Fe]K2P3o
ool000X0oooo00@0];Bd0::RXP2RXZ80T92@0P2CTi<01@2TY:@0Z:RX0;6a/@2a/K40UIFE0080Rh^;
00D0XZ:R09bLW02LW9`0;2`/09^KV`020::RXP0509>CT`2=SHd0SHf=08b<S026QXH00P20P800102;
Rh/0RHV908V9R@25QHD206UYJ@05092@T02GUiL0?Shn03hn?P24Q8@00P2<S8`01@2=SHd0WYjN0:2P
X02PX:00WIfM0080YZJV00D0YjNW0:RXZ02WYjL0YjNW0:>SX`020:2PX00409>CT`1]KFd0KFe]0::R
XP<0X:2P00D0Xj>S0:6QX@2QXJ40X:2P09^KV`0208^;R`0409RHV02OWil0WinO0:BTY080ZZZZ00D0
M7Ad055AD@2UYJD0YJFU0:6QX@020:FUY@050:VYZ@2ZZZX0YZJV0:JVYP2SXj<00P2HV9P01@2PX:00
YJFU0:FUY@2^[Zh0/;2`0080Kfm_00D0NGUi0:RXZ02XZ:P0ZJVY0:^[Z`020;Fe]@030;:b/P2_[jl0
[jn_0080^KVi0P2f][H0102d];@0][Jf0;Jf]P2h^;P206m_K`0507]kN`2g]kL0]kNg0;Ng]`2a/K40
0P2/[:`20;Vi^@80/k>c00@0[Zj^0;Ng]`2g]kL0_;bl0P30`<001@2b/[80?Cdm07emO@1mOGd0YjNW
0080/k>c00D0[jn_0:BTY02LW9`0W9bL09ZJVP0208b<S0050:6QX@2`/;00^k^k0;^k^`1XJ6P00P2E
UID01@2i^KT0/K6a0;6a/@2b/[80/;2`0080/k>c00D0YJFU0861P@21PH40XZ:R0:f][@020:ZZZP04
0;2`/025QHD0QHF508:2PP80^KVi00D0`<300;jn_P31`L40`L710;Rh^0020;Vi^@030;Rh^03oool0
oooo00l0oooo00@0NWYj08f=S@2=SHd0Q8B40P1BDU8309bLW00508j>SP2<S8`0Shn?08n?S`1`L700
0P1]KFd01@1XJ6P0JVYZ05eMG@1MGEd0CTi>0080G5aL00D0JVYZ092@T02@T900KFe]038b<P0205AD
E00405UIF@1DE5@0E5AD07IfMP80EUIF00D0UYJF09FEU@2UYJD0YJFU0:JVYP0209>CT`05071`L01e
MGD0MGEe05aLG036a/H00P2LW9`01@1mOGd0MWIf07IfMP16ATH0U9BD0080]KFe00@0e=CD09>CT`2C
Ti<0M7Ad0P1XJ6P01@2OWil0TY:B07alO01lO7`0W9bL0080IVIV00D0Kfm_0;6a/@2a/K40[Jf]0;2`
/0020::RXP050:n_[`1fMWH0MWIf0=SHf02ZZZX00P2PX:001030`<00Zj^[0:^[Z`37alL207UiN@05
07IfMP1cLg<0Kfm_06m_K`1>CTh00P1lO7`01@1bLW80IFEU06EUI@2VYZH0][Jf0080T92@00D0QXJ6
07AdM01dM7@0QXJ60:NWY`020;fm_@0406m_K`20P800P82005QHF080g]kN00D0VIVI07MgM`22PX80
PX:206i^KP0208n?S`050<g=c@33`l<0`l?30;>c/`1]KFd00P2QXJ401029RHT0VYZJ09ZJVP1hN7P2
07emO@0508N7Q`2l_;`0IfMW06MWI`0h>3P00P0^;Rh01@15ADD0G5aL061PH01PH600Fe]K0080JVYZ
00D0FUYJ05UIF@1IFET0F5QH05mOG`0206i^KP04079bLP1FEUH0EUIF07UiN@80V9RH00D0YJFU08f=
S@2o_kl0_kno06m_K`0208N7Q`050:ZZZP1nOWh0Kfm_06m_K`1DE5@00P1<C4`0101JFUX0G5aL05aL
G01KFe/:0?ooo`002P3oool0102[Zj/0YJFU0:FUY@2DU9@208f=S@050:2PX02VYZH0YjNW0:NWY`2>
SXh00P29RHT01@2OWil0Ti>C09>CT`0/;2`0WYjN0080WinO00D0V9RH08R8R028R8P0Q8B407UiN@02
08B4Q00408Z:RP26QXH0QXJ608n?S`80OWin00D0Ti>C096AT@0g=cL0=cLg08:2PP0209:BTP0508J6
QP2ATI40WinO09nOW`2PX:000P2QXJ40102VYZH0ZJVY0:BTY02TY:@30:2PX00507moO`1[Jf/0Jf][
096AT@2MWId00P2GUiL01@2LW9`0WinO09nOW`2KVi/0W9bL0080U9BD00@0UYJF0:2PX02PX:00Xj>S
0P2UYJD01@1aLG40EUIF0:BTY02TY:@0YZJV0080Y:BT0P2UYJD20:NWY`040:>SX`2JVYX0VYZJ09jN
WP80YJFU00D0Z:RX0:FUY@1ZJVX0JVYZ061PH0020:6QX@050:BTY02/[:`0/k>c0;>c/`2d];@00P2^
[Zh01@2e]KD0^k^k0;Ng]`2g]kL0]KFe00<0][Jf0P1/K6`01@23Ph<0^;Rh0;Bd]02d];@0Z:RX0080
ZJVY00D0][Jf0;Ng]`2c/k<0/k>c0:ZZZP020;Ng]`<0_;bl00D0^[Zj04Q8B02CTi<0Ti>C0;Ng]`02
0;>c/`050:b/[02KVi/0VIVI09VIV@2VYZH00P2[Zj/01@2/[:`0[jn_0;Rh^02h^;P0JVYZ0080UiNG
00D0]KFe0;Bd]02d];@0/K6a0;>c/`020;:b/P050:f][@2RXZ80XZ:R0:ZZZP2[Zj/00P2WYjL0102_
[jl0N7Qh07QhN01lO7`20;Jf]P050;^k^`34a<@0_Kfm0;fm_@2][Jd00P2g]kL00`2e]KD0oooo0?oo
o`0?0?ooo`04075aL@28R8P0R8R807alO080DU9B00D0SXj>09^KV`2KVi/0M7Ad08:2PP0208j>SP05
06a/K01`L700L71`07UiN@1KFe/00P1IFET0101:BTX0EEEE05EEE@1fMWH209RHV00508F5Q@0l?3`0
IVIV06IVIP1IFET00P1CDe<01@1kNg/0F5QH05QHF02NWYh0WIfM0080[:b/00@0Zj^[09NGU`2GUiL0
KVi^0P1bLW801@1KFe/0clo?0:VYZ@2YZJT0Rh^;0080Ng]k00D0H61P07QhN02=SHd0SHf=0<?3``02
09ZJVP0507MgM`1NGUh0GUiN08f=S@2EUID00P1gMgL0102OWil0GUiN05iNGP1VIVH20<_;b`050;Zj
^P2[Zj/0W9bL09bLW02a/K400P1mOGd01@3Ph>00/K6a0:ZZZP2ZZZX0[:b/0080Zj^[00D0_kno07al
O01lO7`0QHF506i^KP0207]kN`0404m?C`2HV9P0V9RH07QhN080LW9b00D0]kNg0<?3``2TY:@0Y:BT
09JFUP0207inOP0508^;R`2YZJT0^[Zj0;Zj^P1PH6000P1mOGd01@1LG5`0gMgM0=gMg@2IVIT0Kfm_
0080MGEe00@0IFEU07=cL`1cLg<0^KVi0P2c/k<01@2_[jl0OWin08>3P`23Ph<0P8200080UYJF00D0
Ph>308b<S02<S8`0QhN70<71`@0205UIF@0503Lg=`0[:b/0:b/[04M7A`1KFe/00P1IFET0101ADE40
CTi>04i>CP1DE5@205EEE@0504Y:BP1fMWH0JFUY06UYJ@20P8000P1TI6@01@1YJFT0T92@092@T02^
[Zh0Vi^K0080e]KF00D0GemO08b<S02<S8`0YJFU09BDU00206a/K00404M7A`1ADE40DE5A06m_K`80
GemO00<0E5AD0?ooo`3oool0203oool000X0oooo00@0YJFU0:6QX@2QXJ40Xj>S0P2MWId0102PX:00
WYjN09bLW02LW9`308n?S`0508F5Q@1mOGd0OGem03Ti>@2NWYh00P2PX:001@2VYZH0Y:BT0:BTY02K
Vi/0Q8B40080R8R800@0PH6108V9R@29RHT0T92@0P2KVi/01@2FUYH0V9RH03hn?P0n?Sh0P82000<0
Ph>300@0TY:B09JFUP2FUYH0T92@0P2=SHd01@2ATI40XJ6Q0:>SX`2SXj<0X:2P0080WYjN00D0LG5a
05MGE`1GEeL0IfMW08>3P`02096AT@0508f=S@2LW9`0W9bL09VIV@2LW9`00P26QXH0102BTY80X:2P
0:2PX02QXJ4209nOW`0508F5Q@1VIVH0WIfM09fMW@2XZ:P00P2WYjL01@2SXj<0XJ6Q0:>SX`2SXj<0
Vi^K0080Shn?00D0S8b<09>CT`2CTi<0Ti>C096AT@0207EeM@05065QH@2;Rh/0Rh^;09FEU@2PX:00
0P2WYjL01@2SXj<0XJ6Q0:6QX@2ZZZX0/K6a0080/;2`00@0];Bd0;Ng]`2g]kL0]KFe0P1bLW801@2E
UID0]kNg0;:b/P2b/[80VYZJ0080ZJVY00D0];Bd0;:b/P2^[Zh0[Zj^0:RXZ0020;Jf]P<0^KVi00D0
^;Rh0451@@2KVi/0Vi^K0;Zj^P020;Vi^@040:j^[P2KVi/0YjNW0:NWY`@0[Zj^00@0[jn_0;Vi^@2i
^KT0J6QX0P2JVYX40;6a/@040;Bd]02_[jl0[jn_0:JVYP80Z:RX00D0YJFU0:^[Z`2XZ:P0Z:RX0:j^
[P0207emO@0508:2PP2i^KT0^KVi0;^k^`31`L400P2j^[X0102[Zj/0/;2`0;2`/02d];@A0?ooo`04
07emO@2KVi/0Vi^K08f=S@80Cdm?00D0TY:B09jNWP2NWYh0P82008Z:RP0209nOW`0507UiN@1kNg/0
Ng]k07inOP1LG5`00P1MGEd0100i>CT0FEUI05UIF@23Ph<209:BTP0506YZJP0a<C40ADE504E5A@0k
>c/00P1FEUH01@1]KFd0CDe=04e=C@2IVIT0Shn?0080/[:b00@0Xj>S08n?S`2?Shl0FEUI0P1KFe/0
1@1FEUH0bLW909JFUP2FUYH0QHF50080Lg=c00D0Kfm_08N7Q`2ZZZX0ZZZZ0=?Cd`02092@T00508n?
S`1`L700L71`09bLW02QXJ400P25QHD0102RXZ80Hf=S06=SH`1MGEd20;Jf]P050:NWY`2HV9P0Rh^;
08^;R`2KVi/00P1kNg/01@3@d=00/K6a09BDU02DU9@0UYJF0080U9BD00D0[jn_08B4Q024Q8@0N7Qh
07EeM@0207alO004055AD@2LW9`0W9bL07EeM@80Q8B400D0][Jf0<71`@2=SHd0SHf=09ZJVP0206][
J`0507moO`2HV9P0e]KF0=KFeP1TI6@00P22PX801@1SHf<0hN7Q0>7Qh@2CTi<0JFUY0080Ng]k0`1[
Jf/01@2`/;00_Kfm0;fm_@2YZJT0GUiN0080S8b<00@0TI6A09ZJVP2JVYX0O7al0P2;Rh/01@25QHD0
_kno04e=C@1=CDd0>SXj0080:RXZ00D0B4Q805eMG@1^KVh0KVi^04i>CP0205YJFP05051@D01BDU80
DU9B05YJFP1bLW800P1/K6`0102BTY80E5AD05ADE01YJFT2096AT@050:6QX@1bLW80`L710<71`@1F
EUH00P2OWil01@2QXJ40SXj>07inOP1nOWh0FUYJ0080H61P00@0QHF507AdM01dM7@0J6QX2P3oool0
00X0oooo00@0Lg=c06IVIP1VIVH0IfMW0P1LG5`01@10@400ATI60492@P12@T80>SXj0080>CTi00D0
9RHV02LW9`0W9bL0:BTY04E5A@0205=CD`05059BDP1CDe<0De=C0492@P18B4P00P0m?Cd01019BDT0
Cdm?04m?C`1LG5`204a<C00504=3@`0d=3@0?Shn03hn?P1CDe<00P19BDT01@1>CTh0GEeM06IVIP1V
IVH0De=C0080BTY:00D0AdM704m?C`1IFET0FEUI051@D002065QH@0504e=C@19BDT0BDU904E5A@1@
D5000P15ADD01@17AdL0Bd];04];B`1NGUh0EeMG0080Cdm?0`1FEUH01@1JFUX0EEEE05EEE@1:BTX0
ATI60080LG5a00D0Jf][06i^KP1^KVh0JVYZ06QXJ00206IVIP0406ATI01]KFd0KFe]06=SH`80H61P
00D0JVYZ06ATI01FEUH0EUIF04m?C`0204i>CP0505]KF`1`L700Lg=c07=cL`1eMGD00P1cLg<01@1Y
JFT0IFEU075aL@1aLG40Kfm_0080L71`00D0KVi^03/k>`0k>c/0Hf=S0820P00207]kN`0507EeM@21
PH40PH6108B4Q01mOGd00P23Ph<0101jNWX0O7al07alO01gMgL207alO00507IfMP0e=CD0LW9b079b
LP25QHD00P24Q8@01@1mOGd0G5aL07AdM01dM7@0OWin0080Q8B400D0S8b<092@T02BTY80TY:B05mO
G`0207EeM@0508N7Q`2:RXX0RXZ:08F5Q@1nOWh00P1hN7P01@1`L700OWin07inOP20P800R8R80080
PH6100@0PX:206EUI@1UIFD0HF5Q0P2JVYX01@2RXZ80X:2P09fMW@2MWId0Ng]k0080TI6A00<0UiNG
0?ooo`3oool03`3oool0101]KFd0QhN708N7Q`1oOgl204M7A`0508N7Q`2IVIT0VIVI07]kN`28R8P0
0P2CTi<01@1aLG40IFEU06EUI@1cLg<0EEEE0080HF5Q00@0IVIV05iNGP1NGUh0IVIV0P1iNGT0101D
E5@08B4Q04A4A014A4@305EEE@0506][J`1PH600H61P08j>SP28R8P00P2ZZZX0102VYZH0Vi^K09^K
V`1ZJVX2069RHP0505YJFP2j^[X0UiNG09NGU`1mOGd00P25QHD01@1HF5P0OWin0:VYZ@2YZJT0dm?C
0080Ph>300D0T92@07EeM@1eMGD0Y:BT0::RXP0208Z:RP0408f=S@1PH600H61P059BDP80Z:RX00D0
YZJV09^KV`2@T900T92@0:6QX@0208V9R@050=OGe`3;bl/0V9RH09RHV02IVIT00P2HV9P01@2b/[80
S8b<08b<S028R8P0IFEU0080M7Ad00@0DU9B07]kN`1kNg/0JVYZ0P2?Shl01@2TY:@0c/k>08>3P`23
Ph<0P8200080Hf=S00D0PX:209BDU03?cll0clo?05=CD`0207]kN`0506IVIP3Lg=`0g=cL08n?S`1[
Jf/00P1aLG40101LG5`0K6a/06a/K02e]KD20;^k^`050;Bd]01XJ6P0VYZJ09ZJVP2NWYh00P2HV9P0
1@21PH40SXj>08j>SP2?Shl0b/[:0080E5AD00D0@D5102XZ:P0Z:RX0C4a<07EeM@0206ATI00405]K
F`1YJFT0JFUY06IVIP80FUYJ00D0C4a<07]kN`1HF5P0F5QH07MgM`0204Q8B005059BDP1gMgL0MgMg
08J6QP2=SHd00P3;bl/01@1PH600Vi^K09^KV`2IVIT0WIfM0080GUiN00@0EeMG06ATI01TI6@0Q8B4
0P1ZJVX00`1KFe/0oooo0?ooo`080?ooo`002P3oool0101cLg<0IVIV06IVIP1WIfL205aLG0050410
@016ATH0@T920492@P0j>SX00P0i>CT01@0V9RH09bLW02LW9`0Y:BT0ADE50080De=C00D0DU9B05=C
D`1CDe<0@T9204Q8B00203dm?@0404U9B@1?Cdl0Cdm?05aLG080C4a<00D0@d=303@d=00n?Sh0?Shn
05=CD`0204U9B@0504i>CP1MGEd0IVIV06IVIP1CDe<00P1:BTX01@17AdL0Cdm?05UIF@1IFET0D51@
0080HF5Q00D0CDe=04U9B@19BDT0ADE5051@D00204E5A@0504M7A`1;Bd/0Bd];05iNGP1GEeL00P1?
Cdl305IFEP0505YJFP1EEED0EEEE04Y:BP16ATH00P1aLG401@1[Jf/0KVi^06i^KP1ZJVX0J6QX0080
IVIV00@0I6AT06e]K@1]KFd0Hf=S0P1PH6001@1ZJVX0I6AT05IFEP1FEUH0Cdm?0080CTi>00D0Fe]K
071`L01cLg<0Lg=c07EeM@0207=cL`0506UYJ@1UIFD0LG5a075aL@1_Kfl00P1`L7001@1^KVh0>c/k
03/k>`1SHf<0P8200080Ng]k00D0MGEe0861P@21PH40Q8B407emO@0208>3P`0407YjNP1lO7`0O7al
07MgM`80O7al00D0MWIf03De=@1bLW80LW9b08F5Q@0208B4Q00507emO@1LG5`0M7Ad07AdM01nOWh0
0P24Q8@01@2<S8`0T92@09:BTP2BTY80GemO0080MGEe00D0QhN708Z:RP2:RXX0QHF507inOP0207Qh
N005071`L01nOWh0OWin0820P028R8P00P21PH401022PX80IFEU06EUI@1QHF4209ZJVP050::RXP2P
X:00WIfM09fMW@1kNg/00P2ATI400`2GUiL0oooo0?ooo`0?0?ooo`0406e]K@27QhL0QhN707moO`80
AdM700D0QhN709VIV@2IVIT0Ng]k08R8R00209>CT`05075aL@1UIFD0IFEU07=cL`1EEED00P1QHF40
101VIVH0GUiN05iNGP1VIVH207UiN@0405ADE00Q8B40A4A404A4A0<0EEEE00D0Jf][061PH01PH600
SXj>08R8R0020:ZZZP040:JVYP2KVi/0Vi^K06YZJP80HV9R00D0FUYJ0;Zj^P2GUiL0UiNG07emO@02
08F5Q@0505QHF01nOWh0ZJVY0:VYZ@3Cdm<00P23Ph<01@2@T900MGEe07EeM@2TY:@0XZ:R0080RXZ:
00@0SHf=061PH01PH600DU9B0P2XZ:P01@2VYZH0Vi^K092@T02@T900XJ6Q0080RHV900D0emOG0<_;
b`2HV9P0V9RH09VIV@0209RHV0050;:b/P2<S8`0S8b<08R8R01UIFD00P1dM7@0101BDU80Ng]k07]k
N`1ZJVX208n?S`050:BTY03>c/h0Ph>308>3P`20P8000P1SHf<01@22PX80U9BD0<o?c`3?cll0De=C
0080Ng]k00D0IVIV0=cLg03Lg=`0Shn?06][J`02075aL@0405aLG01/K6`0K6a/0;Fe]@80^k^k00D0
];Bd06QXJ02JVYX0VYZJ09jNWP0209RHV0050861P@2>SXh0SXj>08n?S`3:b/X00P1DE5@01@11@D40
:RXZ02XZ:P1<C4`0MGEe0080I6AT00@0Fe]K06UYJ@1YJFT0IVIV0P1JFUX01@1<C4`0Ng]k05QHF01H
F5P0MgMg0080B4Q800D0DU9B07MgM`1gMgL0QXJ608f=S@020<_;b`05061PH02KVi/0Vi^K09VIV@2M
WId00P1NGUh0101GEeL0I6AT06ATI024Q8@206YZJP0305]KF`3oool0oooo00P0oooo000:0?ooo`04
0:n_[`2TY:@0Y:BT0:FUY@80UiNG00D0C4a<0820P02BTY80TY:B09VIV@0209NGU`0508^;R`2BTY80
TY:B09FEU@2QXJ400P2SXj<01@2XZ:P0YjNW0:NWY`2YZJT0UIFE0080CDe=00@0EeMG0:>SX`2SXj<0
VIVI0P20P8001@2PX:00XZ:R09nOW`2OWil0Vi^K0080V9RH00D0VYZJ09jNWP2PX:00X:2P0:NWY`02
07UiN@0506QXJ02IVIT0VYZJ09ZJVP2;Rh/00P24Q8@01@2BTY80QXJ608J6QP2>SXh0U9BD0080UIFE
00D0T92@09RHV02HV9P0TI6A05eMG@0207IfMP0409bLW02XZ:P0Z:RX0:FUY@80U9BD00D0TI6A092@
T02CTi<0Ti>C092@T00308^;R`040:2PX02TY:@0Y:BT05mOG`80M7Ad00D0R8R808N7Q`27QhL0Ogmo
08>3P`0208f=S@0508J6QP2=SHd0SHf=08Z:RP29RHT00P23Ph<01@26QXH0NGUi07UiN@16ATH0QHF5
0080P82000@0PH6108R8R028R8P0S8b<0P29RHT01@1dM7@0I6AT06=SH`1SHf<0GemO0080G5aL00D0
:b/[069RHP2:RXX0RXZ:08n?S`0208b<S003096AT@2>SXh0SXj>0080S8b<0P23Ph<01@1oOgl0PX:2
08:2PP1oOgl0MGEe0080>SXj00D0IVIV07]kN`1kNg/0Ng]k07EeM@0207=cL`0407MgM`1bLW80LW9b
071`L080JFUY00D0K6a/06IVIP1WIfL0IfMW03Lg=`020410@00505IFEP1JFUX0Cdm?04m?C`1GEeL0
0`1JFUX305eMG@0405iNGP1RHV80HV9R05eMG@80GemO00<0>c/k0?ooo`3oool03`3oool0101oOgl0
TI6A096AT@20P80204];B`0508Z:RP2IVIT0VIVI07emO@1kNg/00P29RHT01@1QHF40J6QX06QXJ01g
MgL0FUYJ0080H61P00@0Fe]K06MWI`1WIfL0L71`0P1dM7@01@1QHF40<S8b05ADE01DE5@0Fe]K0080
EeMG00D0O7al04A4A014A4@0S8b<08R8R0020:^[Z`040:RXZ02KVi/0Vi^K06QXJ080IFEU00D0GemO
0<30`02JVYX0VYZJ08Z:RP0206e]K@0504=3@`2<S8`0ZJVY0:VYZ@3<c<`00P2:RXX01@2FUYH0Kfm_
06m_K`2VYZH0XZ:R00<0Rh^;0P1]KFd01@1ZJVX0YjNW0:NWY`2[Zj/0VYZJ0080TY:B00D0Z:RX09NG
U`2GUiL0bLW90<[:bP0208j>SP0409>CT`2FUYH0UYJF0:b/[080UIFE00D0S8b<06i^KP1dM7@0M7Ad
05IFEP0209VIV@0507QhN02?Shl0Shn?0:>SX`34a<@00P1eMGD01@20P800FEUI05UIF@1kNg/0WIfM
0080g=cL00@0F5QH07moO`1oOgl0L71`0P3Rh^801@2IVIT0LG5a07YjNP1jNWX0Fe]K0080IfMW00D0
YJFU0:VYZ@2YZJT0[Zj^06EUI@0208j>SP0409:BTP2EUID0UIFE08j>SP80V9RH00D0VIVI0<c<c01G
EeL0EeMG04=3@`0202`/;00303/k>`1UIFD0EeMG0080EeMG0P1aLG401@1VIVH0FEUI05UIF@1IFET0
JFUY0080H61P00@0R8R802h^;P0^;Rh0GEeM0P25QHD01@2=SHd0KVi^0:JVYP2VYZH0JFUY0080SXj>
00D0X:2P0:6QX@1KFe/0Fe]K05eMG@0206e]K@0407alO01DE5@0E5AD069RHPX0oooo000:0?ooo`04
0;Jf]P2a/K40/K6a0:b/[080ZZZZ00@0C4a<08R8R02YZJT0ZJVY0`2_[jl0102a/K40/[:b0;:b/P2f
][H30;Bd]0050:JVYP2SXj<0Xj>S0:b/[02IVIT00P1GEeL0101HF5P0W9bL09bLW02GUiL208V9R@05
09VIV@2@T900RXZ:08Z:RP23Ph<00P2;Rh/01@2CTi<0Vi^K0:6QX@2QXJ40YZJV0080PX:200D0KVi^
0:b/[02VYZH0YZJV0:2PX0020:>SX`0509^KV`2OWil0WinO09nOW`2KVi/00P2QXJ401@2TY:@0VYZJ
09ZJVP2<S8`0FUYJ0080Ogmo00@0^;Rh0;Vi^@2i^KT0^;Rh0P2QXJ420:n_[`80[Jf]00D0YZJV0:NW
Y`2WYjL0YJFU0:RXZ0020:^[Z`0407AdM02WYjL0YjNW0;2`/080[jn_0P2`/;020;Bd]0050;Rh^02f
][H0][Jf0;Vi^@2j^[X00`2n_[h20;Bd]00505iNGP2j^[X0[jn_0:n_[`2ZZZX00P2b/[801@2c/k<0
^KVi0;Vi^@2d];@0/K6a0080YZJV00D0VYZJ0:2PX02PX:00<30`08Z:RP020;2`/0040:b/[02YZJT0
ZJVY0;2`/0<0]KFe00@0[Jf]0:b/[02/[:`0/K6a0P2f][H01@2l_;`0YJFU03Lg=`0g=cL0YZJV0080
/k>c00D0/K6a0;:b/P2e]KD0]KFe0;Jf]P020:b/[0050:f][@2^[Zh0[Zj^0;:b/P2^[Zh00P2ZZZX0
101TI6@0NGUi07UiN@2f][H30;Ng]`040;Zj^P2d];@0];Bd0:RXZ080Y:BT00@0/;2`0:j^[P2b/[80
/[:b0`2a/K400`1RHV80oooo0?ooo`0?0?ooo`0407=cL`2DU9@0U9BD08J6QP80C4a<00D0TI6A0:>S
X`2SXj<0QXJ608>3P`0209BDU005079bLP1TI6@0I6AT071`L01NGUh00P1LG5`0101QHF40Hf=S06=S
H`24Q8@209ZJVP0507moO`0l?3`0KVi^06i^KP1`L7000P1LG5`01@29RHT0Bd];04];B`2PX:00U9BD
0080Zj^[00@0Z:RX09jNWP2NWYh0GUiN0P1TI6@01@1RHV80^k^k09NGU`2GUiL0QhN70080IfMW00D0
@d=307alO02[Zj/0Zj^[0<[:bP02092@T00509JFUP1/K6`0K6a/0:6QX@2`/;000`24Q8@206EUI@05
06][J`2_[jl0[jn_0;bl_02SXj<00P2TY:@01@2ZZZX0UYJF09JFUP37alL0fMWI0080UiNG00@0Shn?
0:JVYP2VYZH0Z:RX0P2WYjL01@2?Shl0Lg=c07IfMP1fMWH0GUiN0080Vi^K00D0O7al09NGU`2GUiL0
Shn?0;6a/@0206m_K`0508N7Q`1NGUh0GUiN06m_K`2ATI400P3Bd]80101>CTh0IfMW06MWI`1KFe/2
0;Jf]P0507emO@1UIFD0M7Ad07AdM01PH6000P1fMWH01@37alL0clo?0<o?c`2l_;`0LG5a0080QXJ6
00@0R8R8096AT@2ATI40PX:20P1lO7`01@25QHD0`L7105ADE01DE5@0@41000809bLW00D0>SXj05YJ
FP1CDe<0De=C05MGE`0207=cL`0506=SH`1YJFT0JFUY05aLG01OGel00P1ADE401023Ph<0>SXj03Xj
>P0j>SX2069RHP0507inOP21PH40][Jf0;Jf]P1mOGd00P23Ph<01@2HV9P0Zj^[04m?C`1?Cdl0G5aL
0080JVYZ00@0Jf][05=CD`1CDe<0Hf=S2P3oool000X0oooo00@0][Jf0;6a/@2a/K40[:b/0P2ZZZX0
101<C4`0R8R80:VYZ@2YZJT30:n_[`040;6a/@2b/[80/[:b0;Jf]P<0];Bd00D0YZJV0:>SX`2SXj<0
[:b/09VIV@0205MGE`0405QHF02LW9`0W9bL09NGU`80RHV900D0VIVI092@T02:RXX0RXZ:08>3P`02
08^;R`0509>CT`2KVi/0XJ6Q0:6QX@2VYZH00P22PX801@1^KVh0[:b/0:JVYP2VYZH0X:2P0080Xj>S
00D0Vi^K09nOW`2OWil0WinO09^KV`020:6QX@050:BTY02JVYX0VYZJ08b<S01JFUX00P1oOgl0102h
^;P0^KVi0;Vi^@2h^;P20:6QX@80[jn_0P2][Jd01@2VYZH0YjNW0:NWY`2UYJD0Z:RX0080Zj^[00@0
M7Ad0:NWY`2WYjL0/;2`0P2_[jl20;2`/080];Bd00D0^;Rh0;Jf]P2f][H0^KVi0;Zj^P030;jn_P80
];Bd00D0GUiN0;Zj^P2_[jl0[jn_0:ZZZP020;:b/P050;>c/`2i^KT0^KVi0;Bd]02a/K400P2VYZH0
1@2JVYX0X:2P0:2PX00`<300RXZ:0080/;2`00@0[:b/0:VYZ@2YZJT0/;2`0`2e]KD0102][Jd0[:b/
0:b/[02a/K420;Jf]P050;bl_02UYJD0=cLg03Lg=`2VYZH00P2c/k<01@2a/K40/[:b0;Fe]@2e]KD0
][Jf0080[:b/00D0[Jf]0:j^[P2^[Zh0/[:b0:j^[P020:ZZZP0406ATI01iNGT0NGUi0;Jf]P<0]kNg
00@0^[Zj0;Bd]02d];@0Z:RX0P2TY:@0102`/;00[Zj^0;:b/P2b/[830;6a/@03069RHP3oool0oooo
00l0oooo00@0Lg=c09BDU02DU9@0QXJ60P1<C4`01@2ATI40Xj>S0:>SX`26QXH0Ph>30080U9BD00D0
LW9b06ATI01TI6@0L71`05iNGP0205aLG004065QH@1SHf<0Hf=S08B4Q080VYZJ00D0Ogmo03`l?01^
KVh0KVi^071`L00205aLG00508V9R@1;Bd/0Bd];0:2PX02DU9@00P2[Zj/0102XZ:P0WYjN09jNWP1N
GUh206ATI005069RHP2k^k/0UiNG09NGU`27QhL00P1WIfL01@13@d<0O7al0:^[Z`2[Zj/0b/[:0080
T92@00D0UYJF06a/K01/K6`0XJ6Q0;2`/00308B4Q080IFEU00D0Jf][0:n_[`2_[jl0_;bl0:>SX`02
0:BTY0050:ZZZP2FUYH0UYJF0<O7a`3IfMT00P2GUiL0102?Shl0YZJV0:JVYP2XZ:P20:NWY`0508n?
S`1cLg<0MWIf07IfMP1NGUh00P2KVi/01@1lO7`0UiNG09NGU`2?Shl0/K6a0080Kfm_00D0QhN705iN
GP1NGUh0Kfm_096AT@020=;BdP0404i>CP1WIfL0IfMW05]KF`80][Jf00D0OGem06EUI@1dM7@0M7Ad
061PH00207IfMP050<O7a`3?cll0clo?0;bl_01aLG400P26QXH01028R8P0TI6A096AT@22PX8207al
O00508F5Q@31`L40E5AD05ADE010@4000P0W9bL01@0j>SX0FUYJ05=CD`1CDe<0EeMG0080Lg=c00D0
Hf=S06UYJ@1YJFT0G5aL05mOG`02055AD@0408>3P`0j>SX0>SXj03Xj>P80HV9R00D0OWin0861P@2f
][H0][Jf07emO@0208>3P`0509RHV02[Zj/0Cdm?04m?C`1LG5`00P1ZJVX0101[Jf/0De=C05=CD`1S
Hf<:0?ooo`002P3oool0102c/k<0[Zj^0:j^[P2/[:`20:VYZ@0503/k>`27QhL0[Zj^0:j^[P2_[jl0
0P2ZZZX00`2][Jd0[Zj^0:j^[P040;Ng]`050:BTY02QXJ40XJ6Q0:JVYP2UYJD00P1XJ6P0101DE5@0
YJFU0:FUY@2QXJ4309NGU`0408b<S023Ph<0Ph>307]kN`80O7al00D0Shn?09jNWP2PX:00X:2P09nO
W`0208:2PP03075aL@2WYjL0YjNW0080YjNW0P2KVi/01@29RHT0W9bL09bLW02QXJ40UIFE0080XZ:R
00D0YJFU09BDU02DU9@0Ph>304a<C00207alO0@0];Bd0P2MWId01@2e]KD0[jn_0:ZZZP2ZZZX0ZJVY
0080YjNW00D0[Zj^0:f][@2[Zj/0Zj^[075aL@0209RHV0050:b/[02a/K40/K6a0:j^[P2`/;000P2g
]kL01@2h^;P0^KVi0;Vi^@2l_;`0`L710080a<C400D0_kno0:RXZ02XZ:P0HV9R0;Ng]`020;2`/0<0
Zj^[00D0[Jf]0;Jf]P2f][H0/[:b0:^[Z`020:>SX`0509nOW`2ATI40TI6A030`<01fMWH00P2][Jd0
102/[:`0[Zj^0:j^[P2_[jl20;>c/`050;:b/P2d];@0[jn_0:n_[`2e]KD00`2k^k/0102NWYh0=CDe
03De=@2VYZH20:RXZ0050:f][@2XZ:P0[Jf]0:f][@2UYJD00P2XZ:P01@2/[:`0/;2`0;2`/02`/;00
Z:RX0080Zj^[00D0Kfm_07IfMP1fMWH0/;2`0:j^[P020;2`/0040;Fe]@2[Zj/0Zj^[09VIV@80WinO
00D0Zj^[0;:b/P2a/K40/K6a0;Bd]0020;6a/@0306YZJP3oool0oooo00l0oooo00@0Hf=S08R8R028
R8P0MgMg0P1?Cdl01@2BTY80Vi^K09^KV`24Q8@0RHV90080SHf=00D0I6AT06QXJ01XJ6P0KVi^05IF
EP02055AD@04069RHP1PH600H61P07YjNP80SHf=00D0LG5a03Xj>P1WIfL0IfMW065QH@0205=CD`05
07moO`1LG5`0G5aL08:2PP2EUID00P2d];@0102YZJT0WIfM09fMW@1UIFD206UYJ@0506i^KP36a/H0
]KFe0;Fe]@2HV9P00P1cLg<01@1KFe/0OGem092@T02@T900`/;20080Y:BT00D0SXj>06][J`1[Jf/0
UYJF09nOW`0207]kN`0406e]K@1XJ6P0J6QX06ATI080ZJVY00D0_[jn0:FUY@2RXZ80XZ:R0:n_[`02
09BDU0050<K6aP3@d=00SXj>08j>SP2?Shl00P2^[Zh01@2QXJ40YJFU0:FUY@22PX80Jf][0080KVi^
00@0F5QH09VIV@2IVIT0LW9b0P2BTY801@29RHT0bLW906YZJP1ZJVX0O7al0080EEEE00D0LG5a0;bl
_02j^[X0^[Zj05QHF00207IfMP0506m_K`3Rh^80h^;R09FEU@1ZJVX00P1[Jf/0101OGel0KVi^06i^
KP2d];@20<c<c0050:j^[P1TI6@0VIVI09VIV@2LW9`00P2<S8`01@25QHD0Ng]k07]kN`1dM7@0ZJVY
0080BTY:00D0?3`l02HV9P0V9RH0=CDe04U9B@0204a<C00404Q8B01aLG40LG5a06QXJ080HF5Q00D0
GemO06][J`1VIVH0IVIV07EeM@020451@@0506][J`2ZZZX0ZZZZ09bLW02XZ:P00P35aLD01@2MWId0
V9RH09RHV02ZZZX0`<300080OWin0`1kNg/0101_Kfl0IfMW06MWI`1nOWh:0?ooo`002P3oool0102`
/;00ZZZZ0:ZZZP2XZ:P20:ZZZP05055AD@1eMGD0YZJV0:JVYP2XZ:P00P2RXZ801@2QXJ40YZJV0:JV
YP2[Zj/0/;2`0080YjNW00D0XZ:R0:2PX02PX:00VYZJ0:6QX@0206MWI`04059BDP2RXZ80XZ:R09ZJ
VP80UiNG00<0V9RH08N7Q`1mOGd00P1mOGd207YjNP0507]kN`24Q8@0RXZ:08Z:RP2DU9@00P1iNGT0
1@1fMWH0Y:BT0:RXZ02XZ:P0YZJV0080Vi^K00@0UiNG0:BTY02TY:@0ZJVY0`2PX:001@2SXj<0UiNG
09NGU`28R8P0DE5A0080Q8B40`2^[Zh0102/[:`0WinO09nOW`2_[jl30:b/[0050::RXP2QXJ40XJ6Q
0:^[Z`2VYZH00P2UYJD00`1SHf<0RHV908V9R@030:n_[`050:^[Z`2/[:`0Z:RX0:RXZ02OWil00P2l
_;`01@2m_Kd0`l?30<;2`P32`/80`L710080W9bL00D0GEeM0;Fe]@2c/k<0/k>c0;:b/P020:>SX`05
09nOW`2ZZZX0ZZZZ0:^[Z`2YZJT00P2TY:@01@27QhL0O7al07alO00m?Cd0J6QX0080YjNW00@0ZZZZ
0:b/[02/[:`0[jn_0P2d];@01@2b/[80][Jf0;Jf]P2f][H0/k>c0080/;2`00@0[jn_0:b/[00o?cl0
?clo0`2][Jd01@2ZZZX0/[:b0;>c/`2c/k<0[Jf]0080/;2`00D0[Zj^0;Ng]`2g]kL0^k^k0;Rh^002
0;Vi^@0507alO01gMgL0MgMg0:f][@2`/;000P2c/k<0102d];@0[jn_0:n_[`2[Zj/20:NWY`050:ZZ
ZP2d];@0]kNg0;Ng]`2j^[X00P2b/[800`1WIfL0oooo0?ooo`0?0?ooo`0405iNGP29RHT0RHV907Yj
NP80DE5A00D0Shn?0::RXP2RXZ80SHf=08V9R@0208f=S@05071`L01YJFT0JFUY07AdM01kNg/00P1=
CDd00`1>CTh0EUIF05IFEP03071`L00506UYJ@11@D40HV9R069RHP1SHf<00P1TI6@01@2:RXX0WIfM
09fMW@2SXj<0TY:B0080];Bd00@0WinO09FEU@2EUID0M7Ad0P1PH6001@1WIfL0`L710:^[Z`2[Zj/0
RHV90080GEeM00D0H61P07IfMP2IVIT0VIVI0;>c/`0209:BTP0508^;R`1`L700L71`09BDU02ATI40
0P1aLG40101CDe<0LW9b079bLP1dM7@209nOW`050:n_[`2CTi<0UIFE09FEU@2`/;000P2GUiL01@2o
_kl0`L7108>3P`23Ph<0RXZ:0080ZJVY00D0V9RH0:n_[`2_[jl0OGem08J6QP0207]kN`04061PH02L
W9`0W9bL075aL@80UYJF00D0QXJ60<_;b`26QXH0QXJ607inOP0205EEE@0507UiN@2HV9P0gMgM0=gM
g@1/K6`00P1^KVh01@1YJFT0hn?S0>?Sh`2CTi<0LW9b0080Lg=c00@0Hf=S07]kN`1kNg/0a/K60P3=
cLd01@2_[jl0M7Ad07]kN`1kNg/0TY:B0080S8b<00D0TY:B0861P@21PH40QXJ60;fm_@0205iNGP05
03/k>`0c<c<0<c<c02d];@1>CTh00P1OGel0101IFET0Lg=c07=cL`2<S8`20861P@05071`L01YJFT0
G5aL05aLG01XJ6P00P0g=cL01@1<C4`0XJ6Q0:6QX@28R8P0Q8B40080^KVi00D0WYjN06EUI@1UIFD0
RXZ:09:BTP0206YZJP040820P02WYjL0YjNW06YZJP80Hf=S00<0N7Qh0?ooo`3oool0203oool000X0
oooo00@0/;2`0:ZZZP2ZZZX0Z:RX0P2ZZZX01@1ADE40MGEe0:JVYP2VYZH0Z:RX0080XZ:R00D0XJ6Q
0:JVYP2VYZH0Zj^[0;2`/0020:NWY`050::RXP2PX:00X:2P09ZJVP2QXJ400P1WIfL0101BDU80XZ:R
0::RXP2JVYX209NGU`0309RHV027QhL0OGem0080OGem0P1jNWX01@1kNg/0Q8B408Z:RP2:RXX0U9BD
0080NGUi00D0MWIf0:BTY02XZ:P0Z:RX0:JVYP0209^KV`0409NGU`2TY:@0Y:BT0:VYZ@<0X:2P00D0
Xj>S09NGU`2GUiL0R8R8055AD@0208B4Q0<0[Zj^00@0[:b/09nOW`2OWil0[jn_0`2/[:`01@2RXZ80
XJ6Q0:6QX@2[Zj/0YZJV0080YJFU00<0Hf=S08V9R@29RHT00`2_[jl01@2[Zj/0[:b/0:RXZ02XZ:P0
WinO0080_;bl00D0_Kfm0<?3``32`/80`/;20<71`@0209bLW00505eMG@2e]KD0/k>c0;>c/`2b/[80
0P2SXj<01@2OWil0ZZZZ0:ZZZP2[Zj/0ZJVY0080Y:BT00D0QhN707alO01lO7`0?Cdm06QXJ0020:NW
Y`040:ZZZP2/[:`0[:b/0:n_[`80];Bd00D0/[:b0;Jf]P2f][H0][Jf0;>c/`020;2`/0040:n_[`2/
[:`0?clo03lo?`<0[Jf]00D0ZZZZ0;:b/P2c/k<0/k>c0:f][@020;2`/0050:j^[P2g]kL0]kNg0;^k
^`2h^;P00P2i^KT01@1lO7`0MgMg07MgM`2][Jd0/;2`0080/k>c00@0];Bd0:n_[`2_[jl0Zj^[0P2W
YjL01@2ZZZX0];Bd0;Ng]`2g]kL0^[Zj0080/[:b00<0IfMW0?ooo`3oool03`3oool0101NGUh0RHV9
08V9R@1jNWX2055AD@0508n?S`2RXZ80XZ:R08f=S@29RHT00P2=SHd01@1`L700JFUY06UYJ@1dM7@0
Ng]k0080CDe=00<0CTi>05IFEP1FEUH00`1`L7001@1YJFT0@D51069RHP1RHV80Hf=S0080I6AT00D0
RXZ:09fMW@2MWId0Xj>S09:BTP020;Bd]00409nOW`2EUID0UIFE07AdM080H61P00D0IfMW0<71`@2[
Zj/0Zj^[08V9R@0205eMG@05061PH01fMWH0VIVI09VIV@2c/k<00P2BTY801@2;Rh/0L71`071`L02D
U9@0TI6A0080LG5a00@0De=C079bLP1bLW80M7Ad0P2OWil01@2_[jl0Ti>C09FEU@2EUID0/;2`0080
UiNG00D0_kno0<71`@23Ph<0Ph>308Z:RP020:VYZ@0509RHV02_[jl0[jn_07emO@26QXH00P1kNg/0
101PH600W9bL09bLW01aLG4209JFUP0508J6QP3;bl/0QXJ608J6QP1nOWh00P1EEED01@1iNGT0V9RH
0=gMg@3MgMd0K6a/0080KVi^00D0JFUY0>?Sh`3Shn<0Ti>C079bLP0207=cL`0406=SH`1kNg/0Ng]k
0<K6aP80cLg=00D0[jn_07AdM01kNg/0Ng]k09:BTP0208b<S00509:BTP21PH40PH6108J6QP2m_Kd0
0P1NGUh01@0k>c/0<c<c03<c<`0];Bd0CTi>0080GemO00@0FEUI07=cL`1cLg<0S8b<0P21PH401@1`
L700JFUY05aLG01LG5`0J6QX0080=cLg00D0C4a<0:6QX@2QXJ40R8R808B4Q0020;Vi^@0509jNWP1U
IFD0IFEU08Z:RP2BTY800P1ZJVX01020P800YjNW0:NWY`1ZJVX206=SH`0307QhN03oool0oooo00P0
oooo000:0?ooo`0407EeM@1aLG40LG5a06UYJ@80Hf=S00D0=3@d05aLG01^KVh0KVi^06MWI`0306YZ
JP80Jf][00D0HF5Q06UYJ@1WIfL0IfMW06=SH`0205ADE00504i>CP1<C4`0<30`030`<00d=3@00P1]
KFd01@1eMGD0L71`071`L01`L700I6AT0080FUYJ00D0FEUI05]KF`1KFe/0De=C05YJFP02065QH@05
06QXJ00l?3`0?3`l04i>CP1fMWH00P1`L700101_Kfl0I6AT06ATI01QHF4206IVIP05071`L01OGel0
GUiN05iNGP1QHF400P1DE5@01@1<C4`0<S8b055AD@1ADE40Lg=c0080MGEe00D0LW9b06m_K`1_Kfl0
L71`07YjNP0207EeM@0506YZJP1OGel0GemO05mOG`1FEUH00P1?Cdl0100a<C40AdM704M7A`1EEED2
06EUI@0506i^KP1WIfL0IfMW06MWI`1NGUh00P1iNGT01@23Ph<0RXZ:08J6QP26QXH0Ph>30080BTY:
00D0?clo08R8R022PX80PX:208b<S00207moO`0508N7Q`22PX80PX:20820P027QhL00P1jNWX01@1W
IfL0KVi^06i^KP14A4@0HF5Q0080Shn?00@0VIVI09NGU`2GUiL0XJ6Q0P2NWYh01@2@T900PX:209FE
U@2EUID0T92@0080VYZJ00D0Ti>C0820P00f=SH0=SHf0861P@0209fMW@05092@T02DU9@0U9BD09BD
U02GUiL00P2LW9`01@2PX:00Y:BT0:BTY02XZ:P0Zj^[0080[:b/00D0P82006ATI01TI6@0UIFE0:BT
Y0020:ZZZP040:JVYP2ZZZX0ZZZZ0:FUY@80WIfM00D0XJ6Q0::RXP2TY:@0Y:BT0:ZZZP020:VYZ@03
06ATI03oool0oooo00l0oooo00@0G5aL09:BTP2BTY80NWYj0P18B4P01@1kNg/0Shn?08n?S`1gMgL0
RHV90080P82000D0GUiN04U9B@19BDT0J6QX06IVIP0205YJFP0405]KF`1^KVh0KVi^096AT@80UYJF
00D0OGem0492@P1QHF40HF5Q06a/K00205mOG`0509JFUP2WYjL0YjNW0;>c/`2IVIT00P2i^KT0102/
[:`0Ti>C09>CT`1NGUh2059BDP0506a/K02m_Kd0/K6a0;6a/@2ATI400P1YJFT01@1SHf<0MgMg08b<
S02<S8`0Zj^[0080VIVI00D0SXj>06m_K`1_Kfl0WinO08J6QP0207alO00405ADE027QhL0QhN706m_
K`80VIVI00D0XZ:R09>CT`2QXJ40XJ6Q0;Zj^P0208J6QP0509jNWP2o_kl0V9RH09RHV02DU9@00P2a
/K401@2e]KD0`<300<30`020P800SHf=0080PH6100@0JFUY09jNWP2NWYh0RHV90P2][Jd01@21PH40
e=CD08N7Q`27QhL0PX:20080F5QH00D0N7Qh0:>SX`3QhN40hN7Q07=cL`0306ATI080gmoO00D0TI6A
07MgM`1]KFd0KFe]06QXJ002075aL@050;bl_03;bl/0bl_;0:j^[P1fMWH00P2:RXX0102ATI40NWYj
07YjNP1cLg<206a/K00508:2PP2QXJ40I6AT06ATI00i>CT00P0b<S801@0`<300D51@05UIF@1IFET0
CTi>0080JVYZ00D0Q8B407QhN01hN7P0NWYj06i^KP02071`L004061PH01BDU80DU9B03lo?`80TI6A
00D0WinO08b<S02`/;00/;2`0:2PX002065QH@0408R8R02JVYX0PX:208:2PP<0GEeM00@0=cLg05AD
E01DE5@0K6a/2P3oool000X0oooo00@0UiNG09RHV02HV9P0UIFE0P2@T9000`2EUID0T92@08B4Q002
08B4Q080U9BD00D0W9bL0:2PX02PX:00F5QH06QXJ00208n?S`0508f=S@21PH40PH6108:2PP29RHT0
0P2@T900102CTi<0T92@092@T029RHT208>3P`0508B4Q01oOgl0E5AD05ADE00i>CT00P1NGUh01@1P
H600I6AT06][J`1[Jf/0JFUY00<0H61P00@0K6a/06YZJP1ZJVX0KVi^0P1]KFd01@1ZJVX0ATI604I6
AP1OGel0IVIV0080K6a/00D0IVIV06i^KP1^KVh0Lg=c07inOP0207IfMP0407YjNP1fMWH0MWIf06][
J`80LG5a00<0HV9R04I6AP1_Kfl00P1_Kfl206UYJ@0506YZJP1WIfL0Jf][06][J`1dM7@00P1gMgL0
1@1/K6`0MWIf07IfMP1hN7P0MWIf0080Bd];00D0>CTi06EUI@1UIFD0L71`06][J`0206EUI@0506][
J`1_Kfl0Kfm_07MgM`1/K6`00P1^KVh0101aLG40Kfm_06m_K`1WIfL205ADE00506a/K01]KFd0JVYZ
06YZJP1bLW800`1hN7P0101dM7@0L71`071`L01/K6`206QXJ005069RHP1OGel0GemO03Ti>@0T92@0
0P0a<C401@0l?3`0?Cdm03dm?@1:BTX0AdM70080DE5A00D0DU9B05MGE`1GEeL0Bd];04m?C`0204M7
A`0403lo?`0j>SX0>SXj05mOG`80HF5Q00D0HV9R061PH01NGUh0GUiN06ATI00206=SH`0505QHF01O
Gel0G5aL05aLG01FEUH00P1@D5001@0e=CD0@d=304=3@`1QHF40GEeM0080HV9R00@0Fe]K061PH01P
H600Fe]K4@3oool0101PH600VIVI09VIV@1cLg<204A4A00507alO021PH40PH6107EeM@1mOGd00P1n
OWh01@1iNGT0EEEE05EEE@1`L700H61P0080BDU900@0E5AD06IVIP1VIVH0RHV90P28R8P01@1jNWX0
@D5106MWI`1WIfL0Fe]K0080HV9R00D0RXZ:09NGU`2GUiL0[:b/09VIV@020;Zj^P040:FUY@2HV9P0
V9RH07AdM080E5AD00D0M7Ad0<30`031`L40`L7109JFUP0206QXJ00506e]K@25QHD0V9RH09RHV03>
c/h00P2][Jd01@2KVi/0PH610861P@2i^KT0RHV90080OGem00@0HF5Q09:BTP2BTY80P8200P2JVYX0
1@2a/K40/;2`0;Fe]@2e]KD0bl_;0080SXj>00D0YZJV0;Jf]P2DU9@0U9BD08>3P`020:^[Z`050:b/
[032`/80`/;207IfMP28R8P00P24Q8@0101gMgL0U9BD09BDU023Ph<209RHV00506i^KP3Lg=`0OWin
07inOP1]KFd00P1SHf<01@29RHT0WinO0=[JfP3Jf]X0IFEU0080DE5A00D0J6QX0>3Ph03Ph>00V9RH
07IfMP0207YjNP0407emO@1jNWX0NWYj0<c<c080emOG00D0^k^k092@T02LW9`0W9bL0:FUY@0208n?
S`0509ZJVP22PX80PX:209jNWP39bLT00P1kNg/01@0j>SX0=3@d03@d=00_;bl0C4a<0080FEUI00@0
EeMG07IfMP1fMWH0MGEe0P1iNGT01@1WIfL0IFEU06i^KP1^KVh0Bd];0080Fe]K00D0EUIF08^;R`2;
Rh/0UiNG08R8R0020;^k^`050:FUY@1UIFD0IFEU08N7Q`2HV9P00P28R8P0101ZJVX0Hf=S06=SH`1<
C4`206][J`0308J6QP3oool0oooo00P0oooo000:0?ooo`040;jn_P2i^KT0^KVi0;Fe]@80][Jf00D0
^;Rh0;:b/P2a/K40/K6a0:f][@020:j^[P050;2`/02d];@0];Bd065QH@1kNg/00P2YZJT0102TY:@0
WYjN09jNWP2FUYH309jNWP040:JVYP2RXZ80XZ:R0:6QX@80Y:BT00D0YjNW0:>SX`1SHf<0Hf=S055A
D@0208b<S00508V9R@2DU9@0UiNG09NGU`2JVYX00`2ZZZX0102][Jd0ZJVY0:VYZ@2ZZZX20:VYZ@05
0;6a/@1RHV80HV9R08J6QP2^[Zh00P2g]kL01@2h^;P0[Zj^0:j^[P2/[:`0[Jf]00<0[Zj^0P2/[:`0
1@2`/;00[:b/0:b/[02TY:@0JFUY0080ZZZZ00D0Xj>S09RHV02HV9P0Ti>C092@T00209nOW`040:FU
Y@2TY:@0Y:BT0:FUY@80ZJVY0P2VYZH2079bLP04061PH02ZZZX0ZZZZ0;2`/0<0/k>c00D0/K6a0;Rh
^02h^;P0]kNg0;Vi^@020;Jf]P040;Vi^@2c/k<0/k>c0:^[Z`80Ph>300D0YjNW0;6a/@2g]kL0]kNg
0;Jf]P020;>c/`050;Bd]02^[Zh0[Zj^0:j^[P2g]kL00P2i^KT01@2g]kL0^;Rh0;Rh^01`L700IVIV
0080Ogmo00D0P8200:2PX02PX:00XZ:R096AT@0207MgM`0505YJFP1jNWX0NWYj08B4Q025QHD00P23
Ph<0101OGel0CDe=04e=C@2UYJD20:b/[0050:j^[P2d];@0^KVi0;Vi^@2f][H00P2ZZZX01@2g]kL0
^KVi0;no_`2o_kl0^k^k0080^KVi00D0@d=309:BTP2BTY80ZZZZ0:VYZ@020;:b/P040;Ng]`2e]KD0
]KFe0;6a/A40oooo00@0GEeM07emO@1mOGd0Kfm_0P15ADD01@26QXH0W9bL09bLW025QHD0R8R80080
T92@00D0NWYj05EEE@1EEED0O7al07=cL`0205=CD`0404I6AP1ZJVX0JVYZ08N7Q`80IfMW00D0F5QH
03Xj>P1NGUh0GUiN06e]K@02065QH@0508:2PP2:RXX0RXZ:0:6QX@22PX800P2b/[80102QXJ40Vi^K
09^KV`1cLg<204U9B@0507YjNP3=cLd0a<C40<C4a02:RXX00P1QHF401@1/K6`0PX:209VIV@2IVIT0
`l?30080[:b/00D0VYZJ075aL@1aLG40][Jf08J6QP0208N7Q`0406i^KP2EUID0UIFE07UiN@80X:2P
00D0/[:b0<C4a02g]kL0]kNg0<C4a00208j>SP050:VYZ@3<c<`0YJFU0:FUY@2CTi<00P2d];@01@2Z
ZZX0aLG50<G5a@1PH600OGem0080QHF500@0QhN70:JVYP2VYZH0Shn?0P2@T9001@1/K6`0fMWI08B4
Q024Q8@0I6AT0080HF5Q00D0NWYj0:6QX@3De=@0e=CD05eMG@0205=CD`0505QHF037alL0alO709:B
TP1]KFd00P1hN7P0101lO7`0MWIf07IfMP33`l<20<_;b`030::RXP1lO7`0Z:RX0080Z:RX0P2ATI40
1@2GUiL0R8R808R8R02TY:@0aLG50080M7Ad00D0>CTi03`l?00l?3`0<C4a055AD@0205ADE00405YJ
FP1eMGD0MGEe06EUI@80Lg=c00D0IfMW05QHF01@D500D51@04];B`0205iNGP0504a<C01OGel0GemO
09RHV01iNGT00P2EUID01@26QXH0M7Ad07AdM01iNGT0Q8B40080V9RH0`1`L700101MGEd0LG5a075a
L@2:RXX:0?ooo`002P3oool0102n_[h0^KVi0;Vi^@2e]KD20;Jf]P050;Rh^02b/[80/K6a0;6a/@2]
[Jd00P2^[Zh01@2`/;00];Bd0;Bd]01QHF40Ng]k0080ZJVY00@0Y:BT09jNWP2NWYh0UYJF0`2NWYh0
102VYZH0XZ:R0::RXP2QXJ420:BTY0050:NWY`2SXj<0Hf=S06=SH`1ADE400P2<S8`01@29RHT0U9BD
09NGU`2GUiL0VYZJ00<0ZZZZ00@0[Jf]0:VYZ@2YZJT0ZZZZ0P2YZJT01@2a/K40HV9R069RHP26QXH0
[Zj^0080]kNg00D0^;Rh0:j^[P2^[Zh0[:b/0:f][@030:j^[P80[:b/00D0/;2`0:b/[02/[:`0Y:BT
06UYJ@020:ZZZP050:>SX`2HV9P0V9RH09>CT`2@T9000P2OWil0102UYJD0Y:BT0:BTY02UYJD20:VY
Z@80YZJV0P1bLW80101PH600ZZZZ0:ZZZP2`/;030;>c/`050;6a/@2h^;P0^;Rh0;Ng]`2i^KT00P2f
][H0102i^KT0/k>c0;>c/`2[Zj/208>3P`050:NWY`2a/K40]kNg0;Ng]`2f][H00P2c/k<01@2d];@0
[Zj^0:j^[P2^[Zh0]kNg0080^KVi00D0]kNg0;Rh^02h^;P0L71`06IVIP0207moO`050820P02PX:00
X:2P0::RXP2ATI400P1gMgL01@1JFUX0NWYj07YjNP24Q8@0QHF50080Ph>300@0GemO04e=C@1=CDd0
YJFU0P2/[:`01@2^[Zh0];Bd0;Vi^@2i^KT0][Jf0080ZZZZ00D0]kNg0;Vi^@2o_kl0_kno0;^k^`02
0;Vi^@0504=3@`2BTY80TY:B0:ZZZP2YZJT00P2b/[80102g]kL0]KFe0;Fe]@2a/K4A0?ooo`0405eM
G@1mOGd0OGem06m_K`80ADE500D0QXJ609bLW02LW9`0QHF508R8R002092@T00507YjNP1EEED0EEEE
07alO01cLg<00P1CDe<01016ATH0JVYZ06YZJP27QhL206MWI`0505QHF00j>SX0GUiN05iNGP1]KFd0
0P1QHF401@22PX80RXZ:08Z:RP2QXJ40PX:20080/[:b00@0XJ6Q09^KV`2KVi/0Lg=c0P19BDT01@1j
NWX0cLg=0<C4a034a<@0RXZ:0080HF5Q00D0K6a/08:2PP2IVIT0VIVI0<?3``020:b/[00509ZJVP1a
LG40LG5a0;Jf]P26QXH00P27QhL0101^KVh0UIFE09FEU@1iNGT20:2PX0050;:b/P34a<@0]kNg0;Ng
]`34a<@00P2>SXh01@2YZJT0c<c<0:FUY@2UYJD0Ti>C0080];Bd00D0ZZZZ0<G5a@35aLD0H61P07em
O@0208F5Q@0408N7Q`2VYZH0YZJV08n?S`80T92@00D0K6a/0=WIf@24Q8@0Q8B406ATI002065QH@05
07YjNP2QXJ40e=CD0=CDe01MGEd00P1CDe<01@1HF5P0alO70<O7a`2BTY80KFe]0080N7Qh00@0O7al
07IfMP1fMWH0`l?30P3;bl/00`2RXZ80O7al0:RXZ0020:RXZ080TI6A00D0UiNG08R8R028R8P0Y:BT
0<G5a@0207AdM00503Ti>@0l?3`0?3`l034a<@1ADE400P1DE5@0101JFUX0MGEe07EeM@1UIFD207=c
L`0506MWI`1HF5P0D51@051@D01;Bd/00P1NGUh01@1<C4`0GemO05mOG`2HV9P0NGUi0080UIFE00D0
QXJ607AdM01dM7@0NGUi08B4Q00209RHV0<0L71`00@0GEeM075aL@1aLG40RXZ:2P3oool000X0oooo
00<0_[jn0;Zj^P2j^[X00`2`/;001@2f][H0[jn_0:n_[`2_[jl0[:b/0080[jn_00D0[Jf]0;6a/@2a
/K40KFe]08F5Q@020:b/[0050:6QX@2KVi/0Vi^K09FEU@2KVi/00P2IVIT0102MWId0X:2P0:2PX02S
Xj<20:FUY@050:JVYP2JVYX0H61P061PH01@D5000P2=SHd01@2BTY80Shn?09VIV@2IVIT0UIFE0080
XZ:R00D0Xj>S0:ZZZP2XZ:P0Z:RX0:>SX`0209nOW`050:FUY@1/K6`0K6a/08>3P`2/[:`00P2][Jd0
1@2`/;00XZ:R0::RXP2PX:00Zj^[0080[Jf]00@0[:b/0:VYZ@2YZJT0Z:RX0P2YZJT01@2MWId0EUIF
0:NWY`2WYjL0Xj>S0080V9RH00D0QXJ608j>SP2TY:@0Y:BT0:JVYP0209^KV`050:>SX`2XZ:P0Z:RX
0:ZZZP2WYjL00P1^KVh01@1YJFT0Zj^[0:^[Z`2_[jl0];Bd0080[jn_00D0[Zj^0;2`/02`/;00/k>c
0;Fe]@020;^k^`040;fm_@2h^;P0^;Rh0:BTY080QXJ600D0X:2P0:j^[P2d];@0];Bd0;6a/@030:n_
[`040:JVYP2/[:`0[:b/0:n_[`80]KFe00D0^;Rh0;>c/`2c/k<0IfMW09BDU0020:ZZZP05092@T02Q
XJ40XJ6Q09JFUP2IVIT00P26QXH01@1FEUH0UYJF09JFUP2WYjL0ZZZZ0080[:b/00@0MgMg05aLG01L
G5`0[:b/0P2UYJD01@2WYjL0[:b/0;:b/P2b/[80[Zj^0080Shn?00D0WYjN0;Rh^02k^k/0^k^k0;Jf
]P020;Vi^@0505aLG02CTi<0Ti>C0:f][@2`/;000P2a/K40102e]KD0/K6a0;6a/@2][JdA0?ooo`04
06e]K@2@T900T92@07alO080Bd];00D0SHf=08j>SP2>SXh0QHF508V9R@0209^KV`0506YZJP18B4P0
B4Q806][J`1jNWX00P1RHV801014A4@0L71`071`L02:RXX208:2PP0507=cL`11@D40De=C05=CD`1[
Jf/00P1aLG401@26QXH0Y:BT0:BTY02NWYh0QhN70080/;2`00@0W9bL09:BTP2BTY80KFe]0P1;Bd/0
1@1gMgL0a/K60;Vi^@2i^KT0PX:20080HV9R00D0IFEU07moO`2NWYh0WYjN0<G5a@020:f][@0509jN
WP1/K6`0K6a/0:b/[01kNg/00P21PH40101bLW80WYjN09jNWP1bLW8208Z:RP050:FUY@2l_;`0XJ6Q
0:6QX@2WYjL00P21PH401@2LW9`0_[jn0;6a/@2a/K40[:b/0080^;Rh00D0_;bl0<[:bP3:b/X0EeMG
08N7Q`0209JFUP0408Z:RP2<S8`0S8b<08:2PP80QXJ600D0LW9b0=gMg@1kNg/0Ng]k06=SH`0207=c
L`0508N7Q`2/[:`0g=cL0=cLg01QHF400P18B4P01@1TI6@0emOG0=OGe`26QXH0GEeM0080M7Ad00@0
Kfm_07UiN@1iNGT0_Kfm0P37alL01@2QXJ40K6a/08V9R@29RHT0X:2P0080OWin00D0SHf=08N7Q`27
QhL0V9RH0<;2`P0207UiN@0503/k>`0m?Cd0?Cdm03Hf=P1:BTX00P1QHF40101UIFD0P8200820P01/
K6`207MgM`05071`L01eMGD0FUYJ05YJFP1QHF400P1ZJVX01@1KFe/0IVIV06IVIP2LW9`0NWYj0080
V9RH00D0Lg=c06=SH`1SHf<0LG5a08n?S`0209:BTP0406IVIP1XJ6P0J6QX071`L080K6a/00<0RXZ:
0?ooo`3oool0203oool000X0oooo00@0/k>c0;2`/02`/;00[:b/0P2XZ:P01@2YZJT0[:b/0:^[Z`2[
Zj/0[:b/0080[Jf]00D0[Zj^0:f][@2][Jd0N7Qh08B4Q0020::RXP0509BDU01bLW80LW9b071`L01o
Ogl00P2GUiL0102PX:00Ti>C09>CT`2QXJ420:>SX`0509nOW`2@T900EEEE05EEE@1>CTh00P1oOgl0
1@21PH40SHf=096AT@2ATI40QXJ60080RXZ:00D0RHV909fMW@2PX:00X:2P09^KV`0209fMW@050::R
XP1UIFD0IFEU07moO`2ATI400P2TY:@01@2/[:`0XZ:R0::RXP2FUYH0V9RH0080YJFU00@0Y:BT0:NW
Y`2WYjL0YZJV0P2UYJD01@2HV9P0GUiN0:2PX02PX:00TY:B0080Ti>C00D0R8R808F5Q@2PX:00X:2P
0:>SX`020::RXP030:FUY@2VYZH0YZJV0080Zj^[0P1fMWH01@22PX80YZJV0:JVYP2YZJT0[:b/0080
YZJV00<0Z:RX0::RXP2RXZ800P2_[jl30;Fe]@80/K6a00D0YJFU08N7Q`27QhL0VIVI0;:b/P020:n_
[`<0[Zj^00D0ZJVY0:2PX02WYjL0YjNW0:RXZ0020:b/[0050;2`/02XZ:P0Z:RX061PH02;Rh/00P2N
WYh01@2?Shl0WIfM09fMW@2;Rh/0SHf=0080SXj>00D0FEUI09BDU02DU9@0WIfM0:NWY`020:ZZZP04
07YjNP1IFET0FEUI0:ZZZP80WIfM00D0Zj^[0:RXZ02_[jl0[jn_0:RXZ00209^KV`050;6a/@2i^KT0
^[Zj0;Zj^P2h^;P00P2i^KT0101_Kfl0Vi^K09^KV`2XZ:P30:n_[`<0[Zj^00<0Zj^[0?ooo`3oool0
3`3oool0101`L700SHf=08f=S@1mOGd204U9B@05096AT@2b/[80/[:b09fMW@2EUID00P2GUiL01@1X
J6P0C4a<04a<C01bLW80IfMW0080GEeM00@0BTY:06a/K01/K6`0NWYj0P25QHD01@1aLG40AdM705eM
G@1MGEd0Kfm_0080GUiN00D0M7Ad092@T02@T900ZJVY096AT@020;Ng]`040:6QX@2<S8`0S8b<06e]
K@80EeMG00D0Ng]k0<k>cP2o_kl0_kno08F5Q@02065QH@0507UiN@2LW9`0/;2`0;2`/03Hf=P00P30
`<001@2[Zj/0MGEe07EeM@2`/;00LW9b0080Ph>300@0NWYj09^KV`2KVi/0K6a/0P1mOGd01@2PX:00
]KFe08^;R`2;Rh/0Shn?00<0QXJ600@0Zj^[0:>SX`2SXj<0Y:BT0P2XZ:P01@2`/;00]kNg0;Ng]`1F
EUH0SXj>0080Rh^;00@0QhN708B4Q024Q8@0NGUi0P22PX801@1[Jf/0fm_K07]kN`1kNg/0GEeM0080
NGUi00D0U9BD0:^[Z`3Lg=`0g=cL0820P00205MGE`0506e]K@3Vi^H0i^KV09ZJVP1XJ6P00P21PH40
101^KVh0Ph>308>3P`35aLD20=3@d0050;Zj^P1jNWX0SXj>08j>SP2XZ:P00P2=SHd01@2>SXh0S8b<
08b<S02SXj<0`l?30080P82000D0@d=304M7A`17AdL0?clo05EEE@0206QXJ00407inOP28R8P0R8R8
07UiN@80Ph>300D0LG5a08:2PP1PH600H61P06ATI00207IfMP05069RHP1CDe<0De=C07emO@2ATI40
0P2ZZZX01@24Q8@0Kfm_06m_K`2@T900P8200080TI6A00@0LG5a06e]K@1]KFd0LW9b0P21PH400`28
R8P0oooo0?ooo`080?ooo`002P3oool0102c/k<0/;2`0;2`/02/[:`20:RXZ0050:VYZ@2/[:`0Zj^[
0:^[Z`2/[:`00P2][Jd01@2^[Zh0[Jf]0:f][@1hN7P0Q8B40080XZ:R00D0U9BD079bLP1bLW80L71`
07moO`0209NGU`040:2PX02CTi<0Ti>C0:6QX@80Xj>S00D0WinO092@T01EEED0EEEE04i>CP0207mo
O`050861P@2=SHd0TI6A096AT@26QXH00P2:RXX01@29RHT0WIfM0:2PX02PX:00Vi^K0080WIfM00D0
XZ:R06EUI@1UIFD0Ogmo096AT@020:BTY0050:b/[02RXZ80XZ:R09JFUP2HV9P00P2UYJD0102TY:@0
YjNW0:NWY`2VYZH20:FUY@0509RHV01NGUh0X:2P0:2PX02BTY800P2CTi<01@28R8P0QHF50:2PX02P
X:00Xj>S0080XZ:R00<0YJFU0:JVYP2VYZH00P2[Zj/207IfMP0508:2PP2VYZH0YZJV0:VYZ@2/[:`0
0P2VYZH00`2XZ:P0XZ:R0::RXP020:n_[`<0]KFe0P2a/K401@2UYJD0QhN708N7Q`2IVIT0/[:b0080
[jn_0`2^[Zh01@2YZJT0X:2P0:NWY`2WYjL0Z:RX0080[:b/00D0/;2`0:RXZ02XZ:P0H61P08^;R`02
09jNWP0508n?S`2MWId0WIfM08^;R`2=SHd00P2>SXh01@1IFET0U9BD09BDU02MWId0YjNW0080ZZZZ
00@0NWYj05UIF@1IFET0ZZZZ0P2MWId01@2[Zj/0Z:RX0:n_[`2_[jl0Z:RX0080Vi^K00D0/K6a0;Vi
^@2j^[X0^[Zj0;Rh^0020;Vi^@0406m_K`2KVi/0Vi^K0:RXZ0<0[jn_0`2^[Zh00`2[Zj/0oooo0?oo
o`0?0?ooo`04071`L02=SHd0SHf=07emO@80BDU900D0TI6A0;:b/P2b/[80WIfM09FEU@0209NGU`05
06QXJ01<C4`0C4a<079bLP1WIfL00P1MGEd0101:BTX0K6a/06a/K01jNWX208F5Q@05075aL@17AdL0
GEeM05eMG@1_Kfl00P1NGUh01@1dM7@0T92@092@T02YZJT0TI6A0080]kNg00@0XJ6Q08b<S02<S8`0
KFe]0P1GEeL01@1kNg/0c/k>0;no_`2o_kl0QHF50080HF5Q00D0NGUi09bLW02`/;00/;2`0=SHf002
0<30`0050:^[Z`1eMGD0MGEe0;2`/01bLW800P23Ph<0101jNWX0Vi^K09^KV`1/K6`207emO@050:2P
X02e]KD0Rh^;08^;R`2?Shl00`26QXH0102[Zj/0Xj>S0:>SX`2TY:@20:RXZ0050;2`/02g]kL0]kNg
05IFEP2>SXh00P2;Rh/01027QhL0Q8B408B4Q01iNGT208:2PP0506][J`3Kfm/0Ng]k07]kN`1MGEd0
0P1iNGT01@2DU9@0Zj^[0=cLg03Lg=`0P8200080EeMG00D0KFe]0>KViP3Vi^H0VYZJ06QXJ0020861
P@0406i^KP23Ph<0Ph>30<G5a@80d=3@00D0^[Zj07YjNP2>SXh0SXj>0:RXZ00208f=S@0508j>SP2<
S8`0S8b<0:>SX`33`l<00P20P8001@13@d<0AdM704M7A`0o?cl0EEEE0080J6QX00@0OWin08R8R028
R8P0NGUi0P23Ph<01@1aLG40PX:2061PH01PH600I6AT0080MWIf00D0HV9R05=CD`1CDe<0OGem096A
T@020:ZZZP0508B4Q01_Kfl0Kfm_092@T020P8000P2ATI40101aLG40KFe]06e]K@1bLW820861P@03
08R8R03oool0oooo00P0oooo000:0?ooo`0408J6QP1gMgL0MgMg079bLP80MGEe0P1`L70206e]K@04
06MWI`1[Jf/0Jf][06QXJ080JVYZ00D0>3Ph061PH01mOGd0OGem08:2PP0207YjNP0504];B`1MGEd0
GUiN05iNGP1_Kfl00P1eMGD01@1]KFd0LG5a075aL@21PH40N7Qh0080?Shn00D0EUIF079bLP1bLW80
LW9b07EeM@0207=cL`0506MWI`1JFUX0FUYJ04m?C`1RHV800P1fMWH3075aL@0506][J`16ATH0ATI6
06e]K@1gMgL00P29RHT01@20P800LG5a075aL@1NGUh0E5AD0080Kfm_00@0NGUi07IfMP1fMWH0Lg=c
0P1gMgL01@1jNWX0CDe=06e]K@1]KFd0JVYZ0080M7Ad00@0KVi^06EUI@1ZJVX0JVYZ0`1OGel01@1[
Jf/0KVi^06i^KP1_Kfl0I6AT0080E5AD00D0JFUY06MWI`1WIfL0JVYZ07YjNP0207emO@0507=cL`2:
RXX0RXZ:08Z:RP29RHT00P2?Shl01022PX80Ogmo07moO`24Q8@2079bLP0506IVIP2<S8`0SHf=08f=
S@2?Shl00P2CTi<209BDU080W9bL0`2@T9001@2FUYH0QXJ608J6QP1IFET0QHF50080PX:200D0P820
07moO`1oOgl0Kfm_07UiN@0206][J`0304];B`1oOgl0Ogmo0080TI6A0P2PX:00101[Jf/0IVIV06IV
IP1kNg/207alO00509fMW@2LW9`0W9bL09bLW02BTY800P1lO7`01@2XZ:P0Y:BT09FEU@2EUID0QhN7
0080LG5a00D0EUIF06EUI@1UIFD0V9RH0:^[Z`020:FUY@040:>SX`2ZZZX0ZZZZ0;6a/A40oooo00@0
LW9b096AT@2ATI40Ogmo0P1BDU801024Q8@0WinO09nOW`2;Rh/3096AT@0507MgM`1>CTh0CTi>07em
O@1kNg/00P1BDU801010@400GEeM05eMG@1_Kfl206e]K@0505mOG`1ADE40Hf=S06=SH`1YJFT00P1M
GEd01@1XJ6P0Ogmo07moO`2>SXh0QHF50080Y:BT00@0Ti>C06m_K`1_Kfl0G5aL0P18B4P01@1SHf<0
/k>c0:BTY02TY:@0KFe]0080EUIF00D0Kfm_09BDU02][Jd0[Jf]0=OGe`020;jn_P050:FUY@1dM7@0
M7Ad0;6a/@1gMgL00P2:RXX01021PH40SXj>08j>SP1OGel208f=S@050:ZZZP2g]kL0Ph>308>3P`2Q
XJ400P2FUYH01@2GUiL0_kno0:NWY`2WYjL0/K6a0080YJFU00D0^k^k0;Fe]@2e]KD0GemO08j>SP02
08B4Q00409^KV`21PH40PH6109jNWP80Ng]k00D0KFe]0=_Kf`2<S8`0S8b<05]KF`0207]kN`0509:B
TP2LW9`0gmoO0=oOg`2<S8`00P1FEUH01@1/K6`0i>CT0>CTi02RXZ80K6a/0080QXJ600@0JVYZ0820
P020P800`<300P32`/801@2QXJ40Kfm_08F5Q@25QHD0XZ:R0080S8b<00D0SXj>09NGU`2GUiL0ZZZZ
0<?3``0208F5Q@05059BDP16ATH0ATI604I6AP1?Cdl00P1QHF40102<S8`0QHF508F5Q@1jNWX207Mg
M`0506a/K02<S8`0IVIV06IVIP1UIFD00P1lO7`01@1WIfL0KVi^06i^KP22PX80RXZ:0080UiNG00<0
Ph>307alO01lO7`00P2FUYH207moO`0406MWI`1/K6`0K6a/09:BTP80S8b<00<0YZJV0?ooo`3oool0
203oool000X0oooo00@0OWin06m_K`1_Kfl0Hf=S0P16ATH01@0`<300LG5a07=cL`1cLg<0MGEe0080
NGUi00D0PX:208V9R@29RHT0RHV908B4Q00207QhN005071`L01kNg/0Ng]k07MgM`1EEED00P0^;Rh0
101MGEd0IfMW06MWI`1UIFD205mOG`80F5QH0P1FEUH0101GEeL0E5AD05ADE01?Cdl3051@D00503<c
<`0N7Qh07QhN05ADE01]KFd00`1UIFD2065QH@05069RHP1SHf<0Hf=S06ATI01LG5`00P1TI6@01@1P
H600GEeM05eMG@18B4P0<S8b0080GEeM00@0HV9R05mOG`1OGel0IFEU0P1QHF401@1PH600GUiN05]K
F`1KFe/0H61P0080GUiN00D0EUIF051@D00c<c<0<c<c02PX:00203dm?@0504I6AP12@T80@T9204A4
A01JFUX00P1OGel305aLG00505mOG`1QHF40HF5Q065QH@1IFET00P0j>SX01@17AdL0Hf=S06YZJP1Z
JVX0IVIV0080GemO00D0LW9b071`L01`L700KFe]07EeM@0207=cL`0507EeM@1jNWX0NWYj075aL@0d
=3@00P1?Cdl0101NGUh0G5aL05aLG01:BTX205YJFP80EeMG0P1CDe<01@1EEED0ATI604I6AP0j>SX0
8R8R00807AdM00D09bLW02HV9P0V9RH0>SXj04I6AP0205QHF00405eMG@1RHV80HV9R06IVIP80KFe]
00D0K6a/065QH@1@D500D51@03Lg=`0202DU9@0504Y:BP0o?cl0@D510451@@0n?Sh00P10@4001@18
B4P0DU9B059BDP1XJ6P0Lg=c0080MGEe00@0Ogmo07IfMP1fMWH0Hf=S4@3oool0101hN7P0YZJV0:JV
YP1nOWh205iNGP050861P@2VYZH0YZJV09>CT`2FUYH00P22PX801@1TI6@0BTY:04Y:BP1]KFd0Kfm_
0080GEeM00@0@d=305eMG@1MGEd0PH610P1aLG401@1cLg<0F5QH05eMG@1MGEd0JFUY0080HV9R00D0
N7Qh08f=S@2=SHd0XZ:R09>CT`020:f][@040:BTY022PX80PX:2069RHP80?Shn00D0H61P0;jn_P2j
^[X0^[Zj079bLP0205]KF`05079bLP22PX80W9bL09bLW032`/800P2/[:`01@2>SXh0HV9R069RHP2K
Vi/0I6AT0080Ng]k0`1jNWX01@1JFUX0PX:208:2PP2TY:@0^[Zj0080S8b<0`2IVIT01@2QXJ40/K6a
0:ZZZP2ZZZX0_[jn0080TY:B00D0_kno0;:b/P2b/[80IfMW0:FUY@0208Z:RP040::RXP1kNg/0Ng]k
09jNWP80R8R800D0KFe]0=_Kf`2KVi/0Vi^K05mOG`0208j>SP050:JVYP2>SXh0e=CD0=CDe01oOgl0
0P1?Cdl01@1JFUX0fm_K0=_Kf`2IVIT0IFEU0080OGem00@0JVYZ07]kN`1kNg/0_[jn0P38b<P01@2[
Zj/0K6a/08Z:RP2:RXX0YJFU0080RHV900D0S8b<09RHV02HV9P0Y:BT0<?3``0208J6QP0504A4A011
@D40@D5104e=C@1:BTX00P1BDU80101nOWh0SXj>08j>SP1`L70206a/K00506YZJP2:RXX0IfMW06MW
I`1[Jf/00P1QHF401@1ADE40Vi^K09^KV`2OWil0Vi^K0080TI6A00D0LG5a06a/K01/K6`0Vi^K09>C
T`0206e]K@0405IFEP1HF5P0F5QH07inOP80Ph>300<0XJ6Q0?ooo`3oool0203oool000X0oooo00@0
Y:BT08N7Q`27QhL0Lg=c0P1dM7@01@0n?Sh0Z:RX0:VYZ@2YZJT0[jn_0080ZZZZ00D0Zj^[0:JVYP2V
YZH0[Jf]0:RXZ0020:ZZZP0509nOW`2WYjL0YjNW0:6QX@1oOgl00P1IFET0102][Jd0Zj^[0:^[Z`2X
Z:P20:ZZZP050:NWY`2[Zj/0Y:BT0:BTY02HV9P00P2?Shl01@2NWYh0Xj>S0:6QX@2QXJ40K6a/0080
?Cdm00D0[Zj^0:^[Z`2YZJT0ZJVY0:>SX`0209nOW`050:>SX`2PX:00X:2P0::RXP2VYZH00P2RXZ80
1@2BTY80SHf=08f=S@1nOWh0?3`l0080R8R800@0XJ6Q0:^[Z`2[Zj/0[jn_0P2d];@20;Fe]@80/k>c
00D0]kNg0;:b/P2b/[80YZJV0:j^[P02065QH@0404E5A@1cLg<0Lg=c07]kN`<0NGUi00@0Ti>C09RH
V02HV9P0Shn?0P21PH4209:BTP80R8R800D0RXZ:05YJFP1JFUX0UIFE0;2`/0020;>c/`040;Fe]@2d
];@0];Bd0;2`/0<0][Jf00@0^KVi0;Fe]@2e]KD0/;2`0`2^[Zh0100a<C40Shn?08n?S`2_[jl20;>c
/`050<71`@2f][H0][Jf0;jn_P2g]kL00P2h^;P01@2n_[h0`L710<71`@2j^[X0Zj^[0080<30`00D0
@d=308J6QP26QXH0Zj^[0:n_[`020;Bd]0040;^k^`2l_;`0_;bl0;^k^`80];Bd00D0/;2`0;6a/@2Y
ZJT0ZJVY09fMW@0207AdM080/[:b0`2TY:@20;Jf]P050;Ng]`2h^;P0^;Rh0;bl_030`<000P35aLD0
103Bd]80d=3@0=3@d01fMWHA0?ooo`0406e]K@2@T900T92@07IfMP80HV9R00D0PH6109^KV`2KVi/0
Shn?08f=S@0207]kN`0506][J`1EEED0EEEE07YjNP1`L7000P1GEeL0101CDe<0K6a/06a/K02CTi<2
0820P005079bLP1@D500DE5A055AD@1ZJVX00P1WIfL01@1iNGT0Q8B408B4Q02a/K40WinO0080Xj>S
00@0TI6A07QhN01hN7P0IfMW0P1;Bd/01@1UIFD0Zj^[0:BTY02TY:@0IVIV0080DU9B00D0Hf=S08Z:
RP2CTi<0Ti>C0<W9b@020<[:bP0509JFUP1/K6`0K6a/0:f][@1^KVh00P2@T9001025QHD0LG5a075a
L@1UIFD207inOP050::RXP31`L40Ph>308>3P`2IVIT00P2;Rh/01@2MWId0^[Zj0:NWY`2WYjL0c/k>
0080R8R800D0[Jf]0;Bd]02d];@0Hf=S09VIV@0206][J`0407EeM@1fMWH0MWIf09BDU080JVYZ00D0
IFEU0=KFeP2][Jd0[Jf]05iNGP0209:BTP0508b<S02;Rh/0g]kN0=kNgP2EUID00P1IFET01@1GEeL0
hn?S0>?Sh`2ZZZX0IVIV0080R8R800@0KVi^08J6QP26QXH0a<C40P3>c/h01@2/[:`0JVYZ08N7Q`27
QhL0XJ6Q0080Q8B400D0R8R8096AT@2ATI40U9BD0:^[Z`0207MgM`0504E5A@0n?Sh0?Shn04];B`14
A4@00P18B4P0101^KVh0Ng]k07]kN`1JFUX2059BDP05065QH@1nOWh0MWIf07IfMP1cLg<00P1TI6@0
1@1GEeL0K6a/06a/K01kNg/0W9bL0080UYJF00D0S8b<08:2PP22PX80YJFU0:JVYP0207inOP03071`
L01_Kfl0Kfm_00<0P82000<0O7al0?ooo`3oool0203oool000X0oooo00@0Y:BT08N7Q`27QhL0Lg=c
0P1dM7@01@0n?Sh0Z:RX0:VYZ@2YZJT0[jn_0080ZZZZ00D0Zj^[0:JVYP2VYZH0[Jf]0:RXZ0020:ZZ
ZP0509nOW`2WYjL0YjNW0:6QX@1oOgl00P1IFET0102][Jd0Zj^[0:^[Z`2XZ:P20:ZZZP050:NWY`2[
Zj/0Y:BT0:BTY02HV9P00P2?Shl01@2NWYh0Xj>S0:6QX@2QXJ40K6a/0080?Cdm00D0[Zj^0:^[Z`2Y
ZJT0ZJVY0:>SX`0209nOW`050:>SX`2PX:00X:2P0::RXP2VYZH00P2RXZ801@2BTY80SHf=08f=S@1n
OWh0?3`l0080R8R800@0XJ6Q0:^[Z`2[Zj/0[jn_0P2d];@20;Fe]@80/k>c00D0]kNg0;:b/P2b/[80
YZJV0:j^[P02065QH@0404E5A@1cLg<0Lg=c07]kN`<0NGUi00@0Ti>C09RHV02HV9P0Shn?0P21PH42
09:BTP80R8R800D0RXZ:05YJFP1JFUX0UIFE0;2`/0020;>c/`040;Fe]@2d];@0];Bd0;2`/0<0][Jf
00@0^KVi0;Fe]@2e]KD0/;2`0`2^[Zh0100a<C40Shn?08n?S`2_[jl20;>c/`050<71`@2f][H0][Jf
0;jn_P2g]kL00P2h^;P01@2n_[h0`L710<71`@2j^[X0Zj^[0080<30`00D0@d=308J6QP26QXH0Zj^[
0:n_[`020;Bd]0040;^k^`2l_;`0_;bl0;^k^`80];Bd00D0/;2`0;6a/@2YZJT0ZJVY09fMW@0207Ad
M080/[:b0`2TY:@20;Jf]P050;Ng]`2h^;P0^;Rh0;bl_030`<000P35aLD0103Bd]80d=3@0=3@d01f
MWHA0?ooo`0406e]K@2@T900T92@07IfMP80HV9R00D0PH6109^KV`2KVi/0Shn?08f=S@0207]kN`05
06][J`1EEED0EEEE07YjNP1`L7000P1GEeL0101CDe<0K6a/06a/K02CTi<20820P005079bLP1@D500
DE5A055AD@1ZJVX00P1WIfL01@1iNGT0Q8B408B4Q02a/K40WinO0080Xj>S00@0TI6A07QhN01hN7P0
IfMW0P1;Bd/01@1UIFD0Zj^[0:BTY02TY:@0IVIV0080DU9B00D0Hf=S08Z:RP2CTi<0Ti>C0<W9b@02
0<[:bP0509JFUP1/K6`0K6a/0:f][@1^KVh00P2@T9001025QHD0LG5a075aL@1UIFD207inOP050::R
XP31`L40Ph>308>3P`2IVIT00P2;Rh/01@2MWId0^[Zj0:NWY`2WYjL0c/k>0080R8R800D0[Jf]0;Bd
]02d];@0Hf=S09VIV@0206][J`0407EeM@1fMWH0MWIf09BDU080JVYZ00D0IFEU0=KFeP2][Jd0[Jf]
05iNGP0209:BTP0508b<S02;Rh/0g]kN0=kNgP2EUID00P1IFET01@1GEeL0hn?S0>?Sh`2ZZZX0IVIV
0080R8R800@0KVi^08J6QP26QXH0a<C40P3>c/h01@2/[:`0JVYZ08N7Q`27QhL0XJ6Q0080Q8B400D0
R8R8096AT@2ATI40U9BD0:^[Z`0207MgM`0504E5A@0n?Sh0?Shn04];B`14A4@00P18B4P0101^KVh0
Ng]k07]kN`1JFUX2059BDP05065QH@1nOWh0MWIf07IfMP1cLg<00P1TI6@01@1GEeL0K6a/06a/K01k
Ng/0W9bL0080UYJF00D0S8b<08:2PP22PX80YJFU0:JVYP0207inOP03071`L01_Kfl0Kfm_00<0P820
00<0O7al0?ooo`3oool0203oool000X0oooo00@0[Zj^09FEU@2EUID0J6QX0P1cLg<01@1GEeL0/;2`
0:j^[P2^[Zh0[:b/0080ZZZZ00D0YJFU0:JVYP2VYZH0Y:BT0:VYZ@0208F5Q@0507emO@2IVIT0VIVI
09ZJVP2@T9000P1LG5`0102[Zj/0[Zj^0:j^[P2^[Zh30:ZZZP040:^[Z`2RXZ80XZ:R0:6QX@80UYJF
00D0W9bL0:6QX@2NWYh0WYjN07QhN00203dm?@050:ZZZP2][Jd0Z:RX0:RXZ02QXJ400P2NWYh01@2L
W9`0WIfM09fMW@2RXZ80XJ6Q00<0XZ:R0P2PX:001@1nOWh0?clo09fMW@2MWId0Y:BT0080ZJVY00D0
Zj^[0:f][@2][Jd0ZJVY0:n_[`020:j^[P050;2`/02/[:`0[:b/0:NWY`2][Jd00P1aLG400`1GEeL0
MGEe07EeM@0306i^KP0506YZJP1gMgL0KVi^06i^KP1YJFT00P1SHf<00`1fMWH0RHV908B4Q00208B4
Q080EEEE00D0QhN70;:b/P2e]KD0]KFe0;>c/`0209nOW`0309JFUP2_[jl0[jn_0080/k>c0P2_[jl0
1@2`/;00[Zj^0:j^[P2XZ:P0=SHf0080U9BD00@0ZJVY0:RXZ02XZ:P0/K6a0P2_[jl0102g]kL0^;Rh
0;Fe]@2e]KD30;Rh^0050;Zj^P2e]KD0ATI604I6AP1fMWH00P2][Jd01@2SXj<0T92@09VIV@2IVIT0
Zj^[0080/K6a00D0/[:b0;>c/`2c/k<0[Zj^0:f][@020:ZZZP050:VYZ@1bLW80LW9b0;Ng]`2d];@0
0P2a/K40102`/;00][Jf0;Jf]P2b/[820;Bd]0050;^k^`2g]kL0^k^k0;^k^`32`/800P30`<000`1a
LG40oooo0?ooo`0?0?ooo`0406YZJP25QHD0QHF507=cL`80D51@00D0RXZ:09fMW@2MWId0S8b<092@
T00207EeM@0506a/K01=CDd0CDe=08:2PP1hN7P00P1GEeL0101@D500GUiN05iNGP1aLG42071`L005
06e]K@12@T80EeMG05MGE`1iNGT00P1ZJVX01@1gMgL0R8R808R8R02h^;P0YZJV0080Xj>S00@0WYjN
07AdM01dM7@0GemO0P1GEeL01@1[Jf/0]KFe0;Rh^02h^;P0LW9b0080GEeM00D0G5aL07IfMP27QhL0
QhN70;fm_@020;Rh^00508b<S01CDe<0De=C09>CT`1XJ6P00P21PH401026QXH0H61P061PH01RHV82
07YjNP0509nOW`2d];@0Ng]k07]kN`2@T9000P28R8P01@2MWId0ZJVY09FEU@2EUID0[jn_0080Lg=c
00D0XJ6Q09NGU`2GUiL0E5AD07AdM00206=SH`0408>3P`1iNGT0NGUi08V9R@80JFUY00D0GemO0=7A
d@2NWYh0WYjN05=CD`0208j>SP0507]kN`27QhL0c<c<0<c<c02EUID00P1ADE401@1@D500hN7Q0>7Q
h@2l_;`0Lg=c0080S8b<00@0IFEU07QhN01hN7P0/k>c0P31`L401@2c/k<0LW9b09BDU02DU9@0WYjN
0080QhN700D0PH61096AT@2ATI40/K6a0<S8b00207IfMP050451@@12@T80@T9204I6AP19BDT00P1G
EeL0101cLg<0Ng]k07]kN`1XJ6P205iNGP0506EUI@1hN7P0Jf][06][J`1gMgL00P1dM7@01@1SHf<0
Xj>S0:>SX`2BTY80ZZZZ0080X:2P00D0PH6108B4Q024Q8@0X:2P0:JVYP02065QH@0405iNGP1bLW80
LW9b08B4Q080OWin00<0TI6A0?ooo`3oool0203oool000X0oooo00@0[:b/09ZJVP2JVYX0Lg=c0P1K
Fe/01@1WIfL0]KFe0;Fe]@2e]KD0ZZZZ0080[Jf]00D0/;2`0;>c/`2c/k<0/;2`0:^[Z`0206YZJP05
07alO02^[Zh0[Zj^0:ZZZP2?Shl00P1QHF440:b/[080ZZZZ00<0Z:RX0:b/[02IVIT01@2IVIT0102?
Shl0TI6A096AT@1/K6`203lo?`80/;2`0P2TY:@0102XZ:P0X:2P0:2PX02XZ:P20:NWY`050:^[Z`2W
YjL0X:2P0:2PX02SXj<00P2PX:001@1nOWh0;bl_09fMW@2MWId0UiNG0080W9bL00D0YJFU0:ZZZP2Z
ZZX0YjNW0:VYZ@020:b/[0050:n_[`2ZZZX0ZZZZ0:VYZ@2^[Zh00P1aLG401013@d<0IFEU06EUI@1V
IVH206YZJP0506][J`1ZJVX0J6QX06QXJ01HF5P00P1?Cdl01@1NGUh0MGEe07EeM@1eMGD0Lg=c0080
B4Q800D0Ph>30:n_[`2a/K40/K6a0:j^[P020:>SX`0509bLW02MWId0WIfM0;>c/`2d];@00P2/[:`0
1@2_[jl0/k>c0;>c/`2_[jl0=cLg0080TY:B00@0ZZZZ0:b/[02/[:`0[:b/0P2b/[801@2f][H0_;bl
0;Vi^@2i^KT0`<300080^k^k00D0`<300;Jf]P1BDU80DU9B07emO@020:^[Z`050:FUY@2IVIT0YJFU
0:FUY@2/[:`00P2d];@01@2a/K40/[:b0;:b/P2`/;00[Zj^0080[:b/00<0ZZZZ06e]K@1]KFd00P2a
/K420:n_[`030:f][@2b/[80/[:b00<0/k>c00<0][Jf0;Fe]@2h^;P0102h^;P00`1dM7@0oooo0?oo
o`0?0?ooo`0407AdM021PH40PH6108B4Q080B4Q800D0NWYj07alO01lO7`0Kfm_07EeM@0207moO`05
069RHP12@T80@T9206a/K01bLW800P1FEUH01013@d<0O7al07alO027QhL206][J`05069RHP12@T80
DU9B059BDP1eMGD00P1IFET01@1LG5`0PH610861P@2^[Zh0VIVI0080S8b<00@0QXJ6075aL@1aLG40
H61P0P1EEED01@1aLG40/;2`0;Ng]`2g]kL0NGUi0080J6QX00D0MGEe08Z:RP2;Rh/0Rh^;0=GEe@02
0=?Cd`0509NGU`0n?Sh0?Shn09VIV@1oOgl00P2=SHd0102?Shl0Fe]K05]KF`1ZJVX207emO@050:FU
Y@2YZJT0Q8B408B4Q02SXj<00P2@T9001@2PX:00[jn_0:6QX@2QXJ40aLG50080NWYj00D0/[:b0:j^
[P2^[Zh0K6a/096AT@0207EeM@0408B4Q02EUID0UIFE0:FUY@80NWYj00D0N7Qh0=;BdP31`L40`L71
05UIF@0208V9R@0508^;R`2QXJ40fMWI0=WIf@2HV9P00P14A4@01@1?Cdl0eMGE0=GEe@2XZ:P0Kfm_
0080Q8B400@0Hf=S079bLP1bLW80WIfM0P2a/K401@2NWYh0Hf=S0861P@21PH40UIFE0080Ng]k00D0
N7Qh08Z:RP2:RXX0]kNg0<G5a@0207inOP<0ATI600D0@T9204e=C@1OGel0GemO08:2PP0208^;R`05
07YjNP1QHF40HF5Q069RHP1lO7`00P1aLG40101PH600HF5Q065QH@1[Jf/209NGU`0509FEU@2a/K40
Y:BT0:BTY022PX800P2ATI401@2ZZZX0/[:b0820P020P800K6a/0080IFEU00@0IfMW05]KF`1KFe/0
MWIf2P3oool000X0oooo00@0[:b/09ZJVP2JVYX0Lg=c0P1KFe/01@1WIfL0]KFe0;Fe]@2e]KD0ZZZZ
0080[Jf]00D0/;2`0;>c/`2c/k<0/;2`0:^[Z`0206YZJP0507alO02^[Zh0[Zj^0:ZZZP2?Shl00P1Q
HF440:b/[080ZZZZ00<0Z:RX0:b/[02IVIT01@2IVIT0102?Shl0TI6A096AT@1/K6`203lo?`80/;2`
0P2TY:@0102XZ:P0X:2P0:2PX02XZ:P20:NWY`050:^[Z`2WYjL0X:2P0:2PX02SXj<00P2PX:001@1n
OWh0;bl_09fMW@2MWId0UiNG0080W9bL00D0YJFU0:ZZZP2ZZZX0YjNW0:VYZ@020:b/[0050:n_[`2Z
ZZX0ZZZZ0:VYZ@2^[Zh00P1aLG401013@d<0IFEU06EUI@1VIVH206YZJP0506][J`1ZJVX0J6QX06QX
J01HF5P00P1?Cdl01@1NGUh0MGEe07EeM@1eMGD0Lg=c0080B4Q800D0Ph>30:n_[`2a/K40/K6a0:j^
[P020:>SX`0509bLW02MWId0WIfM0;>c/`2d];@00P2/[:`01@2_[jl0/k>c0;>c/`2_[jl0=cLg0080
TY:B00@0ZZZZ0:b/[02/[:`0[:b/0P2b/[801@2f][H0_;bl0;Vi^@2i^KT0`<300080^k^k00D0`<30
0;Jf]P1BDU80DU9B07emO@020:^[Z`050:FUY@2IVIT0YJFU0:FUY@2/[:`00P2d];@01@2a/K40/[:b
0;:b/P2`/;00[Zj^0080[:b/00<0ZZZZ06e]K@1]KFd00P2a/K420:n_[`030:f][@2b/[80/[:b00<0
/k>c00<0][Jf0;Fe]@2h^;P0102h^;P00`1dM7@0oooo0?ooo`0?0?ooo`0407AdM021PH40PH6108B4
Q080B4Q800D0NWYj07alO01lO7`0Kfm_07EeM@0207moO`05069RHP12@T80@T9206a/K01bLW800P1F
EUH01013@d<0O7al07alO027QhL206][J`05069RHP12@T80DU9B059BDP1eMGD00P1IFET01@1LG5`0
PH610861P@2^[Zh0VIVI0080S8b<00@0QXJ6075aL@1aLG40H61P0P1EEED01@1aLG40/;2`0;Ng]`2g
]kL0NGUi0080J6QX00D0MGEe08Z:RP2;Rh/0Rh^;0=GEe@020=?Cd`0509NGU`0n?Sh0?Shn09VIV@1o
Ogl00P2=SHd0102?Shl0Fe]K05]KF`1ZJVX207emO@050:FUY@2YZJT0Q8B408B4Q02SXj<00P2@T900
1@2PX:00[jn_0:6QX@2QXJ40aLG50080NWYj00D0/[:b0:j^[P2^[Zh0K6a/096AT@0207EeM@0408B4
Q02EUID0UIFE0:FUY@80NWYj00D0N7Qh0=;BdP31`L40`L7105UIF@0208V9R@0508^;R`2QXJ40fMWI
0=WIf@2HV9P00P14A4@01@1?Cdl0eMGE0=GEe@2XZ:P0Kfm_0080Q8B400@0Hf=S079bLP1bLW80WIfM
0P2a/K401@2NWYh0Hf=S0861P@21PH40UIFE0080Ng]k00D0N7Qh08Z:RP2:RXX0]kNg0<G5a@0207in
OP<0ATI600D0@T9204e=C@1OGel0GemO08:2PP0208^;R`0507YjNP1QHF40HF5Q069RHP1lO7`00P1a
LG40101PH600HF5Q065QH@1[Jf/209NGU`0509FEU@2a/K40Y:BT0:BTY022PX800P2ATI401@2ZZZX0
/[:b0820P020P800K6a/0080IFEU00@0IfMW05]KF`1KFe/0MWIf2P3oool000X0oooo00@0TI6A08R8
R028R8P0K6a/0P1>CTh01@1?Cdl0Rh^;08F5Q@25QHD0Lg=c0080MgMg00D0PX:207EeM@1eMGD0MgMg
07moO`0205aLG00506MWI`21PH40PH6108J6QP1UIFD00P1<C4`01021PH40MGEe07EeM@1gMgL207in
OP0508J6QP28R8P0Ph>308>3P`25QHD00P1XJ6P01@1bLW80HF5Q069RHP1RHV80B4Q80080@41000D0
Rh^;096AT@2@T900T92@08^;R`0208B4Q00507emO@1iNGT0NGUi079bLP28R8P00P1dM7@01@1aLG40
K6a/06a/K01NGUh0;bl_0080OGem00@0Ng]k075aL@1aLG40PH610P23Ph<01@28R8P0QXJ607emO@1m
OGd0N7Qh0080LW9b00D0LG5a071`L01=CDd0CDe=034a<@02030`<00502d];@0f=SH0=SHf03Lg=`14
A4@00P0n?Sh30410@00504a<C015ADD0E5AD05ADE01>CTh00P18B4P01@1nOWh0TI6A08n?S`2?Shl0
UIFE0080QHF500D0QhN707inOP1nOWh0SHf=08Z:RP0208^;R`0508b<S02CTi<0Ti>C08F5Q@0h>3P0
0P1HF5P01022PX80QXJ608J6QP29RHT207inOP0507emO@21PH40P8200820P01oOgl00`1aLG40101g
MgL0>CTi03Ti>@1PH60209ZJVP050:JVYP2TY:@0Xj>S0:>SX`2XZ:P00P2^[Zh01@2][Jd0ZJVY0:VY
Z@2SXj<0[:b/0080WYjN00D0Ng]k06=SH`1SHf<0TI6A09JFUP0209BDU004092@T02CTi<0Ti>C09VI
V@80Vi^K00D0WIfM0:BTY02YZJT0ZJVY0:FUY@0209RHV00305ADE03oool0oooo00l0oooo00@0O7al
08F5Q@25QHD0UIFE0P1NGUh01@2SXj<0ZZZZ0:ZZZP28R8P0TI6A0080VYZJ00D0PX:205IFEP1FEUH0
R8R808^;R`0205EEE@0403dm?@1SHf<0Hf=S09BDU080MGEe00D0Fe]K05YJFP1@D500D51@05iNGP02
065QH@0506ATI025QHD0QHF50<30`02RXZ800P2MWId0102WYjL0N7Qh07QhN01VIVH205aLG00506=S
H`2NWYh0U9BD09BDU01RHV800P1SHf<01@1cLg<0QHF508f=S@2=SHd0c<c<0080bLW900D0TI6A0410
@010@400Z:RX08n?S`0209ZJVP0408n?S`1HF5P0F5QH06i^KP80NGUi00D0Zj^[0:j^[P2IVIT0VIVI
0:^[Z`020:RXZ0050::RXP2f][H0Xj>S0:>SX`2LW9`00P1bLW801@2k^k/0_;bl0;bl_01eMGD0SHf=
0080MGEe00@0NGUi08V9R@29RHT0VYZJ0P1hN7P01@1eMGD0bl_;0;Jf]P2f][H0Fe]K0080MgMg00D0
SHf=08n?S`3De=@0e=CD0:f][@0203Xj>P0505ADE03Ng]h0g]kN09:BTP1gMgL00P29RHT0101YJFT0
PX:208:2PP2l_;`20<G5a@050:ZZZP1QHF40QXJ608J6QP2<S8`00P29RHT01@1jNWX0Q8B408B4Q02l
_;`0bLW90080QhN700D0BDU904i>CP1>CTh0B4Q8051@D00205]KF`040820P01bLW80LW9b07UiN@80
G5aL00D0Hf=S08N7Q`1_Kfl0Kfm_071`L00206IVIP0504e=C@1`L700L71`08:2PP2NWYh00P2VYZH0
1@26QXH0QhN708N7Q`2ZZZX0][Jf0080QXJ600@0S8b<07emO@1mOGd0IFEU0P1NGUh00`1SHf<0oooo
0?ooo`080?ooo`002P3oool01011@D40@T920492@P1NGUh206IVIP0506e]K@1VIVH0GEeM05eMG@0f
=SH00P19BDT01@1IFET0D51@051@D01EEED0FEUI0080DE5A00D092@T03Lg=`0g=cL0EeMG055AD@02
061PH004069RHP1QHF40HF5Q04I6AP80@41000D0=cLg04M7A`1CDe<0De=C05ADE00204m?C`0502/[
:`0S8b<0>3Ph03Ph>016ATH00P1@D5001@1=CDd0<C4a024Q8@0Q8B40>3Ph0080ADE500D0C4a<055A
D@1ADE40EeMG04A4A002034a<@0503hn?P1SHf<0Hf=S06UYJ@1ZJVX00P1KFe/0101NGUh09RHV02HV
9P0M7Ad204e=C@05059BDP1ADE40CTi>04i>CP1BDU800P0/;2`01@0n?Sh0CTi>05YJFP1JFUX0HV9R
0080G5aL00D0DE5A02TY:@0Y:BT0?Shn05QHF002051@D00505QHF01RHV80HV9R03lo?`0W9bL00P1C
De<0101WIfL0J6QX06QXJ01QHF4305mOG`0403Hf=P1LG5`0G5aL06IVIP80EeMG00D0G5aL05iNGP1D
E5@0E5AD02HV9P0204U9B@80HV9R0P1UIFD0101NGUh0AdM704M7A`15ADD2069RHP0506ATI01RHV80
De=C05=CD`1NGUh00P0i>CT01@1EEED0GEeM05UIF@1IFET0ATI60080B4Q800D0=cLg02TY:@0a<C40
<C4a03Xj>P02030`<00503Ph>00f=SH0=SHf02XZ:P0[:b/00P0g=cL01@11@D40>CTi03Ti>@11@D40
>SXj008092@T00@0;bl_03dm?@0m?Cd0@T920P1>CTh01@19BDT0@D5103<c<`0c<c<0CDe=0080C4a<
00<0B4Q80?ooo`3oool03`3oool306m_K`0407moO`1<C4`0C4a<0:VYZ@80/;2`00D0UYJF08j>SP2G
UiL0UiNG079bLP0205=CD`0506QXJ01/K6`0FEUI05UIF@0n?Sh00P1aLG401@2HV9P0RXZ:08Z:RP1_
Kfl0FEUI0080C4a<00@0DU9B06EUI@1UIFD0HF5Q0P1fMWH01@33`l<0X:2P08V9R@29RHT0[jn_0080
OGem00D0KFe]075aL@1aLG40LG5a0:6QX@020:RXZ00508N7Q`1_Kfl0Kfm_07]kN`24Q8@00P27QhL0
1036a/H0`<300<30`029RHT204M7A`050:FUY@2@T900XZ:R0::RXP2;Rh/00P1DE5@01@1bLW80OWin
07inOP2YZJT0/k>c0080VYZJ00D0ZJVY09ZJVP2JVYX0XJ6Q0<30`00209NGU`0408J6QP1VIVH0IVIV
0::RXP80YjNW00D0FEUI07AdM01^KVh0KVi^07inOP0208>3P`0508V9R@1eMGD0MGEe07QhN03<c<`0
0P2g]kL01@1kNg/0RXZ:08Z:RP2@T900YJFU0080dM7A00@0_kno06ATI01TI6@0GEeM0P3QhN401@2c
/k<0Ng]k08J6QP26QXH0Jf][0080R8R800D0b/[:0<;2`P32`/80]KFe06i^KP02092@T00409fMW@2K
Vi/0Vi^K08j>SP80TI6A00D0_Kfm09fMW@2TY:@0Y:BT05ADE003059BDP0405EEE@1MGEd0GEeM08F5
Q@80QhN700D0KVi^06=SH`1SHf<0Fe]K08R8R002075aL@0407emO@1TI6@0I6AT0410@080K6a/00D0
MgMg07inOP2:RXX0RXZ:08B4Q0020820P005092@T02MWId0QhN708N7Q`2QXJ400P1WIfL0101YJFT0
JVYZ06YZJP1_Kfl:0?ooo`002P3oool01011@D40@T920492@P1NGUh206IVIP0506e]K@1VIVH0GEeM
05eMG@0f=SH00P19BDT01@1IFET0D51@051@D01EEED0FEUI0080DE5A00D092@T03Lg=`0g=cL0EeMG
055AD@02061PH004069RHP1QHF40HF5Q04I6AP80@41000D0=cLg04M7A`1CDe<0De=C05ADE00204m?
C`0502/[:`0S8b<0>3Ph03Ph>016ATH00P1@D5001@1=CDd0<C4a024Q8@0Q8B40>3Ph0080ADE500D0
C4a<055AD@1ADE40EeMG04A4A002034a<@0503hn?P1SHf<0Hf=S06UYJ@1ZJVX00P1KFe/0101NGUh0
9RHV02HV9P0M7Ad204e=C@05059BDP1ADE40CTi>04i>CP1BDU800P0/;2`01@0n?Sh0CTi>05YJFP1J
FUX0HV9R0080G5aL00D0DE5A02TY:@0Y:BT0?Shn05QHF002051@D00505QHF01RHV80HV9R03lo?`0W
9bL00P1CDe<0101WIfL0J6QX06QXJ01QHF4305mOG`0403Hf=P1LG5`0G5aL06IVIP80EeMG00D0G5aL
05iNGP1DE5@0E5AD02HV9P0204U9B@80HV9R0P1UIFD0101NGUh0AdM704M7A`15ADD2069RHP0506AT
I01RHV80De=C05=CD`1NGUh00P0i>CT01@1EEED0GEeM05UIF@1IFET0ATI60080B4Q800D0=cLg02TY
:@0a<C40<C4a03Xj>P02030`<00503Ph>00f=SH0=SHf02XZ:P0[:b/00P0g=cL01@11@D40>CTi03Ti
>@11@D40>SXj008092@T00@0;bl_03dm?@0m?Cd0@T920P1>CTh01@19BDT0@D5103<c<`0c<c<0CDe=
0080C4a<00<0B4Q80?ooo`3oool03`3oool306m_K`0407moO`1<C4`0C4a<0:VYZ@80/;2`00D0UYJF
08j>SP2GUiL0UiNG079bLP0205=CD`0506QXJ01/K6`0FEUI05UIF@0n?Sh00P1aLG401@2HV9P0RXZ:
08Z:RP1_Kfl0FEUI0080C4a<00@0DU9B06EUI@1UIFD0HF5Q0P1fMWH01@33`l<0X:2P08V9R@29RHT0
[jn_0080OGem00D0KFe]075aL@1aLG40LG5a0:6QX@020:RXZ00508N7Q`1_Kfl0Kfm_07]kN`24Q8@0
0P27QhL01036a/H0`<300<30`029RHT204M7A`050:FUY@2@T900XZ:R0::RXP2;Rh/00P1DE5@01@1b
LW80OWin07inOP2YZJT0/k>c0080VYZJ00D0ZJVY09ZJVP2JVYX0XJ6Q0<30`00209NGU`0408J6QP1V
IVH0IVIV0::RXP80YjNW00D0FEUI07AdM01^KVh0KVi^07inOP0208>3P`0508V9R@1eMGD0MGEe07Qh
N03<c<`00P2g]kL01@1kNg/0RXZ:08Z:RP2@T900YJFU0080dM7A00@0_kno06ATI01TI6@0GEeM0P3Q
hN401@2c/k<0Ng]k08J6QP26QXH0Jf][0080R8R800D0b/[:0<;2`P32`/80]KFe06i^KP02092@T004
09fMW@2KVi/0Vi^K08j>SP80TI6A00D0_Kfm09fMW@2TY:@0Y:BT05ADE003059BDP0405EEE@1MGEd0
GEeM08F5Q@80QhN700D0KVi^06=SH`1SHf<0Fe]K08R8R002075aL@0407emO@1TI6@0I6AT0410@080
K6a/00D0MgMg07inOP2:RXX0RXZ:08B4Q0020820P005092@T02MWId0QhN708N7Q`2QXJ400P1WIfL0
101YJFT0JVYZ06YZJP1_Kfl:0?ooo`002P3oool0101jNWX0Fe]K05]KF`2TY:@20:FUY@050:ZZZP2a
/K40]kNg0;Ng]`1NGUh00P1kNg/01@2ATI40R8R808R8R02HV9P0XJ6Q0080UiNG00D0:RXZ04e=C@1=
CDd0U9BD09VIV@0209>CT`0409bLW02YZJT0ZJVY04m?C`80Hf=S00D0UYJF09ZJVP2DU9@0U9BD08f=
S@0207alO080>c/k0P1QHF401@1cLg<0EeMG05MGE`1hN7P0TY:B0080?Cdm00@0Ng]k0:>SX`2SXj<0
X:2P0P2SXj<01@2^[Zh0SHf=0410@010@400JFUY0080Shn?00D0Vi^K09jNWP2ATI40TI6A09:BTP02
03Ti>@0506YZJP2/[:`0[:b/0:>SX`28R8P00P25QHD01@2NWYh0BTY:04Y:BP1^KVh0Zj^[0080XZ:R
00@0YZJV09fMW@2MWId0XZ:R0P19BDT01@2>SXh0[jn_0;6a/@2a/K40]KFe0080_Kfm00D0YjNW02HV
9P2@T900T92@0;6a/@020;Bd]0050;Jf]P2h^;P0_[jn0;jn_P0j>SX00P2SXj<01@31`L40^KVi0;Vi
^@2a/K40[Zj^0080WinO00D0;bl_08:2PP22PX80R8R809:BTP0209RHV004092@T01eMGD0MGEe07Qh
N080[jn_00D0[Zj^0:b/[02_[jl0[jn_0;Ng]`0205eMG@0509JFUP2PX:00YJFU0:FUY@2ZZZX00P2Y
ZJT01@1dM7@09RHV09ZJVP2JVYX0aLG50080`L7100D0_;bl0:n_[`2_[jl0Fe]K03lo?`030:RXZ080
YjNW00D0Xj>S09RHV01<C4`0C4a<06QXJ00208j>SP<0[Zj^00D0][Jf0:2PX011@D40@D510;2`/003
0;Rh^140oooo00@0L71`07MgM`1gMgL0UIFE0P1>CTh30:6QX@0409>CT`2?Shl0Xj>S0:>SX`<0IfMW
00D0PH6106ATI01:BTX0BTY:038b<P0205MGE`0506i^KP1eMGD0MGEe05iNGP1>CTh00P1?Cdl0101A
DE40MgMg07MgM`1IFET208J6QP050<S8b02VYZH0R8R808R8R02[Zj/00P1iNGT01@1dM7@0LG5a075a
L@2>SXh0Zj^[0080]KFe00D0QHF507inOP1nOWh0Q8B4096AT@020:j^[P040<k>cP33`l<0`l?309BD
U080B4Q800D0[:b/09JFUP2OWil0WinO09BDU00204Y:BP0507emO@2@T900T92@0;:b/P2m_Kd00P2U
YJD01@2i^KT0RHV908V9R@2DU9@0`L710080[jn_00@0WinO07UiN@1iNGT0_kno0P30`<001@1kNg/0
VYZJ075aL@1aLG40PX:20080V9RH00D0[Jf]06m_K`1_Kfl0O7al0;bl_0020;Jf]P0509^KV`1dM7@0
M7Ad08:2PP2KVi/00P34a<@0102j^[X0FUYJ05YJFP1PH6020=oOg`0509jNWP20P800RHV908V9R@1T
I6@00P1mOGd01@34a<@0_;bl0;bl_02j^[X0MWIf0080V9RH00@0W9bL0:FUY@2UYJD0RHV90P2BTY80
1@2g]kL0U9BD09^KV`2KVi/0GEeM0080DU9B00D0BDU904];B`1FEUH0EUIF06IVIP0207AdM005065Q
H@1[Jf/0Jf][04m?C`1oOgl00P1eMGD0101OGel0M7Ad07AdM01=CDd206e]K@0507]kN`2^[Zh0V9RH
09RHV020P8000P1mOGd01@2RXZ80UYJF07]kN`1kNg/0YJFU0080J6QX00@0F5QH06MWI`1WIfL0F5QH
2P3oool000X0oooo00@0Rh^;06i^KP1^KVh0X:2P0P2UYJD01@2XZ:P0]KFe0;^k^`2k^k/0Hf=S0080
FUYJ00D0Xj>S08n?S`2?Shl0WinO0:RXZ0020;2`/00504U9B@1CDe<0De=C08j>SP2EUID00P2@T900
102=SHd0V9RH09RHV01JFUX2065QH@0509^KV`2JVYX0SXj>08j>SP1mOGd00P1cLg<01@0j>SX0>CTi
05eMG@1MGEd0OWin0080I6AT00D0MgMg08J6QP1<C4`0C4a<07QhN00209FEU@0509VIV@2EUID0UIFE
0:RXZ02@T9000P1<C4`01@1_Kfl0Vi^K09^KV`2XZ:P0X:2P0080VYZJ00@0W9bL04i>CP1>CTh0LW9b
0P2_[jl01@2ZZZX0X:2P09jNWP2NWYh0Vi^K0080Bd];00D0KVi^0:ZZZP2XZ:P0Z:RX0:JVYP0209^K
V`0509fMW@19BDT0BDU909JFUP2h^;P00P2f][H01@2i^KT0_[jn0;jn_P2f][H0De=C0080WYjN00D0
/K6a0:b/[02/[:`0/;2`0;Zj^P020;^k^`0403dm?@2YZJT0ZJVY0;no_`80_;bl00D0]KFe0;:b/P2I
VIT0VIVI038b<P0207emO@0508f=S@2?Shl0TI6A096AT@21PH400P1RHV801@1ZJVX0[Zj^0:j^[P2c
/k<0]kNg0080`L7100D0`<3005EEE@1EEED0QXJ609nOW`020::RXP050:FUY@2PX:00X:2P079bLP0h
>3P00P2e]KD0102f][H0]kNg0;Ng]`2e]KD20;Ng]`0506ATI01eMGD0[jn_0:n_[`2WYjL00P2YZJT0
1@2][Jd0YjNW04M7A`17AdL0NWYj0080VIVI00D0XZ:R0:JVYP2VYZH0[jn_0;:b/P0204m?C`040;>c
/`2h^;P0^;Rh0;Rh^140oooo00@0O7al08J6QP26QXH0V9RH0P1ADE401@2JVYX0ZJVY0:VYZ@2GUiL0
TY:B0080Vi^K00D0K6a/05mOG`1OGel0P82007]kN`0205]KF`0404A4A01VIVH0IVIV07moO`80PX:2
00D0Lg=c071`L01^KVh0KVi^05YJFP02092@T00506QXJ026QXH0QXJ60;^k^`2MWId00P24Q8@0102e
]KD0N7Qh07QhN01hN7P207emO@0508j>SP2d];@0bLW90<W9b@2@T9000P2=SHd01@20P800RHV90:6Q
X@2QXJ40c<c<0080_;bl00D0Ti>C04A4A014A4@0VIVI08V9R@0208n?S`0408V9R@19BDT0BDU907al
O080Rh^;00D0^;Rh0<k>cP2TY:@0Y:BT0;fm_@0209>CT`05092@T03:b/X0Zj^[0:^[Z`2OWil00P1b
LW801@2XZ:P0_Kfm0;fm_@1lO7`0TI6A0080KFe]0`1mOGd01@2LW9`0PX:208:2PP2:RXX0`L710080
[Jf]00D0Vi^K06e]K@1]KFd0Ogmo0:JVYP020;Zj^P0409^KV`11@D40@D5105]KF`80`l?300D0V9RH
08:2PP1fMWH0MWIf065QH@0207UiN@050;jn_P2f][H0][Jf0;bl_01bLW800P2KVi/0102@T900Z:RX
0:RXZ01ZJVX209RHV0050:BTY02PX:00RXZ:08Z:RP1YJFT00P1IFET01@1ADE40Bd];055AD@1ADE40
M7Ad0080Q8B400D0Ng]k07QhN01hN7P0EUIF08Z:RP0208N7Q`0406UYJ@1hN7P0N7Qh051@D080QXJ6
00D0RXZ:08^;R`2EUID0UIFE09BDU00207AdM00507EeM@1jNWX0Ph>308>3P`2EUID00P1BDU80101K
Fe/0IVIV06IVIP1JFUX:0?ooo`002P3oool0102?Shl0MgMg07MgM`2ZZZX20:JVYP050;6a/@2n_[h0
_kno0;no_`1JFUX00P1cLg<01@2XZ:P0SXj>08j>SP2WYjL0];Bd0080[Jf]00D0A4A406UYJ@1YJFT0
W9bL092@T00208f=S@0408j>SP2QXJ40XJ6Q059BDP80IVIV00D0Shn?07moO`1_Kfl0Kfm_06e]K@02
065QH@0503@d=00i>CT0DE5A055AD@1IFET00P1KFe/01@1QHF40MGEe03hn?P0n?Sh0Ng]k0080Vi^K
00D0XJ6Q0:NWY`2WYjL0Z:RX09NGU`0204M7A`0507YjNP2OWil0WinO09NGU`2DU9@00P27QhL0102C
Ti<0DU9B059BDP1jNWX20:f][@050:RXZ02LW9`0TY:B09:BTP2MWId00P1:BTX01@1bLW80XZ:R0:FU
Y@2UYJD0Y:BT0080YjNW00D0UiNG03lo?`0o?cl0V9RH0;Rh^0030;Ng]`80^;Rh00D0/[:b04e=C@2I
VIT0VIVI0:VYZ@020:NWY`050:ZZZP2c/k<0^KVi0;Vi^@0k>c/00P2XZ:P01@2m_Kd0^[Zj0;Zj^P2h
^;P0^KVi0080Y:BT00D0=cLg0820P020P800R8R807moO`0207]kN`0408J6QP1XJ6P0J6QX079bLP80
/[:b00D0^;Rh0;Vi^@30`<00`<300;^k^`0205QHF00509jNWP2YZJT0YjNW0:NWY`2VYZH00P2QXJ40
1@1[Jf/0Bd];0;Fe]@2e]KD0/[:b0080[jn_00D0];Bd0;>c/`2c/k<0L71`07IfMP020;2`/0<0ZZZZ
00D0/K6a0:f][@0l?3`0?3`l07alO00209JFUP<0YJFU00D0Vi^K06IVIP19BDT0BDU90;:b/P020;Zj
^P030;Ng]`3oool0oooo00l0oooo00@0KVi^07=cL`1cLg<0QHF50P14A4@01@2:RXX0T92@092@T020
P800QhN70080T92@00D0K6a/05MGE`1GEeL0LW9b071`L00205MGE`0404U9B@1bLW80LW9b0861P@80
QHF500D0Kfm_07]kN`1]KFd0KFe]05EEE@0208>3P`0505YJFP24Q8@0Q8B40;Ng]`2HV9P00P28R8P0
102^[Zh0Ng]k07]kN`1kNg/20861P@0407]kN`2b/[80_;bl0;bl_0<0Ph>300D0OGem092@T02IVIT0
VIVI0=CDe0020;^k^`0509>CT`10@400@41009>CT`28R8P00P2BTY801022PX80ATI604I6AP1kNg/2
08:2PP050:>SX`2i^KT0ZJVY0:VYZ@2`/;000P2EUID01@29RHT0bLW90;Fe]@2e]KD0XJ6Q0080MWIf
00D0_kno0<C4a034a<@0Ogmo08J6QP0206m_K`0407QhN026QXH0QXJ609^KV`80N7Qh00D0RHV90;^k
^`2SXj<0Xj>S08Z:RP0206UYJ@0507UiN@2TY:@0^;Rh0;Rh^02i^KT00P1ADE401@1ZJVX0h^;R0>;R
hP25QHD0QXJ60080MGEe00@0IVIV075aL@1aLG40^;Rh0P2[Zj/01@2b/[80MWIf08b<S02<S8`0M7Ad
0080Zj^[00D0GemO09NGU`2GUiL0[:b/09bLW002096AT@0505IFEP1>CTh0CTi>04i>CP19BDT00P1E
EED0101VIVH0NWYj07YjNP1`L70206YZJP0505IFEP2;Rh/0TI6A096AT@1XJ6P00P1VIVH01@1BDU80
LW9b079bLP2:RXX0VIVI0080VYZJ00D0YjNW07alO01lO7`0MGEe07inOP0209:BTP040820P015ADD0
ADE506ATI080JFUY00<0IFEU0?ooo`3oool0203oool000X0oooo00@0Shn?07MgM`1gMgL0ZZZZ0P2V
YZH01@2a/K40_[jn0;no_`2o_kl0FUYJ0080Lg=c00D0Z:RX08j>SP2>SXh0YjNW0;Bd]0020:f][@05
04A4A01YJFT0JFUY09bLW02@T9000P2=SHd0102>SXh0XJ6Q0:6QX@1BDU8206IVIP0508n?S`1oOgl0
Kfm_06m_K`1]KFd00P1QHF401@0d=3@0>CTi055AD@1ADE40FEUI0080Fe]K00D0HF5Q07EeM@0n?Sh0
?Shn07]kN`0209^KV`050:6QX@2WYjL0YjNW0:RXZ02GUiL00P17AdL01@1jNWX0WinO09nOW`2GUiL0
U9BD0080QhN700@0Ti>C059BDP1BDU80NWYj0P2][Jd01@2XZ:P0W9bL09:BTP2BTY80WIfM0080BTY:
00D0LW9b0::RXP2UYJD0YJFU0:BTY0020:NWY`0509NGU`0o?cl0?clo09RHV02h^;P00`2g]kL20;Rh
^0050;:b/P1=CDd0VIVI09VIV@2YZJT00P2WYjL01@2ZZZX0/k>c0;Vi^@2i^KT0>c/k0080Z:RX00D0
_Kfm0;Zj^P2j^[X0^;Rh0;Vi^@020:BTY00503Lg=`20P800P82008R8R01oOgl00P1kNg/01026QXH0
J6QX06QXJ01bLW820;:b/P050;Rh^02i^KT0`<300<30`02k^k/00P1HF5P01@2NWYh0ZJVY0:NWY`2W
YjL0YZJV0080XJ6Q00D0Jf][04];B`2e]KD0]KFe0;:b/P020:n_[`050;Bd]02c/k<0/k>c071`L01f
MWH00P2`/;030:ZZZP050;6a/@2][Jd0?3`l03`l?01lO7`00P2FUYH30:FUY@0509^KV`1VIVH0BDU9
04U9B@2b/[800P2j^[X00`2g]kL0oooo0?ooo`0?0?ooo`0406i^KP1cLg<0Lg=c08F5Q@80A4A400D0
RXZ:092@T02@T900P82008N7Q`02092@T00506a/K01GEeL0EeMG079bLP1`L7000P1GEeL01019BDT0
LW9b079bLP21PH4208F5Q@0506m_K`1kNg/0KFe]06e]K@1EEED00P23Ph<01@1JFUX0Q8B408B4Q02g
]kL0V9RH0080R8R800@0[Zj^07]kN`1kNg/0Ng]k0P21PH40101kNg/0/[:b0;bl_02l_;`308>3P`05
07emO@2@T900VIVI09VIV@3De=@00P2k^k/01@2CTi<0@4100410@02CTi<0R8R80080TY:B00@0PX:2
04I6AP16ATH0Ng]k0P22PX801@2SXj<0^KVi0:VYZ@2YZJT0/;2`0080UIFE00D0RHV90<W9b@2e]KD0
]KFe0:6QX@0207IfMP050;no_`34a<@0a<C407moO`26QXH00P1_Kfl0101hN7P0QXJ608J6QP2KVi/2
07QhN00508V9R@2k^k/0Xj>S0:>SX`2:RXX00P1YJFT01@1iNGT0Y:BT0;Rh^02h^;P0^KVi0080DE5A
00D0JVYZ0>;RhP3Rh^80QHF508J6QP0207EeM@0406IVIP1aLG40LG5a0;Rh^080Zj^[00D0/[:b07If
MP2<S8`0S8b<07AdM0020:^[Z`0505mOG`2GUiL0UiNG0:b/[02LW9`00P2ATI401@1FEUH0CTi>04i>
CP1>CTh0BDU90080EEEE00@0IVIV07YjNP1jNWX0L71`0P1ZJVX01@1FEUH0Rh^;096AT@2ATI40J6QX
0080IVIV00D0DU9B079bLP1bLW80RXZ:09VIV@0209ZJVP050:NWY`1lO7`0O7al07EeM@1nOWh00P2B
TY801020P800ADE504E5A@1TI6@206UYJ@0306EUI@3oool0oooo00P0oooo000:0?ooo`0408f=S@1R
HV80HV9R09bLW0<0X:2P00@0YJFU09bLW02LW9`0Cdm?0P14A4@01@26QXH0V9RH09RHV02^[Zh0/K6a
0080XJ6Q00D0=3@d05aLG01LG5`0XJ6Q09:BTP02092@T00408f=S@2IVIT0VIVI04M7A`80;2`/00D0
R8R808Z:RP1eMGD0MGEe07alO00207emO@0504i>CP1IFET0MgMg07MgM`1eMGD00P1UIFD01@1LG5`0
P82004];B`1;Bd/0QHF50080VYZJ00D0Zj^[0;:b/P2b/[80ZJVY0:2PX00204=3@`05061PH02WYjL0
YjNW09nOW`2@T9000P22PX801028R8P0E5AD05ADE01`L70209VIV@0509fMW@2BTY80QXJ608J6QP1g
MgL00P13@d<01@1dM7@0WIfM08N7Q`27QhL0PX:20080V9RH00@0Vi^K06IVIP1VIVH0Vi^K0`2b/[80
1@2e]KD0Zj^[0:^[Z`2=SHd0@T920080VIVI00@0Xj>S0:ZZZP2ZZZX0/K6a0`2h^;P0101<C4`0Xj>S
0:>SX`2e]KD20;2`/0050:RXZ02TY:@0T92@092@T00b<S800P1;Bd/00`1NGUh0K6a/08>3P`0208>3
P`80G5aL00D0EUIF08b<S02<S8`0UiNG09JFUP0209RHV0050::RXP2ATI40TI6A0:f][@2b/[800P2a
/K401@2[Zj/0YZJV0:JVYP1bLW80I6AT0080][Jf0`2d];@01@2i^KT0^k^k0;^k^`1bLW80Ph>30080
/;2`00D0Zj^[0:b/[02/[:`0/;2`0:j^[P0204I6AP0407]kN`2^[Zh0[Zj^0:RXZ080X:2P00D0TY:B
07emO@1BDU80DU9B0;:b/P020;>c/`030;Bd]03oool0oooo00l0oooo00@0MWIf0820P020P800QXJ6
0P1:BTX01@2>SXh0V9RH09RHV02:RXX0UYJF0080V9RH00D0NGUi05EEE@1EEED0O7al06MWI`0204Y:
BP040451@@1/K6`0K6a/096AT@80R8R800D0LG5a06m_K`1@D500D51@04m?C`0205eMG@0505ADE01X
J6P0J6QX0::RXP2?Shl00P22PX80102TY:@0Lg=c07=cL`1oOgl207]kN`0506MWI`2/[:`0YjNW0:NW
Y`1^KVh00P1oOgl01@1bLW80P82009jNWP2NWYh0f][J0080aLG500D0TY:B05eMG@1MGEd0ZJVY09RH
V00209fMW@0408N7Q`18B4P0B4Q807YjNP80RXZ:00D0Zj^[0<?3``2g]kL0]kNg0:f][@02096AT@05
0820P034a<@0/k>c0;>c/`2RXZ800P26QXH00`32`/80a<C40<C4a00208V9R@80O7al00@0P82008R8
R028R8P0V9RH0P23Ph<01@1gMgL0[Zj^0;Bd]02d];@0TI6A0080MgMg00D0O7al0;^k^`2h^;P0^;Rh
0;2`/002059BDP0506=SH`3MgMd0gMgM09:BTP2:RXX00P1mOGd0101iNGT0OWin07inOP2k^k/20;Bd
]0050:FUY@1^KVh0OGem07emO@1dM7@00P2ATI401@1IFET0S8b<08b<S02CTi<0IfMW0080UiNG00D0
EeMG04];B`1;Bd/0@D5104A4A00205]KF`04071`L01lO7`0O7al06i^KP80FUYJ00D0EeMG07moO`25
QHD0QHF505UIF@0205eMG@0504m?C`1]KFd0KFe]0820P01PH6000P1`L7001@2LW9`0I6AT06ATI01m
OGd0MWIf0080SHf=00@0MgMg0451@@11@D40I6AT0P1bLW800`1cLg<0oooo0?ooo`080?ooo`002P3o
ool0101YJFT0F5QH05QHF01@D50203lo?`05038b<P0d=3@0=CDe03De=@0c<c<00P0k>c/01@19BDT0
Cdm?04m?C`1>CTh0De=C0080D51@00D0Bd];05EEE@1EEED0EUIF03lo?`0203Ti>@0404Q8B01=CDd0
CDe=055AD@80Bd];00D0D51@05=CD`1JFUX0FUYJ055AD@0204I6AP0503Xj>P0b<S80?Shn03hn?P0T
92@00P0Z:RX01@1<C4`0A4A403Xj>P0j>SX0Bd];0080CTi>00D0JFUY06][J`1[Jf/0Kfm_069RHP02
05=CD`0505mOG`1HF5P0F5QH02d];@1CDe<00P1JFUX01015ADD0B4Q804Q8B017AdL206QXJ005079b
LP1hN7P0D51@051@D01HF5P00P1GEeL01@1:BTX0>3Ph02@T900T92@0C4a<0080FEUI00D0GUiN05QH
F01HF5P0Fe]K06IVIP0306MWI`80FUYJ00D0De=C04U9B@1;Bd/0Bd];04M7A`0202l_;`0504];B`1J
FUX0HV9R069RHP1IFET00P1]KFd01@1aLG40J6QX06QXJ01VIVH0I6AT0080FUYJ00D0FEUI05ADE01D
E5@0@D5103Lg=`0204];B`0405MGE`12@T80@T9204E5A@80EUIF00D0FUYJ051@D01HF5P0F5QH06i^
KP0207moO`0507UiN@1^KVh0@T920492@P1GEeL00P1UIFD01@1QHF40IVIV08>3P`23Ph<0Q8B40080
OWin0`1lO7`01@1HF5P0GUiN05aLG01LG5`0DU9B0080EeMG00D0HV9R05eMG@1;Bd/0Bd];05eMG@02
069RHP0505eMG@1FEUH0EUIF05ADE012@T800P0k>c/0101=CDd0De=C05=CD`1FEUHA0?ooo`04075a
L@23Ph<0Ph>308J6QP80Cdm?00D0RHV909FEU@2EUID0R8R809BDU00209JFUP0507=cL`1CDe<0De=C
08^;R`1dM7@00P1ADE401011@D40IVIV06IVIP1gMgL207]kN`0506e]K@1bLW80BDU904U9B@1@D500
0P1OGel01@1PH600OGem07emO@2h^;P0YjNW0080Ph>300@0^[Zj0820P020P800QhN70P2?Shl01@1`
L700ZZZZ0;2`/02`/;00MWIf0080Ti>C00D0HF5Q075aL@2JVYX0VYZJ0=?Cd`020;Jf]P0509ZJVP1R
HV80HV9R0:6QX@2JVYX00P2FUYH01027QhL0Bd];04];B`1lO7`2096AT@050:f][@2/[:`0[jn_0:n_
[`2SXj<00P28R8P01@2:RXX0b<S80:j^[P2^[Zh0VYZJ0080Rh^;00D0alO70<c<c03<c<`0Shn?08R8
R00207IfMP0406m_K`2ATI40TI6A0:FUY@80TY:B00D0RHV90<;2`P2`/;00/;2`096AT@020820P005
07=cL`2h^;P0];Bd0;Bd]02^[Zh00P0k>c/01@1UIFD0g=cL0=cLg02IVIT0UIFE0080T92@00@0Kfm_
07alO01lO7`0`<300P2o_kl01@2UYJD0MgMg08R8R028R8P0Ph>30080PX:200D0MgMg09^KV`2KVi/0
YZJV06i^KP0209:BTP0504i>CP1BDU80DU9B03dm?@16ATH00P1PH600101iNGT0QhN708N7Q`1dM7@2
05aLG00506UYJ@27QhL0SXj>08j>SP1IFET00P1LG5`01@1:BTX0EUIF05IFEP1eMGD0QXJ60080QHF5
00D0ZJVY06m_K`1_Kfl0MWIf07emO@0209BDU00406=SH`11@D40@D5106=SH`80EEEE00<0I6AT0?oo
o`3oool0203oool000X0oooo00@0JFUY05QHF01HF5P0D51@0P0o?cl01@0b<S80=3@d03De=@0e=CD0
<c<c0080>c/k00D0BDU904m?C`1?Cdl0CTi>05=CD`02051@D00504];B`1EEED0EEEE05IFEP0o?cl0
0P0i>CT01018B4P0CDe=04e=C@1ADE4204];B`05051@D01CDe<0FUYJ05YJFP1ADE400P16ATH01@0j
>SX0<S8b03hn?P0n?Sh092@T0080:RXZ00D0C4a<04A4A00j>SX0>SXj04];B`0204i>CP0506UYJ@1[
Jf/0Jf][06m_K`1RHV800P1CDe<01@1OGel0F5QH05QHF00];Bd0De=C0080FUYJ00@0ADE504Q8B018
B4P0AdM70P1XJ6P01@1bLW80N7Qh051@D01@D500F5QH0080EeMG00D0BTY:03Ph>00T92@092@T04a<
C00205UIF@0505iNGP1HF5P0F5QH05]KF`1VIVH00`1WIfL205YJFP0505=CD`19BDT0Bd];04];B`17
AdL00P0_;bl01@1;Bd/0FUYJ069RHP1RHV80FEUI0080KFe]00D0LG5a06QXJ01XJ6P0IVIV06ATI002
05YJFP0505UIF@1DE5@0E5AD0451@@0g=cL00P1;Bd/0101GEeL0@T920492@P15ADD205IFEP0505YJ
FP1@D500F5QH05QHF01^KVh00P1oOgl01@1iNGT0KVi^0492@P12@T80EeMG0080IFEU00D0HF5Q06IV
IP23Ph<0Ph>308B4Q00207inOP<0O7al00D0F5QH05iNGP1LG5`0G5aL059BDP0205MGE`05069RHP1M
GEd0Bd];04];B`1MGEd00P1RHV801@1MGEd0EUIF05IFEP1DE5@0@T920080>c/k00@0CDe=05=CD`1C
De<0EUIF4@3oool0101aLG40Ph>308>3P`26QXH204m?C`0508V9R@2EUID0UIFE08R8R02DU9@00P2F
UYH01@1cLg<0De=C05=CD`2;Rh/0M7Ad0080DE5A00@0@D5106IVIP1VIVH0MgMg0P1kNg/01@1]KFd0
LW9b04U9B@19BDT0D51@0080GemO00D0H61P07emO@1mOGd0^;Rh0:NWY`0208>3P`040;Zj^P20P800
P82008N7Q`80Shn?00D0L71`0:ZZZP2`/;00/;2`07IfMP0209>CT`05065QH@1aLG40VYZJ09ZJVP3C
dm<00P2f][H01@2JVYX0HV9R069RHP2QXJ40VYZJ0080UYJF00@0QhN704];B`1;Bd/0O7al0P2ATI40
1@2][Jd0[:b/0:n_[`2_[jl0Xj>S0080R8R800D0RXZ:0<S8b02^[Zh0[Zj^09ZJVP0208^;R`050<O7
a`3<c<`0c<c<08n?S`28R8P00P1fMWH0101_Kfl0TI6A096AT@2UYJD209:BTP0508V9R@32`/80/;2`
0;2`/02ATI400P20P8001@1cLg<0^;Rh0;Bd]02d];@0[Zj^0080>c/k00D0IFEU0=cLg03Lg=`0VIVI
09FEU@02092@T00406m_K`1lO7`0O7al0<30`080_kno00D0YJFU07MgM`28R8P0R8R808>3P`0208:2
PP0507MgM`2KVi/0Vi^K0:JVYP1^KVh00P2BTY801@1>CTh0DU9B059BDP0m?Cd0ATI60080H61P00@0
NGUi08N7Q`27QhL0M7Ad0P1LG5`01@1YJFT0QhN708j>SP2>SXh0FEUI0080G5aL00D0BTY:05IFEP1F
EUH0MGEe08J6QP0208F5Q@050:VYZ@1_Kfl0Kfm_07IfMP1mOGd00P2DU9@0101SHf<0@D510451@@1S
Hf<205EEE@0306ATI03oool0oooo00P0oooo000:0?ooo`040:ZZZP2WYjL0YjNW09fMW@80KVi^00D0
=cLg08^;R`2LW9`0W9bL0:2PX0050:NWY`050:b/[02^[Zh0[Zj^0:j^[P2ZZZX00P2/[:`01@2XZ:P0
MWIf06=SH`1SHf<0T92@0080S8b<00D0W9bL08>3P`23Ph<0Q8B409ZJVP0209fMW@0509FEU@2=SHd0
SHf=07QhN02;Rh/00P2=SHd01@1QHF40HV9R069RHP2QXJ40YZJV0080YjNW00@0YJFU0::RXP2RXZ80
YZJV0P2[Zj/00`2^[Zh0/K6a0;6a/@020;6a/@80/[:b00@0C4a<09>CT`2XZ:P0Z:RX0`2OWil01@2I
VIT0Zj^[0:^[Z`2^[Zh0[:b/0080YZJV00D0XZ:R0:ZZZP2ZZZX0X:2P0:BTY00203`l?0040:JVYP2Z
ZZX0ZZZZ0:n_[`80Z:RX0P2UYJD20:b/[0050:^[Z`2^[Zh0[Zj^0;2`/02a/K400`2b/[820492@P05
09nOW`2XZ:P0/[:b0;:b/P2_[jl00P2a/K401@2h^;P0/K6a0;6a/@2b/[80[:b/0080YJFU00D0Z:RX
0:b/[02/[:`0W9bL08F5Q@020;Bd]0040;Rh^02ZZZX0ZZZZ0:FUY@80/K6a00D0[Zj^0;Jf]P2c/k<0
/k>c0;bl_0020;Zj^P050;6a/@2^[Zh0EUIF05IFEP2[Zj/00P2c/k<01@2i^KT0]kNg0;Zj^P2j^[X0
^k^k0080^[Zj00D0^;Rh0;6a/@2a/K40YjNW0:BTY0020:j^[P05071`L01TI6@0I6AT08f=S@2GUiL0
0P2RXZ800`2/[:`0/;2`0;2`/0030:j^[P050;:b/P2a/K40/k>c0;>c/`2g]kL00P2^[Zh00`1QHF40
oooo0?ooo`0?0?ooo`04069RHP1lO7`0O7al07emO@80BTY:00D0QHF509ZJVP2JVYX0TI6A09VIV@02
09BDU00507YjNP1ADE40DE5A07alO01^KVh00P1PH600101<C4`0L71`071`L02=SHd208n?S`0507Yj
NP1iNGT0BDU904U9B@1GEeL00P1[Jf/01@1XJ6P0QHF508F5Q@2c/k<0WIfM0080Ogmo00@0_kno08^;
R`2;Rh/0Shn?0P22PX801@1`L700WinO0:BTY02TY:@0OWin0080QXJ600D0Hf=S06a/K02RXZ80XZ:R
0=GEe@020:VYZ@050:6QX@1WIfL0IfMW09ZJVP2WYjL00P20P8001023Ph<0CTi>04i>CP21PH4209FE
U@050:FUY@2VYZH0_;bl0;bl_02RXZ800P2BTY801@1/K6`0^[Zj0:NWY`2WYjL0SXj>0080Ph>30`2o
_kl01@21PH40N7Qh07AdM01dM7@0JVYZ0080Ph>300D0TY:B08j>SP2>SXh0R8R80;fm_@020:VYZ@05
08:2PP1kNg/0Ng]k06IVIP2j^[X00P2^[Zh0102YZJT09RHV02HV9P1]KFd20=kNgP0508B4Q02RXZ80
PX:208:2PP1YJFT00P1`L7001@2/[:`0YZJV0:JVYP2JVYX0QHF50080Ogmo00@0S8b<07UiN@1iNGT0
K6a/0P23Ph<01@2PX:00LG5a09VIV@2IVIT0GUiN0080K6a/00D0@41004m?C`1QHF40HF5Q08J6QP02
09BDU00507EeM@1QHF40HF5Q069RHP2<S8`00P2QXJ40101DE5@0GEeM05eMG@1FEUH206QXJ00507in
OP1mOGd0Ph>308>3P`2_[jl00P1eMGD01@1jNWX0Ph>308V9R@29RHT0MGEe0080EUIF00@0KVi^06EU
I@1UIFD0GUiN2P3oool000X0oooo00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH01@1QHF40Z:RX09jNWP2N
WYh0RXZ:0080V9RH00D0X:2P09fMW@2MWId0WYjN0:6QX@020:BTY00509nOW`2TY:@0Y:BT0:>SX`28
R8P00P1XJ6P0102IVIT0VYZJ09ZJVP2RXZ8208b<S00508V9R@2?Shl0VYZJ09ZJVP2?Shl00P2>SXh0
1@2=SHd0UiNG096AT@2ATI40J6QX0080Q8B400D0Y:BT0:VYZ@2UYJD0YJFU0:6QX@0209jNWP0509bL
W02MWId0WIfM09nOW`2SXj<00P2VYZH01@2ZZZX0/[:b0;:b/P1XJ6P0VIVI0080ZJVY00@0WYjN09NG
U`2GUiL0SHf=0P2VYZH01@2ZZZX0YjNW0:VYZ@2YZJT0VIVI0080YZJV00D0XJ6Q0:BTY01OGel0GemO
0:2PX0020:BTY0050:JVYP2TY:@0Y:BT092@T02JVYX00P2TY:@01@2RXZ80YJFU0:FUY@2VYZH0ZZZZ
00<0[Jf]0P0o?cl01@2TY:@0Z:RX0:j^[P2^[Zh0/[:b0080/K6a00D0[Jf]0:BTY02TY:@0WinO0:ZZ
ZP020:f][@050;:b/P2a/K40/K6a0:2PX026QXH00`2h^;P20:f][@050:^[Z`2j^[X0^[Zj0;Fe]@2l
_;`00P2g]kL01@31`L40_kno0;no_`2i^KT0/k>c0080GUiN00D0[Zj^0;Bd]02d];@0][Jf0;jn_P02
0;fm_@<0`<3000D0_[jn0;:b/P2b/[80YZJV0:NWY`020;Fe]@0507IfMP1hN7P0N7Qh0:RXZ02[Zj/0
0P2XZ:P0102[Zj/0[Jf]0:f][@2WYjL20:VYZ@80YjNW0P2ZZZX0102[Zj/0[Jf]0:f][@1VIVHA0?oo
o`0405eMG@21PH40PH6107moO`80De=C00<0LW9b08b<S02<S8`00P2>SXh207inOP0506YZJP1BDU80
DU9B07emO@1OGel00P1VIVH0101GEeL0Ng]k07]kN`28R8P209NGU`0507IfMP20P800G5aL05aLG01O
Gel00P1fMWH01@1WIfL0RXZ:08Z:RP2a/K40XJ6Q0080RXZ:00<0^k^k08:2PP22PX800`21PH401@1`
L700W9bL0;Fe]@2e]KD0RHV90080W9bL00D0CTi>065QH@2HV9P0V9RH0<S8b0020:VYZ@0509RHV01`
L700L71`09NGU`2a/K400P22PX80101`L700DU9B059BDP1bLW8209NGU`0508n?S`2TY:@0^[Zj0;Zj
^P2ZZZX00P2FUYH01@1mOGd0_;bl09:BTP2BTY80Shn?0080SHf=00D0]kNg0<O7a`37alL0S8b<07Ad
M00207emO@0406i^KP2BTY80TY:B09^KV`80W9bL00D0QXJ60;jn_P2/[:`0[:b/08:2PP0207AdM005
05mOG`2g]kL0Xj>S0:>SX`2XZ:P00P0^;Rh01@1]KFd0e=CD0=CDe01kNg/0UiNG0080PH6100@0KFe]
07=cL`1cLg<0_[jn0P2o_kl01@2WYjL0^KVi07EeM@1eMGD0SXj>0080RXZ:00D0PH610820P020P800
Ph>308^;R`0209RHV00506a/K01NGUh0GUiN03dm?@1@D5000P1JFUX0101XJ6P0Rh^;08^;R`26QXH2
06MWI`0505eMG@27QhL0OWin07inOP1HF5P00P1EEED01@17AdL0G5aL05aLG01_Kfl0NGUi0080Rh^;
00@0[Zj^07alO01lO7`0Ogmo101iNGT204Q8B0<0GemO00<0KFe]0?ooo`3oool0203oool000X0oooo
00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH01@1QHF40Z:RX09jNWP2NWYh0RXZ:0080V9RH00D0X:2P09fM
W@2MWId0WYjN0:6QX@020:BTY00509nOW`2TY:@0Y:BT0:>SX`28R8P00P1XJ6P0102IVIT0VYZJ09ZJ
VP2RXZ8208b<S00508V9R@2?Shl0VYZJ09ZJVP2?Shl00P2>SXh01@2=SHd0UiNG096AT@2ATI40J6QX
0080Q8B400D0Y:BT0:VYZ@2UYJD0YJFU0:6QX@0209jNWP0509bLW02MWId0WIfM09nOW`2SXj<00P2V
YZH01@2ZZZX0/[:b0;:b/P1XJ6P0VIVI0080ZJVY00@0WYjN09NGU`2GUiL0SHf=0P2VYZH01@2ZZZX0
YjNW0:VYZ@2YZJT0VIVI0080YZJV00D0XJ6Q0:BTY01OGel0GemO0:2PX0020:BTY0050:JVYP2TY:@0
Y:BT092@T02JVYX00P2TY:@01@2RXZ80YJFU0:FUY@2VYZH0ZZZZ00<0[Jf]0P0o?cl01@2TY:@0Z:RX
0:j^[P2^[Zh0/[:b0080/K6a00D0[Jf]0:BTY02TY:@0WinO0:ZZZP020:f][@050;:b/P2a/K40/K6a
0:2PX026QXH00`2h^;P20:f][@050:^[Z`2j^[X0^[Zj0;Fe]@2l_;`00P2g]kL01@31`L40_kno0;no
_`2i^KT0/k>c0080GUiN00D0[Zj^0;Bd]02d];@0][Jf0;jn_P020;fm_@<0`<3000D0_[jn0;:b/P2b
/[80YZJV0:NWY`020;Fe]@0507IfMP1hN7P0N7Qh0:RXZ02[Zj/00P2XZ:P0102[Zj/0[Jf]0:f][@2W
YjL20:VYZ@80YjNW0P2ZZZX0102[Zj/0[Jf]0:f][@1VIVHA0?ooo`0405eMG@21PH40PH6107moO`80
De=C00<0LW9b08b<S02<S8`00P2>SXh207inOP0506YZJP1BDU80DU9B07emO@1OGel00P1VIVH0101G
EeL0Ng]k07]kN`28R8P209NGU`0507IfMP20P800G5aL05aLG01OGel00P1fMWH01@1WIfL0RXZ:08Z:
RP2a/K40XJ6Q0080RXZ:00<0^k^k08:2PP22PX800`21PH401@1`L700W9bL0;Fe]@2e]KD0RHV90080
W9bL00D0CTi>065QH@2HV9P0V9RH0<S8b0020:VYZ@0509RHV01`L700L71`09NGU`2a/K400P22PX80
101`L700DU9B059BDP1bLW8209NGU`0508n?S`2TY:@0^[Zj0;Zj^P2ZZZX00P2FUYH01@1mOGd0_;bl
09:BTP2BTY80Shn?0080SHf=00D0]kNg0<O7a`37alL0S8b<07AdM00207emO@0406i^KP2BTY80TY:B
09^KV`80W9bL00D0QXJ60;jn_P2/[:`0[:b/08:2PP0207AdM00505mOG`2g]kL0Xj>S0:>SX`2XZ:P0
0P0^;Rh01@1]KFd0e=CD0=CDe01kNg/0UiNG0080PH6100@0KFe]07=cL`1cLg<0_[jn0P2o_kl01@2W
YjL0^KVi07EeM@1eMGD0SXj>0080RXZ:00D0PH610820P020P800Ph>308^;R`0209RHV00506a/K01N
GUh0GUiN03dm?@1@D5000P1JFUX0101XJ6P0Rh^;08^;R`26QXH206MWI`0505eMG@27QhL0OWin07in
OP1HF5P00P1EEED01@17AdL0G5aL05aLG01_Kfl0NGUi0080Rh^;00@0[Zj^07alO01lO7`0Ogmo101i
NGT204Q8B0<0GemO00<0KFe]0?ooo`3oool0203oool000X0oooo00@0[jn_0:VYZ@2YZJT0[:b/0P1M
GEd01@17AdL0YJFU09nOW`2OWil0SHf=0080TI6A00D0XZ:R0:JVYP2VYZH0YjNW0:BTY0020:2PX005
09jNWP2WYjL0YjNW0:BTY02<S8`00P1UIFD0102QXJ40XZ:R0::RXP2UYJD209nOW`0509ZJVP2<S8`0
S8b<08b<S02IVIT00P22PX801@1hN7P0QhN708f=S@2=SHd0JFUY0080Q8B400D0Xj>S09^KV`2QXJ40
XJ6Q09jNWP0209VIV@0508J6QP29RHT0RHV909^KV`2OWil00P2KVi/01@2VYZH0[:b/0:b/[01ZJVX0
W9bL0080Z:RX0`2SXj<01@2ATI40XZ:R0::RXP2QXJ40YJFU0080Zj^[00D0XZ:R0:FUY@2UYJD0Xj>S
09fMW@0205eMG@030::RXP2MWId0WIfM00<0VYZJ00D0U9BD09ZJVP2GUiL0UiNG08f=S@020:2PX005
0:BTY02VYZH0Z:RX0:RXZ02][Jd00P1>CTh01@2TY:@0XZ:R0:BTY02TY:@0[Jf]0080[:b/00D0[Zj^
0:FUY@2UYJD0XZ:R0:n_[`020;2`/0<0[Jf]00D0X:2P08B4Q02h^;P0^;Rh0;bl_0020;:b/P050:j^
[P2f][H0][Jf0;Jf]P2n_[h00P2k^k/01@32`/80_Kfm0;fm_@2l_;`0]kNg0080Kfm_0`2b/[801@2k
^k/0`/;20;bl_02l_;`0_[jn0080_Kfm00D0^k^k0:^[Z`2[Zj/0XJ6Q0:VYZ@020;>c/`0506QXJ01a
LG40LG5a0:2PX02VYZH00P2ZZZX0102YZJT0YZJV0:JVYP2NWYh209fMW@050:2PX02QXJ40Z:RX0:RX
Z02SXj<00P2XZ:P00`1gMgL0oooo0?ooo`0?0?ooo`0406EUI@2<S8`0S8b<08B4Q080DU9B00D0O7al
0:2PX02PX:00WIfM09>CT`0208R8R00507UiN@1QHF40HF5Q07alO01ZJVX00P1VIVH0101JFUX0Jf][
06][J`1cLg<208>3P`0504m?C`20P800FUYJ05YJFP1=CDd00P1_Kfl01@1SHf<0RXZ:08Z:RP2][Jd0
VYZJ0080QXJ600@0/;2`08>3P`23Ph<0T92@0P1oOgl01@1UIFD0Shn?0:b/[02/[:`0UYJF0080WinO
00D0EUIF06e]K@2_[jl0[jn_0<g=c@020;Ng]`050;Fe]@1gMgL0MgMg09RHV030`<000P1oOgl0101g
MgL0D51@051@D024Q8@20:>SX`0509^KV`2c/k<0a<C40<C4a02`/;000P2/[:`01@22PX80bLW909jN
WP2NWYh0SHf=0080TY:B00D0ZZZZ0;bl_02l_;`0R8R8061PH00207=cL`0406UYJ@1mOGd0OGem096A
T@80VIVI00D0Shn?0<;2`P2VYZH0YZJV07emO@0207YjNP0505QHF02j^[X0YjNW0:NWY`2`/;000P0n
?Sh01@1]KFd0g=cL0=cLg025QHD0XJ6Q0080MgMg0`1aLG401@2l_;`0^KVi0;Vi^@2WYjL0/[:b0080
Rh^;00@0WYjN08B4Q024Q8@0IfMW0P1nOWh01@1dM7@0UYJF09BDU02DU9@0JVYZ0080BDU900D0=CDe
04Q8B01JFUX0FUYJ05IFEP0207UiN@0507inOP1ZJVX0JVYZ05eMG@2;Rh/00P2=SHd0101UIFD0J6QX
06QXJ01`L70206m_K`0507alO02DU9@0Ti>C09>CT`2c/k<00P27QhL208>3P`80QXJ600@0JFUY04e=
C@1=CDd0HF5Q0P1GEeL00`1[Jf/0oooo0?ooo`080?ooo`002P3oool30;Rh^0050;Jf]P1bLW80LW9b
0451@@2MWId00P2SXj<0102PX:00Xj>S0:>SX`2MWId209nOW`050:FUY@2XZ:P0[Zj^0:j^[P2/[:`0
0P2WYjL01@2QXJ40Q8B406=SH`1SHf<0Ti>C0080XJ6Q00D0YZJV0:BTY02TY:@0XJ6Q09nOW`0209fM
W@0509ZJVP29RHT0RHV907EeM@1kNg/00P2IVIT01@1UIFD0Q8B408B4Q02RXZ80W9bL0080WinO00@0
WIfM0:6QX@2QXJ40S8b<0P24Q8@01@1nOWh0R8R808Z:RP2:RXX0XZ:R0080UIFE00D0ADE509JFUP2H
V9P0V9RH08B4Q00209RHV00509^KV`2ZZZX0ZZZZ0:RXZ02WYjL00P2VYZH01@2MWId0WinO09nOW`2N
WYh0VYZJ0080AdM700<0PH6108F5Q@25QHD00`1lO7`01@1iNGT0Q8B408J6QP26QXH0Ti>C0080VYZJ
00D0WinO0:NWY`2XZ:P0Z:RX0:ZZZP0204i>CP80WinO0P2VYZH0102/[:`0ZZZZ0:ZZZP2UYJD209ZJ
VP0509FEU@2HV9P0WYjN09jNWP2QXJ400P2LW9`01@1nOWh0N7Qh0;2`/02`/;00/[:b0080Y:BT00D0
XJ6Q0;Bd]02d];@0^KVi0;^k^`020;Ng]`050;Vi^@2m_Kd0_Kfm0;Vi^@2e]KD00P1aLG401@2PX:00
Xj>S0:>SX`2c/k<0]kNg00<0^;Rh0P2c/k<01@2b/[80Xj>S0:>SX`2GUiL0Xj>S0080[jn_00@0Fe]K
06ATI01TI6@0Zj^[0`2UYJD0102VYZH0Xj>S0:>SX`2LW9`309nOW`0409VIV@2NWYh0WYjN0:JVYP80
X:2P00<0Ph>30?ooo`3oool03`3oool0101`L700SHf=08f=S@1lO7`2055AD@05071`L02BTY80TY:B
09:BTP2IVIT00P2BTY80101mOGd0GemO05mOG`1hN7P306EUI@04051@D01DE5@0E5AD04=3@`80PX:2
00D0Jf][07QhN012@T80@T9203Ph>00206YZJP0505eMG@1cLg<0Lg=c0:JVYP2MWId00P1kNg/0102]
[Jd0Ph>308>3P`22PX820861P@0506e]K@2DU9@0/K6a0;6a/@2;Rh/00P2FUYH01@1ADE40E5AD092@
T02@T900YZJV0080UYJF00D0UIFE06i^KP1^KVh0OWin0::RXP0207QhN00407UiN@1CDe<0De=C08^;
R`80][Jf00D0UIFE0:n_[`35aLD0aLG50:BTY00209bLW00508N7Q`3Hf=P0[Jf]0:f][@2?Shl00P2@
T9001@2i^KT0d=3@0=3@d02SXj<0Ng]k0080Ogmo00@0MWIf08b<S02<S8`0NWYj0P2?Shl01@23Ph<0
Z:RX09JFUP2FUYH0Lg=c0080IFEU00D0CDe=0:ZZZP2f][H0][Jf0:j^[P0204=3@`0506m_K`3Jf]X0
f][J07UiN@2GUiL00P1eMGD0101/K6`0Jf][06][J`2c/k<20;no_`050:BTY02CTi<0TY:B09:BTP2:
RXX00P2EUID01@1_Kfl0UYJF09JFUP1_Kfl0YZJV0080UiNG00D0NWYj05UIF@1IFET0>c/k055AD@02
04m?C`04065QH@1]KFd0KFe]06a/K080Kfm_00D0I6AT08Z:RP24Q8@0Q8B4075aL@0206e]K@05069R
HP24Q8@0Q8B40861P@2<S8`00P27QhL01@2f][H0P8200820P023Ph<0QXJ60080U9BD00@0Jf][0492
@P12@T80EeMG0P1PH6000`1DE5@0oooo0?ooo`080?ooo`002P3oool0101VIVH0JFUY06UYJ@1TI6@2
05ADE00503lo?`1@D500GUiN05iNGP1KFe/00P1WIfL01@1NGUh0A4A404A4A011@D40BTY:00<0Bd];
0P0/;2`01@0[:b/0;Rh^02l_;`0_;bl0<c<c0080@D5100D0Bd];05YJFP1JFUX0Cdm?03dm?@0203@d
=00503Xj>P0i>CT0>CTi05UIF@1@D5000P1RHV801@14A4@0Fe]K05]KF`1YJFT0IfMW0080Fe]K00@0
CDe=0410@010@400=cLg0P0l?3`00`19BDT0Cdm?055AD@02055AD@80=CDe00D0:2PX03`l?010@400
@41003hn?P0203dm?@050410@01=CDd0CDe=03Ti>@0a<C400P0n?Sh01@0o?cl0@4100410@012@T80
?3`l0080=3@d00@0<30`03/k>`0k>c/0<30`0P0f=SH01@0_;bl0;Rh^02@T900T92@0<S8b0080>c/k
00D0De=C04Q8B01?Cdl0Cdm?04U9B@0202h^;P0504Q8B01=CDd0EEEE05EEE@1IFET00P1<C4`01@1A
DE40<S8b038b<P14A4@0ATI60080FEUI00D0Fe]K05mOG`1OGel0K6a/06IVIP02061PH00406ATI01K
Fe/0Fe]K04I6AP80?clo00D0=3@d038b<P1=CDd0CDe=04Y:BP02059BDP05051@D01CDe<0BTY:04Y:
BP19BDT00P1BDU801@1MGEd0F5QH05]KF`1KFe/0EEEE0080IVIV00D0GemO065QH@1QHF40F5QH06YZ
JP0206][J`0504Y:BP0c<c<0<c<c04a<C01;Bd/00P13@d<01012@T80@D510451@@1>CTh205MGE`05
04m?C`1OGel0De=C05=CD`1>CTh00P18B4P00`0i>CT0oooo0?ooo`0?0?ooo`04071`L028R8P0R8R8
09>CT`80FEUI00D0Ogmo09JFUP2FUYH0UYJF09NGU`0208f=S@0507emO@1KFe/0Fe]K06i^KP1`L700
0P1_Kfl0101fMWH0Ph>308>3P`1YJFT20820P00506a/K01YJFT0ADE504E5A@0f=SH00P1bLW801@1c
Lg<0S8b<08b<S02WYjL0S8b<0080L71`00<0];Bd09BDU02DU9@00`28R8P01@1SHf<0Shn?0;>c/`2c
/k<0TI6A0080V9RH00D0GemO06=SH`2/[:`0[:b/0;Fe]@020;>c/`050:FUY@24Q8@0Q8B408J6QP2a
/K400P20P800101jNWX0D51@051@D024Q8@209nOW`0508f=S@2n_[h0aLG50<G5a@2RXZ800P2GUiL0
1@21PH40f=SH0:f][@2][Jd0V9RH0080Vi^K00D0^[Zj0<o?c`3?cll0ZZZZ07IfMP0207MgM`0406IV
IP2CTi<0Ti>C0861P@80VIVI00D0SXj>0:j^[P2VYZH0YZJV092@T00206i^KP0505IFEP36a/H0^[Zj
0;Zj^P2_[jl00P1<C4`01@1[Jf/0g]kN0=kNgP1fMWH0Zj^[0080RHV900@0K6a/06QXJ01XJ6P0ZJVY
0P36a/H01@2[Zj/0O7al092@T02@T900SHf=0080TY:B00D0LW9b09>CT`2CTi<0J6QX0:VYZ@020:>S
X`0507=cL`1:BTX0BTY:03Lg=`1<C4`00P1;Bd/0101iNGT0IFEU06EUI@1XJ6P206][J`0506IVIP22
PX80NWYj07YjNP1YJFT00P1/K6`01@1bLW80Ph>308>3P`2=SHd0Xj>S0080Z:RX00D0^[Zj08b<S02<
S8`0QHF507QhN00209>CT`0407inOP1FEUH0EUIF05YJFP80Fe]K00<0FEUI0?ooo`3oool0203oool0
00X0oooo00@0IVIV06UYJ@1YJFT0I6AT0P1DE5@01@0o?cl0D51@05iNGP1NGUh0Fe]K0080IfMW00D0
GUiN04A4A014A4@0@D5104Y:BP0304];B`80;2`/00D0:b/[02h^;P0_;bl0;bl_03<c<`020451@@05
04];B`1JFUX0FUYJ04m?C`0m?Cd00P0d=3@01@0j>SX0>CTi03Ti>@1IFET0D51@0080HV9R00D0A4A4
05]KF`1KFe/0JFUY06MWI`0205]KF`0404e=C@10@400@41003Lg=`80?3`l00<0BDU904m?C`1ADE40
0P1ADE4203De=@0502PX:00l?3`0@4100410@00n?Sh00P0m?Cd01@10@400CDe=04e=C@0i>CT0<C4a
0080?Shn00D0?clo0410@010@400@T9203`l?00203@d=004030`<00k>c/0>c/k030`<080=SHf00D0
;bl_02h^;P0T92@092@T038b<P0203/k>`0505=CD`18B4P0Cdm?04m?C`19BDT00P0^;Rh01@18B4P0
CDe=05EEE@1EEED0FEUI0080C4a<00D0DE5A038b<P0b<S80A4A404I6AP0205UIF@0505]KF`1OGel0
GemO06a/K01VIVH00P1PH600101TI6@0Fe]K05]KF`16ATH203lo?`0503@d=00b<S80CDe=04e=C@1:
BTX00P1BDU801@1@D500De=C04Y:BP1:BTX0BDU90080DU9B00D0GEeM05QHF01KFe/0Fe]K05EEE@02
06IVIP0505mOG`1QHF40HF5Q05QHF01ZJVX00P1[Jf/01@1:BTX0<c<c03<c<`1<C4`0Bd];0080@d=3
00@0@T920451@@11@D40CTi>0P1GEeL01@1?Cdl0GemO05=CD`1CDe<0CTi>0080B4Q800<0>CTi0?oo
o`3oool03`3oool0101`L700R8R808R8R02CTi<205UIF@0507moO`2FUYH0UYJF09JFUP2GUiL00P2=
SHd01@1mOGd0Fe]K05]KF`1^KVh0L71`0080Kfm_00@0MWIf08>3P`23Ph<0JFUY0P20P8001@1/K6`0
JFUY04E5A@15ADD0=SHf0080LW9b00D0Lg=c08b<S02<S8`0YjNW08b<S002071`L0030;Bd]02DU9@0
U9BD00<0R8R800D0Hf=S08n?S`2c/k<0/k>c096AT@0209RHV00505mOG`1SHf<0[:b/0:b/[02e]KD0
0P2c/k<01@2UYJD0Q8B408B4Q026QXH0/K6a0080P82000@0NWYj051@D01@D500Q8B40P2OWil01@2=
SHd0_[jn0<G5a@35aLD0XZ:R0080UiNG00D0PH610=SHf02][Jd0[Jf]09RHV00209^KV`050;Zj^P3?
cll0clo?0:ZZZP1fMWH00P1gMgL0101VIVH0Ti>C09>CT`21PH4209VIV@0508j>SP2^[Zh0YZJV0:JV
YP2@T9000P1^KVh01@1FEUH0a/K60;Zj^P2j^[X0[jn_0080C4a<00D0Jf][0=kNgP3Ng]h0MWIf0:^[
Z`0208V9R@0406a/K01XJ6P0J6QX0:VYZ@80a/K600D0Zj^[07alO02@T900T92@08f=S@0209:BTP05
079bLP2CTi<0Ti>C06QXJ02YZJT00P2SXj<01@1cLg<0BTY:04Y:BP0g=cL0C4a<0080Bd];00@0NGUi
06EUI@1UIFD0J6QX0P1[Jf/01@1VIVH0PX:207YjNP1jNWX0JFUY0080K6a/00D0LW9b08>3P`23Ph<0
SHf=0:>SX`020:RXZ0050;Zj^P2<S8`0S8b<08F5Q@1hN7P00P2CTi<0101nOWh0EUIF05IFEP1JFUX2
05]KF`0305UIF@3oool0oooo00P0oooo000:0?ooo`040:RXZ02SXj<0Xj>S0:>SX`80XJ6Q00D0X:2P
0:>SX`2UYJD0YJFU09jNWP0209bLW00509FEU@1FEUH0EUIF069RHP2`/;000P2[Zj/01@2RXZ80ZZZZ
0:ZZZP2UYJD0YjNW0080Z:RX00<0ZJVY0;2`/02`/;000`2c/k<01@2`/;00DU9B05EEE@1EEED0T92@
0080U9BD00D0UIFE0:2PX02VYZH0YZJV0:n_[`020;2`/0050::RXP2MWId0VYZJ09ZJVP2VYZH00P2M
WId01@1LG5`0B4Q804Q8B02XZ:P0Xj>S0080X:2P00<0Z:RX0:ZZZP2ZZZX00P2TY:@20:6QX@040:BT
Y02/[:`0[:b/0:n_[`80/K6a00D0OGem02`/;020P800P82008V9R@0209>CT`0509FEU@2MWId0UYJF
09JFUP2HV9P00P2CTi<01@2KVi/0UIFE09FEU@2TY:@0UIFE0080?Cdm00D0GemO06EUI@1UIFD0K6a/
06e]K@0207IfMP0508F5Q@2CTi<0Ti>C09VIV@2BTY800P29RHT01025QHD0Vi^K09^KV`1TI6@204a<
C0050;:b/P2e]KD0/k>c0;>c/`2[Zj/00P2c/k<01@2k^k/0_Kfm0;fm_@2m_Kd0`/;20080][Jf00D0
UiNG07alO01lO7`0FUYJ08:2PP020<_;b`050<?3``2m_Kd0_Kfm0;Ng]`2e]KD00P2g]kL00`2c/k<0
/[:b0;:b/P020;Jf]P80V9RH00<0L71`0;Jf]P2f][H00`2j^[X01@2a/K40/;2`0;Fe]@2e]KD0^;Rh
0080/k>c00D0[Zj^0;2`/02_[jl0[jn_08B4Q00203`l?0050:FUY@2NWYh0WYjN0::RXP2b/[800P2e
]KD0102c/k<0[Zj^0:j^[P2^[ZhA0?ooo`0407MgM`2CTi<0Ti>C09RHV080FUYJ00D0R8R809jNWP2N
WYh0XJ6Q09bLW00208j>SP0507EeM@1IFET0FEUI06][J`1XJ6P00P1RHV80101YJFT0MGEe07EeM@1/
K6`208:2PP0506IVIP1cLg<0F5QH05QHF01:BTX00P1VIVH01@1hN7P0SXj>08j>SP2ZZZX0RHV90080
OGem00@0Xj>S07]kN`1kNg/0IfMW0P1gMgL01@1JFUX0QhN70;Rh^02h^;P0UiNG0080U9BD00D0I6AT
069RHP2o_kl0_kno0;Fe]@020<C4a0050:NWY`2CTi<0Ti>C07moO`2WYjL00P25QHD0101nOWh0EEEE
05EEE@2=SHd20:VYZ@0509ZJVP33`l<0bLW90<W9b@2TY:@00P2IVIT01@20P800h>3P0:n_[`2_[jl0
XJ6Q0080X:2P00D0_kno0=;BdP3Bd]80VYZJ07EeM@0208F5Q@0406EUI@2UYJD0YJFU08>3P`80Vi^K
00D0SHf=0;2`/02YZJT0ZJVY08j>SP0206MWI`0504i>CP2g]kL0Zj^[0:^[Z`2UYJD00P1CDe<01@1J
FUX0d=3@0=3@d01^KVh0Y:BT0080P82000@0KVi^065QH@1QHF40/[:b0P3=cLd01@2b/[80Ph>308Z:
RP2:RXX0S8b<0080QXJ600D0NGUi09bLW02LW9`0HV9R09nOW`020::RXP0507=cL`18B4P0B4Q803Ph
>017AdL00P18B4P01020P800DU9B059BDP1oOgl207QhN00306QXJ028R8P0KVi^0080KVi^0P1SHf<0
1@1eMGD0V9RH09RHV02FUYH0Rh^;0080UYJF00D0`<3009>CT`2CTi<0S8b<08n?S`020:>SX`0409BD
U01[Jf/0Jf][06YZJP<0IFEU2P3oool000X0oooo00@0YZJV09fMW@2MWId0VYZJ0P2@T90208b<S080
WIfM00@0UYJF08j>SP2>SXh0Shn?0P1MGEd01@1[Jf/0[Jf]0:j^[P2^[Zh0XZ:R0080Xj>S00D0XJ6Q
0::RXP2RXZ80XZ:R0:NWY`020:VYZ@050;>c/`2d];@0];Bd0:n_[`1oOgl00P1WIfL01@2GUiL0Ng]k
07]kN`1iNGT0W9bL0080X:2P00D0WinO09VIV@2IVIT0VIVI08b<S00208n?S`0408Z:RP28R8P0R8R8
065QH@80=SHf00D0UYJF0:2PX02IVIT0VIVI09fMW@020:6QX@0509fMW@2NWYh0R8R808R8R02SXj<0
0P2ZZZX30:j^[P050861P@15ADD0YjNW0:NWY`2SXj<00P2VYZH01@2TY:@0YZJV0:JVYP2VYZH0Z:RX
0080YZJV00D0YjNW08^;R`2;Rh/0XZ:R0:VYZ@0205YJFP0506EUI@1bLW80LW9b07IfMP23Ph<00P1k
Ng/01@1aLG40O7al07alO025QHD0Q8B40080Ng]k00@0PH6107YjNP1jNWX0HF5Q0P0o?cl01@2NWYh0
[Zj^0:j^[P2^[Zh0Xj>S0080[Jf]00D0/K6a0;:b/P2d];@0];Bd0;Jf]P030;Bd]080]KFe00@0KFe]
09:BTP2k^k/0^k^k0`2h^;P01@2d];@0/K6a0;6a/@2a/K40[Jf]0080/K6a00<0/;2`0:VYZ@1_Kfl0
0P1_Kfl20;Ng]`050;Jf]P2e]KD0]KFe0;Bd]02g]kL00P2e]KD01@2g]kL0];Bd0;Bd]02_[jl0[Jf]
0080[Zj^00@0WIfM059BDP1BDU80XZ:R0P2SXj<01@2VYZH0/k>c0;6a/@2a/K40[Zj^0080[Jf]00<0
/[:b0?ooo`3oool03`3oool0101bLW80QhN708N7Q`20P80204e=C@0508R8R02JVYX0VYZJ09NGU`2?
Shl00P2BTY801@1gMgL0GUiN05iNGP1[Jf/0L71`0080Jf][00@0Hf=S07UiN@1iNGT0G5aL0P20P800
1@1mOGd0DE5A02d];@0];Bd0DE5A0080I6AT00D0MgMg08J6QP26QXH0/[:b08b<S00208J6QP040:n_
[`2EUID0UIFE07alO080Kfm_00D0BTY:06m_K`2RXZ80XZ:R08j>SP0208:2PP0505eMG@1@D500[Jf]
0:f][@2^[Zh00P2j^[X01@2KVi/0XZ:R0::RXP1hN7P0Vi^K0080Q8B400@0M7Ad05]KF`1KFe/0P820
0P2/[:`01@2GUiL0_Kfm0<71`@31`L40ZJVY0080Vi^K00D0OGem0=gMg@2[Zj/0Zj^[09RHV00209jN
WP050;Ng]`3@d=00d=3@09nOW`1]KFd00P1[Jf/0101FEUH0UiNG09NGU`22PX8209VIV@0508^;R`2a
/K40[Jf]0:f][@2LW9`00P1UIFD01@1;Bd/0_[jn0;Ng]`2g]kL0`L710080De=C00D0G5aL0=CDe03D
e=@0JVYZ0::RXP0207alO00406EUI@1SHf<0Hf=S09VIV@80[jn_00D0WYjN08N7Q`22PX80PX:20820
P00209FEU@0507UiN@2TY:@0Y:BT061PH02YZJT00P2KVi/01@1/K6`0@4100410@00e=CD0B4Q80080
CTi>00@0MWIf05]KF`1KFe/0LG5a0P1eMGD01@1iNGT0UYJF07EeM@1eMGD0NGUi0080HV9R00D0JFUY
0820P020P800LG5a07]kN`0207UiN@0509ZJVP1dM7@0M7Ad07moO`1iNGT00P2FUYH0102=SHd0LG5a
075aL@1gMgL207YjNP0307UiN@3oool0oooo00P0oooo000:0?ooo`040:JVYP2MWId0WIfM09ZJVP80
T92@0P2<S8`209fMW@0409JFUP2>SXh0SXj>08n?S`80GEeM00D0Jf][0:f][@2^[Zh0[Zj^0::RXP02
0:>SX`050:6QX@2RXZ80XZ:R0::RXP2WYjL00P2YZJT01@2c/k<0];Bd0;Bd]02_[jl0Ogmo0080IfMW
00D0UiNG07]kN`1kNg/0NGUi09bLW0020:2PX00509nOW`2IVIT0VIVI09VIV@2<S8`00P2?Shl0102:
RXX0R8R808R8R01QHF4203Hf=P0509JFUP2PX:00VIVI09VIV@2MWId00P2QXJ401@2MWId0WYjN08R8
R028R8P0Xj>S0080ZZZZ0`2^[Zh01@21PH40ADE50:NWY`2WYjL0Xj>S0080YZJV00D0Y:BT0:JVYP2V
YZH0YZJV0:RXZ0020:JVYP050:NWY`2;Rh/0Rh^;0::RXP2YZJT00P1JFUX01@1UIFD0LW9b079bLP1f
MWH0Ph>30080Ng]k00D0LG5a07alO01lO7`0QHF508B4Q00207]kN`040861P@1jNWX0NWYj065QH@80
?clo00D0WYjN0:j^[P2^[Zh0[Zj^0:>SX`020:f][@050;6a/@2b/[80];Bd0;Bd]02f][H00`2d];@2
0;Fe]@0406e]K@2BTY80^k^k0;^k^`<0^;Rh00D0];Bd0;6a/@2a/K40/K6a0:f][@020;6a/@030;2`
/02YZJT0Kfm_0080Kfm_0P2g]kL01@2f][H0]KFe0;Fe]@2d];@0]kNg0080]KFe00D0]kNg0;Bd]02d
];@0[jn_0:f][@020:j^[P0409fMW@1BDU80DU9B0::RXP80Xj>S00D0YZJV0;>c/`2a/K40/K6a0:j^
[P020:f][@030;:b/P3oool0oooo00l0oooo00@0LW9b08N7Q`27QhL0P8200P1=CDd01@28R8P0VYZJ
09ZJVP2GUiL0Shn?0080TY:B00D0MgMg05iNGP1NGUh0Jf][071`L00206][J`0406=SH`1iNGT0NGUi
05aLG080P82000D0OGem055AD@0];Bd0;Bd]055AD@0206ATI00507MgM`26QXH0QXJ60;:b/P2<S8`0
0P26QXH0102_[jl0UIFE09FEU@1lO7`206m_K`0504Y:BP1_Kfl0XZ:R0::RXP2>SXh00P22PX801@1M
GEd0D51@0:f][@2][Jd0[Zj^0080^[Zj00D0Vi^K0::RXP2RXZ80N7Qh09^KV`0208B4Q00407AdM01K
Fe/0Fe]K0820P080[:b/00D0UiNG0;fm_@31`L40`L710:VYZ@0209^KV`0507emO@3MgMd0Zj^[0:^[
Z`2HV9P00P2NWYh01@2g]kL0d=3@0=3@d02OWil0KFe]0080Jf][00@0EUIF09NGU`2GUiL0PX:20P2I
VIT01@2;Rh/0/K6a0:f][@2][Jd0W9bL0080IFEU00D0Bd];0;jn_P2g]kL0]kNg0<71`@0205=CD`05
05aLG03De=@0e=CD06YZJP2RXZ800P1lO7`0101UIFD0Hf=S06=SH`2IVIT20:n_[`0509jNWP27QhL0
PX:208:2PP20P8000P2EUID01@1iNGT0Y:BT0:BTY01PH600ZJVY0080Vi^K00D0K6a/0410@010@400
=CDe04Q8B00204i>CP0407IfMP1KFe/0Fe]K075aL@80MGEe00D0NGUi09JFUP1eMGD0MGEe07UiN@02
069RHP0506UYJ@20P800P820075aL@1kNg/00P1iNGT01@2JVYX0M7Ad07AdM01oOgl0NGUi0080UYJF
00@0SHf=075aL@1aLG40MgMg0P1jNWX00`1iNGT0oooo0?ooo`080?ooo`002P3oool0102XZ:P0Xj>S
0:>SX`2PX:0309:BTP0408:2PP2DU9@0U9BD09FEU@80Rh^;00D0Q8B4065QH@1QHF40IVIV0:^[Z`02
0:b/[0050::RXP2MWId0WIfM09fMW@2JVYX00P2TY:@0102PX:00YZJV0:JVYP2ZZZX20;6a/@050:^[
Z`20P800J6QX06QXJ02CTi<00P21PH401@26QXH0RXZ:08f=S@2=SHd0[:b/0080ZJVY00D0[Zj^0:^[
Z`2/[:`0[:b/0:NWY`0209RHV00506YZJP0];Bd0;Bd]09ZJVP2WYjL00P2TY:@01@2ZZZX0YZJV0:JV
YP2SXj<0WinO0080T92@00@0Y:BT0:f][@2][Jd0/k>c0P2^[Zh01028R8P0B4Q80:VYZ@2YZJT30;Bd
]0050:ZZZP2SXj<0YjNW0:NWY`2TY:@00P2VYZH01@2PX:00OWin07inOP2PX:00Zj^[0080GEeM00D0
IVIV07moO`1oOgl0Rh^;08V9R@0207moO`<0OGem00D0Ogmo08N7Q`25QHD0QHF508R8R00207UiN@05
06QXJ012@T80@T9208:2PP1lO7`00P1YJFT01@1]KFd0WinO09nOW`2ZZZX0[Zj^0080Zj^[0`2_[jl3
0:f][@0505mOG`2BTY80/k>c0;>c/`2a/K400P2b/[801@2ZZZX0Zj^[0:ZZZP2ZZZX0ZJVY0080YJFU
00D0Y:BT0:FUY@1IFET0FEUI07inOP020<[:bP050<C4a02m_Kd0_Kfm0;Bd]02f][H00P2d];@00`2f
][H0^;Rh0;Rh^0040;>c/`040:RXZ01NGUh0GUiN09jNWP80XJ6Q00D0YjNW0:f][@2_[jl0[jn_0:RX
Z0020:b/[0030:j^[P3oool0oooo00l0oooo00@0Jf][096AT@2ATI40OGem0P1>CTh00`23Ph<0VYZJ
09ZJVP0209ZJVP80TI6A00D0MgMg061PH01PH600M7Ad06i^KP02059BDP04071`L01]KFd0KFe]05eM
G@80P82000D0MGEe04E5A@1FEUH0EUIF04m?C`0205ADE00507]kN`29RHT0RHV90:f][@2?Shl00P1b
LW80102/[:`0X:2P0:2PX026QXH206e]K@0505MGE`2EUID0^[Zj0;Zj^P2BTY800P23Ph<01@1WIfL0
ATI60:NWY`2WYjL0X:2P0080_Kfm00D0YJFU0:>SX`2SXj<0NWYj09JFUP0208Z:RP0407UiN@1bLW80
LW9b08^;R`80XJ6Q00D0YJFU0;Bd]02h^;P0^;Rh0:VYZ@0209:BTP0507alO03De=@0Zj^[0:^[Z`2S
Xj<00P2VYZH01@38b<P0eMGE0=GEe@2LW9`0N7Qh0080P82000@0G5aL09:BTP2BTY80QhN70P2QXJ40
1@28R8P0]kNg0:BTY02TY:@0Ti>C0080GemO00D0D51@0;fm_@2g]kL0]kNg0<o?c`0205EEE@0506m_
K`3MgMd0gMgM07EeM@2`/;000P1lO7`0101QHF40Kfm_06m_K`2[Zj/20<;2`P0509fMW@1hN7P0QHF5
08F5Q@2JVYX00P2HV9P01@1eMGD0X:2P0:2PX01MGEd0ZZZZ0080WinO00D0HV9R03`l?00l?3`0>3Ph
05UIF@0205=CD`0405MGE`1KFe/0Fe]K06IVIP80KFe]00D0G5aL08j>SP1]KFd0KFe]055AD@0207=c
L`0507emO@2IVIT0VIVI09FEU@2;Rh/00P28R8P01@2f][H0Ph>308>3P`25QHD0QXJ60080R8R800@0
OWin05IFEP1FEUH0GUiN0P1MGEd00`1cLg<0oooo0?ooo`080?ooo`002P3oool0102UYJD0Xj>S0:>S
X`2IVIT209^KV`0508n?S`2=SHd0TI6A096AT@28R8P00P2?Shl01@2CTi<0JVYZ06YZJP1LG5`0ZZZZ
0080YjNW00D0Xj>S0:BTY02TY:@0WIfM09ZJVP0209nOW`040:2PX02YZJT0ZJVY0:ZZZP80[Zj^00D0
YJFU06YZJP1aLG40LG5a08b<S00208Z:RP0507QhN021PH40Ph>308>3P`2NWYh00P2WYjL00`2[Zj/0
[Jf]0:VYZ@020:VYZ@80XZ:R00D0JVYZ038b<P0b<S80V9RH0:j^[P020:f][@050;6a/@2/[:`0[:b/
0:b/[02UYJD00P2QXJ40102YZJT0[:b/0:b/[02`/;020:NWY`0509RHV010@400YJFU0:FUY@2RXZ80
0`2WYjL0102QXJ40TY:B09:BTP2IVIT20::RXP050:2PX02:RXX0RXZ:08f=S@2UYJD00P1ZJVX01@1g
MgL0WinO09nOW`2OWil0V9RH0080NWYj00D0KVi^07IfMP1fMWH0O7al08n?S`0209:BTP0408F5Q@26
QXH0QXJ607=cL`80JFUY00D0X:2P09jNWP2NWYh0WYjN06a/K0020820P00508Z:RP2QXJ40Xj>S0:>S
X`2KVi/00P2MWId01@2CTi<0Rh^;08^;R`0n?Sh0P8200080WinO00D0VIVI09RHV02HV9P0UYJF0:6Q
X@0209bLW0030:2PX02KVi/0Vi^K0080VIVI0P1PH6000`1bLW80_;bl0;bl_0030;bl_0050;Fe]@2_
[jl0ZJVY0:VYZ@2QXJ400P2XZ:P01@2`/;00X:2P09jNWP2NWYh0VYZJ0080EEEE00D0W9bL09jNWP2N
WYh0YJFU0:ZZZP020:f][@040:FUY@2SXj<0Xj>S0:RXZ140oooo00@0MgMg0:2PX02PX:00OGem0P1?
Cdl01@2ATI40W9bL09bLW02PX:00UIFE0080SHf=00D0Ogmo05mOG`1OGel0Jf][07IfMP0203dm?@04
06][J`1kNg/0Ng]k06UYJ@80XJ6Q00D0QHF507MgM`1lO7`0O7al05eMG@02055AD@0508>3P`27QhL0
QhN70;:b/P2?Shl00P1/K6`0102^[Zh0XZ:R0::RXP29RHT2079bLP0505ADE026QXH0]KFe0;Fe]@2O
Wil00`1eMGD01019BDT0`L710<71`@2i^KT20<K6aP050:b/[02TY:@0Y:BT07emO@2HV9P00P2GUiL0
101fMWH0MGEe07EeM@29RHT20:FUY@050:b/[02l_;`0c/k>0<k>cP2`/;000P2CTi<01@1lO7`0emOG
0;2`/02`/;00WinO0080WIfM00D0^;Rh0=KFeP3Fe]H0TI6A079bLP020820P004065QH@2IVIT0VIVI
08N7Q`80V9RH00D0O7al0;:b/P2JVYX0VYZJ08f=S@0205]KF`0505EEE@35aLD0YjNW0:NWY`2VYZH0
0P0n?Sh01@1PH600emOG0=OGe`1dM7@0^KVi0080Ogmo00@0N7Qh07IfMP1fMWH0/k>c0P3GemL01@2U
YJD0Lg=c096AT@2ATI40Y:BT0080UiNG00D0NWYj09VIV@2IVIT0G5aL0:n_[`0209VIV@0506i^KP0j
>SX0>SXj04A4A01WIfL00P1dM7@0101KFe/0JVYZ06YZJP1dM7@207YjNP0507AdM02EUID0MGEe07Ee
M@1hN7P00P1jNWX01@1`L700WinO09nOW`25QHD0YZJV0080WYjN00D0/;2`07AdM01dM7@0MGEe08J6
QP0207QhN00407=cL`1dM7@0M7Ad07QhN080Bd];00<0LG5a0?ooo`3oool0203oool000X0oooo00@0
IFEU05QHF01HF5P0AdM70P0i>CT00`0k>c/0@T9204Q8B00204Q8B080BDU900D0?clo02HV9P0V9RH0
;2`/061PH002075aL@0507QhN01dM7@0M7Ad06UYJ@17AdL00P19BDT0101=CDd0BDU904U9B@1?Cdl2
04Y:BP0503hn?P0/;2`0?3`l03`l?013@d<00P1;Bd/204=3@`80ATI600D0C4a<059BDP1BDU80CTi>
05=CD`02065QH@0405iNGP0n?Sh0?Shn02@T9080:b/[00@0BDU905ADE01LG5`0G5aL0`1?Cdl01@12
@T80ATI604M7A`17AdL0@d=30080B4Q800D0A4A402l_;`0_;bl0>CTi03Lg=`0204e=C@05051@D01<
C4`0C4a<03lo?`11@D400P0a<C40100`<300<c<c03<c<`11@D430492@P0404=3@`10@400@4100410
@080ATI600D0C4a<04U9B@0o?cl0?clo030`<00203Ph>00503@d=00k>c/0=cLg03Lg=`0i>CT00P0o
?cl01@0b<S80>c/k03/k>`0o?cl0=CDe0080@41000D0AdM704=3@`13@d<0;Bd]024Q8@0203Ph>004
03/k>`11@D40@D5103dm?@80>c/k00D0>CTi0410@01;Bd/0Bd];04=3@`0203lo?`0504A4A00l?3`0
8b<S02<S8`0c<c<00P0f=SH01@0e=CD0?3`l04A4A014A4@0?Cdm0080A4A400D0B4Q804U9B@19BDT0
B4Q803<c<`02038b<P0501`L700^;Rh0;Rh^03`l?00g=cL00P0f=SH01014A4@0BTY:04Y:BP1DE5@2
05UIF@0306=SH`1MGEd0CTi>0080CTi>0P16ATH00`1KFe/0oooo0?ooo`0?0?ooo`0406IVIP2IVIT0
VIVI07]kN`80Bd];00D0Ti>C09bLW02LW9`0WYjN0:6QX@0208b<S00507]kN`1KFe/0Fe]K07IfMP1i
NGT00P24Q8@0101iNGT0MgMg07MgM`1RHV8209fMW@0507]kN`1WIfL0L71`071`L01GEeL00P1>CTh0
1@1lO7`0QXJ608J6QP2c/k<0Shn?0080NWYj00@0ZJVY0:FUY@2UYJD0Rh^;0P1cLg<01@1/K6`0YJFU
0<c<c03<c<`0YjNW0080OWin00D0Ng]k04];B`2l_;`0_;bl0:j^[P020<O7a`050:NWY`2DU9@0U9BD
08F5Q@20P8000P1cLg<0101ZJVX0MGEe07EeM@22PX8209:BTP0509bLW02OWil0_[jn0;jn_P2RXZ80
0P2;Rh/01@1nOWh0f][J0;Bd]02d];@0V9RH0080WYjN00D0/;2`0=[JfP3Jf]X0U9BD07MgM`0208F5
Q@0406IVIP2BTY80TY:B08F5Q@80W9bL00D0Ogmo0:BTY02RXZ80XZ:R0:VYZ@0206ATI00505mOG`39
bLT0]kNg0;Ng]`36a/H00P16ATH01@1`L700emOG0=OGe`1fMWH0YZJV0080O7al00@0P820075aL@1a
LG40[jn_0P3@d=001@2VYZH0O7al0;2`/02`/;00[jn_0080WinO00D0QXJ60:f][@2][Jd0G5aL0;Bd
]0020:6QX@0508>3P`0i>CT0>CTi0410@01SHf<00P1]KFd0101;Bd/0KFe]06e]K@1WIfL207=cL`05
08:2PP2HV9P0Lg=c07=cL`1eMGD00P1mOGd01@21PH40XJ6Q0:6QX@2UYJD0WYjN0080R8R800D0[Zj^
06e]K@1]KFd0L71`08>3P`0207moO`0408b<S01dM7@0M7Ad06e]K@80GUiN00<0PX:20?ooo`3oool0
203oool000X0oooo00@0IFEU05QHF01HF5P0AdM70P0i>CT00`0k>c/0@T9204Q8B00204Q8B080BDU9
00D0?clo02HV9P0V9RH0;2`/061PH002075aL@0507QhN01dM7@0M7Ad06UYJ@17AdL00P19BDT0101=
CDd0BDU904U9B@1?Cdl204Y:BP0503hn?P0/;2`0?3`l03`l?013@d<00P1;Bd/204=3@`80ATI600D0
C4a<059BDP1BDU80CTi>05=CD`02065QH@0405iNGP0n?Sh0?Shn02@T9080:b/[00@0BDU905ADE01L
G5`0G5aL0`1?Cdl01@12@T80ATI604M7A`17AdL0@d=30080B4Q800D0A4A402l_;`0_;bl0>CTi03Lg
=`0204e=C@05051@D01<C4`0C4a<03lo?`11@D400P0a<C40100`<300<c<c03<c<`11@D430492@P04
04=3@`10@400@4100410@080ATI600D0C4a<04U9B@0o?cl0?clo030`<00203Ph>00503@d=00k>c/0
=cLg03Lg=`0i>CT00P0o?cl01@0b<S80>c/k03/k>`0o?cl0=CDe0080@41000D0AdM704=3@`13@d<0
;Bd]024Q8@0203Ph>00403/k>`11@D40@D5103dm?@80>c/k00D0>CTi0410@01;Bd/0Bd];04=3@`02
03lo?`0504A4A00l?3`08b<S02<S8`0c<c<00P0f=SH01@0e=CD0?3`l04A4A014A4@0?Cdm0080A4A4
00D0B4Q804U9B@19BDT0B4Q803<c<`02038b<P0501`L700^;Rh0;Rh^03`l?00g=cL00P0f=SH01014
A4@0BTY:04Y:BP1DE5@205UIF@0306=SH`1MGEd0CTi>0080CTi>0P16ATH00`1KFe/0oooo0?ooo`0?
0?ooo`0406IVIP2IVIT0VIVI07]kN`80Bd];00D0Ti>C09bLW02LW9`0WYjN0:6QX@0208b<S00507]k
N`1KFe/0Fe]K07IfMP1iNGT00P24Q8@0101iNGT0MgMg07MgM`1RHV8209fMW@0507]kN`1WIfL0L71`
071`L01GEeL00P1>CTh01@1lO7`0QXJ608J6QP2c/k<0Shn?0080NWYj00@0ZJVY0:FUY@2UYJD0Rh^;
0P1cLg<01@1/K6`0YJFU0<c<c03<c<`0YjNW0080OWin00D0Ng]k04];B`2l_;`0_;bl0:j^[P020<O7
a`050:NWY`2DU9@0U9BD08F5Q@20P8000P1cLg<0101ZJVX0MGEe07EeM@22PX8209:BTP0509bLW02O
Wil0_[jn0;jn_P2RXZ800P2;Rh/01@1nOWh0f][J0;Bd]02d];@0V9RH0080WYjN00D0/;2`0=[JfP3J
f]X0U9BD07MgM`0208F5Q@0406IVIP2BTY80TY:B08F5Q@80W9bL00D0Ogmo0:BTY02RXZ80XZ:R0:VY
Z@0206ATI00505mOG`39bLT0]kNg0;Ng]`36a/H00P16ATH01@1`L700emOG0=OGe`1fMWH0YZJV0080
O7al00@0P820075aL@1aLG40[jn_0P3@d=001@2VYZH0O7al0;2`/02`/;00[jn_0080WinO00D0QXJ6
0:f][@2][Jd0G5aL0;Bd]0020:6QX@0508>3P`0i>CT0>CTi0410@01SHf<00P1]KFd0101;Bd/0KFe]
06e]K@1WIfL207=cL`0508:2PP2HV9P0Lg=c07=cL`1eMGD00P1mOGd01@21PH40XJ6Q0:6QX@2UYJD0
WYjN0080R8R800D0[Zj^06e]K@1]KFd0L71`08>3P`0207moO`0408b<S01dM7@0M7Ad06e]K@80GUiN
00<0PX:20?ooo`3oool0203oool000X0oooo00@0/[:b0:RXZ02XZ:P0Xj>S0P1JFUX01@1lO7`0TY:B
07AdM01dM7@0OGem0080UiNG00D0U9BD0:BTY02TY:@0ZZZZ08n?S`020:b/[0050:ZZZP2WYjL0YjNW
0:FUY@0i>CT00P1XJ6P01028R8P0XZ:R0::RXP2][Jd20:n_[`050:j^[P2/[:`0ZZZZ0:ZZZP2RXZ80
0P2QXJ401@2RXZ80X:2P0:VYZ@2YZJT0F5QH0080NWYj00D0YZJV0:RXZ02[Zj/0Zj^[0:>SX`020:NW
Y`050:2PX02UYJD0YJFU0:ZZZP2QXJ400P2XZ:P01@2_[jl0WYjN09jNWP16ATH0L71`0080PH6100@0
SHf=09ZJVP2JVYX0Vi^K0P2PX:000`2LW9`0XJ6Q0:6QX@020:6QX@<0VYZJ00@0UiNG04U9B@19BDT0
WinO0P2][Jd01@2_[jl0];Bd0;Bd]030`<00]kNg0080/;2`00D0[Jf]0;2`/02`/;00[Zj^0;>c/`02
0;Bd]00509FEU@1YJFT0JFUY0:BTY02^[Zh00P2[Zj/0102^[Zh0]kNg0;Ng]`2j^[X20;^k^`050;Ng
]`2f][H0];Bd0;Bd]02`/;000P2c/k<01@17AdL0HF5Q0;Vi^@2i^KT0_;bl0080^[Zj00D0[jn_0;Bd
]02d];@0^k^k0;fm_@020;Zj^P050;fm_@2l_;`0_;bl0;Zj^P2WYjL00P0m?Cd00`2k^k/0]kNg0;Ng
]`040;Zj^P030;Jf]P2d];@0];Bd00<0/K6a00D0/[:b0:f][@2UYJD0YJFU06QXJ0020::RXP050;Bd
]02`/;00];Bd0;Bd]02a/K400`2`/;020:ZZZP050:BTY02VYZH0Y:BT0:BTY02ZZZX00P1aLG400`2P
X:00oooo0?ooo`0?0?ooo`0406e]K@2RXZ80XZ:R07]kN`80Bd];00D0UIFE09VIV@2IVIT0WYjN0:BT
Y00208^;R`0507UiN@1GEeL0EeMG07moO`1lO7`00P1gMgL0101`L700IVIV06IVIP1HF5P209FEU@05
07QhN01FEUH0Jf][06][J`1KFe/00P1EEED307YjNP050;:b/P2=SHd0QhN708N7Q`2XZ:P00P2UYJD0
1@2<S8`0I6AT06ATI01HF5P0VIVI0080c/k>00D0XZ:R07YjNP1jNWX0NGUi04I6AP020;bl_0040:BT
Y02n_[h0_[jn0:JVYP80Ogmo00D0Ng]k07inOP20P800P82007QhN00208R8R00508f=S@2<S8`0S8b<
09:BTP2f][H00P3<c<`01@2e]KD0VIVI09VIV@1hN7P0fm_K0080][Jf00@0UiNG0:2PX02PX:00^;Rh
0P3De=@01@2RXZ80MWIf08b<S02<S8`0IfMW0080UYJF00D0QhN70:6QX@2QXJ40Rh^;0:n_[`020:NW
Y`05096AT@1IFET0FEUI05iNGP2[Zj/00P2^[Zh0102k^k/0>SXj03Xj>P1jNWX20=CDe00507UiN@2e
]KD0MgMg07MgM`24Q8@00P1nOWh01@2][Jd0fm_K0=_Kf`2UYJD0NWYj0080TY:B00@0Z:RX09VIV@2I
VIT0Q8B40P2CTi<01@1JFUX0_[jn09FEU@2EUID0OWin0080=CDe00D0?Cdm05aLG01KFe/0Fe]K04a<
C00205=CD`05051@D01JFUX0FUYJ05eMG@1gMgL00P1FEUH0101[Jf/0HV9R069RHP1/K6`208V9R@05
09jNWP2OWil0R8R808R8R02d];@00P28R8P208N7Q`80LW9b00@0Shn?071`L01`L700Lg=c0P1ZJVX0
0`1mOGd0oooo0?ooo`080?ooo`002P3oool0102ZZZX0YjNW0:NWY`2UYJD206ATI00507QhN02DU9@0
G5aL05aLG01jNWX00P29RHT01@1kNg/0TY:B09:BTP2EUID0IFEU00D0WYjN00D0WIfM02d];@1UIFD0
IFEU07YjNP020820P00509fMW@2JVYX0VYZJ09JFUP2HV9P00P2GUiL01@2ATI40U9BD09BDU02BTY80
UiNG0080Z:RX00<0IVIV08R8R028R8P00P2ZZZX20:JVYP040:FUY@2TY:@0Y:BT09bLW080XJ6Q00D0
X:2P09jNWP2VYZH0YZJV0:ZZZP020:^[Z`0505YJFP1iNGT0VIVI09VIV@2HV9P00P2OWil01@2SXj<0
YJFU0:FUY@2PX:00VYZJ0080T92@00D0SXj>08f=S@2=SHd0Shn?08Z:RP0203lo?`040:>SX`2b/[80
/[:b0;Rh^080]KFe00D0^k^k0;Bd]02`/;00/;2`0:n_[`020:b/[0050:j^[P2[Zj/0/;2`0;2`/02G
UiL00P1YJFT01@2MWId0Xj>S0:b/[02/[:`0/k>c0080[jn_00D0/k>c0;Rh^02h^;P0][Jf0;:b/P02
0:^[Z`050:b/[02^[Zh0[Zj^04e=C@22PX800P2m_Kd01035aLD0_kno0;no_`2d];@20;Ng]`050<30
`02o_kl0a<C40<C4a035aLD00P36a/H01@2n_[h0[Jf]04E5A@15ADD0];Bd0080/K6a00D0];Bd0;>c
/`2d];@0];Bd0:NWY`030:JVYP80[Zj^0P2_[jl20:VYZ@05061PH02][Jd0[Jf]0;Fe]@2][Jd00P2`
/;00102a/K40/;2`0;2`/02f][H20:b/[0050:RXZ02`/;00/K6a0;6a/@2b/[800P1iNGT00`2/[:`0
oooo0?ooo`0?0?ooo`0406YZJP2FUYH0UYJF07alO080ADE500D0RXZ:09BDU02DU9@0UYJF0:JVYP02
08>3P`0507AdM01IFET0FEUI08B4Q01gMgL00P1eMGD0101SHf<0KFe]06e]K@1HF5P208b<S00507in
OP1:BTX0G5aL05aLG01GEeL00P1<C4`01@1eMGD0LG5a075aL@2[Zj/0QXJ60080Shn?00@0XZ:R0:2P
X02PX:00Ph>30P1VIVH01@1GEeL0RHV90<O7a`37alL0WIfM0080JVYZ00D0HV9R0492@P2d];@0];Bd
09^KV`020;Vi^@050:JVYP26QXH0QXJ607alO01nOWh00P1cLg<0101OGel0P8200820P01lO7`209BD
U00508V9R@2e]KD0_Kfm0;fm_@2a/K400P2DU9@01@1oOgl0d];B0;Rh^02h^;P0ZZZZ0080XJ6Q00D0
^[Zj0<c<c03<c<`0XJ6Q07UiN@0207inOP04065QH@2EUID0UIFE092@T080X:2P00D0TI6A0:^[Z`2V
YZH0YZJV08Z:RP0205=CD`05065QH@2GUiL0ZJVY0:VYZ@3AdM400P0o?cl01@2ATI40i>CT0>CTi01n
OWh0[:b/0080NWYj00@0Ph>307YjNP1jNWX0[Jf]0P3Jf]X01@2TY:@0VYZJ08^;R`2;Rh/0[Zj^0080
Shn?00D0UiNG092@T02@T900Lg=c0<C4a0020::RXP0507moO`0m?Cd0?Cdm0410@01SHf<00P1RHV80
101OGel0IfMW06MWI`1XJ6P207EeM@0506e]K@1nOWh0H61P061PH01UIFD00P1[Jf/01@1LG5`0NGUi
07UiN@2FUYH0Rh^;0080RXZ:00D0]KFe08B4Q024Q8@0OWin09:BTP020820P00308F5Q@1dM7@0M7Ad
00<0MgMg00<0Shn?0?ooo`3oool0203oool000X0oooo00@0ZZZZ0:NWY`2WYjL0YJFU0P1TI6@01@1h
N7P0U9BD05aLG01LG5`0NWYj0080RHV900D0Ng]k09:BTP2BTY80UIFE06EUI@0509jNWP0509fMW@0]
;Bd0IFEU06EUI@1jNWX00P20P8001@2MWId0VYZJ09ZJVP2FUYH0V9RH0080UiNG00D0TI6A09BDU02D
U9@0TY:B09NGU`020:RXZ00306IVIP28R8P0R8R80080ZZZZ0P2VYZH0102UYJD0Y:BT0:BTY02LW9`2
0:6QX@050:2PX02NWYh0YZJV0:JVYP2ZZZX00P2[Zj/01@1JFUX0NGUi09VIV@2IVIT0V9RH0080WinO
00D0Xj>S0:FUY@2UYJD0X:2P09ZJVP02092@T00508j>SP2=SHd0SHf=08n?S`2:RXX00P0o?cl0102S
Xj<0/[:b0;:b/P2h^;P20;Fe]@050;^k^`2d];@0/;2`0;2`/02_[jl00P2/[:`01@2^[Zh0Zj^[0;2`
/02`/;00UiNG0080JFUY00D0WIfM0:>SX`2/[:`0[:b/0;>c/`020:n_[`050;>c/`2h^;P0^;Rh0;Jf
]P2b/[800P2[Zj/01@2/[:`0[Zj^0:j^[P1=CDd0PX:20080_Kfm00@0aLG50;no_`2o_kl0];Bd0P2g
]kL01@30`<00_kno0<C4a034a<@0aLG50080a/K600D0_[jn0:f][@15ADD0ADE50;Bd]0020;6a/@05
0;Bd]02c/k<0];Bd0;Bd]02WYjL00`2VYZH20:j^[P80[jn_0P2YZJT01@1PH600[Jf]0:f][@2e]KD0
[Jf]0080/;2`00@0/K6a0;2`/02`/;00][Jf0P2/[:`01@2XZ:P0/;2`0;6a/@2a/K40/[:b0080NGUi
00<0[:b/0?ooo`3oool03`3oool0101ZJVX0UYJF09JFUP1lO7`204E5A@0508Z:RP2DU9@0U9BD09JF
UP2VYZH00P23Ph<01@1dM7@0FEUI05UIF@24Q8@0MgMg0080MGEe00@0Hf=S06e]K@1]KFd0F5QH0P2<
S8`01@1nOWh0BTY:05aLG01LG5`0EeMG0080C4a<00D0MGEe075aL@1aLG40Zj^[08J6QP0208n?S`04
0::RXP2PX:00X:2P08>3P`80IVIV00D0EeMG08V9R@37alL0alO709fMW@0206YZJP05069RHP12@T80
];Bd0;Bd]02KVi/00P2i^KT01@2VYZH0QXJ608J6QP1lO7`0OWin0080Lg=c00@0GemO0820P020P800
O7al0P2DU9@01@29RHT0]KFe0;fm_@2m_Kd0/K6a0080U9BD00D0Ogmo0=;BdP2h^;P0^;Rh0:ZZZP02
0:6QX@050;Zj^P3<c<`0c<c<0:6QX@1iNGT00P1nOWh0101QHF40UIFE09FEU@2@T9020:2PX005096A
T@2[Zj/0YZJV0:JVYP2:RXX00P1CDe<01@1QHF40UiNG0:VYZ@2YZJT0dM7A0080?clo00D0TI6A0>CT
i03Ti>@0OWin0:b/[00207YjNP0408>3P`1jNWX0NWYj0:f][@80f][J00D0Y:BT09ZJVP2;Rh/0Rh^;
0:j^[P0208n?S`0509NGU`2@T900T92@07=cL`34a<@00P2RXZ801@1oOgl0?Cdm03dm?@10@400Hf=S
0080HV9R00@0GemO06MWI`1WIfL0J6QX0P1eMGD01@1]KFd0OWin061PH01PH600IFEU0080Jf][00D0
G5aL07UiN@1iNGT0UYJF08^;R`0208Z:RP050;Fe]@24Q8@0Q8B407inOP2BTY800P20P8000`25QHD0
M7Ad07AdM00307MgM`0308n?S`3oool0oooo00P0oooo000:0?ooo`040:6QX@2MWId0WIfM09nOW`80
GEeM00D0Lg=c08Z:RP1DE5@0E5AD08V9R@02096AT@0507moO`2CTi<0Ti>C0861P@1VIVH00P2JVYX3
09RHV00409nOW`0g=cL0GUiN05iNGP<0NGUi00D0WYjN09bLW02LW9`0UiNG096AT@020861P@0308R8
R02@T900T92@0080TY:B0P2DU9@01@1BDU80Lg=c07=cL`2QXJ40Xj>S00<0XJ6Q0P2PX:001@2CTi<0
UYJF09JFUP2BTY80Ti>C0080X:2P00D0Y:BT0:6QX@2QXJ40BTY:06UYJ@0209VIV@0409ZJVP2QXJ40
XJ6Q09fMW@80SXj>00D0RXZ:08V9R@25QHD0QHF508B4Q00208j>SP0508b<S029RHT0@D510451@@2K
Vi/00`2][Jd20:j^[P050;Bd]02`/;00ZJVY0:VYZ@2WYjL00P2TY:@01@2SXj<0YJFU0:VYZ@2YZJT0
Xj>S0080IFEU00D0TY:B09JFUP2PX:00X:2P0:RXZ0020:6QX@050:b/[02^[Zh0[Zj^0:b/[02XZ:P0
0P2TY:@01@2WYjL0ZZZZ0:ZZZP1<C4`0SHf=0080_kno00@0`/;20;no_`2o_kl0^k^k0P2j^[X01@2n
_[h0`l?30<W9b@39bLT0aLG50080_Kfm00D0^k^k0;:b/P1:BTX0BTY:0;>c/`020;6a/@050;Fe]@2f
][H0/K6a0;6a/@2WYjL00P2OWil01@2IVIT0V9RH09RHV02OWil0ZJVY0080Xj>S00D0EUIF0:f][@2]
[Jd0/[:b0:f][@020:b/[0040:j^[P2_[jl0[jn_0;6a/@<0[Jf]00@0];Bd0;Jf]P2f][H0[jn_0P1f
MWH00`2YZJT0oooo0?ooo`0?0?ooo`0407inOP2LW9`0W9bL0820P080CDe=00D0SXj>09JFUP2FUYH0
VIVI0;6a/@0209>CT`0507inOP1IFET0FEUI08^;R`1kNg/00P1oOgl0101hN7P0QhN708N7Q`1QHF42
09:BTP05071`L01RHV80KVi^06i^KP1BDU800P1:BTX01@1iNGT0QXJ608J6QP2^[Zh0RXZ:0080R8R8
00@0X:2P09VIV@2IVIT0Lg=c0P1KFe/01@1GEeL0SXj>0;Fe]@2e]KD0UiNG0080IVIV00D0MGEe04M7
A`2WYjL0YjNW09^KV`020<;2`P050:b/[029RHT0RHV907MgM`25QHD00P26QXH0101eMGD0Shn?08n?
S`1cLg<209^KV`0509>CT`2c/k<0`L710<71`@2c/k<00P2KVi/01@21PH40h>3P0;:b/P2b/[80XJ6Q
0080WIfM00D0^[Zj0<k>cP3>c/h0Z:RX07EeM@0208j>SP0406QXJ02IVIT0VIVI08b<S080XJ6Q00D0
TI6A0:ZZZP2^[Zh0[Zj^09NGU`0205aLG00507MgM`2VYZH0[Zj^0:j^[P3?cll00P0_;bl01@2=SHd0
gMgM0=gMg@1nOWh0/[:b0080R8R800@0Ogmo07IfMP1fMWH0];Bd0P3EeMD01@2NWYh0UYJF09JFUP2F
UYH0/;2`0080Ti>C00D0WYjN08^;R`2;Rh/0NWYj0;no_`020:2PX00507AdM01;Bd/0Bd];04=3@`1P
H6000P1RHV800`1DE5@0KVi^06i^KP0307EeM@05075aL@1fMWH0LG5a075aL@1bLW800P1/K6`01@25
QHD0UiNG09NGU`2SXj<0RHV90080RXZ:00D0/K6a09JFUP2FUYH0QXJ609jNWP0207UiN@0308R8R01e
MGD0MGEe00<0Jf][00<0RXZ:0?ooo`3oool0203oool000X0oooo00@0XJ6Q09bLW02LW9`0Vi^K0P1U
IFD01@1aLG40Shn?06m_K`1_Kfl0WinO0080Vi^K00D0VYZJ0:BTY02TY:@0P82007emO@020:6QX@05
0:2PX02MWId0WIfM09>CT`13@d<00P1NGUh01023Ph<0S8b<08b<S02LW9`20:>SX`0509nOW`2JVYX0
TI6A096AT@2@T9000P2>SXh01@2=SHd0Ti>C08:2PP22PX80=3@d0080MGEe0P2NWYh209fMW@0409NG
U`2PX:00X:2P09RHV080SHf=00@0R8R809>CT`2GUiL0UiNG0`2IVIT01@1?Cdl0Hf=S08R8R028R8P0
UIFE0080VYZJ00D0VIVI08n?S`2?Shl0Ph>307moO`0207inOP050820P025QHD0QHF508R8R01gMgL0
0P12@T80102:RXX0WYjN09jNWP2TY:@209fMW@050:BTY02VYZH0WinO09nOW`2GUiL00P2DU9@01@2A
TI40WIfM09ZJVP2JVYX0UiNG0080Fe]K00D0UiNG08J6QP29RHT0RHV909fMW@0309VIV@80WYjN00D0
VIVI09JFUP2GUiL0UiNG09jNWP0209ZJVP0503Ti>@20P800YjNW0:NWY`2TY:@00P2`/;001@2^[Zh0
[jn_0:n_[`2/[:`0Xj>S0080];Bd00D0YZJV0:NWY`2WYjL0[jn_09VIV@02055AD@0508b<S02=SHd0
SHf=09VIV@2ZZZX00P2WYjL0102BTY80QXJ608J6QP27QhL208R8R00508B4Q02DU9@0V9RH09RHV01K
Fe/00`2SXj<30:BTY0040:VYZ@2JVYX0VYZJ09nOW`80UYJF00D0Xj>S0:BTY02PX:00X:2P09ZJVP02
05eMG@0309FEU@3oool0oooo00l0oooo00@0MWIf09NGU`2GUiL0PH610P1EEED01@2NWYh0Xj>S0:>S
X`2RXZ80]kNg0080UiNG00D0MgMg05YJFP1JFUX0Ti>C07UiN@03079bLP80MgMg00D0G5aL08n?S`2?
Shl0Q8B405YJFP0207MgM`0406UYJ@1PH600H61P08n?S`80T92@00D0/K6a09RHV02KVi/0Vi^K0;Rh
^0020:b/[00508B4Q01ZJVX0JVYZ05mOG`2VYZH00P3@d=001@2a/K40KVi^06i^KP1hN7P0De=C0080
X:2P00@0Ti>C0<C4a034a<@0/K6a0P20P8001@1[Jf/0N7Qh08R8R028R8P0MWIf0080Vi^K00D0IFEU
08^;R`2;Rh/0TI6A0:>SX`020:BTY0050:NWY`2>SXh0SXj>07QhN03EeMD00P2c/k<0102UYJD0Zj^[
0:^[Z`2j^[X20=SHf0050:f][@1kNg/0QXJ608J6QP1PH6000P2FUYH01@26QXH0Y:BT0:BTY02;Rh/0
W9bL0080VIVI00D0M7Ad059BDP1BDU80Kfm_08n?S`020:JVYP040<30`00b<S80<S8b09bLW080f=SH
00D0O7al0:2PX023Ph<0Ph>307YjNP0207=cL`050;Vi^@3AdM40dM7A09ZJVP1jNWX00P2a/K40102]
[Jd0XZ:R0::RXP2YZJT208n?S`050861P@2n_[h0RHV908V9R@1SHf<00P1ADE401@0m?Cd0HF5Q05mO
G`1OGel0Bd];0080HF5Q00D0OGem06][J`1[Jf/0JFUY07=cL`0206i^KP0406][J`1cLg<0Lg=c07mo
O`80RXZ:00D0XJ6Q09JFUP2KVi/0Vi^K0;:b/P0208j>SP0507inOP22PX80GUiN05iNGP1UIFD00P1/
K6`0101JFUX0G5aL05aLG01oOgl:0?ooo`002P3oool0102QXJ40W9bL09bLW02KVi/206EUI@05075a
L@2?Shl0Kfm_06m_K`2OWil00P2KVi/01@2JVYX0Y:BT0:BTY020P800OGem0080XJ6Q00D0X:2P09fM
W@2MWId0Ti>C04=3@`0205iNGP0408>3P`2<S8`0S8b<09bLW080Xj>S00D0WinO09ZJVP2ATI40TI6A
092@T00208j>SP0508f=S@2CTi<0PX:208:2PP0d=3@00P1eMGD209jNWP80WIfM00@0UiNG0:2PX02P
X:00V9RH0P2=SHd01028R8P0Ti>C09NGU`2GUiL309VIV@0504m?C`1SHf<0R8R808R8R02EUID00P2J
VYX01@2IVIT0Shn?08n?S`23Ph<0Ogmo0080OWin00D0P82008F5Q@25QHD0R8R807MgM`020492@P04
08Z:RP2NWYh0WYjN0:BTY080WIfM00D0Y:BT0:JVYP2OWil0WinO09NGU`0209BDU005096AT@2MWId0
VYZJ09ZJVP2GUiL00P1KFe/01@2GUiL0QXJ608V9R@29RHT0WIfM00<0VIVI0P2NWYh01@2IVIT0UYJF
09NGU`2GUiL0WYjN0080VYZJ00D0>CTi0820P02WYjL0YjNW0:BTY0020;2`/0050:j^[P2_[jl0[jn_
0:b/[02SXj<00P2d];@01@2VYZH0YjNW0:NWY`2_[jl0VIVI0080DE5A00D0S8b<08f=S@2=SHd0VIVI
0:ZZZP020:NWY`0409:BTP26QXH0QXJ608N7Q`80R8R800D0Q8B409BDU02HV9P0V9RH05]KF`030:>S
X`<0Y:BT00@0ZJVY09ZJVP2JVYX0WinO0P2FUYH01@2SXj<0Y:BT0:2PX02PX:00VYZJ0080GEeM00<0
UIFE0?ooo`3oool03`3oool0101fMWH0UiNG09NGU`21PH4205EEE@0509jNWP2SXj<0Xj>S0::RXP2g
]kL00P2GUiL01@1gMgL0FUYJ05YJFP2CTi<0NGUi00<0LW9b0P1gMgL01@1LG5`0Shn?08n?S`24Q8@0
FUYJ0080MgMg00@0JFUY061PH01PH600Shn?0P2@T9001@2a/K40V9RH09^KV`2KVi/0^;Rh0080[:b/
00D0Q8B406YZJP1ZJVX0GemO0:JVYP020=3@d0050;6a/@1^KVh0KVi^07QhN01CDe<00P2PX:00102C
Ti<0a<C40<C4a02a/K420820P00506][J`1hN7P0R8R808R8R01fMWH00P2KVi/01@1UIFD0Rh^;08^;
R`2ATI40Xj>S0080Y:BT00D0YjNW08j>SP2>SXh0N7Qh0=GEe@020;>c/`040:FUY@2[Zj/0Zj^[0;Zj
^P80f=SH00D0[Jf]07]kN`26QXH0QXJ6061PH00209JFUP0508J6QP2TY:@0Y:BT08^;R`2LW9`00P2I
VIT01@1dM7@0DU9B059BDP1_Kfl0Shn?0080YZJV00@0`<30038b<P0b<S80W9bL0P3Hf=P01@1lO7`0
X:2P08>3P`23Ph<0NWYj0080Lg=c00D0^KVi0=7Ad@3AdM40VYZJ07YjNP020;6a/@040:f][@2RXZ80
XZ:R0:VYZ@80Shn?00D0PH610;jn_P29RHT0RHV906=SH`02055AD@0503dm?@1QHF40GemO05mOG`1;
Bd/00P1QHF401@1mOGd0Jf][06][J`1YJFT0Lg=c0080KVi^00@0Jf][07=cL`1cLg<0Ogmo0P2:RXX0
1@2QXJ40UYJF09^KV`2KVi/0/[:b0080SXj>00D0OWin08:2PP1NGUh0GUiN06EUI@0206a/K00405YJ
FP1LG5`0G5aL07moO`X0oooo000:0?ooo`0405UIF@1;Bd/0Bd];04Y:BP80>CTi00D0>c/k04];B`0o
?cl0?clo04A4A00204Q8B00504m?C`1>CTh0CTi>03/k>`1:BTX00P1@D5001@17AdL0A4A404A4A00j
>SX06a/K008092@T0`0l?3`303Ph>0050492@P0h>3P0;Bd]02d];@0j>SX00P1<C4`01@1?Cdl0De=C
03`l?00l?3`07alO0080ATI600@0GUiN05UIF@1OGel0GemO0`1EEED01@1>CTh0BTY:04Y:BP17AdL0
ATI60080D51@00D0CDe=04Q8B018B4P08B4Q03Lg=`0204];B`04059BDP1CDe<0De=C059BDP80CDe=
00D0DE5A04E5A@18B4P0B4Q804=3@`020492@P0503Xj>P0g=cL0820P020P800/;2`00P0_;bl01@0^
;Rh09RHV02HV9P0m?Cd0@T920080>3Ph00D0=cLg02l_;`0_;bl0:BTY030`<00203<c<`0502TY:@0V
9RH09RHV04i>CP11@D400P0l?3`0100k>c/0>SXj03Xj>P11@D4204I6AP0503Hf=P0`<300<C4a034a
<@0];Bd00P0S8b<01@0O7al07QhN02@T900T92@09BDU0080:RXZ00D0;2`/02HV9P0V9RH0:2PX03Xj
>P020410@0050451@@19BDT0BDU904a<C01=CDd00P12@T801@0n?Sh0>SXj03Xj>P0S8b<09bLW0080
:2PX00@04Q8B020P800P82009bLW0P0V9RH01@0O7al09RHV02HV9P0V9RH05QHF00806ATI00D0820P
01/K6`0R8R808R8R01XJ6P0200d=3@0301HF5P0W9bL09bLW0080<C4a0P0_;bl0100Y:BT08R8R028R
8P0R8R8A0?ooo`04079bLP2FUYH0UYJF08:2PP80EeMG00D0V9RH09JFUP2FUYH0WinO0:f][@0207Ee
M@0506m_K`1IFET0FEUI08:2PP1[Jf/00P1gMgL0101iNGT0Lg=c07=cL`1fMWH20:2PX00508:2PP1C
De<0Hf=S06=SH`1]KFd00P1LG5`01@1aLG40N7Qh07QhN02VYZH0RHV90080TI6A00@0Zj^[0:6QX@2Q
XJ40MWIf0P1[Jf/01@1OGel0Zj^[0=gMg@3MgMd0^k^k0080J6QX00D0Ogmo051@D02OWil0WinO09ZJ
VP020<30`0050;bl_022PX80PX:206i^KP21PH400P2ATI40101nOWh0VYZJ09ZJVP1WIfL208^;R`05
09^KV`2e]KD0`/;20<;2`P2c/k<00P2NWYh01@1cLg<0^;Rh0:FUY@2UYJD0Vi^K0080ZZZZ00D0YjNW
0<[:bP3:b/X0P820079bLP0207alO00406UYJ@2VYZH0YZJV08j>SP80YjNW00D0S8b<0:ZZZP2SXj<0
Xj>S08^;R`0205UIF@0507]kN`2VYZH0/K6a0;6a/@34a<@00P0k>c/01@2WYjL0h>3P0>3Ph022PX80
UiNG0080OGem00@0LW9b069RHP1RHV80XZ:R0P2l_;`01@2;Rh/0J6QX0:n_[`2_[jl0WIfM0080Shn?
00D0SXj>08b<S02<S8`0X:2P0<S8b00208Z:RP0505]KF`1JFUX0FUYJ04=3@`1XJ6P00P1TI6@0101I
FET0LG5a075aL@24Q8@207]kN`0507AdM01VIVH0K6a/06a/K01[Jf/00P1oOgl01@26QXH0WYjN09jN
WP2XZ:P0NGUi0080Ti>C00@0/k>c08n?S`2?Shl0Ogmo0`2;Rh/0101IFET0C4a<04a<C01TI6@206IV
IP0306YZJP3oool0oooo00P0oooo000:0?ooo`0409>CT`28R8P0R8R808N7Q`80PH6100<0OGem07Ui
N@1dM7@00P1dM7@207UiN@0507emO@24Q8@0Q8B4030`<018B4P00P1[Jf/01@1jNWX0MGEe07EeM@1k
Ng/0P8200080MWIf0`1nOWh01@1lO7`0LW9b079bLP1^KVh0J6QX008092@T00D0O7al08Z:RP2:RXX0
QXJ608n?S`0209fMW@050:JVYP2JVYX0VYZJ09RHV02KVi/00P2EUID01028R8P0SHf=08f=S@23Ph<2
02l_;`0505eMG@1mOGd0RHV908V9R@23Ph<00P1iNGT01@1gMgL0M7Ad06ATI01TI6@0JVYZ0080KVi^
00D0Jf][06a/K01/K6`0MGEe03<c<`0206m_K`05071`L01WIfL0IfMW07AdM01hN7P00P20P8001024
Q8@0RXZ:08Z:RP2>SXh309JFUP04092@T01dM7@0M7Ad06i^KP80V9RH00D0S8b<09BDU02MWId0WIfM
09VIV@0209bLW080UiNG0P2XZ:P0102YZJT0Zj^[0:^[Z`1UIFD208>3P`0309ZJVP2CTi<0SXj>0080
SXj>0P2CTi<01@2JVYX0VIVI09nOW`2OWil0XZ:R0080WinO00D0XJ6Q07YjNP1jNWX0J6QX09RHV002
09jNWP050;2`/02e]KD0]KFe0:RXZ02^[Zh00P2MWId01@2KVi/0X:2P0:2PX02JVYX0RHV90080Y:BT
00@0E5AD08Z:RP2:RXX0GUiN0P1lO7`01@2GUiL0XZ:R09bLW02LW9`0Lg=c0080Ng]k00D0OGem08^;
R`2RXZ80XZ:R0:2PX002061PH0050861P@2QXJ40XJ6Q0:BTY02UYJD00`2WYjL209bLW00308J6QP3o
ool0oooo00l0oooo00@0FUYJ08>3P`23Ph<0NGUi0P1:BTX01@2GUiL0Vi^K09^KV`2MWId0UYJF0080
W9bL00D0MWIf05ADE01DE5@0NGUi07alO00206IVIP0405EEE@17AdL0AdM705=CD`80RHV900D0KFe]
0492@P1JFUX0FUYJ04a<C00205IFEP0507=cL`1nOWh0OWin09bLW029RHT00P2GUiL0102[Zj/0Z:RX
0:RXZ01cLg<2075aL@0505aLG02DU9@0dM7A0=7Ad@2IVIT00P1SHf<01@1mOGd0EeMG09FEU@2EUID0
V9RH0080a<C400D0/;2`07YjNP1jNWX0KFe]075aL@0208^;R`0407=cL`2HV9P0V9RH07=cL`80T92@
00D0VIVI0;Fe]@33`l<0`l?30;Bd]00209fMW@0507MgM`3EeMD0`<300<30`02b/[800P2i^KT01@2Y
ZJT0f][J0=[JfP2>SXh0Ogmo0080R8R800@0JVYZ09^KV`2KVi/0QXJ60P2XZ:P01@1nOWh0YZJV08n?
S`2?Shl0PX:20080G5aL00D0OWin09^KV`2^[Zh0[Zj^0<O7a`0203lo?`050:>SX`3Ph>00h>3P08f=
S@2KVi/00`1oOgl206m_K`050;:b/P3;bl/0bl_;09jNWP1RHV800P1LG5`01027QhL0XJ6Q0:6QX@2>
SXh208f=S@0508n?S`2ZZZX0Q8B408B4Q01CDe<00P17AdL01@0l?3`0DU9B05QHF01HF5P0EUIF0080
J6QX00D0NGUi07EeM@1eMGD0JVYZ07IfMP0205eMG@0406YZJP1/K6`0K6a/06][J`80PX:200D0S8b<
05IFEP1kNg/0Ng]k09^KV`0207AdM005071`L029RHT0Ph>308>3P`1RHV800P1_Kfl0101bLW80NWYj
07YjNP2LW9`:0?ooo`002P3oool00`2_[jl0XJ6Q0:6QX@030:6QX@0509fMW@2UYJD0YZJV0:JVYP2S
Xj<00P2RXZ801@2KVi/0XJ6Q0:6QX@0l?3`0RXZ:0080UiNG00D0X:2P0:BTY02TY:@0WIfM09JFUP02
08f=S@0409nOW`2TY:@0Y:BT0:>SX`80Ti>C00D0SHf=08:2PP0];Bd0;Bd]08Z:RP0209^KV`0409RH
V02MWId0W9bL09bLW0<0Y:BT00D0Xj>S0:BTY02IVIT0VIVI08b<S00208^;R`0508V9R@1;Bd/0Bd];
09^KV`2CTi<00P2MWId01@2QXJ40YZJV0:JVYP2SXj<0VYZJ0080Ti>C00@0Ph>308J6QP26QXH0MWIf
0P20P8000`2FUYH0=3@d08V9R@0208V9R@80RXZ:00D0QhN709NGU`2MWId0WIfM09:BTP02092@T005
08n?S`2QXJ40XJ6Q0::RXP2BTY800P1gMgL01@1CDe<0RXZ:08Z:RP2=SHd0Ti>C0080VIVI00<0Vi^K
09nOW`2OWil00P2PX:020:VYZ@<0ZZZZ00D0CDe=09^KV`2KVi/0YZJV09jNWP020:2PX00509jNWP2X
Z:P0Z:RX0:ZZZP2UYJD00P2ZZZX0102/[:`0Zj^[0:^[Z`2SXj<208:2PP0405YJFP2SXj<0XZ:R0::R
XP<0Zj^[00D0TY:B0:>SX`22PX80PX:208j>SP0209JFUP0508n?S`26QXH0VYZJ09ZJVP1JFUX00P24
Q8@01@17AdL0T92@092@T02JVYX0WinO0080VIVI00D0L71`06e]K@1]KFd0J6QX071`L00209>CT`04
0:JVYP1/K6`0K6a/07]kN`80Ti>C00D0WYjN0:2PX02TY:@0Y:BT0:NWY`020:>SX`030:JVYP3oool0
oooo00l0oooo00@0K6a/09FEU@2EUID0OWin0P1BDU801@2>SXh0T92@092@T02GUiL0SHf=0080S8b<
00D0Kfm_04Y:BP1:BTX0K6a/07=cL`0206QXJ00406YZJP1WIfL0IfMW05=CD`80S8b<00D0LW9b0451
@@1UIFD0IFEU04M7A`0204U9B@0506YZJP1iNGT0NGUi0::RXP1nOWh00P2KVi/0102QXJ40U9BD09BD
U01TI6@206a/K005061PH02>SXh0`<300<30`02FUYH00P1NGUh01@20P800F5QH09bLW02LW9`0YjNW
0080a/K600D0ZJVY07MgM`1gMgL0LG5a06e]K@0208:2PP04075aL@2ATI40TI6A06i^KP80QhN700D0
U9BD0;Bd]02RXZ80XZ:R0:>SX`02096AT@0506EUI@3Bd]80^k^k0;^k^`2BTY800P2_[jl01@2`/;00
h>3P0>3Ph02DU9@0RHV90080PX:200@0H61P09fMW@2MWId0QHF50P2XZ:P01@1mOGd0[:b/0:BTY02T
Y:@0S8b<0080GUiN00D0Ogmo09ZJVP2NWYh0WYjN0=;BdP0204I6AP050:>SX`3Shn<0hn?S0861P@2>
SXh00P1nOWh01025QHD0Lg=c07=cL`2_[jl20<o?c`050:FUY@1EEED0GEeM05eMG@26QXH00P2IVIT0
1@29RHT0UYJF09JFUP2LW9`0^k^k0080NGUi00D0@41004A4A014A4@0=SHf05aLG00205YJFP04069R
HP1/K6`0K6a/07UiN@80L71`00D0JFUY06e]K@1XJ6P0J6QX05aLG00206a/K00507MgM`2BTY80TY:B
08^;R`1RHV800P1lO7`01@2HV9P0Ph>308>3P`1nOWh0MWIf0080Kfm_00@0Hf=S06i^KP1^KVh0Kfm_
0P1/K6`00`1hN7P0oooo0?ooo`080?ooo`002P3oool00`2_[jl0XJ6Q0:6QX@030:6QX@0509fMW@2U
YJD0YZJV0:JVYP2SXj<00P2RXZ801@2KVi/0XJ6Q0:6QX@0l?3`0RXZ:0080UiNG00D0X:2P0:BTY02T
Y:@0WIfM09JFUP0208f=S@0409nOW`2TY:@0Y:BT0:>SX`80Ti>C00D0SHf=08:2PP0];Bd0;Bd]08Z:
RP0209^KV`0409RHV02MWId0W9bL09bLW0<0Y:BT00D0Xj>S0:BTY02IVIT0VIVI08b<S00208^;R`05
08V9R@1;Bd/0Bd];09^KV`2CTi<00P2MWId01@2QXJ40YZJV0:JVYP2SXj<0VYZJ0080Ti>C00@0Ph>3
08J6QP26QXH0MWIf0P20P8000`2FUYH0=3@d08V9R@0208V9R@80RXZ:00D0QhN709NGU`2MWId0WIfM
09:BTP02092@T00508n?S`2QXJ40XJ6Q0::RXP2BTY800P1gMgL01@1CDe<0RXZ:08Z:RP2=SHd0Ti>C
0080VIVI00<0Vi^K09nOW`2OWil00P2PX:020:VYZ@<0ZZZZ00D0CDe=09^KV`2KVi/0YZJV09jNWP02
0:2PX00509jNWP2XZ:P0Z:RX0:ZZZP2UYJD00P2ZZZX0102/[:`0Zj^[0:^[Z`2SXj<208:2PP0405YJ
FP2SXj<0XZ:R0::RXP<0Zj^[00D0TY:B0:>SX`22PX80PX:208j>SP0209JFUP0508n?S`26QXH0VYZJ
09ZJVP1JFUX00P24Q8@01@17AdL0T92@092@T02JVYX0WinO0080VIVI00D0L71`06e]K@1]KFd0J6QX
071`L00209>CT`040:JVYP1/K6`0K6a/07]kN`80Ti>C00D0WYjN0:2PX02TY:@0Y:BT0:NWY`020:>S
X`030:JVYP3oool0oooo00l0oooo00@0K6a/09FEU@2EUID0OWin0P1BDU801@2>SXh0T92@092@T02G
UiL0SHf=0080S8b<00D0Kfm_04Y:BP1:BTX0K6a/07=cL`0206QXJ00406YZJP1WIfL0IfMW05=CD`80
S8b<00D0LW9b0451@@1UIFD0IFEU04M7A`0204U9B@0506YZJP1iNGT0NGUi0::RXP1nOWh00P2KVi/0
102QXJ40U9BD09BDU01TI6@206a/K005061PH02>SXh0`<300<30`02FUYH00P1NGUh01@20P800F5QH
09bLW02LW9`0YjNW0080a/K600D0ZJVY07MgM`1gMgL0LG5a06e]K@0208:2PP04075aL@2ATI40TI6A
06i^KP80QhN700D0U9BD0;Bd]02RXZ80XZ:R0:>SX`02096AT@0506EUI@3Bd]80^k^k0;^k^`2BTY80
0P2_[jl01@2`/;00h>3P0>3Ph02DU9@0RHV90080PX:200@0H61P09fMW@2MWId0QHF50P2XZ:P01@1m
OGd0[:b/0:BTY02TY:@0S8b<0080GUiN00D0Ogmo09ZJVP2NWYh0WYjN0=;BdP0204I6AP050:>SX`3S
hn<0hn?S0861P@2>SXh00P1nOWh01025QHD0Lg=c07=cL`2_[jl20<o?c`050:FUY@1EEED0GEeM05eM
G@26QXH00P2IVIT01@29RHT0UYJF09JFUP2LW9`0^k^k0080NGUi00D0@41004A4A014A4@0=SHf05aL
G00205YJFP04069RHP1/K6`0K6a/07UiN@80L71`00D0JFUY06e]K@1XJ6P0J6QX05aLG00206a/K005
07MgM`2BTY80TY:B08^;R`1RHV800P1lO7`01@2HV9P0Ph>308>3P`1nOWh0MWIf0080Kfm_00@0Hf=S
06i^KP1^KVh0Kfm_0P1/K6`00`1hN7P0oooo0?ooo`080?ooo`002P3oool0102a/K40Y:BT0:BTY02Q
XJ4209jNWP0509JFUP2ATI40W9bL09bLW02QXJ400P2DU9@01@23Ph<0QHF508F5Q@0j>SX0JFUY0080
Ph>300D0Shn?09ZJVP2JVYX0T92@08R8R00208>3P`04092@T02NWYh0WYjN09:BTP80QHF50P1gMgL2
02h^;P050861P@2?Shl0Shn?092@T02?Shl00P1nOWh01@1iNGT0Ogmo07moO`2;Rh/0WYjN0080OWin
00@0KFe]07IfMP1fMWH0L71`0P0m?Cd01@2>SXh0WinO0::RXP2RXZ80YJFU0080Y:BT00D0XJ6Q09JF
UP2;Rh/0Rh^;079bLP0208>3P`0507emO@2?Shl0Shn?09fMW@0`<3000P2JVYX01@2LW9`0WYjN09jN
WP2ATI40UIFE0080Ti>C00@0Ph>308R8R028R8P0PH610P2JVYX01@2QXJ40U9BD06m_K`1_Kfl0GemO
0080UYJF00D0TI6A09bLW02MWId0WIfM092@T00209BDU00508n?S`2NWYh0YjNW0:NWY`2][Jd00P2[
Zj/0101TI6@0X:2P0:2PX02UYJD40:NWY`80YZJV00D0ZJVY0:FUY@2WYjL0YjNW0:VYZ@020:JVYP05
0:BTY02=SHd0SHf=061PH02OWil00P2SXj<01@2_[jl0UYJF09JFUP2/[:`0WIfM0080PX:200D0U9BD
09ZJVP2JVYX0VIVI09:BTP0209bLW00403lo?`1<C4`0C4a<055AD@<0QXJ600@0R8R808V9R@29RHT0
Fe]K0P1XJ6P01@1CDe<0M7Ad09VIV@2IVIT0XJ6Q0080Fe]K00D0O7al0861P@21PH40UiNG09bLW002
0:FUY@040:2PX02OWil0WinO0:>SXa40oooo00@0IfMW0:JVYP2VYZH0NGUi0P1DE5@01@2ATI40W9bL
09bLW02PX:00XZ:R0080PX:200D0MgMg05MGE`1GEeL0NWYj07EeM@0205QHF004079bLP1TI6@0I6AT
071`L080R8R800D0KFe]03hn?P1ZJVX0JVYZ05IFEP0205ADE00507QhN01bLW80LW9b09^KV`1oOgl0
0P2IVIT0102/[:`0Xj>S0:>SX`1UIFD206IVIP05065QH@2;Rh/0`l?30<?3``2@T9000P1EEED01@1j
NWX0De=C07emO@1mOGd0Ti>C0080b<S800D0[jn_07emO@1mOGd0Kfm_06=SH`0207moO`04079bLP28
R8P0R8R8071`L080QhN700D0S8b<0;Fe]@2[Zj/0Zj^[09RHV00209FEU@0506e]K@3Jf]X0aLG50<G5
a@2LW9`00P1jNWX01@2<S8`0YZJV0:JVYP1lO7`0MgMg0080LW9b00@0Fe]K092@T02@T900PX:20P2V
YZH01@1mOGd0/[:b0:f][@2][Jd0QXJ60080I6AT00D0QHF50:f][@2^[Zh0[Zj^0<[:bP020410@005
0:FUY@3Ti>@0i>CT08B4Q02CTi<00P23Ph<01026QXH0M7Ad07AdM02h^;P20=3@d0050:NWY`1OGel0
TI6A096AT@2@T9000P2BTY801@23Ph<0Vi^K09^KV`2;Rh/0^;Rh0080K6a/00D0CDe=04A4A014A4@0
=cLg05MGE`0205YJFP04069RHP1WIfL0IfMW07alO080JFUY00D0KFe]07EeM@1ADE40DE5A069RHP02
05MGE`0505]KF`1gMgL0MgMg09ZJVP1ZJVX00P2;Rh/0102ATI40HF5Q065QH@1NGUh306MWI`04059B
DP1PH600H61P06=SH`80KVi^00<0P8200?ooo`3oool0203oool000X0oooo00@0Zj^[0:FUY@2UYJD0
YJFU0P2OWil01@2JVYX0TI6A09^KV`2KVi/0WIfM0080SHf=00D0Q8B408V9R@29RHT0@D5107QhN002
08b<S00508F5Q@2;Rh/0Rh^;08Z:RP27QhL00P28R8P01023Ph<0UiNG09NGU`2:RXX206YZJP05065Q
H@1aLG40;bl_02l_;`26QXH00P2CTi<01@2IVIT0R8R807UiN@1iNGT0NWYj0080NGUi00D0QhN70:BT
Y02;Rh/0Rh^;06UYJ@0206EUI@0505IFEP0`<300<30`0861P@29RHT00P2DU9@01@2GUiL0Ti>C09>C
T`2<S8`0RHV90080NGUi00@0MWIf0820P020P800Ti>C0P2FUYH01@2<S8`0@41009>CT`2CTi<0UiNG
0080SXj>00D0Ph>308V9R@27QhL0QhN708V9R@0209ZJVP0308n?S`2CTi<0Ti>C0080Shn?0P1YJFT0
1@1BDU80IFEU06EUI@1RHV80J6QX0080KVi^00D0Kfm_07AdM01dM7@0LG5a07UiN@0208f=S@0409FE
U@1hN7P0N7Qh04m?C`80OWin00@0UiNG09FEU@2QXJ40XJ6Q0`2UYJD01@2WYjL0Xj>S09NGU`2GUiL0
YZJV0080VIVI00@0Vi^K08F5Q@25QHD0J6QX0`2FUYH01@2`/;00]KFe0;Fe]@2ZZZX0UIFE0080W9bL
00D0Rh^;09NGU`2GUiL0VYZJ09NGU`0209jNWP0403Ti>@1@D500D51@06ATI080TY:B00D0RHV908^;
R`1SHf<0Hf=S04Q8B00205YJFP03051@D01iNGT0Ph>30080Ph>30P0n?Sh01@1YJFT0UiNG09NGU`2R
XZ80VIVI0080TI6A00@0WYjN0:6QX@2QXJ40X:2P4@3oool0101]KFd0[Jf]0:f][@1mOGd206MWI`05
08N7Q`2OWil0WinO0:NWY`2d];@00P2>SXh01@1lO7`0H61P061PH029RHT0Shn?0080Fe]K00@0MgMg
06IVIP1VIVH0OGem0P2@T9001@1_Kfl0B4Q805MGE`1GEeL0@4100080AdM700D0IFEU071`L01`L700
];Bd08R8R00209BDU0040:JVYP2HV9P0V9RH05aLG080I6AT00D0MgMg09^KV`3@d=00d=3@09fMW@02
05aLG0050820P01HF5P0QhN708N7Q`2EUID00P3;bl/01@2e]KD0PX:208:2PP1iNGT0GemO0080O7al
00@0M7Ad08B4Q024Q8@0I6AT0P1nOWh01@2:RXX0ZZZZ09RHV02HV9P0QXJ60080Shn?00D0LG5a0=KF
eP2o_kl0_kno0;>c/`0206EUI@050<O7a`2GUiL0UiNG06IVIP1fMWH00P1hN7P0101SHf<0TY:B09:B
TP20P8020:>SX`0508J6QP2ZZZX0[Zj^0:j^[P2;Rh/00P1RHV801@27QhL0YjNW0:n_[`2_[jl0_Kfm
0080@41000D0XZ:R0>;RhP3Rh^80Shn?09VIV@0207emO@0407moO`1kNg/0Ng]k0;2`/080d=3@00D0
YZJV06ATI02`/;00/;2`09:BTP020:BTY00508n?S`2XZ:P0Z:RX092@T02XZ:P00P1[Jf/01@1IFET0
>SXj03Xj>P1;Bd/0PX:20080IFEU00@0L71`07]kN`1kNg/0PX:20P1cLg<01@24Q8@0KFe]071`L01`
L700Lg=c0080MWIf00D0MgMg09ZJVP2JVYX0_kno07inOP020:j^[P050;6a/@2<S8`0S8b<07EeM@25
QHD00P1nOWh0101dM7@0DE5A055AD@1VIVH2079bLP0307YjNP3oool0oooo00P0oooo000:0?ooo`04
0:^[Z`2UYJD0YJFU0:FUY@80WinO00D0VYZJ096AT@2KVi/0Vi^K09fMW@0208f=S@0508B4Q029RHT0
RHV90451@@1hN7P00P2<S8`01@25QHD0Rh^;08^;R`2:RXX0QhN70080R8R800@0Ph>309NGU`2GUiL0
RXZ:0P1ZJVX01@1QHF40LG5a02l_;`0_;bl0QXJ60080Ti>C00D0VIVI08R8R01iNGT0NGUi07YjNP02
07UiN@0508N7Q`2TY:@0Rh^;08^;R`1YJFT00P1UIFD01@1FEUH0<30`030`<021PH40RHV90080U9BD
00D0UiNG09>CT`2CTi<0S8b<08V9R@0207UiN@0407IfMP20P800P82009>CT`80UYJF00D0S8b<0410
@02CTi<0Ti>C09NGU`0208j>SP0508>3P`29RHT0QhN708N7Q`29RHT00P2JVYX00`2?Shl0Ti>C09>C
T`0208n?S`80JFUY00D0DU9B06EUI@1UIFD0HV9R06QXJ00206i^KP0506m_K`1dM7@0M7Ad075aL@1i
NGT00P2=SHd0102EUID0N7Qh07QhN01?Cdl207inOP0409NGU`2EUID0XJ6Q0:6QX@<0YJFU00D0YjNW
0:>SX`2GUiL0UiNG0:JVYP0209VIV@0409^KV`25QHD0QHF506QXJ0<0UYJF00D0/;2`0;Fe]@2e]KD0
ZZZZ09FEU@0209bLW00508^;R`2GUiL0UiNG09ZJVP2GUiL00P2NWYh0100i>CT0D51@051@D01TI6@2
09:BTP0508V9R@2;Rh/0Hf=S06=SH`18B4P00P1JFUX00`1@D500NGUi08>3P`0208>3P`80?Shn00D0
JFUY09NGU`2GUiL0XZ:R09VIV@02096AT@0409jNWP2QXJ40XJ6Q0:2PX140oooo00@0KFe]0:f][@2]
[Jd0OGem0P1WIfL01@27QhL0WinO09nOW`2WYjL0];Bd0080SXj>00D0O7al061PH01PH600RHV908n?
S`0205]KF`0407MgM`1VIVH0IVIV07emO@80T92@00D0Kfm_04Q8B01GEeL0EeMG0410@00204M7A`05
06EUI@1`L700L71`0;Bd]028R8P00P2DU9@0102VYZH0V9RH09RHV01LG5`206ATI00507MgM`2KVi/0
d=3@0=3@d02MWId00P1LG5`01@20P800F5QH08N7Q`27QhL0UIFE0080bl_;00D0]KFe08:2PP22PX80
NGUi05mOG`0207alO00407AdM024Q8@0Q8B406ATI080OWin00D0RXZ:0:ZZZP2HV9P0V9RH08J6QP02
08n?S`05075aL@3Fe]H0_kno0;no_`2c/k<00P1UIFD01@37alL0UiNG09NGU`1VIVH0MWIf0080N7Qh
00@0Hf=S09:BTP2BTY80P8200P2SXj<01@26QXH0ZZZZ0:j^[P2^[Zh0Rh^;0080HV9R00D0QhN70:NW
Y`2_[jl0[jn_0;fm_@020410@0050::RXP3Rh^80h^;R08n?S`2IVIT00P1mOGd0101oOgl0Ng]k07]k
N`2`/;020=3@d0050:JVYP1TI6@0/;2`0;2`/02BTY800P2TY:@01@2?Shl0Z:RX0:RXZ02@T900Z:RX
0080Jf][00D0FEUI03Xj>P0j>SX0Bd];08:2PP0206EUI@04071`L01kNg/0Ng]k08:2PP80Lg=c00D0
Q8B406e]K@1`L700L71`07=cL`0207IfMP0507MgM`2JVYX0VYZJ0;no_`1nOWh00P2^[Zh01@2a/K40
S8b<08b<S01eMGD0QHF50080OWin00@0M7Ad055AD@1ADE40IVIV0P1bLW800`1jNWX0oooo0?ooo`08
0?ooo`002P3oool0101`L700IfMW06MWI`1[Jf/206QXJ005069RHP1SHf<0I6AT06ATI01VIVH00P1C
De<01@1HF5P0HF5Q065QH@0f=SH0ATI60080EUIF0`1DE5@01@1BDU80De=C04e=C@1=CDd0AdM70080
C4a<00D0CTi>03Lg=`0g=cL0>SXj0410@00201hN7P05055AD@1KFe/0Fe]K06ATI01QHF400P1TI6@0
1@1RHV80GEeM05eMG@1SHf<0I6AT0080H61P00@0Cdm?04E5A@15ADD0=cLg0P0/;2`01@1FEUH0FEUI
05YJFP1JFUX0GemO0080Fe]K00D0BTY:04A4A01ADE40DE5A04I6AP0204Q8B0<0Bd];00D0@d=301`L
701RHV80HV9R05iNGP0206ATI00505iNGP1HF5P0DU9B059BDP1IFET00P1VIVH01@1BDU80GemO05mO
G`1MGEd0ADE50080>3Ph00D0;bl_04A4A014A4@0@d=303Xj>P02038b<P0403De=@12@T80@T92051@
D0<0De=C00@0EEEE02XZ:P0Z:RX09BDU0P0N7Qh01@19BDT0EUIF05QHF01HF5P0B4Q80080BDU900D0
Bd];03dm?@10@400@41005ADE00204Q8B00503/k>`0Q8B408B4Q02DU9@0];Bd00P0F5QH01@0U9BD0
<30`030`<00Y:BT0=CDe00808B4Q00D0820P02HV9P0V9RH09BDU02TY:@0201lO7`0400`<300A4A40
4A4A01hN7P<09BDU00@06a/K01`L700L71`061PH0P0I6AT01@0M7Ad09bLW02LW9`0W9bL0;Bd]0080
92@T00@09RHV02XZ:P0Z:RX0<S8b0`0T92@01010@400@D510451@@14A4@A0?ooo`0407YjNP2n_[h0
_[jn08J6QP80IFEU00D0Q8B40:2PX02PX:00YZJV0:j^[P0208j>SP0507moO`1LG5`0G5aL08>3P`2C
Ti<00P1VIVH0101SHf<0Fe]K05]KF`1bLW8207YjNP050451@@14A4@0OGem07emO@1LG5`00P1HF5P3
06MWI`050:^[Z`27QhL0T92@092@T02d];@00P2TY:@01@1RHV80JFUY06UYJ@1aLG40Z:RX0080c<c<
00D0Xj>S06YZJP1ZJVX0SHf=05aLG0020861P@040::RXP3:b/X0b/[:0;:b/P80O7al00D0N7Qh05mO
G`23Ph<0Ph>3079bLP0208F5Q@0506ATI01hN7P0N7Qh08j>SP2c/k<00P2SXj<01@2<S8`0Xj>S0:>S
X`1eMGD0a<C40080]kNg00@0]KFe08^;R`2;Rh/0_;bl0P2c/k<01@28R8P0PX:207UiN@1iNGT0DU9B
0080P82000D0OGem09VIV@2IVIT0QXJ60:FUY@020:f][@0508:2PP1NGUh0GUiN08R8R02JVYX00P2a
/K401031`L40@T920492@P2QXJ420=SHf00508F5Q@2>SXh0MWIf07IfMP1oOgl00P1dM7@01@2_[jl0
dM7A0=7Ad@2OWil0JFUY0080][Jf00@0S8b<09NGU`2GUiL0P8200P2XZ:P01@22PX80[jn_075aL@1a
LG40D51@0080?3`l00D0G5aL08B4Q01RHV80HV9R09>CT`02071`L00507EeM@1iNGT0NGUi07inOP23
Ph<00P1bLW80101fMWH0KFe]06e]K@1nOWh209VIV@050;6a/@1QHF40Ti>C09>CT`2YZJT00P2@T900
1@2>SXh0UYJF07moO`1oOgl0Q8B40080OGem00@0Kfm_07YjNP1jNWX0Q8B42P3oool000X0oooo00@0
IfMW05EEE@1EEED0@d=30P0i>CT01@0H61P0<C4a05aLG01LG5`0@4100080Cdm?00D0De=C04e=C@1=
CDd0G5aL06EUI@0205iNGP<0GEeM00D0FUYJ05IFEP19BDT0BDU904i>CP0207]kN`05079bLP1ZJVX0
JVYZ06MWI`1XJ6P00P1]KFd01@1[Jf/0KVi^06i^KP1hN7P0KFe]0080Lg=c00D0K6a/0410@010@400
H61P06UYJ@02065QH@0405mOG`1IFET0FEUI05iNGP<0H61P00@0HF5Q069RHP1RHV80Fe]K0P1TI6@0
1@1NGUh0@T9206EUI@1UIFD0IVIV0080Hf=S00D0Bd];04e=C@1=CDd0HF5Q06i^KP0205iNGP0505IF
EP1IFET0FEUI05iNGP1UIFD00P0k>c/01012@T80K6a/06a/K01kNg/207QhN00507]kN`1hN7P0LW9b
079bLP1eMGD00P1aLG401@1SHf<0IfMW06][J`1[Jf/0JVYZ0080:BTY00D0BTY:06IVIP1eMGD0MGEe
075aL@0207inOP0508R8R026QXH0QXJ608B4Q02:RXX00P1iNGT01@1hN7P0PX:208:2PP1bLW80:b/[
0080Ng]k00@0QHF509BDU02DU9@0R8R80P2>SXh01@2VYZH0WYjN0::RXP2RXZ80X:2P0080XZ:R00D0
WinO09bLW00n?Sh0?Shn07YjNP0208F5Q@0508n?S`2GUiL0UiNG09NGU`2JVYX00P2RXZ801@2SXj<0
WinO09nOW`2OWil0V9RH0080Ti>C00D0IfMW07AdM01dM7@0TY:B08j>SP0208J6QP040861P@1QHF40
HF5Q06YZJP80RXZ:00D0U9BD08f=S@2=SHd0SHf=09FEU@0208^;R`0306ATI03oool0oooo00l0oooo
00@0P8200;Jf]P2f][H0R8R80P1[Jf/01@2<S8`0WYjN09jNWP2b/[80[Jf]0080S8b<00D0Ph>306IV
IP1VIVH0QXJ609:BTP02075aL@0406UYJ@18B4P0B4Q806m_K`80RHV900D0>SXj05IFEP1mOGd0OGem
06MWI`0206e]K@0507AdM01`L700L71`0:n_[`2CTi<00P2?Shl0102MWId0Vi^K09^KV`1XJ6P205YJ
FP0506=SH`2HV9P0`l?30<?3``2EUID00P1NGUh01@1oOgl0I6AT08R8R028R8P0/[:b0080d];B00D0
/[:b08Z:RP2:RXX0Ph>306=SH`0208j>SP0407emO@2ATI40TI6A06m_K`80H61P00D0OWin0:6QX@2G
UiL0UiNG07QhN00208F5Q@0507MgM`3AdM40`l?30<?3``2h^;P00P2EUID01@2MWId0/[:b0;:b/P2<
S8`0QXJ60080OGem00@0GUiN08^;R`2;Rh/0O7al0P2CTi<01@1hN7P0Y:BT0;6a/@2a/K40QXJ60080
FUYJ00D0QhN70:6QX@2_[jl0[jn_0<[:bP0204Y:BP050:NWY`3Kfm/0fm_K07EeM@24Q8@00P20P800
1025QHD0Lg=c07=cL`2a/K420<[:bP0509BDU01[Jf/0_[jn0;jn_P2>SXh00P2FUYH01@24Q8@0[:b/
0:b/[020P800^[Zj0080KVi^00D0Cdm?03`l?00l?3`0GUiN08>3P`0206QXJ00408Z:RP1VIVH0IVIV
071`L080JFUY00D0OGem07UiN@1[Jf/0Jf][06m_K`0205iNGP0507=cL`22PX80PX:209ZJVP1KFe/0
0P2DU9@01@2NWYh0NGUi07UiN@1WIfL0O7al0080JFUY00@0O7al06UYJ@1YJFT0Hf=S0P1hN7P00`22
PX80oooo0?ooo`080?ooo`002P3oool0101WIfL0EEEE05EEE@13@d<203Ti>@0501PH600a<C40G5aL
05aLG010@4000P1?Cdl01@1CDe<0CDe=04e=C@1LG5`0IFEU0080GUiN0`1MGEd01@1JFUX0EUIF04U9
B@19BDT0CTi>0080Ng]k00D0LW9b06YZJP1ZJVX0IfMW06QXJ00206e]K@0506][J`1^KVh0KVi^07Qh
N01]KFd00P1cLg<01@1/K6`0@4100410@01PH600JFUY0080HF5Q00@0GemO05UIF@1IFET0GUiN0`1P
H600101QHF40HV9R069RHP1KFe/206ATI00505iNGP12@T80IFEU06EUI@1VIVH00P1SHf<01@1;Bd/0
CDe=04e=C@1QHF40KVi^0080GUiN00D0EUIF05UIF@1IFET0GUiN06EUI@0203/k>`040492@P1/K6`0
K6a/07]kN`80N7Qh00D0Ng]k07QhN01bLW80LW9b07EeM@02075aL@0506=SH`1WIfL0Jf][06][J`1Z
JVX00P0Y:BT01@1:BTX0IVIV07EeM@1eMGD0LG5a0080OWin00D0R8R808J6QP26QXH0Q8B408Z:RP02
07UiN@0507QhN022PX80PX:2079bLP0[:b/00P1kNg/01025QHD0U9BD09BDU028R8P208j>SP050:JV
YP2NWYh0XZ:R0::RXP2PX:000P2RXZ801@2OWil0W9bL03hn?P0n?Sh0NWYj0080QHF500D0Shn?09NG
U`2GUiL0UiNG09ZJVP020::RXP050:>SX`2OWil0WinO09nOW`2HV9P00P2CTi<01@1WIfL0M7Ad07Ad
M02BTY80SXj>0080QXJ600@0PH61065QH@1QHF40JVYZ0P2:RXX01@2DU9@0SHf=08f=S@2=SHd0UIFE
0080Rh^;00<0I6AT0?ooo`3oool03`3oool01020P800][Jf0;Jf]P28R8P206][J`0508b<S02NWYh0
WYjN0;:b/P2][Jd00P2<S8`01@23Ph<0IVIV06IVIP26QXH0TY:B0080LG5a00@0JFUY04Q8B018B4P0
Kfm_0P29RHT01@0j>SX0EUIF07emO@1mOGd0IfMW0080KFe]00D0M7Ad071`L01`L700[jn_09>CT`02
08n?S`0409fMW@2KVi/0Vi^K06QXJ080FUYJ00D0Hf=S09RHV033`l<0`l?309FEU@0205iNGP0507mo
O`1TI6@0R8R808R8R02b/[800P3Bd]801@2b/[80RXZ:08Z:RP23Ph<0Hf=S0080SXj>00@0OGem096A
T@2ATI40Kfm_0P1PH6001@1nOWh0XJ6Q09NGU`2GUiL0N7Qh0080QHF500D0MgMg0=7Ad@33`l<0`l?3
0;Rh^00209FEU@0509fMW@2b/[80/[:b08b<S026QXH00P1mOGd0101NGUh0Rh^;08^;R`1lO7`209>C
T`0507QhN02TY:@0/K6a0;6a/@26QXH00P1JFUX01@27QhL0XJ6Q0:n_[`2_[jl0b/[:0080BTY:00D0
YjNW0=_Kf`3Kfm/0MGEe08B4Q0020820P00408F5Q@1cLg<0Lg=c0;6a/@80b/[:00D0U9BD06][J`2n
_[h0_[jn08j>SP0209JFUP0508B4Q02/[:`0[:b/0820P02j^[X00P1^KVh01@1?Cdl0?3`l03`l?01N
GUh0Ph>30080J6QX00@0RXZ:06IVIP1VIVH0L71`0P1YJFT01@1mOGd0NGUi06][J`1[Jf/0Kfm_0080
GUiN00D0Lg=c08:2PP22PX80VYZJ05]KF`0209BDU00509jNWP1iNGT0NGUi06MWI`1lO7`00P1YJFT0
101lO7`0JFUY06UYJ@1SHf<207QhN00308:2PP3oool0oooo00P0oooo000:0?ooo`040:n_[`2a/K40
/K6a0;Bd]080ZZZZ00D0?Shn05eMG@2CTi<0Ti>C05=CD`0205EEE@0507moO`25QHD0QHF508n?S`28
R8P00P2<S8`01@25QHD0Q8B408B4Q01nOWh0MgMg0080EEEE00@0QHF50;bl_02l_;`0_;bl0P2k^k/0
1@2e]KD0][Jf0;Jf]P2f][H0];Bd0080/;2`00D0/k>c0;2`/02b/[80/[:b0:n_[`0205aLG00507em
O@26QXH0NGUi07UiN@1aLG400P1YJFT01@1WIfL0IFEU06EUI@1QHF40I6AT0080Jf][00D0K6a/07Mg
M`1gMgL0OGem05aLG00209ZJVP0409BDU02GUiL0UiNG0:>SX`80ZJVY00D0Z:RX0:ZZZP2TY:@0Y:BT
0:6QX@020::RXP050:BTY02YZJT0M7Ad07AdM01ZJVX00P2UYJD01@2XZ:P0Zj^[0:^[Z`2ZZZX0Xj>S
0080YJFU00D0Y:BT0:>SX`2SXj<0Y:BT0:>SX`0209nOW`050:2PX00g=cL0=cLg07=cL`2PX:000P2S
Xj<0102VYZH0YjNW0:NWY`2VYZH20:BTY0050::RXP2UYJD0Shn?08n?S`2CTi<00P2JVYX01@1oOgl0
De=C09FEU@2EUID0XZ:R0080Vi^K00D0V9RH0:2PX02PX:00XZ:R0:NWY`020:JVYP050:FUY@2WYjL0
YjNW0:VYZ@2JVYX00P0f=SH01@2LW9`0X:2P0:2PX02XZ:P0[jn_0080Z:RX00@0XZ:R0:FUY@2UYJD0
YZJV0P2UYJD01@2LW9`0UYJF09RHV02HV9P0G5aL0080P82000D0WYjN09ZJVP28R8P0R8R8092@T002
09RHV00509VIV@27QhL0QhN708Z:RP2<S8`00P2=SHd0102PX:00Rh^;08^;R`1eMGDA0?ooo`0406i^
KP2ZZZX0ZZZZ08B4Q080Hf=S00D0PH610:RXZ02XZ:P0`<300:BTY00208b<S00508V9R@1/K6`0K6a/
08>3P`2NWYh00P22PX80101bLW80E5AD05ADE01oOgl209fMW@05061PH01JFUX0Rh^;08^;R`1lO7`0
0P1`L7001@1mOGd0N7Qh07QhN02e]KD0UiNG0080WIfM00@0/[:b0;^k^`2k^k/0LG5a0P1QHF401@1^
KVh0Y:BT0=;BdP3Bd]80Y:BT0080IFEU00D0PH6107emO@2EUID0UIFE0;Bd]0020=gMg@050;Fe]@2?
Shl0Shn?08N7Q`1QHF400P2>SXh0101eMGD0Q8B408B4Q01/K6`207IfMP050:JVYP2d];@0YjNW0:NW
Y`2CTi<00P2GUiL01@22PX80b<S80;Vi^@2i^KT0][Jf0080UIFE00D0UiNG0:f][@2][Jd0Ph>307al
O00207QhN00405aLG02FUYH0UYJF09:BTP80V9RH00D0Kfm_0:6QX@2][Jd0[Jf]07QhN00205eMG@05
08J6QP2>SXh0/k>c0;>c/`38b<P00P1;Bd/01@2WYjL0hn?S0>?Sh`1cLg<0UYJF0080QHF500@0Shn?
08>3P`23Ph<0^;Rh0P3IfMT01@2JVYX0JFUY0;Jf]P2f][H0UiNG0080S8b<00D0PH610:NWY`2WYjL0
IVIV0;^k^`0206UYJ@0503hn?P0/;2`0;2`/055AD@1kNg/00P1HF5P0102ATI40KVi^06i^KP1^KVh2
06QXJ00506ATI01aLG40Jf][06][J`1ADE400P1GEeL01@1XJ6P0Rh^;08^;R`2[Zj/0J6QX0080Shn?
00D0QhN706YZJP1ZJVX0GEeM06ATI00206e]K@0406UYJ@1VIVH0IVIV05eMG@80RXZ:00<0Rh^;0?oo
o`3oool0203oool000X0oooo00@0/k>c0;2`/02`/;00[jn_0P2XZ:P01@11@D40FEUI08R8R028R8P0
BDU90080E5AD00D0NGUi07MgM`1gMgL0Ogmo07YjNP0207alO0050820P01gMgL0MgMg07alO01cLg<0
0P1?Cdl01028R8P0][Jf0;Jf]P2h^;P20;>c/`050:^[Z`2][Jd0ZJVY0:VYZ@2PX:000P2SXj<01@2U
YJD0VYZJ0:NWY`2WYjL0YJFU0080HV9R00D0MWIf08N7Q`25QHD0QHF506=SH`0207=cL`0506QXJ01Q
HF40HF5Q05]KF`1CDe<00P1FEUH01@1QHF40HV9R069RHP1XJ6P0EEEE0080UIFE00@0XJ6Q09fMW@2M
WId0XJ6Q0P2UYJD01@2VYZH0[Zj^0:JVYP2VYZH0Vi^K00<0X:2P00@0YJFU06IVIP1VIVH0JVYZ0`2W
YjL20:b/[0050:BTY02QXJ40Y:BT0:BTY02RXZ800P2QXJ401@2RXZ80Y:BT0::RXP2RXZ80W9bL0080
?3`l00@0LG5a08n?S`2SXj<0Xj>S0`2TY:@01@2IVIT0X:2P0:2PX02SXj<0X:2P0080OWin00D0U9BD
09VIV@2IVIT0KFe]059BDP0209RHV00409ZJVP2KVi/0Vi^K09nOW`80YJFU00D0X:2P0:>SX`2@T900
T92@09nOW`020:ZZZP050:6QX@1`L7009BDU02DU9@2CTi<00P2PX:001@2ZZZX0/;2`0:f][@2][Jd0
[Zj^0080Zj^[00D0XJ6Q09jNWP2NWYh0WYjN09RHV00208^;R`0505ADE01fMWH0MWIf09FEU@2JVYX0
0P2OWil0102;Rh/0R8R808R8R02OWil208Z:RP0507YjNP2>SXh0Y:BT0:BTY02ZZZX00P2<S8`00`1a
LG40oooo0?ooo`0?0?ooo`0406i^KP23Ph<0Ph>306i^KP80GEeM00D0P82009VIV@2IVIT0YZJV08J6
QP0207emO@0507YjNP1ZJVX0JVYZ08j>SP2HV9P00P1hN7P01018B4P0CDe=04e=C@1/K6`20861P@05
06UYJ@1EEED0SXj>08j>SP1YJFT00P1WIfL01@1fMWH0LG5a075aL@2h^;P0T92@0080WIfM00@0/K6a
0;:b/P2b/[80IfMW0P1OGel01@1aLG40Y:BT0<S8b038b<P0Zj^[0080GemO00D0PX:206m_K`28R8P0
R8R80;bl_0020=cLg0050;6a/@21PH40PH610861P@1MGEd00P2<S8`01022PX80Q8B408B4Q01UIFD2
05mOG`0508b<S02RXZ80Vi^K09^KV`24Q8@00P2?Shl01@1oOgl0a/K60;Jf]P2f][H0^[Zj0080VIVI
00D0YZJV09ZJVP2JVYX0Q8B4075aL@02079bLP0305EEE@2IVIT0VIVI00<0V9RH00D0OWin0:BTY02Z
ZZX0ZZZZ075aL@0205]KF`0508J6QP2NWYh0[Zj^0:j^[P34a<@00P19BDT01@2][Jd0gmoO0=oOg`1T
I6@0U9BD0080N7Qh00@0MGEe07moO`1oOgl0[Zj^0P33`l<01@25QHD0IVIV0:b/[02/[:`0UIFE0080
QhN700D0Q8B408j>SP2>SXh0Fe]K0<71`@0206i^KP0504A4A00];Bd0;Bd]05=CD`1iNGT00P1CDe<0
0`2:RXX0LG5a075aL@0306UYJ@80M7Ad0P1]KFd0101UIFD0L71`071`L02<S8`209bLW0050::RXP1i
NGT0UIFE09FEU@2ATI400P1hN7P01@1QHF40L71`06YZJP1ZJVX0EEEE0080LG5a00@0DE5A079bLP1b
LW80S8b<2P3oool000X0oooo00@0[Jf]0:RXZ02XZ:P0Y:BT0P2BTY801@10@400B4Q807inOP1nOWh0
ADE50080EeMG00D0PX:207YjNP1jNWX0Ng]k07inOP02071`L00507YjNP1iNGT0NGUi07YjNP1hN7P0
0P16ATH0101nOWh0/;2`0;2`/02ZZZX309jNWP0409nOW`2PX:00X:2P09ZJVP80S8b<00D0T92@08>3
P`2CTi<0Ti>C09:BTP0206QXJ00506m_K`26QXH0Ph>308>3P`1[Jf/00P1bLW801@1hN7P0QHF508F5
Q@2<S8`0TI6A0080TY:B00D0QXJ607EeM@1eMGD0Lg=c05QHF00208n?S`0409JFUP2CTi<0Ti>C09fM
W@80WYjN00D0XJ6Q0::RXP2HV9P0V9RH08j>SP0208V9R@0508^;R`2FUYH0FUYJ05YJFP1ZJVX00P2S
Xj<30:6QX@0509VIV@2HV9P0WIfM09fMW@2IVIT00P2@T9001@2SXj<0YJFU0::RXP2RXZ80WinO0080
=CDe00D0E5AD07emO@2IVIT0VIVI0::RXP0209NGU`0509BDU02LW9`0W9bL0:>SX`2MWId00P1WIfL0
1@1jNWX0L71`071`L01VIVH0Hf=S0080Xj>S00@0XJ6Q0::RXP2RXZ80YJFU0P2VYZH01@2PX:00UiNG
07MgM`1gMgL0P8200080T92@00D0O7al075aL@0n?Sh0?Shn09:BTP0209jNWP050:^[Z`2YZJT0YZJV
0:JVYP2XZ:P00P2TY:@01@2OWil0WYjN09jNWP2GUiL0WYjN0080Q8B400<0?clo07EeM@1eMGD00P2;
Rh/209FEU@0408B4Q01lO7`0O7al096AT@80MgMg00D0NWYj09nOW`2OWil0WinO0:RXZ00208>3P`03
06][J`3oool0oooo00l0oooo00@0PX:20;2`/02`/;00Q8B40P1nOWh01@2JVYX0/[:b0;:b/P2UYJD0
RXZ:0080MgMg00D0RHV907=cL`1cLg<0G5aL07]kN`0207inOP0406i^KP25QHD0QHF508>3P`80QhN7
00D0F5QH04U9B@2:RXX0RXZ:06MWI`0205UIF@0507MgM`1WIfL0IfMW0:>SX`20P8000P2EUID0102^
[Zh0X:2P0:2PX01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/01@25QHD0Rh^;08R8
R028R8P0`<300080emOG00D0][Jf08J6QP26QXH0RHV905eMG@0208Z:RP040861P@1mOGd0OGem07If
MP80Hf=S00D0XZ:R0:2PX02`/;00/;2`09NGU`0209BDU00508j>SP3=cLd0`<300<30`032`/800P2T
Y:@01@2`/;00X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0T92@0P2UYJD01@24Q8@0
X:2P0:JVYP2VYZH0KVi^0080HV9R00D0Ng]k09RHV02][Jd0[Jf]0=OGe`0204Q8B00509RHV03Rh^80
h^;R07alO02PX:000`28R8P20861P@050;:b/P3EeMD0eMGE0:BTY01XJ6P00P2NWYh01026QXH0T92@
092@T02=SHd208b<S00505=CD`2a/K40PH610861P@1NGUh00P0n?Sh01@1DE5@0RHV905aLG01LG5`0
Shn?0080MGEe00@0HF5Q05UIF@1IFET0KFe]0`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@050:>S
X`23Ph<0Ti>C09>CT`2<S8`00P1gMgL01@1_Kfl0RHV906][J`1[Jf/0F5QH0080G5aL00@0DE5A06m_
K`1_Kfl0KVi^2P3oool000X0oooo00@0[Jf]0:RXZ02XZ:P0Y:BT0P2BTY801@10@400B4Q807inOP1n
OWh0ADE50080EeMG00D0PX:207YjNP1jNWX0Ng]k07inOP02071`L00507YjNP1iNGT0NGUi07YjNP1h
N7P00P16ATH0101nOWh0/;2`0;2`/02ZZZX309jNWP0409nOW`2PX:00X:2P09ZJVP80S8b<00D0T92@
08>3P`2CTi<0Ti>C09:BTP0206QXJ00506m_K`26QXH0Ph>308>3P`1[Jf/00P1bLW801@1hN7P0QHF5
08F5Q@2<S8`0TI6A0080TY:B00D0QXJ607EeM@1eMGD0Lg=c05QHF00208n?S`0409JFUP2CTi<0Ti>C
09fMW@80WYjN00D0XJ6Q0::RXP2HV9P0V9RH08j>SP0208V9R@0508^;R`2FUYH0FUYJ05YJFP1ZJVX0
0P2SXj<30:6QX@0509VIV@2HV9P0WIfM09fMW@2IVIT00P2@T9001@2SXj<0YJFU0::RXP2RXZ80WinO
0080=CDe00D0E5AD07emO@2IVIT0VIVI0::RXP0209NGU`0509BDU02LW9`0W9bL0:>SX`2MWId00P1W
IfL01@1jNWX0L71`071`L01VIVH0Hf=S0080Xj>S00@0XJ6Q0::RXP2RXZ80YJFU0P2VYZH01@2PX:00
UiNG07MgM`1gMgL0P8200080T92@00D0O7al075aL@0n?Sh0?Shn09:BTP0209jNWP050:^[Z`2YZJT0
YZJV0:JVYP2XZ:P00P2TY:@01@2OWil0WYjN09jNWP2GUiL0WYjN0080Q8B400<0?clo07EeM@1eMGD0
0P2;Rh/209FEU@0408B4Q01lO7`0O7al096AT@80MgMg00D0NWYj09nOW`2OWil0WinO0:RXZ00208>3
P`0306][J`3oool0oooo00l0oooo00@0PX:20;2`/02`/;00Q8B40P1nOWh01@2JVYX0/[:b0;:b/P2U
YJD0RXZ:0080MgMg00D0RHV907=cL`1cLg<0G5aL07]kN`0207inOP0406i^KP25QHD0QHF508>3P`80
QhN700D0F5QH04U9B@2:RXX0RXZ:06MWI`0205UIF@0507MgM`1WIfL0IfMW0:>SX`20P8000P2EUID0
102^[Zh0X:2P0:2PX01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/01@25QHD0Rh^;
08R8R028R8P0`<300080emOG00D0][Jf08J6QP26QXH0RHV905eMG@0208Z:RP040861P@1mOGd0OGem
07IfMP80Hf=S00D0XZ:R0:2PX02`/;00/;2`09NGU`0209BDU00508j>SP3=cLd0`<300<30`032`/80
0P2TY:@01@2`/;00X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0T92@0P2UYJD01@24
Q8@0X:2P0:JVYP2VYZH0KVi^0080HV9R00D0Ng]k09RHV02][Jd0[Jf]0=OGe`0204Q8B00509RHV03R
h^80h^;R07alO02PX:000`28R8P20861P@050;:b/P3EeMD0eMGE0:BTY01XJ6P00P2NWYh01026QXH0
T92@092@T02=SHd208b<S00505=CD`2a/K40PH610861P@1NGUh00P0n?Sh01@1DE5@0RHV905aLG01L
G5`0Shn?0080MGEe00@0HF5Q05UIF@1IFET0KFe]0`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@05
0:>SX`23Ph<0Ti>C09>CT`2<S8`00P1gMgL01@1_Kfl0RHV906][J`1[Jf/0F5QH0080G5aL00@0DE5A
06m_K`1_Kfl0KVi^2P3oool000X0oooo00@0P82006YZJP1ZJVX0B4Q80P1EEED01@0m?Cd0EEEE06][
J`1[Jf/0CDe=0080HV9R00D0GEeM06IVIP1VIVH0MgMg06MWI`0205UIF@0506a/K01_Kfl0Kfm_06EU
I@1DE5@00P0g=cL0101FEUH0UiNG09NGU`2DU9@2092@T00508V9R@21PH40MWIf07IfMP1eMGD00P1c
Lg<01@1ZJVX0I6AT051@D01@D500A4A40080<c<c00D09RHV05EEE@1?Cdl0Cdm?04Y:BP02055AD@03
04m?C`1UIFD0IFEU0080FUYJ0P1WIfL01@1FEUH0DE5A055AD@1?Cdl09BDU0080D51@00@0FUYJ05IF
EP1FEUH0J6QX0P1/K6`01@1PH600IVIV071`L01`L700IfMW0080FUYJ00D0DU9B05iNGP11@D40@D51
04e=C@0207QhN005075aL@1TI6@0I6AT06QXJ01RHV800P1VIVH01@1GEeL0DE5A055AD@1SHf<0KFe]
0080K6a/00D0IVIV02l_;`0_;bl0?Cdm05MGE`0205aLG00406e]K@1bLW80LW9b06m_K`<0LW9b00@0
IVIV04];B`1;Bd/0DE5A0P0i>CT01@0X:2P0@41005IFEP1FEUH0FEUI0080EEEE0`1NGUh01@1OGel0
FUYJ05iNGP1NGUh0Fe]K0080IfMW00D0EeMG04e=C@0Q8B408B4Q04I6AP0205EEE@05061PH01HF5P0
EeMG05MGE`1OGel00P1NGUh01@1KFe/0E5AD05ADE01DE5@0BTY:0080?Shn00D0:RXZ04=3@`13@d<0
D51@04E5A@0205=CD`0405MGE`1CDe<0De=C05ADE080B4Q800D0A4A404Q8B018B4P0B4Q804a<C002
038b<P0303Ph>03oool0oooo00l0oooo00@0QXJ60;>c/`2c/k<0RHV90P2BTY801@2KVi/0Zj^[0:^[
Z`2YZJT0UYJF0080SHf=00@0S8b<07alO01lO7`0Ng]k0`27QhL0101SHf<0GUiN05iNGP1dM7@209nO
W`0506EUI@1?Cdl0Ph>308>3P`1WIfL00P1ADE4306m_K`050:FUY@2DU9@0XZ:R0::RXP2XZ:P00P2K
Vi/01@1QHF40CDe=04e=C@1aLG40WYjN0080b/[:00D0UIFE05EEE@1EEED0P82008N7Q`0208^;R`04
0;Zj^P3De=@0e=CD0:JVYP80PX:200D0SXj>06=SH`21PH40PH6108V9R@0208J6QP0508Z:RP1^KVh0
KVi^0<C4a02TY:@00P2d];@01@2NWYh0UYJF09JFUP27QhL0`L710080aLG500@0^KVi09^KV`2KVi/0
/K6a0P2VYZH01@2=SHd0QHF50820P020P800F5QH0080X:2P00D0T92@09fMW@2MWId0Q8B409nOW`02
0:FUY@05079bLP1SHf<0Hf=S08:2PP2MWId00P2HV9P0103@d=00ATI604I6AP29RHT20=[JfP0508n?
S`2GUiL0Q8B408B4Q01fMWH00P1kNg/01@2WYjL0dM7A0=7Ad@2SXj<0VIVI0080Z:RX00@0XZ:R09fM
W@2MWId0XZ:R0P2MWId01@1EEED0Shn?08n?S`2?Shl0EEEE0080>3Ph00D0D51@07QhN01@D500D51@
08F5Q@0206m_K`0506a/K01BDU80DU9B06ATI01nOWh00P1dM7@0101YJFT0De=C05=CD`1lO7`207Mg
M`0509fMW@20P800WinO09nOW`2CTi<00P1^KVh01@1dM7@0WIfM07=cL`1cLg<0HF5Q0080Fe]K00@0
EUIF06QXJ01XJ6P0Kfm_2P3oool000X0oooo00@0H61P030`<00`<300:2PX0P1DE5@01@1KFe/0DE5A
04A4A014A4@0?Shn008071`L00D08R8R05=CD`1CDe<0De=C04];B`0204U9B@0503Hf=P0L71`071`L
00X:2P1ADE400P1LG5`0101]KFd0J6QX06QXJ01ZJVX20492@P05024Q8@0k>c/0B4Q804Q8B01<C4`0
0P1ADE40101KFe/0A4A402TY:@0Y:BT305]KF`80GUiN0P1QHF401018B4P09RHV02HV9P1GEeL206YZ
JP05075aL@1cLg<0NWYj07YjNP0o?cl00P0U9BD205YJFP80GemO00@0Hf=S05aLG01LG5`0:2PX0P0g
=cL01@1UIFD0LG5a0861P@21PH40MgMg0080LW9b0P0[:b/304E5A@80Cdm?00D0De=C020P800P8200
:RXZ06EUI@0206a/K00505eMG@1RHV80HV9R05mOG`10@4000P19BDT306QXJ00506ATI01QHF40?clo
03lo?`0N7Qh00P16ATH01@1SHf<0HV9R069RHP1[Jf/0Lg=c0080:RXZ00D0AdM707QhN01hN7P0QHF5
08R8R00207]kN`0406IVIP0[:b/0:b/[06YZJP80PH6100D0QhN708V9R@28R8P0R8R804Y:BP020492
@P0506][J`24Q8@0SXj>08j>SP2;Rh/00P1JFUX01@071`L0<c<c05ADE01DE5@0A4A40080>3Ph00D0
HV9R05=CD`1CDe<06ATI06ATI00207]kN`0508R8R02:RXX0RXZ:07emO@1:BTX00P0f=SH306e]K@05
071`L01lO7`0O7al07inOP0n?Sh00P1TI6@01022PX80SXj>08j>SP2DU9@A0?ooo`0407emO@2YZJT0
ZJVY08:2PP80WIfM00D0U9BD0:JVYP2VYZH0Zj^[09>CT`0208F5Q@0407QhN01lO7`0O7al07MgM`<0
Ph>30`1kNg/01@1gMgL0Ti>C09>CT`1PH600CDe=0080QXJ600@0Fe]K05UIF@1IFET0IfMW0P1]KFd0
1@2[Zj/0UiNG0:BTY02TY:@0ZZZZ0080WYjN00D0IFEU05aLG01LG5`0Ogmo0:JVYP020=;BdP050:>S
X`1PH600H61P08f=S@2FUYH00P1mOGd0102VYZH0b/[:0<[:bP28R8P206a/K00508J6QP1UIFD0PX:2
08:2PP20P8000P1_Kfl01@1gMgL0GUiN05iNGP30`<00XZ:R0080YJFU00D0U9BD096AT@2ATI40Ng]k
0<W9b@020<C4a0040;bl_02XZ:P0Z:RX0;jn_P80Z:RX00D0Rh^;07inOP1nOWh0OWin05eMG@0209JF
UP0508^;R`2YZJT0ZJVY08^;R`2SXj<00P2g]kL01@1mOGd0K6a/06a/K02=SHd0]KFe0080[jn_00@0
eMGE04I6AP16ATH0WinO0P3De=@01@2/[:`0VIVI08V9R@29RHT0L71`0080QhN700D0Y:BT0<c<c03<
c<`0S8b<08J6QP020:6QX@040:JVYP27QhL0QhN709bLW080WYjN00D0HV9R0:ZZZP2<S8`0S8b<05MG
E`0203Ti>@0505eMG@1nOWh0E5AD05ADE021PH400P1VIVH01@1PH600E5AD05ADE01VIVH0Q8B40080
Kfm_00@0GUiN05=CD`1CDe<0O7al0P21PH401@2h^;P0P8200:FUY@2UYJD0TI6A0080MWIf00D0RXZ:
0:2PX01fMWH0MWIf06EUI@0206YZJP0406IVIP1dM7@0M7Ad08B4Q0X0oooo000:0?ooo`04061PH00`
<300<30`02PX:080E5AD00D0Fe]K055AD@14A4@0A4A403hn?P0201`L7005028R8P1CDe<0De=C05=C
D`1;Bd/00P19BDT01@0f=SH071`L01`L700:2PX0DE5A0080G5aL00@0KFe]06QXJ01XJ6P0JVYZ0P12
@T801@0Q8B40>c/k04Q8B018B4P0C4a<0080DE5A00@0Fe]K04A4A00Y:BT0:BTY0`1KFe/205iNGP80
HF5Q00@0B4Q802HV9P0V9RH0EeMG0P1ZJVX01@1aLG40Lg=c07YjNP1jNWX0?clo00809BDU0P1JFUX2
05mOG`0406=SH`1LG5`0G5aL02PX:080=cLg00D0IFEU075aL@21PH40PH6107MgM`02079bLP80:b/[
0`15ADD204m?C`0505=CD`0P8200820P02XZ:P1UIFD00P1/K6`01@1MGEd0HV9R069RHP1OGel0@410
0080BDU90`1XJ6P01@1TI6@0HF5Q03lo?`0o?cl07QhN0080ATI600D0Hf=S069RHP1RHV80Jf][07=c
L`0202XZ:P0504M7A`1hN7P0N7Qh08F5Q@28R8P00P1kNg/0101VIVH0:b/[02/[:`1ZJVX20861P@05
08N7Q`29RHT0R8R808R8R01:BTX00P12@T801@1[Jf/0Q8B408j>SP2>SXh0Rh^;0080FUYJ00D01`L7
03<c<`1DE5@0E5AD04A4A00203Ph>005069RHP1CDe<0De=C01TI6@1TI6@00P1kNg/01@28R8P0RXZ:
08Z:RP1mOGd0BTY:0080=SHf0`1]KFd01@1`L700O7al07alO01nOWh0?Shn0080I6AT00@0PX:208j>
SP2>SXh0U9BD4@3oool0101mOGd0ZJVY0:VYZ@22PX8209fMW@0509BDU02VYZH0YZJV0:^[Z`2CTi<0
0P25QHD0101hN7P0O7al07alO01gMgL308>3P`<0Ng]k00D0MgMg09>CT`2CTi<0H61P04e=C@0208J6
QP0405]KF`1IFET0FEUI06MWI`80KFe]00D0Zj^[09NGU`2TY:@0Y:BT0:ZZZP0209jNWP0506EUI@1L
G5`0G5aL07moO`2VYZH00P3Bd]801@2SXj<0H61P061PH02=SHd0UYJF0080OGem00@0YZJV0<[:bP3:
b/X0R8R80P1/K6`01@26QXH0IFEU08:2PP22PX80P8200080Kfm_00D0MgMg05iNGP1NGUh0`<300::R
XP020:FUY@0509BDU02ATI40TI6A07]kN`39bLT00P34a<@0102l_;`0Z:RX0:RXZ02n_[h20:RXZ005
08^;R`1nOWh0OWin07inOP1MGEd00P2FUYH01@2;Rh/0ZJVY0:VYZ@2;Rh/0Xj>S0080]kNg00D0OGem
06a/K01/K6`0SHf=0;Fe]@020:n_[`040=GEe@16ATH0ATI609nOW`80e=CD00D0[:b/09VIV@29RHT0
RHV9071`L00208N7Q`050:BTY03<c<`0c<c<08b<S026QXH00P2QXJ40102VYZH0QhN708N7Q`2LW9`2
09jNWP05069RHP2ZZZX0S8b<08b<S01GEeL00P0i>CT01@1MGEd0OWin05ADE01DE5@0PH610080IVIV
00D0H61P05ADE01DE5@0IVIV08B4Q00206m_K`0405iNGP1CDe<0De=C07alO080PH6100D0^;Rh0820
P02UYJD0YJFU096AT@0207IfMP0508Z:RP2PX:00MWIf07IfMP1UIFD00P1ZJVX0101VIVH0M7Ad07Ad
M024Q8@:0?ooo`002P3oool0102l_;`0JFUY06UYJ@1DE5@20:ZZZP0509BDU027QhL0RHV908V9R@2@
T9000P0h>3P01@19BDT0UiNG09NGU`2TY:@0/;2`0080/k>c00D0Xj>S051@D01@D500:RXZ0;:b/P02
0;>c/`040;Rh^02k^k/0^k^k0;bl_080OGem00D06QXJ09JFUP2UYJD0YJFU09^KV`0309ZJVP0407Qh
N00d=3@0=3@d08J6QP80Q8B400D0MGEe0861P@1kNg/0Ng]k05=CD`0204A4A00508>3P`2=SHd0SHf=
09BDU02<S8`00P2@T9001@1GEeL0=CDe03De=@2RXZ80Vi^K0080UYJF00@0X:2P0::RXP2RXZ80EEEE
0P1QHF400`2UYJD0YZJV0:VYZ@020:VYZ@80TI6A00D0?Shn07alO02;Rh/0Rh^;08R8R00208b<S004
07inOP1iNGT0NGUi055AD@<0XZ:R00D0ZJVY0:^[Z`2[Zj/0R8R806=SH`0207AdM0050:2PX02FUYH0
UYJF08N7Q`2HV9P00P2NWYh01012@T80WIfM09fMW@2KVi/209FEU@050:2PX02NWYh0EUIF05IFEP1i
NGT00P2PX:001@2VYZH0YjNW0:JVYP2VYZH0V9RH0080>CTi00D0S8b<0:RXZ02XZ:P0ZZZZ0:FUY@02
0:BTY00505MGE`1cLg<0Lg=c0:j^[P2d];@00P2c/k<01@2d];@0QHF508F5Q@0E5AD0Ng]k0080YZJV
00@0XZ:R0:FUY@2UYJD0Zj^[0P2BTY801@0N7Qh0Rh^;08n?S`2?Shl0TI6A0080W9bL00D0Y:BT05QH
F00e=CD0=CDe09NGU`020:2PX0050:f][@2d];@0];Bd0;Bd]016ATH00P2@T900102ZZZX0/[:b0;:b
/P2h^;PA0?ooo`0408N7Q`2/[:`0[:b/08>3P`80Rh^;00D0PH610:RXZ02XZ:P0XZ:R09VIV@0208b<
S00508:2PP1gMgL0MgMg06][J`25QHD00P2@T9001028R8P0PH610861P@24Q8@209JFUP0506m_K`1E
EED0NGUi07UiN@1aLG400P1QHF401@1lO7`0KFe]06e]K@2][Jd0W9bL0080XJ6Q00@0/;2`0:>SX`2S
Xj<0IVIV0P1YJFT01@29RHT0[jn_0=KFeP3Fe]H0WYjN0080GEeM00D0Ph>308N7Q`24Q8@0Q8B40:ZZ
ZP020=OGe`050;>c/`27QhL0QhN709fMW@1JFUX00P24Q8@0101kNg/0OGem07emO@25QHD2071`L005
0<;2`P2`/;00/K6a0;6a/@2HV9P00P2PX:001@28R8P0b/[:0<?3``33`l<0Xj>S0080VIVI00D0_[jn
09jNWP2NWYh0SXj>0820P00207inOP0406MWI`2BTY80TY:B09JFUP80XJ6Q00D0RHV90:RXZ02ZZZX0
ZZZZ06m_K`0206MWI`0507inOP2UYJD0];Bd0;Bd]03>c/h00P14A4@01@2TY:@0hn?S0>?Sh`2_[jl0
TY:B0080S8b<00@0QXJ60::RXP2RXZ80_;bl0P3Cdm<01@2GUiL0PH610:f][@2][Jd0[:b/0080Ogmo
00D0VYZJ09nOW`2OWil0HV9R0:ZZZP0209BDU00504Q8B00`<300<30`061PH02:RXX00P1OGel0101h
N7P0IVIV06IVIP1IFET2055AD@0506YZJP26QXH0Q8B408B4Q02;Rh/00P1FEUH01@20P800UIFE09FE
U@2][Jd0MGEe0080VYZJ00D0NGUi07alO01lO7`0S8b<0;bl_002092@T00405aLG01>CTh0CTi>061P
H080LG5a00<0OGem0?ooo`3oool0203oool000X0oooo00@0^k^k069RHP1RHV80CDe=0P2SXj<01@2V
YZH0X:2P09>CT`2CTi<0Ogmo0080<C4a00D0BDU90:BTY02TY:@0WinO09jNWP020:^[Z`050:RXZ01F
EUH0EUIF02TY:@2^[Zh00P2i^KT0102l_;`0]kNg0;Ng]`2i^KT207AdM00501lO7`2RXZ80YJFU0:FU
Y@2@T9000P2=SHd01@2?Shl0LW9b02d];@0];Bd0R8R80080T92@00D0V9RH092@T01kNg/0Ng]k04M7
A`0203<c<`0507MgM`2ATI40TI6A09VIV@2ATI400P2JVYX01@1DE5@0;2`/02`/;02MWId0XZ:R00<0
W9bL0P2OWil01@1CDe<0J6QX06QXJ02UYJD0ZJVY0080Z:RX00D0X:2P09BDU02DU9@0@d=307QhN002
07]kN`04092@T02DU9@0U9BD06e]K@80C4a<00D0EUIF09:BTP2JVYX0VYZJ0:JVYP020:j^[P050:ZZ
ZP1HF5P0MgMg07MgM`2EUID00P23Ph<01@24Q8@0S8b<08:2PP22PX80CDe=0080XJ6Q00D0X:2P08j>
SP2>SXh0QXJ609JFUP0205YJFP0507inOP2/[:`0[:b/0:ZZZP2YZJT00P2JVYX0102@T900A4A404A4
A02PX:020;2`/0050;>c/`2a/K40[Zj^0:j^[P1XJ6P00P1iNGT01@2][Jd0][Jf0;Rh^02h^;P0][Jf
0080RHV900D03`l?06m_K`2QXJ40XJ6Q0:NWY`020:ZZZP050:f][@2VYZH0YZJV01dM7@21PH400P2E
UID01@2MWId0X:2P0:2PX02KVi/0C4a<0080@D5100@0YjNW0:VYZ@2YZJT0Zj^[0P2/[:`01@2UYJD0
@d=308^;R`2;Rh/0Zj^[0080[Jf]00<0];Bd0?ooo`3oool03`3oool0101jNWX0YJFU0:FUY@25QHD2
08J6QP0508Z:RP2_[jl0[jn_0:j^[P2EUID00`2=SHd2079bLP0506=SH`1jNWX0Q8B408B4Q01cLg<0
0P1nOWh01@27QhL0ZJVY0:VYZ@1gMgL0DU9B0080RHV900@0NGUi06YZJP1ZJVX0QXJ60P1oOgl01@2h
^;P0VIVI08Z:RP2:RXX0ZZZZ0080X:2P00D0IVIV06ATI01TI6@0J6QX0::RXP020=3@d00509VIV@1N
GUh0GUiN08V9R@2=SHd00P29RHT0102a/K40dm?C0=?Cd`2WYjL207MgM`0507EeM@17AdL0Lg=c07=c
L`1jNWX00P1hN7P01@1TI6@0F5QH05QHF01mOGd0X:2P0080Vi^K00D0VYZJ09jNWP2NWYh0R8R80<K6
aP020;bl_0040;2`/029RHT0RHV90;jn_P80V9RH00D0R8R808^;R`1iNGT0NGUi07MgM`02092@T005
09jNWP2QXJ40XJ6Q08b<S02^[Zh00P2`/;001@1`L700J6QX06QXJ01dM7@0UiNG0080/K6a00@0bl_;
04=3@`13@d<0VIVI0P3Shn<01@2e]KD0UIFE08V9R@29RHT0Rh^;0080Z:RX00D0_[jn0=GEe@3EeMD0
W9bL08>3P`020;:b/P040:f][@27QhL0QhN70::RXP80WYjN00D0Fe]K0:^[Z`2DU9@0U9BD061PH002
03Ph>005079bLP2QXJ40QhN708N7Q`24Q8@00P1bLW801@1`L700CTi>04i>CP1TI6@0Lg=c0080L71`
00@0PH6104];B`1;Bd/0LW9b0P23Ph<01@2][Jd0SHf=0:f][@2][Jd0Shn?0080Ogmo00D0U9BD0:f]
[@2EUID0UIFE05iNGP0206IVIP0405]KF`1YJFT0JFUY07IfMPX0oooo000:0?ooo`040;Ng]`1WIfL0
IfMW05EEE@80Y:BT00D0YJFU0:>SX`2MWId0WIfM08:2PP0203`l?00504a<C02OWil0WinO09jNWP2J
VYX00`2TY:@205QHF00502PX:02][Jd0^;Rh0;Rh^02b/[800P2_[jl01@2d];@0MGEe07EeM@0R8R80
WYjN0080XZ:R00D0W9bL09RHV02HV9P0U9BD06e]K@0203Lg=`0508f=S@2IVIT0VIVI08F5Q@2;Rh/0
0P2@T900101OGel0?Cdm03dm?@2>SXh20:BTY0050:ZZZP2TY:@0Y:BT0:BTY01gMgL00P16ATH01@2Q
XJ40XZ:R0::RXP2RXZ80TI6A0080WIfM00D0GUiN06MWI`1WIfL0YjNW0:j^[P020:n_[`050::RXP2C
Ti<0Ti>C03/k>`2>SXh00P2OWil0102ATI40QXJ608J6QP1RHV8203Xj>P050451@@1fMWH0Ogmo07mo
O`2:RXX00P2CTi<01@28R8P0DE5A07UiN@1iNGT0S8b<0080Ogmo00D0Ph>308Z:RP2=SHd0SHf=04M7
A`0208n?S`0509nOW`2HV9P0V9RH08^;R`2JVYX00P1PH6001@1aLG40Z:RX0:RXZ02XZ:P0YjNW0080
W9bL00@0Ti>C03Xj>P0j>SX0[Jf]0P2h^;P01@2d];@0/k>c0;:b/P2b/[80G5aL0080Rh^;00D0]kNg
0;Vi^@2f][H0][Jf0:ZZZP0208J6QP0504A4A021PH40YJFU0:FUY@2[Zj/00P2a/K401@2`/;00WinO
09nOW`0R8R80RXZ:0080UIFE00D0X:2P0:>SX`2SXj<0YjNW05mOG`0205aLG0040:^[Z`2TY:@0Y:BT
096AT@80OGem00D0O7al03Lg=`2;Rh/0Rh^;0:JVYP020:ZZZP030:^[Z`3oool0oooo00l0oooo00@0
RXZ:0:JVYP2VYZH0Rh^;0P22PX801@2MWId0[:b/0:b/[02_[jl0WYjN0080PX:200D0RXZ:07=cL`1c
Lg<0HF5Q07emO@0208^;R`04071`L025QHD0QHF507YjNP80Vi^K00D0Ng]k05IFEP1oOgl0Ogmo065Q
H@02061PH00507]kN`1]KFd0KFe]0;Bd]02DU9@00P25QHD0102a/K40Z:RX0:RXZ01/K6`206QXJ005
065QH@2JVYX0emOG0=OGe`2WYjL00P1YJFT208B4Q080Shn?00@0][Jf0=GEe@3EeMD0[jn_0P1mOGd0
1@24Q8@0GemO09:BTP2BTY80NGUi0080UIFE00D0IFEU07UiN@1iNGT0/K6a0;Ng]`020;:b/P0509FE
U@2NWYh0WYjN08N7Q`3@d=000P34a<@0102[Zj/0R8R808R8R02e]KD208^;R`0507alO021PH40MGEe
07EeM@1nOWh00P2;Rh/01@2SXj<0XJ6Q0:6QX@22PX80_;bl0080Y:BT00D0P82006YZJP1ZJVX0IfMW
09fMW@020;Ng]`040<[:bP1;Bd/0Bd];09jNWP80i>CT00D0/K6a08J6QP1`L700L71`0820P0020:NW
Y`050;:b/P3>c/h0c/k>09fMW@1nOWh00P2`/;000`2VYZH0Ogmo07moO`0309BDU00506m_K`32`/80
TI6A096AT@1?Cdl00P0/;2`01@1cLg<0W9bL07]kN`1kNg/0LW9b0080MGEe00D0N7Qh06QXJ01XJ6P0
Kfm_079bLP0207MgM`0408Z:RP1>CTh0CTi>07]kN`80WinO00D0Y:BT09jNWP2i^KT0^KVi08b<S002
09:BTP050:JVYP2d];@0V9RH09RHV01IFET00P1OGel0101MGEd0GemO05mOG`20P80:0?ooo`002P3o
ool0102g]kL0IfMW06MWI`1EEED20:BTY0050:FUY@2SXj<0WIfM09fMW@22PX800P0l?3`01@1<C4`0
WinO09nOW`2NWYh0VYZJ00<0Y:BT0P1HF5P01@0X:2P0[Jf]0;Rh^02h^;P0/[:b0080[jn_00D0];Bd
07EeM@1eMGD08R8R09jNWP020::RXP0509bLW02HV9P0V9RH09BDU01]KFd00P0g=cL01@2=SHd0VIVI
09VIV@25QHD0Rh^;0080T92@00@0GemO03dm?@0m?Cd0SXj>0P2TY:@01@2ZZZX0Y:BT0:BTY02TY:@0
MgMg0080ATI600D0XJ6Q0::RXP2RXZ80XZ:R096AT@0209fMW@0505iNGP1WIfL0IfMW0:NWY`2^[Zh0
0P2_[jl01@2RXZ80Ti>C09>CT`0k>c/0SXj>0080WinO00@0TI6A08J6QP26QXH0HV9R0P0j>SX01@11
@D40MWIf07moO`1oOgl0RXZ:0080Ti>C00D0R8R8055AD@1iNGT0NGUi08b<S00207moO`0508>3P`2:
RXX0SHf=08f=S@17AdL00P2?Shl01@2OWil0V9RH09RHV02;Rh/0VYZJ0080H61P00D0LG5a0:RXZ02X
Z:P0Z:RX0:NWY`0209bLW00409>CT`0j>SX0>SXj0:f][@80^;Rh00D0];Bd0;>c/`2b/[80/[:b05aL
G00208^;R`050;Ng]`2i^KT0][Jf0;Jf]P2ZZZX00P26QXH01@14A4@0PH610:FUY@2UYJD0Zj^[0080
/K6a00D0/;2`09nOW`2OWil08R8R08Z:RP0209FEU@050:2PX02SXj<0Xj>S0:NWY`1OGel00P1LG5`0
102[Zj/0Y:BT0:BTY02ATI4207emO@0507alO00g=cL0Rh^;08^;R`2VYZH00P2ZZZX00`2[Zj/0oooo
0?ooo`0?0?ooo`0408Z:RP2VYZH0YZJV08^;R`80PX:200D0WIfM0:b/[02/[:`0[jn_09jNWP0208:2
PP0508Z:RP1cLg<0Lg=c065QH@1mOGd00P2;Rh/0101`L700QHF508F5Q@1jNWX209^KV`0507]kN`1F
EUH0Ogmo07moO`1QHF400P1PH6001@1kNg/0KFe]06e]K@2d];@0U9BD0080QHF500@0/K6a0:RXZ02X
Z:P0K6a/0P1XJ6P01@1QHF40VYZJ0=OGe`3GemL0YjNW0080JFUY0P24Q8@208n?S`040;Jf]P3EeMD0
eMGE0:n_[`80OGem00D0Q8B405mOG`2BTY80TY:B07UiN@0209FEU@0506EUI@1iNGT0NGUi0;6a/@2g
]kL00P2b/[801@2EUID0WYjN09jNWP27QhL0d=3@0080a<C400@0Zj^[08R8R028R8P0]KFe0P2;Rh/0
1@1lO7`0PH6107EeM@1eMGD0OWin0080Rh^;00D0Xj>S0:6QX@2QXJ40PX:20;bl_0020:BTY0050820
P01ZJVX0JVYZ06MWI`2MWId00P2g]kL0103:b/X0Bd];04];B`2NWYh20>CTi0050;6a/@26QXH0L71`
071`L020P8000P2WYjL01@2b/[80c/k>0<k>cP2MWId0OWin0080/;2`00<0YZJV07moO`1oOgl00`2D
U9@01@1_Kfl0`/;2096AT@2ATI40Cdm?0080;2`/00D0Lg=c09bLW01kNg/0Ng]k079bLP0207EeM@05
07QhN01XJ6P0J6QX06m_K`1bLW800P1gMgL0102:RXX0CTi>04i>CP1kNg/209nOW`050:BTY02NWYh0
^KVi0;Vi^@2<S8`00P2BTY801@2VYZH0];Bd09RHV02HV9P0FEUI0080GemO00@0GEeM05mOG`1OGel0
P8202P3oool000X0oooo00@0RHV9059BDP1BDU80FEUI0P2KVi/01@2:RXX0VYZJ09^KV`2KVi/0S8b<
0080AdM700D092@T04M7A`17AdL0RXZ:08j>SP0208^;R`0508F5Q@19BDT0BDU901`L7013@d<00P1f
MWH0102FUYH0Vi^K09^KV`1RHV8205aLG003024Q8@27QhL0QhN70080QhN70P21PH401@1hN7P0>c/k
02LW9`0W9bL0BTY:0080FEUI00D0IVIV07IfMP25QHD0QHF505=CD`0204M7A`0507QhN02<S8`0S8b<
09:BTP2CTi<00P2@T9001@19BDT0:BTY02TY:@1^KVh0NWYj0080Ng]k00@0NGUi08b<S02<S8`0DU9B
0P1ADE401@1_Kfl0O7al07UiN@1iNGT0Ng]k0080KFe]00D0;Rh^07EeM@25QHD0QHF506QXJ00205=C
D`0504A4A018B4P0B4Q803<c<`1XJ6P00P1]KFd01@1SHf<0JFUY06UYJ@1VIVH0;bl_0080C4a<00D0
HF5Q06IVIP1VIVH0Hf=S06][J`02069RHP0401HF5P00000000000410@080De=C00D0FEUI06a/K014
A4@0A4A4028R8P0203dm?@0506i^KP1/K6`0JFUY06UYJ@1JFUX00P0`<3001@1EEED0F5QH05QHF01E
EED0B4Q80080A4A400D09BDU05EEE@1EEED0Fe]K06IVIP0206EUI@0505iNGP0b<S80<S8b01DE5@1J
FUX00P1dM7@307MgM`0506a/K01QHF40HF5Q02PX:01;Bd/00P1MGEd306UYJ@0506m_K`10@40071`L
01`L701WIfL00P1YJFT01@1MGEd0Bd];04];B`1:BTX0<c<c0080HV9R00@0JFUY06ATI01TI6@0H61P
4@3oool01023Ph<0Ti>C09>CT`1iNGT207IfMP0509ZJVP2VYZH0YZJV0;>c/`2OWil00P22PX801@2C
Ti<0PX:208:2PP1/K6`0O7al0080RHV900@0Lg=c08b<S02<S8`0L71`0P2IVIT01@1`L700E5AD07Yj
NP1jNWX0F5QH0080CDe=00D0Lg=c07QhN01hN7P0YZJV08J6QP0207IfMP040:6QX@2JVYX0VYZJ06i^
KP80JFUY00D0IFEU09nOW`3MgMd0gMgM0;>c/`02075aL@0508V9R@25QHD0X:2P0:2PX031`L400P3G
emL01@2k^k/0Shn?08n?S`26QXH0Hf=S0080TY:B00@0QHF508^;R`2;Rh/0IfMW0P1lO7`01@2l_;`0
];Bd0;Bd]02d];@0UiNG0080WIfM00D0Shn?0=GEe@36a/H0a/K60:RXZ00208n?S`050<S8b02HV9P0
V9RH08f=S@2ATI400P1cLg<01022PX80S8b<08b<S02VYZH209VIV@050820P034a<@0/K6a0;6a/@2B
TY800P1UIFD01@1/K6`0WYjN0:^[Z`2[Zj/0dm?C0080ATI600D0UiNG0>3Ph03Ph>00YjNW07MgM`02
06EUI@0407MgM`2VYZH0YZJV0;2`/080dM7A00D0Ti>C06UYJ@2YZJT0ZJVY09VIV@0208b<S00508V9
R@2EUID0UIFE08b<S033`l<00P25QHD01@0o?cl0:BTY02TY:@1iNGT0RHV90080Lg=c00@0JVYZ06QX
J01XJ6P0F5QH0P1QHF401@1cLg<0QHF508N7Q`27QhL0U9BD0080FEUI00D0Lg=c09jNWP2NWYh0WinO
08Z:RP020;2`/00508Z:RP2EUID0UIFE0:JVYP2a/K400P2CTi<0101RHV80LW9b079bLP1QHF42061P
H003071`L03oool0oooo00P0oooo000:0?ooo`0405mOG`1JFUX0FUYJ04i>CP80820P00D04a<C02DU
9@0R8R808R8R03dm?@0303lo?`80;2`/00D08b<S02`/;00a<C40<C4a03Xj>P020492@P0504U9B@0F
5QH020P800P8200E5AD00P0Q8B401@0S8b<0:RXZ02XZ:P0];Bd0<S8b0080<c<c00@0<C4a03`l?00l
?3`0?Cdm0`10@4001@0R8R802PX:00X:2P12@T80BDU90080@T9200@0>CTi02/[:`0[:b/0?Cdm0P15
ADD01@1<C4`0CDe=04m?C`1?Cdl0EUIF0080EeMG00D0?Cdm01LG5`0^;Rh0;Rh^03dm?@0203Xj>P05
0410@01:BTX0BTY:05IFEP1=CDd00P10@4001@0f=SH0>c/k03/k>`1ADE40DU9B0080;Bd]00@08B4Q
04A4A014A4@0@T920P1<C4`01011@D40@d=304Q8B018B4P304i>CP05059BDP1RHV80Hf=S06=SH`1N
GUh00P0R8R801@0l?3`0EEEE06IVIP1VIVH0MGEe0080Ph>300D0QXJ608B4Q024Q8@0N7Qh079bLP02
08>3P`0508J6QP2=SHd0SHf=06YZJP0g=cL00P1UIFD0101ADE40I6AT06ATI01XJ6P206a/K00506i^
KP1WIfL0EEEE05EEE@1[Jf/00P1nOWh01@21PH40HV9R02`/;00/;2`0D51@0080OWin00D0R8R808J6
QP1cLg<0Lg=c079bLP0207IfMP03079bLP1TI6@0I6AT0080NGUi0P1ZJVX01@11@D40CDe=04e=C@1Z
JVX0KVi^0080PH6100@0QHF50820P020P800Lg=c0P1IFET01@19BDT0JFUY08b<S02<S8`0R8R80080
>SXj00<0DE5A0?ooo`3oool03`3oool0101hN7P0TI6A096AT@23Ph<206m_K`050:BTY02SXj<0Xj>S
0::RXP2JVYX00P2<S8`01@2LW9`0Ng]k07]kN`1oOgl0OWin0080SHf=00@0N7Qh07IfMP1fMWH0FEUI
0P2BTY801@1XJ6P0EEEE06m_K`1_Kfl0CDe=0080EeMG00D0OWin07QhN01hN7P0[Jf]092@T00207Ui
N@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0GemO09NGU`3?cll0clo?0:FUY@02061PH0050861P@1T
I6@0UiNG09NGU`2UYJD00P3;bl/01@2ZZZX0P8200820P022PX80HF5Q0080SHf=00@0P82008N7Q`27
QhL0GUiN0P1^KVh01@2IVIT0WinO09nOW`2OWil0T92@0080UIFE00D0MGEe0=WIf@3Bd]80d];B0::R
XP0208B4Q0050<?3``2PX:00X:2P08F5Q@20P8000P1YJFT01020P800M7Ad07AdM02DU9@208N7Q`05
0820P03AdM40Xj>S0:>SX`2MWId00P1_Kfl01@1XJ6P0YjNW0::RXP2RXZ80bl_;0080Bd];00D0TI6A
0=cLg03Lg=`0SHf=07UiN@0206UYJ@0407]kN`2e]KD0]KFe0;Zj^P80clo?00D0UiNG05eMG@2_[jl0
[jn_08n?S`0209>CT`0506IVIP21PH40PH610:BTY02o_kl00P1hN7P01@0h>3P0<C4a034a<@24Q8@0
T92@0080DE5A00@0Lg=c07MgM`1gMgL0H61P0P1aLG401@1JFUX0O7al07QhN01hN7P0QHF50080EUIF
00D0NWYj0:FUY@2UYJD0UiNG08>3P`020:f][@0507alO02=SHd0SHf=0;Fe]@2`/;000P2:RXX0101N
GUh0MGEe07EeM@1ZJVX2065QH@0306MWI`3oool0oooo00P0oooo000:0?ooo`0405mOG`1JFUX0FUYJ
04i>CP80820P00D04a<C02DU9@0R8R808R8R03dm?@0303lo?`80;2`/00D08b<S02`/;00a<C40<C4a
03Xj>P020492@P0504U9B@0F5QH020P800P8200E5AD00P0Q8B401@0S8b<0:RXZ02XZ:P0];Bd0<S8b
0080<c<c00@0<C4a03`l?00l?3`0?Cdm0`10@4001@0R8R802PX:00X:2P12@T80BDU90080@T9200@0
>CTi02/[:`0[:b/0?Cdm0P15ADD01@1<C4`0CDe=04m?C`1?Cdl0EUIF0080EeMG00D0?Cdm01LG5`0^
;Rh0;Rh^03dm?@0203Xj>P050410@01:BTX0BTY:05IFEP1=CDd00P10@4001@0f=SH0>c/k03/k>`1A
DE40DU9B0080;Bd]00@08B4Q04A4A014A4@0@T920P1<C4`01011@D40@d=304Q8B018B4P304i>CP05
059BDP1RHV80Hf=S06=SH`1NGUh00P0R8R801@0l?3`0EEEE06IVIP1VIVH0MGEe0080Ph>300D0QXJ6
08B4Q024Q8@0N7Qh079bLP0208>3P`0508J6QP2=SHd0SHf=06YZJP0g=cL00P1UIFD0101ADE40I6AT
06ATI01XJ6P206a/K00506i^KP1WIfL0EEEE05EEE@1[Jf/00P1nOWh01@21PH40HV9R02`/;00/;2`0
D51@0080OWin00D0R8R808J6QP1cLg<0Lg=c079bLP0207IfMP03079bLP1TI6@0I6AT0080NGUi0P1Z
JVX01@11@D40CDe=04e=C@1ZJVX0KVi^0080PH6100@0QHF50820P020P800Lg=c0P1IFET01@19BDT0
JFUY08b<S02<S8`0R8R80080>SXj00<0DE5A0?ooo`3oool03`3oool0101hN7P0TI6A096AT@23Ph<2
06m_K`050:BTY02SXj<0Xj>S0::RXP2JVYX00P2<S8`01@2LW9`0Ng]k07]kN`1oOgl0OWin0080SHf=
00@0N7Qh07IfMP1fMWH0FEUI0P2BTY801@1XJ6P0EEEE06m_K`1_Kfl0CDe=0080EeMG00D0OWin07Qh
N01hN7P0[Jf]092@T00207UiN@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0GemO09NGU`3?cll0clo?
0:FUY@02061PH0050861P@1TI6@0UiNG09NGU`2UYJD00P3;bl/01@2ZZZX0P8200820P022PX80HF5Q
0080SHf=00@0P82008N7Q`27QhL0GUiN0P1^KVh01@2IVIT0WinO09nOW`2OWil0T92@0080UIFE00D0
MGEe0=WIf@3Bd]80d];B0::RXP0208B4Q0050<?3``2PX:00X:2P08F5Q@20P8000P1YJFT01020P800
M7Ad07AdM02DU9@208N7Q`050820P03AdM40Xj>S0:>SX`2MWId00P1_Kfl01@1XJ6P0YjNW0::RXP2R
XZ80bl_;0080Bd];00D0TI6A0=cLg03Lg=`0SHf=07UiN@0206UYJ@0407]kN`2e]KD0]KFe0;Zj^P80
clo?00D0UiNG05eMG@2_[jl0[jn_08n?S`0209>CT`0506IVIP21PH40PH610:BTY02o_kl00P1hN7P0
1@0h>3P0<C4a034a<@24Q8@0T92@0080DE5A00@0Lg=c07MgM`1gMgL0H61P0P1aLG401@1JFUX0O7al
07QhN01hN7P0QHF50080EUIF00D0NWYj0:FUY@2UYJD0UiNG08>3P`020:f][@0507alO02=SHd0SHf=
0;Fe]@2`/;000P2:RXX0101NGUh0MGEe07EeM@1ZJVX2065QH@0306MWI`3oool0oooo00P0oooo000:
0?ooo`040:BTY02MWId0WIfM0:2PX080E5AD00D0BTY:071`L01ZJVX0JVYZ09ZJVP020:6QX@050:2P
X022PX80PX:206e]K@21PH400P2;Rh/01@2[Zj/0[jn_0:n_[`2VYZH0@410008030`<00@0VYZJ0:RX
Z02XZ:P0YjNW0P2XZ:P01@2RXZ80YJFU09nOW`2OWil0T92@0080R8R800D0Vi^K09RHV02LW9`0W9bL
06=SH`0201HF5P050:RXZ02UYJD0WYjN09jNWP2DU9@00P1oOgl01@2BTY80[Zj^0:j^[P2^[Zh0/;2`
0080[Jf]00D0[jn_0;Bd]02d];@0Vi^K024Q8@0209RHV00409nOW`2CTi<0Ti>C08Z:RP80Ph>300D0
TI6A09:BTP2>SXh0SXj>07AdM00208:2PP050:>SX`2[Zj/0P8200820P01=CDd00P2ZZZX01@2KVi/0
V9RH09RHV020P800QXJ60080Ti>C00@0UIFE09fMW@2MWId0WYjN0`2WYjL01@2SXj<0?clo03lo?`1M
GEd0QHF50080Ph>30`2EUID01@2CTi<0UYJF09JFUP2HV9P0Ti>C0080WYjN00D0WinO0::RXP2RXZ80
XZ:R06e]K@0209jNWP0408N7Q`29RHT0RHV90::RXP80X:2P00<0Xj>S09:BTP2?Shl00P2?Shl20:j^
[P050;Bd]02`/;00AdM704M7A`2[Zj/00P2XZ:P01@2RXZ80YjNW0:JVYP2VYZH0Y:BT0080YjNW0`2R
XZ801@2LW9`0UYJF0:>SX`2SXj<0J6QX0080RXZ:00D0XJ6Q09ZJVP2ATI40TI6A09nOW`020:6QX@05
09VIV@1kNg/0Ng]k059BDP24Q8@00P2NWYh0102YZJT0?3`l03`l?01XJ6PA0?ooo`0406IVIP20P800
P82007alO080Ti>C00D0LG5a09NGU`2GUiL0X:2P08^;R`0208f=S@0509>CT`1cLg<0Lg=c08F5Q@21
PH400P20P8001024Q8@0WYjN09jNWP1YJFT209fMW@0506UYJ@1SHf<0OWin07inOP1DE5@00P1QHF40
1@21PH40NGUi07UiN@2SXj<0QXJ60080MGEe00@0Y:BT09NGU`2GUiL0OGem0P1_Kfl01@1OGel0Z:RX
0=SHf03Hf=P0[Jf]0080GUiN00D0PX:205YJFP2`/;00/;2`0:NWY`020=GEe@050;Zj^P23Ph<0Ph>3
08:2PP1[Jf/00P2EUID0101mOGd0RXZ:08Z:RP1XJ6P2071`L00509nOW`2NWYh0VIVI09VIV@28R8P0
0P2BTY801@1TI6@0b<S80;:b/P2b/[80SHf=0080Ogmo00D0a<C40:j^[P2^[Zh0P82008V9R@0206i^
KP0408V9R@1oOgl0Ogmo09FEU@80MGEe00D0Ng]k0=CDe02LW9`0W9bL0::RXP0207=cL`0506=SH`2b
/[80[Jf]0:f][@2o_kl00P14A4@01@2JVYX0g]kN0=kNgP2b/[80Kfm_0080JVYZ00@0OGem0;Vi^@2i
^KT0alO70P3@d=00102j^[X0HF5Q0:b/[02/[:`308R8R005065QH@28R8P0R8R80;Ng]`2BTY800P1m
OGd01@14A4@0=3@d03@d=01eMGD0O7al0080?3`l0`1lO7`01@1jNWX0M7Ad07AdM01RHV80Q8B40080
Ph>300@0Ti>C05UIF@1IFET0L71`0P2PX:001@2IVIT0QHF50<O7a`37alL0RXZ:0080TI6A00D0YjNW
0:ZZZP1kNg/0Ng]k06IVIP0207alO004071`L01VIVH0IVIV07AdM0X0oooo000:0?ooo`0409fMW@2D
U9@0U9BD09RHV080DU9B00D0H61P092@T01dM7@0M7Ad09BDU002092@T00509BDU026QXH0QXJ606UY
J@1nOWh00P2?Shl30:JVYP050:ZZZP1;Bd/0=SHf03Hf=P2RXZ800P2VYZH01@2WYjL0ZZZZ0:ZZZP2Z
ZZX0YZJV0080WinO00<0T92@0861P@21PH400P2CTi<209JFUP0506=SH`0H61P061PH0:2PX02SXj<0
0P2LW9`0102FUYH0OGem07emO@25QHD30:JVYP040:b/[02_[jl0[jn_0:n_[`80/K6a00D0XJ6Q02PX
:02IVIT0VIVI09RHV00209VIV@0508Z:RP1gMgL0MgMg08V9R@2@T9000P2?Shl01@25QHD0Q8B408B4
Q02JVYX0Y:BT0080OWin00@0AdM70:JVYP2VYZH0YJFU0P29RHT01@1kNg/0N7Qh08:2PP22PX80SXj>
0080V9RH00D0VYZJ0:JVYP2XZ:P0Z:RX0:FUY@0204M7A`0506MWI`20P800Rh^;08^;R`2<S8`00P27
QhL01@24Q8@0RHV908V9R@27QhL0QHF50080T92@00D0U9BD08b<S02<S8`0UiNG075aL@020:f][@04
0:2PX02BTY80TY:B09bLW080UYJF00D0WIfM09bLW02ATI40TI6A09FEU@020:FUY@050:ZZZP2_[jl0
C4a<04a<C02DU9@00P2PX:020:ZZZP80YjNW00@0WYjN0:>SX`2SXj<0Y:BT0P2OWil01@2MWId0XJ6Q
0:>SX`2SXj<0Cdm?0080RXZ:00D0WYjN09:BTP23Ph<0Ph>309JFUP0209^KV`0509RHV023Ph<0Ph>3
055AD@24Q8@00P2PX:00102TY:@0ATI604I6AP1cLg<A0?ooo`0408B4Q02CTi<0Ti>C08b<S080]kNg
00D0SHf=0:FUY@2UYJD0^;Rh096AT@0208V9R@0509:BTP1YJFT0JFUY08>3P`22PX800P1VIVH01024
Q8@0SHf=08f=S@1UIFD20:>SX`05071`L01_Kfl0QHF508F5Q@1/K6`00P1YJFT01@1kNg/0K6a/06a/
K02RXZ80Ti>C0080MWIf00@0Z:RX08j>SP2>SXh0N7Qh0P1eMGD01@1EEED0Vi^K0=CDe03De=@0Vi^K
0080L71`00D0NWYj04a<C02ZZZX0ZZZZ0:JVYP020=CDe0050<C4a020P800P82007emO@1_Kfl00P2E
UID0101lO7`0UiNG09NGU`1=CDd206IVIP0509FEU@2KVi/0V9RH09RHV02@T9000P2?Shl01@1[Jf/0
f][J0;fm_@2m_Kd0Vi^K0080NWYj00D0`<3009bLW02LW9`0MWIf09:BTP0207EeM@04096AT@20P800
P82009VIV@80M7Ad00D0KVi^0=CDe02GUiL0UiNG092@T00206a/K00505QHF02f][H0YjNW0:NWY`3<
c<`00P16ATH01@2LW9`0gmoO0=oOg`2o_kl0P8200080Jf][00@0MGEe0;>c/`2c/k<0cLg=0P3@d=00
1@2g]kL0Kfm_09^KV`2KVi/0Rh^;0080HV9R00D0MGEe07alO01lO7`0[jn_07IfMP0208b<S00505]K
F`0j>SX0>SXj08F5Q@1lO7`00P1RHV80101WIfL0LW9b079bLP1eMGD20820P005069RHP25QHD0MGEe
07EeM@2?Shl00P1NGUh01@2;Rh/0[:b/0:b/[02@T900MgMg0080aLG500D0QHF509NGU`2GUiL0[jn_
0:VYZ@0208:2PP0405aLG01/K6`0K6a/05IFEP80CTi>00<0K6a/0?ooo`3oool0203oool000X0oooo
00@0WIfM09BDU02DU9@0V9RH0P1BDU801@1PH600T92@07AdM01dM7@0U9BD0080T92@00D0U9BD08J6
QP26QXH0JFUY07inOP0208n?S`<0YZJV00D0ZZZZ04];B`0f=SH0=SHf0::RXP020:JVYP050:NWY`2Z
ZZX0ZZZZ0:ZZZP2VYZH00P2OWil00`2@T900PH610861P@0209>CT`80UYJF00D0Hf=S01PH600H61P0
X:2P0:>SX`0209bLW00409JFUP1mOGd0OGem08F5Q@<0YZJV00@0[:b/0:n_[`2_[jl0[jn_0P2a/K40
1@2QXJ40:2PX09VIV@2IVIT0V9RH0080VIVI00D0RXZ:07MgM`1gMgL0RHV9092@T00208n?S`0508F5
Q@24Q8@0Q8B409ZJVP2TY:@00P1nOWh01017AdL0YZJV0:JVYP2UYJD208V9R@0507]kN`1hN7P0PX:2
08:2PP2>SXh00P2HV9P01@2JVYX0YZJV0:RXZ02XZ:P0YJFU0080AdM700D0IfMW0820P02;Rh/0Rh^;
08b<S00208N7Q`0508B4Q029RHT0RHV908N7Q`25QHD00P2@T9001@2DU9@0S8b<08b<S02GUiL0LG5a
0080[Jf]00@0X:2P09:BTP2BTY80W9bL0P2FUYH01@2MWId0W9bL096AT@2ATI40UIFE0080YJFU00D0
ZZZZ0:n_[`1<C4`0C4a<09BDU0020:2PX080ZZZZ0P2WYjL0102NWYh0Xj>S0:>SX`2TY:@209nOW`05
09fMW@2QXJ40Xj>S0:>SX`1?Cdl00P2:RXX01@2NWYh0TY:B08>3P`23Ph<0UYJF0080Vi^K00D0V9RH
08>3P`23Ph<0DE5A08B4Q0020:2PX0040:BTY016ATH0ATI607=cLa40oooo00@0Q8B409>CT`2CTi<0
S8b<0P2g]kL01@2=SHd0YJFU0:FUY@2h^;P0TI6A0080RHV900D0TY:B06UYJ@1YJFT0Ph>308:2PP02
06IVIP0408B4Q02=SHd0SHf=06EUI@80Xj>S00D0L71`06m_K`25QHD0QHF506a/K00206UYJ@0507]k
N`1/K6`0K6a/0::RXP2CTi<00P1fMWH0102XZ:P0SXj>08j>SP1hN7P207EeM@0505EEE@2KVi/0e=CD
0=CDe02KVi/00P1`L7001@1jNWX0C4a<0:ZZZP2ZZZX0YZJV0080e=CD00D0a<C40820P020P800OGem
06m_K`0209FEU@0407alO02GUiL0UiNG04e=C@80IVIV00D0UIFE09^KV`2HV9P0V9RH092@T00208n?
S`0506][J`3Jf]X0_Kfm0;fm_@2KVi/00P1jNWX01@30`<00W9bL09bLW01fMWH0TY:B0080MGEe00@0
TI6A0820P020P800VIVI0P1dM7@01@1^KVh0e=CD09NGU`2GUiL0T92@0080K6a/00D0F5QH0;Jf]P2W
YjL0YjNW0<c<c00204I6AP0509bLW03Ogml0gmoO0;no_`20P8000P1[Jf/0101eMGD0/k>c0;>c/`3=
cLd20=3@d0050;Ng]`1_Kfl0Vi^K09^KV`2;Rh/00P1RHV801@1eMGD0O7al07alO02_[jl0MWIf0080
S8b<00D0Fe]K03Xj>P0j>SX0QHF507alO002069RHP0406MWI`1bLW80LW9b07EeM@80P82000D0HV9R
08F5Q@1eMGD0MGEe08n?S`0205iNGP0508^;R`2/[:`0[:b/092@T01gMgL00P35aLD01@25QHD0UiNG
09NGU`2_[jl0ZJVY0080PX:200@0G5aL06a/K01/K6`0EUIF0P1>CTh00`1/K6`0oooo0?ooo`080?oo
o`002P3oool0102YZJT0Xj>S0:>SX`2NWYh205YJFP0505aLG02OWil0NGUi07UiN@2LW9`00P2MWId0
1@2KVi/0V9RH09RHV01dM7@0V9RH0080UiNG00D0YJFU0:b/[02/[:`0Z:RX05MGE`02034a<@040:>S
X`2][Jd0[Jf]0:n_[`80[Zj^00D0Zj^[0:NWY`2RXZ80XZ:R09>CT`0207emO@80SHf=0P2>SXh01@1e
MGD061PH01PH602LW9`0VIVI0080W9bL00@0XJ6Q08J6QP26QXH0O7al0P2RXZ801@2[Zj/0[Zj^0:n_
[`2_[jl0/;2`0080[:b/00D0XJ6Q03Lg=`2KVi/0Vi^K09fMW@020::RXP0509nOW`25QHD0QHF509JF
UP2JVYX00P2LW9`01@27QhL0Q8B408B4Q02MWId0V9RH0080OGem00@0D51@09JFUP2FUYH0YJFU0P2;
Rh/01@1nOWh0O7al08Z:RP2:RXX0VYZJ0080W9bL00D0Xj>S0:FUY@2XZ:P0Z:RX0:BTY00204U9B@05
05QHF01hN7P0SXj>08j>SP2HV9P00P25QHD01@1lO7`0N7Qh07QhN01eMGD0PX:20080R8R800D0RHV9
09BDU02DU9@0SHf=06i^KP020:RXZ0030:BTY02;Rh/0Rh^;00<0WinO00D0Y:BT09NGU`2=SHd0SHf=
09ZJVP020:VYZ@80Zj^[0P11@D401@2JVYX0YjNW0:NWY`2/[:`0[Zj^0080[jn_00@0[Jf]0:ZZZP2Z
ZZX0Zj^[0P2YZJT01@2IVIT0UIFE09BDU02DU9@0De=C0080TI6A00@0Vi^K09fMW@2MWId0WIfM0`2L
W9`01@2SXj<0Ph>308>3P`1LG5`0RHV90080XJ6Q00@0Xj>S05EEE@1EEED0P8204@3oool0101mOGd0
Shn?08n?S`20P8020;2`/00508:2PP2YZJT0ZJVY0;Zj^P2ATI400P23Ph<01@2EUID0LW9b079bLP25
QHD0PX:20080EEEE00@0Rh^;0::RXP2RXZ80HV9R0P2QXJ401@1_Kfl0Lg=c0861P@21PH40JVYZ0080
Fe]K00D0NWYj07]kN`1kNg/0_;bl08^;R`0207MgM`040:FUY@2KVi/0Vi^K07UiN@80Kfm_00D0D51@
08Z:RP39bLT0bLW90:>SX`02071`L00507]kN`18B4P0^KVi0;Vi^@2[Zj/00P3Jf]X01@3Cdm<0S8b<
08b<S02;Rh/0OGem0080TI6A00@0Ogmo09fMW@2MWId0IfMW0P1gMgL01@2^[Zh0];Bd09fMW@2MWId0
WYjN0080Ti>C00D0MGEe0>3Ph034a<@0a<C40:2PX00207emO@050;^k^`2DU9@0U9BD06i^KP2JVYX0
0P1kNg/0102SXj<0S8b<08b<S02UYJD207]kN`0506][J`3Bd]80WYjN09jNWP2GUiL00P1fMWH01@1H
F5P0^;Rh0:VYZ@2YZJT0`<300080>CTi00D0Vi^K0>;RhP3Rh^80^;Rh075aL@0206][J`0407EeM@2/
[:`0[:b/0<O7a`80^k^k00D0Zj^[07UiN@2>SXh0SXj>09ZJVP02065QH@0508Z:RP23Ph<0Ph>309JF
UP2DU9@00P1UIFD01@1/K6`0?clo03lo?`2<S8`0L71`0080SXj>00@0LW9b06][J`1[Jf/0M7Ad0P2<
S8`01@1MGEd0NWYj079bLP1bLW80V9RH0080L71`00D0QhN70:RXZ02XZ:P0S8b<07UiN@020<c<c005
09:BTP2QXJ40XJ6Q0;:b/P2NWYh00P29RHT0101WIfL0J6QX06QXJ01NGUh206i^KP030:FUY@3oool0
oooo00P0oooo000:0?ooo`0409jNWP2CTi<0Ti>C08J6QP80;Bd]00D0DE5A09RHV01fMWH0MWIf08j>
SP02092@T00509JFUP2DU9@0U9BD06IVIP21PH400P1lO7`01@2ATI40T92@092@T02LW9`0CTi>0080
51@D00@0Rh^;09:BTP2BTY80Rh^;0P29RHT01@27QhL0P82007emO@1mOGd0MWIf0080J6QX00D0Fe]K
06ATI01JFUX0FUYJ04Q8B00200h>3P0506e]K@1aLG40N7Qh07QhN01eMGD00P1dM7@00`1OGel0PH61
0861P@0207emO@80M7Ad00D0Lg=c06e]K@1]KFd0F5QH02XZ:P02061PH004071`L01mOGd0OGem06AT
I080HF5Q00D0M7Ad079bLP1^KVh0KVi^069RHP0205EEE@05061PH01UIFD0>SXj03Xj>P0m?Cd00P1c
Lg<01@1gMgL0N7Qh07QhN01`L700Jf][0080H61P00D0IfMW06QXJ01XJ6P0H61P05QHF003065QH@80
>SXj00@0>c/k04m?C`1FEUH0EUIF0`1bLW801@1NGUh0IVIV06IVIP1LG5`0CDe=0080A4A400D0=cLg
02DU9@0U9BD0CDe=01/K6`0205IFEP0405]KF`1?Cdl0Cdm?06=SH`80GemO00D0IVIV05ADE01:BTX0
BTY:05iNGP0205eMG@0506=SH`1YJFT08R8R028R8P1OGel00P1`L7001@1]KFd0L71`05QHF01HF5P0
JFUY0080L71`00D0J6QX06UYJ@1YJFT0E5AD03Ph>00203dm?@0504a<C01@D500D51@05YJFP1QHF40
0P1SHf<0101PH600GUiN05iNGP1KFe/204I6AP0503Xj>P11@D40D51@051@D019BDT00P0/;2`00`0d
=3@0oooo0?ooo`0?0?ooo`0407moO`2BTY80TY:B0861P@80VYZJ00D0NGUi0:6QX@2QXJ40]kNg09:B
TP0208^;R`0509JFUP1kNg/0Ng]k0861P@2=SHd00P1KFe/01025QHD0XZ:R0::RXP1_Kfl20:BTY004
06m_K`1YJFT0MGEe07EeM@<0FUYJ00D0Ogmo07UiN@1iNGT0^;Rh09>CT`0208:2PP030:f][@2MWId0
WIfM00<0O7al00D0FEUI09:BTP3?cll0clo?0:ZZZP0207UiN@0507emO@18B4P0_;bl0;bl_02IVIT0
0P3Cdm<01@39bLT0QHF508F5Q@1dM7@0KFe]0080R8R800@0MgMg09BDU02DU9@0KFe]0P1^KVh01@2R
XZ80/[:b0:2PX02PX:00WIfM0080V9RH00D0NWYj0=WIf@2i^KT0^KVi09RHV00208R8R0050:n_[`2G
UiL0UiNG06QXJ02MWId00P2;Rh/0102OWil0S8b<08b<S02VYZH207QhN00506ATI03Cdm<0X:2P0:2P
X023Ph<00P1oOgl01@1HF5P0`<300:^[Z`2[Zj/0aLG50080=3@d00D0XJ6Q0>?Sh`3Shn<0_;bl06YZ
JP0206QXJ00407AdM02WYjL0YjNW0;^k^`80a/K600D0UYJF07alO029RHT0RHV909VIV@0207IfMP05
07QhN020P800P82006QXJ02m_Kd00P1VIVH01@1CDe<0;2`/02`/;01ZJVX0IFEU0080R8R800@0RXZ:
079bLP1bLW80KVi^0P1nOWh01@1MGEd0Lg=c05eMG@1MGEd0Ph>30080Lg=c00D0PH6109nOW`2OWil0
Ph>306e]K@020<G5a@05092@T02?Shl0Shn?0;2`/02KVi/00P2RXZ80101aLG40HV9R069RHP1YJFT2
07emO@030:>SX`3oool0oooo00P0oooo000:0?ooo`0403dm?@0c<c<0<c<c034a<@80;Bd]00D0=3@d
03Ph>00n?Sh0?Shn03Ph>00203`l?004020P800?3`l03`l?018B4P<04a<C00D0410@01PH600H61P0
9BDU03De=@02038b<P0402XZ:P0];Bd0;Bd]03De=@80<C4a00D0<c<c014A4@0a<C40<C4a02h^;P02
02TY:@0502DU9@0R8R806a/K01/K6`0R8R800P0S8b<01@0O7al08b<S02LW9`0W9bL092@T00807AdM
00D04a<C02TY:@0Y:BT0;Bd]028R8P03034a<@80:b/[00D0<C4a03lo?`0o?cl0?clo03@d=00202XZ
:P05030`<00M7Ad07AdM01dM7@0e=CD00P0X:2P01@0Q8B409BDU02DU9@0_;bl0=SHf0080>CTi00@0
?Shn03<c<`0c<c<092@T0P0V9RH01@0I6AT04A4A01hN7P0N7Qh0;Bd]0080;bl_00D0?clo04M7A`0n
?Sh0?Shn03Ti>@0202d];@0503Xj>P0f=SH0BDU904U9B@0m?Cd00P0];Bd01@0S8b<0Cdm?04m?C`1=
CDd0Cdm?0080D51@00D0GEeM06IVIP1VIVH0IVIV05eMG@0204M7A`0403/k>`1:BTX0BTY:04U9B@80
92@T00D0AdM705]KF`1MGEd0GEeM05iNGP0205QHF005065QH@1JFUX0H61P061PH01KFe/00P1HF5P0
1@1DE5@0EeMG02HV9P0V9RH0ADE50080H61P00D0KFe]071`L01`L700MgMg07QhN00208R8R0050820
P01dM7@0M7Ad06YZJP1[Jf/00P20P800101EEED0<30`030`<01TI6@207AdM00507QhN023Ph<0U9BD
09BDU02IVIT00P2NWYh00`2KVi/0oooo0?ooo`0?0?ooo`0408B4Q02=SHd0SHf=07UiN@80RXZ:00D0
QXJ60;Jf]P2f][H0/[:b09:BTP0208B4Q00509^KV`1eMGD0MGEe07EeM@2=SHd00P1JFUX01026QXH0
VIVI09VIV@1fMWH208R8R00406YZJP1RHV80PX:208:2PP<0Fe]K00D0Lg=c07moO`1oOgl0/;2`08B4
Q00207alO0<0Xj>S00D0Q8B407inOP1nOWh0GUiN0:2PX0020<c<c0050:RXZ01mOGd0OGem08B4Q014
A4@00P2h^;P0102MWId0f][J0=[JfP3Bd]82096AT@0508N7Q`1TI6@0S8b<08b<S01nOWh00P2FUYH0
1@1oOgl0MWIf07IfMP2YZJT0/k>c0080XZ:R00D0X:2P08n?S`2?Shl0NGUi0=CDe0020;6a/@0408n?
S`1nOWh0OWin0:VYZ@80QhN700D0H61P09JFUP2=SHd0SHf=0:JVYP0208^;R`050:BTY01eMGD0MGEe
05iNGP3=cLd00P2JVYX01@28R8P0QXJ608J6QP1HF5P0`/;20080Zj^[00@0a/K602PX:00X:2P0/;2`
0P3Ti>@01@2`/;00Kfm_07EeM@1eMGD0LW9b0080WYjN00D0`l?30<g=c@3=cLd0XJ6Q09:BTP0208n?
S`040:JVYP1jNWX0NWYj08n?S`80P82000D0O7al0:BTY01]KFd0KFe]04U9B@02038b<P05075aL@1V
IVH0LG5a075aL@2@T9000P1jNWX01@1iNGT0Lg=c07=cL`1_Kfl0Jf][0080KVi^00@0MgMg075aL@1a
LG40NWYj0P2RXZ801@1dM7@0IfMW0<C4a034a<@0UYJF0080QhN700D0[Jf]08N7Q`1/K6`0K6a/07Yj
NP02079bLP0406][J`1iNGT0NGUi06i^KPX0oooo000:0?ooo`0403dm?@0c<c<0<c<c034a<@80;Bd]
00D0=3@d03Ph>00n?Sh0?Shn03Ph>00203`l?004020P800?3`l03`l?018B4P<04a<C00D0410@01PH
600H61P09BDU03De=@02038b<P0402XZ:P0];Bd0;Bd]03De=@80<C4a00D0<c<c014A4@0a<C40<C4a
02h^;P0202TY:@0502DU9@0R8R806a/K01/K6`0R8R800P0S8b<01@0O7al08b<S02LW9`0W9bL092@T
00807AdM00D04a<C02TY:@0Y:BT0;Bd]028R8P03034a<@80:b/[00D0<C4a03lo?`0o?cl0?clo03@d
=00202XZ:P05030`<00M7Ad07AdM01dM7@0e=CD00P0X:2P01@0Q8B409BDU02DU9@0_;bl0=SHf0080
>CTi00@0?Shn03<c<`0c<c<092@T0P0V9RH01@0I6AT04A4A01hN7P0N7Qh0;Bd]0080;bl_00D0?clo
04M7A`0n?Sh0?Shn03Ti>@0202d];@0503Xj>P0f=SH0BDU904U9B@0m?Cd00P0];Bd01@0S8b<0Cdm?
04m?C`1=CDd0Cdm?0080D51@00D0GEeM06IVIP1VIVH0IVIV05eMG@0204M7A`0403/k>`1:BTX0BTY:
04U9B@8092@T00D0AdM705]KF`1MGEd0GEeM05iNGP0205QHF005065QH@1JFUX0H61P061PH01KFe/0
0P1HF5P01@1DE5@0EeMG02HV9P0V9RH0ADE50080H61P00D0KFe]071`L01`L700MgMg07QhN00208R8
R0050820P01dM7@0M7Ad06YZJP1[Jf/00P20P800101EEED0<30`030`<01TI6@207AdM00507QhN023
Ph<0U9BD09BDU02IVIT00P2NWYh00`2KVi/0oooo0?ooo`0?0?ooo`0408B4Q02=SHd0SHf=07UiN@80
RXZ:00D0QXJ60;Jf]P2f][H0/[:b09:BTP0208B4Q00509^KV`1eMGD0MGEe07EeM@2=SHd00P1JFUX0
1026QXH0VIVI09VIV@1fMWH208R8R00406YZJP1RHV80PX:208:2PP<0Fe]K00D0Lg=c07moO`1oOgl0
/;2`08B4Q00207alO0<0Xj>S00D0Q8B407inOP1nOWh0GUiN0:2PX0020<c<c0050:RXZ01mOGd0OGem
08B4Q014A4@00P2h^;P0102MWId0f][J0=[JfP3Bd]82096AT@0508N7Q`1TI6@0S8b<08b<S01nOWh0
0P2FUYH01@1oOgl0MWIf07IfMP2YZJT0/k>c0080XZ:R00D0X:2P08n?S`2?Shl0NGUi0=CDe0020;6a
/@0408n?S`1nOWh0OWin0:VYZ@80QhN700D0H61P09JFUP2=SHd0SHf=0:JVYP0208^;R`050:BTY01e
MGD0MGEe05iNGP3=cLd00P2JVYX01@28R8P0QXJ608J6QP1HF5P0`/;20080Zj^[00@0a/K602PX:00X
:2P0/;2`0P3Ti>@01@2`/;00Kfm_07EeM@1eMGD0LW9b0080WYjN00D0`l?30<g=c@3=cLd0XJ6Q09:B
TP0208n?S`040:JVYP1jNWX0NWYj08n?S`80P82000D0O7al0:BTY01]KFd0KFe]04U9B@02038b<P05
075aL@1VIVH0LG5a075aL@2@T9000P1jNWX01@1iNGT0Lg=c07=cL`1_Kfl0Jf][0080KVi^00@0MgMg
075aL@1aLG40NWYj0P2RXZ801@1dM7@0IfMW0<C4a034a<@0UYJF0080QhN700D0[Jf]08N7Q`1/K6`0
K6a/07YjNP02079bLP0406][J`1iNGT0NGUi06i^KPX0oooo000:0?ooo`0309BDU02IVIT0VIVI00<0
YjNW00D0Zj^[0:ZZZP2_[jl0[jn_0:^[Z`020:FUY@0405]KF`0@4100410@07MgM`<0OGem00D0Ng]k
08Z:RP2:RXX0TI6A08V9R@0208^;R`0409>CT`2LW9`0W9bL09ZJVP80XJ6Q00D0VIVI02l_;`2MWId0
WIfM09BDU00209FEU@0508J6QP1lO7`0Ogmo07moO`27QhL00P2DU9@01@27QhL0Shn?09FEU@2EUID0
U9BD0080MGEe00D0:b/[09RHV02HV9P0VYZJ0:FUY@020:NWY`050:BTY027QhL0QhN70::RXP2VYZH0
0P2YZJT0102ZZZX0WYjN09jNWP2UYJD2079bLP0506IVIP2VYZH0YZJV0:JVYP2TY:@00P2LW9`01@2S
Xj<0XZ:R0:NWY`2WYjL0Y:BT0080Xj>S00D0Y:BT0:VYZ@2YZJT0TI6A04M7A`02079bLP0509ZJVP2K
Vi/0Vi^K09^KV`2CTi<00P2LW9`01@2FUYH0R8R808R8R02FUYH0Ti>C0080XJ6Q00@0[:b/09NGU`2G
UiL0FEUI0P2][Jd01@2ZZZX0Xj>S0:RXZ02XZ:P0[Jf]0080[:b/00D0/K6a0:n_[`2WYjL0YjNW0:j^
[P020:f][@050:NWY`1BDU80DU9B09RHV02`/;000P2WYjL01@2UYJD0Xj>S0:>SX`2WYjL0XZ:R0080
Xj>S00D0SHf=07alO01lO7`0Ph>30:VYZ@0205EEE@040820P02_[jl0[jn_0:n_[`80[Jf]00D0YZJV
09RHV02VYZH0YZJV09fMW@020:6QX@050:2PX026QXH0YjNW0:NWY`1fMWH00P1=CDd01@2IVIT0RXZ:
08Z:RP2JVYX0YJFU0080[jn_00@0/k>c0;Fe]@2e]KD0/[:b4@3oool01022PX80UYJF09JFUP23Ph<2
09:BTP0508R8R02e]KD0]KFe0:VYZ@2EUID00P26QXH01@2WYjL0Ogmo07moO`1/K6`0RHV90080De=C
00@0QHF5096AT@2ATI40MGEe0P2MWId01@20P800Jf][07=cL`1cLg<0DU9B0080D51@00D0NWYj07Qh
N01hN7P0/k>c08N7Q`0207inOP040:NWY`2NWYh0WYjN08B4Q080QXJ600D0IFEU08Z:RP37alL0alO7
0:VYZ@0208:2PP0508V9R@18B4P0]kNg0;Ng]`2UYJD00P3MgMd01@3De=@0TY:B09:BTP23Ph<0GemO
0080SHf=00@0KFe]08b<S02<S8`0Ph>30P1XJ6P01@2TY:@0YJFU09fMW@2MWId0XJ6Q0080SHf=00D0
PH610=?Cd`2TY:@0Y:BT096AT@0207emO@050:b/[028R8P0R8R806IVIP2DU9@00P23Ph<0102;Rh/0
OGem07emO@2DU9@207IfMP05065QH@3=cLd0V9RH09RHV01`L7000P1mOGd01@1GEeL0b/[:0:ZZZP2Z
ZZX0`/;200806QXJ00D0]kNg0>;RhP3Rh^80Ti>C07inOP0207UiN@0407EeM@2SXj<0Xj>S0;jn_P80
_;bl00D0Rh^;0::RXP2>SXh0SXj>0:ZZZP0207]kN`0509ZJVP1/K6`0K6a/0:VYZ@2ATI400P1/K6`0
1@17AdL0;bl_02l_;`1lO7`0HV9R0080FEUI00@0V9RH06a/K01/K6`0IfMW0P1OGel01@2BTY80Kfm_
075aL@1aLG40J6QX0080Ph>300D0Ogmo09VIV@2IVIT0Ph>306EUI@020<71`@0509nOW`1mOGd0OGem
0:6QX@2=SHd00P24Q8@0101NGUh0IVIV06IVIP1IFET20861P@0306ATI03oool0oooo00P0oooo000:
0?ooo`040:2PX025QHD0QHF5092@T0<0W9bL00@0XJ6Q0:FUY@2UYJD0YJFU0P2MWId01@2;Rh/08R8R
028R8P23Ph<0T92@0080WIfM00D0UYJF08J6QP26QXH0QhN707moO`0208B4Q004092@T02BTY80TY:B
09bLW080VYZJ00D0V9RH03`l?02BTY80TY:B0:JVYP020:>SX`050:6QX@28R8P0P8200820P02;Rh/0
0`2DU9@0102EUID0SXj>08j>SP2MWId208^;R`0503De=@1/K6`0K6a/079bLP1lO7`00P1fMWH01@29
RHT0RXZ:08Z:RP2JVYX0UiNG0080Y:BT00@0X:2P0::RXP2RXZ80Xj>S0P1oOgl01@1>CTh0PH6108R8
R028R8P0OWin0080Q8B400D0Ph>308^;R`2DU9@0U9BD092@T00208j>SP05092@T02ATI40TI6A09:B
TP1KFe/00P1OGel01@2;Rh/0Shn?08n?S`2LW9`0Ti>C0080T92@00D0QhN708B4Q024Q8@0Shn?09NG
U`0209ZJVP040:RXZ02@T900T92@06QXJ080Zj^[00D0[Jf]0:NWY`2XZ:P0Z:RX0:ZZZP020:^[Z`05
0:RXZ02/[:`0[Jf]0:f][@2e]KD00P2`/;001@2XZ:P0Fe]K05]KF`2ZZZX0[Zj^0080Y:BT00D0Vi^K
0::RXP2RXZ80ZZZZ0:^[Z`020:b/[00509^KV`2IVIT0VIVI0:>SX`2YZJT00P1PH6000`27QhL0[Jf]
0:f][@030:f][@050:NWY`2MWId0Y:BT0:BTY02RXZ800P2NWYh01@2PX:00Ti>C0:RXZ02XZ:P0Lg=c
0080GemO00D0UIFE08R8R028R8P0U9BD09FEU@0209ZJVP040:FUY@2^[Zh0[Zj^0;6a/A40oooo00@0
Rh^;08V9R@29RHT0K6a/0P1hN7P01@1lO7`0[jn_0:n_[`2][Jd0V9RH0080P82000D0YZJV08J6QP26
QXH0NWYj08b<S00205MGE`0408N7Q`1mOGd0OGem06i^KP80XJ6Q00D0LG5a061PH01_Kfl0Kfm_04];
B`0204a<C005071`L01eMGD0MGEe0:ZZZP21PH400P1fMWH0102WYjL0W9bL09bLW01kNg/208F5Q@05
06UYJ@2JVYX0b/[:0<[:bP2TY:@00P1jNWX01@22PX80BTY:0;Rh^02h^;P0YJFU0080fm_K00D0b/[:
08f=S@2=SHd0Ng]k065QH@0208N7Q`0406i^KP2@T900T92@06YZJP80HV9R00D0Vi^K06IVIP25QHD0
QHF509NGU`0208n?S`0507moO`3IfMT0[Zj^0:j^[P2;Rh/00P1]KFd0102VYZH0SXj>08j>SP1_Kfl3
09VIV@0409ZJVP2@T900T92@0:2PX080Ng]k00D0HV9R0<c<c02IVIT0VIVI06e]K@0207inOP05055A
D@2k^k/0XZ:R0::RXP33`l<00P0n?Sh0102UYJD0hn?S0>?Sh`2@T90308F5Q@0407]kN`2HV9P0V9RH
0<c<c080b<S800D0NWYj0:NWY`29RHT0RHV90:JVYP0207moO`0509BDU01/K6`0K6a/09fMW@2FUYH0
0P1VIVH01@1BDU80@4100410@01aLG40G5aL0080H61P00@0TY:B09BDU02DU9@0O7al0P1_Kfl01@2M
WId0JFUY06MWI`1WIfL0D51@0080PH6100D0Ph>309>CT`2CTi<0Q8B406QXJ0020;Zj^P0509jNWP1d
M7@0M7Ad08f=S@2GUiL00P1mOGd0101KFe/0FEUI05UIF@1dM7@209BDU00308J6QP3oool0oooo00P0
oooo000:0?ooo`040:2PX025QHD0QHF5092@T0<0W9bL00@0XJ6Q0:FUY@2UYJD0YJFU0P2MWId01@2;
Rh/08R8R028R8P23Ph<0T92@0080WIfM00D0UYJF08J6QP26QXH0QhN707moO`0208B4Q004092@T02B
TY80TY:B09bLW080VYZJ00D0V9RH03`l?02BTY80TY:B0:JVYP020:>SX`050:6QX@28R8P0P8200820
P02;Rh/00`2DU9@0102EUID0SXj>08j>SP2MWId208^;R`0503De=@1/K6`0K6a/079bLP1lO7`00P1f
MWH01@29RHT0RXZ:08Z:RP2JVYX0UiNG0080Y:BT00@0X:2P0::RXP2RXZ80Xj>S0P1oOgl01@1>CTh0
PH6108R8R028R8P0OWin0080Q8B400D0Ph>308^;R`2DU9@0U9BD092@T00208j>SP05092@T02ATI40
TI6A09:BTP1KFe/00P1OGel01@2;Rh/0Shn?08n?S`2LW9`0Ti>C0080T92@00D0QhN708B4Q024Q8@0
Shn?09NGU`0209ZJVP040:RXZ02@T900T92@06QXJ080Zj^[00D0[Jf]0:NWY`2XZ:P0Z:RX0:ZZZP02
0:^[Z`050:RXZ02/[:`0[Jf]0:f][@2e]KD00P2`/;001@2XZ:P0Fe]K05]KF`2ZZZX0[Zj^0080Y:BT
00D0Vi^K0::RXP2RXZ80ZZZZ0:^[Z`020:b/[00509^KV`2IVIT0VIVI0:>SX`2YZJT00P1PH6000`27
QhL0[Jf]0:f][@030:f][@050:NWY`2MWId0Y:BT0:BTY02RXZ800P2NWYh01@2PX:00Ti>C0:RXZ02X
Z:P0Lg=c0080GemO00D0UIFE08R8R028R8P0U9BD09FEU@0209ZJVP040:FUY@2^[Zh0[Zj^0;6a/A40
oooo00@0Rh^;08V9R@29RHT0K6a/0P1hN7P01@1lO7`0[jn_0:n_[`2][Jd0V9RH0080P82000D0YZJV
08J6QP26QXH0NWYj08b<S00205MGE`0408N7Q`1mOGd0OGem06i^KP80XJ6Q00D0LG5a061PH01_Kfl0
Kfm_04];B`0204a<C005071`L01eMGD0MGEe0:ZZZP21PH400P1fMWH0102WYjL0W9bL09bLW01kNg/2
08F5Q@0506UYJ@2JVYX0b/[:0<[:bP2TY:@00P1jNWX01@22PX80BTY:0;Rh^02h^;P0YJFU0080fm_K
00D0b/[:08f=S@2=SHd0Ng]k065QH@0208N7Q`0406i^KP2@T900T92@06YZJP80HV9R00D0Vi^K06IV
IP25QHD0QHF509NGU`0208n?S`0507moO`3IfMT0[Zj^0:j^[P2;Rh/00P1]KFd0102VYZH0SXj>08j>
SP1_Kfl309VIV@0409ZJVP2@T900T92@0:2PX080Ng]k00D0HV9R0<c<c02IVIT0VIVI06e]K@0207in
OP05055AD@2k^k/0XZ:R0::RXP33`l<00P0n?Sh0102UYJD0hn?S0>?Sh`2@T90308F5Q@0407]kN`2H
V9P0V9RH0<c<c080b<S800D0NWYj0:NWY`29RHT0RHV90:JVYP0207moO`0509BDU01/K6`0K6a/09fM
W@2FUYH00P1VIVH01@1BDU80@4100410@01aLG40G5aL0080H61P00@0TY:B09BDU02DU9@0O7al0P1_
Kfl01@2MWId0JFUY06MWI`1WIfL0D51@0080PH6100D0Ph>309>CT`2CTi<0Q8B406QXJ0020;Zj^P05
09jNWP1dM7@0M7Ad08f=S@2GUiL00P1mOGd0101KFe/0FEUI05UIF@1dM7@209BDU00308J6QP3oool0
oooo00P0oooo000:0?ooo`040:2PX027QhL0QhN708Z:RP80UIFE00D0Ti>C09jNWP2IVIT0VIVI09JF
UP0208^;R`0507alO00e=CD0=CDe08J6QP2EUID00`2NWYh208b<S00508j>SP1lO7`0KFe]06e]K@2>
SXh00P2LW9`01@2TY:@0WYjN09jNWP27QhL0@T920080V9RH00D0Xj>S0:ZZZP2ZZZX0ZZZZ09RHV002
08V9R@050:6QX@2SXj<0Xj>S0:BTY02VYZH00P2RXZ80102VYZH0QHF508F5Q@0f=SH209VIV@0509nO
W`2VYZH0WIfM09fMW@20P8000P2ATI401@2HV9P0Q8B408V9R@29RHT0S8b<0080Vi^K00D0XZ:R08>3
P`23Ph<0CDe=08>3P`0208N7Q`0508B4Q01iNGT0NGUi07alO01oOgl00P26QXH0102>SXh0QHF508F5
Q@2=SHd20820P00507inOP1?Cdl0KVi^06i^KP2BTY800P2@T9001@2HV9P0YZJV09nOW`2OWil0Rh^;
0080Shn?00D0W9bL09fMW@2HV9P0V9RH0:>SX`0208b<S00505QHF02a/K40/K6a0;>c/`2][Jd00P2`
/;001@2][Jd0[:b/0:b/[02^[Zh0/[:b0080];Bd00@0]kNg0;Fe]@2e]KD0[Jf]0P18B4P01@2NWYh0
/;2`0:ZZZP2ZZZX0[Jf]0080[jn_00D0]KFe0:j^[P2e]KD0]KFe0:b/[0020:6QX@050:VYZ@2/[:`0
FEUI05UIF@25QHD00P2^[Zh30:b/[0030:NWY`2RXZ80Z:RX00@0Z:RX00D0YjNW0:6QX@2f][H0][Jf
08F5Q@0206QXJ00508R8R01kNg/0Ng]k08R8R021PH400P26QXH0102QXJ40Z:RX0:RXZ02XZ:PA0?oo
o`0407emO@25QHD0QHF507AdM080U9BD00D0Shn?0;2`/02`/;00^KVi096AT@020820P00509jNWP1k
Ng/0Ng]k0820P02EUID00P1MGEd0102=SHd0UIFE09FEU@1]KFd209bLW00506i^KP1OGel0HV9R069R
HP1;Bd/00P1:BTX01@1gMgL0IVIV06IVIP2LW9`0NWYj0080PH6100@0ZZZZ0:FUY@2UYJD0QXJ60P1k
Ng/01@1IFET0SXj>0<C4a034a<@0Zj^[0080N7Qh00D0O7al04e=C@2^[Zh0[Zj^08n?S`020=?Cd`05
0<_;b`2;Rh/0Rh^;07moO`1/K6`00P2>SXh0101]KFd0Shn?08n?S`1WIfL206YZJP050:j^[P2>SXh0
UiNG09NGU`2MWId00P2;Rh/01@1gMgL0e=CD0:>SX`2SXj<0SHf=0080QHF500D0[Zj^09VIV@2IVIT0
NGUi08j>SP0209jNWP04096AT@2=SHd0SHf=0:BTY080PX:200D0GUiN0=CDe02NWYh0WYjN079bLP02
08b<S00505]KF`2k^k/0XJ6Q0:6QX@2n_[h00P1EEED01@2OWil0h^;R0>;RhP2>SXh0Ogmo0080Rh^;
00@0RXZ:09^KV`2KVi/0`L710P2m_Kd01@23Ph<0ZJVY08j>SP2>SXh0W9bL0080RXZ:00D0U9BD07Ad
M01dM7@0Y:BT09JFUP0206i^KP0505EEE@1<C4`0C4a<07YjNP1TI6@00P1YJFT0101eMGD0QhN708N7
Q`1fMWH207]kN`05096AT@1_Kfl0F5QH05QHF018B4P00P1WIfL01@1iNGT0Ti>C09>CT`2@T900I6AT
0080Xj>S00D0UiNG07alO01lO7`0Rh^;09ZJVP02075aL@0408:2PP1HF5P0F5QH06ATI080SXj>00<0
NGUi0?ooo`3oool0203oool000X0oooo00@0XZ:R09:BTP2BTY80VYZJ0P2NWYh01@2:RXX0SHf=096A
T@2ATI40RHV90080Ng]k00D0MWIf02LW9`0W9bL0P82009RHV00209fMW@050:JVYP2LW9`0W9bL09fM
W@2IVIT00P2=SHd01020P800U9BD09BDU02JVYX208>3P`0506EUI@17AdL0WYjN09jNWP2RXZ800P2V
YZH01@2[Zj/0WinO09NGU`2GUiL0WIfM0080X:2P00D0Y:BT09jNWP2FUYH0UYJF09:BTP0207]kN`05
030`<02:RXX0RXZ:09VIV@2MWId00P2RXZ801@23Ph<0Ng]k07]kN`1oOgl0KFe]0080K6a/00@0KFe]
08V9R@29RHT0PH610P1EEED01@15ADD0LW9b07MgM`1gMgL0Ng]k0080NGUi0P1YJFT207=cL`0406a/
K01^KVh0KVi^07alO080MWIf00D0P82004a<C01NGUh0GUiN07UiN@0208:2PP0308F5Q@28R8P0SHf=
0080SHf=0P1kNg/01@2;Rh/0QHF508F5Q@25QHD0PH610080FUYJ00D0:BTY08J6QP26QXH0Ti>C08j>
SP0208n?S`0508>3P`21PH40PH6108:2PP25QHD00P27QhL0102:RXX0QXJ608J6QP1oOgl202d];@05
06QXJ022PX80Ogmo07moO`2>SXh00P29RHT01@2:RXX0L71`07IfMP1fMWH0OWin0080Lg=c00D0KVi^
06UYJ@0a<C40<C4a04U9B@02071`L005075aL@1_Kfl0Kfm_06][J`1UIFD00`1EEED205YJFP0505IF
EP1CDe<0A4A404A4A00S8b<00P0Y:BT01@0l?3`0=cLg03Lg=`0l?3`0A4A40080EUIF00@0HV9R05mO
G`1OGel0Fe]K4@3oool01029RHT0Ng]k07]kN`24Q8@209:BTP0508N7Q`2XZ:P0Z:RX0:RXZ02@T900
0P2=SHd01@2HV9P0NWYj07YjNP2;Rh/0SXj>0080I6AT00@0T92@09RHV02HV9P0MgMg0P2MWId01@1n
OWh0Kfm_079bLP1bLW80BDU90080DU9B00D0NWYj07alO01lO7`0/K6a08J6QP0208^;R`040:JVYP2O
Wil0WinO08F5Q@80Ph>300D0FEUI09bLW03:b/X0b/[:0:n_[`0207]kN`0508>3P`1EEED0`l?30<?3
``2XZ:P00P3Ng]h01@3@d=00T92@092@T02;Rh/0M7Ad0080SHf=00@0NWYj09nOW`2OWil0HV9R0P1`
L7001@2l_;`0SHf=0:n_[`2_[jl0X:2P0080Rh^;00D0Ph>30=GEe@2QXJ40XJ6Q08f=S@020820P005
0;6a/@2XZ:P0Z:RX07UiN@2:RXX00P2NWYh0102=SHd0UIFE09FEU@2PX:0208:2PP0506MWI`3MgMd0
WIfM09fMW@1/K6`00P2?Shl01@1PH600`l?30:VYZ@2YZJT0][Jf0080;bl_00D0YJFU0>CTi03Ti>@0
R8R80861P@0207IfMP0407YjNP2IVIT0VIVI0<o?c`80a/K600D0T92@09jNWP2OWil0WinO09jNWP02
08R8R00509BDU01gMgL0MgMg0;Vi^@2?Shl00P1_Kfl01@13@d<0<C4a034a<@1/K6`0GUiN0080O7al
00@0Hf=S07UiN@1iNGT0H61P0P1kNg/01@23Ph<0Ogmo06ATI01TI6@0MGEe0080PX:200D0QXJ608b<
S02<S8`0V9RH06ATI0020;fm_@050:JVYP1oOgl0Ogmo08^;R`2?Shl00P1RHV801023Ph<0Cdm?04m?
C`1>CTh207=cL`0306m_K`3oool0oooo00P0oooo000:0?ooo`040::RXP2BTY80TY:B09ZJVP80WYjN
00D0RXZ:08f=S@2ATI40TI6A08V9R@0207]kN`0507IfMP0W9bL09bLW0820P02HV9P00P2MWId01@2V
YZH0W9bL09bLW02MWId0VIVI0080SHf=00@0P82009BDU02DU9@0VYZJ0P23Ph<01@1UIFD0AdM709jN
WP2NWYh0XZ:R0080YZJV00D0Zj^[09nOW`2GUiL0UiNG09fMW@020:2PX0050:BTY02NWYh0UYJF09JF
UP2BTY800P1kNg/01@0`<300RXZ:08Z:RP2IVIT0WIfM0080XZ:R00D0Ph>307]kN`1kNg/0Ogmo06e]
K@0206a/K00406e]K@29RHT0RHV90861P@80EEEE00D0ADE5079bLP1gMgL0MgMg07]kN`0207UiN@80
JFUY0P1cLg<0101/K6`0KVi^06i^KP1lO7`207IfMP050820P01<C4`0GUiN05iNGP1iNGT00P22PX80
0`25QHD0R8R808f=S@0208f=S@80Ng]k00D0Rh^;08F5Q@25QHD0QHF50861P@0205YJFP0502TY:@26
QXH0QXJ609>CT`2>SXh00P2?Shl01@23Ph<0PH610861P@22PX80QHF50080QhN700@0RXZ:08J6QP26
QXH0Ogmo0P0];Bd01@1XJ6P0PX:207moO`1oOgl0SXj>0080RHV900D0RXZ:071`L01fMWH0MWIf07in
OP0207=cL`0506i^KP1YJFT0<C4a034a<@19BDT00P1`L7001@1aLG40Kfm_06m_K`1[Jf/0IFEU00<0
EEEE0P1JFUX01@1FEUH0De=C04A4A014A4@08b<S0080:BTY00D0?3`l03Lg=`0g=cL0?3`l04A4A002
05IFEP04069RHP1OGel0GemO05]KFa40oooo00@0RHV907]kN`1kNg/0Q8B40P2BTY801@27QhL0Z:RX
0:RXZ02XZ:P0T92@0080SHf=00D0V9RH07YjNP1jNWX0Rh^;08j>SP0206ATI004092@T02HV9P0V9RH
07MgM`80WIfM00D0OWin06m_K`1bLW80LW9b04U9B@02059BDP0507YjNP1lO7`0O7al0;6a/@26QXH0
0P2;Rh/0102VYZH0WinO09nOW`25QHD208>3P`0505UIF@2LW9`0b/[:0<[:bP2_[jl00P1kNg/01@23
Ph<0EEEE0<?3``33`l<0Z:RX0080g]kN00D0d=3@092@T02@T900Rh^;07AdM00208f=S@0407YjNP2O
Wil0WinO069RHP80L71`00D0_;bl08f=S@2_[jl0[jn_0:2PX00208^;R`0508>3P`3EeMD0XJ6Q0:6Q
X@2=SHd00P20P8001@2a/K40Z:RX0:RXZ01iNGT0RXZ:0080WYjN00@0SHf=09FEU@2EUID0X:2P0P22
PX801@1WIfL0gMgM09fMW@2MWId0K6a/0080Shn?00D0H61P0<?3``2YZJT0ZJVY0;Jf]P0202l_;`05
0:FUY@3Ti>@0i>CT08R8R021PH400P1fMWH0101jNWX0VIVI09VIV@3?cll20<K6aP05092@T02NWYh0
WinO09nOW`2NWYh00P28R8P01@2DU9@0MgMg07MgM`2i^KT0Shn?0080Kfm_00D0@d=3034a<@0a<C40
K6a/05iNGP0207alO00406=SH`1iNGT0NGUi061PH080Ng]k00D0Ph>307moO`1TI6@0I6AT07EeM@02
08:2PP0508J6QP2<S8`0S8b<09RHV01TI6@00P2m_Kd01@2VYZH0Ogmo07moO`2;Rh/0Shn?0080HV9R
00@0Ph>304m?C`1?Cdl0CTi>0P1cLg<00`1_Kfl0oooo0?ooo`080?ooo`002P3oool0100/;2`09BDU
02DU9@0J6QX201hN7P05018B4P0A4A404a<C01<C4`0;2`/00P0=3@d01@092@T02PX:00X:2P0F5QH0
6QXJ008061PH00<07alO020P800P82000P0M7Ad201TI6@0401<C4`0E5AD05ADE01TI6@8051@D00D0
7QhN03Ph>00_;bl0;bl_02TY:@0202HV9P809BDU0P0Q8B401@0K6a/06QXJ01XJ6P0W9bL0:2PX0080
92@T0`0N7Qh01@0G5aL071`L01`L700@41005ADE00806QXJ00D0820P00l?3`0?3`l07AdM02@T9002
01HF5P04024Q8@0T92@092@T02d];@80<30`00D0=3@d03<c<`0T92@092@T02<S8`0201lO7`0501XJ
6P0C4a<0:b/[02/[:`0d=3@00P0c<c<01@0i>CT0=CDe03De=@0^;Rh0>3Ph0080@41000D0ADE50451
@@11@D40?Cdm03Xj>P02028R8P05020P800V9RH09RHV03<c<`0i>CT00P16ATH0101;Bd/0AdM704M7
A`1=CDd204A4A00503Hf=P0d=3@0;bl_02l_;`0a<C400P0O7al01@0X:2P0<c<c02HV9P0V9RH0=cLg
0080;Rh^00D0?3`l04I6AP16ATH0AdM704e=C@0204Y:BP0504e=C@1?Cdl0Cdm?02<S8`0g=cL00P1L
G5`01@1RHV80GUiN05iNGP1QHF40Hf=S0080JVYZ00@0KFe]06MWI`1WIfL0J6QX0P1WIfL01@1^KVh0
HV9R03Xj>P0j>SX0KFe]0080Lg=c00D0NWYj07moO`1jNWX0NWYj07AdM002075aL@0506][J`1`L700
L71`07AdM01jNWX00P1mOGd0100W9bL0IVIV06IVIP2=SHdA0?ooo`0409>CT`1jNWX0NWYj07moO`80
SXj>00D0RHV90;Fe]@2e]KD0/K6a09RHV00209BDU0050:>SX`1lO7`0O7al07alO02=SHd00P1`L700
1020P800R8R808R8R01SHf<208J6QP0507IfMP1YJFT0Kfm_06m_K`17AdL00P1BDU801@1fMWH0OWin
07inOP2[Zj/0Q8B40080PX:200@0/K6a0:2PX02PX:00QhN70P2;Rh/01@1GEeL0SHf=0<C4a034a<@0
XZ:R0080NGUi00D0Ogmo059BDP2n_[h0_[jn09^KV`020=WIf@050<W9b@2CTi<0Ti>C08V9R@1[Jf/0
0P1gMgL00`1`L700U9BD09BDU00306IVIP050:ZZZP23Ph<0^[Zj0;Zj^P2VYZH00P2KVi/01@1oOgl0
i>CT0:n_[`2_[jl0Ti>C0080MWIf00D0XZ:R09bLW02LW9`0LG5a0861P@0308R8R080RHV900D0XZ:R
08F5Q@25QHD0FEUI0=3@d00208b<S00507EeM@2LW9`0W9bL07UiN@2m_Kd00P2RXZ80102LW9`09BDU
02DU9@3Ph>020>KViP05092@T025QHD0R8R808R8R01kNg/00P2ATI401@32`/80^k^k0;^k^`2=SHd0
Zj^[0080WYjN00@0[Jf]09BDU02DU9@0VIVI0P24Q8@01@2YZJT0PX:206MWI`1WIfL0>3Ph0080?clo
00D0SHf=051@D023Ph<0Ph>305QHF00208B4Q00505mOG`1dM7@0M7Ad08j>SP1mOGd00P1_Kfl0102;
Rh/0OWin07inOP2;Rh/209RHV0050:2PX01cLg<0b<S80<S8b02l_;`00P1bLW801@2BTY80WIfM05mO
G`1OGel0M7Ad00<0?clo0P1QHF400`1NGUh0oooo0?ooo`080?ooo`002P3oool0102KVi/0UIFE09FE
U@2:RXX205=CD`030:n_[`2WYjL0Q8B40080Q8B40P2ATI4309fMW@050:>SX`2][Jd0Z:RX0:RXZ02e
]KD00P2b/[801@1fMWH0?3`l092@T02@T900XJ6Q0080YZJV00D0[:b/0:BTY02TY:@0XZ:R09jNWP02
09JFUP0508V9R@26QXH0QXJ608^;R`2MWId00P0i>CT01@1LG5`0UYJF09JFUP2MWId0ZJVY0080UiNG
00<0T92@08n?S`2?Shl00`28R8P01@27QhL0W9bL09nOW`2OWil0VYZJ0080:RXZ00@0PX:209>CT`2<
S8`0S8b<0`2@T9001@2HV9P0X:2P0:2PX02OWil0X:2P0080XZ:R0`2NWYh01@1_Kfl0>SXj0:NWY`2W
YjL0YJFU0080YjNW00D0XJ6Q09FEU@2EUID0UiNG0:6QX@020::RXP050:FUY@2VYZH0YZJV0:FUY@2Q
XJ400P1>CTh01@1[Jf/0V9RH09RHV02HV9P0U9BD0080XZ:R00<0YjNW0:b/[02/[:`00`2^[Zh01@2Z
ZZX0Xj>S07]kN`1kNg/0TI6A0080A4A400D0X:2P0;^k^`2n_[h0_[jn0;bl_0020;Zj^P<0^KVi00D0
_kno0<C4a033`l<0`l?30<G5a@020<O7a`0504m?C`1jNWX0/k>c0;>c/`2h^;P00P2b/[800`2_[jl0
/;2`0:b/[0020:b/[080YJFU00D0SXj>09:BTP2BTY80V9RH08B4Q00204e=C@<0R8R800D0Rh^;09:B
TP2?Shl0Shn?08V9R@0208^;R`0508R8R02CTi<0Ti>C09NGU`2PX:000P2MWId0100k>c/0X:2P0:2P
X02d];@A0?ooo`0408^;R`1bLW80LW9b07emO@80QhN700D0Ng]k09^KV`2KVi/0[Zj^0:2PX00209NG
U`0509RHV020P800P82008n?S`25QHD00P1KFe/0101gMgL0T92@092@T01CDe<206][J`80BDU90P1L
G5`0101EEED0HV9R069RHP1kNg/208R8R0050;Bd]02=SHd0P8200820P02_[jl00P2MWId01@21PH40
Ti>C09>CT`1NGUh0SHf=0080a/K600D0YjNW07alO01lO7`0PX:204e=C@020;jn_P04096AT@3Fe]H0
e]KF0<?3``80VYZJ00D0PH61079bLP21PH40PH6107QhN00209^KV`05075aL@1_Kfl0Kfm_0:VYZ@2G
UiL00P35aLD01@2SXj<0YJFU0:FUY@1lO7`0emOG0080YZJV00@0Vi^K08N7Q`27QhL0Zj^[0P2UYJD0
1@1jNWX0Ng]k08f=S@2=SHd0Q8B40080TI6A00D0_;bl096AT@2ATI40QXJ60:2PX0020:JVYP05079b
LP2PX:00X:2P0820P02o_kl00P2c/k<0102YZJT0:RXZ02XZ:P3Lg=`20>?Sh`0508F5Q@1mOGd0Ng]k
07]kN`1iNGT00P2DU9@01@3=cLd0_;bl0;bl_01nOWh0XJ6Q0080Shn?00@0UIFE08^;R`2;Rh/0O7al
0P2ATI401@30`<00Rh^;06QXJ01XJ6P0B4Q80080?Shn00D0P82004e=C@2:RXX0RXZ:06ATI00208>3
P`0507UiN@1`L700L71`08R8R01aLG400P1gMgL0101QHF40MWIf07IfMP25QHD207inOP0508b<S01b
LW80^[Zj0;Zj^P30`<000P1VIVH01@2?Shl0_Kfm06=SH`1SHf<0QHF50080FEUI00@0CTi>075aL@1a
LG40GemO2P3oool000X0oooo00@0Zj^[0:NWY`2WYjL0ZJVY0P1<C4`20:ZZZP80WinO00@0V9RH09VI
V@2IVIT0XJ6Q0`2UYJD0102WYjL0[Jf]0:f][@2/[:`20:j^[P05096AT@0n?Sh0SHf=08f=S@2IVIT0
0P2HV9P01@2JVYX0TI6A096AT@2ATI40TY:B0080Shn?00D0Ti>C08B4Q024Q8@0P82009RHV00204U9
B@0306m_K`2NWYh0WYjN0080YZJV0P2DU9@01028R8P0QhN708N7Q`24Q8@207inOP0508>3P`2GUiL0
VYZJ09ZJVP2ATI400P0T92@01@1aLG40MGEe07UiN@1iNGT0PH610080SXj>00D0VYZJ08j>SP2>SXh0
UIFE09>CT`020:BTY0050:RXZ02VYZH0YZJV06EUI@0l?3`00P2TY:@0102RXZ80WYjN09jNWP2NWYh2
0:6QX@0509ZJVP2EUID0U9BD09BDU02EUID00P2>SXh01@2DU9@0XJ6Q05aLG01LG5`0Hf=S0080SXj>
00D0TY:B09RHV027QhL0QhN708f=S@0209jNWP0509NGU`2ATI40TI6A08f=S@29RHT00P2;Rh/01@1o
Ogl0@d=304=3@`2`/;00_Kfm0080^[Zj00@0]kNg0;>c/`2c/k<0^[Zj0P2c/k<01@2d];@0^k^k0;Zj
^P2j^[X0_kno0080`L7100<0Hf=S08:2PP2/[:`00P2/[:`20:6QX@050:>SX`2QXJ40W9bL09bLW02J
VYX00P2IVIT01@1dM7@0L71`071`L01gMgL0KFe]0080BDU90`20P8001@27QhL0PX:208B4Q024Q8@0
Ogmo0080OGem00D0Ogmo07]kN`1kNg/0QHF509>CT`0209RHV00403Lg=`2LW9`0W9bL0:VYZA40oooo
00@0Shn?07QhN01hN7P0RXZ:0P2MWId01@2<S8`0[Jf]0:f][@30`<00[:b/0080Shn?00D0Vi^K06UY
J@1YJFT0QhN709BDU002069RHP0408J6QP2HV9P0V9RH06][J`80Vi^K00D0O7al06a/K01VIVH0IVIV
04e=C@0205YJFP0507inOP29RHT0RHV90:n_[`2>SXh00P20P800102`/;00WIfM09fMW@25QHD207mo
O`0504m?C`2?Shl0^k^k0;^k^`2UYJD00P1fMWH01@2;Rh/0Bd];0<K6aP36a/H0WYjN0080h>3P00D0
_[jn0:NWY`2WYjL0Q8B406m_K`0208J6QP040820P02QXJ40XJ6Q07inOP80Ng]k00D0VYZJ0;:b/P2k
^k/0^k^k09FEU@0209nOW`0509:BTP3De=@0Z:RX0:RXZ02d];@00P29RHT01@2TY:@0WinO09nOW`20
P800O7al0080Ogmo00@0JVYZ07EeM@1eMGD0YjNW0P2JVYX01@1jNWX0c/k>09NGU`2GUiL0HV9R0080
UYJF00D0PH610::RXP2_[jl0[jn_09VIV@0203Xj>P050>7Qh@3UiND0iNGU07QhN01kNg/00P28R8P0
102<S8`0Z:RX0:RXZ035aLD20;Vi^@05079bLP2XZ:P0U9BD09BDU023Ph<00P1fMWH01@22PX80R8R8
08R8R02g]kL0MWIf0080MgMg00D0@d=303hn?P0n?Sh0Ng]k05QHF00207UiN@04069RHP1gMgL0MgMg
0820P080QHF500D0UiNG06e]K@1nOWh0OWin06IVIP0206a/K00507inOP2<S8`0S8b<0:VYZ@1iNGT0
0P2i^KT01@30`<00HF5Q065QH@2>SXh0aLG50080Fe]K00@0K6a/061PH01PH600IfMW0`1]KFd:0?oo
o`002P3oool0102[Zj/0YjNW0:NWY`2YZJT204a<C080ZZZZ0P2OWil0102HV9P0VIVI09VIV@2QXJ43
0:FUY@040:NWY`2][Jd0[Jf]0:b/[080[Zj^00D0TI6A03hn?P2=SHd0SHf=09VIV@0209RHV00509ZJ
VP2ATI40TI6A096AT@2BTY800P2?Shl01@2CTi<0Q8B408B4Q020P800V9RH0080BDU900<0Kfm_09jN
WP2NWYh00P2VYZH209BDU00408R8R027QhL0QhN708B4Q080OWin00D0Ph>309NGU`2JVYX0VYZJ096A
T@0202@T9005075aL@1eMGD0NGUi07UiN@21PH400P2>SXh01@2JVYX0SXj>08j>SP2EUID0Ti>C0080
Y:BT00D0Z:RX0:JVYP2VYZH0IFEU03`l?0020:BTY0040::RXP2NWYh0WYjN09jNWP80XJ6Q00D0VYZJ
09FEU@2DU9@0U9BD09FEU@0208j>SP0509BDU02QXJ40G5aL05aLG01SHf<00P2>SXh01@2BTY80V9RH
08N7Q`27QhL0SHf=0080WYjN00D0UiNG096AT@2ATI40SHf=08V9R@0208^;R`0507moO`13@d<0@d=3
0;2`/02m_Kd00P2j^[X0102g]kL0/k>c0;>c/`2j^[X20;>c/`050;Bd]02k^k/0^[Zj0;Zj^P2o_kl0
0P31`L400`1SHf<0PX:20:b/[0020:b/[080XJ6Q00D0Xj>S0:6QX@2LW9`0W9bL09ZJVP0209VIV@05
07AdM01`L700L71`07MgM`1]KFd00P19BDT30820P00508N7Q`22PX80Q8B408B4Q01oOgl00P1mOGd0
1@1oOgl0Ng]k07]kN`25QHD0Ti>C0080V9RH00@0=cLg09bLW02LW9`0ZJVY4@3oool0102?Shl0N7Qh
07QhN02:RXX209fMW@0508b<S02][Jd0[Jf]0<30`02/[:`00P2?Shl01@2KVi/0JFUY06UYJ@27QhL0
U9BD0080HV9R00@0QXJ609RHV02HV9P0Jf][0P2KVi/01@1lO7`0K6a/06IVIP1VIVH0CDe=0080FUYJ
00D0OWin08V9R@29RHT0[jn_08j>SP020820P0040;2`/02MWId0WIfM08F5Q@80Ogmo00D0Cdm?08n?
S`2k^k/0^k^k0:FUY@0207IfMP0508^;R`1;Bd/0a/K60<K6aP2NWYh00P3Ph>001@2n_[h0YjNW0:NW
Y`24Q8@0Kfm_0080QXJ600@0P8200:6QX@2QXJ40OWin0P1kNg/01@2JVYX0/[:b0;^k^`2k^k/0UIFE
0080WinO00D0TY:B0=CDe02XZ:P0Z:RX0;Bd]00208V9R@050:BTY02OWil0WinO0820P01lO7`00P1o
Ogl0101ZJVX0MGEe07EeM@2WYjL209ZJVP0507YjNP3>c/h0UiNG09NGU`1RHV800P2FUYH01@21PH40
XZ:R0:n_[`2_[jl0VIVI0080>SXj00D0hN7Q0>GUi@3UiND0N7Qh07]kN`0208R8R00408b<S02XZ:P0
Z:RX0<G5a@80^KVi00D0LW9b0:RXZ02DU9@0U9BD08>3P`0207IfMP0508:2PP28R8P0R8R80;Ng]`1f
MWH00P1gMgL01@13@d<0?Shn03hn?P1kNg/0F5QH0080NGUi00@0HV9R07MgM`1gMgL0P8200P25QHD0
1@2GUiL0KFe]07inOP1nOWh0IVIV0080K6a/00D0OWin08b<S02<S8`0ZJVY07UiN@020;Vi^@050<30
`01QHF40HF5Q08j>SP35aLD00P1KFe/0101/K6`0H61P061PH01WIfL306e]K@X0oooo000:0?ooo`04
0:JVYP2OWil0WinO0:VYZ@80CDe=0P2WYjL20:FUY@040::RXP2HV9P0V9RH09nOW`80WYjN00D0UiNG
09RHV02WYjL0YjNW0:n_[`020:b/[00508f=S@0o?cl0S8b<08b<S02KVi/00P2UYJD01@2WYjL0Y:BT
0:BTY02MWId0XJ6Q0080YjNW00D0WinO08J6QP26QXH0SXj>09FEU@0204I6AP0506IVIP2SXj<0Xj>S
0:RXZ02TY:@00P2HV9P0102?Shl0QhN708N7Q`1kNg/207QhN005079bLP24Q8@0VIVI09VIV@2ATI40
0P0b<S801@1dM7@0O7al08f=S@2=SHd0Rh^;0080RXZ:0`2QXJ401@2OWil0V9RH09^KV`2KVi/0Xj>S
0080Vi^K00D08b<S0410@02WYjL0YjNW0:RXZ0020::RXP050:>SX`2MWId0WIfM09>CT`2EUID00P2C
Ti<409jNWP040:JVYP1SHf<0Hf=S05IFEP80OWin00D0RXZ:09VIV@2IVIT0VIVI09jNWP020:BTY005
09fMW@2PX:00X:2P0:BTY02DU9@00P2:RXX01@2IVIT0BDU904U9B@2`/;00`<300080^;Rh00@0]kNg
0;Bd]02d];@0];Bd0P2][Jd20:RXZ080[Jf]00D0_Kfm0<[:bP3:b/X0IFEU08B4Q0020:VYZ@030:>S
X`2LW9`0W9bL0080V9RH0P2DU9@0102BTY80TI6A096AT@1lO7`207EeM@05075aL@1WIfL0DE5A055A
D@2EUID00P2HV9P01@2BTY80R8R808B4Q024Q8@0N7Qh0080PX:200D0P82007moO`1oOgl0RHV909JF
UP0209VIV@0402TY:@2:RXX0RXZ:09JFUQ40oooo00@0SXj>07QhN01hN7P0RHV90P2][Jd01@2CTi<0
[Jf]0:f][@30`<00[Jf]0080V9RH00D0W9bL07YjNP1jNWX0SHf=08j>SP02069RHP040861P@2FUYH0
UYJF08F5Q@80[:b/00D0MWIf07AdM01oOgl0Ogmo05QHF002069RHP0508J6QP1kNg/0Ng]k0;Fe]@2L
W9`00P1lO7`0102d];@0Xj>S0:>SX`25QHD208n?S`0506ATI02@T900`<300<30`02VYZH00P1jNWX0
1@2:RXX0Bd];0<G5a@35aLD0UYJF0080d];B00D0_;bl0:f][@2][Jd0PX:206e]K@0208R8R00407]k
N`2EUID0UIFE07UiN@80OGem00D0R8R809^KV`2k^k/0^k^k07inOP0208^;R`050:f][@35aLD0YJFU
0:FUY@2j^[X00P25QHD01@2/[:`0XJ6Q0:6QX@2=SHd0P8200080QhN700@0J6QX07moO`1oOgl0R8R8
0P2OWil01@21PH40cLg=09JFUP2FUYH0IVIV0080R8R800D0PX:20:j^[P2b/[80/[:b08B4Q00203/k
>`050=gMg@3QhN40hN7Q06EUI@1hN7P00`1dM7@209fMW@050<C4a02h^;P0^;Rh06e]K@2PX:000P28
R8P0101nOWh0MWIf07IfMP1YJFT208N7Q`050:j^[P1WIfL0KVi^06i^KP16ATH00P0l?3`01@1cLg<0
F5QH06EUI@1UIFD0QHF50080SHf=00D0LW9b07AdM01dM7@0PH6105eMG@0207IfMP0406a/K01YJFT0
JFUY08B4Q080PH6100D0S8b<06m_K`2a/K40/K6a0:>SX`0206e]K@0508Z:RP2WYjL0DE5A055AD@1F
EUH00P1[Jf/0101FEUH0KVi^06i^KP1bLW8:0?ooo`002P3oool0102/[:`0YZJV0:JVYP2HV9P204];
B`050:^[Z`2WYjL0WinO09nOW`2PX:000P2HV9P01@2GUiL0Q8B408B4Q02@T900PH610080UiNG00D0
Vi^K08n?S`2?Shl0NGUi0410@00208J6QP0409bLW02XZ:P0Z:RX0:VYZ@80[:b/00D0[Zj^0:VYZ@2U
YJD0YJFU09^KV`0209ZJVP0509bLW02;Rh/09BDU02DU9@1]KFd00P2QXJ401@2CTi<0XJ6Q09>CT`2C
Ti<0MGEe0080M7Ad00D0MGEe06i^KP1^KVh0L71`07moO`0209VIV@0509BDU00i>CT0>CTi07moO`22
PX800P2:RXX0102DU9@0R8R808R8R02FUYH309^KV`04096AT@2=SHd0SHf=09fMW@80U9BD00D0EEEE
0492@P2TY:@0Y:BT0:VYZ@030:ZZZP80Xj>S00D0UIFE08J6QP1iNGT0NGUi09JFUP0309RHV00409ZJ
VP1XJ6P0J6QX04e=C@80N7Qh00D0Rh^;0:6QX@2UYJD0YJFU0:JVYP0209BDU00509fMW@2GUiL0UiNG
092@T02;Rh/00P1lO7`01@2HV9P0De=C05=CD`2LW9`0VYZJ0080[:b/00@0_[jn0;2`/02`/;00Y:BT
0P2HV9P01@2PX:00UIFE096AT@2ATI40SHf=0080WYjN00D0CDe=079bLP1nOWh0OWin07IfMP0207in
OP0507EeM@1bLW80MgMg07MgM`1cLg<00P1bLW801@1MGEd0EeMG05MGE`19BDT0>3Ph0080<c<c00D0
G5aL06=SH`1SHf<0IFEU05]KF`0204U9B@0404=3@`19BDT0BDU905=CD`80CDe=0P1CDe<204I6AP04
01`L701NGUh0GUiN06YZJQ40oooo00@0SHf=07alO01lO7`0U9BD0P2[Zj/01@2=SHd0[jn_0:n_[`30
`<00Xj>S0080UiNG00D0W9bL07QhN01hN7P0QXJ609BDU00205UIF@0407alO02HV9P0V9RH07inOP80
YZJV00D0JVYZ069RHP1kNg/0Ng]k04m?C`0206ATI00507emO@2BTY80TY:B0;>c/`2NWYh00P1mOGd0
102n_[h0Y:BT0:BTY028R8P208b<S00506QXJ02CTi<0alO70<O7a`2ZZZX00P1mOGd01@29RHT0BTY:
0<O7a`37alL0VIVI0080bLW900D0^KVi0:^[Z`2[Zj/0R8R80861P@0208^;R`0407emO@2FUYH0UYJF
08J6QP80U9BD00D0W9bL0;2`/02n_[h0_[jn08n?S`0209nOW`050:^[Z`3Cdm<0XJ6Q0:6QX@36a/H0
0P21PH401@2^[Zh0Xj>S0:>SX`1nOWh0Ng]k0080QHF500@0HV9R09FEU@2EUID0S8b<0P2SXj<01@2W
YjL0gMgM08f=S@2=SHd0KVi^0080RHV900D0TY:B09NGU`2k^k/0^k^k07moO`02034a<@050=KFeP3M
gMd0gMgM069RHP1cLg<00P24Q8@01022PX80/K6a0;6a/@35aLD20;Rh^00506YZJP2RXZ80Shn?08n?
S`2;Rh/00P1iNGT01@1bLW80Jf][06][J`2h^;P0JFUY0080I6AT00D0@D5103Ph>00h>3P0N7Qh06YZ
JP0206MWI`040820P027QhL0QhN706i^KP80Shn?00D0P82007AdM01]KFd0KFe]06=SH`02065QH@05
06][J`1oOgl0Ogmo09FEU@1fMWH00P2][Jd01@28R8P0Lg=c07=cL`2=SHd0[:b/0080FUYJ00@0Cdm?
05UIF@1IFET0EUIF0P1WIfL00`1PH600oooo0?ooo`080?ooo`002P3oool0102/[:`0YZJV0:JVYP2H
V9P204];B`050:^[Z`2WYjL0WinO09nOW`2PX:000P2HV9P01@2GUiL0Q8B408B4Q02@T900PH610080
UiNG00D0Vi^K08n?S`2?Shl0NGUi0410@00208J6QP0409bLW02XZ:P0Z:RX0:VYZ@80[:b/00D0[Zj^
0:VYZ@2UYJD0YJFU09^KV`0209ZJVP0509bLW02;Rh/09BDU02DU9@1]KFd00P2QXJ401@2CTi<0XJ6Q
09>CT`2CTi<0MGEe0080M7Ad00D0MGEe06i^KP1^KVh0L71`07moO`0209VIV@0509BDU00i>CT0>CTi
07moO`22PX800P2:RXX0102DU9@0R8R808R8R02FUYH309^KV`04096AT@2=SHd0SHf=09fMW@80U9BD
00D0EEEE0492@P2TY:@0Y:BT0:VYZ@030:ZZZP80Xj>S00D0UIFE08J6QP1iNGT0NGUi09JFUP0309RH
V00409ZJVP1XJ6P0J6QX04e=C@80N7Qh00D0Rh^;0:6QX@2UYJD0YJFU0:JVYP0209BDU00509fMW@2G
UiL0UiNG092@T02;Rh/00P1lO7`01@2HV9P0De=C05=CD`2LW9`0VYZJ0080[:b/00@0_[jn0;2`/02`
/;00Y:BT0P2HV9P01@2PX:00UIFE096AT@2ATI40SHf=0080WYjN00D0CDe=079bLP1nOWh0OWin07If
MP0207inOP0507EeM@1bLW80MgMg07MgM`1cLg<00P1bLW801@1MGEd0EeMG05MGE`19BDT0>3Ph0080
<c<c00D0G5aL06=SH`1SHf<0IFEU05]KF`0204U9B@0404=3@`19BDT0BDU905=CD`80CDe=0P1CDe<2
04I6AP0401`L701NGUh0GUiN06YZJQ40oooo00@0SHf=07alO01lO7`0U9BD0P2[Zj/01@2=SHd0[jn_
0:n_[`30`<00Xj>S0080UiNG00D0W9bL07QhN01hN7P0QXJ609BDU00205UIF@0407alO02HV9P0V9RH
07inOP80YZJV00D0JVYZ069RHP1kNg/0Ng]k04m?C`0206ATI00507emO@2BTY80TY:B0;>c/`2NWYh0
0P1mOGd0102n_[h0Y:BT0:BTY028R8P208b<S00506QXJ02CTi<0alO70<O7a`2ZZZX00P1mOGd01@29
RHT0BTY:0<O7a`37alL0VIVI0080bLW900D0^KVi0:^[Z`2[Zj/0R8R80861P@0208^;R`0407emO@2F
UYH0UYJF08J6QP80U9BD00D0W9bL0;2`/02n_[h0_[jn08n?S`0209nOW`050:^[Z`3Cdm<0XJ6Q0:6Q
X@36a/H00P21PH401@2^[Zh0Xj>S0:>SX`1nOWh0Ng]k0080QHF500@0HV9R09FEU@2EUID0S8b<0P2S
Xj<01@2WYjL0gMgM08f=S@2=SHd0KVi^0080RHV900D0TY:B09NGU`2k^k/0^k^k07moO`02034a<@05
0=KFeP3MgMd0gMgM069RHP1cLg<00P24Q8@01022PX80/K6a0;6a/@35aLD20;Rh^00506YZJP2RXZ80
Shn?08n?S`2;Rh/00P1iNGT01@1bLW80Jf][06][J`2h^;P0JFUY0080I6AT00D0@D5103Ph>00h>3P0
N7Qh06YZJP0206MWI`040820P027QhL0QhN706i^KP80Shn?00D0P82007AdM01]KFd0KFe]06=SH`02
065QH@0506][J`1oOgl0Ogmo09FEU@1fMWH00P2][Jd01@28R8P0Lg=c07=cL`2=SHd0[:b/0080FUYJ
00@0Cdm?05UIF@1IFET0EUIF0P1WIfL00`1PH600oooo0?ooo`080?ooo`002P3oool0101MGEd0AdM7
04M7A`0h>3P202HV9P0503Lg=`0l?3`0>3Ph03Ph>00j>SX00P0g=cL01@0c<c<0;2`/02`/;00L71`0
8B4Q00809RHV00D092@T02XZ:P0Z:RX08R8R010@400203lo?`0404M7A`11@D40@D5104I6AP80B4Q8
00D0Bd];05UIF@16ATH0ATI603Hf=P0203<c<`0503Ti>@0J6QX01PH600H61P0=3@d00`0C4a<0100K
6a/06ATI01TI6@0L71`201dM7@0501hN7P0I6AT06ATI01hN7P0P82000P0M7Ad01@0O7al07AdM01dM
7@0G5aL06a/K00807alO00@0820P01XJ6P0J6QX0820P0P0S8b<01@0I6AT09bLW02<S8`0S8b<09BDU
00<0820P00@08B4Q02/[:`0[:b/0?Shn0P0o?cl01@0i>CT0=3@d03@d=00/;2`08b<S008020P800D0
5aLG02/[:`0[:b/0<S8b034a<@02030`<00502`/;00j>SX0>SXj03Ph>010@4000P1CDe<0101ADE40
=cLg03Lg=`0T92@201lO7`0502HV9P0Y:BT0=cLg03Lg=`0n?Sh00P0k>c/01@0j>SX0=cLg04A4A014
A4@0Bd];0080CTi>00D0C4a<03De=@0e=CD07QhN03/k>`0203dm?@050492@P13@d<0@d=304e=C@16
ATH00`14A4@203dm?@0504M7A`19BDT0BDU904U9B@0L71`00P0k>c/01@1PH600GemO05mOG`1QHF40
Jf][0080JVYZ00D0HV9R071`L01`L700PH6107emO@0207alO00406IVIP0i>CT0>CTi07moO`80NGUi
00D0Ng]k0820P024Q8@0Q8B408b<S00207YjNP0306m_K`3oool0oooo00l0oooo00@0TI6A07]kN`1k
Ng/0UIFE0P2/[:`01@2@T900Z:RX0:RXZ02n_[h0YZJV0080QXJ600D0TY:B07AdM01dM7@0QXJ6096A
T@02051@D00408>3P`2NWYh0WYjN08Z:RP80Y:BT00D0H61P06ATI01lO7`0O7al05ADE00207QhN005
0820P02>SXh0SXj>0<30`02GUiL00P20P800102n_[h0X:2P0:2PX026QXH2092@T00506i^KP2@T900
^k^k0;^k^`2][Jd00P26QXH01@2FUYH0DE5A0;Zj^P2j^[X0UYJF0080dm?C00D0^KVi0:ZZZP2ZZZX0
QHF506IVIP0208f=S@040820P02>SXh0SXj>08b<S080WinO00D0U9BD0:BTY02a/K40/K6a09:BTP02
09>CT`050;Jf]P3@d=00WinO09nOW`2h^;P00P1iNGT0102>SXh0SHf=08f=S@1eMGD30861P@04055A
D@2?Shl0Shn?075aL@80V9RH00D0Z:RX0=KFeP29RHT0RHV908:2PP0208>3P`050;>c/`2OWil0clo?
0<o?c`1gMgL00P1=CDd01@3Rh^80g=cL0=cLg01ZJVX0PH610080M7Ad00@0Jf][0;fm_@2m_Kd0`L71
0P2k^k/01@1oOgl0WIfM09:BTP2BTY80UIFE0080K6a/00D0SHf=05iNGP1NGUh0Z:RX075aL@02065Q
H@05051@D00m?Cd0?Cdm07IfMP1YJFT00P1LG5`0101hN7P0OWin07inOP1UIFD208B4Q005071`L01g
MgL0MgMg07MgM`1WIfL00P1/K6`01@1fMWH0QXJ608J6QP2DU9@0M7Ad0080`l?300D0OGem07moO`1o
Ogl0TI6A0:VYZ@02069RHP0405MGE`1IFET0FEUI04e=C@80Jf][00<0Hf=S0?ooo`3oool0203oool0
00X0oooo00@0V9RH09BDU02DU9@0UYJF0P2IVIT01@2JVYX0V9RH08f=S@2=SHd0V9RH00<0X:2P0P2C
Ti<01@0R8R80JFUY08V9R@29RHT0QHF50080UYJF00D0Ti>C08b<S01nOWh0OWin07alO0020820P005
096AT@2JVYX0VYZJ0:6QX@2NWYh00P0b<S801@1TI6@0QHF508F5Q@26QXH0R8R80080Y:BT00D0Xj>S
09RHV02HV9P0Xj>S0:2PX00309bLW080V9RH00D0OWin03Hf=P0f=SH0QhN709bLW00209ZJVP0509^K
V`2PX:00X:2P09fMW@2RXZ800P2OWil0102PX:00XZ:R0::RXP2SXj<20:FUY@0503De=@21PH40OWin
07inOP20P8000P1gMgL01@1^KVh0MGEe096AT@2ATI40UYJF0080Ti>C00D0TI6A08>3P`23Ph<0PX:2
075aL@02038b<P0507]kN`26QXH0QXJ609>CT`2HV9P00P2LW9`01@2JVYX0UIFE09FEU@2DU9@0XJ6Q
0080X:2P00@0YjNW0:BTY02TY:@0EUIF0P1lO7`01@2ZZZX0YJFU0:BTY02TY:@0YZJV0080Y:BT00D0
YJFU0:>SX`2XZ:P0Z:RX09ZJVP0207=cL`05079bLP1_Kfl0Kfm_051@D02f][H00P2[Zj/00`2NWYh0
Xj>S0:>SX`020;>c/`80ZZZZ00D0WYjN08n?S`2?Shl0YJFU0:ZZZP020:BTY004059BDP2QXJ40XJ6Q
09^KV`80Rh^;00D0O7al07AdM024Q8@0Q8B407IfMP0207alO00509BDU02IVIT0U9BD09BDU01bLW80
0P0e=CD309ZJVP0509RHV02KVi/0X:2P0:2PX02:RXX00P24Q8@00`1iNGT0oooo0?ooo`0?0?ooo`04
096AT@1lO7`0O7al08j>SP80Vi^K00D0Shn?0:RXZ02XZ:P0^;Rh0:b/[00208J6QP0509^KV`1XJ6P0
J6QX08j>SP2EUID00P1PH600101mOGd0W9bL09bLW027QhL209RHV00506][J`1TI6@0LG5a075aL@1=
CDd00P1fMWH01@1`L700QhN708N7Q`2g]kL0V9RH0080MGEe00@0_Kfm09^KV`2KVi/0RHV90P2EUID0
1@1YJFT0UIFE0<30`030`<00Zj^[0080SXj>00D0U9BD04Y:BP32`/80`/;20:BTY0020<k>cP050;Bd
]02RXZ80XZ:R08^;R`1VIVH00P20P800101cLg<0NGUi07UiN@1nOWh209NGU`050;2`/02XZ:P0Z:RX
0:RXZ02BTY800P2FUYH01@2IVIT0WYjN0:JVYP2VYZH0]kNg0080Ogmo00D0Z:RX09^KV`2KVi/0Ph>3
08b<S00208:2PP04051@D02LW9`0W9bL07moO`80TY:B00D0/K6a0=GEe@2ATI40TI6A08N7Q`0206e]
K@050:^[Z`2QXJ40f][J0=[JfP1ZJVX00P1:BTX30=kNgP0507UiN@1YJFT0MgMg07MgM`1IFET00P39
bLT01@2XZ:P0/;2`0;2`/028R8P0UYJF0080SHf=00@0U9BD07EeM@1eMGD0TI6A0P1XJ6P01@1oOgl0
Ti>C05eMG@1MGEd0C4a<0080?Cdm00D0Ogmo061PH01GEeL0EeMG06e]K@0207]kN`0505aLG01jNWX0
NWYj07=cL`1`L7000P1jNWX0101]KFd0LW9b079bLP1oOgl209JFUP0508f=S@1mOGd0eMGE0=GEe@1b
LW800P2BTY80102JVYX0XZ:R06e]K@1]KFd306=SH`04059BDP1dM7@0M7Ad06][J`X0oooo000:0?oo
o`0409RHV02DU9@0U9BD09JFUP80VIVI00D0VYZJ09RHV02=SHd0SHf=09RHV0030:2PX080Ti>C00D0
8R8R06UYJ@29RHT0RHV908F5Q@0209JFUP0509>CT`2<S8`0OWin07inOP1lO7`00P20P8001@2ATI40
VYZJ09ZJVP2QXJ40WYjN0080<S8b00D0I6AT08F5Q@25QHD0QXJ608R8R0020:BTY0050:>SX`2HV9P0
V9RH0:>SX`2PX:000`2LW9`209RHV00507inOP0f=SH0=SHf08N7Q`2LW9`00P2JVYX01@2KVi/0X:2P
0:2PX02MWId0XZ:R0080WinO00@0X:2P0::RXP2RXZ80Xj>S0P2UYJD01@0e=CD0PH6107inOP1nOWh0
P8200080MgMg00D0KVi^07EeM@2ATI40TI6A09JFUP0209>CT`05096AT@23Ph<0Ph>308:2PP1aLG40
0P0b<S801@1kNg/0QXJ608J6QP2CTi<0V9RH0080W9bL00D0VYZJ09FEU@2EUID0U9BD0:6QX@020:2P
X0040:NWY`2TY:@0Y:BT05IFEP80O7al00D0ZZZZ0:FUY@2TY:@0Y:BT0:JVYP020:BTY0050:FUY@2S
Xj<0Z:RX0:RXZ02JVYX00P1cLg<01@1bLW80Kfm_06m_K`1@D500][Jf0080Zj^[00<0WYjN0:>SX`2S
Xj<00P2c/k<20:ZZZP0509jNWP2?Shl0Shn?0:FUY@2ZZZX00P2TY:@0101BDU80XJ6Q0:6QX@2KVi/2
08^;R`0507alO01dM7@0Q8B408B4Q01fMWH00P1lO7`01@2DU9@0VIVI09BDU02DU9@0LW9b0080=CDe
0`2JVYX01@2HV9P0Vi^K0:2PX02PX:00RXZ:0080Q8B400<0NGUi0?ooo`3oool03`3oool0102ATI40
O7al07alO02>SXh209^KV`0508n?S`2XZ:P0Z:RX0;Rh^02/[:`00P26QXH01@2KVi/0J6QX06QXJ02>
SXh0UIFE0080H61P00@0OGem09bLW02LW9`0QhN70P2HV9P01@1[Jf/0I6AT075aL@1aLG40CDe=0080
MWIf00D0L71`08N7Q`27QhL0]kNg09RHV00207EeM@040;fm_@2KVi/0Vi^K08V9R@80UIFE00D0JFUY
09FEU@30`<00`<300:^[Z`0208j>SP0509BDU01:BTX0`/;20<;2`P2TY:@00P3>c/h01@2d];@0XZ:R
0::RXP2;Rh/0IVIV0080P82000@0Lg=c07UiN@1iNGT0OWin0P2GUiL01@2`/;00Z:RX0:RXZ02XZ:P0
TY:B0080UYJF00D0VIVI09jNWP2VYZH0YZJV0;Ng]`0207moO`050:RXZ02KVi/0Vi^K08>3P`2<S8`0
0P22PX80101@D500W9bL09bLW01oOgl209:BTP050;6a/@3EeMD0TI6A096AT@27QhL00P1]KFd01@2[
Zj/0XJ6Q0=[JfP3Jf]X0JVYZ0080BTY:0`3Ng]h01@1iNGT0JFUY07MgM`1gMgL0FEUI0080bLW900D0
Z:RX0;2`/02`/;00R8R809JFUP0208f=S@0409BDU01eMGD0MGEe096AT@80J6QX00D0Ogmo09>CT`1M
GEd0GEeM04a<C00203dm?@0507moO`1PH600EeMG05MGE`1]KFd00P1kNg/01@1LG5`0NWYj07YjNP1c
Lg<0L71`0080NWYj00@0KFe]079bLP1bLW80Ogmo0P2FUYH01@2=SHd0OGem0=GEe@3EeMD0LW9b0080
TY:B00@0VYZJ0::RXP1]KFd0KFe]0`1SHf<0101BDU80M7Ad07AdM01[Jf/:0?ooo`002P3oool00`2g
]kL0/;2`0;2`/0030:j^[P050;2`/02^[Zh0YjNW0:NWY`2UYJD00P2TY:@01@2ZZZX0Zj^[0:^[Z`0f
=SH0Shn?00<0ZJVY0P2TY:@01@2:RXX0MgMg08J6QP26QXH0Vi^K0080QXJ600D0Rh^;0:6QX@2QXJ40
Y:BT09nOW`0203Ti>@0409:BTP2PX:00X:2P09>CT`<0YZJV00D0XZ:R09:BTP2BTY80SHf=08B4Q002
09NGU`040:2PX02>SXh0SXj>07UiN@80@D5100D0R8R80:6QX@2MWId0WIfM0::RXP0209VIV@0509fM
W@2IVIT0RHV908V9R@2<S8`00P2HV9P01@2UYJD0ZJVY0:VYZ@0i>CT0IVIV00<0OWin0P1iNGT0101/
K6`0LG5a07MgM`1gMgL407emO@80O7al00D0Ng]k0820P013@d<0@d=30861P@0207moO`0507YjNP25
QHD0QXJ608J6QP23Ph<00P2@T9001@2:RXX0Ti>C09ZJVP2JVYX0X:2P0080[:b/00D0H61P07moO`1o
Ogl0Z:RX0::RXP0208^;R`0508J6QP22PX80PX:208B4Q02=SHd00P2KVi/0102FUYH0OWin07inOP1h
N7P206=SH`0504A4A02][Jd0Z:RX0:RXZ02WYjL00P2RXZ801@2UYJD0Zj^[0:JVYP2VYZH0Y:BT0080
XJ6Q00D0Y:BT0:>SX`2KVi/0Vi^K04I6AP0209fMW@0508f=S@25QHD0QHF507MgM`1^KVh00P1jNWX0
1@1eMGD0LW9b079bLP29RHT0Ti>C0080XJ6Q00@0N7Qh034a<@0a<C40S8b<0P2=SHd01@29RHT0Shn?
0:2PX02PX:00QXJ60080NWYj00<0Ph>30?ooo`3oool03`3oool0102@T900Ph>308>3P`2?Shl209VI
V@0508j>SP2_[jl0[jn_0:RXZ02e]KD00P26QXH01@2?Shl0Fe]K05]KF`2ATI40R8R80080IVIV00@0
TY:B08f=S@2=SHd0R8R80P2JVYX01@1_Kfl0GUiN071`L01`L700G5aL0080KVi^00D0M7Ad08N7Q`27
QhL0]KFe09:BTP0208R8R0040<[:bP2PX:00X:2P092@T080Ti>C00D0IVIV096AT@30`<00`<300:RX
Z00208V9R@0508F5Q@1:BTX0^k^k0;^k^`2][Jd00P3;bl/01@2`/;00VIVI09VIV@1oOgl0KFe]0080
SHf=00@0K6a/07=cL`1cLg<0QhN70P2;Rh/01@2EUID0VIVI0:ZZZP2ZZZX0SXj>0080R8R800D0]kNg
0:^[Z`2ZZZX0ZZZZ0;Bd]00208n?S`050;Jf]P29RHT0RHV908N7Q`2BTY800P1mOGd0101FEUH0SHf=
08f=S@27QhL20820P0050:n_[`3Bd]80RXZ:08Z:RP2?Shl00P1PH6001@2[Zj/0XJ6Q0=cLg03Lg=`0
HV9R0080CDe=00D0f=SH0=7Ad@3AdM40Ng]k06UYJ@0207MgM`04055AD@3>c/h0c/k>0;Zj^P80^;Rh
00D0U9BD07EeM@1/K6`0K6a/08V9R@0206YZJP0507moO`1jNWX0NWYj07IfMP2GUiL00P1DE5@01@10
@400D51@051@D025QHD0NGUi0080HV9R00@0H61P08:2PP22PX80QHF50P27QhL01@1[Jf/0IFEU06UY
J@1YJFT0NGUi0080Ph>300D0Rh^;0;6a/@2a/K40Q8B407UiN@020=OGe`0507AdM02EUID0UIFE09jN
WP2EUID00P1IFET0101XJ6P0GEeM05eMG@1>CTh206][J`0306a/K03oool0oooo00P0oooo000:0?oo
o`040;Ng]`2^[Zh0[Zj^0;6a/@80[Jf]00D0];Bd0:n_[`2ZZZX0ZZZZ0:NWY`020:ZZZP050;:b/P2I
VIT0VIVI02XZ:P2;Rh/00P2TY:@01@2WYjL0XZ:R0::RXP22PX80N7Qh00<0PH610P1nOWh01@2<S8`0
V9RH09RHV02TY:@0X:2P0080=cLg00D0Vi^K09RHV02HV9P0Shn?09fMW@0209JFUP0509fMW@2FUYH0
UYJF092@T024Q8@00P2<S8`0102GUiL0Rh^;08^;R`1nOWh203dm?@05096AT@2QXJ40XJ6Q0:6QX@2O
Wil00P2EUID01@2KVi/0UIFE09NGU`2GUiL0T92@0080TY:B00D0Xj>S0:FUY@2UYJD0<c<c069RHP02
07=cL`0507moO`26QXH0QXJ606QXJ01WIfL00P1bLW80101hN7P0P8200820P022PX8208R8R00508J6
QP1oOgl0B4Q804Q8B01oOgl00P1fMWH01@1^KVh0N7Qh0861P@21PH40O7al0080N7Qh00D0Ogmo07al
O02BTY80TY:B09>CT`020:^[Z`0506a/K01kNg/0Ng]k0:JVYP2RXZ800P2JVYX01@2ATI40Ti>C09>C
T`2@T900Ti>C0080XZ:R00@0S8b<08>3P`23Ph<0Q8B40P1XJ6P01@1EEED0ZZZZ0:RXZ02XZ:P0/;2`
0080[:b/00D0[jn_0:VYZ@2XZ:P0Z:RX0:NWY`020:2PX0050::RXP2MWId0S8b<08b<S00T92@00P2L
W9`01@2UYJD0QXJ608J6QP1_Kfl0JFUY0080GUiN00D0JFUY06IVIP1VIVH0T92@09^KV`0209jNWP04
07emO@18B4P0B4Q80::RXP80WinO0P2VYZH20:n_[`040:JVYP2PX:00X:2P0:>SXa40oooo00@0R8R8
07inOP1nOWh0R8R80P26QXH01@25QHD0/k>c0;>c/`2QXJ40_[jn0080Shn?00D0Rh^;05]KF`1KFe/0
U9BD08Z:RP0206UYJ@0408F5Q@2EUID0UIFE0861P@80UIFE00D0MWIf05mOG`1`L700L71`05QHF002
06IVIP0507EeM@2:RXX0RXZ:0<C4a02CTi<00P26QXH0102o_kl0SXj>08j>SP25QHD207emO@05069R
HP2@T900/K6a0;6a/@2GUiL00P2<S8`01@20P800CTi>0;bl_02l_;`0Vi^K0080_;bl00D0/[:b09nO
W`2OWil0OGem06i^KP0208R8R00407EeM@1_Kfl0Kfm_08f=S@80Shn?00D0/k>c0:ZZZP2VYZH0YZJV
0:BTY002092@T0050:ZZZP36a/H0XZ:R0::RXP2OWil00P25QHD01@2k^k/0Ogmo07moO`2;Rh/0Shn?
0080Rh^;00@0LG5a09ZJVP2JVYX0R8R80P1cLg<01@2`/;00alO70820P020P800WYjN0080GUiN00D0
X:2P09NGU`3Ogml0gmoO05MGE`0205eMG@050>7Qh@31`L40`L7109VIV@1hN7P00P1mOGd0101KFe/0
`/;20<;2`P3;bl/20:^[Z`0509^KV`2LW9`0RHV908V9R@2VYZH00P1gMgL01@20P800Ti>C09>CT`2C
Ti<0VYZJ0080N7Qh00D0@D5105ADE01DE5@0P82007emO@0207moO`04071`L02:RXX0RXZ:069RHP80
Lg=c00D0Jf][06YZJP1UIFD0IFEU0861P@0308j>SP80^[Zj00D0NWYj08V9R@3Lg=`0g=cL05MGE`02
09bLW00509FEU@29RHT0Ph>308>3P`1eMGD00P1ZJVX0101DE5@0LW9b079bLP1iNGT:0?ooo`002P3o
ool0102h^;P0/k>c0;>c/`2d];@20:ZZZP050:VYZ@2^[Zh0ZJVY0:VYZ@2ZZZX00P2SXj<01@2PX:00
WinO09nOW`19BDT0WinO0080X:2P00D0XJ6Q09NGU`2GUiL0RHV907alO00207emO@0407QhN02ATI40
TI6A09ZJVP80Vi^K00D0Xj>S09NGU`0m?Cd0?Cdm09^KV`0209VIV@0509:BTP2TY:@0X:2P0:2PX02U
YJD00P2<S8`01@2@T900MWIf08N7Q`27QhL0QHF50080Ph>300D0MGEe04E5A@15ADD0Ti>C09bLW002
09>CT`05096AT@2NWYh0WYjN09jNWP2IVIT00P2GUiL0102?Shl0U9BD09BDU02NWYh209fMW@0504E5
A@1ZJVX0KFe]06e]K@21PH400P1kNg/01@20P800IVIV07AdM01dM7@0MGEe0080LG5a00D0Jf][07al
O01lO7`0MWIf07MgM`0204];B`05065QH@1PH600H61P06=SH`1[Jf/00P1aLG401@1ZJVX0Lg=c07=c
L`1kNg/0R8R80080Shn?00@0UYJF09ZJVP2JVYX0JFUY0P1oOgl01@26QXH0MWIf08>3P`23Ph<0S8b<
0080R8R800D0TI6A09JFUP2;Rh/0Rh^;07emO@0206YZJP0506IVIP1;Bd/0Bd];04];B`2?Shl00P2<
S8`01@2?Shl0RXZ:08Z:RP2<S8`0RHV90080OGem00D0Ogmo07YjNP1jNWX0NWYj07]kN`0205iNGP04
01LG5`1ZJVX0JVYZ07AdM080IVIV00D0CTi>03`l?00f=SH0=SHf03hn?P0203Hf=P0504a<C01LG5`0
G5aL05aLG016ATH00P0^;Rh01@14A4@0CDe=04e=C@1?Cdl0@D510080AdM700@0FUYJ06IVIP1VIVH0
I6AT4@3oool0102HV9P0RXZ:08Z:RP27QhL20820P00507inOP2_[jl0[jn_0;>c/`2d];@00P23Ph<0
1@26QXH0FUYJ05YJFP2OWil0TY:B0080H61P00@0KFe]09RHV02HV9P0QhN70P2BTY801@28R8P0IfMW
06i^KP1^KVh0D51@0080GUiN00D0NWYj08R8R028R8P0[Zj^09:BTP0207emO@040<30`023Ph<0Ph>3
0861P@80SHf=00D0J6QX09FEU@2d];@0];Bd09RHV00209VIV@050820P01GEeL0][Jf0;Jf]P2RXZ80
0P38b<P01@2][Jd0ZJVY0:VYZ@1hN7P0LG5a0080QhN700@0NGUi059BDP1BDU80P8200P2ATI401@2l
_;`0Y:BT09BDU02DU9@0WIfM0080Ogmo00D0[Jf]0=CDe02SXj<0Xj>S0:JVYP0208V9R@050<;2`P1k
Ng/0Ng]k07IfMP25QHD00P2BTY801020P800SXj>08j>SP2MWId206EUI@050:JVYP2j^[X0Q8B408B4
Q02WYjL00P1HF5P01@2ATI40UIFE0=oOg`3Ogml0D51@0080Lg=c00D0i>CT0;fm_@2m_Kd0UiNG07Yj
NP0207MgM`0406][J`2[Zj/0Zj^[0=OGe`80WinO00D0PH6109^KV`2>SXh0SXj>09^KV`0207]kN`05
08V9R@2PX:00X:2P0:RXZ02MWId00P1mOGd01@10@400FUYJ05YJFP2ATI40EUIF0080X:2P00@0LW9b
07QhN01hN7P0J6QX0P1bLW801@1aLG40KVi^06e]K@1]KFd0OGem0080UiNG00D0TI6A0;>c/`2c/k<0
KVi^09BDU0020=;BdP0505=CD`2:RXX0RXZ:092@T02;Rh/00P2BTY80101>CTh0K6a/06a/K01>CTh2
075aL@0306YZJP3oool0oooo00P0oooo000:0?ooo`040;Rh^02c/k<0/k>c0;Bd]080ZZZZ00D0ZJVY
0:j^[P2YZJT0ZJVY0:ZZZP020:>SX`050:2PX02OWil0WinO04U9B@2OWil00P2PX:001@2QXJ40UiNG
09NGU`29RHT0O7al0080OGem00@0N7Qh096AT@2ATI40VYZJ0P2KVi/01@2SXj<0UiNG03dm?@0m?Cd0
Vi^K0080VIVI00D0TY:B0:BTY02PX:00X:2P0:FUY@0208b<S005092@T01fMWH0QhN708N7Q`25QHD0
0P23Ph<01@1eMGD0ADE504E5A@2CTi<0W9bL0080Ti>C00D0TI6A09jNWP2NWYh0WYjN09VIV@0209NG
U`0408n?S`2DU9@0U9BD09jNWP80WIfM00D0ADE506YZJP1]KFd0KFe]0861P@0207]kN`050820P01V
IVH0M7Ad07AdM01eMGD00P1aLG401@1[Jf/0O7al07alO01fMWH0MgMg0080Bd];00D0HF5Q061PH01P
H600Hf=S06][J`02075aL@0506YZJP1cLg<0Lg=c07]kN`28R8P00P2?Shl0102FUYH0VYZJ09ZJVP1Y
JFT207moO`0508J6QP1fMWH0Ph>308>3P`2<S8`00P28R8P01@2ATI40UYJF08^;R`2;Rh/0OGem0080
JVYZ00D0IVIV04];B`1;Bd/0Bd];08n?S`0208b<S00508n?S`2:RXX0RXZ:08b<S029RHT00P1mOGd0
1@1oOgl0NWYj07YjNP1jNWX0Ng]k0080GUiN00@05aLG06YZJP1ZJVX0M7Ad0P1VIVH01@1>CTh0?3`l
03Hf=P0f=SH0?Shn0080=SHf00D0C4a<05aLG01LG5`0G5aL04I6AP0202h^;P0504A4A01=CDd0CDe=
04m?C`11@D400P17AdL0101JFUX0IVIV06IVIP1TI6@A0?ooo`0409RHV02:RXX0RXZ:08N7Q`80P820
00D0OWin0:n_[`2_[jl0/k>c0;Bd]00208>3P`0508J6QP1JFUX0FUYJ09nOW`2BTY800P1PH600101]
KFd0V9RH09RHV027QhL209:BTP0508R8R01WIfL0KVi^06i^KP1@D5000P1NGUh01@1jNWX0R8R808R8
R02^[Zh0TY:B0080OGem00@0`<3008>3P`23Ph<0PH610P2=SHd01@1XJ6P0UIFE0;Bd]02d];@0V9RH
0080VIVI00D0P82005MGE`2f][H0][Jf0::RXP020<S8b0050:f][@2YZJT0ZJVY07QhN01aLG400P27
QhL0101iNGT0DU9B059BDP20P802096AT@050;bl_02TY:@0U9BD09BDU02MWId00P1oOgl01@2][Jd0
e=CD0:>SX`2SXj<0YZJV0080RHV900D0`/;207]kN`1kNg/0MWIf08F5Q@0209:BTP040820P02>SXh0
SXj>09fMW@80IFEU00D0YZJV0;Zj^P24Q8@0Q8B40:NWY`0205QHF005096AT@2EUID0gmoO0=oOg`1@
D5000P1cLg<01@3Ti>@0_Kfm0;fm_@2GUiL0NWYj0080MgMg00@0Jf][0:^[Z`2[Zj/0emOG0P2OWil0
1@21PH40Vi^K08j>SP2>SXh0Vi^K0080Ng]k00D0RHV90:2PX02PX:00Z:RX09fMW@0207emO@050410
@01JFUX0FUYJ096AT@1FEUH00P2PX:00101bLW80N7Qh07QhN01XJ6P2079bLP05075aL@1^KVh0KFe]
06e]K@1mOGd00P2GUiL01@2ATI40/k>c0;>c/`1^KVh0U9BD0080d];B00D0De=C08Z:RP2:RXX0T92@
08^;R`0209:BTP0404i>CP1/K6`0K6a/04i>CP80LG5a00<0JVYZ0?ooo`3oool0203oool000X0oooo
00@0HF5Q05MGE`1GEeL0HF5Q0P1<C4`01@15ADD0>3Ph03hn?P0n?Sh0@4100080?Cdm00D0=3@d02TY
:@0Y:BT05ADE055AD@02051@D00504m?C`13@d<0@d=304M7A`19BDT00P1ADE401019BDT0?3`l03`l
?014A4@204M7A`0504E5A@0o?cl06QXJ01XJ6P10@4000P19BDT0100o?cl0>SXj03<c<`0c<c<303Hf
=P0502XZ:P0O7al05aLG01LG5`0H61P00P0F5QH01@0?3`l04Q8B018B4P0Z:RX0<c<c0080=CDe00D0
=3@d03Xj>P0j>SX0=3@d030`<00202`/;00401dM7@0_;bl0;bl_034a<@8071`L00D0:RXZ02@T900M
7Ad07AdM01hN7P02024Q8@806a/K0P0S8b<0100_;bl0:BTY02TY:@0R8R8202h^;P0502/[:`0/;2`0
;Rh^02h^;P0d=3@00`0b<S80100[:b/0:2PX02PX:00T92@202TY:@0505ADE01HF5P0DU9B059BDP0n
?Sh00P0^;Rh01@0i>CT0?3`l03`l?00k>c/0?3`l0080>SXj00D0=3@d03<c<`0c<c<06ATI030`<002
04U9B@04051@D01GEeL0EeMG04i>CP80F5QH101MGEd01@1NGUh0CTi>04i>CP1?Cdl0;Rh^0080:RXZ
0`10@4001@19BDT0B4Q804e=C@1=CDd0De=C0080DU9B00D0Bd];04m?C`1?Cdl0B4Q804i>CP0202h^
;P0506IVIP1`L700L71`08Z:RP2HV9P00P2FUYH0102RXZ80VYZJ09ZJVP2CTi<208^;R`0509NGU`2F
UYH0QHF508F5Q@11@D400P25QHD00`2@T900oooo0?ooo`0?0?ooo`<0SHf=00@0QXJ607inOP1nOWh0
Ogmo0P2e]KD01@39bLT0aLG509JFUP2FUYH0RHV90080GemO00D0VIVI07inOP1NGUh0GUiN07AdM002
09NGU`<0RHV900D0Q8B406EUI@1WIfL0IfMW04a<C002059BDP0507inOP20P800P8200:b/[02DU9@0
0P1jNWX0102o_kl0Rh^;08^;R`24Q8@208F5Q@0506i^KP28R8P0`L710<71`@2PX:000P2YZJT01@24
Q8@0FEUI0;jn_P2n_[h0/K6a0080clo?00D0/K6a0;Fe]@2e]KD0Ng]k07emO@0208j>SP0408V9R@1O
Gel0GemO08n?S`80YZJV00D0[:b/0:6QX@2CTi<0Ti>C0::RXP0208^;R`030:JVYP3<c<`0Y:BT0080
Y:BT0P2>SXh01@2g]kL0MWIf07IfMP1cLg<0PH610080SXj>00@0TY:B09ZJVP2JVYX0^;Rh0P1^KVh0
1@2YZJT0]KFe096AT@2ATI40YZJV0080J6QX00D0RXZ:0:ZZZP3UiND0iNGU04m?C`0207MgM`050>?S
h`2^[Zh0[Zj^09VIV@25QHD00P1`L700101kNg/0_Kfm0;fm_@3Ng]h209RHV00506EUI@2PX:00UiNG
09NGU`20P8000P1jNWX01@1[Jf/0TI6A096AT@2i^KT0Shn?0080LG5a00D0BDU906=SH`1SHf<0RXZ:
04U9B@020::RXP0407IfMP1ZJVX0JVYZ07QhN080Jf][00D0OWin06YZJP1^KVh0KVi^07EeM@0208Z:
RP05096AT@2PX:00X:2P06m_K`2=SHd00P3@d=001@1FEUH0Ng]k07]kN`2<S8`0Q8B40080TI6A00@0
JFUY05YJFP1JFUX0Fe]K0P1kNg/00`1iNGT0oooo0?ooo`080?ooo`002P3oool01025QHD0Ng]k07]k
N`26QXH203dm?@0505IFEP2IVIT0S8b<08b<S02?Shl00P1mOGd01@24Q8@0QhN708N7Q`2FUYH0Z:RX
0080Xj>S00D0WYjN0:VYZ@2YZJT0ZJVY03@d=00203`l?00307moO`1lO7`0O7al00@0Ph>300@0QHF5
08J6QP26QXH0SXj>0P26QXH0102?Shl0UiNG09BDU02DU9@305=CD`0506MWI`2KVi/0XJ6Q0:6QX@2T
Y:@00P2XZ:P01@2LW9`0YJFU0:FUY@2XZ:P0ZJVY0080Y:BT00D0SXj>0:ZZZP2ZZZX0?3`l06][J`02
09ZJVP0408>3P`1kNg/0Ng]k08N7Q`80Shn?00D0TI6A08:2PP1nOWh0OWin07IfMP0208:2PP0508>3
P`1kNg/05QHF01HF5P1nOWh00P2SXj<01@2LW9`0YjNW0:NWY`2CTi<0X:2P0080XZ:R00D0YjNW08N7
Q`27QhL0T92@09:BTP020:^[Z`0507moO`1KFe/0Fe]K0:NWY`26QXH00P2SXj<0102][Jd0/[:b0;:b
/P2^[Zh20:NWY`050:FUY@2LW9`0UIFE09FEU@2IVIT00P2KVi/01@10@400TI6A0;Jf]P2f][H0];Bd
0080/K6a00D0[:b/0:n_[`2_[jl0]KFe0;bl_0020;jn_P050<G5a@32`/80`/;20<G5a@1cLg<00P2G
UiL01@2i^KT0]KFe0;Fe]@2h^;P0^[Zj0080^k^k00<0_Kfm0<;2`P32`/800`31`L401@2l_;`0];Bd
05ADE01DE5@0UYJF0080/[:b00D0/k>c0;6a/@2XZ:P0Z:RX0:JVYP020:^[Z`050:b/[02[Zj/0Zj^[
0:^[Z`2^[Zh00P2SXj<0101GEeL0W9bL09bLW02TY:@A0?ooo`0408b<S02XZ:P0Z:RX07moO`80NGUi
00D0P8200;Rh^02h^;P0b<S80<;2`P0209VIV@0508J6QP1OGel0GemO0:2PX02@T9000P1MGEd0101Z
JVX0QXJ608J6QP2:RXX208j>SP0508>3P`1_Kfl0J6QX06QXJ01;Bd/00P1JFUX01@22PX80PH610861
P@2/[:`0V9RH0080RXZ:00@0`l?308f=S@2=SHd0RXZ:0P2?Shl01@1WIfL0QXJ60<30`030`<00WIfM
0080ZJVY00D0Ng]k05QHF02^[Zh0[Zj^0:NWY`020<k>cP050:^[Z`2/[:`0[:b/07UiN@1kNg/00P24
Q8@01028R8P0D51@051@D025QHD20:ZZZP050<30`02JVYX0UYJF09JFUP2WYjL00P2QXJ401@2UYJD0
clo?0:b/[02/[:`0WIfM0080U9BD00D0`/;2075aL@1aLG40M7Ad0861P@0208Z:RP0409VIV@2ATI40
TI6A0;Jf]P80Lg=c00D0XZ:R0:BTY027QhL0QhN709nOW`02079bLP0508J6QP2VYZH0gMgM0=gMg@1<
C4`00P28R8P00`3UiND0W9bL09bLW00208n?S`80QXJ600@0QHF50;:b/P2b/[80fm_K0P2ATI401@1R
HV80WinO09ZJVP2JVYX0SHf=0080WinO00D0Ogmo08N7Q`27QhL0/[:b07emO@0208N7Q`0505YJFP1Q
HF40HF5Q07]kN`12@T800P2JVYX0101hN7P0HV9R069RHP1iNGT207=cL`05092@T01VIVH0VIVI09VI
V@1YJFT00P2PX:001@2HV9P0X:2P0:2PX01UIFD0RXZ:0080`<3000D0IFEU07YjNP1jNWX0WinO08>3
P`0207QhN00407alO01KFe/0Fe]K05YJFP80Q8B400<0MGEe0?ooo`3oool0203oool000X0oooo00@0
QHF507]kN`1kNg/0QXJ60P0m?Cd01@1FEUH0VIVI08b<S02<S8`0Shn?0080OGem00D0Q8B408N7Q`27
QhL0UYJF0:RXZ0020:>SX`0509jNWP2YZJT0ZJVY0:VYZ@0d=3@00P0l?3`00`1oOgl0O7al07alO004
08>3P`0408F5Q@26QXH0QXJ608j>SP80QXJ600@0Shn?09NGU`2DU9@0U9BD0`1CDe<01@1WIfL0Vi^K
0:6QX@2QXJ40Y:BT0080Z:RX00D0W9bL0:FUY@2UYJD0Z:RX0:VYZ@020:BTY00508j>SP2ZZZX0ZZZZ
03`l?01[Jf/00P2JVYX01023Ph<0Ng]k07]kN`27QhL208n?S`05096AT@22PX80OWin07inOP1fMWH0
0P22PX801@23Ph<0Ng]k01HF5P0F5QH0OWin0080Xj>S00D0W9bL0:NWY`2WYjL0Ti>C0:2PX0020::R
XP050:NWY`27QhL0QhN7092@T02BTY800P2[Zj/01@1oOgl0Fe]K05]KF`2WYjL0QXJ60080Xj>S00@0
[Jf]0;:b/P2b/[80[Zj^0P2WYjL01@2UYJD0W9bL09FEU@2EUID0VIVI0080Vi^K00D0@410096AT@2f
][H0][Jf0;Bd]0020;6a/@050:b/[02_[jl0[jn_0;Fe]@2l_;`00P2n_[h01@35aLD0`/;20<;2`P35
aLD0Lg=c0080UiNG00D0^KVi0;Fe]@2e]KD0^;Rh0;Zj^P020;^k^`030;fm_@32`/80`/;200<0`L71
00D0_;bl0;Bd]01DE5@0E5AD09JFUP020;:b/P050;>c/`2a/K40Z:RX0:RXZ02VYZH00P2[Zj/01@2/
[:`0Zj^[0:^[Z`2[Zj/0[Zj^0080Xj>S00@0EeMG09bLW02LW9`0Y:BT4@3oool0102<S8`0Z:RX0:RX
Z01oOgl207UiN@050820P02h^;P0^;Rh0<S8b032`/800P2IVIT01@26QXH0GemO05mOG`2PX:00T92@
0080GEeM00@0JVYZ08J6QP26QXH0RXZ:0P2>SXh01@23Ph<0Kfm_06QXJ01XJ6P0Bd];0080FUYJ00D0
PX:20861P@21PH40[:b/09RHV00208Z:RP040<?3``2=SHd0SHf=08Z:RP80Shn?00D0IfMW08J6QP30
`<00`<3009fMW@020:VYZ@0507]kN`1HF5P0[Zj^0:j^[P2WYjL00P3>c/h01@2[Zj/0[:b/0:b/[01i
NGT0Ng]k0080Q8B400@0R8R8051@D01@D500QHF50P2ZZZX01@30`<00VYZJ09JFUP2FUYH0YjNW0080
XJ6Q00D0YJFU0<o?c`2/[:`0[:b/09fMW@0209BDU0050<;2`P1aLG40LG5a07AdM021PH400P2:RXX0
102IVIT0TI6A096AT@2f][H207=cL`050::RXP2TY:@0QhN708N7Q`2OWil00P1bLW801@26QXH0YZJV
0=gMg@3MgMd0C4a<0080R8R800<0iNGU09bLW02LW9`00P2?Shl208J6QP0408F5Q@2b/[80/[:b0=_K
f`80TI6A00D0HV9R09nOW`2JVYX0VYZJ08f=S@0209nOW`0507moO`27QhL0QhN70;:b/P1mOGd00P27
QhL01@1JFUX0HF5Q065QH@1kNg/0@T920080VYZJ00@0N7Qh069RHP1RHV80NGUi0P1cLg<01@2@T900
IVIV09VIV@2IVIT0JFUY0080X:2P00D0V9RH0:2PX02PX:00IFEU08Z:RP020<30`00506EUI@1jNWX0
NWYj09nOW`23Ph<00P1hN7P0101lO7`0Fe]K05]KF`1JFUX208B4Q00307EeM@3oool0oooo00P0oooo
000:0?ooo`040:^[Z`2b/[80/[:b0;2`/080BTY:00D0Jf][09nOW`2KVi/0Vi^K092@T00308F5Q@80
RXZ:00@0UiNG0::RXP2NWYh0WYjN0`2XZ:P01@2`/;00GemO05]KF`1KFe/0UiNG0080PH6100D0PX:2
07moO`1oOgl0Ng]k07MgM`0207=cL`0507inOP21PH40PH6107UiN@26QXH00P2HV9P01@1ADE40HV9R
069RHP1TI6@0TI6A0080YjNW00@0YZJV0:6QX@2QXJ40Ph>30P2JVYX01@2MWId0Y:BT0:BTY02TY:@0
SXj>0080[:b/00D0@d=3075aL@2>SXh0SXj>07]kN`0207UiN@0307YjNP1mOGd0OGem0080OWin0P1l
O7`307inOP0508F5Q@1oOgl0820P020P802;Rh/00P2PX:001@2QXJ40Xj>S0:>SX`2GUiL0WIfM0080
YZJV00D0Y:BT07UiN@1iNGT0NWYj08J6QP020:b/[00309NGU`1NGUh0GUiN0080UYJF0P2MWId0102N
WYh0XZ:R0::RXP2SXj<209ZJVP0509nOW`2KVi/0TI6A096AT@2JVYX00P2CTi<0100o?cl0/[:b0;fm
_@2m_Kd40;Rh^080_;bl00D0_[jn0<71`@31`L40`L710;^k^`020<30`0050;jn_P1YJFT0QXJ608J6
QP2ZZZX00P2_[jl01@2VYZH0XJ6Q09RHV02HV9P0XZ:R0080Z:RX00D0]kNg0:j^[P2^[Zh0[Zj^0:RX
Z00205MGE`050:>SX`2VYZH0YZJV0:>SX`2UYJD01@2TY:@01@2RXZ80YJFU0:FUY@2WYjL0Zj^[0080
V9RH00@0Cdm?08^;R`2;Rh/0WIfM4@3oool0102;Rh/0YZJV0:JVYP1mOGd207=cL`0507inOP2^[Zh0
[Zj^0<?3``2WYjL00P2CTi<01@1lO7`0GEeM05eMG@2LW9`0SHf=0080Hf=S00@0LW9b07moO`1oOgl0
V9RH0`26QXH0101dM7@0JFUY06UYJ@12@T8204i>CP0507inOP1fMWH0MWIf0;Vi^@2LW9`00P26QXH0
102h^;P0SHf=08f=S@2:RXX208^;R`0505eMG@1iNGT0/[:b0;:b/P2GUiL00P2PX:001@23Ph<0Fe]K
0;Zj^P2j^[X0Zj^[0080bl_;00D0YZJV0:BTY02TY:@0NWYj08>3P`0208F5Q@0408R8R01=CDd0CDe=
0820P080Xj>S00D0/k>c0:>SX`2GUiL0UiNG0:6QX@0209ZJVP050:2PX038b<P0Xj>S0:>SX`2IVIT0
0P2=SHd01@2n_[h0MWIf07IfMP1bLW80PX:20080Shn?00@0UYJF09bLW02LW9`0`<300P1lO7`01@2T
Y:@0Z:RX08j>SP2>SXh0UIFE0080Ogmo00D0V9RH0:ZZZP3Ph>00h>3P03`l?00209>CT`050>?Sh`2F
UYH0UYJF07inOP22PX800P2ATI40102LW9`0a/K60<K6aP3Jf]X208V9R@0505MGE`2DU9@0VIVI09VI
V@24Q8@00P2>SXh01@24Q8@0Xj>S0:>SX`2o_kl0SXj>0080Ogmo00D0ATI605iNGP1NGUh0PH6104];
B`0208V9R@0407IfMP1lO7`0O7al08Z:RP80QHF500D0RXZ:07MgM`2d];@0];Bd06=SH`0208f=S@05
08^;R`2^[Zh0[Zj^06e]K@2KVi/00P2WYjL01@1aLG40Lg=c07=cL`2/[:`0RXZ:0080O7al00@0HF5Q
05=CD`1CDe<0De=C0P1kNg/00`1/K6`0oooo0?ooo`080?ooo`002P3oool0102ZZZX0[:b/0:b/[02Z
ZZX204I6AP0506ATI02HV9P0W9bL09bLW02FUYH00P2;Rh/01@28R8P0Rh^;08^;R`27QhL0Shn?0080
SHf=00D0V9RH09nOW`2OWil0YjNW05QHF00204M7A`0407emO@2:RXX0RXZ:08Z:RP80Q8B400@0NWYj
07QhN01eMGD0MGEe0`26QXH207QhN080Rh^;00D0F5QH069RHP1RHV80FUYJ08>3P`020:FUY@0409nO
W`2KVi/0Vi^K07MgM`80UYJF00D0Vi^K09jNWP2OWil0WinO07alO0020:6QX@0403hn?P1TI6@0OWin
07inOP<0M7Ad0`1_Kfl01@1eMGD0N7Qh07QhN01hN7P0OGem0080N7Qh00D0NGUi07IfMP0^;Rh0;Rh^
08b<S00208Z:RP0509NGU`2ATI40TI6A09JFUP2NWYh00P2TY:@01@2VYZH0QhN708N7Q`23Ph<0Rh^;
0080Y:BT00D0Shn?04a<C01<C4`0Vi^K09VIV@0209nOW`040::RXP2OWil0WinO0:>SX`<0WinO00@0
SXj>09>CT`2CTi<0TY:B0P2CTi<0100n?Sh0/;2`0;jn_P2n_[h40;fm_@80^KVi00D0^[Zj0;Vi^@2g
]kL0]kNg0;>c/`020;6a/@050:b/[01DE5@0NGUi07UiN@2JVYX00P2ATI401@1fMWH0MGEe08V9R@29
RHT0UiNG0080I6AT00D0YjNW09:BTP2BTY80U9BD08n?S`0205IFEP0509BDU02QXJ40XJ6Q09nOW`2L
W9`00P2IVIT409RHV0<0XZ:R00@0Y:BT08B4Q024Q8@0=SHf0P2;Rh/00`2IVIT0oooo0?ooo`0?0?oo
o`0408V9R@2YZJT0ZJVY0820P080KVi^00D0Ng]k0:j^[P2^[Zh0_kno0::RXP020:2PX00507emO@1U
IFD0IFEU09FEU@2<S8`00P1WIfL0101iNGT0OWin07inOP2UYJD208V9R@0508Z:RP1jNWX0Hf=S06=S
H`1:BTX00P1FEUH01@20P800HF5Q065QH@2i^KT0/K6a0080U9BD00@0bLW909>CT`2CTi<0Shn?0P2C
Ti<01@1^KVh0PH610<k>cP3>c/h0XJ6Q0080ZJVY00D0Ng]k05EEE@2b/[80/[:b0:ZZZP020<K6aP<0
[:b/00D0Ogmo07]kN`27QhL0QhN708J6QP0204a<C00507emO@2VYZH0YZJV0;Bd]02`/;000P20P800
1@2TY:@0YJFU0:FUY@2a/K40f][J0080Xj>S00@0X:2P09bLW02LW9`0a<C40P1gMgL207]kN`80Ti>C
00@0SXj>0:^[Z`2[Zj/0[Jf]0P2;Rh/01@2YZJT0/[:b096AT@2ATI40QXJ60080VIVI00D0UiNG0;6a
/@3MgMd0gMgM03/k>`0209fMW@050>?Sh`2KVi/0Vi^K07]kN`1cLg<00P26QXH0102LW9`0cLg=0<g=
c@30`<0209BDU00505ADE02MWId0Shn?08n?S`1iNGT00P2?Shl01@2:RXX0U9BD09BDU02a/K40RHV9
0080PH6100D0<30`05YJFP1JFUX0MWIf04Y:BP0207EeM@0407alO01oOgl0Ogmo07UiN@80S8b<00D0
Lg=c08:2PP2l_;`0_;bl07=cL`02096AT@0409JFUP2/[:`0[:b/07emO@<0ZJVY00D0QhN707IfMP1f
MWH0W9bL09^KV`0208R8R00405mOG`1@D500D51@051@D080T92@00<0P8200?ooo`3oool0203oool0
00X0oooo00@0[Zj^0:f][@2][Jd0Xj>S0P11@D400`1GEeL0Vi^K09nOW`0209nOW`80VYZJ00D0VIVI
0::RXP2RXZ80WinO09FEU@0207alO00508b<S02EUID0UIFE0:FUY@1>CTh00P0^;Rh0101aLG40MgMg
07MgM`24Q8@208:2PP0407emO@2:RXX0SHf=08f=S@<0Rh^;0P26QXH208n?S`0505YJFP1=CDd0CDe=
06ATI02<S8`00P2FUYH0102>SXh0TY:B09:BTP1[Jf/207EeM@0508:2PP2ATI40Rh^;08^;R`1ZJVX0
0P1YJFT01@0/;2`0@d=307]kN`1kNg/0NWYj0080N7Qh00D0KFe]075aL@1aLG40Ng]k0820P0020861
P@0507QhN01]KFd0KFe]06MWI`1RHV800P0n?Sh00`26QXH0Rh^;08^;R`0408J6QP0409:BTP2JVYX0
VYZJ0:NWY`80Vi^K00D0U9BD08V9R@2;Rh/0Rh^;05=CD`0201LG5`0508F5Q@2?Shl0QHF508F5Q@23
Ph<00P2;Rh/01@2<S8`0QhN708N7Q`24Q8@0Ph>30080SHf=00D0Ogmo07UiN@1iNGT0>3Ph08N7Q`02
09bLW00409:BTP2?Shl0Shn?09>CT`80QhN700D0PX:2096AT@2?Shl0Shn?08j>SP0208b<S00507Ui
N@10@400KFe]06e]K@1HF5P00P19BDT01@0k>c/0ADE504U9B@19BDT0@D510080ADE500D0B4Q803Hf
=P0f=SH0?clo03Lg=`02034a<@0504I6AP1<C4`0C4a<05EEE@1;Bd/00P1=CDd01018B4P0Bd];04];
B`1>CTh204U9B@050451@@0j>SX08R8R028R8P0C4a<00P0S8b<00`0g=cL0oooo0?ooo`0?0?ooo`04
08R8R02c/k<0/k>c08N7Q`80NWYj00D0RHV90;Rh^02h^;P0aLG509jNWP0209nOW`0508:2PP1]KFd0
KFe]08J6QP1mOGd00P1WIfL0101TI6@0G5aL05aLG02[Zj/208J6QP0508Z:RP1mOGd0IVIV06IVIP15
ADD00P1EEED01@0a<C40FUYJ05YJFP2a/K40XJ6Q0080UYJF00@0_kno08f=S@2=SHd0RHV90P27QhL0
1@1aLG40QXJ60<30`030`<00UiNG0080WIfM00D0Kfm_065QH@34a<@0a<C40;Jf]P020<K6aP050:b/
[02e]KD0]KFe07emO@1nOWh00P2@T900102BTY80BDU904U9B@1bLW820:VYZ@050:JVYP2d];@0O7al
07alO02a/K400P2f][H01@2h^;P0fMWI09^KV`2KVi/0UYJF0080W9bL00D0`l?307]kN`1kNg/0Ogmo
07]kN`0308f=S@80WYjN00D0W9bL09jNWP2NWYh0/;2`0:^[Z`0209FEU@0507EeM@2UYJD0YJFU0:FU
Y@2i^KT00P3Fe]H01012@T80Zj^[0:^[Z`3Vi^H20:VYZ@0507UiN@1UIFD0PH610861P@2LW9`00P2f
][H01@2DU9@0Zj^[0:^[Z`1TI6@0/;2`0080VIVI00@0Rh^;09bLW02LW9`0S8b<0P2=SHd01@2XZ:P0
SHf=07emO@1mOGd0=SHf0080KVi^00D0Ph>304M7A`1XJ6P0J6QX07=cL`0206YZJP0506i^KP2ATI40
TI6A08:2PP2<S8`00P2m_Kd0101eMGD0Rh^;08^;R`29RHT209bLW0050861P@2CTi<0WIfM09fMW@26
QXH00P2VYZH01@2XZ:P0ZJVY07UiN@1iNGT0Fe]K0080CDe=00@0G5aL07IfMP1fMWH0K6a/2P3oool0
00X0oooo00@0[Zj^0:f][@2][Jd0Xj>S0P11@D400`1GEeL0Vi^K09nOW`0209nOW`80VYZJ00D0VIVI
0::RXP2RXZ80WinO09FEU@0207alO00508b<S02EUID0UIFE0:FUY@1>CTh00P0^;Rh0101aLG40MgMg
07MgM`24Q8@208:2PP0407emO@2:RXX0SHf=08f=S@<0Rh^;0P26QXH208n?S`0505YJFP1=CDd0CDe=
06ATI02<S8`00P2FUYH0102>SXh0TY:B09:BTP1[Jf/207EeM@0508:2PP2ATI40Rh^;08^;R`1ZJVX0
0P1YJFT01@0/;2`0@d=307]kN`1kNg/0NWYj0080N7Qh00D0KFe]075aL@1aLG40Ng]k0820P0020861
P@0507QhN01]KFd0KFe]06MWI`1RHV800P0n?Sh00`26QXH0Rh^;08^;R`0408J6QP0409:BTP2JVYX0
VYZJ0:NWY`80Vi^K00D0U9BD08V9R@2;Rh/0Rh^;05=CD`0201LG5`0508F5Q@2?Shl0QHF508F5Q@23
Ph<00P2;Rh/01@2<S8`0QhN708N7Q`24Q8@0Ph>30080SHf=00D0Ogmo07UiN@1iNGT0>3Ph08N7Q`02
09bLW00409:BTP2?Shl0Shn?09>CT`80QhN700D0PX:2096AT@2?Shl0Shn?08j>SP0208b<S00507Ui
N@10@400KFe]06e]K@1HF5P00P19BDT01@0k>c/0ADE504U9B@19BDT0@D510080ADE500D0B4Q803Hf
=P0f=SH0?clo03Lg=`02034a<@0504I6AP1<C4`0C4a<05EEE@1;Bd/00P1=CDd01018B4P0Bd];04];
B`1>CTh204U9B@050451@@0j>SX08R8R028R8P0C4a<00P0S8b<00`0g=cL0oooo0?ooo`0?0?ooo`04
08R8R02c/k<0/k>c08N7Q`80NWYj00D0RHV90;Rh^02h^;P0aLG509jNWP0209nOW`0508:2PP1]KFd0
KFe]08J6QP1mOGd00P1WIfL0101TI6@0G5aL05aLG02[Zj/208J6QP0508Z:RP1mOGd0IVIV06IVIP15
ADD00P1EEED01@0a<C40FUYJ05YJFP2a/K40XJ6Q0080UYJF00@0_kno08f=S@2=SHd0RHV90P27QhL0
1@1aLG40QXJ60<30`030`<00UiNG0080WIfM00D0Kfm_065QH@34a<@0a<C40;Jf]P020<K6aP050:b/
[02e]KD0]KFe07emO@1nOWh00P2@T900102BTY80BDU904U9B@1bLW820:VYZ@050:JVYP2d];@0O7al
07alO02a/K400P2f][H01@2h^;P0fMWI09^KV`2KVi/0UYJF0080W9bL00D0`l?307]kN`1kNg/0Ogmo
07]kN`0308f=S@80WYjN00D0W9bL09jNWP2NWYh0/;2`0:^[Z`0209FEU@0507EeM@2UYJD0YJFU0:FU
Y@2i^KT00P3Fe]H01012@T80Zj^[0:^[Z`3Vi^H20:VYZ@0507UiN@1UIFD0PH610861P@2LW9`00P2f
][H01@2DU9@0Zj^[0:^[Z`1TI6@0/;2`0080VIVI00@0Rh^;09bLW02LW9`0S8b<0P2=SHd01@2XZ:P0
SHf=07emO@1mOGd0=SHf0080KVi^00D0Ph>304M7A`1XJ6P0J6QX07=cL`0206YZJP0506i^KP2ATI40
TI6A08:2PP2<S8`00P2m_Kd0101eMGD0Rh^;08^;R`29RHT209bLW0050861P@2CTi<0WIfM09fMW@26
QXH00P2VYZH01@2XZ:P0ZJVY07UiN@1iNGT0Fe]K0080CDe=00@0G5aL07IfMP1fMWH0K6a/2P3oool0
00X0oooo00@0IVIV06a/K01/K6`0HF5Q0P0c<c<01@0b<S80H61P06IVIP1VIVH0HF5Q0080Fe]K0`1L
G5`01@1JFUX0H61P05]KF`1KFe/0I6AT0080FUYJ00@0HV9R03De=@0a<C40<C4a0`13@d<01@0k>c/0
A4A404A4A00g=cL0=CDe0080;2`/00D0=cLg030`<00`<300=cLg02d];@0202/[:`0502<S8`0R8R80
8R8R02PX:00_;bl00P0a<C40100R8R805ADE01DE5@0F5QH2018B4P0501DE5@0^;Rh09bLW02LW9`0N
7Qh00P0G5aL00`0A4A405ADE02/[:`0202/[:`80<C4a00D0BDU903hn?P0n?Sh0@d=304I6AP0204Q8
B0<0<S8b00D0@d=303/k>`0B4Q804Q8B01/K6`0202<S8`05030`<00o?cl0?clo03`l?00/;2`00P0b
<S801@10@400>c/k03/k>`0b<S80;2`/00806ATI00D07QhN02l_;`0_;bl0=cLg02XZ:P0201@D5004
02DU9@0e=CD0=CDe03/k>`80@D5100D0@T9201HF5P0Q8B408B4Q038b<P02034a<@0502d];@0c<c<0
=cLg03Lg=`0K6a/00P0_;bl00`19BDT0CTi>04i>CP0204i>CP80=SHf00D0Bd];051@D01@D500IFEU
07]kN`0208Z:RP0506IVIP1ADE40DE5A075aL@1`L7000P1_Kfl0101[Jf/0I6AT06ATI00S8b<206i^
KP0507AdM01ZJVX0J6QX06QXJ01SHf<00P0Y:BT01@0[:b/0H61P06UYJ@1YJFT0MWIf0080OWin00<0
MWIf01`L700L71`00P1cLg<207YjNP0408n?S`27QhL0QhN704Y:BQ40oooo00@0RHV909fMW@2MWId0
S8b<0P1]KFd01@2?Shl0/;2`0;2`/036a/H0XZ:R0080Z:RX00D0T92@07EeM@1eMGD0U9BD07QhN002
06YZJP0406EUI@1OGel0GemO0:FUY@80OWin00D0MWIf07]kN`1SHf<0Hf=S051@D00205IFEP0503hn
?P1kNg/0Ng]k0:VYZ@2PX:000P2BTY80102m_Kd0TY:B09:BTP2?Shl208Z:RP0507QhN02CTi<0^[Zj
0;Zj^P2HV9P00P2PX:02071`L080`/;200@0^[Zj0<C4a034a<@0/;2`0P2YZJT01@23Ph<0OGem08n?
S`2?Shl0UIFE0080ATI600D0M7Ad0:NWY`2WYjL0]KFe0;Vi^@0207=cL`050:^[Z`2g]kL0]kNg0<?3
``3Ogml00P2IVIT309bLW0050;Zj^P25QHD0QHF508^;R`1cLg<00P2<S8`0101jNWX0WYjN09jNWP2B
TY820:>SX`050;Bd]02`/;00PH610861P@1aLG400P2XZ:P01@2`/;00`/;20=GEe@3EeMD0>CTi0080
[Zj^00D0jn_[0;Jf]P2f][H0NGUi05MGE`020820P004096AT@2j^[X0^[Zj0;Zj^P80[:b/00D0JVYZ
0:ZZZP27QhL0QhN708Z:RP0209ZJVP05092@T02<S8`0S8b<0;Fe]@2:RXX00P29RHT01@0m?Cd0OGem
07emO@1nOWh0D51@0080N7Qh00@0K6a/06][J`1[Jf/0Jf][0`20P8001029RHT0Y:BT0:BTY01]KFd2
07emO@0508N7Q`2HV9P0V9RH08:2PP2BTY800P2;Rh/01@22PX80Shn?08n?S`2TY:@0/k>c0080NWYj
00@0JVYZ04i>CP1>CTh0JFUY0P1hN7P00`1TI6@0oooo0?ooo`080?ooo`002P3oool0101fMWH0D51@
051@D01lO7`207YjNP0507IfMP1nOWh0PX:208:2PP0e=CD00P0f=SH01@1cLg<0Ng]k07]kN`1jNWX0
S8b<0080Rh^;00D0:2PX055AD@1ADE40W9bL09^KV`020:RXZ0040:b/[02DU9@0U9BD03hn?P80Kfm_
00D0VIVI09bLW02LW9`0W9bL096AT@0207MgM`0502PX:02EUID0ZZZZ0:ZZZP2][Jd00P2XZ:P01@2^
[Zh0G5aL02/[:`0[:b/0SHf=0080U9BD00D0Shn?08Z:RP2:RXX0RXZ:04I6AP02028R8P0504=3@`1J
FUX0FUYJ05eMG@1cLg<00P23Ph<0100m?Cd0=CDe03De=@1ZJVX206EUI@05075aL@1`L700Kfm_06m_
K`0`<3000P0^;Rh01@1ZJVX0NGUi07MgM`1gMgL0Kfm_0080I6AT00D0;bl_06e]K@1]KFd0PX:207Ee
M@020861P@0509BDU01HF5P0F5QH00`<301jNWX00P2EUID01@2BTY80S8b<08b<S02NWYh0MGEe0080
=CDe00@0ZZZZ0:n_[`2_[jl0[Jf]0P2TY:@01@2NWYh09bLW07IfMP1fMWH0[Jf]0080[jn_00D0/k>c
0;fm_@2f][H0][Jf02h^;P020:FUY@050;^k^`2i^KT0^KVi0;^k^`2g]kL00P1FEUH01@2MWId0^;Rh
0;Rh^02i^KT0][Jf0080/[:b00D0Q8B4075aL@1aLG40ZJVY0;Fe]@020;Jf]P040;Bd]02XZ:P0Z:RX
03De=@80ZJVY00<0[jn_0:RXZ02WYjL00P2WYjL20451@@0306a/K02YZJT0/K6a0080/K6a0P2d];@0
1@2QXJ407alO01lO7`20P800MgMg0080HF5Q00@0Jf][06a/K01/K6`0@4104@3oool0101iNGT0Ti>C
09>CT`27QhL205EEE@0509RHV02UYJD0YJFU0;bl_02KVi/00P2/[:`01@22PX80NGUi07UiN@2EUID0
Ph>30080M7Ad00@0LG5a07QhN01hN7P0/K6a0P29RHT01@1lO7`0QhN706m_K`1_Kfl0I6AT0080F5QH
00D0I6AT08:2PP22PX80/;2`09^KV`0209BDU0040:j^[P2<S8`0S8b<08f=S@80QXJ600D0QhN709RH
V033`l<0`l?309fMW@0209nOW`0506][J`1cLg<0[:b/0:b/[033`l<00P32`/801@2ZZZX0VYZJ09ZJ
VP21PH40N7Qh0080QXJ600@0WYjN04e=C@1=CDd0IfMW0P2VYZH01@2][Jd0[Zj^07MgM`1gMgL0YZJV
0080Y:BT00D0bLW90=_Kf`2EUID0UIFE09fMW@0208n?S`050:^[Z`20P800P82008Z:RP1jNWX00P2<
S8`01023Ph<0VIVI09VIV@25QHD20::RXP050;>c/`2_[jl0NWYj07YjNP1TI6@00P2PX:001@2b/[80
alO70=?Cd`3Cdm<0<S8b0080[jn_00D0i^KV0;fm_@2m_Kd0O7al05eMG@0207inOP0409RHV02g]kL0
]kNg0;bl_080[jn_00D0Lg=c09ZJVP21PH40PH6108n?S`020861P@0508f=S@1mOGd0OGem0<C4a020
P8000P1mOGd01@0];Bd0J6QX06QXJ01OGel0DE5A0080Ph>300@0I6AT07]kN`1kNg/0OGem0P2:RXX0
1@23Ph<0NGUi08V9R@29RHT0NGUi0080Ph>30`2FUYH01@2=SHd0ZZZZ07moO`1oOgl0Shn?0080UiNG
00D0ZJVY0:BTY01gMgL0MgMg0820P00206=SH`0406][J`1mOGd0OGem079bLPX0oooo000:0?ooo`04
07IfMP1@D500D51@07alO080NWYj00D0MWIf07inOP22PX80PX:203De=@0203Hf=P0507=cL`1kNg/0
Ng]k07YjNP2<S8`00P2;Rh/01@0X:2P0DE5A055AD@2LW9`0Vi^K0080Z:RX00@0[:b/09BDU02DU9@0
?Shn0P1_Kfl01@2IVIT0W9bL09bLW02LW9`0TI6A0080MgMg00D0:2PX09FEU@2ZZZX0ZZZZ0:f][@02
0:RXZ0050:j^[P1LG5`0:b/[02/[:`2=SHd00P2DU9@01@2?Shl0RXZ:08Z:RP2:RXX0ATI600808R8R
00D0@d=305YJFP1JFUX0GEeM07=cL`0208>3P`0403dm?@0e=CD0=CDe06YZJP80IFEU00D0LG5a071`
L01_Kfl0Kfm_030`<00202h^;P0506YZJP1iNGT0MgMg07MgM`1_Kfl00P1TI6@01@0_;bl0KFe]06e]
K@22PX80MGEe0080PH6100D0U9BD05QHF01HF5P030`<07YjNP0209FEU@0509:BTP2<S8`0S8b<09jN
WP1eMGD00P0e=CD0102ZZZX0[jn_0:n_[`2][Jd20:BTY00509jNWP0W9bL0MWIf07IfMP2][Jd00P2_
[jl01@2c/k<0_Kfm0;Jf]P2f][H0;Rh^0080YJFU00D0^k^k0;Vi^@2i^KT0^k^k0;Ng]`0205IFEP05
09fMW@2h^;P0^;Rh0;Vi^@2f][H00P2b/[801@24Q8@0LG5a075aL@2YZJT0]KFe0080][Jf00@0];Bd
0:RXZ02XZ:P0=CDe0P2YZJT00`2_[jl0Z:RX0:NWY`020:NWY`80@D5100<0K6a/0:VYZ@2a/K400P2a
/K420;Bd]0050:6QX@0O7al07alO0820P01gMgL00P1QHF40101[Jf/0K6a/06a/K010@40A0?ooo`04
07UiN@2CTi<0Ti>C08N7Q`80EEEE00D0V9RH0:FUY@2UYJD0_;bl09^KV`020:b/[00508:2PP1iNGT0
NGUi09FEU@23Ph<00P1dM7@0101aLG40N7Qh07QhN02a/K4208V9R@0507alO027QhL0Kfm_06m_K`1T
I6@00P1HF5P01@1TI6@0PX:208:2PP2`/;00Vi^K0080U9BD00@0[Zj^08b<S02<S8`0SHf=0P26QXH0
1@27QhL0V9RH0<?3``33`l<0WIfM0080WinO00D0Jf][07=cL`2/[:`0[:b/0<?3``020<;2`P050:ZZ
ZP2JVYX0VYZJ0861P@1hN7P00P26QXH0102NWYh0CDe=04e=C@1WIfL20:JVYP050:f][@2^[Zh0MgMg
07MgM`2VYZH00P2TY:@01@39bLT0fm_K09FEU@2EUID0WIfM0080Shn?00D0Zj^[0820P020P800RXZ:
07YjNP0208b<S00408>3P`2IVIT0VIVI08F5Q@80XZ:R00D0/k>c0:n_[`1jNWX0NWYj06ATI0020:2P
X0050;:b/P37alL0dm?C0=?Cd`0b<S800P2_[jl01@3Vi^H0_Kfm0;fm_@1lO7`0GEeM0080OWin00@0
V9RH0;Ng]`2g]kL0_;bl0P2_[jl01@1cLg<0VYZJ0861P@21PH40Shn?0080PH6100D0SHf=07emO@1m
OGd0a<C40820P00207emO@0502d];@1XJ6P0J6QX05mOG`1ADE400P23Ph<0101TI6@0Ng]k07]kN`1m
OGd208Z:RP0508>3P`1iNGT0RHV908V9R@1iNGT00P23Ph<309JFUP0508f=S@2ZZZX0Ogmo07moO`2?
Shl00P2GUiL01@2YZJT0Y:BT07MgM`1gMgL0P8200080Hf=S00@0Jf][07emO@1mOGd0LW9b2P3oool0
00X0oooo00@0Ti>C05ADE01DE5@0Zj^[0P2`/;001@2[Zj/0/;2`0;6a/@2a/K40GEeM0080L71`00D0
]KFe0;Ng]`2g]kL0^;Rh0;bl_0020;fm_@0503Hf=P1RHV80HV9R0:j^[P2c/k<00P2i^KT30;Ng]`05
04M7A`23Ph<0Ph>30;Fe]@2c/k<00P2_[jl01@2`/;00Ph>308>3P`0P8200VIVI0080XJ6Q00D0YjNW
0:JVYP2VYZH0Z:RX06EUI@020492@P040:BTY02[Zj/0Zj^[0:VYZ@80[Zj^00D0[:b/05UIF@0f=SH0
=SHf05YJFP0206MWI`0406][J`1^KVh0K6a/06a/K0<0=CDe0`1eMGD01@1gMgL0JFUY06=SH`1SHf<0
:2PX0080;Rh^00D0GUiN06YZJP1^KVh0KVi^06QXJ00206EUI@05028R8P1VIVH0IVIV07YjNP1bLW80
0P1aLG401@2<S8`0G5aL05aLG00=3@d0NWYj00<0W9bL0P2JVYX01@2DU9@0HV9R05IFEP1FEUH0[jn_
0080/K6a00D0Y:BT09FEU@2EUID0SHf=02HV9P0207EeM@050:VYZ@2XZ:P0Z:RX0;>c/`2k^k/00P2a
/K40100];Bd0/;2`0;2`/02l_;`20;Vi^@050;^k^`2i^KT0E5AD05ADE02IVIT00P2g]kL01@2j^[X0
^k^k0;Vi^@2i^KT0QHF50080LG5a00D0/;2`0;6a/@2/[:`0[:b/0:RXZ0020::RXP0503`l?02XZ:P0
Z:RX0:n_[`2ZZZX00`2TY:@20492@P0308>3P`2d];@0/;2`0080/;2`0P2c/k<01@2LW9`08R8R028R
8P27QhL0NWYj0080IfMW00@0O7al08J6QP26QXH0CDe=4@3oool0101mOGd0VIVI09VIV@2;Rh/205]K
F`050:2PX02IVIT0VIVI0:NWY`2FUYH00P2ZZZX01@24Q8@0KFe]06e]K@26QXH0QHF50080PH6100@0
MWIf06UYJ@1YJFT0[:b/0P2GUiL01@1nOWh0Ti>C06i^KP1^KVh0GEeM0080AdM700D0?Shn08B4Q024
Q8@0^;Rh09jNWP020:2PX0040;fm_@2>SXh0SXj>09>CT`80RHV900D0Ogmo0:>SX`33`l<0`l?309^K
V`0209bLW00507AdM01jNWX0YJFU0:FUY@3Hf=P00P3AdM401@2h^;P0UiNG09NGU`26QXH0O7al0080
OGem00@0Vi^K069RHP1RHV80J6QX0P2PX:00102c/k<0Vi^K07AdM01dM7@30:>SX`050=GEe@3Cdm<0
XJ6Q0:6QX@2YZJT00P27QhL01@2ZZZX0Shn?08n?S`27QhL0QXJ60080QHF500@0Ogmo09JFUP2FUYH0
Ogmo0P2CTi<01@2d];@0/k>c08>3P`23Ph<0HV9R0080WYjN00D0ZZZZ0<;2`P32`/80`/;202`/;002
0;Fe]@050>[ZjP30`<00`<30079bLP1RHV800P1FEUH0102<S8`0XJ6Q0:6QX@2h^;P20;6a/@0508N7
Q`2YZJT0T92@092@T02PX:000P1iNGT01@2GUiL0K6a/06a/K02g]kL0QXJ60080Ogmo00D0>CTi07mo
O`1oOgl0LG5a069RHP0209>CT`0405mOG`1iNGT0NGUi06m_K`80SHf=00D0MgMg07YjNP1oOgl0Ogmo
08>3P`0208N7Q`0509jNWP2?Shl0Shn?092@T02QXJ400P2:RXX01@2KVi/0UYJF09JFUP2JVYX0V9RH
0080K6a/00@0MGEe05aLG01LG5`0KFe]0P1mOGd00`1`L700oooo0?ooo`080?ooo`002P3oool0102D
U9@0EUIF05IFEP2TY:@20:^[Z`050:ZZZP2TY:@0WinO09nOW`1?Cdl00P1iNGT0102i^KT0_;bl0;bl
_02i^KT30;Zj^P0504];B`1XJ6P0J6QX0:BTY02d];@00P2h^;P0102i^KT0]kNg0;Ng]`0o?cl208J6
QP050:n_[`2`/;00[:b/0:b/[02_[jl00P2HV9P00`0g=cL0Zj^[0;6a/@020;6a/@80/;2`00D0Zj^[
065QH@0f=SH0=SHf09VIV@020:ZZZP050:f][@2_[jl0[jn_0:j^[P1EEED00P0a<C401@1IFET0GUiN
05iNGP1KFe/0Bd];0080IfMW00@0?clo04I6AP16ATH0S8b<0P27QhL01@20P800LW9b06MWI`1WIfL0
:2PX0080;bl_00D0EeMG05QHF01QHF40HF5Q06=SH`02065QH@0502DU9@1dM7@0M7Ad08^;R`24Q8@0
0P1nOWh01@2BTY80GemO05mOG`0=3@d0Ti>C0080]KFe00D0[Zj^0:BTY02TY:@0XJ6Q06MWI`0206=S
H`030;6a/@2b/[80/[:b00<0/K6a00D0[Jf]03<c<`1oOgl0Ogmo0:VYZ@020:n_[`050;Bd]02j^[X0
]KFe0;Fe]@0d=3@00`2g]kL30;no_`040;Zj^P1DE5@0E5AD09^KV`80_Kfm00D0^[Zj0;Jf]P2e]KD0
]KFe08V9R@0207=cL`050:2PX02MWId0W9bL09bLW02BTY800P1oOgl01@0f=SH0YZJV0:JVYP2/[:`0
Zj^[0080Z:RX00@0Xj>S03lo?`0o?cl0P8200`2^[Zh0102`/;00[:b/0:b/[02VYZH203Lg=`050:^[
Z`2;Rh/0QhN708N7Q`2ATI400P27QhL00`1:BTX0oooo0?ooo`0?0?ooo`040861P@2HV9P0V9RH08^;
R`80Hf=S00D0WYjN09RHV02HV9P0^;Rh09ZJVP020:n_[`0508V9R@2ATI40TI6A096AT@1eMGD00P1^
KVh0101/K6`0F5QH05QHF02NWYh208B4Q00506UYJ@2?Shl0Kfm_06m_K`1BDU800P1XJ6P01@14A4@0
QXJ608J6QP2i^KT0UYJF0080Shn?00@0XZ:R08J6QP26QXH0N7Qh0P21PH401@23Ph<0][Jf0<C4a034
a<@0X:2P0080U9BD00D0K6a/07]kN`2SXj<0Xj>S0=3@d0020<;2`P050;6a/@28R8P0R8R80861P@29
RHT00P20P800102HV9P0M7Ad07AdM01cLg<209:BTP050:b/[02JVYX0NWYj07YjNP2QXJ400P2MWId0
1@3QhN40d];B0:f][@2][Jd0X:2P0080RHV900D0Xj>S09NGU`2GUiL0QHF509BDU00207UiN@0407Ad
M02@T900T92@08R8R080W9bL00D0/K6a0:>SX`1]KFd0KFe]06ATI00209RHV0050:FUY@34a<@0alO7
0<O7a`0V9RH00P2n_[h01@3WinL0_;bl0;bl_01bLW80MWIf0080H61P00@0WIfM0:JVYP2VYZH0_Kfm
0`2EUID0102/[:`0TY:B09:BTP2GUiL206IVIP0509jNWP1aLG40LG5a0::RXP2UYJD00P1YJFT01@0m
?Cd0KVi^06i^KP1HF5P0HV9R0080UYJF00@0EeMG075aL@1aLG40L71`0P26QXH01@1`L700P82006a/
K01/K6`0RHV90080PX:200D0^KVi09NGU`2GUiL0UYJF0:NWY`02092@T00509^KV`2DU9@0U9BD09ZJ
VP2BTY800P1dM7@0101aLG40IVIV06IVIP1YJFT207QhN00307]kN`3oool0oooo00P0oooo000:0?oo
o`0409BDU01FEUH0EUIF0:BTY080Zj^[00D0ZZZZ0:BTY02OWil0WinO04m?C`0207UiN@040;Vi^@2l
_;`0_;bl0;Vi^@<0^[Zj00D0Bd];06QXJ01XJ6P0Y:BT0;Bd]0020;Rh^0040;Vi^@2g]kL0]kNg03lo
?`80QXJ600D0[jn_0;2`/02/[:`0[:b/0:n_[`0209RHV00303Lg=`2[Zj/0/K6a0080/K6a0P2`/;00
1@2[Zj/0HF5Q03Hf=P0f=SH0VIVI0080ZZZZ00D0[Jf]0:n_[`2_[jl0[Zj^05EEE@02034a<@0505UI
F@1NGUh0GUiN05]KF`1;Bd/00P1WIfL0100o?cl0ATI604I6AP2<S8`208N7Q`050820P01bLW80IfMW
06MWI`0X:2P00P0_;bl01@1GEeL0F5QH065QH@1QHF40Hf=S0080HF5Q00D09BDU07AdM01dM7@0Rh^;
08B4Q00207inOP0509:BTP1OGel0GemO00d=3@2CTi<00P2e]KD01@2^[Zh0Y:BT0:BTY02QXJ40IfMW
0080Hf=S00<0/K6a0;:b/P2b/[800`2a/K401@2][Jd0<c<c07moO`1oOgl0ZJVY0080[jn_00D0];Bd
0;Zj^P2e]KD0]KFe03@d=0030;Ng]`<0_kno00@0^[Zj05ADE01DE5@0Vi^K0P2m_Kd01@2j^[X0][Jf
0;Fe]@2e]KD0RHV90080Lg=c00D0X:2P09fMW@2LW9`0W9bL09:BTP0207moO`0503Hf=P2VYZH0YZJV
0:b/[02[Zj/00P2XZ:P0102SXj<0?clo03lo?`20P8030:j^[P040;2`/02/[:`0[:b/0:JVYP80=cLg
00D0Zj^[08^;R`27QhL0QhN7096AT@0208N7Q`0304Y:BP3oool0oooo00l0oooo00@0PH6109RHV02H
V9P0Rh^;0P1SHf<01@2NWYh0V9RH09RHV02h^;P0VYZJ0080[jn_00D0RHV9096AT@2ATI40TI6A07Ee
M@0206i^KP0406a/K01HF5P0F5QH09jNWP80Q8B400D0JFUY08n?S`1_Kfl0Kfm_059BDP0206QXJ005
04A4A026QXH0QXJ60;Vi^@2FUYH00P2?Shl0102RXZ80QXJ608J6QP1hN7P20861P@0508>3P`2f][H0
a<C40<C4a02PX:000P2DU9@01@1/K6`0Ng]k0:>SX`2SXj<0d=3@0080`/;200D0/K6a08R8R028R8P0
PH6108V9R@020820P00409RHV01dM7@0M7Ad07=cL`80TY:B00D0[:b/09ZJVP1jNWX0NWYj0:6QX@02
09fMW@050>7Qh@3Bd]80[Jf]0:f][@2PX:000P29RHT01@2SXj<0UiNG09NGU`25QHD0U9BD0080NGUi
00@0M7Ad092@T02@T900R8R80P2LW9`01@2a/K40Xj>S06e]K@1]KFd0I6AT0080V9RH00D0YJFU0<C4
a037alL0alO702HV9P020;jn_P050>OWi`2l_;`0_;bl079bLP1fMWH00P1PH600102MWId0YZJV0:JV
YP2m_Kd309FEU@040:b/[02BTY80TY:B09NGU`80IVIV00D0WYjN075aL@1aLG40XZ:R0:FUY@0206UY
J@0503dm?@1^KVh0KVi^05QHF01RHV800P2FUYH0101GEeL0LG5a075aL@1`L70208J6QP05071`L020
P800K6a/06a/K029RHT00P22PX801@2i^KT0UiNG09NGU`2FUYH0YjNW0080T92@00D0Vi^K09BDU02D
U9@0VYZJ09:BTP0207AdM004075aL@1VIVH0IVIV06UYJ@80N7Qh00<0Ng]k0?ooo`3oool0203oool0
00X0oooo00@0U9BD05YJFP1JFUX0Y:BT0P2[Zj/20:NWY`80XZ:R00@0DU9B07MgM`1gMgL0[jn_0`2`
/;00102b/[80^;Rh0;Rh^01CDe<206ATI0050861P@2<S8`0WinO09nOW`2PX:000P2JVYX01@0a<C40
R8R808R8R02][Jd0ZZZZ0080YZJV00D0Zj^[08J6QP26QXH0>c/k0:FUY@020:NWY`<0[Jf]00D0Vi^K
05YJFP1HF5P0F5QH0:>SX`030:^[Z`<0/;2`00@0GUiN071`L01`L700IFEU0P1cLg<01@1DE5@0H61P
07=cL`1cLg<0FEUI0080Kfm_00D0Y:BT09VIV@2IVIT0QhN707emO@0206m_K`0402`/;00^;Rh0;Rh^
04=3@`<0BTY:00@0?Shn0451@@11@D4071`L0P2;Rh/01@2IVIT0T92@08f=S@2=SHd0UIFE0080EEEE
00D071`L09JFUP2ZZZX0ZZZZ0:^[Z`020:>SX`0509NGU`1_Kfl0De=C05=CD`2OWil00`2YZJT20:FU
Y@050:>SX`0h>3P0J6QX06QXJ01dM7@00P1cLg<01@2XZ:P0/k>c0;:b/P2b/[80=SHf0080QHF500D0
PX:208R8R028R8P0PH6107EeM@02038b<P0307IfMP23Ph<0Ph>30080Ogmo0P1]KFd01@11@D40DE5A
055AD@1]KFd0JFUY0080IVIV00@0G5aL05IFEP1FEUH0:2PX0P1JFUX2069RHP80Fe]K00D0ATI602<S
8`0S8b<0@d=3055AD@02059BDP0404U9B@13@d<0@d=3038b<P807QhN00D0?clo038b<P0e=CD0=CDe
034a<@02030`<00301/K6`3oool0oooo00l0oooo00@0QhN709FEU@2EUID0T92@0P1EEED01@2MWId0
VYZJ09ZJVP2d];@0U9BD0080]KFe00D0TY:B0:BTY02TY:@0T92@07MgM`0207alO00406a/K01bLW80
LW9b0:JVYP80PX:200D0QHF50:2PX025QHD0QHF5051@D00206a/K00504A4A028R8P0R8R80;Zj^P2<
S8`00P2HV9P0102TY:@0M7Ad07AdM01UIFD2079bLP0507=cL`2b/[80_kno0;no_`2CTi<00P2?Shl0
1@1`L700KFe]0:6QX@2QXJ40gMgM0080alO700D0/[:b08F5Q@25QHD0Shn?06i^KP0208B4Q00408j>
SP1iNGT0NGUi07AdM080TI6A00D0[:b/08R8R01cLg<0Lg=c096AT@0209>CT`050>?Sh`35aLD0/[:b
0;:b/P2YZJT00P2@T9001@2/[:`0SXj>08j>SP22PX80[Zj^0080PH6100@0Ogmo0:RXZ02XZ:P0Q8B4
0P2IVIT01@2e]KD0[Zj^08F5Q@25QHD0Ph>30080U9BD00D0alO70<[:bP2YZJT0ZJVY03@d=0020<C4
a0050>OWi`2ZZZX0ZZZZ07]kN`24Q8@00P1<C4`0102DU9@0X:2P0:2PX03AdM4209FEU@050:>SX`1o
Ogl0Y:BT0:BTY02GUiL00P1XJ6P01@28R8P0Ph>308>3P`24Q8@0^KVi0080De=C00D0>3Ph09JFUP2F
UYH0I6AT07=cL`02096AT@0405]KF`1aLG40LG5a05]KF`80LW9b00D0Hf=S06m_K`1SHf<0Hf=S08^;
R`0209VIV@050;Ng]`2TY:@0Y:BT08n?S`2a/K400P2/[:`01@2SXj<0][Jf0;Jf]P2HV9P0MgMg0080
P82000@0KVi^05eMG@1MGEd0Jf][0P20P8000`1^KVh0oooo0?ooo`080?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-7.08559, \
-2.21307, 0.704095, 0.704095}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-146.827, -2.21307, 0.704095, 0.704095}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute one-dimensional pdfs and corresponding error on 1d color \
channels\
\>", "Subsection"],

Cell[BoxData[{
    \(\(p1 = ComputePDF1D[d1];\)\), "\[IndentingNewLine]", 
    \(\(p2 = ComputePDF1D[d2];\)\)}], "Input"],

Cell[BoxData[
    \(\(pl1 = 
        ShowTwoGaussianPDFs1D[p1, \ p2, {0, 255}, x, FrameTicks \[Rule] None, 
          nS];\)\)], "Input"],

Cell[BoxData[
    \(\(error = ExpectedError1D[p1, p2, x];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show one-dimensional pdfs", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[pl1, yS, ImageSize \[Rule] 400]; error\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00373483 0.0143198 51.3464 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
1 0 0 r
.01 w
.02381 .01861 m
.04262 .02041 L
.06244 .023 L
.08255 .02657 L
.10458 .03188 L
.12415 .03811 L
.14509 .04672 L
.16639 .05793 L
.18653 .07114 L
.22495 .1045 L
.26581 .15283 L
.30517 .21139 L
.343 .27586 L
.38329 .34713 L
.42206 .41003 L
.44177 .43698 L
.46328 .46083 L
.47325 .46958 L
.48388 .47715 L
.48904 .48014 L
.4939 .48255 L
.4986 .48447 L
.50299 .48592 L
.50765 .48707 L
.51011 .48753 L
.51276 .48789 L
.51408 .48803 L
.51478 .48808 L
.51553 .48814 L
.51618 .48817 L
.51689 .48821 L
.51815 .48824 L
.51937 .48825 L
.52069 .48822 L
.52193 .48817 L
.52307 .4881 L
.52415 .48801 L
.5253 .48789 L
.52737 .48761 L
.52983 .48719 L
.53207 .4867 L
.53694 .48534 L
.54154 .48366 L
.55127 .47889 L
.56156 .47208 L
.58001 .4556 L
.59958 .43275 L
.6179 .40718 L
.65672 .3437 L
.698 .27064 L
Mistroke
.73776 .20356 L
.776 .14779 L
.8167 .10087 L
.85588 .06804 L
.87734 .05467 L
.89752 .04465 L
.91593 .03738 L
.93612 .03115 L
.95562 .02655 L
.97619 .02291 L
Mfstroke
0 0 1 r
.02381 .01472 m
.03279 .01483 L
.04262 .015 L
.05288 .01523 L
.06244 .0155 L
.0731 .01589 L
.0828 .01634 L
.094 .01702 L
.10458 .01783 L
.11428 .01876 L
.12455 .01999 L
.14299 .02298 L
.1524 .02498 L
.16253 .02757 L
.18083 .03366 L
.20196 .04353 L
.22205 .05648 L
.24186 .07347 L
.26025 .09364 L
.29938 .15289 L
.34096 .24128 L
.38102 .34568 L
.41958 .45026 L
.43912 .49873 L
.46058 .54416 L
.47043 .56141 L
.481 .57691 L
.49097 .58845 L
.50007 .59619 L
.50487 .59916 L
.50751 .60045 L
.50998 .60145 L
.51225 .60218 L
.51434 .60269 L
.51547 .6029 L
.51665 .60308 L
.51785 .60321 L
.51915 .60329 L
.51982 .60331 L
.52055 .60332 L
.52124 .60331 L
.52188 .60328 L
.52308 .60319 L
.52435 .60304 L
.52572 .60282 L
.527 .60255 L
.52991 .60173 L
.53243 .60078 L
.53473 .59972 L
.53991 .59667 L
Mistroke
.54469 .59306 L
.54978 .58838 L
.55893 .57789 L
.57967 .54497 L
.60112 .49975 L
.62131 .44975 L
.65991 .345 L
.70096 .2383 L
.7405 .15436 L
.77853 .09601 L
.79808 .07421 L
.81901 .05621 L
.84029 .04267 L
.86042 .03344 L
.8701 .03001 L
.88037 .02696 L
.8988 .02277 L
.9082 .02114 L
.91831 .01971 L
.9366 .01779 L
.94583 .01707 L
.9559 .01645 L
.96642 .01594 L
.97619 .01557 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003oool0002@
o`00007ooooo00000ol0003oooooooooo`3oooooohcooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooon<ooooo`7o00000Oooool00003o`000?oooooooooo0?ooooooS?ooool1o`00007ooooo
00000ol0003oooooooooo`3oooooohcooooo0Ol00001ooooo`0000?o0000ooooooooool01OoooolE
o`00ooooooooL_ooool1o`00007ooooo00000ol0003oooooooooo`05ooooobGo003ooooooom5oooo
oaH0003o1oooool1o`00007ooooo00000ol0003oooooooooo`05oooooboo003oooooooleoooooa`0
003o1oooool1o`00007ooooo00000ol0003oooooooooo`05oooooa?oo`008_l00?ooooooobOooooo
90000?l7ooooo`7o00000Oooool00003o`000?oooooooooo00Gooooo6Ooo000:oooooaKo003ooooo
oolPoooooa<0003o2_ooool:0?l000Oooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool@
ool0013ooooo3ol00?oooooooaWooooo4@000?l<ooooo`h0o`001oooool1o`00007ooooo00000ol0
003oooooooooo`0Hooooo`koo`004_ooool<o`00oooooooo4_ooool=0000oa7ooooo3P3o000:oooo
o`7o00000Oooool00003o`000?oooooooooo01cooooo3_oo000Booooo`[o003oooooool?ooooo`/0
003o4?ooool=0?l000oooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool>ool0017ooooo
2Ol00?ooooooo`_ooooo2@000?l@ooooo`d0o`004oooool1o`00007ooooo00000ol0003ooooooooo
o`0Tooooo`goo`004Oooool8o`00oooooooo1_ooool80000oa7ooooo3@3o000Fooooo`7o00000Ooo
ool00003o`000?oooooooooo02Sooooo2ooo000Aooooo`So003oooooool1ooooo`X0003o3oooool<
0?l001[ooooo0Ol00001ooooo`0000?o0000ooooooooool0;?ooool:ool0013ooooo2?l00?oloooo
o`X0003o3_ooool;0?l001kooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool9ool0013o
oooo2?l00?oiooooo`P0003o3oooool:0?l0027ooooo0Ol00001ooooo`0000?o0000ooooooooool0
<Oooool9ool0013ooooo1ol00?ofooooo`L0003o4?ooool90?l002Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0=?ooool8ool0013ooooo1ol00?ocooooo`H0003o4?ooool80?l002Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0=_ooool8ool0013ooooo1ol00?o_ooooo`L0003o3oooool8
0?l002Wooooo0Ol00001ooooo`0000?o0000ooooooooool0>?ooool8ool000oooooo1ol00?o]oooo
o`H0003o3oooool80?l002_ooooo0Ol00001ooooo`0000?o0000ooooooooool0>_ooool8ool000oo
oooo1ol00?oYooooo`L0003o3oooool70?l002gooooo0Ol00001ooooo`0000?o0000ooooooooool0
??ooool7ool0013ooooo1_l00?oWooooo`H0003o3oooool70?l002oooooo0Ol00001ooooo`0000?o
0000ooooooooool0?_ooool6ool0013ooooo1_l00?oUooooo`H0003o3_ooool70?l0037ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0@?ooool6ool0013ooooo1Ol00?oSooooo`D0003o3oooool7
0?l003;ooooo0Ol00001ooooo`0000?o0000ooooooooool0@Oooool6ool0013ooooo1Ol00?oQoooo
o`D0003o3_ooool70?l003Cooooo0Ol00001ooooo`0000?o0000ooooooooool0@_ooool6ool0013o
oooo1Ol00?oOooooo`D0003o3_ooool60?l003Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
A?ooool6ool000oooooo1Ol00?oMooooo`D0003o3_ooool60?l003Oooooo0Ol00001ooooo`0000?o
0000ooooooooool0AOooool6ool000oooooo1Ol00?oKooooo`D0003o3_ooool50?l003Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0A_ooool6ool000oooooo1Ol00?oJooooo`@0003o3Oooool6
0?l003[ooooo0Ol00001ooooo`0000?o0000ooooooooool0B?ooool5ool000oooooo1Ol00?oHoooo
o`@0003o3Oooool60?l003_ooooo0Ol00001ooooo`0000?o0000ooooooooool0BOooool5ool000oo
oooo1Ol00?oFooooo`D0003o3?ooool60?l003cooooo0Ol00001ooooo`0000?o0000ooooooooool0
B_ooool5ool000oooooo1Ol00?oDooooo`D0003o3?ooool50?l003kooooo0Ol00001ooooo`0000?o
0000ooooooooool0Boooool6ool000kooooo1Ol00?oBooooo`D0003o3?ooool50?l003oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0C?ooool6ool000kooooo1Ol00?o@ooooo`D0003o2oooool6
0?l0043ooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool6ool000kooooo1Ol00?o>oooo
o`D0003o2oooool60?l0047ooooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool5ool000ko
oooo1Ol00?o<ooooo`D0003o2oooool60?l004;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
D?ooool5ool000kooooo1?l00?o;ooooo`D0003o2oooool50?l004Cooooo0Ol00001ooooo`0000?o
0000ooooooooool0DOooool5ool000kooooo1?l00?o:ooooo`@0003o2oooool50?l004Gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0D_ooool5ool000gooooo1Ol00?o8ooooo`@0003o3?ooool4
0?l004Kooooo0Ol00001ooooo`0000?o0000ooooooooool0Doooool5ool000gooooo1?l00?o7oooo
o`D0003o2oooool40?l004Oooooo0Ol00001ooooo`0000?o0000ooooooooool0E?ooool4ool000ko
oooo1?l00?o6ooooo`@0003o2oooool50?l004Oooooo0Ol00001ooooo`0000?o0000ooooooooool0
EOooool4ool000gooooo1Ol00?o4ooooo`@0003o2oooool50?l004Sooooo0Ol00001ooooo`0000?o
0000ooooooooool0EOooool5ool000gooooo1?l00?o3ooooo`D0003o2_ooool50?l004Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0E_ooool5ool000gooooo1?l00?o2ooooo`@0003o2_ooool5
0?l004[ooooo0Ol00001ooooo`0000?o0000ooooooooool0Eoooool5ool000cooooo1Ol00?o0oooo
o`@0003o2oooool40?l004_ooooo0Ol00001ooooo`0000?o0000ooooooooool0F?ooool5ool000co
oooo1?l00?noooooo`D0003o2_ooool40?l004cooooo0Ol00001ooooo`0000?o0000ooooooooool0
FOooool5ool000cooooo1?l00?nnooooo`@0003o2_ooool50?l004cooooo0Ol00001ooooo`0000?o
0000ooooooooool0F_ooool5ool000_ooooo1Ol00?nlooooo`@0003o2_ooool50?l004gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Foooool5ool000_ooooo1?l00?nkooooo`D0003o2Oooool5
0?l004kooooo0Ol00001ooooo`0000?o0000ooooooooool0G?ooool5ool000_ooooo1?l00?njoooo
o`@0003o2Oooool50?l004oooooo0Ol00001ooooo`0000?o0000ooooooooool0GOooool4ool000_o
oooo1?l00?niooooo`@0003o2Oooool50?l0053ooooo0Ol00001ooooo`0000?o0000ooooooooool0
G_ooool4ool000_ooooo1?l00?nhooooo`@0003o2Oooool40?l0057ooooo0Ol00001ooooo`0000?o
0000ooooooooool0G_ooool5ool000[ooooo1Ol00?nfooooo`@0003o2Oooool40?l005;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Goooool5ool000[ooooo1?l00?neooooo`D0003o2?ooool5
0?l005;ooooo0Ol00001ooooo`0000?o0000ooooooooool0H?ooool5ool000[ooooo1?l00?ndoooo
o`@0003o2?ooool50?l005?ooooo0Ol00001ooooo`0000?o0000ooooooooool0HOooool5ool000Wo
oooo1Ol00?nbooooo`@0003o2?ooool50?l005Cooooo0Ol00001ooooo`0000?o0000ooooooooool0
H_ooool5ool000Wooooo1?l00?naooooo`D0003o1oooool50?l005Gooooo0Ol00001ooooo`0000?o
0000ooooooooool0Hoooool5ool000Wooooo1?l00?n`ooooo`@0003o2?ooool40?l005Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0I?ooool5ool000Sooooo1Ol00?n^ooooo`@0003o2?ooool4
0?l005Oooooo0Ol00001ooooo`0000?o0000ooooooooool0IOooool4ool000Wooooo1?l00?n]oooo
o`D0003o1oooool50?l005Oooooo0Ol00001ooooo`0000?o0000ooooooooool0I_ooool4ool000Wo
oooo1?l00?n/ooooo`@0003o2?ooool40?l005Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
I_ooool5ool000Sooooo1?l00?n[ooooo`@0003o2?ooool40?l005Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0Ioooool4ool000Wooooo1?l00?nZooooo`@0003o1oooool50?l005Wooooo0Ol0
0001ooooo`0000?o0000ooooooooool0J?ooool4ool000Sooooo1?l00?nYooooo`@0003o2?ooool4
0?l005[ooooo0Ol00001ooooo`0000?o0000ooooooooool0J?ooool4ool000Wooooo1?l00?nXoooo
o`@0003o1oooool40?l005_ooooo0Ol00001ooooo`0000?o0000ooooooooool0JOooool4ool000So
oooo1?l00?nWooooo`@0003o1oooool50?l005_ooooo0Ol00001ooooo`0000?o0000ooooooooool0
JOooool5ool000Sooooo1?l00?nVooooo`@0003o1oooool40?l005cooooo0Ol00001ooooo`0000?o
0000ooooooooool0J_ooool4ool000Sooooo1?l00?nUooooo`@0003o1oooool40?l005gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Joooool4ool000Sooooo1?l00?nTooooo`@0003o1_ooool5
0?l005gooooo0Ol00001ooooo`0000?o0000ooooooooool0Joooool5ool000Oooooo1?l00?nSoooo
o`@0003o1_ooool50?l005kooooo0Ol00001ooooo`0000?o0000ooooooooool0K?ooool4ool000So
oooo1?l00?nRooooo`@0003o1_ooool40?l005oooooo0Ol00001ooooo`0000?o0000ooooooooool0
KOooool4ool000Oooooo1?l00?nQooooo`@0003o1_ooool40?l0063ooooo0Ol00001ooooo`0000?o
0000ooooooooool0KOooool4ool000Sooooo1?l00?nPooooo`@0003o1Oooool50?l0063ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0K_ooool4ool000Oooooo1?l00?nOooooo`@0003o1_ooool4
0?l0067ooooo0Ol00001ooooo`0000?o0000ooooooooool0K_ooool5ool000Oooooo1?l00?nNoooo
o`@0003o1Oooool40?l006;ooooo0Ol00001ooooo`0000?o0000ooooooooool0Koooool4ool000Oo
oooo1?l00?nMooooo`@0003o1Oooool50?l006;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
L?ooool4ool000Oooooo1?l00?nLooooo`@0003o1Oooool40?l006?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0L?ooool5ool000Kooooo1?l00?nLooooo`<0003o1Oooool40?l006Cooooo0Ol0
0001ooooo`0000?o0000ooooooooool0LOooool4ool000Oooooo0ol00?nKooooo`@0003o1?ooool5
0?l006Cooooo0Ol00001ooooo`0000?o0000ooooooooool0L_ooool4ool000Kooooo1?l00?nJoooo
o`@0003o1?ooool40?l006Gooooo0Ol00001ooooo`0000?o0000ooooooooool0L_ooool4ool000Ko
oooo1?l00?nIooooo`@0003o1?ooool40?l006Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
Loooool4ool000Kooooo1?l00?nHooooo`@0003o1?ooool40?l006Kooooo0Ol00001ooooo`0000?o
0000ooooooooool0Loooool5ool000Gooooo1?l00?nGooooo`@0003o1?ooool40?l006Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool0M?ooool4ool000Kooooo1?l00?nFooooo`@0003o0oooool5
0?l006Oooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool4ool000Gooooo1?l00?nEoooo
o`@0003o1?ooool40?l006Sooooo0Ol00001ooooo`0000?o0000ooooooooool0MOooool5ool000Go
oooo1?l00?nDooooo`@0003o0oooool40?l006Wooooo0Ol00001ooooo`0000?o0000ooooooooool0
M_ooool4ool000Gooooo1?l00?nCooooo`@0003o1?ooool40?l006Wooooo0Ol00001ooooo`0000?o
0000ooooooooool0Moooool4ool000Gooooo1?l00?nBooooo`@0003o0oooool40?l006[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Moooool4ool000Gooooo1?l00?nAooooo`@0003o0oooool5
0?l006[ooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool4ool000Gooooo1?l00?n@oooo
o`@0003o0oooool40?l006_ooooo0Ol00001ooooo`0000?o0000ooooooooool0N?ooool5ool000Co
oooo1?l00?n?ooooo`@0003o0oooool40?l006cooooo0Ol00001ooooo`0000?o0000ooooooooool0
NOooool4ool000Gooooo1?l00?n>ooooo`@0003o0oooool40?l006cooooo0Ol00001ooooo`0000?o
0000ooooooooool0N_ooool4ool000Cooooo1?l00?n=ooooo`@0003o0oooool40?l006gooooo0Ol0
0001ooooo`0000?o0000ooooooooool0N_ooool4ool000Gooooo1?l00?n<ooooo`@0003o0_ooool5
0?l006gooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool4ool000Cooooo1?l00?n;oooo
o`@0003o0oooool40?l006kooooo0Ol00001ooooo`0000?o0000ooooooooool0Noooool5ool000Co
oooo1?l00?n:ooooo`@0003o0_ooool40?l006oooooo0Ol00001ooooo`0000?o0000ooooooooool0
O?ooool4ool000Cooooo1?l00?n:ooooo`<0003o0oooool40?l006oooooo0Ol00001ooooo`0000?o
0000ooooooooool0OOooool4ool000Cooooo0ol00?n9ooooo`@0003o0_ooool40?l0073ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0OOooool4ool000Cooooo1?l00?n8ooooo`@0003o00?ooooo
0?l0003o00000`3o001`ooooo`7o00000Oooool00003o`000?oooooooooo07kooooo1?oo0003oooo
o`Co003oR?ooool30000o`;ooooo103o001aooooo`7o00000Oooool00003o`000?oooooooooo07ko
oooo1Ooo0003ooooo`?o003oQoooool40000o`03ooooo`3o0000o`000080o`00L_ooool1o`00007o
oooo00000ol0003oooooooooo`1oooooo`Coo`000oooool4o`00ohKooooo10000?l00oooool0o`00
0?l000020?l007;ooooo0Ol00001ooooo`0000?o0000ooooooooool0P?ooool4ool000;ooooo1?l0
0?n5ooooo`@0003o00?ooooo0?l0003o00000P3o001cooooo`7o00000Oooool00003o`000?oooooo
oooo083ooooo1?oo0003ooooo`Co003oQ?ooool40000o`D0o`00Loooool1o`00007ooooo00000ol0
003oooooooooo`21ooooo`Coo`000_ooool4o`00ohCooooo0`000?l00oooool0o`000?l000020?l0
07Cooooo0Ol00001ooooo`0000?o0000ooooooooool0POooool5ool000;ooooo0ol00?n3ooooo`@0
003o103o001eooooo`7o00000Oooool00003o`000?oooooooooo08;ooooo1?oo0002ooooo`Co003o
P_ooool40000o`@0o`00MOooool1o`00007ooooo00000ol0003oooooooooo`23ooooo`Coo`0000?o
ooooo`00ool00?l00_l00?n2ooooo`<0003o00Coo`000?l0003o0000o`00M_ooool1o`00007ooooo
00000ol0003oooooooooo`23ooooo`Coo`000_ooool4o`00oh3ooooo10000?l4ool007Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Q?ooool4ool00003ooooool00?oo003o00;o003oP?ooool4
0000o`?oo`00Moooool1o`00007ooooo00000ol0003oooooooooo`24ooooo`Coo`000_ooool3o`00
ogoooooo10000?l4ool007Oooooo0Ol00001ooooo`0000?o0000ooooooooool0QOooool4ool00003
ooooool00?oo003o00;o003oO_ooool40000o`?oo`00N?ooool1o`00007ooooo00000ol0003ooooo
ooooo`25ooooo`Goo`001?l00?mnooooo`<0003o0ooo001iooooo`7o00000Oooool00003o`000?oo
oooooooo08Kooooo1?oo00001?oooooo003oo`00ool00?mmooooo`@0003o0ooo001iooooo`7o0000
0Oooool00003o`000?oooooooooo08Oooooo1?oo0004o`00ogcooooo10000?l2ool007[ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0Qoooool4ool000Co003oO?ooool30000o`?oo`00N_ooool1
o`00007ooooo00000ol0003oooooooooo`28ooooo`Coo`001?l00?mjooooo`@0003o0_oo001koooo
o`7o00000Oooool00003o`000?oooooooooo08Sooooo1?oo0004o`00og[ooooo10000?l00ooo003o
ooooooooo`1jooooo`7o00000Oooool00003o`000?oooooooooo08Wooooo1?oo0003o`00og[ooooo
0`000?l2ool007cooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool3ool000Co003oN?oo
ool40000o`03ool00?oooooooooo07_ooooo0Ol00001ooooo`0000?o0000ooooooooool0R_ooool3
ool000Co003oN?ooool40000o`03ool00?oooooooooo07_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool0Roooool3ool000?o003oMoooool40000o`03ool00?oooooooooo07cooooo0Ol00001oooo
o`0000?o0000ooooooooool0Roooool3ool000Co003oM_ooool40000ogoooooo0Ol00001ooooo`00
00?o0000ooooooooool0S?ooool2ool000Co003oM_ooool30000o`03ool00?oooooooooo07gooooo
0Ol00001ooooo`0000?o0000ooooooooool0SOooool2ool000Co003oM?ooool40000oh3ooooo0Ol0
0001ooooo`0000?o0000ooooooooool0SOooool2ool000Co003oM?ooool40000oh3ooooo0Ol00001
ooooo`0000?o0000ooooooooool0S_ooool2ool000?o003oLoooool01?oo0000003o0000o`000?n1
ooooo`7o00000Oooool00003o`000?oooooooooo08kooooo0_oo0004o`00og7ooooo00?oo`000000
o`000?l00P000?n1ooooo`7o00000Oooool00003o`000?oooooooooo08oooooo00?oo`00o`00ool0
0?l00_l00?maooooo`03ool000000?l0003o0080003oPOooool1o`00007ooooo00000ol0003ooooo
ooooo`2?ooooo`;oo`001?l00?m_ooooo`03ool000000?l0003o0080003oP_ooool1o`00007ooooo
00000ol0003oooooooooo`2@ooooo`03ool00?l00?oo003o00;o003oKoooool00ooo0000003o0000
o`020000oh;ooooo0Ol00001ooooo`0000?o0000ooooooooool0TOooool01?oo003o003oo`00ool0
0?m^ooooo`;oo`000`000?n3ooooo`7o00000Oooool00003o`000?oooooooooo097ooooo00?oo`00
o`00ool00?l00_l00?m/ooooo`;oo`0010000?n3ooooo`7o00000Oooool00003o`000?oooooooooo
09;ooooo1?l00?m/ooooo`;oo`0010000?n3ooooo`7o00000Oooool00003o`000?oooooooooo09;o
oooo00Goo`00o`00ool00?oo003oool0001Zooooo`?oo`000`000?n4ooooo`7o00000Oooool00003
o`000?oooooooooo09?ooooo1?l00?mZooooo`;oo`0010000?n4ooooo`7o00000Oooool00003o`00
0?oooooooooo09?ooooo1?l00?l00ooo003oooooooooo`1Vooooo`?oo`0010000?n4ooooo`7o0000
0Oooool00003o`000?oooooooooo09Cooooo1?l00?mXooooo`;oo`0010000?n5ooooo`7o00000Ooo
ool00003o`000?oooooooooo09Cooooo1?l00?l00ooo003oooooooooo`1Tooooo`?oo`0010000?n5
ooooo`7o00000Oooool00003o`000?oooooooooo09Gooooo0ol00?l2ool006Cooooo1?oo00030000
ohKooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4o`00o`03ool00?oooooooooo06;o
oooo0ooo00040000ohKooooo0Ol00001ooooo`0000?o0000ooooooooool0UOooool4o`00o`;oo`00
H_ooool4ool000@0003oQ_ooool1o`00007ooooo00000ol0003oooooooooo`2Fooooo`?o003o0_oo
001Rooooo`?oo`0010000?n7ooooo`7o00000Oooool00003o`000?oooooooooo09Kooooo1?l00?l2
ool0063ooooo1?oo00040000ohOooooo0Ol00001ooooo`0000?o0000ooooooooool0U_ooool4o`00
o`?oo`00Goooool4ool000<0003oR?ooool1o`00007ooooo00000ol0003oooooooooo`2Gooooo`?o
003o0ooo001Nooooo`Coo`0010000?n8ooooo`7o00000Oooool00003o`000?oooooooooo09Oooooo
1?l00?l3ool005cooooo1Ooo00040000ohSooooo0Ol00001ooooo`0000?o0000ooooooooool0Uooo
ool4o`00o`?oo`00G?ooool4ool00004ooooo`000?l0003o0000ohWooooo0Ol00001ooooo`0000?o
0000ooooooooool0V?ooool3o`00o`Coo`00F_ooool4ool00003ooooo`000?l0003o0080003oROoo
ool1o`00007ooooo00000ol0003oooooooooo`2Hooooo`Co003o1?oo001Iooooo`Coo`0000?ooooo
0000o`000?l00P000?n9ooooo`7o00000Oooool00003o`000?oooooooooo09Sooooo1?l00?l4ool0
05Sooooo1?oo00000oooool0003o0000o`020000oh[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0VOooool4o`00o`Coo`00E_ooool5ool00003ooooo`000?l0003o0080003oR_ooool1o`00007o
oooo00000ol0003oooooooooo`2Iooooo`Co003o1?oo001Fooooo`Coo`000_ooool30000oh_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0V_ooool3o`00o`03oooooooo003oo`0000;oo`00E?oo
ool4ool000;ooooo10000?n;ooooo`7o00000Oooool00003o`000?oooooooooo09[ooooo1?l00?l5
ool005?ooooo1?oo0002ooooo`@0003oRoooool1o`00007ooooo00000ol0003oooooooooo`2Joooo
o`Co003o00?oooooool00?oo00000_oo001Booooo`Coo`000_ooool40000ohcooooo0Ol00001oooo
o`0000?o0000ooooooooool0Voooool3o`00o`;ooooo1?oo001Aooooo`Coo`000_ooool40000ohco
oooo0Ol00001ooooo`0000?o0000ooooooooool0Voooool4o`00o`03oooooooo003oo`0000;oo`00
D?ooool4ool000?ooooo0`000?n=ooooo`7o00000Oooool00003o`000?oooooooooo09_ooooo1?l0
0?l2ooooo`Coo`00C_ooool5ool000;ooooo10000?n=ooooo`7o00000Oooool00003o`000?oooooo
oooo09cooooo0ol00?l2ooooo`Goo`00COooool4ool000?ooooo10000?n=ooooo`7o00000Oooool0
0003o`000?oooooooooo09cooooo1?l00?l2ooooo`Coo`00C?ooool4ool000?ooooo10000?n>oooo
o`7o00000Oooool00003o`000?oooooooooo09cooooo1?l00?l3ooooo`Coo`00Boooool4ool000?o
oooo10000?n>ooooo`7o00000Oooool00003o`000?oooooooooo09gooooo0ol00?l3ooooo`Coo`00
B_ooool4ool000Cooooo0`000?n?ooooo`7o00000Oooool00003o`000?oooooooooo09gooooo1?l0
0?l3ooooo`Coo`00B?ooool5ool000?ooooo10000?n?ooooo`7o00000Oooool00003o`000?oooooo
oooo09gooooo1?l00?l3ooooo`Goo`00Aoooool4ool000Cooooo10000?n?ooooo`7o00000Oooool0
0003o`000?oooooooooo09kooooo1?l00?l3ooooo`Goo`00AOooool4ool000Cooooo10000?n@oooo
o`7o00000Oooool00003o`000?oooooooooo09kooooo1?l00?l4ooooo`Goo`00@oooool5ool000Co
oooo10000?n@ooooo`7o00000Oooool00003o`000?oooooooooo09oooooo0ol00?l5ooooo`Coo`00
@_ooool5ool000Gooooo0`000?nAooooo`7o00000Oooool00003o`000?oooooooooo09oooooo1?l0
0?l5ooooo`Coo`00@Oooool4ool000Gooooo10000?nAooooo`7o00000Oooool00003o`000?oooooo
oooo09oooooo1?l00?l5ooooo`Goo`00?oooool4ool000Kooooo10000?nAooooo`7o00000Oooool0
0003o`000?oooooooooo0:3ooooo0ol00?l6ooooo`Goo`00?Oooool5ool000Kooooo0`000?nBoooo
o`7o00000Oooool00003o`000?oooooooooo0:3ooooo1?l00?l6ooooo`Goo`00??ooool4ool000Ko
oooo10000?nBooooo`7o00000Oooool00003o`000?oooooooooo0:3ooooo1?l00?l7ooooo`Coo`00
>oooool4ool000Oooooo10000?nBooooo`7o00000Oooool00003o`000?oooooooooo0:7ooooo0ol0
0?l8ooooo`Coo`00>Oooool5ool000Kooooo10000?nCooooo`7o00000Oooool00003o`000?oooooo
oooo0:7ooooo1?l00?l7ooooo`Goo`00=oooool5ool000Oooooo10000?nCooooo`7o00000Oooool0
0003o`000?oooooooooo0:7ooooo1?l00?l8ooooo`Goo`00=Oooool5ool000Sooooo0`000?nDoooo
o`7o00000Oooool00003o`000?oooooooooo0:;ooooo0ol00?l9ooooo`Goo`00<oooool5ool000So
oooo10000?nDooooo`7o00000Oooool00003o`000?oooooooooo0:;ooooo1?l00?l9ooooo`Coo`00
<_ooool5ool000Wooooo10000?nDooooo`7o00000Oooool00003o`000?oooooooooo0:;ooooo1?l0
0?l:ooooo`Coo`00<?ooool5ool000Wooooo10000?nEooooo`7o00000Oooool00003o`000?oooooo
oooo0:?ooooo1?l00?l9ooooo`Goo`00;Oooool6ool000[ooooo10000?nEooooo`7o00000Oooool0
0003o`000?oooooooooo0:?ooooo1?l00?l:ooooo`Goo`00:oooool6ool000_ooooo0`000?nFoooo
o`7o00000Oooool00003o`000?oooooooooo0:Cooooo0ol00?l;ooooo`Koo`00:?ooool6ool000_o
oooo10000?nFooooo`7o00000Oooool00003o`000?oooooooooo0:Cooooo1?l00?l;ooooo`Koo`00
9_ooool5ool000gooooo10000?nFooooo`7o00000Oooool00003o`000?oooooooooo0:Cooooo1?l0
0?l<ooooo`Koo`009?ooool5ool000gooooo10000?nGooooo`7o00000Oooool00003o`000?oooooo
oooo0:Gooooo1?l00?l=ooooo`Koo`008Oooool5ool000kooooo10000?nGooooo`7o00000Oooool0
0003o`000?oooooooooo0:Gooooo1?l00?l>ooooo`Ooo`007Oooool6ool000oooooo0`000?nHoooo
o`7o00000Oooool00003o`000?oooooooooo0:Kooooo1?l00?l>ooooo`Ooo`006_ooool7ool000oo
oooo10000?nHooooo`7o00000Oooool00003o`000?oooooooooo0:Kooooo1?l00?l@ooooo`Koo`00
6?ooool7ool0013ooooo10000?nHooooo`7o00000Oooool00003o`000?oooooooooo0:Oooooo0ol0
0?lBooooo`Goo`005Oooool7ool0017ooooo10000?nIooooo`7o00000Oooool00003o`000?oooooo
oooo0:Oooooo1?l00?lBooooo`Koo`004_ooool6ool001?ooooo10000?nIooooo`7o00000Oooool0
0003o`000?oooooooooo0:Oooooo1?l00?lCooooo`Soo`003Oooool7ool001Cooooo0`000?nJoooo
o`7o00000Oooool00003o`000?oooooooooo0:Sooooo1?l00?lCooooo`[oo`001_ooool9ool001Go
oooo10000?nJooooo`7o00000Oooool00003o`000?oooooooooo0:Sooooo1?l00?lEoooooaKoo`00
5_ooool40000oi[ooooo0Ol00001ooooo`0000?o0000ooooooooool0ZOooool4o`00oaOooooo4Ooo
000Gooooo`@0003oVoooool1o`00007ooooo00000ol0003oooooooooo`2Yooooo`Co003o6_ooool:
ool001_ooooo10000?nKooooo`7o00000Oooool00003o`000?oooooooooo0:[ooooo0ol00?looooo
o`<0003oW?ooool1o`00007ooooo00000ol0003oooooooooo`2Zooooo`Co003o?Oooool40000oico
oooo0Ol00001ooooo`0000?o0000ooooooooool0Z_ooool4o`00ocgooooo10000?nLooooo`7o0000
0Oooool00003o`000?oooooooooo0:_ooooo1?l00?lkooooo`@0003oWOooool1o`00007ooooo0000
0ol0003oooooooooo`2[ooooo`Co003o>oooool40000oigooooo0Ol00001ooooo`0000?o0000oooo
ooooool0[?ooool4o`00ocWooooo10000?nNooooo`7o00000Oooool00003o`000?oooooooooo0:co
oooo1?l00?liooooo`@0003oW_ooool1o`00007ooooo00000ol0003oooooooooo`2]ooooo`?o003o
>Oooool30000oioooooo0Ol00001ooooo`0000?o0000ooooooooool0[Oooool4o`00ocOooooo1000
0?nOooooo`7o00000Oooool00003o`000?oooooooooo0:gooooo1?l00?lgooooo`@0003oWoooool1
o`00007ooooo00000ol0003oooooooooo`2^ooooo`Co003o=Oooool40000oj3ooooo0Ol00001oooo
o`0000?o0000ooooooooool0[_ooool4o`00ocGooooo10000?nPooooo`7o00000Oooool00003o`00
0?oooooooooo0:oooooo1?l00?lcooooo`@0003oXOooool1o`00007ooooo00000ol0003ooooooooo
o`2_ooooo`Co003o<oooool40000oj7ooooo0Ol00001ooooo`0000?o0000ooooooooool0/?ooool4
o`00oc7ooooo10000?nRooooo`7o00000Oooool00003o`000?oooooooooo0;3ooooo1?l00?laoooo
o`@0003oX_ooool1o`00007ooooo00000ol0003oooooooooo`2aooooo`?o003o<Oooool30000oj?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0/Oooool4o`00oboooooo10000?nSooooo`7o0000
0Oooool00003o`000?oooooooooo0;7ooooo1?l00?l_ooooo`@0003oXoooool1o`00007ooooo0000
0ol0003oooooooooo`2booooo`Co003o;Oooool40000ojCooooo0Ol00001ooooo`0000?o0000oooo
ooooool0/_ooool4o`00obgooooo10000?nTooooo`7o00000Oooool00003o`000?oooooooooo0;?o
oooo1?l00?l[ooooo`@0003oYOooool1o`00007ooooo00000ol0003oooooooooo`2cooooo`Co003o
:_ooool50000ojGooooo0Ol00001ooooo`0000?o0000ooooooooool0]?ooool4o`00obWooooo1000
0?nVooooo`7o00000Oooool00003o`000?oooooooooo0;Cooooo1Ol00?lWooooo`@0003oYoooool1
o`00007ooooo00000ol0003oooooooooo`2eooooo`Co003o9_ooool50000ojOooooo0Ol00001oooo
o`0000?o0000ooooooooool0]_ooool4o`00obGooooo10000?nXooooo`7o00000Oooool00003o`00
0?oooooooooo0;Kooooo1?l00?lTooooo`@0003oZOooool1o`00007ooooo00000ol0003ooooooooo
o`2gooooo`Co003o8oooool40000ojWooooo0Ol00001ooooo`0000?o0000ooooooooool0]oooool5
o`00ob7ooooo10000?nZooooo`7o00000Oooool00003o`000?oooooooooo0;Sooooo1?l00?lPoooo
o`D0003oZ_ooool1o`00007ooooo00000ol0003oooooooooo`2iooooo`Co003o7oooool40000oj_o
oooo0Ol00001ooooo`0000?o0000ooooooooool0^Oooool5o`00oagooooo10000?n/ooooo`7o0000
0Oooool00003o`000?oooooooooo0;[ooooo1?l00?lLooooo`D0003o[?ooool1o`00007ooooo0000
0ol0003oooooooooo`2kooooo`Co003o6oooool40000ojgooooo0Ol00001ooooo`0000?o0000oooo
ooooool0^oooool5o`00oaWooooo10000?n^ooooo`7o00000Oooool00003o`000?oooooooooo0;co
oooo1Ol00?lGooooo`D0003o[_ooool1o`00007ooooo00000ol0003oooooooooo`2mooooo`Ko003o
5?ooool50000ojoooooo0Ol00001ooooo`0000?o0000ooooooooool0__ooool6o`00oa;ooooo1@00
0?n`ooooo`7o00000Oooool00003o`000?oooooooooo0;oooooo1_l00?l?ooooo`H0003o/Oooool1
o`00007ooooo00000ol0003oooooooooo`31ooooo`Ko003o2oooool00ol00?l0003o0000o`040000
ok;ooooo0Ol00001ooooo`0000?o0000ooooooooool0`_ooool7o`00o`Sooooo0_l00?l50000ok?o
oooo0Ol00001ooooo`0000?o0000ooooooooool0`oooool9o`00o`03ooooool00?oo003o00Co003o
0`000?neooooo`7o00000Oooool00003o`000?oooooooooo0<Gooooo3ol00?ngooooo`7o00000Ooo
ool00003o`000?oooooooooo0<Oooooo3?l00?nhooooo`7o00000Oooool00003o`000?oooooooooo
0<[ooooo1_l00?nkooooo`7o00000Oooool00003o`000?oooooooooo0?ooooooS?ooool1o`00007o
oooo00000ol0003oooooooooo`3oooooohcooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oon<ooooo`7o00000Oooool00?oo0000T?l00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {-6.59737, -0.000278946, \
0.672167, 4.8892*^-5}}],

Cell[BoxData[
    \(89.48806951142826`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify training and test image", "Subsection"],

Cell[BoxData[{
    \(\(c1 = 
        ClassifyImage1D[brick, 
          ComputeDecisionBoundary1D[p1, p2, x]];\)\), "\[IndentingNewLine]", 
    \(\(c2 = 
        ClassifyImage1D[wood, 
          ComputeDecisionBoundary1D[p1, p2, x]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification results", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{brick, c1}, {wood, c2}}], \ 
        ImageSize \[Rule] 400, \ GraphicsSpacing \[Rule]  .02];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.495285 0.495285 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
78668C7A9191A8888F6B458C5E8B6D57667A7A4D647256946997954C904D717172D7845F
4675ACCAA4B2A5A9A49B7D656B7CA6BF719B95A5CD8FB1BFAAC34C89638B837574A0A97A
7654ABC2ACA47851E1A07C756360A9B799518A938E8992C4774B423E7583575B777E7082
5C675F7B938D8E9A9BBC7B9CA66D465C5F8D8275
71547B77868EAF7A887653885B7964536C868C505A65518069948D488D58818678D08D68
4B77AAC0A6AEA0A5A0987B687176A2C277959FA9BF78B9B3A2C35582618F87726EB0B17A
8A6998BFB6A5755BDC9C6A76746EB8B9A3618A9D939094D47F4943386A745C585E61658F
6B695B829594A29C9CB191A4AF7A50665F74817A
7F6081708579875D74663D745D8860564D63985D565D487E739B8E4B955C77767ED18369
5371A1B39CA59AAD98998E7D8585B1CA71AB95A2BB7CBDAEA5CF5C805F7E7B686CA4A276
7E7187C6BEAC735FD1945D837977A2B9AD6A7FA18B8494D783444431648D65655D677076
53675E788E7F9696A5BDA2BEA96B4F7A6F6E7E72
6B567D707E75A469856143815E75515958727B5D49573D7A72998C4A8A5C787677C08B6B
4A7CA7ACABB89E9D91997D6E6A6F98BD71A08F9DB976B9A19ABF5D8267867D5F5CA2BB71
868581C3B5AE6976BC8C5E78766D95C8A963819368707FBD783B3E3058806D7079856B7E
5A5F4C6F7F77A8657E756A7F996E575A73827A7F
7767878194889D5F88764F8B62966475647C8367505F427E6B908B4B825F777177D09A68
477AB4BFBFB79C9D9798867C767098AC6C9995A8B47EC4ACA3C55A80637F7C6C6F9FBD93
88848DBCB2A76671BB8A5B85897AA0C6A1706C9461827DAE713634314E70736C89817997
6A755B786E79A27AA4A280A7B47B5C526B7B8976
80608A748F81B26B8D7955886591515D6484926E5D59547D6A9C9A4A8356716781CC7D5D
417CAEBCBCBA9A959AA2847C6F789AB8799E74BEB983B9ACA8C05682607D8C545D95C27E
807484C3BBC8797EC583578B867AA7C9B76F8A9A71968DB97D423C3C53797C6E8B8B8295
6969787B9795B287AC90889DAF7C505F64798368
866E8B6C7F7BAC5E706A43806A803E5E54778F6A6159477965949E4A885B8D7C7FD2845A
376494A69BAC9FA09DA6837571719AA66AA277B1C57FB7AB9FB54E755D74786F659DB27B
7F8599BDA9B37577BA92638C8175A2C79F53B6A96D8F92CA7F45373D4A737A7088907C97
69776B737F7A96729A89879FB18651676981667C
7F5C80677E8DC169936641855D8E4A5F686A837E5E5845676F9E99498360867580D48C64
4186C1CAAFB69A989F93777464749AB05E8E91A9C97FAEB09BB24B76607C7F5D6B92BF7C
838397C1B1C0777EB887608E6A759CC7A86380A063828BC27C443E42426E7C6F6C856F8D
656763797483BB86BF818BA5AE7E516970868E7D
8976986D827FB064736C4A8D6295505D788C936D544E5265739E9F50825F7C6F7CC67E5B
3E77B6C6B5B7A4989B8474747591AEC6779A99A8CA82B7BEA1B14E84678283636392BF86
7E7680AEC1B17A7BA9885D84717091BCB0738095667A8AC4814A3A3F3F697276868A708C
675C5F839891C57CBB7380928F6751526D959479
7B5E8053878CBA7782724F935F9C4D5A7B7E92755C4C47636F949C457F4D718183D6875F
426B97A8A3A28B9191808167698398A5789898AABF7AABB49EBF37716383856963A8C49A
79807FB0B6B590849B8B7A89787196CAAD647B975F5A77C57E4638393D5A4F5B5E7C6091
646965768069966DB773929D92774B4C657A8783
7D648F5F866F7A757265437F609A4C568E858E644B464A5F78999D4989596D736DBB7B54
3D6B9CACA3B09B9D978E8A6B707B99C2809B90A9C083A69C98BA39654E67655E6594AA8D
5C6F7EA7C2B4847D9A9E8D7B7B638DB6A4588F84755B70B5934C3A384F636C6A76726072
5D4E5C7C8886AB92CF6D878C7C67505D5F657070
82718F5276738E68716745785B8E49529682997060575D64718C9B3F854F67747ACB8B6B
467DB8BBADAA8B9796868562717A9BCB779987A6BB9BABB39EC341807189835D5BB7B589
5D6188ACD3AF87778C9BA370605A73B19D639BA0795876C3A9554939577B70796F746E70
7963776E7F9A9B90AB487895968166596A698B84
8472955F7D778A5266624774679048488B7A926855484B4F7D968C437B5162687DC6915D
3E72B8B6A4B39B90988D7B5466758BA6638789B4C1A0AAC0AEB03F725C64736D4E9BB8A8
745F8CB7C8B18C7291B19B6A6F6398C7A07894968D6773C6B05B463C4D776C7A5A685F67
8A6368738B98878CAC508EA0977E7C6C646B7B72
766A835884819261715B436B697D484890718A716349615E829A954C7F546B6387BB8758
3467A6A6A3ADA1969A8B6B536D7994BB648F88B3C7A69BB8B9C44F917B7479736C8BAF9F
7E588DAEDABC70659BBE996B7173A8C2AB79A8A69A6978B2B6523E4A4681736F67736562
796A5563727E8D9EA94A888D8477625A7567877A
647E8446887E9158705A4F73707A464D877881714F47474B7A8F915682506E5E8BCB9E4D
2D64A2A7AEB39592A1957970717B95AB559587BACAAD93B1B6BA468A8488828D6D8ECC8C
6F4D7F84DAAD735D9FC581696170A1A8A185A19E855B6AA3B2603E4C415F747F70695D77
5F67636E899088939D5299A4A18C7A5F5E686765
6A747746937D815D726D5C9072794541907978855949455C73949C557E48606193CBA55C
3B739DB5AEAE939BA6A47E5C7C7D97AD609480B7C8B296B2B5B749807B7B7E8B6D7AC58A
7A589596BAA07A658FC77A6E6D6F9DADA9858E8D7F7690A5AE5F3E5444606C76727A6677
726E5C75859E8C819B5486B29D8D8B6A757A6E68
7A8A894B7F7A7C547B716A877D7758465A6570794246525A658F92558F5D786089CDA765
4B7EAEB1BBB18F7F8C7F644F78849EB76EB07BB8D0B398AFD0C15E86877E78946D74D886
715494AECDB8898E97CA6471776795B5A28286A383618BA3A1654D454164736F6F787880
77605B626A9A867C904971909880745A7C78626A
7C8E87458185764C6C687276837E6D4D7371866A48413D616D927C427753735D88CBA16E
5185A0BAB4A68D989A7F70586F7C9AA561A080B6C4BD9BB1D5C15F8B8E797F997862D396
7A53819CBAB4807E95D86B847C74939ABE9488897B7391A697714F3C4F69616B6D7B7876
6F7A646A5C938492B25B8CA69F756C5A74687169
7FA386467F8B7456816B78797E7A644B88828E6F4B4E566D6E978D3F894B73538DCBA356
416AA6B0AEA1848593826A546C7291AC5C9885BFC9D0A1A5C3BB6584917874967D56E38B
77556C93C5AF948CA0D6666D736E809DC0908BA982607FA19B744A334B635B7D6686787D
6B71677778AD949DAE5E7EA0A2897057645C7266
7AA97D5077816E54735A6B6C776E57467B8594715B4B546B769682557D426E4986BE8060
3C74B6B7A7AE9983998D755F6F7AA0B564A087BBC7CC9697B9B97C7994757B95714FD08D
7A6A7F9BBCB58B8A89D95F757F7275A7BF8D759C755B699BA2724533395E64785B786C7F
64745E6D729B90A1AE5E97A8AC84746B626B7972
74A17643788C73618668787378694D457F8196736A5550606C9F956E90577E5187CD915B
3A67A6A897AB9B759589735969778BB9649E90BEC8C5888BBBB07771906F70926C5FD075
7E6F728CB5C4878A79D36C9C7B78759CC8956F877C5A63A6A765433836617D696A6B787F
6469597476939193A5559CAEAF8A705870686A5C
6B936C406C6C685471697A6B716A47437180976756564C5F6C9A8661935F825F7FC39B5D
4069959DB1C0A29BA088775A6C7A92C468A992B8C7CC898AB6AE7A798E767A975F60D27D
8872719EB0C5999276CA5897777374A6CA95699C775F78B1B5724A434167755B6368778E
786A52787398AE8FAC68829B99735E67696C806F
71A7774A7C856D58805C76737E63545E7376896D5C44475E74A08B558C567E668CC78A59
2B5EB8B7B2BA9B97A588795A747E9DC964AA96BFCDD48F8FC4B581938A7A7D9D666BCF82
8887719A9FB8927C69D969886A808FBBD6996AA87A6F7EA2B56D3E393F5D705A5B626E85
87594D6D7999A38EAF84829AAC7C654D59597356
6298643B6E78695D84597B6C7B604653758C8F7066584E6174998A59995481707ABF854A
5259A9B3BEB98A9E998B7558677C8FAF549484AEC7D99393C5AF868973726D92606ED790
8F946EB6A3C9AC8170DF6F927B787CA7D09E67A589767A97BC74414040608A5E4E5D6766
754F547E7995B695B08085A0AC85625A626B8471
62A9754C7A85765C887C97787064435F697F857358463C5D728F92809E5A7F8282D18763
7464B4B8C0B8A6889F8B7559708793C45E9785ABBBC98484BBBD82867C7B7D9B5768CBA8
899067B8ACC69A6C52D97F90879395BFDCA175B48D8A739ACA6C45433C5684535D686D5B
7F4455706E8AAA80B78D8898AE7D545C6A577A62
679D7244707B654D6B68796C735B3C5C7C877E6D5058567C6F988B7A944E706676B16C5D
5960A09B9B9696879189755A818097C761A085B7BFD38C91BEB784786F7B798C5C6EC39F
768F5EB5AABC996050D67387838690ACD3A26DB39C987894CF68403A384C7D546859695D
6E4F616A79A9AC9BC09791B1AF7E5F606954765A
6AA96C426D7565597F69808C8A5A395E63818D795E584979609FA483AA5D776E6EBE8D5B
5973BAC4B6AEB29CA48B745670839EC35EAC8DBAC0D69389B1B38D767077768C6373C099
6F8760BEACAEAF714BD67393757B719DCE8862BDA496798CC76C413737536F65686F6875
7951685C889BAB94B79F5B7C987B6B5E625B9160
6EA47146768373667F759284805B426D5B727A6D4C434D5E5082897D95566F7980D59064
5C70A8B5BBAFAA9B938777637A7581AF57A69AB8C2CA9185B6B3986F736E848A7475C5A3
627152BBAEC6B37A47E08190828C8BB4DD936BB8A993717DC4764839394062785F83777C
6A5E6A6380AAAB85B7BC748FA3845B6B6A678A77
5F967B4C7376735E7F768B65664E387169878B745A55407255928E7E9C6476757BCC8B60
516EA9B2B2A2A690917E6E596C7993BD5D8C8FB5BDC58C79ABA197786D7793847788B89F
577250C3BAB6A96A40D07A9E81776897C79073BEB7826E8ACA8F4F3E2E4471956880767D
765978607FAAA691BEB67096A69168765F748D79
678C7B467581745777697F787B434560537E816853504477609A8E879D7678767DCD9762
6272A3B9B8B3B09AA58C7E617E8390BC619587B6BCC28F92AFB89071727892817D91BCA6
627A59C2B3A9AC7C4BDB768F758482ADC67F679EB2746986CC955A4716378A8E5E7D7E8C
806264508EB3A29FA09F6486888A5B7B74819976
5D8B7A517785805E807C7971764F4D5955799061535A447B639EA7849570737673C47F5A
737395B8C1B69D798E807556727C9CB76D9481B2BDC3907DAFAF8E757081927E7B8EB794
59775AC6C29AAD8148DE88897B8389AED5977DACB8677C71B3995C4133246F69536C7385
7956684260949B8881B8738C9B895170697B9D84
65A3744A7D9E875E7C7D94827C5C4765677B704B5D4E426F5896A78C9E7673796ABD7956
605A7AA0A7A6957A8C7D7257787F9ABA73988BA2BAC59578B8BA9D7E647793848592BAA0
5C745EBEC7B7AB8444D7958C847B7EABD59084A1BE67745BC0994C433534686152587F73
725A67516A89969594AD69A098985759485D8A78
5E936B4876896F56817D94817B6258686889A5525055497A52979D94A373757C72CC845E
71697FA9ACB18A8192838153739699BF8E9E95A2C4C29C74A9AEAD797194A67E8886BDAB
636A78A2B0A4967642C986907E706E9DC58487ACAE6E825DA19C51434A51636C64475C56
73506C4C5F7BA18599AB648E7F9C59725D7D8E6F
649E6A446C9E8F759A8BA28E79535B67688F9D5F5D5A467D55A09587AC7776816FD39C64
796B9DC5C0C78F8C8E77785B86919FB29CA58E99D5B4A98EAEA38F7D7B94AA869891BFBB
79597CABC4AB9A6F3ECA858981706EA5C787819B8B744C569A894B33344B63616A4A685D
6C57664E59959C928B9A63A690A55B66677E8574
659172466C7E88859B808F826D5B4F694F758C595951436353968B83A3715F736DCA836A
865D88BDB7C1929B908181558081AB9A98938E81DAB5BA8FC2C29E7F737991819A8EB7B6
725694AABDBFA07943D68D8D7D6E6C9EB88C8B9E87936A5D9297543E3B5B5A59664C675C
84455D604578A08F859C6FA985AA555F74878D8D
69AE7C558AA593779C7E917F80513F5C5E7378545D4F417F629F8D90A36B65605DC58D66
7B5A73ADB5B1848E8A7E8B708F88B0A396909979DFA9AC85C1BE977773849681AE87AFBD
765891ACB9A37A6B3FCF978A89787EB8CD9596A485A4628DA29E4E37354F564A6B596253
8943505E4F768C998A887CB79992625C798A8473
549365447AA0A084958D7D7E6F57465C5E8084486559478276A28D95AD7A6F6A5DBC8575
7B618EB9C5BB899D908390787A77A799996C915ED8A5A696BBBD816C617B8575A06D99A0
72518CADBBA68F6B43D2967F806F72AEC39F9AB28FB574929E8C463533434C466E6A544F
83484A74567A928A8A8B88AA9D9E5E557C6A696B
66A079517FA39F806C7E66736D5F3A555E6D6A466B5944685A9393A0A37C6F6C5AB3897C
775A7BAEC6B5898D908291857B80B29699839B6CC6A59FA4ADC19179768780738661A1A9
6B5080ADB79A956A4FDD7E7B6D656DB5B89A80A792AA5C8F9E894D3929414A3E7D6C5B6C
75674F78797B99998E84919A9A9F585D6453746F
67917266819B9C897B956D7D77664D5A837A622F52464987548994A3A47B6E7065C08782
6F5B84B8D6AE6D80897894806D65A273AB99A75FD49E94A19AB692777E8D8E828C739EA7
766D779DA696936151DA9073796678C0B5A587A380AB63838F9060342B3F413459665A67
6A60516270789D95887B8BA5A689706A7B5C7365
749A7C5D7A909EA16B7F667673604E648F97833970725F7D558F8D9BA27A6B725AC28881
7F5D93BBDAAB534D806D8476666EB183AD96A159DFA29BB897C98D7C81938B9FA280A7BB
79817F9EA9AF8B5850D288636E5671CBBEA9839B8DB5637E9FA476433E5352427B4C4F6B
66564544507FA19789918E7F957E6E7286637177
658D764A83A09D80787A5674735B333B687F74335A6352765A9194ABB491746C4DBA8B80
845A8FB4D19E7A5C7D7185935F6CB18BA695AB5CCB9492A689BC8773667973889777A5A9
72817C90A0B9967162E1936487677FD5C0B57D9E81B7727D9DA7773B3A464E407A5D5057
505B635B506BA2899DA59298BC897D6C77517F71
678574468EA19B8F967D66857F61454F6B916B315F6A658A619799A6B08B6B6C57C3887C
8C4F90BCD69F7261847A878A5B6AA283A1939967DFA39CB39BCE8E847B8679A3875EA3B4
7D7E7789A0AC806E62DC986F7B6A77C5BBB9819F7FA97F83A2B17E4440606A5A8A746364
5A625E4741809BA28FA37E84B1809669775C7A7B
688D7E4D9499968A948077858262535F6E937735596E65755C8D95A6B19674705DCA8986
8F4999C3D3A16D668D85868855689B8C8F84A06ED9B297BE96BE777471816DA07F5BA4AD
7987757FA5AD7C7355E08C6C746986C3BAB76FA9809A857B98B976403C576E5F6E6D685E
576B62594663919E96B6778FAC80825D74728875
7A8D84529C9C8E8C8F706D686A5D4E5C6A906D3254595476569695A5A69370755CC69C7D
764694B5D49374689F927C9C666FB1ADB0A2AF76D8AAA0C0ABC77976736F4E7C7265A6B6
90867486A7BD6F8058DE9977826E8FCDC3B36DA1899A787D87BC67382E455C605B6A5A59
585F6E72567998A58DBF6F87AA7E6F544C5A5C5B
71887C528E9B74828E6C70795B594A557698853C6659537B589E9DACAB976E725BCFA98B
7B60788DC39A775E8D95779F5E66CBBAAB9CB17DE0B1AAACABBF7C856E7B4F987872B7C3
A4967E8BA9BA607D5CDD996F756573B9B3AF7E838096838C87C159372B475B59514E5455
4A766980646990AE9BD65F8CA5946C47516F5F54
7D9B8D4F929E808A9F797B7E5C5D395983926A31453B566D4D998FB2A38F595B56C99685
736F87AAD3908F709CA185A2635DB6A7988B9B7BD0B1949694AF8478757C519C7584B6C1
8D9A6B7F98D6648263E193697B6B6BB0BDA95E8C919A7C8B85BF4D3A2A485D6E4E5A5052
5A726C92546991A172C1569FA18E7E5A60857468
6D877F4787997B88937165735561665E667954214455556B608E88AAA69B6A625ABA977D
85587EA9D3839075A4A28A8D6052A8A69B90A189D7CB989998B28C886574527B6A8FA4CE
8380638294CF537B66DC8F6B715C6CB5BBB4689A9E98818E8FCA54412A4C75645B69665A
4C7B5877485277868DCB609B999D5E5764846A5B
7F91804B8A997D7B896168775A605B6770746132545B577C448C88ABA89B68655FC09A8A
6D438CA9CC8A966FA6A28B8B6D6AA7AB9A92A897C9CA8E9396AC958C6E745699788FA3C4
7580597B9DDC587F70E299717A5B67A5A9AE658E92958E9899CC57432C3B655757716659
596960882E5D858D6EA6698EA0A15B5D6D7C5462
7394864C91A38683947264705E5C6163849A7F3C6E705C894BA094ABA89E5E6462BB9787
67437CABCA90966CA1B08484656BAFBCA3A4AA96C7D9978FA6A8A78F73765E9B7C978FB1
6F875E6F91D24E675BB67D65746076C7CFBC71868891827C85C15440273A5A5357736369
5C5F51833A3A627E81B67D8398AB4F5C6A6B5363
6388774F929B84898D64686E565162607A8D713A6761537F5C8295B4A99D65696EC6B598
735B7D90C2A48E6B969F7B6D6864A9BEA5A2AF94C6D08E8FAEA1A5826B6E5899729289C9
6A7C5571BCBA58766FE2956A6B5F6EB4CCAE64999C8C857B74A94A3C2635494C48716861
5F6B6675416BAA9CA8C59D98AAC07E7B7B6F677E
5E897A518FA28D898D7069747B4D4E56707069416263648A9DA392B49F95746067C1AB89
5D607699B3928B709491715372749FAF9395B097BFC1838AA998AF7D867B609C719686CB
867E557998DD6C6E69E3937273637BC6CDAF747B928C928186BD5E3B332D4E5F59738C81
70695C68374CA18884B99E658A926A80A76A6378
5C927A487B8F7789805E4968665A5B6E91967D42616C5F96A7B399B9AC935E526CBDB191
6963778CAB998E6F9F867C54876F99A293A1BA869EBF9894B1B5C0808D81699E89AD81D4
87825878A3E1736464DF91776D6871BCCBAE768A917A736C82A16439323050594E6A8478
7A6E7060523F919F8CB0A061889A825D5D37546C
609973447C81757D7E7955706049546689887A41675B628A97AC99BAA598745474C0C196
686D8598CEAD9B81B9897D6192809AB1B0B5CB8EA6B69483ABACC2768884779483986EDC
7E6D63899FDA655168E098767A7D7ACCD7BB909CA58F9A829EC97B3A342F4C5957767579
67656E4B5B568B9788BBA5658798886A634C6B86
5D7D6F45869C8588907A557C7353466A8767583A5E6D61828AA182B2A19B73497ACDC48A
616C8299C3AC9A71B686876E9579A0B2C4B7C48EA9CCA593B4AAC5607D8587A68F906CD9
8464617AA1D45D5358C7926D787C76C3CBA27CA8A8919788A4C574393C3151545A756573
6758504B5E4C5F987995867479849870705D718A
6D907C4B8D8E85899B6A486B7A6244708A827341536B7186A49E87B09C926D4B77C6B982
62657F9EC5AD9E6CAC7B81729E728AA5BCA1A7819CBEB1ACB8BCCA5787968A8C828672DD
7B637387ACDC614864D7865D746F79BDC7A16C89A07E8D8798C2793B3D364A6165806C77
70755A616A5B669C7A987363718F926668706C8A
708D7D4991B29D9597684C72675D4A6C7A8571475D6F5E7490A991B7A18C6D577BCEBF85
61799CB0D8C0AB75B072837A9B6C7DA0B58B8F8686ABA3A4A8B0B7568E8B878479826BDB
7B5D7994ABDC80576DE69A68816E83C5D0BA7A8EA88D8E8CA3C38043473F55687E887983
718260647662537D91AA846F908091716D728188
72917F52849F8B9191774E7D7B52405D6F6D5F5163695D687F8E85A4936F5C4863B3A46D
566F94ADD7BEA574B1778A818E5F8DAAB783A19697BFA7B1A5BBB55F8E849B819E7B6DDB
8C5B7B929CDF8C566CE4A26C866A80C0C2A16F85A28C8E97AAC3855246464F618C857A77
6C8C66657C676E828A97837C96967F676C928CA6
78A67E5E81A6939682644A6D6F5D435D817173585D6962788DA293ADA482623E60BEBA72
5B72829CC2AC8E629B647B7A7A5A82A4BA8C9999A1B1AABE92BFB267A58AA27B9E886DDB
9B5F8EA68ED47F4F5ADB99657D6A7BBEC8AB6C8AA5898C98A4C38644414D4A527E8E706C
6A8A676B61519B9F9B91716C9B936D56587E83A1
6D907662819B8F8D7B6B557A7057536C93807250516A677984B19FA39178674B65ABA466
52638A93C9CA966CAD6E908571657EA2C183998B9DBAA7CE88ADB463996B7576946A65D6
AD5E928C8BDE955957E3AA66886E86C4CEAC6A87A184889194AB77453E4B44486E7B5A52
617E767364576C7B9C968C82A5A67E706F80807C
6A8573508A9D8C90756C4D827857505E71706D4257796A7788B8A6A39E745F576BB5B872
5D5C7687BDB88C539368818660627A9FB47B90889DA995AF73A197547463837989695FD1
9E538E7B87CC955150E1BC738C6578B3C1B372949E878191B1C8764142464957737B685E
65786B777463A392AAA08184A0A6615E72847E91
748184487A7C6F757F62426C7256437C876B62425275595C81AE998C8671605571B0B779
68758A8BD5D3973E997F8D8F5B6A7DA5A984A390A0AFA1C57AB2AE6C91758495A57A78D2
C159898BA1D998444FD5A86F8463729DB19E6381957B788AB7C57E4646424D5F828B7A61
627C7160616B9795B1A48291AAB2806C65675B76
7C85955EA3AA88919A8256888B553D6394755B5A505E616485C0A29DA778665C639E9462
6373858DCCC99140A88F9A8F586E79ABAE99ABA8A2B6A39C72BBBC758D7579899A7875CB
B65B778D8FD4AD3A54DE9277896982BCC5AA61868C897A84BCC987494E48505B8072795C
63876F70664D70829EA68687AAB6868C7D655E63
6F6F7F4CA9B0968E977253686C593E71988A6F594C52656176C3A089AF7D6D7171A1A887
6F7B8487C6C08947A590A28B54727EA9B39AA99AA1C0978666A2A759746E7E83897578CC
B77B8A90A5D1BF645DE1B37B866B88CAC2B56E909D9B8E91BD9DA4545252555D85876E63
5B88717D64406C777E8A8480909D87A167696A6F
7077954EA1A1938FA3676781644A32576E755E4E4F51775986C8A688AB7974718EABB585
7E8491AECEC39448AC969F944A7D90B2BDA5B98994C1AF9F79BFC07B9A718298AD6F7CBC
B69B74829BC4BA5A60DF9E8089647DC4BCBA76989CA58992B7949B5D52494B566674616B
4F7F755F744D6D7BAE98807DA2967BA568586758
7C8698519AA997929B6C5F807B5B44667F8273706E5A906886BB9D84B578787D8EB4C990
8D8089A1CCBC934499898F89497C8BB8CEA4BD9390CAAB9F72A8BD7C916D7D7D9C828AC1
AD9B6D7FA6BA9B415BC39882766179BEB6BC729B90A86A98A4A08A6959514B5174847B78
568A87697850868A8B959474757A8395525B665A
6E7385448A908087906C57727057497281856F7B6D55835A84B79888AE7B7B817BB2BC83
837D9099D4BB934093889282467B82A3B9A9B09589C9B5A176BFC47F866F78869B7889BB
A38A6979A4B8B9516AE28586756671B8ABB2768C74AB5F97AC9C91564E4E4955667A706A
568B91686652728A999AA77C757E928045646965
7680864A8E988A969879557C674A416C9188716F504F5D5468A28F82A4737F7B67ACA76E
7F72809EDAC5925DA9989D87487A8AABC3B7AD9180C4B3A286C2C489897C8088988377AE
B491777CBBB8B05263DD928A7D797EBBB4A56E7D7491598C936797574B41445B707C6E5A
577F85595D4F6D8060709C647D768D7741647273
7183864F899588949673538B74514166777B6D7249505F607DB8A783BA80878F70AAB076
9361719AD3B69A62A19A96874B7C91ADACAFA3888AC8AE9A8BC7CC8F88766F91A59289C2
B0918073B8B4AE3B65DC9995906F7CC0BFA577888382779BA66E924E523D46607987745C
69878E595C4A56758685A96F767D946341635564
627C7D4A859A9199947A517C6E604C708D8F7A7949576B6885B39D7FBF8B8F82709FA47E
86636CA2D5A9A1679AA780834E8195A5A6BCA2926CBAA78E83BFBF8178746A83928E88BD
A9827B66BAAEA9266DDE84A2826970ACA69A857F8C796C83A071995E6C404F6186947561
628CA1545D56687E7D83AF757A838975566E655E
5D817F53728C8E8E7E6A527D5F66577B889776805C5F76678AB1A18ABB828181709CB589
9C4E6198C8A9987097B182705272978FA4BAAA967DBC928F8DB7C78C747D6E929B9C86BE
AC82745FB7A3A82E6DD47B97816D73BEBFA7B9758E8A8180838B986C5E3D505A688B8667
5D877E5855475C6F798BAE7C7F797979485F5F6D
658C84527CA09D938879617C6A665A6B73834F805A4D6F638AAD9A86B083907F658FAC96
9F566DAFCDB7B57798C07F775084A39BB3C4B0AC82C99E8D92AABC886073697D91998FC2
A67D7A58BAA7B03E6DDC85A1777171BCB9A7B28B9E84677E7496946A4935485A56797E6A
5D8B8D6568706F7C9493B387838386694D61576B
708D7C5170929299927D5F786565505443826B7842386A5D73A69D7BAD8382816D94B18B
96515490A696956E7EA27879538BB695AFC5A49C87D8AD8F90B9D0A37B7F768C7A8F83A8
9673654DAAB6AE436FDA7997756C6BB3BFA493928A956F966FA6977A593B514F616D6C6F
648A84716D6284818C87B6808386946B42576054
708893597F9696978D7D5B6E706F768369806C69453672738CA78C70B4948888638FB391
985F63ACB5B3A58486B1807A50849F8DBEC5A29781D8AD989BBACFAA7677669381998EAE
A6906E56C6BAAF4C6BDE76AB896C68A9C6AB7C908D92729368A9A3734A374C4B7965686B
66827A696C72838DA3A8BA8C8578937E565A5B59
7793985A889EA19C8E75596B686269756C826673584A66788EAA897DA37B67775A87B897
946462BFB5C4A7937FA7857E558DA99AC3C9A49980E0AFA1A0BFD29A758565A5839B8DB0
A98E674EB7ABA5535AD06EA4806E61B2CDB2838A8C86799C629FA2734838474880527F78
68886E6E637598968B96C0938C8FA3946B6A6565
7287804D889A978F92775E6B706B63795C807D512D51647786B28C86AF957C6F4A6FA28E
825D50ADAEBA9BA2789B84745B80AC97BDC1A99B7DDDAB989EB7D09F6D6B569782998BB1
AD9C654BBEB7C1535CD46AA27C656399AF9E8782809579A460A99B6C4035484E765B7175
79967579626980717B799A747F79968D71777A79
6B917D4E839A9A9A917760746E52706D5D807545564F547B89AD8F72ACA0866D5795BA92
836746A7A0BDA5A37A968A79728BA1A5B4B8A9927CD4ABA3A6C8D59C78805C9287A188B7
A4935F50BDB7CF556FDD75B07C616FABC29D78859A9875A05DAA9F623C385953575B666D
5C8E6D51737D99958B88B6838586887E565E5D73
77A07D4F919CA0958D7F5F6B763D6B7B69A185777C5D518387B28F6CAEA289725486B59F
757549C1B9C6ACA47D9897767589A5ACBCCEB0937CD7B09F9DB8D6917280619987987CB2
9A8D5B55C5A7A63E60D774B97F7876B3D7A57391A4977A995CAF996E3A4467745B6A747A
749575787A709F85A69EB0747586787374784B71
66997B4B939C9EA18C7B5B7679847977629D7B6770574E7C86B38F7AA9A58B736CA5CCA7
7E7B4BBCAEC7A7948580736A7582929C9FBEA28B7EDAB4989EB0DA9477856692859C7FA4
A2A9645FC9B7C64670D776A67C8071AFD0A67CB0AF9F86AD5CB4A1833940636D4B6D6773
829873757D81A1A59E88AE6D70837F8C746D5E82
6DA27B4B95999EA48B79577F7C777066589578566B5B557A7AB28D87A8A58C645899CEA2
7A7946BCA4BEA67F7B7E8078888D8C92B6CCB59978DBB697A0B8D4A2768C679687A18BAF
A791595EABAEBB3A7AD479B577847EADDBA57A92A89984935ABE957E353D5C5B4C53505A
5D77566B626C899E9F88B4888787728F70736A7D
6A967C458A9496A6837459847775636D588C7E4A5C574C7571AB868FA2A083665789C79D
6A6242B49BB9A6867C7E735F807C9489B5BDB1947FD2B8AAA1BACCA1797E619590A091AB
A68A536197A9D13F91E47EAC7A837AADDAA49A8BAE8F979073C4A27F3D4063625F676875
6D7E60656B5C79968B8AB5847E9280857477778F
7E9C804D8E9699B1937E598B7B7F7887619270626E524A7986AE8A88A099735B578EB597
667547A79BC2AC89778586758F739B93B3C1B39B81E0B2A19DBACEA8758E68998CA191AA
AE975C77A6AECF2F8DDD7EB2887F76B4D59E9696B0939E8B7ABFA0744B436062546E7575
717671726C8597A3898AB196869E7988756B6B8A
769781559EA3A2B797775A93797272775C8F845A7769608F90B1989BB8AC846A5FA6D0B1
6E7853A093C4B1806B7888769B658B91A3A4A78E78D5B3A5ABBAD8AD7B86609686A48B9C
9974526F8FA6C0329CD87CA0837A73B9D19A7AB1ADA2A98F81BE8963513D615F4B617D6B
69736E6B737F8AA1969BB28E7E825E656C5A5C7F
7296825798969FAD756F59826B77797376A08253636D5C7178A68991ABA1766B5FABDDBB
687F509F9AC0BC826E81917E9A678B9BB5C2B39E73B8A59BAAA7CA80727C69A68EA78CAA
A38B597BA6B1C43BA7E082977D7262A2BC8B68AF9D8F8E8CA0C88A5B5A4368645971847B
74666C6B7F869EA87993B38F7F8B8B594C64666A
5A83794A979B9D969C7654797C66554753896D425A4C56737E9C8997ABA873715C94D199
637D579598C4B07A6D718B7398739099B5C3B49D77D5C0B2B9A9DA8E7F886A9B86A87EA6
8F825C7E9BAEC73FA3E08D9B7F7F6FB2CB9E625C87A18E8D8FAA8453473C525856687975
6A765D6A6C6B828C567B9B74708983626F727A9C
6C957E528E90978D8C6F4A6C73686A67538C72416547496A79A27E9BA194646C608EC096
5E80589CA7C6A977716D8271916E8794B4A2A39165D2BB92AFB0E0948982609D85A87DAC
A48C5E7F9A9ED246A3E3818E7E8573AFCFA5555D869989969CBB794044365C5A626C7970
696D685C6C77928B627C98837E766F636E6F6C78
67A67954919CA0A28277577A7558726470886D3E6A565478729B7F99ACA36566618BC390
557A537D93C8AF7D6F637F728870878CB5AB98956DDAC59C7A8CA67C77725B9082A67DB2
AD866485ADAECA40A5E48493838674B8D0A75F919092839B8BB86C4D4437575A62677C69
6D755162575B779A6A8B91615E67675260636E80
6DAD7D67879FA7B48E7C60898F5B77667D906F485740476570B48894A6985C64779BD09D
5C80588795CBB582795F7C7484647E8AAA98868F71D6BFB365C797667678639280A386AA
AE8B6287A7AFBD40A2E28F997D7F7BB0D0A664B092A48FA890A86B593A4B8265707B8273
846D707376779ABF7EAEB18C75857E745166727A
7ABE866584A0A6AE8E7F5C839366635B727A41447D5C586767AB8790B4A4626971A8CCA3
6A8D5C81A2CAB27C785F83728564788EB3A38CA375C4B7B58BBCB388827952807D9986A5
AD825E889AB1C142A1D8858E767F74AFD19F69B68C9780A882AF71503C5C846293707579
7E8372766D7E99B16193A9908E967F847D6F7A84
80B6886B8C9EB2AD8C836686927169486F893A567D676D7470AF938F9D9B685A6398C395
5E7F6488B2D2B28A83638E7D916F607EA197788577D1C3B8959DB28C867D5E8B7C9378A4
B1865A87A1AFCA4AA7DB7584808573B1CA946BBE8E9684AC80BA6E4F3C5E83688A667069
7D796B6F5E73829A5B949E79677C697C69637882
6EAA846381A8C0A48C896C839E8272547F9D605A8B7C707D78B5979DB2BB71616EA4D2A4
65817D95B4DDB58F87618E75846C76A6B4A7939782C8B9B69597AD837C785C9692986FA1
AD785D868EB3C84BA7E37396858F83B8D99A69B6978C81A766BB693E2C517B58916E6E68
64716B5157688BAB688F876A5D646D69665D8A8B
6E836E5D8099A6867D7A6A8E9878484D6C8169558E69677671B8909DB1B2675F71A4C8AB
5F826F88BCDCB181815D8C8284655F8CA29B848F7FC6B6BA99A69A847172559998987EA4
AA715B869EAEC449ADDF649478757FAEC38566AC9587848E5BC16E442D5379538A716969
74746D65708C9CA27995917861706A557151728C
82B0847E9AB2A58A7789735C7B7E6E85838758498A67597767A38095AEA05E597599D8B6
5B858B88C0D7B686895D8A817D7663A2A0B097948ECDC0C2A4B0A08A7276509D90A584A0
A66E627B98ADD74898E27CA0888881B2D5A4689E86908D8C53B1815E3E54895C8F756159
6D7E7E54648691A383938C776F896B585C516F6E
86B389929BABA9968D8C7C7B8787635E749F654F8367516F6FA594A2A89B614D719ECA95
5580878BBAD4A6828E638189868A6EC4A4B49E9687C1C5B99BB1A68D858058A0909D849F
A57263829D98D04689DA8F9784767BA7D1A399A8A29DA29D558F8F5538507850856F6C52
647E7469537C779D809F936E749D73615B56686F
7DA9829D94A6AB9385787C7783837B7B7793604D865B59676DAB97A4AA9E655C7FA6D2A3
608D967DA6CA886C866582806F775EC0A2A594917BC9C4BCA8BEA88B7E7E5D968BA98BA3
B77D6C8DB5AFD5469FD4AC99897087A4CC8C86A1A6879C9E62AA8C57395D7E5481666054
66846F5E537C81B880A591768AA076656A667484
87AC838B81A8A2998C82776B8590888184966F557971617C6DAD9CA1B0A3666989AFD69E
5D838784AAD7B3879D5A847B7D8570C2B0B198A088CAC3A399BE9E8E807E679296A189A8
AA6F677EA5B4CE44A4E3AF928C86A2BCD39781ADAC7F9A9F62AA944830608A5F78665951
6A86848B568095AD759A797C8CBC905C4E60717D
7AA585868AAFAE958D8D72637A84737E87A9775289796A867FB8998AAAA0666468A2D099
5E898D89B1D3A7777547737A7864587DA09B9A9E88C6BCB089BE98888B7977909EA18CAE
B070687497B1CB4399E3B595898BA8BED59C83B2AD87A29E5BAB94603872A1878472704E
647370814B7283AD8DAD8F7F94AD955E665B6976
8AA68B829DACAF9E828A73617D8B70857A9B7B567F61607B6DB49485B1A86C68619AD7A7
6984848FB6D5AF7D845F9279956579B1B7B2959E87D0C4AB88B58B7C81757E8BA3A182BC
A4806A679DB7CA4B9EE4B1867080A7B2CE9D7EB0A67F94946FC2914F2C739C7B72757868
6F72778A4E7B9FA49EB98C92A6B498595F5D5F80
839379769AA6B39F8293826C7C89738C709970547A584D7378A68676A19A6E69659FDDB3
718985A0C1D7BB8F866392858B677CBCB4B4979D8FD5C6A88FC8988D9173828CA69980C4
B192656C9EABD34697E0A7776577A6B0D19369A9998C89958CC3853F297989736A685861
7385879459739E9F8AB08A95A6B1936272616070
7891836FA4A3A29A8C9C7B7F7E8D7876599268556F4D577E78AD9079ABA068665F97CFA5
60816497A5CBAA8082618D80875E6E999F9F909575D9D2A284C3A08580698074948780D1
A39D6F68A7A2CB4B91DC8D79697BB5BACF975DAF8F936681A4BF78383184905173776071
5A7C7885567AA59783AD7C8DB5B08A5E756A6167
66807C937197A08B8D9373858180849E699D69637E54618179A38675A4977D6F5FA8D8AD
5E825AB0A7D5BA83826B957D8A68709F9E99889264C8B28D7FC4AE80896E897F95757BD4
9CA27363B2ADBF449ADEB26F6A7DB9C7D0BA61AC88886188B7927D4434757C3C7C7C7A74
628483935970A09985C78A91A7AA7B667C706674
84938CB78DA5B891899269838266848D65A3706F856C697B6CA29376A88E7875559BD49B
707A4CAAA6D4C4807D6F957C974D66959B98908F6BDABD9B7AC09C769275918099746ED4
97906C58B6A7CC469CDFBF806B75B3CDD0B76F9B8B62757CAF768C5B3A857C6267727580
6285758F5E8BAC9077C58597AFA9825C6C564E6C
7D8F80B082A9BA918395728582558BA262A16F73816A5B7A7BBC8B77A59B796F508AC9A3
707B48B9ABDAD38C8B7D917F9D6777AEB49D9E9375E0C4A07DBB946E9A7BA38CA57B6BD2
9E977658B8A9C0399BE2B8716B75ACC7BBAB798E9A618A839694656C3F8C708E726B748C
5D7A72987087A88C79CC92A1B29E8967685E6EA5
7F92819A79A1B7928B967B818D5B85A26FA46F69755A5A7F79B89382AD9D7C7C5992CFAA
797D48BC99D3C985746D8877946D6EA2B2A09D987AD9B99888AF97689D8B9F8CA67864D3
A0837F58C0ABC534A1E3BC6A6874A7BBC6967C899976788068BD66532C6A65888A726E7E
5D735D8373819F836DC5908FB09BA27162697DA3
848D798A86B6B292849B75758D5A869976886A62825B5B737FB0847CA3A3847E5EA0CCA8
7D8444B89DDAD29187648C7E967F76A9B3A2A08F79D4B18F7EA98760968DA68BA4755ECD
9A888658C2ABC628B0E4B06F75729EC3CDA1928FA67A8F807CA46D4932716671907A7973
6F6B6E77717AA27467C49687AD876C7A726B796E
8296839288B5A99586A77F6C89538591759D806B7352507A78B3877EA79E8486658AC7A9
828948B7A5DDD492835F8D6D8C8368A4A59DA18D81D3A4917DAC886694838B7D947661CD
98707D57CAAAC21AB7E2937E7975A3BEBC8BA28EAA7B9A6CA9916C472F7C6259986C675F
926F7168837F998365C19F7DA18D845E66598164
8B896C787CAFAD9880A6867A8C57877D6EA171606F4B4C7075AA8176A79C7B85699ACAA4
7A824AB8A5DBCA8D7B61876E906A629B6685978F7FD9AE8B6DA68E6F99999A90A07B62CC
996D7E51BBA2C33EA5E39085857B98CCC87AA789A67F946C9D96665240715C6092947C6F
9D6967508183938468BA9E748D977D5B59749486
7D8574948FB0B991809E7B80955D8D956D9C6E5F624B4A77669C7A81AAA5867B598EC4AB
787C4DAE8FD3CB8B7F6C8E6D8F676AAE8E979D8B77D4A38D85AE99798E9E918DA4825ED4
9E728C5BBBA1BE559FE28E7F8B8A9BC1BD83A98E9C8A9474A4966E554C7A64697587767B
916F58486779939064A3977C8B9A718258648E79
897B849287A8A8908D987A8B8E649098779D7E6F7249527A7CB1868BA69F8583599CCAAF
7B8355C3A8DED0908B748D7A9F6270BC8DAFA08B83D5A18D80B1A8798A9E8D95A08267DD
9D6C8F60C3A9B62FA5E48881767A99CFC6909E9F9E889477B98F6F43316C5E7C6379607B
837F647582868C9864BDA67F8B8F62834F4E736F
937A7F8E89B5B19894A37C7C8D708088638676696F4752767EAB8482B1A0878B578DC4A2
797F52BE9BD9C993896B7770946666AA83BAA69B7FE4AF9376A29C7181888889A28559D0
8C759C79BDA29C25E0E69085887B91C2BB8DAB9EAD949984A98267383F8D508358845F74
8E7D6F8B7E8B98A073C8BC72929D5F743F3F615E
8B727D877B9BAEA09798808F855B7790536B49495C55627B88B48D80AF9D81935E8DC6A7
7C824DBE91D6C39A817281789B716FA997C5A3A57CD7A69B87ABA57A7B8D8491BC9186A0
A672A080BFB3A92ADCE3857D7B7994CDBC7EA18F958B7C91C08B68483E804D8A64837970
8871776176857E8C72BAC0668FBD6385594E715F
8F788A9D8CADC0AC8F9B6987946286986B9B7C6C664D5A7E89AF8E80B09D857F4F8FBBA5
768B4BC69EE0BEA7846F8680A17E7B9AB2BB959F92D4A8B489A49F807C7F6A75A79A7ACE
97629681A2AF993AE1E5787B888CA8C5B972A89483768288B77677433E7B587962778085
976D7E666C7E8CA979B9C0618EC55B6C60676D6D
8E7889AD93ADC0AD989C7A8D8E62819685AC76747F5862867BB59C7CB4A3858F6490C0A6
7A8A4BC596D2BCAD826D887B95797D889BBB7E8BADC5A5BA85ACA18D8087687F889F81CD
96668882AEB2843BDDE1657874749DC4B86DA0887E766987AE676E463C735865858D7274
815D766C6984818C6FB1A36D8AA751566B566E72
8D7C94AB8DAFC0A3979C788694597C987EA66A627B4F647D92B39E7DBEA4888C6893C7AA
7D894AC799C9B9AB88818B7D9686949CB0BE8F9FABD3A1C681AEA37E7B8562958CA3A7DD
8D6E899297BB7F31D6DD62738482B1C5B86AA28F8B79726BB869644138786A6780876E8F
80746D63616B7F9576AD88738DAC5A4F59566760
917B95AC90A8BEA6869274869150839E8AA460647C5478808EC09780BEA086906E90BBAD
869651BA96D3B9AA85668D808E8C9F94A4B19293B6D09FB8798E8D758181518F7198A8D6
898283B39FCF774DE2DC6A81746BBDC1BB7F9D92956C8D5EA87161503D76695C787E6584
707777676C76869474C37D7F91A96257594D6B63
917C8E9B8FA8B8AC869B688E95607D9C87986B64714D767087B79875BD9B89956995C0AB
8E944AC2A4CEB4A28B668073797E97B0A8A89296999EA6B77FA89B838C82509C7F92B1D5
91876DABA1DA6A4ADEDE79697759C9A8B088968D947591687F935D4C3D7F60576D7B5C7A
73707A6D727F968D7DD572929AA26D636352746B
90838F998EAFA8B5868F5B918866928D889A6F5E705C6E7487B59288CAA090936691C0A8
89854ABBADCBB0997F6D8D6C73878B9599AA8E88B7ABAAB48FB68987927D568D8780AFD2
8A8F60ABA1DC624DD8D17B697751CEBAB894756C896A7F7A769754405085796260828587
6B656979838BB18479D774959E9559685D4E6B6C
887E888685B3A1BE8F8B5B948A6985958195765F705866758AC49386BF8E857D6290B197
8C804EBC9BBCB29F7D6E88756F8D8FB3AAA6A490AAC6A29F85BB7F8B8F8B719A8873B0C7
809E5EA097DF575DE1C199787D5BC2CBAB9B9C89A6778093939A784154807D7F708A6273
6B6A65818E8EBA7A89DC579C958983756A547279
988A87807EAFB3B483865A9F92606D98879288676E505E7A88AE927DC083818D6895B498
998057B6A2C8ADA978718779528091BCA4949D7FADD4A3A689C27B768592808E9D65A6BA
84A7589195DF5073E4BD977A776BABD79F819B8E9B7B89A0A89D7D405A9156A072786872
716E6D7D9791B36E94D2538A908B924E6C4E716A
8D8D867E7FB5C9C596895F997E5E749789898465674C527E80AC947ABF8B84856E88C1A0
A98459BEB1CFB1B57B7D8E895F8FA6ACA193A28BA6CCA4A48EB77673818E929AB86EA9B5
91A6688AAAE54F77E3AE9985707BBDDE9865A097807A6B91B98F7149638A49A2766A786B
7E6A6E758A91A06F8DD0567B8C8491695A5B7B79
8CA87F7980B8C8C299865FA0905D6A868A8E836F684B5A8281AC988AC38D8A8F6786C09D
A97B58AEA7CEABAC797B84885085AAC09A96A7A1A5CFAC9D94C27174818A9991B673A2A4
879F7286A6DD4C88E59C8F8F8685B2DB91629F9A8D9F7F87B27D875A617B429A78627973
90669969A098A0658AC0657A9F83787C5B5A8475
8BA67D737EAEC3A7937C5D9C8D63727F9886867469424E7E76B99C86B88D8A8B5D79B297
A0835BBAABCBA6A47A8385884D80A3B3A397A19AA0C8A3998DBE7672828F969CC07CA4A8
8E957F98AAE03C93E3967E82919CC6DA89579499848E84A3BF8E7F465E814B89767C8A85
8A77B4638D8BAE6D9BA77173AC8A7C6153537B6C
89A9806E7BAEBFA2A07D65958C67797EA5898A7A634A568061B9B194C9938F936E81CEA1
A97B55B2AAC6ACAC7F7B87864C7DA6B4B080A4A5B1DAA3A09CC4777B7B938EABAD8BA9B2
91869997B1DD3B9DE39B7B73869CCDC094549D8F798F8A94B18981305A764A757C7F798C
7382BC739196AC7DA9A987769C9B885F50509080
88B3877A89B8C59E9F826D867D67645CAB868A7D664555315AB1A196BF8D89877186C097
9D6F61C4B6C6ACB57D7E90924972A9A6B47CB1B6B8D99B969CC37B7F7B8D8D9E9C9EB0AB
9575A5A5B9D642ABE6A97965819CB694AB64B0998B9C8C8DA88D7D366E834768736A6E91
828CBD758B899C81939D86A6A8A9795B4D5C766C
899D8C6D8FB0C6A2A8907594786A655FA57E767B6350563E7BA9A092BD928F8A7893BA98
A07070C2BAC4B0A9837D8F954674A7B5B973ABB7C3DF999C9CBA858B738C7A9E92A3B4B0
8171A8B0C2D539AEEBB679578091BABAAC6AAA878A9A908CB58A893D7D7E50786C6B6B80
8089A46D7D879882928B828FA4B37A6A4E697864
7993875598A5BC9BAC82799583747178B1897C876F64586482B09B94AE8C8D868798C39D
9F6B73ACC3C2AA9A8178869E4D67A6ADAE77A6A4C9DB959D8FAB808A7A8C839985A2B3AF
7A64A0B2C7D332AFE6BD7C5D7E98B7BCAF739A818F818D7DC4807D2D685F5183647B7D8A
837989798396968DAA7F8F97A9A47780636B7D72
7D998B5BA099A796AA846D8685817669AC977E936E5D473E84B89EA0BD8E93897FA3C39B
9C747AA5D8D1B897867C7D9B6268A0B39B74A3A3D5D3A1A987AA8F8786857F967F93B4B3
83629EAAC2C22CB5EAC07262568CA1B8B187A990A079976CB7867F397F7162935F796F8D
777A7F83879E8F90A18A9B969A986C755C6D7D70
81988B639E98B89AAF899191756E6C589E84698F6F52684486B9968FA286788183B6C4A0
946C7BA3D0C2B18881898098747392AC9A7AA19DE1D2ADA089A3978594797490889CB1A3
6D6498A5C4C726BEE7BC7276609DA6BD9595AC9297669E71A2A5693D6E58629657717086
70806C8982B99796A7909B949A9274716669787B
879590559D9AB494B592A490777C6C72A68285A085506C4488BA8C98A474657273B2BF93
8F706DA1DDC7B2858F6E848E797491AC88739193E3C5B2A990AC8E82AE817FA88499B5AE
858394C7CAA934C4E7AA7B844C94A0D195A37FA49768888384B95338966473915B715B72
636F638B99B7A48FB1ACA3B69877806E5D6B806E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.504715 0.0238095 0.97619 0.495285 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00787 translate
1.00787 1.00787 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FFFF8000
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FFFF8000FF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FFFF8000
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF80000000FF0000FF
FF80000000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF80000000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF8000FF80000000FFFF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FFFF80000000FFFF80000000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000
FF80000000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
FF8000FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF80000000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
FF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF
0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.504715 0.495285 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A8393A1AF9E5037B3B9BCB8B67D2F7F757780858147ADB1AAA9AB951E788F94999E9326
556269696E733D7E929DA4AAA9B0B4579FB2B2B0B0713A9DABAFABB06E338380929CA96C
2546495568754F6EB9B2AFADAE539AB8B8BABCB664B4B8BCB9B85B84B2ADB4B48689B2AF
ADACA95388A5ACB1AD8683C3C7C0BEAD52ACB0AE
5E91A1B5B9B37239AEBCBCBCB97E38756D6E7884883AA8B0AEAAAD91268C9BA5A4A19522
647E836D68593180969FA3AAAEB3B555A1ABAFAEB0762C87A0A0AAAD6C369C979CA3A977
3D65434E67704973B3ABADB0AC5196B3AFB0BAAB6BB7B9BFB9B96A8FB3ABB3B5A6A1BDB6
B8B6B25C869EAAABB5938DBBBBBBBFC36FAAAAAA
5E97AAADA8A5662D9EB5B4B9B89D5571696A75859138839DA3A397623F8392A19E98842E
57796F6E60502C8AA3ABA1A7AEB0B05398ABADAFB0742AAA9F90A0AB703B9F9DA2A6AC78
4795535E6F734561B3A8A6AEB04E95B6B2B1B1B064B6BFB8BCB96B8EB4B5B3B6A498B7B8
B6B2B1579CB0AEB5B89286B0B0AEB3BC72ADA39E
3C40463D393829242F2F202826221E282328292D322D3D4E34291D151F3D3E3A35374932
383E3937342D2346494E4E575D66612E4E686C6E7145176D63575E755A216D6E6B7A7B52
3044372E2C363B629E98938590456A9EA4B1B5AA61B3BCB6BCAE4E65A0A3A2A88E8FBEBA
B5B8B75C8DAEACAEB0867FA5A698A5B7659EA6AA
A5A5ABA85F7F9088A0A4A8ACA3A6A49C948A6B66A49FA29E9A8D8C8F868F8C88824A6B79
6B70767877777878745E4732526665655E46564C4539392F2217212F34382F352B232A29
2A2B2D1F222F35373E3C3C3C2D1F171B2630231F10242C212A1803112724272E221C3643
45494D192E4B494D512D335161636D743B414A4C
AEAEB3B5589288809BADAFB2B5B1B3B0B1B16D6AAFABADACA8A5A8ABAEB1B7B3B55A7B86
858A8F9EA09C8E85858F9F4B7BACAAA9A68D969F7F7E656D6147887F72AAAAAD917085B4
B4B2B7677CADB3B2AEB2B1B0AEAAAAAB9357879B9FA09A999E9A8B878C8B7F668E8B877D
757A77696A6F726C60456B5D55515457686C6D66
AEA8ACB2529D8C90A1A4A5A0A6A7A6ACADB06F6AAAABACACAAA4A6A7A8ACAFB6B34CA49C
95A4A5A6A7A49A898298A24681A1AFB3AA9696987476788382568A8C8CACABAC94776FB1
B8B6BA6179ADADA8A6A7A7A7A9A5ABACA75F8AAAADADAEB5BAB0A6A8ADABAF67BAC5C4C1
B6C2A78568B2BEB98A8FB8B3AAB3B7BCBDB3BCBB
B1AEB3B353A89795A7A3A6A3AAA3A5A4ADB16767AAABACABA8A6A9A6A5A6A6AEAB43A8A1
989BA3A7A6A09D948EA09B4B81A1AFB1B0AC9E9B9F94A0A48C538C9194A9A8AF8F7785B2
B5B3B95C76A9A8A5A4A9A9A8A7AAADADA4578AA9ABA9AAB2B6B2A5B0B4B2B34AA5C4C5C7
B9BB805340A7BEBD8B8AB9B7ACB6BABCBCBDC1BE
A9ACA49652808487878C909198928D9A9FA1695A888B9A9E8C938D948D8E8F9B9446A8A7
99A09DA1A1989A928B979B4579A59F9DB1B3ADABA9ACAAAB8750889B9FAAABB39A7E81B6
B9BAB9617FAFACA3A29F9FA3A6A7ACA6A26A96A8A6A19FA5AEB09DA0ACADAB4098BFBEB2
AAA46137449DB2B0718BBAB5ADB6BABFBDBABCBD
9A97938F8D877D787968356668757E797A777C65797E71583F5473767375786F6F6E6F62
5754405E7F7C798181877D767B7C6257534E4D4C5151555B4D444C6060695E5846495568
787578504E78796967657A7C82886D7382497A8C8575848F989D9C8D979D9F3884A69B7E
8079554A6B798C96738DAFB2ACB3BBBBB9B8BDB4
BBB7BABAB7B5B2AFA9AC4E9CA19FA3A5ABA8ADB1B4B3ACA160A1AFAEADB5B4B4BBB9BCBF
C0BA65ADAFA9A6A6A5AAADADAEB1B3B36B8EB2B0A7A4B4B7B4B8B6B1AFA56789979C9A97
9695969EA8A99A835A7B83777471797E7E887869653F49656A6A5A5B62615F645F6C6A44
61686264655C5F5B574B393B3B3A3E4C474F4A4B
B7B0B3B0AFACA9ACABAC50A2A5A59D98909DA8AAAFAEA9A75CA4ABACA9ABA9A9A7A9B1B7
BBBF76A7ADA49B9DA2A1A9AEAEADB0AE7B8CAAA7A6A5ACAEB0B0B0ACAAAA88B6BBC2BCBB
BEC2BFC1C1C5BEB589B8BAB8B4AFB6B7B3B3B4B6B35F89BABCBCBAB8B2B4B8B4BAC0BC69
AFB7B1ACAFB4B4B7B4A8A9AD9664A0AEB3AFA4A0
B1AFAFAAA9A9A6ABADAF608E899A9CA19F9FACADACABAAAC72B3AAA8A7A8AAA8ABA9ADB4
BBBA78B3AE9D9A95A6A0A4A2A5ABAFAD73819B96979FA8A7AAA9AEABA79D8BB5B8BCBBB7
B5BFC6BDBFC7C3B57AB5B7B8B5B1BBB8B5B2ABACAD5A7DB8BCBAB9B9B4B4B4B8B9BBB964
9BB3ACA9AFB3B2B0AFAAADAE9064ABB4B2B3ABB1
B3B1B1B6B09FA1A3A9A9578698A8B1B1AEA8ACB1B3B9B6B270A2A8A8A7AAADAAB3B0B5B7
BCBB7CB9B5B0AEA9A296A0ABB0B6B5B3637A8E8B8F94A1999DA2A2A89E7C81B1B4B6B7B9
BABDBDB7B8BEBBB183B3B1B6B9B7B2B1ADACABA6A3578BB4B7B9B8B6B1B3B2B1B7B9B456
94AFA8A7ADB1B0AEADAAACAB8E77AAB7B4B3A9AF
665D483931363431413C3432403B3C39423D30363C3E3B3A263E4C4B4D3D3B34352A3A43
463A3B595E61566061605D616A75736B344E5B5C666263646B6C6E6E6765487B80817C6C
667081858A908F65618E7FA3A1A49EA09C97989B924E85B1B3B8B6B4AFAEAEB3B2B3AD4A
9EB0AEAEB0B1B2B2AB9FAAB08C77A2A4B1A9A9B1
B7B6AB7279AEAFB3B3B3B4BCB8B4ADACA99352B3B6B7B3B2AAA59D948C8D9187499EACAD
A4A4A7A7A6A09B9791834F7D8182807E776C68656969767036525F595E656E6C67625B5D
563D2F4A4A4F4A493E2F463F403B354C525155484953544441483B2C2E373A43474D372D
414E4B50545A5E62666C6A685235535D6A656276
B1B2A87689ADB1B5B5B9BABBC0BBAEA6ABAC5AADAFB5A7AEADA9A29D8C90979B51AEB0A9
A9AEAFB5B4AFAAA4A3A16AA9B8BBBDBEBCB9BAB9B5B9BCBC69B2B2AAA7B4B4B4B3B8B8B4
B29557B098B3BBBDBEBEBFBFBB6B64B4B6B8B7B3B3B7BBBBC1BFB86D7DA5A9A0B0BCBBBA
AFAB9A968C4E72857E807F726D747B7078818462
B0B0AD778AAEAEB2B8B3B4B2B3B4AD9EAC9E5BAEB3B3A4A8A8A5A79E9B9E9CA049ACAEAB
A4A0AEB7B5B1AEA99F9E67AFB6B7BBBBBBBBBCB9B7B9BBBE65B3ACA9A7ABB2B4B2B2B0AD
AD9C78B39AAABFBEBDBCC2C3BD6869B7B1B6B5B4B6B9B5BCBEBEB8828EAFACA8B3BABABF
B8BCB9B7B056A3BEBEC0BDBBB8BBBDC0C2C1BC94
AEAFA96983B0A9ADB5A8AAA5A9ACAC99A5A162B5B4B4AFACA7A8A9A59F9F9BA342A0B2A4
A6A9ACB5AEADACA9A69E5FAFB4B3B5B7B6B6BBBBB6B3B2A562B2AA98A1AEB7BCB7B3B1AE
AE9672AEA8ADB1B8B6BBBDBAB77565B3B2B6B3B3B4B7B8B8BEBDB9748BADAB9BAFB7BBB7
B2B3B4BAB147B0C3C5C3BBB7B2B7BBBEC3C0B98F
887E6B485F7B7981867E7678736E716A666449888488806265666B6D5B5F535723406572
777E92918976817D84803B909EABAB8C96A1B6A298B4B5A66FB2A6899FACB0B4B2B5B0B5
B28D5999ADB2B3B4B6B1B4B2AB7173B4B0ABADB0B0B3B5B7B9B6B46B8DA9A9A0ADB7B8B7
AEB1B4B8AF47ADBFBEBCB7B5A8B3B8BDBBBCA881
A4998D909088858484576470717378796E6F7D777B80795542656E6C727173716C6C7A75
655B3053555758565C5A6454585B573E24414842423C3F4D464838424F333D5045575745
4F502F3B4553564C4E4E4E57634336494952555B575A5E63626166323260697172787D7C
777D6F786E2F6B9497949B98949191A3A6AD7962
B9B7B8BCBCBCB9B7B56E92B2A8B7B8B9B8B4B9B8B7B8B87A6BADA7A7AFB1B8B7B8B4B3AD
AA933DA3B0A49A928C84949CA2A6ABAB529AA4A3A7A9A9A6B1B2B1ABACAF69A6A8A4A6AA
ABA7ACA7AAA9A78677A6A6A7ACABA2A3A199988F7D3D55706D696A7679777A706D656440
5F63676665636463626467533F3D60636668665D
B8B7BDBEBFBCB8B8B56D91AD9AA9AEACABADAFB7B7B1AA826BA4A5A2A1A6A8A9AFAEB1AF
B2A149ACAFA79897948E8A8C94A3AEA741939D9D9DA5A1A4AEB1ABADB5B379ABA7A7A7A7
A8A8A7AAAAA9AA8381B0B0AEB3B4B2B0B2B4AAABA95F80A0AAB2B0AEAAADA7A4A8ADA861
A6AEAFB0B1B4B3B1AEA9AA947D6595A1ACB6B6B4
B7B5B7B8B5B5B4B7B0698AA998A9A9AEA6A9ABAEAEAFAB7D659A929FA2A5A7A7A9A7AEAD
B1AE48A5A89B9194838482858598A8963F8E96979A9C9C9BADACAAAAB3B16FA79FA09FA5
9FA1A3A5A4A5A7828BACADADAAA8A6ACABB0ABADA74E769EACA9ABAAA7A3A39CA29FA95C
9EACA8AAA9ACAEB3AFA8A7A79B679595A7AAAFAE
87827D7B7D848D8A8C5A7C907292949C9C9BA0A1A9A8A6774F8C9298A0A1A0A49AACB2AE
ACB04CA7A08F8C9183827B807F84948E578B8E84878EA09FAEADADABAFAA669997939191
969E9FA89E9FA27A80A9A8A7A8A6A5A4A6A3A3A6A15C7997AAABA9A49D9E9E9394969D59
A0A6ABABA7A7ACAFAE9898A5986B8B7896A5A7A7
695F51304D504942394B4F464946474F39293F464B413D392B302A232F2623232A4C5A60
5D494169726A554F5B5D57626B55585737394440424D51524C585658524D4265676D6D6B
6667645C63656251577A8072757F81817F70797E7F4A636776787D7162594E5D5B596348
7A828A70758B928F8F8378896859736E8AA09D9C
BAB9B16FB9B5B0B4ADB2B3B7BABEBFBAA65A7C88B3BAB9BEB5B2AEA5ACACA74AAAB4B3B0
ADB0A2AFAFACA19B8D509EACA7A4A8A8A29D9D959F9B7C457F8A85878C8F848B8E8E9195
8C56707A797B76736D68645859572C375E5A55585E645C56615A483C5C656559555B6468
5F544E432638473E413F3F3C4542494D58533E44
B5B4AE71B3B4B7B2AEB1ADB7BBBAB7B1AE4E8E95ABAFB7B4B1ABA8A5A8A49E53AFAEB0AE
A7B0AEAEABA5ABABAC60ACB1B2B6B5B4B0AB9B9DACB2A4539FA59C9BA4A7A6A5A3A6ACAE
B276B9BDBDBDBFBFC0BFBCB6B3BB3F8CA7A8AAAAAFB4B8BBBBB86D6EA4A9B2B8BDBBBDBB
B8B1AF9E5194AEA9ACB4B3B0B9B7BEBDBDAC6AAE
B5B1A66EB3B8B9B4B1AEABB2B7B5B2ACAD5DA9A3ADA9A6A9A7A3A3A7AAA08A5FAEACAAA9
9EA6AAA4A6A7A6AAB071B1ADB4B1ADA5A29DA2A3AAACA64B9E9E8F97929E9C9EA4A2A9AD
B071B9BEBFC1C2BEAFB2B6B5B8B94DA4A7ABA9AAAFB2B5B4B7B66970A7AEB3B7BBBDBABA
B5B2AC8C4A9BAAAEAEAFB0B2BAB8BBBAB9AF74B1
AFAAA777B5B7B8ADA1A4A9B3B4B2ADA9A758ADAAACAEA4A2A59AA0A3A7AA8F5AAEA8A9A7
9299989599A8AAA7AF64AEAEACAEA4A5A6A5A6A3A1A5AF4D9D9B837F7C8A9194A3A0AAAA
AA72BDC1C0BDBDBBB9B3BBB7BCBA589A9A8E94A0A7B0B5B9B9AE4E6DABABACABADB7B5AE
AAA3A8944B99A1A6A6A697A5A0A1A9B1A8A37DB4
4D443027404338363320303B3E413D3E322C3A484C4848413B484E505546421D5C646667
6B67706C6A766E6B6F3D7277797B737373716C76787C793A7D77787166787E81818B8B87
8C568D8A9088879091859599A2B14B99A8988B979298A6ADB8B04E6D9D9C9EA2ABA8A9A4
A08B9A8E599F94949EA19691898B9AA4AEA376B0
6B4483908B88722C638A8B817E67305F828383777436696E62575E55283A444D66623928
5E776F6668672B3E60635749513758544A3C403A2A5C5858483029232B2F38362B273A45
49423A3633413D38342219262D312A2D3A45414445413D3942574B4C4C53534D494E5759
58525255362A3B414545555748474C4C5C4E3045
9E3DBCC8C9CABD2B81B4B7B7B89E288CB9B9B9AC974D919D8C8A8E804D565565838F8233
8DAE9D97A19C4375A9B1B0B3B855A18D645D565148B7B9B8B6B2695BA7B6B7BCAB4289B5
B4B4BAAE43BABFC4C58B83BAB2A8A48C52A1AAA5ABAAA456AFB4BCB9B34C6CA093909096
5F488891A3A1893B6E8D9998998F36618E99A29C
AF45BEC5C9CAB42485AFADB2B4A72692B7B3B4A5933A93B3B1B3A9A9553D3D4B6D7B7E42
88B2A597A3A03B83B7B7BABFBF63A6A690705F4B56B5B8B9BCB86874B0B4B9C0B84B94B4
AAAEB8BC68BDC1C2C8B36FA8A89DA3A760A7ABA5A29C8D52B7BBBBB7B86D74959C908790
5985AEB6B7B3AE419FB9B8B8B3AD3EA1A8ACB0B0
B255B8C1C0C6A82D8FA9A8ABA893218EB3B2AC97803F98B4ABACB0AE4F3717191E414533
849F7F7A939A497FA9AFB0BBBE639CABA983725F4EB3AEACB2B4657FAFB4B5B7AA3A96B1
ACB2B7B560BABDBDC6AF71A6A1A7A5976299A59D95848647B2B5B3AEB063648A827F7B75
4888B2B6B8B7B036A4B3B8B6B1A83798A5ADABA7
84337C857E82763D5C7F7A76877B2A5F6D715B535F4562788282868D463E2C3B3C415440
63644B55606947617C72708087489A977464436147938B7E7B885669808393A082378894
9FA0ABA45A9799B5B6A06CA8A7A4A79C5A969F9893857F4FAAAFAAA4A7544E89887C796D
4E92B8C4BCB9B32BA0B6BBBAB9B139A4A6A8B0AE
887B7872415B70797E6F6D70796A685855583E47686F685E5C4B555B5A595E503C49636A
6B625C5C5F5F625F585E463A5157555C5C5B5D62605F69624E555B5B564D464C46526262
66614D4A423B444C483E4B564A4F515B536664615A645B537C736D6A664C405F665C5D59
4C6A7885837678416F7B817577713F787C79837E
B4B0A79F4294ABABACA5B2B4B5B0AAA4959D6A7EB4ABA6A0ADADACACA8AAAEB0738BB1B1
B1ABAEA6A6A9A6ACA9AB7870B9BDBCB5B8B7B5B1B4B3B9B569AEB6B6B7B3A6AAB0BEB9B6
C2C45252A8A9B4B4B1AAA59E8B7B41A5AFA182938C969B9E9F99896256959A8E9AA2A081
98A197969552809C90846F51556E896A63614F4F
B4AEABA73897A7A5A29BA6ACA8A5A5A3A29C6881AFB1A789A5A2A4A79CA1ADB27D8EB6B4
B2B6B0A7A6A7A7ABA7A18C91B2B1B0AEB3B5B4B2B1B6B7B657A6B4B0B1B0A1A2A7BFC0C0
BDAE447AA9AFB6B8ADA8A6A3A38145B8B8BCB9B9B7B6AB94A9B3B59175B1B2ADB4BBBEBA
BCBBB7ACB46FA8B2A99C9FB5B8B3B4ADB1B87A6D
A8A3A69F379AA3A3A29E9FA5A8A9A39DA3A06E86B0B8B397A69DA0A9A3A5B4B48C84B9B6
B4B3AFA6A5AAAAAAA8AD766FAAAEB1ADB0ADB0AFB1B0B5B761A4ABAEAAADA5A5A6B4BBBF
BEA0397FAAADACAEAAA2A5A3948449B7BBC3BEC2BDBAA593AFBCBB9380B2B4B5B9B9B9B4
BCBBB8B0B267A6B3AA9094B6BAB9B7B5B9BB7C76
B1B3B0B257A2A2A3A2929A99A8ACA7A1A3A06280A9AFB09BADA1A6A9A29CA2AF7F7EAFB1
B6B4B3ACA5ADABACA89F595BA2AAAAA8A7A8A5A9AAAEB3B66EA3A3A6A7A8A9ADAAB4B9BA
BBAF4D76A8A7ADABADA9A58F88835DB1B6B8B6BCB7BCA8A8B8C1BD9783B2B3B8B9BAB9B3
B5B9B3ADB05DA3B3A98275A3AFB2ADB4B4B78A80
6557484831404B51524A3E294B635B4D473F3E4B556A605444383839313845403B4A595A
656757423C53514D413F362B5451523E4339354941524D4D37626761636D6D716A70666B
68532C4866615B665D584C5D656139606B73717B757C6F7780858369557A7C8380817D81
7A827E78794A7B7962535461717A7A828D886562
B18A799AA2A9AC9E928D8126A6A7A1A09B9A9A979E9E8B8F9254919CA1AEB1B3B4B4B6AF
AFA98959A6A1A7A8A1A39F959AA2A8AA633A8E989EA6A9A9A09094A3ADA778669DA6A4AF
B1AFAEA69AACB6B268709B9D97969D9E9D9998989B85436B787A7473767467585C523762
6A6969666C6F575E6C6B735F4A6C6B6967696864
B4A29093A4A8B1958BA29C2C9BA2938D8C86808B89856990973E848C8D9EA09DA6A7A8A7
A3A0936DA2A0A0A3A1A09B8B989FA4AA7451A5A1A5A9AAA6A398A0A5AEB06F79A8A9ABB5
B2AFB9B9B6B4B6B86F7BB7B7B1ACB9B9B3AEB7BCC0B23D7DA7B3AFA49C9A8CA1B0BB6895
B9B1B2B0B3A581A2ADAAB08582B9C0BEC1B8B9B8
ABA5948DA0A6A78E899F932C9E9F98888479848A868F7E939137829286919FA0A1A6A9A4
A0A07F6B919D979C9F9B9C9496A0A3A57156A4A6A4A5A5A7A39A9EA5A8A56A60A1A4ACB3
B4AEB5BBB7B5B6B66C83B8B4A8A9B6B7B3AAB7BCBCBA4893B7B3AC9B99A6ABACAFB86A97
B5B4B1B3B2ADA2AAABA7AF787CB6BBC4BDADB7B5
A5A1A39DA09E9C8F8F857D399EA0A6A49B84888189909B96983E8083839296908D91A1A3
A09E71576783918D9C999C8692A0A19F85669DA8A7A3A1A39B8F8C93939175618B95A0A7
A3A1AAB1B0B4B7B57295B7B29AA9B4B2AEA8B6B9B9B8419BBAB9AE9BA7AEAEAEAFB9689A
B1B1B1B4AFA6A8A5ABA8AE7D82B9BBC1BAABB0B4
7366675C4046423A392627294553525342483D494F5C4C43343E53494E5D66534A474F59
50614D49455045474B5E574F56565A554A46716B6E6A6866646D63606A64564F4E5B7073
75736965716F706E3B63807B7581847D837A7C777C76357285847D5C747E848C90925F75
878A857E78707E8088818265619AA2A09D7B9197
AFA4A5974C809299978B9295A1A3A8A7A9954D57A39980A0A29F9B989A9EA0A77968999A
8B8492868E94959098915D769CA8A594919093908B8BA0A45F7488877F838D868D8A8983
867946858081888C897464635F5C2B628A8F8C918E8C8C837F827F753A667B7B75737772
70696C66673740565A4F575A5A5D5D5E625D5F3B
B6B1ACAA4C88A9AFAFB1B2B6B4B4A6A3AC9957589C978999908A838B939BA1A6826EACA6
A0A39B9F9F9BA1A49A8C5A7FB8B9B8A1AFAFADA6A7A5A8AB74A7B0AFB0B0B4B8B6B9BABE
BEB45EBAAFAAB2B3B9B4B1A69AA0308AB0ACA9B0B5B5ADACB1B6BCA537A6B3B1B2B5B6AC
ADAEB2AEAA6479B6B7B7BAB4A8A4B0AEB2B1B162
B3AEACA93B87AEAFAAADAEB7B7B7A4A1A6A56854A5A197978C837B7C8F9EA09F8271A7A7
A79B899CA195A2A594834C7CB4B4B49DB5AFAAA9A7AEADAB7198ACB1AEB0B7B8B9BCC1C4
BFA862B7B0ABABADB6B2ABA39F913076ADACAEAFB3B2B4AFB5BBBB9E35A6A8ADA8ADA5A8
ACB0B0A8AB6F76B0AEB0B5AB999FABB2B1B4B16A
B0AAA8AA5175A6A8A2A1A6ABB0A7A2A09AA16752A29A9798877D7D7A7B848A947976A4A8
A69B97A4A9A0A0A397885184AEAEAC9FAFACACA2A1ABA6A56389AFAFABACA89FBCBDC3C2
C19C5DB5B3B2A39FAAABA9A4877C3D68A7AAACAFB4B2B6B6B3B0AFAC3FADADAAB2B3ADB0
AEB7BBB8B97C77ADB0B3B4AFABA7AAB4B7BAB267
75716963345C6E676A6A6B61696763544E4C30346D757070645A595B535A61683C4E7670
6F646166705F5E61544C32517375726F707A756A5F5F564F314755656E67675E79838A86
834A3F88828C7F878280877A676E44618F9997A19E908295909A938036819D909494979C
A0A4A8ABAC806495A4AAA6AAA59DA1A2A4AAA964
9798959095908484949CA058688F8D8182899093908983847F54395E60646B6960606C6A
6E6D6A465F666C666E737E767A766B7162466F6F696A676B74776C7678764B3965706B65
6B6F776C6E716F67546C6D6A72787874706C68625F3924313C3D4A475152574B4F473F3A
5F6162605E6463585F5C56503543615D625B605B
BEB9B5B6B8B2B1ADAEB0B4617BA9A49E969E9EA6A2A1A4A7A363518C8994979AAAAAADA9
AAA9B16286AEB7B8AEACADAEAEACB0ACA469AAA39893909FA5A4A5A9A6A67260AAB0B3B3
B1B8B7B9B6B9B3AB83A7B1B7B6B3B4AEAEB7B9B7B870667F80A0A291775A7A8485835F4D
A5ACAEB4B9B6AAB7B9BFBBB94392AAA9B2B7B5B1
BEBAB0B0B6AFAFACAFADB16D85ACA19B959B999DA0A3A5A69A60508D928F9995A2A3AAA8
A39FA56C83ACADB0A2A0ABADACA9A8A99D56A7A398868EA4A69BA3A8AAA76E69ABAFB4AF
AEB0B3B5BBBDB8A486A0AEB4B1AFAFA6ACAFB5B8B36794AA90A19699865696A7AAAC775C
ACA5A7ACB2AE8F9EB8BBB6B95C93ADB0B1B5B1AD
B3B0ACA8A9ACABACADAEAD7884A29472707F97A093A1A39F90554E7F818D91868A899DA0
9B9DA2657F91A4ACA29698A5A4A7A6A5985EA092938885A0A3A2A5A6ABAB7682A6A9ACA6
A8A2AFAFB5B5B1A58799B2AFAEAEA9A0A7A8ACB0A8608B9E8F9D8B8D8E59949DA7AA7A59
AA9DABA8AFA89BB1B9BAB8B96F9BA8AFAFAEAEAB
8677727570706D676B686A38607D827A4B5D5E6F756D7181783E5672727573675A4F6276
71716B466D778980715E546F797673777A4D6D6A746E656A5F5F6B6E6F645469676A7A7D
738A8A898F827F8472668C8D8F9394949C90909686598582807F6F796B4B7F9191A06B66
7B7C9D9C9C927CA8A4958771566598ABA5A3AAB1
7E6F634630717375798289898478707B77552E5D67655F58585657544F5050331E546D65
65616263645C64605D48325D625F6561605E5B605E565033283D4642445A5F5C5C5F6161
593A47636A665F72706D7573757A71344F5E5C4A5A57575355463A221D27263A46585D62
666D6C615037254A3F413E4048526873757F7663
A48773743EA8A9AFAAABA6ADA8AA9FA7A17F59ADABA8AAA7ABA4988F9EA3A16C3DAEABA9
A39FA3A0A2A6A2928D7E3C88A1ABAFB4B5B5B3B7B2A6AE6145737B797993988F81929288
8A5A95B0B3B5B4B0B6B6B9B5B0AEAE318FAFB3C1B6BEB7B8BEC1BAAB304386ABAFB4BBBC
BBB4B0B1A99D74B2B2A4A4B6B7B8BCC0C5D2D076
AE95687357B0AEACAAA5A6A4A9857D999A905CABAEAEAAAAABA2A1969CA19E783DAAADA8
A19E9C9DA2A1A2A2A07E3F9DA4A9ABADA9AFAEB0ACA7AD7157756E6E6A776E6963768984
845587B2B5B39F96AFB3B3AFB0AEA83694A9A8B1AFB7B8B5B8B8BAB54676ADA39099ABB1
B2B3AEADAAA972B7B4B1B0B6B2B4BBB7BBC2C071
AC9A735B67B5B5AAADB0B3B0AB6A7CAEAA8F61ACACACAAA8AC999999998F916C3FB0B0A4
A8A0A8A7ABA7A0A3A07E2F9D979CA5AAA7A9ACAFAAA9AE714365666A6B6A68584F5E7575
734883AFB1AEA39C9DB3B4ACAFB3AF3792AAACACB2B6BCB9C0BBC0B6527DABA599A5ACB4
B1B2B0AEACAA6DB1B1AFADB2B3B3B6B5B8B8B874
91886C4E4F8B8573778275777F5C678186654C8175777E868883856872616248408B9190
8B847D79728874716C5E2F7D7B71818388867D787271704D31302D3637443E40404C4554
4E487E918F9585877E8D8A8B8C938538588286897E7D81807F71717739609AA6A4A3A8AE
ADA9A3AC9E7B639196949093999B9DA4A9A59854
41425E666D665D36495950555951243757516062614640374753544F2B233846504D3121
38454C515744313E63696A5B5E261D4D52514E522C3E4E5A625C51293E585058623F2753
6768615F5F365C66575C5E5426496262655E4745626462535E39555D5946483729313A30
38362A2B374139413A242F3D424E4941334D4C48
7A5BA4A5AAB1B75E7B918898A1972A4D9499939CA94F63969A948D7C3B3B61735778923D
7BA3A0A3AE8D40698F9B9E9192396AACA388859E4A6EABA2A69DA2498EAFB1B5BDA72690
B1B4B6B8BE3AA3C1B9B1AE9F2F82889298907578AFAEACAFB75D96A0A5AAA974269AC5C1
BCAF5B3FA8A8A7A3984C688EAEAEB6A041B0B8B8
8B6EA0A5A8B5BB635AA38F9FA8B049538E95908D985A619B9A8E7D733A395D7E6477864C
78959995A8904C6F9BA8A09A9C4E72AFAAA09E9B4B6EAAA8A69B9D4996B8B6B9BEB6539E
B1ACB0BABB3DA9BFBCB5B299327D8D8F9181626AAEB3B7C1C055869FA2A5A07238B5B6B7
B5B76475AFA7A9ADA7477A99A2A6AFB24FB3B8B8
8F77AAA6B1BEBF5A73A88EA7B4AD44699C908D8EA152668F7F6F6D61343951595B61753E
7B9BA1A7A897477A9F97948793527AADA89C929D4A72A2A5A4A7973F98B8B7B7B8B24D99
A9A7AAB3B93BA8BDBAB8B9A43780887F7B866872B2B8B9C0BB589EA9A7A6A16B4BB5B2AF
B4B37076B0AAAAB1AD3C7C96A5A59B6649B2BAB7
8D629CA0A0A59C4F448698AEB1A1345CA192908D99472C888A757C7D4E597775655C804B
859AABB2A9A04360A79F9082885470999D92867743749D8782989B669BB2B2B5AB8D4299
A3AAB1B8B84CA3B5B0A8A490324B5E6C83835C568C979698A291ADB2B1ABA67264B6B4B4
B9BB7283B0ABACB0AE467BAEA8A0927D52B2B3B4
6958503F323435333B494F4E53504B55563F39484D514B50535A51463A323E242A4C443A
4B4E696B6F62535F582D535A4548476872785058574A38244C595E585B6667675A53494B
472F4B5A62596D716866645A595441374B574245565A50586E7F796E425765616683847E
7C7C585E5C5257625D4B5D625D5654423B4D5356
AAA79D6E378B9CA0A7A7A7ACAEAEAAACA87663908C9C83849A9D958D788B8D6162A1A6A7
A5A2A6ABAEB1B1B1B24C93A89F9F99ABAEACA6A2AAA0A43CA6AAAFA8A5A5ACABAEB0B1B2
B2429FA8B2AFB1B8B1B2ACA5A8AC9C85B4B8AAA5B1AEB6B3BCBAB1AE56ABB3B9B7BABBBA
B8B1A7A4AE70648D97A2ACB0AEAEB2B1B3B7AE61
ABA4AA6661A89E8A98A09D9EA1A49FA4A38868999AA28C898F9A8F8E8D97916884A4A9A5
A19E9C9D9FA3A6AAB26899A99E978DA6AAA7A999A6A1A45FA0A4A6A4909AA4A2A5A6AAAD
AD3FA4A8AEB2B1ADA49FAAADB2B1A086B8B8ADABBAB5BCB7C1BFB9B35EAEB4B6BEBDC0C0
BEB2A6A7B57678A8ABA8ABADA7A9A7A7AAABAD66
AFA9AC5D47A59F8D91A2A6A7A4A09EA7A48C65A1A2A59F9A8C8C998278878D6984A39BA1
9E9986899B9F9BA6AC6A9CA8A3A391A2A1A5ABA2A5A39D5DA29D9A9A949A978DA0A4A6A8
AD4EA4A2A4ADACAEA5A2AFB0ADADA084B8BCB2AEB6B6BEBBC2BDBCB76FB2B2BBC2BCBEBD
BBABA1A9B36871A0A6AAA9A69E9DA0A1A8A3A877
B8B8B672419DA3A0A39D9FA5A8AEACA7A1846393A1A6A4A19F9D9A89757B996584A29C9F
9DA18C847E888AA29545969884989BAAA8A7A69D9F9E9A4781857C7C798486939A9FA7A8
AA4E9F9FA6ACAAA59A95989EA19C7E78B0B2A4A1B4B9BBB7B9BDB9B571A0A3B3B7B8B8B3
B2A397A3AF5B64ABA5A5A6A39C9F9F999EA6A083
666964543F505E5B675E44414A4B4B2C2B2E2F33414B5A4F3D343A39595062445B69675B
4D40373C494F515135283C403E3D404D39313E3F40423C34303B30362F2E24323B53484F
492E484D55594C51324446595B5F6C6660645B463F34324D4A5250534A49525D585B5566
5F61586A6B4A334C4B4342414E574F5F534E4839
A8A3A3A1A0A3A59E9C955662B0ABA2AAA5A7A8A9B0B3B3B05255909495A0A6AFB0A29D9A
A69D5C48A8A3A0A8AAA4A4A1A4ACAFB17D2C808993959D9698939B95A4953D5F656C6D76
8593999289859B644CB2B5B3ABB3BBBDBDC2B6977C5A82CBC3BDB7B5B7B3B2B6B69870B6
BABAB1B0B5B8B3AEB0AF843CA59EA2B2B5B3AEAE
A69D9A908C8C9D968E8F5D6BADAEA2A3A1A2A2A7A9B3B4AF7F67977B799CA09F99998C8F
8A88613696A0999DA19D9E88A3AAAEAE8145A7A3A6A4A6A6A8A6A78BA2A95A657276837B
717C85847B817A613F9EAEAEA3ADB1B2B4B6B4B4B56D92BBB8B8B4B1B1ADB1B0A96F6FB7
B6B5B4B7B5B7B4AFADAE9D52A2A3A6B3B1AEADB2
A8A3A092928294958B846166ABACA29D9D9AA4A0A6AAB1AB80689381868A8DACA9AEABAC
A7986A2D9AA7A4AAA6A39F90A4ADB3AE8848A9B4B4AAA3A7A4A6A07EA0AB5D667F8B897F
7D7D7F878588796842827C696D9FAAAEABAFAFADAD5F92B3B1B2AAABAAA9A5A4A5597ECA
C4BDB4B6B4B6B8B3B3B3A85E9EA1A7ADAFA8ACAE
A5A3999B8F8D91888F936A5CAAA7A3A49D9A9FA0A9AAAEA56A718C8A7881839EA7ABADA9
A9A26A3298AEADB1ACACA5A1A9ACB0A79840A5A2A7A7A19299A2A08A8DA56A779F9F987A
6E767C8F9285867369A09E9E6C808AA1A39B9D938B3E809F999896A19CA09B99996072BC
BCBCB5AFA9A1A8B0A09E9A559C9EA5AAADA5A3A8
655847393B424848493F262C607178746947494D494F4A3E2C3C434B4343464C524E5361
5E3E242B49545C4F4F4246474348442F39374D504C3F41313033414242434040464C493F
3038343B37393F323B3F354047432D21383B413D3B39404B433F443C233336353C443D44
48494833321C2E3C3736444A5459635D4E4E465B
B2A8A35A7C92747D9794A4AA8FACAAA7A5396888A2ADAFAEACAAA2A1A2A0A9587AA6A8AB
A3A7A0A5AAA1A8AF9E4670818D9A9BA09CA1A1A19A9A97499FADAFB4C0B7B0ADB0AEB3B4
9569A4AEABAEB7BABBB7B6B4B0B34761B9BCBAAFB4BBBDBABDBCBAA73DBBB7BABABAB6B4
B1B1B2ADA568A2B4B0B4B1B0B0AAA4A6A4AA71A0
AAA7A56478945C7A897B9295659E9E9E9D2D657A809D9A96989791949297A86688AAAAA6
A5A49CA1A09EA6AAAB5A7999989FA3A5A09A908E8D8F8A3FA3B2B8B5BBB4B0AFACAEABB0
97699DA3ACB3AFB3B8B6B2ABACAE4D82BDC5BFB4B7C0BFC4C5C6BEAD45B4B1B4B3B4A7A6
A6AEAFAFA960ADB5ADB0B1B0B6ACA8B0B1B279AC
A19D9F5D738A5489917F9381669A98989F375E79799E9C97918188909292945273A1A3A1
A1A093969293A0A4A14A69999AA19D8E8A8985848E8C89419BADADAEB4B0A9A7A4A3A5A9
A3659296A0A8A1ACAEACA8A4A7AA4C8DBFC2BFBBBABEC3C9C5BDBBB24AB3B1B5B6B1A79F
99989FA9A356ADB2ADACAEAFB1ADADB4B6AF76A9
A19C9B65718F6F9F9B9AA4807DA1A09D93435E838C9CA39F9A91908E8D938234759E9E9D
97A0988D88939799994F6388959A998F837F7E80858877428A9EA49DA4A69F9794919D9A
975B9786899D99999E9996979E9A3980A7A4B0AEAFACA3B4A6A7AF99518C8D99AAA79286
87888494985BA3A3A4A4A99A9F96A3A4A09A5D95
594B4A393B4B3F44484F4E3B4A5047443A1B243C3C383842382D3A4C4F533C1F465E595F
55554E4A4746504D4821374B5253524D51454843423A37202C2F2E263D4238372F293033
29264E413C3B3A41463630312D231F1E24252A2C26283A4041494C4D423E3A2327281220
27261F26261619201B221A0D162731312F292222
938887817D797474797D8430486B7A757B80767E7E7C726E68247C8A868F9DA69A989B95
888D832F5D7D8983797774646A6E6B6C75336F7067747880848A8E969690746E988C949D
999C9797A8A9AB65839A938E8E939A999FA29FA17A68989EB0B5A8AE9D9BA09A89A4548A
5E7C97A29C737B7D8BA2A06081A1A4A5A7A79C86
AFA1A1A19DA5A6A3A29BA13C8A97A0A49D968D9FA4A3938D822D8A9B989D9CA4A4A3A499
8C8B894B9B939DA1A6A39A9383867680963489898A87979D92908FA1A29277538A8D9399
9B9FA0A0A9AAAA4D9BA69EA09EA8AAA5AAACABA3825AA3A2ABAB92A3828E968F869A5A84
47909A9F99706D687093A66C7B939EA0A4A7A3A6
B1A4A19E96919CA19483853A69838F9A908883909E928577772E818F908F7E797F8B9E7E
6D76703D8E9FA2A5A4A1968B72837D8F9D309A9C9E9195938388819AA1946F5F96919C9D
90948F9EA7ADAB64A0A5A7A7A7A6A9A5A7A9A6A48D609FA3AF96AC9D82949A99929C3F4C
51868688895B68537499A15B7C81979CA5A09FA3
ABA5A59F9A919B9D8D848941788C858B8A878883978A6A61712F86939988797A7987A48B
6965563081899497938C8979768093968C4093978E838987899A8F938F8F69526562686E
6F7471798D95784F7E9795A1A5A5A7A397A6999B85689696B0B5AA959C8B979A979E3950
6492898B63485A507983833E6997A299919EA1A0
70676B6862636466535861364656545452534D474C4E373A401E515B646164625D636460
4F45372C56595A5F5B4A445146484B4B431C625E645E58525966525F5D45382F44433A32
3542505353552A251E49565848494B3D4054483B21252D162530293521202625291F0C11
1E25251B1C18191D27272D24262A322424404144
6755433918315C404F534D5C655E5D5D5A56494E7B726A67686D6B6E786D736C40606961
5F595E606061625B645E426566634B4D616E5E56595E653B426C7B787B7872757163676B
6A294A6675717E8886848A797882722B7B8594888EA69EA2A0A29F9C3E7A858F97979AA2
A39F9F98936774928E8681616A8A948D8D958B64
AFB1B4AA3E5D9353557F858F888C85847E775585BCBCBBB5B6B6B4B0B3B0B2AF5C7D8679
7169676561646B6C777D5C9A9497A3A9A8AAA4A1A2A4A9746AA5A8ABAAA3A5A4A3A4A39F
A03773A0A3A6A7A6A4A2A58F939A7F5395A29B98A0A2A7A6A5A7A99A369CA0A8AFA8A2A5
A6A59C96985C809E9A88909899878A8C8DA08B75
B3B0AFA8415988495479777F7A7C80777C734F88B6B8B3ABADA9A0A3A59AA7A562768785
637368615B53566162685595A19DA1A5A6AEA69BA0A0A5666AA7A7ACA4A1A4A2A1A2A4A2
9C3C718FA3A4A499A0A3A07E94996D52989A9B9FA5A0A3909FAAA1702593A0AAB0ADAEAB
A19E9E988B5476959A9F8B889F8A7A8EA4AA8C71
ADA8A49240487E4557827A7B7E707A797A78467EB0AA9E9E9FA09A8C90839392686F8683
6B7278858C9192867573588F96939D9EA1A2988E898B965A6AA3A1A199989D9990A3A5A2
9F35547D99A297949CA39D677A706663A3A1A2A5A6A0977780907C713E929EABA9A6A8A4
9F9E979E843F758B8B95847C91777A9F9FA8836B
806A48553D556B4D625D667767596C6F6554375697949089817675736A6450443326554F
4A514F655A5A6756514F25505A56686C606670675A525E414D7871646862665751636D6C
662F3D575C6D726F7272664B513928405659555E5E5F5A5E5B67574D2146556058575F5E
5B54544A3E2A43504553575354484448484C3238
603028545B51443E1C2253534B49361C0A515C6D686A42213B484C515B44295B5B5E5E61
4826576A71737A3F255A5A5F635C283765718177722B2B45454F53202A656C5D625F4049
686864613F1E4663626B732A477885887B662B6A818789884A426B848E8B5A0733544438
625319647B888A7D4A366D6D707C7E3E64828E94
BC6954AA94878990384997A4B0B3A3502AB2B3B8BBBC7D1A96A59B9A9A7834868475817B
5344838D948C905735A29B96A0A25561A5A6A9A9913E7C8B888C7E7951A2A2A9AB886374
A09687989E429D9B95A09E5679A0A6A7A698398CA8AAA5A45773AEB4B3B485157BA6A2A5
AB921E8B8F919CA4583597A0ADB4B44690AAB2B8
BB624DA3A6A0937F3149A49F9EABA85629AEB9BCB7B9741FA2A5908D8F722D889098907B
4733779199919A542C9DA29C9C9F5368A5A9A8A09443787B90946D4C56929AA6AEAA5877
9583848C824DA1A08E86965A7EACAAA99A9044A0B0B3B1AE6879ADB6B8B6890F6FA1A7AA
ADA61D81959DA09B4C41A7A9ABACA5438BABADB4
B76755A4A5A39D823C4C9F9E9AA4A45828ADB8B2AFB475229EA29C98946D378D99858B90
5F3D8EA4AAA4A47746A1A2A2919D5E67A7AEAFA2933B8E9F9186623A41767F8A93885179
8C7F838A8D478F9F988B9A6071A8A8A79C933AADB8B4B3B25C8BB7B9B6AA864481A5ABB1
B09F228A95A0A3A75F5CABA4917D7C378BA6AAAB
8952599B8A9A9B8C4724478A8E8B85491C4376969B625C2187878781783B274A59667685
5347788C92939049296E7A7B798C52516F7C797B6D2E75856853444833686D6369662F4C
6166636B6216004053596C44223D6E6C695A30555855484425555B66655E32155A747777
6C61284B5D69696F401C67695D4B4A3362696460
5F5A4E201325223D3F3F2C232C313A424916081521232A2D3233313C3D4040220A424942
392B3D454C4D4F56573D172E3D3A404A564D40363B51522D2144424C4143484E4E526263
5E223C556675838684787283868D6A37655164686C6E67556B7E81622C507E8886737276
726479796A414D6A6E818580735949698C883A51
A49DA0544A706A9AA1A0826D818BABAFA6400C9AA8A7A8A2A59F90889B989C6316A8A59E
947F92AEAEB0ADAFB49B21989F938A8391928E7482A3AB804DAA9B98808693959D9EA7A7
A33F5D85839595939698939E9FA2A26D9E8789A2A0A3928F8FAEB4B047ABA8A2A7A6A4A7
A2A29C96A3688AA19A919FA1997B52849EA93C68
9D94985260907494909486697E8FA6A6AA4B36A2A6A7AAAAA69F90819393966318A0A39C
967D85A6A6ACAFAFB1A1289998998A7789908F85849AA47E47A6A5897B78828E989AA6A8
A54767808B8C878489878590948C9771ADA0929C969D9C9195A5AAAF4C94A0AAAAA79EA3
A49F9DA1A34F8A9E9283969B98835184A0A44673
A9A39E5A5C9F799C9D9B98749897A5ACA85731A3ADAFAEABA7A2937D8D8D8E75189C999C
A1867CA2ABAEAFB0ACA1379B9DA29F85969A9C87849D987D5096A58B7E7C8A9A9CA3A5A8
A44958788E98857C7875828889948D6EA8A48B9F9FA4978D9AA9ABAB419AA7ACAEAFADAA
ABA999959453919B9D9D9C9CA3835C89A1A35580
9E93862D5198768E90969466817C91909C4E148B928B8987807D76685B645A480E6D7178
75745F817D7D74736D582A60707D646174726E625560653A3D737778706B606768605861
613A3B4F5672725E665C4D4437254D1B565B4F635F66544A5E5D6369225F706D70586970
686954383D4C505A6163605E5B463A4150492C34
3D33312D34383E383C200F12131310182535322A2D35313311312E2925221B22231F2327
241D13292D2231312B313F3F342A301D1D352821252F36393E33242619111E2D2F3F473E
392D3A36493D2D234F4D4F505D66665D473B4A4924475B5D5E58615A605B585457264560
6D7077788880746A6B8055306474788394999E9B
9499A7A7ABAAAFABA55B10777D7D7B8A91898B939C9AA1992F9D9495867C7F8794878F95
94752B989AA5A7A487A2A6A9AA9EA57266A6A6A49CA3A2A7A4A3A4A99147729A9B9B939C
96889693A1AC9759ADAAA3A8ADACB1AFA7AEADA75298B0A7A5A3A7A2A38D7C83A95580AF
AFADA698A69DA1A086A7764D998A9AA5AFB3B5B2
A085909C9CA1A5A59D8B2283909D9686877F8490929C9A983C92A6A3A188808B9494958E
9D8B356C727C76898A9A97A4A0A2A37F4E81887E84838B94908E9091925B5F8B8F9C9390
87848F979AA89068ABADA7A8AAABA8ACADB5B0A85BAAAEA49BA2AAABAC9B99A3A96087AD
ADADA79DA4A29EA093A8735F958894959AA5AEB1
A0878A95939E99968B7C3586959E9E8C8E7C6D8E9CA49E874298A3AAAA9889A1A3A4A6A2
A68536999FA69D80919884898C9BA2834D838784797C7F868E858D807E4F6E929098A69F
8B8F9C9D98A38C58B1B3ADB0ADACAEB2B4B7B5AD489EB0AAADAFB5AEB5ACA1A9AC5985AE
ACACA7A2A8A8A8A7A1B68568887B888186A1A8A8
A2929A9E8A8D91897B762780989DA69C9D998D80949A8365479EA2A6AB9F979DA0A49E96
927B308A999DA2837B7F6D6C6D8981554572777B796969736C6E7C76804C5E798285888D
8D7B8B8585815A2986938E8F83818285878A867F2D68827F8E898A70767E736E69314970
716F6B6555555A56534423293C373C4456625F5B
2C251A1E1211130B0D090A161A181F201D1D19131519141E382F29262525211B1A272824
1E1E171C10151A200F1D241621242D30343324231F1A132B343339352E384045413D3A22
20263339464B474D4436342F311F283326372E3C46474D4A4D4F23375C625E61636A6D67
68676E623A6D737A7F7A74716B70747A7D27668D
9B958A53AFA78484919D9DA3ADA8B5B2763C90A1A6ACA4A29E9689868B9D395C969DA997
908F8888879C9F9A2A82938C909098A09FA0A29E9E6F3AA7A5A7A19597A1A2A5A6A5A14E
6B989894A2A7ACAEAEAAA37B9144A0BBBEBCBAB9B9BFC4C3C5C74F7AB3B8B2AFB0ACACA5
8E9298844D88888B928F898B889397A09D3BA0B4
ABA7A94CAAAA9F9899A1A5A5A7ADACAE913E8D99989A9191928F93848098496F9EA6A694
8887847E83979A9124717579818E9A8E9593A4A8A6653CA4A29E9EA19A9594958E94A15C
638E9298878D9E97918D898B7F43B0BDBAB7B3BAB3B4BBBABFC16382ACACA1A3A19C9A99
7470776D4980808782847F7D7F7B859398379CA9
A69FA94DA7A7A5A2989F9E9798A7AFAC8D3F8C9BA5A7A49DA1A79F868E954666A3A8A498
8F877B787284999132747C8D8B8AA1A19F989BA39B2340A7A8A2A39D9395939E9E9EA663
567E8A99999EA49DA0A4948A9949B0C0B8B7B4B4ADA8A8ADBDCA6584A9A39C9898949291
7C7571675195989288847882807F899699298A96
ACA6984BABA79FA09897849081979B8F7940869CA8A9ACAEA9A59B9A9C8B256DA193A193
7574756E707F9994397F828A9488969B9B918D9D945542A4A9AAAAA39586799698989A68
4D788BA1A5A6949D97908B7C98539C9AACBEB0A498A095918D9E4D727E767E7572777372
5D574938335C63655B494349534D5353461C5E6A
5D473826373C383A37332C1C2126242A22103F474146484B59463633391A060D13131B19
1C1D1E191E201D1F1D171B1F201A2023192723252020212B3E3F39342C2308172B323130
2C3A3840535137241F2629373E3B3A37444B4E4C351E3B3D42434D4644443D4749491C3B
605F616B6A6270817D7C66397F797B80848C7A6F
989496999A988D98A0A0932269898596938C7E7C80919AA19E3264858688A4A398A3A09C
9C987E36879C9A9BA09DA29FA0A2A3A535817E80776E7591969391838271327B8693989C
9A9594A1A0A7A4567CAAA5A4A6A4A5A3A89A73726F50B6AB9EA3B3B3AA9E8FA5AAA452A1
9B8B7C7484767C94999472359A9A989BA08A8479
B7B0AEAEB0AEA7A5A4AAAB368FA9A9A48A77869B868BA1A49F3992A093A6A6A2928D8497
A08E794188A19DA2999D99898C98A5A939667E7E796C71777D7D7D7C7B8043817F7A8586
83908A939AA0AC607FA8A28B8682848D9B967E786344ADA8A7A2A5ABA6A4A1A4A39B469D
8D85776E7A75728993A178318C8D898FA0867A83
B7AEB1ADB4AFAAA7AAB2992A8BA4A7A2827881817E8C98A4A0379B988F9D969D9690848C
978B7E3D91A1A19F959B95979092A3A53362737F8668677278808288867F487F766E7881
7C787F7C9293AB6C7BA6A29A91939093A28C83846855AAA8B0ACAFA9A8A7A0A29D8C249C
A5866F695E6966909B9E7D48A29FA6A6AFA6A0A3
B8B3B4AAA9AEA9AAA3A09F499FA0A197897C7D78919A9BA3973D9B9992A4A0A58C907687
85837545939C93919E9E99978F949E9D456A6D817B80667475716B7C76774B6160636B71
6A737B888F969A697F8676838C8891968B7D6A664B4B8F8C8F8A8C897D7F7A7A7B5E176A
74664E3C363E364C5C5C462E444D4F41475A6664
6157614C45383E403D34291551504F43474951493C4447453F1A40493F3A3336362A1F17
18160F122A3335343A34302C1D2F311C2A241D1E211B1B232F29222E2B2C2E3432322B28
24295458523E2E393C3B3C3A343319304950574E585D5D5D5E4E4F2E2A404049484D5352
4B4F484E2E66708A9896A29A938B979685418590
857B863D56998C8F7D848796A8A39EA9A9343C7F7C83838385868E868F97945353679BA1
A4A89CA5A8A9A48EAA3C6B9A837B878F91827E7682837B167EA39CA793A0A2A7879092AB
7F5BA786A3ADB2AEA7A59C95999B4091B6B4B1ACAFB5BCBEC5C2C57397B9B5B8BABBBDC2
C1C1BCB45496B2B3B1A8A6ABACABABAEA3579CA4
ABB2B04A6B9F9B9085858A97A29EA8A8B05F5B9781827F7B77737E8179869851626491A7
A6A1839A9DA4A48EAC43718E7B797A7D7E7E7C7E7E857F208BA0A1A3979DA6A4797A86AC
975E96969D9EA2A39A9F9B919A933FB2BDB8B8B8BCBEC1C1BBC0BE6986AAAFA6A198A2A8
B7AEAEA857A3A6A3A5A4A4A4A2A5A7AB984F8B9D
AAACAA4664989C968B888B878F8D989FA758477D8A8A847A7875868678788B58625A83A5
9F9B77969B9E9F7CA13E647E74746F6F7578787D7879762E8C8A9791969EA4A687838BA4
8F4C9B999FA29FA39F9F8E9392933EB0BEBDBDBDB9BAB9B7B3B1AC54799A917675899764
A792948F5694A19F9C99989898A2A2A484368B99
AEADA341579B9F9F9A99A29F957C8C95A54E2E717784827D8A8D8B8B86868F5A4D648C96
8E926B7582918B6A692C437B7A786D717B8081786D67623E868B868686929AA79B94898B
5317858F85838B8C8784838D7F7938879C928F938782918F8E8C79406D58493B45494145
48363F3731464C554B4D484B4E49413A22132337
666C6133326066615B5C5C5A605B645A62353143433B4437352C3730372D2B2322282F31
22151612152E271E1711152B2B31493E4346483232433B121B23303F3C2C32403B322C19
1E2F372A1425353B4142162132312D33371B2F494E4E4E364B50657B8A665171706F6B64
236E746A6863292B6069767E761C73737A8F874A
76507C7A767E823536737B7A8C8B28519C9BA8AC943E6F999C9C91772895AAADA8AE5C2B
8D948F8A8A4622435A5D73833D356A6571706F302E6A79776F642F6D82758194580C7A95
928C9E7535AAAFADA49E2776ADAFB3BDB62EA5BBB9BBB7569DB8B9B6B28471A9B5B6B4A8
35A9AFA8A7A7416CA9B1B1B4A11F8077616B6C40
9354ABB0ABB0B15D70B5B7B8BCBD3662AEB3B9B7B74783B5B3AFB0832099A1A7A6A86542
A4ABA9AEAC59365A676B6E6C35357575776963282E5E6A6E686522667A72718C5C0D7A9C
9C9A946256AFB1A4958D2675A9A8B3BBB12DB0BCB9BBB95499B7BABBB98571B0B1ACA8A2
3CA8AFAAA4A44283B4B0B0B39C22877A677C864D
9456A4ABAAA49F4F79B9BCB9BABA4B68A4B4B8B9B73F86AFB0ACAF9837ABB1B1B0AB6136
99AAADAFAE5531595E5B4B673F468C87807267282F575861636125748B847E925F0D93B5
AEA4A16763B1B2B1B1AD337FA9AFB4BAB534B7B7BFBFBA549BBDBAB6B58973A09D9C927F
36A6ACABA8A33F80AEAEB0ACA637AB8B8791874A
945AA4ABA7A7A25277AFB0B0B2B85364818C9FA09A3188ADAAA6AB863BA5A7ADAD9B5A58
A3ABABB0B05E706573546073596FA499877D6F2C2E434A4A3E411C8B99908D95551C96AA
ABA3976F539FA9A9A5A338687473A8B3B23685828881753276837F7F6D41516D69665C56
285A62625B46234351524943321E3F323531301B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.504715 0.504715 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
0 -0.00787 translate
1.00787 1.00787 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FF
0000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FFFF80000000FFFF80000000FFFF8000FF8000
0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FFFF80000000FFFF80000000FF0000FFFF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FFFF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FFFF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FF0000FFFF80000000FFFF8000FF80000000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF80000000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FFFF80000000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF80000000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FFFF8000FF80000000FFFF8000FF80000000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FFFF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF80000000FF0000FFFF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
FF80000000FFFF80000000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FFFF80000000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
FF80000000FFFF80000000FFFF80000000FFFF8000FF8000FF80000000FF0000FFFF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Oooool0101hN7P0IVIV06IV
IP2<S8`207YjNP<0TI6A00@0Z:RX08R8R028R8P0Shn?0P1[Jf/01015ADD0S8b<08b<S01NGUh208^;
R`0406e]K@1GEeL0EeMG06IVIP<0NWYj0P1=CDd0101TI6@0LW9b079bLP1FEUH209BDU00406UYJ@2G
UiL0UiNG09FEU@80C4a<00<0T92@04e=C@1=CDd00`1aLG401@1bLW80emOG08B4Q024Q8@0GemO0080
ATI600@0MGEe0:b/[02/[:`0b/[:0P2TY:@0102b/[80YJFU0:FUY@2YZJT20:BTY00409^KV`1mOGd0
OGem06EUI@80Jf][00@0O7al0:JVYP2VYZH0_kno0P1aLG40102KVi/0UIFE09FEU@2UYJD20<g=c@04
08n?S`2a/K40/K6a0;no_`80ZZZZ00D0`l?304a<C01<C4`0RHV906=SH`0208^;R`0408>3P`1eMGD0
MGEe07AdM080X:2P00@0ZJVY07YjNP1jNWX0MWIf0P1DE5@0102[Zj/0`/;20<;2`P2/[:`20:BTY004
07QhN01ADE40DE5A0>7Qh@80X:2P00@0O7al07EeM@1eMGD0Hf=S0P1PH600102YZJT0]kNg0;Ng]`2I
VIT2055AD@0408Z:RP2CTi<0Ti>C08j>SP80RHV900D0TY:B0<C4a034a<@0MgMg04];B`020492@P04
03hn?P1eMGD0MGEe08>3P`80EeMG00@0Fe]K07MgM`1gMgL0OWin0P1`L7001022PX80G5aL05aLG01W
IfL205mOG`0407]kN`2CTi<0Ti>C08f=S@80SXj>00@0VYZJ09^KV`2KVi/0_;bl0P1kNg/0102LW9`0
YZJV0:JVYP1]KFd204I6AP0405aLG01OGel0GemO08f=S@80PX:200<0MGEeooooooooool03`000?l0
103oP000003o0000o`3oP0030000o`80oh0010000?l20?n00080003o0P3oP0060000o`040?n00000
0?l0003o0?n000D0003o00@0oh000000o`000?l0003o0P3oP0030000o`040?n000000?l0003o0?n0
00d0003o0P3oP0060000o`030?n000000?l0003o00<0oh0000@0003o0?n0003oP000oh003`000?l0
103oP000003o0000o`3oP0050000o`<0oh0020000?l20?n000030000o`3oP000oh0000L0003o0P3o
P0000`000?l0oh000?n000030?n000<0003o0`3oP0050000o`80oh0030000?l00`3oP000003o0000
o`040000o`<0oh001P000?l:ooooo`002Oooool0101aLG40E5AD05ADE01kNg/207MgM`0408J6QP2>
SXh0SXj>0:n_[`80NWYj00@0R8R807IfMP1fMWH0De=C0P28R8P0101KFe/0NGUi07UiN@1TI6@205=C
D`0406a/K026QXH0QXJ608b<S080D51@00@0FUYJ06EUI@1UIFD0DE5A0P20P800101YJFT0U9BD09BD
U02=SHd204Q8B00408f=S@1HF5P0F5QH0861P@80QXJ600D0N7Qh0=3@d02=SHd0SHf=06QXJ00204];
B`0407MgM`2ZZZX0ZZZZ0<30`080YZJV00@0[Zj^0:2PX02PX:00YJFU0P2PX:00102HV9P0Ng]k07]k
N`1XJ6P2075aL@0407IfMP2RXZ80XZ:R0<;2`P80MgMg00@0UIFE09nOW`2OWil0ZJVY0P2o_kl0101h
N7P0^KVi0;Vi^@2c/k<20::RXP050<?3``1EEED0EEEE08:2PP1QHF400P2?Shl01027QhL0LW9b079b
LP1^KVh20;2`/0040;6a/@1jNWX0NWYj08Z:RP80JFUY00@0V9RH0;no_`2o_kl0][Jf0P2UYJD0101e
MGD0Fe]K05]KF`3Lg=`209bLW00406YZJP1fMWH0MWIf07AdM080KVi^00@0^;Rh0;Vi^@2i^KT0Xj>S
0P1QHF40102:RXX0WIfM09fMW@2CTi<2092@T00509BDU03De=@0e=CD07moO`19BDT00P13@d<0100h
>3P0JVYZ06YZJP1dM7@205aLG00405QHF01NGUh0GUiN065QH@80IFEU00@0Shn?06][J`1[Jf/0JFUY
0P1KFe/01022PX80UIFE09FEU@2DU9@20::RXP<0W9bL00@0/K6a096AT@2ATI40Y:BT0P2_[jl0101j
NWX0D51@051@D01VIVH205mOG`0407AdM021PH40PH6107YjNP;ooooo00<0003o0?n0003oP0001P00
0?l00`3oP000003o0000o`030000o`040?n000000?l0003o0?n000<0003o0P3oP0040000o`<0oh00
00<0003o0?n0003oP0001P000?l0103oP000003o0000o`3oP0050000o`040?n000000?l0003o0000
o`80oh000`000?l0103oP000003o0000o`3oP00=0000o`80oh001P000?l00`3oP000003o0000o`03
0?n000040000o`3oP000oh000?n000T0003o0`3oP0060000o`<0oh000`000?l30?n000L0003o0`3o
P00:0000o`80oh0000<0003o0?n0003oP0000`3oP0030000o`@0oh001`000?l20?n000T0003o00@0
oh000000o`000?l0003o0P3oP0000`000?l0oh000?n000070000o`[ooooo0009ooooo`04075aL@1D
E5@0E5AD07]kN`80MgMg00@0QXJ608j>SP2>SXh0[jn_0P1jNWX01028R8P0MWIf07IfMP1CDe<208R8
R00405]KF`1iNGT0NGUi06ATI080De=C00@0K6a/08J6QP26QXH0S8b<0P1@D500101JFUX0IFEU06EU
I@1ADE420820P00406UYJ@2DU9@0U9BD08f=S@80B4Q800@0SHf=05QHF01HF5P0PH610P26QXH01@1h
N7P0d=3@08f=S@2=SHd0J6QX0080Bd];00@0MgMg0:ZZZP2ZZZX0`<300P2VYZH0102^[Zh0X:2P0:2P
X02UYJD20:2PX00409RHV01kNg/0Ng]k06QXJ080LG5a00@0MWIf0::RXP2RXZ80`/;20P1gMgL0102E
UID0WinO09nOW`2YZJT20;no_`0407QhN02i^KT0^KVi0;>c/`80XZ:R00D0`l?305EEE@1EEED0PX:2
065QH@0208n?S`0408N7Q`1bLW80LW9b06i^KP80/;2`00@0/K6a07YjNP1jNWX0RXZ:0P1YJFT0102H
V9P0_kno0;no_`2f][H20:FUY@0407EeM@1KFe/0Fe]K0=cLg080W9bL00@0JVYZ07IfMP1fMWH0M7Ad
0P1^KVh0102h^;P0^KVi0;Vi^@2SXj<2065QH@0408Z:RP2MWId0WIfM09>CT`80T92@00D0U9BD0=CD
e03De=@0Ogmo04U9B@0204=3@`0403Ph>01ZJVX0JVYZ07AdM080G5aL00@0F5QH05iNGP1NGUh0HF5Q
0P1UIFD0102?Shl0Jf][06][J`1YJFT205]KF`0408:2PP2EUID0UIFE09BDU080XZ:R0`2LW9`0102a
/K40TI6A096AT@2TY:@20:n_[`0407YjNP1@D500D51@06IVIP80GemO00@0M7Ad0861P@21PH40NWYj
0_ooool00`000?l0oh000?n000060000o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0
oh000`000?l20?n000@0003o0`3oP0000`000?l0oh000?n000060000o`040?n000000?l0003o0?n0
00D0003o00@0oh000000o`000?l0003o0P3oP0030000o`040?n000000?l0003o0?n000d0003o0P3o
P0060000o`030?n000000?l0003o00<0oh0000@0003o0?n0003oP000oh002@000?l30?n000H0003o
0`3oP0030000o`<0oh001`000?l30?n000X0003o0P3oP0000`000?l0oh000?n000030?n000<0003o
103oP0070000o`80oh002@000?l0103oP000003o0000o`000?l20?n000030000o`3oP000oh0000L0
003o2_ooool000Wooooo00@0Ogmo061PH01PH600PH610P1`L7001025QHD0NGUi07UiN@27QhL205eM
G@0407AdM01VIVH0IVIV03dm?@80M7Ad00@0GEeM08R8R028R8P0H61P0P1FEUH0101=CDd0Hf=S06=S
H`2HV9P205eMG@0405IFEP1MGEd0GEeM04Q8B080OWin00@0Lg=c09^KV`2KVi/0SXj>0P1;Bd/0102E
UID0G5aL05aLG01gMgL207IfMP0507inOP3AdM40Ph>308>3P`1YJFT00P1CDe<0101aLG40XJ6Q0:6Q
X@2c/k<209bLW0040:FUY@2JVYX0VYZJ0:f][@80V9RH00@0VIVI08j>SP2>SXh0OGem0`25QHD20;6a
/@040<[:bP1aLG40LG5a0:^[Z`80UIFE00@0XZ:R0;^k^`2k^k/0O7al0P2m_Kd0102^[Zh0YJFU0:FU
Y@3?cll205aLG0050820P01OGel0OWin07inOP1kNg/00P1XJ6P0101/K6`0Y:BT0:BTY02RXZ8207If
MP0407inOP1aLG40LG5a08N7Q`80a/K600@0_[jn0:b/[02/[:`0Lg=c0P1OGel0103AdM40U9BD09BD
U01MGEd208>3P`0407UiN@1gMgL0MgMg0::RXP80^KVi00@0[Jf]06YZJP1ZJVX0Ogmo0P2QXJ40102;
Rh/0Q8B408B4Q02DU9@20=OGe`0508>3P`14A4@0A4A404A4A00a<C400P1TI6@0102=SHd0IFEU06EU
I@1UIFD205eMG@0406MWI`1`L700L71`07IfMP80De=C00@0IfMW05iNGP1NGUh0N7Qh0P2>SXh0101o
Ogl0UYJF09JFUP2FUYH20:FUY@040;fm_@2RXZ80XZ:R0;jn_P80ZJVY00@0Jf][04m?C`1?Cdl0NWYj
0P1_Kfl0101^KVh0OWin07inOP1bLW82ooooo`X0003o0P3oP0030000o`040?n000000?l0003o0?n0
00<0003o0`3oP0030000o`H0oh001P000?l0103oP000003o0000o`3oP0050000o`040?n000000?l0
003o0000o`80oh000`000?l00`3oP000003o0000o`020000o`80oh002@000?l30?n000H0003o00<0
oh000000o`000?l00`3oP00010000?l0oh000?n0003oP00B0000o`<0oh0010000?l20?n000030000
o`3oP000oh0000D0003o0`3oP0090000o`80oh0000<0003o0?n0003oP0000`3oP0060000o`030?n0
00000?l0003o0080003o0P3oP0000`000?l0oh000?n000090000o`040?n000000?l0003o0?n000<0
003o0P3oP0070000o`[ooooo0009ooooo`0406][J`1FEUH0EUIF07emO@80L71`00@0OWin07EeM@1e
MGD0Y:BT0P1YJFT01025QHD0HF5Q065QH@13@d<20861P@0405iNGP1eMGD0MGEe055AD@80FEUI00@0
F5QH079bLP1bLW80Ng]k0P1MGEd01019BDT0EeMG05MGE`0m?Cd207YjNP04079bLP2IVIT0VIVI08b<
S080BTY:00@0RXZ:05aLG01LG5`0N7Qh0P1fMWH01@1gMgL0`<3008^;R`2;Rh/0Jf][0080BTY:00@0
O7al0:NWY`2WYjL0[:b/0P2[Zj/0102h^;P0WYjN09jNWP2MWId2096AT@0409VIV@1mOGd0OGem06i^
KP80JVYZ00@0Kfm_09RHV02HV9P0_Kfm0P1aLG40102PX:00Shn?08n?S`2MWId20;Vi^@0407IfMP2i
^KT0^KVi0:6QX@80VYZJ00D0_kno05eMG@1MGEd0PX:206MWI`0208J6QP0407emO@1OGel0GemO05aL
G080XZ:R00@0^k^k075aL@1aLG40QXJ60P25QHD01021PH40`l?30<?3``2e]KD20:j^[P0406UYJ@1f
MWH0MWIf0;bl_080S8b<00@0GUiN07QhN01hN7P0MWIf0P1]KFd0102EUID0b<S80<S8b02YZJT206=S
H`040861P@2CTi<0Ti>C06QXJ080L71`00D0Ogmo0;fm_@2m_Kd0N7Qh03/k>`0203hn?P04030`<01H
F5P0F5QH0820P080KFe]00@0L71`07UiN@1iNGT0QHF50P1[Jf/0101nOWh0FUYJ05YJFP1OGel204a<
C00406m_K`1oOgl0Ogmo07MgM`80Z:RX00@0IFEU07inOP1nOWh0MGEe0P1ZJVX0101oOgl0VIVI09VI
V@1^KVh205MGE`0405YJFP1cLg<0Lg=c08:2PP80NWYj00@0Ogmoooooooooool0003o0P3oP00<0000
o`040?n000000?l0003o0?n00080003o103oP0030000o`H0oh001P000?l0103oP000003o0000o`3o
P0050000o`040?n000000?l0003o0000o`80oh001P000?l00`3oP000003o0000o`0;0000o`80oh00
1P000?l0103oP000003o0000o`3oP0030000o`<0oh001`000?l20?n000030000o`3oP000oh0000H0
003o103oP0030000o`80oh0000<0003o0?n0003oP0001@000?l20?n000X0003o0P3oP0000`000?l0
oh000?n000040?n000X0003o0P3oP0000`000?l0oh000?n0000@0000o`<0oh001P000?l:ooooo`00
2Oooool0101[Jf/0EUIF05IFEP1mOGd2071`L00407inOP1eMGD0MGEe0:BTY080JFUY00@0QHF5065Q
H@1QHF40@d=30P21PH40101NGUh0MGEe07EeM@1ADE4205UIF@0405QHF01bLW80LW9b07]kN`80GEeM
00@0BDU905MGE`1GEeL0?Cdm0P1jNWX0101bLW80VIVI09VIV@2<S8`204Y:BP0408Z:RP1LG5`0G5aL
07QhN080MWIf00D0MgMg0<30`02;Rh/0Rh^;06][J`0204Y:BP0407alO02WYjL0YjNW0:b/[080Zj^[
00@0^;Rh09jNWP2NWYh0WIfM0P2ATI40102IVIT0OGem07emO@1^KVh206YZJP0406m_K`2HV9P0V9RH
0;fm_@80LG5a00@0X:2P08n?S`2?Shl0WIfM0P2i^KT0101fMWH0^KVi0;Vi^@2QXJ4209ZJVP050;no
_`1MGEd0GEeM08:2PP1WIfL00P26QXH0101mOGd0GemO05mOG`1LG5`20::RXP040;^k^`1aLG40LG5a
08J6QP80QHF500@0PH610<?3``33`l<0]KFe0P2^[Zh0101YJFT0MWIf07IfMP2l_;`208b<S00405iN
GP1hN7P0N7Qh07IfMP80KFe]00@0UIFE0<S8b038b<P0ZJVY0P1SHf<01021PH40Ti>C09>CT`1XJ6P2
071`L00507moO`2m_Kd0_Kfm07QhN00k>c/00P0n?Sh0100`<300F5QH05QHF020P80206e]K@04071`
L01iNGT0NGUi08F5Q@80Jf][00@0OWin05YJFP1JFUX0GemO0P1<C4`0101_Kfl0Ogmo07moO`1gMgL2
0:RXZ00406EUI@1nOWh0OWin07EeM@80JVYZ00@0Ogmo09VIV@2IVIT0KVi^0P1GEeL0101JFUX0Lg=c
07=cL`22PX8207YjNP0407moOooooooooooo0000o`80oh0030000?l0103oP000003o0000o`3oP002
0000o`@0oh000`000?l60?n000H0003o00@0oh000000o`000?l0oh001@000?l0103oP000003o0000
o`000?l20?n000H0003o00<0oh000000o`000?l02`000?l20?n000H0003o00@0oh000000o`000?l0
oh000`000?l30?n000L0003o0P3oP0000`000?l0oh000?n000060000o`@0oh000`000?l20?n00003
0000o`3oP000oh0000D0003o0P3oP00:0000o`80oh0000<0003o0?n0003oP000103oP00:0000o`80
oh0000<0003o0?n0003oP00040000?l30?n000H0003o2_ooool000Wooooo00@0MgMg06MWI`1WIfL0
QhN70P21PH40102DU9@0R8R808R8R02MWId205mOG`0408R8R01fMWH0MWIf04m?C`80Rh^;00@0HV9R
09JFUP2FUYH0I6AT0P1eMGD0101TI6@0O7al07alO023Ph<206MWI`04051@D01OGel0GemO0492@P80
OWin00@0Jf][092@T02@T900Rh^;0P1;Bd/01022PX80GemO05mOG`1gMgL2075aL@0507MgM`3@d=00
VYZJ09ZJVP1XJ6P00P17AdL00`1jNWX0];Bd0;Bd]0030;no_`040;Ng]`2LW9`0W9bL09fMW@80UiNG
00@0V9RH08J6QP26QXH0O7al0P1fMWH0101`L700V9RH09RHV02/[:`206a/K00409VIV@2EUID0UIFE
0:RXZ080];Bd00@0OWin0<C4a034a<@0[:b/0P2SXj<01@35aLD0FUYJ05YJFP20P800Hf=S0080Ogmo
00@0O7al06a/K01/K6`0Kfm_0P2OWil0102m_Kd0Ti>C09>CT`28R8P208B4Q00408f=S@2l_;`0_;bl
0;:b/P80YjNW00@0IVIV075aL@1aLG40^k^k0P2:RXX0101KFe/0QHF508F5Q@29RHT207YjNP040:2P
X036a/H0a/K60:6QX@80L71`00@0K6a/09BDU02DU9@0HF5Q0P22PX801@1mOGd0[Zj^0:j^[P1aLG40
=SHf0080=3@d00@0<C4a04i>CP1>CTh0L71`0P1cLg<0101/K6`0RHV908V9R@21PH4207UiN@0409NG
U`1ZJVX0JVYZ07EeM@80Fe]K00@0N7Qh06i^KP1^KVh0NGUi0P2RXZ80101jNWX0Y:BT0:BTY02RXZ82
0820P0040:NWY`2d];@0];Bd07]kN`80G5aL00@0DU9B06][J`1[Jf/0Ng]k0P29RHT00`1fMWKooooo
ooooo`0?0000o`030?n000000?l0003o00`0003o00@0oh000000o`3oP000oh001P000?l00`3oP000
003o0000o`060000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0003oP000103oP00E0000
o`040?n000000?l0003o0?n000<0003o0`3oP00:0000o`80oh001P000?l30?n000@0003o0P3oP000
0`000?l0oh000?n000050000o`80oh002P000?l20?n000030000o`3oP000oh0000@0oh003@000?l2
0?n000d0003o0P3oP00010000?l0oh000?n0003oP0060000o`[ooooo0009ooooo`040820P01PH600
H61P08Z:RP80M7Ad00@0Shn?0861P@21PH40/[:b0P1[Jf/0102=SHd0NGUi07UiN@1EEED208R8R004
06EUI@2ATI40TI6A055AD@80GEeM00@0I6AT08B4Q024Q8@0TY:B0P1^KVh0101MGEd0FEUI05UIF@1D
E5@207emO@0406YZJP2LW9`0W9bL09ZJVP80BTY:00@0Ph>305IFEP1FEUH0LG5a0P1WIfL01@21PH40
c<c<07emO@1mOGd0GEeM0080@D5100<0O7al0:j^[P2^[Zh00`2l_;`0102j^[X0VYZJ09ZJVP2EUID2
09ZJVP040::RXP24Q8@0Q8B407alO080Kfm_00@0N7Qh09ZJVP2JVYX0^;Rh0P1iNGT0102NWYh0M7Ad
07AdM02n_[h20;Vi^@0408>3P`2i^KT0^KVi0:b/[080Z:RX00D0`<3005IFEP1FEUH0PX:2061PH002
07emO@0408b<S01DE5@0E5AD05eMG@80UIFE00@0`/;207inOP1nOWh0P8200P1dM7@01024Q8@0`l?3
0<?3``2k^k/20<S8b00407UiN@1nOWh0OWin0<G5a@80Ph>300@0EeMG08^;R`2;Rh/0QXJ60P1jNWX0
102WYjL0bLW90<W9b@2g]kL206m_K`0408Z:RP2JVYX0VYZJ075aL@80UYJF00D0SHf=0;Vi^@2i^KT0
OGem0492@P0303`l?080De=C00@0NGUi07alO01lO7`0KVi^0`2;Rh/208:2PP0409FEU@1YJFT0JFUY
06UYJ@80N7Qh00@0Ng]k09NGU`2GUiL0UIFE0P2b/[801027QhL0[:b/0:b/[02@T90208R8R00409fM
W@2_[jl0[jn_07alO080D51@00@0GemO06ATI01TI6@0NGUi0P23Ph<00`1XJ6Soooooooooo`090000
o`030?n000000?l0003o00<0003o00<0oh000000o`000?l00`000?l30?n000H0003o103oP0060000
o`040?n000000?l0003o0?n000D0003o00<0oh000000o`000?l00`3oP0000`000?l0oh000?n00004
0?n000d0003o0P3oP0040000o`<0oh000P000?l0103oP000003o0000o`000?l30?n000H0003o0`3o
P0000`000?l0oh000?n000060000o`@0oh000`000?l20?n000030000o`3oP000oh0000D0003o0`3o
P0090000o`80oh0000<0003o0?n0003oP000103oP00C0000o`80oh001`000?l20?n000030000o`3o
P000oh0000L0003o2_ooool000Wooooo00@0P820061PH01PH600RXZ:0P1dM7@0102?Shl0PH610861
P@2b/[8206][J`0408f=S@1iNGT0NGUi05EEE@80R8R800@0IFEU096AT@2ATI40DE5A0P1MGEd0101T
I6@0Q8B408B4Q02BTY8206i^KP0405eMG@1IFET0FEUI05ADE080OGem00@0JVYZ09bLW02LW9`0VYZJ
0P1:BTX01023Ph<0EUIF05IFEP1aLG4206MWI`050861P@3<c<`0OGem07emO@1MGEd00P11@D400`1l
O7`0[Zj^0:j^[P030;bl_0040;Zj^P2JVYX0VYZJ09FEU@80VYZJ00@0XZ:R08B4Q024Q8@0O7al0P1_
Kfl0101hN7P0VYZJ09ZJVP2h^;P207UiN@0409jNWP1dM7@0M7Ad0;jn_P80^KVi00@0Ph>30;Vi^@2i
^KT0[:b/0P2XZ:P01@30`<00EUIF05IFEP22PX80H61P0080OGem00@0S8b<05ADE01DE5@0GEeM0P2E
UID01032`/80OWin07inOP20P80207AdM00408B4Q033`l<0`l?30;^k^`80b<S800@0NGUi07inOP1n
OWh0aLG50P23Ph<0101GEeL0Rh^;08^;R`26QXH207YjNP040:NWY`39bLT0bLW90;Ng]`80Kfm_00@0
RXZ:09ZJVP2JVYX0LG5a0P2FUYH01@2=SHd0^KVi0;Vi^@1mOGd0@T9200<0?3`l0P1CDe<0101iNGT0
O7al07alO01^KVh308^;R`80PX:200@0UIFE06UYJ@1YJFT0JFUY0P1hN7P0101kNg/0UiNG09NGU`2E
UID20;:b/P0408N7Q`2/[:`0[:b/092@T080R8R800@0WIfM0:n_[`2_[jl0O7al0P1@D500101OGel0
I6AT06ATI01iNGT208>3P`0306QXJ?oooooooooo00T0003o00<0oh000000o`000?l00`000?l00`3o
P000003o0000o`030000o`<0oh001P000?l40?n000H0003o00@0oh000000o`000?l0oh001@000?l0
0`3oP000003o0000o`030?n000030000o`3oP000oh0000@0oh003@000?l20?n000@0003o0`3oP002
0000o`040?n000000?l0003o0000o`<0oh001P000?l30?n000030000o`3oP000oh0000H0003o103o
P0030000o`80oh0000<0003o0?n0003oP0001@000?l30?n000T0003o0P3oP0000`000?l0oh000?n0
00040?n001<0003o0P3oP0070000o`80oh0000<0003o0?n0003oP0001`000?l:ooooo`002Oooool0
1026QXH0KVi^06i^KP2;Rh/206a/K00407moO`1kNg/0Ng]k0:b/[080GUiN00@0L71`06YZJP1ZJVX0
@d=30P20P800101ZJVX0P8200820P00n?Sh205iNGP0405ADE01gMgL0MgMg08n?S`80JVYZ00@0HF5Q
05UIF@1IFET0AdM70P1iNGT0101UIFD0U9BD09BDU02NWYh204Y:BP0408R8R01KFe/0Fe]K08f=S@80
O7al00D0Ogmo0=;BdP24Q8@0Q8B405YJFP0203Lg=`0406ATI02DU9@0U9BD0:JVYP80Vi^K00@0[:b/
09nOW`2OWil0X:2P0P2MWId0102VYZH0Ph>308>3P`1eMGD3075aL@80VYZJ00@0YZJV06YZJP1ZJVX0
XZ:R0P1gMgL0102a/K40aLG50<G5a@1oOgl20;Ng]`040:^[Z`2OWil0WinO0;Fe]@80CTi>00D0MGEe
05eMG@1dM7@0M7Ad07QhN00206m_K`0406EUI@2MWId0WIfM0;:b/P80Ng]k00@0Ogmo08F5Q@25QHD0
VIVI0P2m_Kd0102YZJT0/k>c0;>c/`1eMGD207MgM`040;Zj^P2BTY80TY:B06=SH`80S8b<00@0PH61
07EeM@1eMGD0XZ:R0P37alL0102OWil0De=C05=CD`2f][H20:VYZ@0406e]K@2?Shl0Shn?09:BTP80
b/[:00D0Ogmo04E5A@0g=cL0=cLg03dm?@0204Y:BP0407=cL`1jNWX0NWYj071`L080R8R800@0T92@
07alO01lO7`0UiNG0P1YJFT0101gMgL0Jf][06][J`1cLg<207moO`0407YjNP2FUYH0UYJF079bLP80
VYZJ00@0RHV908N7Q`27QhL0WinO0P2a/K401026QXH0DE5A055AD@1WIfL206UYJ@040861P@1VIVH0
IVIV07alO0;ooooo2P000?l20?n000<0003o00<0oh000000o`000?l00`000?l40?n000H0003o0`3o
P0060000o`040?n000000?l0003o0?n000D0003o00<0oh000000o`000?l00`3oP00J0000o`<0oh00
0P000?l0103oP000003o0000o`000?l30?n00080003o00<0oh000000o`000?l01@000?l20?n000H0
003o00@0oh000000o`000?l0oh000`000?l20?n000P0003o0P3oP00010000?l0oh000?n0003oP006
0000o`80oh0000<0003o0?n0003oP000103oP00L0000o`80oh0000<0003o0?n0003oP0001`000?l:
ooooo`002Oooool0101oOgl0G5aL05aLG020P80206MWI`0407inOP2=SHd0SHf=0<71`@80JFUY00@0
Ti>C06IVIP1VIVH0@D510P25QHD0101MGEd0SXj>08j>SP1:BTX205mOG`0406QXJ01ZJVX0JVYZ08>3
P`80OWin00@0GUiN05QHF01HF5P0ADE50P1WIfL0101_Kfl0WYjN09jNWP2IVIT204U9B@0408>3P`1P
H600H61P08J6QP80MGEe00D0P8200=CDe02<S8`0S8b<06ATI0020451@@0408J6QP31`L40`L710<[:
bP80[jn_00@0][Jf09ZJVP2JVYX0V9RH0P2OWil0102CTi<0MgMg07MgM`1dM7@206ATI00407AdM02J
VYX0VYZJ0;2`/080GUiN00@0SXj>096AT@2ATI40ZJVY0P39bLT0101oOgl0[Zj^0:j^[P2`/;0209^K
V`050;:b/P1;Bd/0Bd];07IfMP1PH6000P1lO7`0101oOgl0GEeM05eMG@1[Jf/209:BTP030;no_`1l
O7`0O7al00<0Ph>300@0UiNG0<71`@31`L40/K6a0P30`<00101gMgL0OWin07inOP2h^;P208N7Q`04
061PH02>SXh0SXj>06YZJP80MGEe00@0W9bL0<O7a`37alL0Z:RX0P1SHf<01020P800X:2P0:2PX01S
Hf<208:2PP0508^;R`32`/80`/;207alO014A4@00P0n?Sh30492@P0406i^KP1lO7`0O7al06m_K`80
K6a/00@0QHF506m_K`1_Kfl0SHf=0P1UIFD0101WIfL0Hf=S06=SH`1iNGT207AdM00408>3P`2k^k/0
^k^k08J6QP80_kno00@0PH6108^;R`2;Rh/0YJFU0P2^[Zh0101nOWh0DE5A055AD@1YJFT2071`L004
08J6QP2>SXh0SXj>07emO@;ooooo00<0003o0?n0003oP0001P000?l00`3oP000003o0000o`030000
o`040?n000000?l0003o0?n00080003o00<0oh000000o`000?l01P000?l40?n000H0003o00<0oh00
0000o`000?l01P000?l0103oP000003o0000o`000?l20?n000030000o`3oP000oh0000@0oh003@00
0?l30?n000D0003o00<0oh000000o`000?l00`3oP00010000?l0oh000?n0003oP0060000o`040?n0
00000?l0003o0000o`80oh001P000?l40?n000<0003o0P3oP0080000o`80oh002P000?l20?n00003
0000o`3oP000oh0000@0oh004`000?l20?n000030000o`3oP000oh0000@0003o0P3oP0000`000?l0
oh000?n000070000o`[ooooo0009ooooo`0407moO`1LG5`0G5aL0820P080IfMW00@0OWin08f=S@2=
SHd0`L710P1YJFT0102CTi<0IVIV06IVIP11@D4208F5Q@0405eMG@2>SXh0SXj>04Y:BP80GemO00@0
J6QX06YZJP1ZJVX0Ph>30P1nOWh0101NGUh0F5QH05QHF015ADD206MWI`0406m_K`2NWYh0WYjN09VI
V@80BDU900@0Ph>3061PH01PH600QXJ60P1eMGD01@20P800e=CD08b<S02<S8`0I6AT0080@D5100@0
QXJ60<71`@31`L40b/[:0P2_[jl0102f][H0VYZJ09ZJVP2HV9P209nOW`0409>CT`1gMgL0MgMg07Ad
M080I6AT00@0M7Ad09ZJVP2JVYX0/;2`0P1NGUh0102>SXh0TI6A096AT@2YZJT20<W9b@0407moO`2^
[Zh0[Zj^0;2`/080Vi^K00D0/[:b04];B`1;Bd/0MWIf061PH00207alO00407moO`1MGEd0GEeM06][
J`80TY:B00<0_kno07alO01lO7`00`23Ph<0102GUiL0`L710<71`@2a/K420<30`00407MgM`1nOWh0
OWin0;Rh^080QhN700@0H61P08j>SP2>SXh0JVYZ0P1eMGD0102LW9`0alO70<O7a`2XZ:P206=SH`04
0820P02PX:00X:2P06=SH`80PX:200D0Rh^;0<;2`P32`/80O7al04A4A00203hn?P<0@T9200@0KVi^
07alO01lO7`0Kfm_0P1/K6`01025QHD0Kfm_06m_K`2=SHd206EUI@0406MWI`1SHf<0Hf=S07UiN@80
M7Ad00@0Ph>30;^k^`2k^k/0QXJ60P2o_kl01021PH40Rh^;08^;R`2UYJD20:j^[P0407inOP1ADE40
DE5A06UYJ@80L71`00@0QXJ608j>SP2>SXh0OGem0_ooool00`000?l0oh000?n000060000o`030?n0
00000?l0003o00<0003o00@0oh000000o`000?l0oh000P000?l00`3oP000003o0000o`060000o`@0
oh001P000?l00`3oP000003o0000o`060000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0
003oP000103oP00=0000o`<0oh001@000?l00`3oP000003o0000o`030?n000040000o`3oP000oh00
0?n000H0003o00@0oh000000o`000?l0003o0P3oP0060000o`@0oh000`000?l20?n000P0003o0P3o
P00:0000o`80oh0000<0003o0?n0003oP000103oP00C0000o`80oh0000<0003o0?n0003oP0001000
0?l20?n000030000o`3oP000oh0000L0003o2_ooool000Wooooo00@0RHV907IfMP1fMWH0V9RH0P1]
KFd01022PX80Ogmo07moO`2`/;0206ATI00407=cL`1/K6`0K6a/04Y:BP80SHf=00@0HV9R09FEU@2E
UID0D51@0P1MGEd0101hN7P0S8b<08b<S02CTi<206e]K@0405ADE01>CTh0CTi>059BDP80IFEU00@0
Lg=c09jNWP2NWYh0WinO0P1@D5001022PX80GemO05mOG`1lO7`206m_K`0507alO036a/H0OWin07in
OP1KFe/00P0n?Sh0101gMgL0][Jf0;Jf]P36a/H20;Fe]@040;Ng]`2TY:@0Y:BT09RHV080Vi^K00@0
Q8B407AdM01dM7@0M7Ad0P1eMGD0102ATI40[Zj^0:j^[P36a/H207MgM`0409ZJVP2IVIT0VIVI0:RX
Z080b/[:00@0PX:20;Ng]`2g]kL0_[jn0P2QXJ401@2a/K40CTi>04i>CP24Q8@0IfMW0080PX:200@0
Ph>306=SH`1SHf<0Hf=S0P2BTY80102o_kl0QXJ608J6QP1nOWh207IfMP040820P02^[Zh0[Zj^0<71
`@80/K6a00@0NWYj07]kN`1kNg/0ZJVY0P28R8P0101MGEd0Q8B408B4Q01aLG42071`L004096AT@2l
_;`0_;bl0;2`/080Lg=c00@0P82009FEU@2EUID0IVIV0P1jNWX01@2:RXX0a<C40<C4a021PH40BTY:
0080>SXj0`0o?cl0101YJFT0LW9b079bLP1fMWH208J6QP0408Z:RP1`L700L71`08b<S080IfMW00@0
G5aL05mOG`1OGel0Ph>30P2HV9P0102ATI40aLG50<G5a@1lO7`20;^k^`0407=cL`20P800P82009:B
TP80Shn?00@0IfMW055AD@1ADE40DU9B0P1]KFd0102EUID0U9BD09BDU01iNGT2ooooo`T0003o00<0
oh000000o`000?l00`000?l00`3oP000003o0000o`030000o`<0oh001P000?l40?n000H0003o00<0
oh000000o`000?l01P000?l00`3oP000003o0000o`030?n000030000o`3oP000oh0000@0oh003000
0?l30?n000H0003o00<0oh000000o`000?l00`3oP00010000?l0oh000?n0003oP00:0000o`80oh00
1P000?l40?n000H0003o0P3oP0050000o`<0oh002@000?l20?n000030000o`3oP000oh0000@0oh00
30000?l00`3oP000003o0000o`040000o`80oh0000<0003o0?n0003oP0001`000?l30?n000H0003o
2_ooool000Wooooo00@0Ng]k05iNGP1NGUh0P8200P1CDe<01027QhL0S8b<08b<S02j^[X207MgM`04
08:2PP1bLW80LW9b04m?C`80Ti>C00@0GemO09bLW02LW9`0CDe=0P1JFUX0101kNg/0OWin07inOP2B
TY8207EeM@0405aLG01<C4`0C4a<04M7A`80Hf=S00@0Kfm_09BDU02DU9@0W9bL0P15ADD0101oOgl0
CDe=04e=C@1aLG420861P@0508>3P`3Fe]H0QhN708N7Q`1OGel00P12@T80101[Jf/0UiNG09NGU`2X
Z:P20:>SX`030::RXP2;Rh/0Rh^;00<0TI6A00@0P8200861P@21PH40IfMW0P1YJFT01023Ph<0V9RH
09RHV02UYJD207QhN0<0V9RH00@0ZZZZ0;no_`2o_kl0NWYj0P2[Zj/0102d];@0WYjN09jNWP2o_kl2
03Lg=`05075aL@1SHf<0Ph>308>3P`25QHD00P1YJFT0101SHf<0Z:RX0:RXZ034a<@209ZJVP0407Ui
N@20P800P82007moO`80/;2`00@0][Jf0;Fe]@2e]KD0T92@0P24Q8@0102KVi/0Rh^;08^;R`1jNWX2
08V9R@0407QhN01aLG40LG5a09JFUP80b/[:00@0[Jf]06ATI01TI6@0Ng]k0P2GUiL0101OGel0FUYJ
05YJFP1gMgL20<G5a@0507inOP16ATH0>3Ph03Ph>00i>CT00P0m?Cd0101JFUX0Cdm?04m?C`1KFe/2
05iNGP0407alO01PH600H61P096AT@80I6AT00@0JFUY06EUI@1UIFD0MWIf0P20P800101YJFT0UYJF
09JFUP1]KFd20;Ng]`0407=cL`2BTY80TY:B09fMW@80TY:B00@0MgMg04];B`1;Bd/0C4a<0P1UIFD0
101jNWX0QhN708N7Q`23Ph<2ooooo`040000o`3oP000oh000000o`80oh000`000?l00`3oP000003o
0000o`030000o`030?n000000?l0003o00<0003o0`3oP0060000o`@0oh001P000?l0103oP000003o
0000o`3oP0050000o`040?n000000?l0003o0000o`80oh0070000?l0103oP000003o0000o`000?l2
0?n000040000o`3oP000oh000?n000X0003o0P3oP0060000o`@0oh003@000?l30?n000H0003o0P3o
P00010000?l0oh000?n000000?l<0?n00100003o0P3oP0070000o`<0oh001P000?l:ooooo`002Ooo
ool0101kNg/0GUiN05iNGP20P80205=CD`0408N7Q`2<S8`0S8b<0;Zj^P80MgMg00@0PX:2079bLP1b
LW80Cdm?0P2CTi<0101OGel0W9bL09bLW01=CDd205YJFP0407]kN`1nOWh0OWin09:BTP80MGEe00@0
G5aL04a<C01<C4`0AdM70P1SHf<0101_Kfl0U9BD09BDU02LW9`204E5A@0407moO`1=CDd0CDe=075a
L@80PH6100D0Ph>30=KFeP27QhL0QhN705mOG`020492@P0406][J`2GUiL0UiNG0:RXZ080Xj>S00<0
XZ:R08^;R`2;Rh/00`2ATI401020P800PH610861P@1WIfL206UYJ@0408>3P`2HV9P0V9RH0:FUY@80
N7Qh0`2HV9P0102ZZZX0_kno0;no_`1jNWX20:^[Z`040;Bd]02NWYh0WYjN0;no_`80=cLg00D0LG5a
06=SH`23Ph<0Ph>308F5Q@0206UYJ@0406=SH`2XZ:P0Z:RX0<C4a080VYZJ00@0NGUi0820P020P800
Ogmo0P2`/;00102f][H0]KFe0;Fe]@2@T90208B4Q00409^KV`2;Rh/0Rh^;07YjNP80RHV900@0N7Qh
075aL@1aLG40UYJF0P3:b/X0102][Jd0I6AT06ATI01kNg/209NGU`0405mOG`1JFUX0FUYJ07MgM`80
aLG500D0OWin04I6AP0h>3P0>3Ph03Ti>@0203dm?@0405YJFP1?Cdl0Cdm?05]KF`80GUiN00@0O7al
061PH01PH600TI6A0P1TI6@0101YJFT0IFEU06EUI@1fMWH20820P00406UYJ@2FUYH0UYJF06e]K@80
]kNg00@0Lg=c09:BTP2BTY80WIfM0P2BTY80101gMgL0Bd];04];B`1<C4`206EUI@0407YjNP27QhL0
QhN708>3P`;ooooo00@0003o0?n0003oP000003o0P3oP0030000o`030?n000000?l0003o00<0003o
00<0oh000000o`000?l00`000?l30?n000H0003o103oP0060000o`040?n000000?l0003o0?n000D0
003o00@0oh000000o`000?l0003o0P3oP00L0000o`040?n000000?l0003o0000o`80oh0000@0003o
0?n0003oP000oh002P000?l20?n000H0003o103oP00=0000o`<0oh001P000?l20?n000040000o`3o
P000oh000000o``0oh0040000?l20?n000L0003o0`3oP0060000o`[ooooo0009ooooo`0407emO@1T
I6@0I6AT08n?S`80GemO00@0QXJ606m_K`1_Kfl0NWYj0P1eMGD0101bLW80IFEU06EUI@13@d<207mo
O`04061PH02JVYX0VYZJ04a<C080EUIF00@0SXj>08F5Q@25QHD0SXj>0P1TI6@0101;Bd/0ATI604I6
AP1:BTX205mOG`0407QhN02IVIT0VIVI09fMW@80BDU900@0RHV905UIF@1IFET0KFe]0P1cLg<01@1]
KFd0^k^k07]kN`1kNg/0E5AD0080?Cdm00@0Jf][09bLW02LW9`0[:b/0P2SXj<0102`/;00Vi^K09^K
V`2MWId209NGU`0408j>SP2:RXX0RXZ:06][J`80L71`00@0Ng]k09VIV@2IVIT0`/;20P20P800102K
Vi/0T92@092@T02YZJT20<30`00408>3P`2VYZH0YZJV09bLW080V9RH00D0^[Zj03Ti>@0i>CT0IFEU
04i>CP0206MWI`0406EUI@1NGUh0GUiN06EUI@80U9BD00@0ZZZZ08f=S@2=SHd0G5aL0P1_Kfl0101n
OWh0YjNW0:NWY`32`/820;Bd]00408B4Q01mOGd0OGem09ZJVP80WYjN00@0SHf=07]kN`1kNg/0Ng]k
0P1SHf<0102=SHd0][Jf0;Jf]P2TY:@205QHF00408n?S`24Q8@0Q8B407EeM@80Fe]K00D0L71`0;Fe
]@2e]KD0Ti>C04a<C00203Xj>P0403Ph>01?Cdl0Cdm?06=SH`80K6a/00@0JVYZ07IfMP1fMWH0LW9b
0P1PH600101bLW80GEeM05eMG@1>CTh205aLG00407alO028R8P0R8R808J6QP80Zj^[00@0TY:B0<o?
c`3?cll0KFe]0P27QhL0102<S8`0O7al07alO01WIfL2051@D00405eMG@1OGel0GemO06EUI@<0L71`
0_ooool?0000o`030?n000000?l0003o00<0003o0`3oP0060000o`@0oh001P000?l0103oP000003o
0000o`3oP0050000o`030?n000000?l0003o00<0oh001P000?l00`3oP000003o0000o`0;0000o`80
oh001P000?l00`3oP000003o0000o`040000o`<0oh000P000?l01@3oP000003o0000o`000?l0oh00
00H0003o0P3oP0040000o`<0oh003@000?l20?n000030000o`3oP000oh0000@0003o0P3oP0001000
0?l0oh000?n000000?l60?n000X0003o1@3oP0070000o`80oh001`000?l30?n000H0003o2_ooool0
00Wooooo00@0PX:2075aL@1aLG40Shn?0P1BDU80101fMWH0Lg=c07=cL`2>SXh206QXJ004075aL@1W
IfL0IfMW04E5A@80N7Qh00@0Fe]K08j>SP2>SXh0BDU90P1BDU80102FUYH0PX:208:2PP2IVIT2071`
L004061PH01GEeL0EeMG05eMG@80I6AT00@0LG5a08b<S02<S8`0Vi^K0P0o?cl01025QHD0Cdm?04m?
C`1WIfL207AdM00507YjNP3;bl/0Rh^;08^;R`1[Jf/00P16ATH0101mOGd0^;Rh0;Rh^02k^k/20:f]
[@040:ZZZP2;Rh/0Rh^;09NGU`80UYJF00@0QXJ608F5Q@25QHD0HV9R0P1aLG40101jNWX0Vi^K09^K
V`3;bl/207MgM`0409VIV@27QhL0QhN70:JVYP80^k^k00@0Vi^K0:^[Z`2[Zj/0/k>c0P2NWYh01@33
`l<0@D510451@@20P800LG5a0080RHV900@0Ph>305eMG@1MGEd0Fe]K0P2g]kL0102e]KD0RHV908V9
R@1MGEd2065QH@0408R8R02/[:`0[:b/0=?Cd`80[jn_00@0QhN707MgM`1gMgL0S8b<0P2KVi/0102S
Xj<0L71`071`L01PH60205YJFP0407=cL`2a/K40/K6a09fMW@80Hf=S00@0Vi^K0:2PX02PX:00NGUi
0P1HF5P01@1fMWH0`l?30<?3``2YZJT0EEEE0080BDU900@0>CTi05MGE`1GEeL0Ng]k0P1`L700101i
NGT0Kfm_06m_K`1dM7@206i^KP04071`L01iNGT0NGUi06=SH`80MgMg00@0KVi^07moO`1oOgl0VYZJ
0P2KVi/0102@T900Zj^[0:^[Z`18B4P207QhN00409FEU@2FUYH0UYJF0861P@80IVIV00@0FEUI06YZ
JP1ZJVX0JFUY0P2;Rh/00`24Q8Coooooooooo`040000o`80oh002@000?l0103oP000003o0000o`3o
P0020000o`<0oh001`000?l30?n000H0003o00@0oh000000o`000?l0oh001@000?l0103oP000003o
0000o`000?l20?n000030000o`3oP000oh0000<0oh003P000?l20?n000H0003o00@0oh000000o`00
0?l0003o0P3oP00010000?l0oh000?n0003oP0060000o`H0oh0000<0003o0?n0003oP00010000?l3
0?n000/0003o00@0oh000000o`3oP000oh001`000?l20?n000040000o`3oP000oh000000o`H0oh00
60000?l00`3oP000003o0000o`060000o`030?n000000?l0003o00@0003o2_ooool000Wooooo00@0
PX:2075aL@1aLG40Shn?0P1BDU80101fMWH0Lg=c07=cL`2>SXh206QXJ004075aL@1WIfL0IfMW04E5
A@80N7Qh00@0Fe]K08j>SP2>SXh0BDU90P1BDU80102FUYH0PX:208:2PP2IVIT2071`L004061PH01G
EeL0EeMG05eMG@80I6AT00@0LG5a08b<S02<S8`0Vi^K0P0o?cl01025QHD0Cdm?04m?C`1WIfL207Ad
M00507YjNP3;bl/0Rh^;08^;R`1[Jf/00P16ATH0101mOGd0^;Rh0;Rh^02k^k/20:f][@040:ZZZP2;
Rh/0Rh^;09NGU`80UYJF00@0QXJ608F5Q@25QHD0HV9R0P1aLG40101jNWX0Vi^K09^KV`3;bl/207Mg
M`0409VIV@27QhL0QhN70:JVYP80^k^k00@0Vi^K0:^[Z`2[Zj/0/k>c0P2NWYh01@33`l<0@D510451
@@20P800LG5a0080RHV900@0Ph>305eMG@1MGEd0Fe]K0P2g]kL0102e]KD0RHV908V9R@1MGEd2065Q
H@0408R8R02/[:`0[:b/0=?Cd`80[jn_00@0QhN707MgM`1gMgL0S8b<0P2KVi/0102SXj<0L71`071`
L01PH60205YJFP0407=cL`2a/K40/K6a09fMW@80Hf=S00@0Vi^K0:2PX02PX:00NGUi0P1HF5P01@1f
MWH0`l?30<?3``2YZJT0EEEE0080BDU900@0>CTi05MGE`1GEeL0Ng]k0P1`L700101iNGT0Kfm_06m_
K`1dM7@206i^KP04071`L01iNGT0NGUi06=SH`80MgMg00@0KVi^07moO`1oOgl0VYZJ0P2KVi/0102@
T900Zj^[0:^[Z`18B4P207QhN00409FEU@2FUYH0UYJF0861P@80IVIV00@0FEUI06YZJP1ZJVX0JFUY
0P2;Rh/00`24Q8Coooooooooo`040000o`80oh002@000?l0103oP000003o0000o`3oP0020000o`<0
oh001`000?l30?n000H0003o00@0oh000000o`000?l0oh001@000?l0103oP000003o0000o`000?l2
0?n000030000o`3oP000oh0000<0oh003P000?l20?n000H0003o00@0oh000000o`000?l0003o0P3o
P00010000?l0oh000?n0003oP0060000o`H0oh0000<0003o0?n0003oP00010000?l30?n000/0003o
00@0oh000000o`3oP000oh001`000?l20?n000040000o`3oP000oh000000o`H0oh0060000?l00`3o
P000003o0000o`060000o`030?n000000?l0003o00@0003o2_ooool000Wooooo00@0Q8B4079bLP1b
LW80UIFE0P1OGel0101mOGd0MgMg07MgM`2:RXX2059BDP0406IVIP1RHV80HV9R04M7A`80M7Ad00<0
IfMW092@T02@T9000`18B4P0102;Rh/0NWYj07YjNP2BTY8206QXJ00405EEE@18B4P0B4Q804];B`80
Cdm?00@0OGem09JFUP2FUYH0S8b<0P13@d<0101kNg/0DE5A055AD@1RHV8206QXJ00507emO@36a/H0
TI6A096AT@1MGEd00P0n?Sh0101bLW80^;Rh0;Rh^02f][H20:BTY0040;>c/`2KVi/0Vi^K092@T080
V9RH00@0SHf=07]kN`1kNg/0E5AD0P1VIVH0101eMGD0Rh^;08^;R`2VYZH206=SH`0408N7Q`29RHT0
RHV90;Bd]080`L7100@0X:2P0:ZZZP2ZZZX0`<300P2^[Zh01@2`/;00?clo03lo?`1bLW80G5aL0080
I6AT00@0Lg=c06e]K@1]KFd0CTi>0P2KVi/0102h^;P0Z:RX0:RXZ01dM7@205mOG`0408b<S02g]kL0
]kNg0<S8b080/K6a00@0S8b<079bLP1bLW80TI6A0P2a/K40102KVi/0JVYZ06YZJP1_Kfl206=SH`04
09RHV037alL0alO70:2PX080N7Qh00@0U9BD09JFUP2FUYH0SHf=0P1WIfL01@1cLg<0a/K60<K6aP2`
/;00Fe]K0080ATI600@0?3`l04e=C@1=CDd0MgMg0P1/K6`0101jNWX0FUYJ05YJFP1XJ6P205mOG`04
06MWI`2:RXX0RXZ:06=SH`80J6QX00@0Lg=c08^;R`2;Rh/0V9RH0P27QhL0102<S8`0[:b/0:b/[01@
D50208j>SP040:2PX02GUiL0UiNG07inOP80O7al00@0K6a/06ATI01TI6@0Jf][0P1kNg/00`1bLW;o
ooooooooo`0:0000o`80oh000`000?l00`3oP000003o0000o`030000o`<0oh001P000?l50?n000D0
003o00@0oh000000o`000?l0oh001@000?l00`3oP000003o0000o`030?n000040000o`3oP000oh00
0?n00080003o00<0oh000000o`000?l01@000?l20?n000X0003o0`3oP0030000o`H0oh000P000?l0
0`3oP000003o0000o`020000o`80oh0000<0003o0?n0003oP0001P000?l40?n000D0003o00<0oh00
0000o`000?l01@000?l20?n000X0003o2@3oP0050000o`030?n000000?l0003o0100003o00<0oh00
0000o`000?l03@000?l:ooooo`002Oooool0101fMWH0JVYZ06YZJP23Ph<205QHF00408B4Q021PH40
PH6109:BTP80HF5Q00@0LG5a05]KF`1KFe/0@d=30P1[Jf/00`1YJFT0OGem07emO@0304Q8B004092@
T01aLG40LG5a08Z:RP80LG5a00@0Hf=S04U9B@19BDT0HF5Q0P1NGUh01022PX80VYZJ09ZJVP2EUID2
04a<C00407moO`1DE5@0E5AD06][J`80Hf=S00D0QhN70;^k^`27QhL0QhN705QHF00203@d=00406MW
I`2VYZH0YZJV0:JVYP80Xj>S00@0[Jf]0:6QX@2QXJ40UYJF0P2JVYX0102;Rh/0Jf][06][J`1CDe<2
06e]K@0407UiN@2DU9@0U9BD0;^k^`80I6AT00@0Shn?08R8R028R8P0/k>c0P37alL0102VYZH0Vi^K
09^KV`2h^;P20;Vi^@050<C4a01?Cdl0Cdm?096AT@1kNg/00P1dM7@0101iNGT0Lg=c07=cL`1/K6`2
08^;R`040:n_[`2OWil0WinO07inOP80F5QH00@0SHf=0:j^[P2^[Zh0f][J0P2l_;`0101`L700IFEU
06EUI@2KVi/20;jn_P0409VIV@1[Jf/0Jf][075aL@80Lg=c00@0Z:RX0<;2`P32`/80Zj^[0P1iNGT0
102XZ:P0YZJV0:JVYP2JVYX206UYJ@0507QhN02b/[80/[:b0;Jf]P1BDU800P0n?Sh0101:BTX0ATI6
04I6AP21PH4207=cL`0406m_K`1WIfL0IfMW07=cL`80IFEU00@0HV9R07UiN@1iNGT0JVYZ0P1EEED0
101SHf<0LW9b079bLP1nOWh208f=S@0409jNWP2YZJT0ZJVY04Y:BP80R8R800@0SHf=08B4Q024Q8@0
MgMg0P1RHV80101JFUX0MGEe07EeM@1WIfL208N7Q`0307YjN_oooooooooo00@0003o0P3oP0070000
o`<0oh001@000?l30?n000L0003o00@0oh000000o`000?l0oh001@000?l0103oP000003o0000o`3o
P0050000o`030?n000000?l0003o00<0oh001P000?l00`3oP000003o0000o`050000o`80oh001000
0?l20?n000@0003o0`3oP0030000o`H0oh002P000?l20?n000<0003o00<0oh000000o`000?l0103o
P0050000o`030?n000000?l0003o00D0003o0P3oP00:0000o`T0oh003@000?l20?n000T0003o00<0
oh000000o`000?l01P000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0407IfMP1ZJVX0
JVYZ08>3P`80F5QH00@0Q8B40861P@21PH40TY:B0P1QHF40101aLG40Fe]K05]KF`13@d<206][J`03
06UYJ@1mOGd0OGem00<0B4Q800@0T92@075aL@1aLG40RXZ:0P1aLG40101SHf<0BDU904U9B@1QHF42
05iNGP0408:2PP2JVYX0VYZJ09FEU@80C4a<00@0Ogmo05ADE01DE5@0Jf][0P1SHf<01@27QhL0^k^k
08N7Q`27QhL0F5QH0080=3@d00@0IfMW0:JVYP2VYZH0YZJV0P2SXj<0102][Jd0XJ6Q0:6QX@2FUYH2
09ZJVP0408^;R`1[Jf/0Jf][05=CD`80KFe]00@0NGUi09BDU02DU9@0^k^k0P1TI6@0102?Shl0R8R8
08R8R02c/k<20<O7a`040:JVYP2KVi/0Vi^K0;Rh^080^KVi00D0a<C404m?C`1?Cdl0TI6A07]kN`02
07AdM00407UiN@1cLg<0Lg=c06a/K080Rh^;00@0[jn_09nOW`2OWil0OWin0P1HF5P0102=SHd0[Zj^
0:j^[P3Jf]X20;bl_004071`L01UIFD0IFEU09^KV`80_[jn00@0VIVI06][J`1[Jf/0LG5a0P1cLg<0
102XZ:P0`/;20<;2`P2[Zj/207UiN@040:RXZ02VYZH0YZJV09ZJVP80JFUY00D0N7Qh0;:b/P2b/[80
][Jf059BDP0203hn?P0404Y:BP16ATH0ATI60861P@80Lg=c00@0Kfm_06MWI`1WIfL0Lg=c0P1UIFD0
101RHV80NGUi07UiN@1ZJVX205EEE@0406=SH`1bLW80LW9b07inOP80SHf=00@0WYjN0:VYZ@2YZJT0
BTY:0P28R8P0102=SHd0Q8B408B4Q01gMgL2069RHP0405YJFP1eMGD0MGEe06MWI`80QhN700<0NWYj
ooooooooool010000?l20?n000L0003o0`3oP0050000o`<0oh001`000?l0103oP000003o0000o`3o
P0050000o`040?n000000?l0003o0?n000D0003o00<0oh000000o`000?l00`3oP0060000o`030?n0
00000?l0003o00D0003o0P3oP0040000o`80oh0010000?l30?n000<0003o1P3oP00:0000o`80oh00
0`000?l00`3oP000003o0000o`040?n000D0003o00<0oh000000o`000?l01@000?l20?n000X0003o
2@3oP00=0000o`80oh002@000?l00`3oP000003o0000o`060000o`030?n000000?l0003o00@0003o
2_ooool000Wooooo00@0I6AT07inOP1nOWh0Q8B40P16ATH01028R8P0OWin07inOP2ATI4205QHF004
071`L01JFUX0FUYJ04m?C`80Lg=c00@0L71`07YjNP1jNWX0ATI60P1=CDd01027QhL0N7Qh07QhN021
PH42075aL@0404m?C`17AdL0AdM704M7A`80Bd];00@0NWYj08n?S`2?Shl0TI6A0P1FEUH01022PX80
D51@051@D01^KVh205iNGP0508^;R`3;bl/0WYjN09jNWP1=CDd00P0];Bd0101TI6@0XZ:R0::RXP2W
YjL20:j^[P040;>c/`2EUID0UIFE09:BTP80XJ6Q00@0UIFE07UiN@1iNGT0L71`0P1aLG40101kNg/0
UIFE09FEU@2[Zj/205EEE@0409FEU@27QhL0QhN70;Zj^P80b/[:00@0[Jf]09>CT`2CTi<0/K6a0P2f
][H01@2j^[X0ATI604I6AP2:RXX0Q8B40080R8R800@0PX:208f=S@2=SHd0KFe]0P2>SXh0103<c<`0
S8b<08b<S01_Kfl204e=C@0407moO`24Q8@0Q8B40=[JfP80[Jf]00@0Lg=c05eMG@1MGEd0WinO0P35
aLD01021PH40JFUY06UYJ@1QHF42071`L0040:6QX@2XZ:P0Z:RX0:6QX@80QHF500@0XJ6Q09jNWP2N
WYh0QHF50P1KFe/01@1ZJVX0Xj>S0:>SX`2b/[80H61P0080?Shn00@0C4a<0451@@11@D40GemO0P1d
M7@0101oOgl0L71`071`L01YJFT205eMG@0407MgM`1OGel0GemO06MWI`80Hf=S00@0KVi^08V9R@29
RHT0T92@0P28R8P0102CTi<0WIfM09fMW@1BDU8209VIV@040:BTY02QXJ40XJ6Q08b<S080NWYj00@0
GemO05iNGP1NGUh0J6QX0P1WIfL00`1UIFGoooooooooo`040000o`80oh0010000?l20?n000040000
o`3oP000oh000?n000D0003o0`3oP0060000o`D0oh001@000?l0103oP000003o0000o`3oP0020000
o`040?n000000?l0003o0?n00080003o0`3oP0040000o`<0oh003`000?l0103oP000003o0000o`00
0?l50?n000030000o`3oP000oh0000@0oh002P000?l20?n000<0003o00@0oh000000o`000?l0003o
0`3oP0020000o`040?n000000?l0003o0?n00100003o0P3oP0030000o`030?n000000?l0003o00@0
oh0020000?l00`3oP000003o0000o`0=0000o`030?n000000?l0003o00L0003o0P3oP0040000o`[o
oooo0009ooooo`0406YZJP1dM7@0M7Ad07MgM`80ATI600@0Ti>C07emO@1mOGd0PH610P1MGEd0101b
LW80KFe]06e]K@1LG5`2092@T004079bLP1iNGT0NGUi04E5A@80@D5100@0T92@07UiN@1iNGT0N7Qh
0P25QHD0101IFET0BDU904U9B@15ADD205aLG00407=cL`2DU9@0U9BD09bLW080EEEE00@0OWin04Q8
B018B4P0H61P0P1QHF401@2CTi<0bl_;0:FUY@2UYJD0G5aL0080>c/k00@0Lg=c09fMW@2MWId0]KFe
0`2^[Zh209>CT`0409^KV`2VYZH0YZJV0:BTY080OWin00@0G5aL07alO01lO7`0OGem0P2GUiL0102]
[Jd0H61P061PH02DU9@20820P0040;Ng]`38b<P0b<S80;:b/P80UYJF00@0/[:b0;Fe]@2e]KD0]kNg
0P19BDT01@20P800Ng]k07]kN`1kNg/0OWin0080Rh^;00@0KFe]07YjNP1jNWX0aLG50P2:RXX0101j
NWX0F5QH05QHF02EUID209JFUP040;Zj^P2PX:00X:2P07YjNP80IFEU00@0Shn?0<O7a`37alL0NWYj
0P1^KVh0101]KFd0Kfm_06m_K`2MWId20:f][@040:VYZ@25QHD0QHF508j>SP80SHf=00@0Ogmo07If
MP1fMWH0T92@0P2UYJD01@2^[Zh0GemO03hn?P0n?Sh0E5AD0080A4A400@0H61P06a/K01/K6`0MWIf
0P1bLW80101jNWX0IVIV06IVIP1gMgL2079bLP0406i^KP1LG5`0G5aL07EeM@80QHF500@0WYjN08b<
S02<S8`0PH610P2KVi/0101DE5@0QXJ608J6QP2b/[8209fMW@0408f=S@2;Rh/0Rh^;06YZJP80MGEe
00@0NWYj06i^KP1^KVh0J6QX0_ooool40000o`80oh0010000?l20?n000<0003o00<0oh000000o`00
0?l00`000?l30?n000H0003o1@3oP0050000o`040?n000000?l0003o0?n000D0003o00<0oh000000
o`000?l00`3oP0030000o`@0oh001`000?l20?n000@0003o0P3oP0040000o`D0oh0000<0003o0?n0
003oP000103oP00:0000o`80oh000`000?l0103oP000003o0000o`000?l20?n000H0003o00<0oh00
0000o`000?l01@000?l20?n000`0003o00<0oh000000o`000?l0103oP00=0000o`80oh002@000?l0
103oP000003o0000o`3oP00<0000o`[ooooo0009ooooo`0406YZJP1dM7@0M7Ad07MgM`80ATI600@0
Ti>C07emO@1mOGd0PH610P1MGEd0101bLW80KFe]06e]K@1LG5`2092@T004079bLP1iNGT0NGUi04E5
A@80@D5100@0T92@07UiN@1iNGT0N7Qh0P25QHD0101IFET0BDU904U9B@15ADD205aLG00407=cL`2D
U9@0U9BD09bLW080EEEE00@0OWin04Q8B018B4P0H61P0P1QHF401@2CTi<0bl_;0:FUY@2UYJD0G5aL
0080>c/k00@0Lg=c09fMW@2MWId0]KFe0`2^[Zh209>CT`0409^KV`2VYZH0YZJV0:BTY080OWin00@0
G5aL07alO01lO7`0OGem0P2GUiL0102][Jd0H61P061PH02DU9@20820P0040;Ng]`38b<P0b<S80;:b
/P80UYJF00@0/[:b0;Fe]@2e]KD0]kNg0P19BDT01@20P800Ng]k07]kN`1kNg/0OWin0080Rh^;00@0
KFe]07YjNP1jNWX0aLG50P2:RXX0101jNWX0F5QH05QHF02EUID209JFUP040;Zj^P2PX:00X:2P07Yj
NP80IFEU00@0Shn?0<O7a`37alL0NWYj0P1^KVh0101]KFd0Kfm_06m_K`2MWId20:f][@040:VYZ@25
QHD0QHF508j>SP80SHf=00@0Ogmo07IfMP1fMWH0T92@0P2UYJD01@2^[Zh0GemO03hn?P0n?Sh0E5AD
0080A4A400@0H61P06a/K01/K6`0MWIf0P1bLW80101jNWX0IVIV06IVIP1gMgL2079bLP0406i^KP1L
G5`0G5aL07EeM@80QHF500@0WYjN08b<S02<S8`0PH610P2KVi/0101DE5@0QXJ608J6QP2b/[8209fM
W@0408f=S@2;Rh/0Rh^;06YZJP80MGEe00@0NWYj06i^KP1^KVh0J6QX0_ooool40000o`80oh001000
0?l20?n000<0003o00<0oh000000o`000?l00`000?l30?n000H0003o1@3oP0050000o`040?n00000
0?l0003o0?n000D0003o00<0oh000000o`000?l00`3oP0030000o`@0oh001`000?l20?n000@0003o
0P3oP0040000o`D0oh0000<0003o0?n0003oP000103oP00:0000o`80oh000`000?l0103oP000003o
0000o`000?l20?n000H0003o00<0oh000000o`000?l01@000?l20?n000`0003o00<0oh000000o`00
0?l0103oP00=0000o`80oh002@000?l0103oP000003o0000o`3oP00<0000o`[ooooo0009ooooo`04
07YjNP2:RXX0RXZ:08V9R@80Bd];00@0Ogmo07YjNP1jNWX0O7al0P1DE5@0101kNg/0LG5a075aL@1Z
JVX208N7Q`0407emO@1gMgL0MgMg05QHF080ATI600@0FUYJ06EUI@1UIFD0L71`0P1iNGT01012@T80
ATI604I6AP1BDU8205YJFP0406EUI@2?Shl0Shn?09:BTP80EEEE00@0Shn?05eMG@1MGEd0N7Qh0P1P
H6001@29RHT0cLg=0:NWY`2WYjL0IFEU0080Bd];00@0OWin0:j^[P2^[Zh0/K6a0P2k^k/0102a/K40
Shn?08n?S`1oOgl208b<S00407moO`1TI6@0I6AT04m?C`80N7Qh00@0Q8B409jNWP2NWYh0]kNg0P1^
KVh0102`/;00Ng]k07]kN`2h^;P20=3@d0040;>c/`2HV9P0V9RH0:n_[`80d=3@00D0`L7105iNGP1N
GUh0QXJ608N7Q`0207inOP0407QhN02DU9@0U9BD06e]K@80M7Ad00@0f=SH08J6QP26QXH0LG5a0P1D
E5@0102DU9@0[Zj^0:j^[P3=cLd20;Rh^00408V9R@2>SXh0SXj>09NGU`80b/[:00@0I6AT075aL@1a
LG40MgMg0P1WIfL0102EUID0]KFe0;Fe]@2RXZ8208:2PP0408J6QP2SXj<0Xj>S08>3P`80HF5Q00D0
Rh^;0:>SX`2SXj<0XJ6Q06EUI@0204e=C@0404E5A@11@D40@D5106ATI080Lg=c0`1_Kfl307QhN004
0820P01gMgL0MgMg061PH080Fe]K00@0HV9R06YZJP1ZJVX0VYZJ0P26QXH0101lO7`0T92@092@T019
BDT2075aL@04092@T02HV9P0V9RH0820P080M7Ad00@0FUYJ07alO01lO7`0N7Qh0P1RHV800`1ZJV[o
ooooooooo`040000o`80oh0010000?l20?n000T0003o103oP0050000o`D0oh001@000?l0103oP000
003o0000o`3oP0050000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0003oP000103oP007
0000o`80oh0010000?l20?n000040000o`3oP000oh000000o`D0oh0000<0003o0?n0003oP000103o
P00:0000o`80oh000`000?l00`3oP000003o0000o`040?n000D0003o00<0oh000000o`000?l01@00
0?l20?n000l0003o103oP00=0000o`80oh002@000?l00`3oP000003o0000o`060000o`030?n00000
0?l0003o00@0003o2_ooool000Wooooo00@0O7al08j>SP2>SXh0QhN70P15ADD01021PH40QHF508F5
Q@1fMWH204a<C00406a/K01XJ6P0J6QX079bLP80MWIf00@0Ph>307inOP1nOWh0KFe]0P1=CDd0101c
Lg<0LG5a075aL@26QXH206YZJP0404Q8B011@D40@D5103dm?@80HF5Q00@0KFe]09:BTP2BTY80O7al
0P12@T80101gMgL0De=C05=CD`1cLg<205eMG@0508R8R03;bl/0XJ6Q0:6QX@1^KVh00P1ADE401025
QHD0X:2P0:2PX02j^[X20;Bd]0040:JVYP2=SHd0SHf=09RHV080VYZJ00@0Ogmo071`L01`L700F5QH
0P1_Kfl0101lO7`0VYZJ09ZJVP2UYJD2065QH@040:2PX020P800P8200;Jf]P80a<C400@0_Kfm09^K
V`2KVi/0/K6a0P3EeMD01@31`L40GemO05mOG`2;Rh/0SXj>0080NGUi00@0Ogmo09VIV@2IVIT0N7Qh
0P1RHV80103Cdm<0UYJF09JFUP1jNWX205=CD`040861P@2LW9`0W9bL0;Zj^P80];Bd00@0P82007in
OP1nOWh0UIFE0P3Hf=P0101[Jf/0Q8B408B4Q01lO7`207AdM00409>CT`2JVYX0VYZJ0;jn_P80U9BD
00@0R8R808V9R@29RHT0Ng]k0P1cLg<01@2ATI40YZJV0:JVYP2GUiL0LG5a0080Cdm?00@0?3`l04m?
C`1?Cdl0JFUY0P1QHF40101[Jf/0KFe]06e]K@1kNg/207QhN00407IfMP1_Kfl0Kfm_07YjNP80I6AT
00@0JVYZ05aLG01LG5`0Ti>C0P24Q8@0102BTY80/[:b0;:b/P1KFe/208b<S0040:JVYP2OWil0WinO
07EeM@80K6a/00@0FUYJ07AdM01dM7@0J6QX0P1aLG400`1YJFWoooooooooo`040000o`80oh001000
0?l20?n000X0003o0P3oP0060000o`@0oh001P000?l0103oP000003o0000o`3oP0020000o`040?n0
00000?l0003o0?n000<0003o0P3oP0030000o`<0oh0020000?l20?n000X0003o1@3oP0000`000?l0
oh000?n000030?n000/0003o0P3oP0030000o`040?n000000?l0003o0000o`<0oh001@000?l00`3o
P000003o0000o`070000o`030?n000000?l0003o00`0003o103oP00@0000o`80oh0010000?l30?n0
00P0003o00<0oh000000o`000?l010000?l:ooooo`002Oooool0101lO7`0SXj>08j>SP27QhL204E5
A@040861P@25QHD0QHF507IfMP80C4a<00@0K6a/06QXJ01XJ6P0LW9b0P1fMWH01023Ph<0OWin07in
OP1]KFd204e=C@0407=cL`1aLG40LG5a08J6QP80JVYZ00@0B4Q80451@@11@D40?Cdm0P1QHF40101]
KFd0TY:B09:BTP1lO7`20492@P0407MgM`1CDe<0De=C07=cL`80GEeM00D0R8R80<_;b`2QXJ40XJ6Q
06i^KP02055AD@0408F5Q@2PX:00X:2P0;Zj^P80];Bd00@0YZJV08f=S@2=SHd0V9RH0P2JVYX0101o
Ogl0L71`071`L01HF5P206m_K`0407alO02JVYX0VYZJ0:FUY@80HF5Q00@0X:2P0820P020P800][Jf
0P34a<@0102m_Kd0Vi^K09^KV`2a/K420=GEe@050<71`@1OGel0GemO08^;R`2>SXh00P1iNGT0101o
Ogl0VIVI09VIV@1hN7P2069RHP040=?Cd`2FUYH0UYJF07YjNP80De=C00@0PH6109bLW02LW9`0^[Zj
0P2d];@01020P800OWin07inOP2EUID20=SHf00406][J`24Q8@0Q8B407alO080M7Ad00@0Ti>C09ZJ
VP2JVYX0_[jn0P2DU9@01028R8P0RHV908V9R@1kNg/207=cL`05096AT@2VYZH0YZJV09NGU`1aLG40
0P1?Cdl0100l?3`0Cdm?04m?C`1YJFT2065QH@0406][J`1]KFd0KFe]07]kN`80N7Qh00@0MWIf06m_
K`1_Kfl0NWYj0P1TI6@0101ZJVX0G5aL05aLG02CTi<208B4Q00409:BTP2b/[80/[:b05]KF`80S8b<
00@0YZJV09nOW`2OWil0MGEe0P1/K6`0101JFUX0M7Ad07AdM01XJ6P2075aL@0306UYJOoooooooooo
00@0003o0P3oP0040000o`80oh002P000?l20?n000H0003o103oP0060000o`040?n000000?l0003o
0?n00080003o00@0oh000000o`000?l0oh000`000?l20?n000<0003o0`3oP0080000o`80oh002P00
0?l50?n000030000o`3oP000oh0000<0oh002`000?l20?n000<0003o00@0oh000000o`000?l0003o
0`3oP0050000o`030?n000000?l0003o00L0003o00<0oh000000o`000?l030000?l40?n00100003o
0P3oP0040000o`<0oh0020000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0407moO`2S
Xj<0Xj>S08J6QP80ATI600@0Ogmo08^;R`2;Rh/0M7Ad0P1FEUH01021PH40Jf][06][J`1hN7P207Ui
N@0407inOP1jNWX0NWYj06ATI080Bd];00@0R8R808:2PP22PX80SXj>0P1_Kfl0101;Bd/0CTi>04i>
CP1FEUH206e]K@0406i^KP2GUiL0UiNG08f=S@80?clo00@0RHV904];B`1;Bd/0Lg=c0P1CDe<01@2=
SHd0bl_;0:>SX`2SXj<0EUIF0080@D5100@0JVYZ0:JVYP2VYZH0/;2`0P2^[Zh0102QXJ40Q8B408B4
Q025QHD209>CT`0408:2PP1ZJVX0JVYZ05ADE080K6a/00@0LW9b096AT@2ATI40[:b/0P1LG5`0102H
V9P0QHF508F5Q@2o_kl20<W9b@040=3@d02QXJ40XJ6Q0:FUY@80`l?300D0^k^k06EUI@1UIFD0Q8B4
096AT@0207QhN00407AdM02FUYH0UYJF07emO@80EUIF00@0hn?S08^;R`2;Rh/0MgMg0P1EEED0101/
K6`0Ti>C09>CT`35aLD20:n_[`0409BDU02<S8`0S8b<0:2PX080e]KF00@0IVIV06e]K@1]KFd0Lg=c
0P1^KVh01020P800WIfM09fMW@30`<02092@T00408^;R`2YZJT0ZJVY08:2PP80H61P00D0Ogmo0:6Q
X@2QXJ40Vi^K07AdM00204Y:BP0403<c<`1;Bd/0Bd];06=SH`80Fe]K00@0OGem06IVIP1VIVH0QXJ6
0P1hN7P0101mOGd0Jf][06][J`1aLG4206MWI`0407MgM`1hN7P0N7Qh0:f][@80U9BD00@0WIfM0:j^
[P2^[Zh0GUiN0P1nOWh0102PX:00XZ:R0::RXP29RHT2071`L00405MGE`1TI6@0I6AT05aLG080LW9b
00<0IVIVooooooooool010000?l20?n000@0003o0P3oP00:0000o`80oh001P000?l40?n000H0003o
00@0oh000000o`000?l0oh000P000?l0103oP000003o0000o`3oP0020000o`<0oh000`000?l30?n0
00P0003o0P3oP0060000o`040?n000000?l0003o0000o`D0oh000`000?l30?n000X0003o0`3oP003
0000o`040?n000000?l0003o0000o`<0oh001@000?l00`3oP000003o0000o`070000o`030?n00000
0?l0003o00`0003o103oP0020000o`030?n000000?l0003o00d0003o00@0oh000000o`000?l0003o
0`3oP0080000o`040?n000000?l0003o0?n000<0003o2_ooool000Wooooo00@0NWYj0:VYZ@2YZJT0
OGem0P1@D500101gMgL0PH610861P@1^KVh205ADE00407=cL`1JFUX0FUYJ06][J`80K6a/00@0MgMg
06i^KP1^KVh0EeMG0P16ATH0101kNg/0QHF508F5Q@2DU9@2075aL@0405]KF`1;Bd/0Bd];05ADE080
Jf][00@0MWIf09JFUP2FUYH0PX:20P1EEED0101mOGd0@T920492@P1^KVh204U9B@0508J6QP2n_[h0
P8200820P01PH6000P0l?3`0101dM7@0][Jf0;Jf]P2g]kL20:NWY`040:j^[P2IVIT0VIVI08>3P`80
VIVI00@0SHf=07EeM@1eMGD0GemO0P1_Kfl0101jNWX0X:2P0:2PX02e]KD206ATI0040:2PX027QhL0
QhN70;^k^`80alO700@0c<c<09JFUP2FUYH0UiNG0`2i^KT207alO00507UiN@2DU9@0MGEe07EeM@1k
Ng/00P2EUID0101aLG40Cdm?04m?C`3@d=0208f=S@0407YjNP1ZJVX0JVYZ07moO`80Vi^K00@0_;bl
0;Fe]@2e]KD0Rh^;0P2:RXX01029RHT0fMWI0=WIf@1OGel207EeM@0407moO`1bLW80LW9b07EeM@80
YjNW00@0_kno08f=S@2=SHd0MGEe0P2LW9`0101eMGD0Fe]K05]KF`1YJFT209^KV`050::RXP1bLW80
ADE504E5A@0c<c<00P0i>CT0101NGUh0I6AT06ATI01hN7P205]KF`0407QhN01/K6`0K6a/07moO`80
I6AT00@0M7Ad05iNGP1NGUh0KFe]0P1bLW80102KVi/0T92@092@T02QXJ420:j^[P0405iNGP2GUiL0
UiNG0:RXZ080[:b/00@0Q8B407AdM01dM7@0Jf][0P1RHV80101[Jf/0NGUi07UiN@1bLW82ooooo`@0
003o0P3oP0040000o`80oh0000<0003o0?n0003oP0001P000?l30?n000H0003o103oP0060000o`04
0?n000000?l0003o0?n00080003o00@0oh000000o`000?l0oh000`000?l20?n000040000o`3oP000
oh000?n00080003o00<0oh000000o`000?l02`000?l20?n000@0003o1@3oP0030000o`<0oh002P00
0?l30?n000L0003o0`3oP0050000o`030?n000000?l0003o00L0003o00<0oh000000o`000?l01000
0?l20?n000H0003o1P3oP0030000o`030?n000000?l0003o00D0003o0P3oP0070000o`<0oh003`00
0?l:ooooo`002Oooool0101jNWX0ZJVY0:VYZ@1mOGd2051@D00407MgM`21PH40PH6106i^KP80E5AD
00@0Lg=c05YJFP1JFUX0Jf][0P1/K6`0101gMgL0KVi^06i^KP1GEeL204I6AP0407]kN`25QHD0QHF5
09BDU080LG5a00@0Fe]K04];B`1;Bd/0E5AD0P1[Jf/0101fMWH0UYJF09JFUP22PX8205EEE@0407em
O@12@T80@T9206i^KP80BDU900D0QXJ60;jn_P20P800P820061PH00203`l?00407AdM02f][H0][Jf
0;Ng]`80YjNW00@0[Zj^09VIV@2IVIT0Ph>30P2IVIT0102=SHd0MGEe07EeM@1OGel206m_K`0407Yj
NP2PX:00X:2P0;Fe]@80I6AT00@0X:2P08N7Q`27QhL0^k^k0P37alL0103<c<`0UYJF09JFUP2GUiL3
0;Vi^@80O7al00D0NGUi09BDU01eMGD0MGEe07]kN`0209FEU@04075aL@1?Cdl0Cdm?0=3@d080SHf=
00@0NWYj06YZJP1ZJVX0Ogmo0P2KVi/0102l_;`0]KFe0;Fe]@2;Rh/208Z:RP0408V9R@3IfMT0fMWI
05mOG`80MGEe00@0Ogmo079bLP1bLW80MGEe0P2WYjL0102o_kl0SHf=08f=S@1eMGD209bLW00407Ee
M@1KFe/0Fe]K06UYJ@80Vi^K00D0XZ:R079bLP15ADD0ADE503<c<`0203Ti>@0405iNGP1TI6@0I6AT
07QhN080Fe]K00@0N7Qh06a/K01/K6`0Ogmo0P1TI6@0101dM7@0GUiN05iNGP1]KFd2079bLP0409^K
V`2@T900T92@0:6QX@80[Zj^00@0GUiN09NGU`2GUiL0Z:RX0P2/[:`01024Q8@0M7Ad07AdM01[Jf/2
069RHP0406][J`1iNGT0NGUi079bLP;ooooo10000?l20?n000@0003o0P3oP0000`000?l0oh000?n0
00060000o`<0oh001P000?l40?n000H0003o00@0oh000000o`000?l0oh000P000?l0103oP000003o
0000o`3oP0030000o`80oh0000@0003o0?n0003oP000oh000P000?l00`3oP000003o0000o`0;0000
o`80oh0010000?l50?n000<0003o0`3oP00:0000o`<0oh001`000?l30?n000D0003o00<0oh000000
o`000?l01`000?l00`3oP000003o0000o`040000o`80oh001P000?l60?n000<0003o00<0oh000000
o`000?l01@000?l20?n000L0003o0`3oP00?0000o`[ooooo0009ooooo`0407AdM02QXJ40XJ6Q07If
MP80@d=300@0N7Qh08b<S02<S8`0Lg=c0P1QHF401026QXH0J6QX06QXJ01hN7P207=cL`0407QhN01Y
JFT0JFUY04e=C@80ADE500@0Ogmo0861P@21PH40UYJF0P1cLg<0101ZJVX0EEEE05EEE@1@D502061P
H00406a/K02OWil0WinO09FEU@80KVi^00@0T92@05MGE`1GEeL0OWin0P1ADE401@27QhL0cLg=096A
T@2ATI40Fe]K0080>SXj00@0IfMW0:JVYP2VYZH0Z:RX0P2GUiL0102[Zj/0Vi^K09^KV`1eMGD209FE
U@0408V9R@1cLg<0Lg=c05UIF@80JFUY00@0MgMg08^;R`2;Rh/0^KVi0P1TI6@0102NWYh0T92@092@
T02n_[h20<S8b0040<G5a@28R8P0R8R808^;R`80^k^k00D0/;2`07MgM`1gMgL0LG5a092@T00206m_
K`04071`L02BTY80TY:B06a/K080GemO00@0d=3@07EeM@1eMGD0OWin0P1_Kfl0101bLW80S8b<08b<
S02e]KD20<C4a00408N7Q`2:RXX0RXZ:07UiN@80dm?C00@0K6a/09bLW02LW9`0Ng]k0P1hN7P0101e
MGD0W9bL09bLW038b<P209FEU@0406m_K`27QhL0QhN707alO080FUYJ00D0Hf=S0:JVYP2VYZH0YjNW
06EUI@0204=3@`0403Ph>00f=SH0=SHf065QH@80OGem00@0JFUY06YZJP1ZJVX0Jf][0P1hN7P0101o
Ogl0I6AT06ATI01YJFT205UIF@0407AdM01fMWH0MWIf09>CT`80TI6A00@0Ti>C0:FUY@2UYJD0EEEE
0P2LW9`0102^[Zh0[jn_0:n_[`2:RXX2071`L00405QHF01`L700L71`06QXJ080JVYZ00<0G5aLoooo
ooooool010000?l20?n000l0003o0`3oP0070000o`<0oh002@000?l0103oP000003o0000o`3oP002
0000o`030?n000000?l0003o00<0oh003P000?l20?n000@0003o0P3oP0040000o`D0oh000`000?l3
0?n000/0003o0P3oP0070000o`<0oh001@000?l00`3oP000003o0000o`070000o`030?n000000?l0
003o00@0003o0P3oP0060000o`@0oh003@000?l20?n000T0003o00<0oh000000o`000?l00`3oP003
0000o`030?n000000?l0003o00<0003o00<0oh00ooooooooool02?ooool000Wooooo00@0Jf][09>C
T`2CTi<0K6a/0P10@40306a/K00406QXJ01DE5@0E5AD075aL@80JFUY00@0NWYj06][J`1[Jf/0LG5a
0P1ZJVX01017AdL0@d=304=3@`1aLG420820P00309NGU`1WIfL0IfMW00<0EUIF00@0C4a<05mOG`1O
Gel0K6a/0P2JVYX01026QXH0HF5Q065QH@2CTi<205mOG`0508:2PP1OGel0GemO07moO`33`l<00P2K
Vi/0101MGEd0@4100410@01YJFT209FEU@0409fMW@2a/K40/K6a0<30`080XZ:R00@0Vi^K0:2PX02P
X:00R8R80P1gMgL0101JFUX0K6a/06a/K01jNWX209:BTP040<C4a01XJ6P0J6QX0:VYZ@80TY:B00@0
^;Rh0<O7a`37alL0c<c<0P29RHT0102:RXX0][Jf0;Jf]P2^[Zh207YjNP0507UiN@2>SXh0MWIf07If
MP1jNWX00P2GUiL0101OGel0H61P061PH03Bd]8207emO@0408R8R01bLW80LW9b075aL@80WYjN00@0
/;2`0<G5a@35aLD0VIVI0P2BTY80101fMWH0b/[:0<[:bP1HF5P209NGU`0407MgM`1cLg<0Lg=c07Ad
M080YZJV00@0b/[:09FEU@2EUID0JFUY0P2LW9`0101gMgL0GemO05mOG`1hN7P20;6a/@050;Fe]@1b
LW80BTY:04Y:BP13@d<00P11@D40101WIfL0MGEe07EeM@1KFe/206=SH`0406QXJ01gMgL0MgMg08j>
SP80N7Qh00@0JVYZ059BDP1BDU80N7Qh0P1cLg<0102HV9P0[Zj^0:j^[P2?Shl20:b/[00406QXJ022
PX80PX:209^KV`80VIVI00@0Lg=c05iNGP1NGUh0IfMW0P1YJFT0101/K6`0P8200820P01_Kfl2oooo
o`@0003o0P3oP0040000o`80oh002@000?l30?n000H0003o103oP00?0000o`030?n000000?l0003o
00<0oh0010000?l30?n000L0003o0P3oP0040000o`80oh0010000?l50?n000<0003o0`3oP00;0000
o`80oh001`000?l30?n000D0003o0`3oP0070000o`030?n000000?l0003o00L0003o0`3oP0020000
o`@0oh000`000?l20?n000P0003o0P3oP0040000o`80oh002P000?l20?n000L0003o2_ooool000Wo
oooo00@0Jf][09>CT`2CTi<0K6a/0P10@40306a/K00406QXJ01DE5@0E5AD075aL@80JFUY00@0NWYj
06][J`1[Jf/0LG5a0P1ZJVX01017AdL0@d=304=3@`1aLG420820P00309NGU`1WIfL0IfMW00<0EUIF
00@0C4a<05mOG`1OGel0K6a/0P2JVYX01026QXH0HF5Q065QH@2CTi<205mOG`0508:2PP1OGel0GemO
07moO`33`l<00P2KVi/0101MGEd0@4100410@01YJFT209FEU@0409fMW@2a/K40/K6a0<30`080XZ:R
00@0Vi^K0:2PX02PX:00R8R80P1gMgL0101JFUX0K6a/06a/K01jNWX209:BTP040<C4a01XJ6P0J6QX
0:VYZ@80TY:B00@0^;Rh0<O7a`37alL0c<c<0P29RHT0102:RXX0][Jf0;Jf]P2^[Zh207YjNP0507Ui
N@2>SXh0MWIf07IfMP1jNWX00P2GUiL0101OGel0H61P061PH03Bd]8207emO@0408R8R01bLW80LW9b
075aL@80WYjN00@0/;2`0<G5a@35aLD0VIVI0P2BTY80101fMWH0b/[:0<[:bP1HF5P209NGU`0407Mg
M`1cLg<0Lg=c07AdM080YZJV00@0b/[:09FEU@2EUID0JFUY0P2LW9`0101gMgL0GemO05mOG`1hN7P2
0;6a/@050;Fe]@1bLW80BTY:04Y:BP13@d<00P11@D40101WIfL0MGEe07EeM@1KFe/206=SH`0406QX
J01gMgL0MgMg08j>SP80N7Qh00@0JVYZ059BDP1BDU80N7Qh0P1cLg<0102HV9P0[Zj^0:j^[P2?Shl2
0:b/[00406QXJ022PX80PX:209^KV`80VIVI00@0Lg=c05iNGP1NGUh0IfMW0P1YJFT0101/K6`0P820
0820P01_Kfl2ooooo`@0003o0P3oP0040000o`80oh002@000?l30?n000H0003o103oP00?0000o`03
0?n000000?l0003o00<0oh0010000?l30?n000L0003o0P3oP0040000o`80oh0010000?l50?n000<0
003o0`3oP00;0000o`80oh001`000?l30?n000D0003o0`3oP0070000o`030?n000000?l0003o00L0
003o0`3oP0020000o`@0oh000`000?l20?n000P0003o0P3oP0040000o`80oh002P000?l20?n000L0
003o2_ooool000Wooooo00@0LG5a0:NWY`2WYjL0MgMg0P1:BTX0101lO7`0QHF508F5Q@1]KFd205QH
F0040820P01LG5`0G5aL07IfMP80Lg=c00@0OWin06=SH`1SHf<0E5AD0P1NGUh0101cLg<0MWIf07If
MP29RHT206e]K@0405aLG014A4@0A4A404M7A`80GUiN00@0M7Ad0:2PX02PX:00Rh^;0P1EEED0102<
S8`0EUIF05IFEP1nOWh206IVIP0508b<S037alL0RXZ:08Z:RP1IFET00P0[:b/0101NGUh0^;Rh0;Rh
^02g]kL20;:b/P040;Zj^P2KVi/0Vi^K09NGU`80YJFU00@0R8R807UiN@1iNGT0FUYJ0P1dM7@0101n
OWh0WIfM09fMW@39bLT206ATI0040:ZZZP2FUYH0UYJF0;no_`80cLg=00@0e=CD08n?S`2?Shl0Shn?
0P34a<@01@2e]KD0PH610861P@2CTi<0RXZ:0080NWYj00@0OGem09fMW@2MWId0IVIV0P1[Jf/0103?
cll0PX:208:2PP28R8P208N7Q`04075aL@2JVYX0VYZJ09nOW`80^;Rh00@0TY:B07alO01lO7`0JFUY
0P3IfMT0101YJFT0R8R808R8R01ZJVX20820P00408n?S`2k^k/0^k^k0=KFeP80VIVI00@0JVYZ0:RX
Z02XZ:P0NWYj0P1_Kfl01@1nOWh0XZ:R0::RXP2e]KD0KFe]0080?Shn00@0>CTi03lo?`0o?cl0GEeM
0P1`L700101JFUX0Fe]K05]KF`1RHV8206i^KP0408F5Q@27QhL0QhN705UIF@80CDe=00@0KFe]07Ui
N@1iNGT0VIVI0P2SXj<0102>SXh0[jn_0:n_[`24Q8@208:2PP0409ZJVP2/[:`0[:b/07alO080IFEU
00@0CDe=05UIF@1IFET0FEUI0P1cLg<00`1FEUKoooooooooo`040000o`80oh0010000?l20?n00003
0000o`3oP000oh0000H0003o0`3oP0060000o`D0oh001@000?l0103oP000003o0000o`3oP0050000
o`030?n000000?l0003o00X0oh001`000?l20?n000@0003o0P3oP0040000o`D0oh000`000?l30?n0
00/0003o0P3oP0090000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l01@000?l30?n0
00/0003o00<0oh000000o`000?l01P3oP00010000?l0oh000?n0003oP0060000o`<0oh001`000?l2
0?n000T0003o103oP0020000o`030?n00?oooooooooo00Sooooo0009ooooo`04069RHP2HV9P0V9RH
06ATI080>c/k00@0KVi^07QhN01hN7P0JFUY0P1MGEd01024Q8@0FEUI05UIF@1kNg/206a/K00407]k
N`1PH600H61P04I6AP80De=C00@0MGEe08b<S02<S8`0Shn?0P1`L700101VIVH0F5QH05QHF01>CTh2
065QH@0407AdM02IVIT0VIVI08Z:RP80FEUI00@0VIVI05ADE01DE5@0PH610P1`L7001@1jNWX0_kno
08F5Q@25QHD0BTY:0080DU9B00@0FEUI0:VYZ@2YZJT0/k>c0P2n_[h0102i^KT0RXZ:08Z:RP2NWYh2
09VIV@0408^;R`1eMGD0MGEe05QHF080IfMW00@0O7al08n?S`2?Shl0[jn_0P1DE5@0102DU9@0Q8B4
08B4Q02^[Zh20<O7a`040=WIf@2CTi<0Ti>C09>CT`80aLG500D0[jn_08J6QP26QXH0RHV907=cL`02
079bLP0406e]K@2BTY80TY:B061PH080KVi^00@0emOG092@T02@T900Shn?0P2DU9@0101^KVh0][Jf
0;Jf]P2SXj<20<W9b@040:b/[021PH40PH61071`L080gmoO00@0Kfm_09:BTP2BTY80Ng]k0P1hN7P0
101lO7`0YjNW0:NWY`3@d=0209jNWP0406MWI`2UYJD0YJFU08V9R@80MWIf00D0NWYj09NGU`2GUiL0
_;bl07AdM0020451@@<0@41000@0H61P08Z:RP2:RXX0GUiN0P1>CTh0101MGEd0IfMW06MWI`1VIVH2
07EeM@0404m?C`1DE5@0E5AD07inOP80NGUi00@0UIFE0;Jf]P2f][H0UIFE0P2`/;001020P800QHF5
08F5Q@2PX:020:b/[00408F5Q@1RHV80HV9R05YJFP80HV9R00@0Jf][08B4Q024Q8@0LG5a0_ooool4
0000o`80oh0010000?l20?n000030000o`3oP000oh0000H0003o0`3oP0070000o`<0oh001P000?l0
103oP000003o0000o`3oP0050000o`030?n000000?l0003o00@0oh000P000?l40?n000L0003o0P3o
P0040000o`<0oh000`000?l50?n000<0003o0`3oP00;0000o`80oh001P000?l0103oP000003o0000
o`3oP0050000o`030?n000000?l0003o00L0003o00<0oh000000o`000?l02@000?l00`3oP000003o
0000o`040?n000<0003o1@3oP0040000o`<0oh0010000?l20?n000030000o`3oP000oh0000T0003o
00<0oh000000o`000?l010000?l:ooooo`002Oooool0101RHV80V9RH09RHV01TI6@203/k>`0406i^
KP1hN7P0N7Qh06UYJ@80GEeM00@0Q8B405UIF@1IFET0Ng]k0P1/K6`0101kNg/0H61P061PH016ATH2
05=CD`0407EeM@2<S8`0S8b<08n?S`80L71`00@0IVIV05QHF01HF5P0CTi>0P1QHF40101dM7@0VIVI
09VIV@2:RXX205UIF@0409VIV@1DE5@0E5AD0861P@80L71`00D0NWYj0;no_`25QHD0QHF504Y:BP02
059BDP0405UIF@2YZJT0ZJVY0;>c/`80_[jn00@0^KVi08Z:RP2:RXX0WYjN0P2IVIT0102;Rh/0MGEe
07EeM@1HF5P206MWI`0407alO02?Shl0Shn?0:n_[`80E5AD00@0U9BD08B4Q024Q8@0[Zj^0P37alL0
103IfMT0Ti>C09>CT`2CTi<20<G5a@050:n_[`26QXH0QXJ608V9R@1cLg<00P1bLW80101]KFd0TY:B
09:BTP1PH60206i^KP040=OGe`2@T900T92@08n?S`80U9BD00@0KVi^0;Jf]P2f][H0Xj>S0P39bLT0
102/[:`0PH610861P@1`L7020=oOg`0406m_K`2BTY80TY:B07]kN`80N7Qh00@0O7al0:NWY`2WYjL0
d=3@0P2NWYh0101WIfL0YJFU0:FUY@29RHT207IfMP0507YjNP2GUiL0UiNG0;bl_01dM7@00P11@D43
0410@004061PH02:RXX0RXZ:05iNGP80CTi>00@0GEeM06MWI`1WIfL0IVIV0P1eMGD0101?Cdl0E5AD
05ADE01nOWh207UiN@0409FEU@2f][H0][Jf09FEU@80/;2`00@0P82008F5Q@25QHD0X:2P0P2/[:`0
1025QHD0HV9R069RHP1JFUX2069RHP0406][J`24Q8@0Q8B4075aL@;ooooo10000?l20?n000@0003o
0P3oP0000`000?l0oh000?n000060000o`<0oh001`000?l30?n000H0003o00@0oh000000o`000?l0
oh001@000?l00`3oP000003o0000o`040?n00080003o103oP0070000o`80oh0010000?l30?n000<0
003o1@3oP0030000o`<0oh002`000?l20?n000H0003o00@0oh000000o`000?l0oh001@000?l00`3o
P000003o0000o`070000o`030?n000000?l0003o00T0003o00<0oh000000o`000?l0103oP0030000
o`D0oh0010000?l30?n000@0003o0P3oP0000`000?l0oh000?n000090000o`030?n000000?l0003o
00@0003o2_ooool000Wooooo00@0HV9R0:VYZ@2YZJT0MGEe0P1<C4`0101jNWX0QHF508F5Q@1fMWH2
05aLG00408R8R01lO7`0O7al09NGU`80N7Qh00@0L71`06ATI01TI6@0@d=30P1OGel0101YJFT0Ogmo
07moO`25QHD207=cL`0405QHF016ATH0ATI603`l?080GEeM00@0LW9b08n?S`2?Shl0TY:B0P20P800
102NWYh0FUYJ05YJFP1oOgl308:2PP040=7Ad@27QhL0QhN706=SH`80M7Ad00@0I6AT0;Bd]02d];@0
^;Rh0P30`<00102h^;P0YZJV0:JVYP28R8P209nOW`0408^;R`1eMGD0MGEe05UIF@80L71`00@0QhN7
09>CT`2CTi<0a<C40P1NGUh0102GUiL0QHF508F5Q@2[Zj/20;^k^`040<W9b@24Q8@0Q8B408B4Q080
^k^k00D0_Kfm08:2PP22PX80QXJ607alO00207]kN`0407emO@2KVi/0Vi^K05MGE`80J6QX00@0bl_;
0:RXZ02XZ:P0RHV90P2@T900101WIfL0^;Rh0;Rh^02/[:`20<K6aP0409ZJVP1/K6`0K6a/059BDP80
fMWI00@0Ogmo092@T02@T900QhN70P2CTi<0102EUID0_kno0;no_`3Lg=`20:6QX@0407EeM@2d];@0
];Bd08f=S@80RXZ:00D0Lg=c09ZJVP2JVYX0b/[:06a/K00204E5A@0404=3@`0l?3`0?3`l05IFEP80
Q8B400@0De=C05eMG@1MGEd0J6QX0P1]KFd0101KFe/0Ogmo07moO`14A4@205EEE@04071`L01^KVh0
KVi^08Z:RP80ZZZZ00@0P8200;Ng]`2g]kL0SHf=0P28R8P0102HV9P0[Zj^0:j^[P1mOGd205ADE004
05aLG01ZJVX0JVYZ05MGE`80NWYj00<0HV9Rooooooooool010000?l20?n000@0003o0P3oP0090000
o`030?n000000?l0003o00H0003o1@3oP0080000o`030?n000000?l0003o00<0003o00<0oh000000
o`000?l010000?l60?n000L0003o0P3oP0040000o`<0oh001@000?l30?n000<0003o0`3oP0080000
o`80oh0000<0003o0?n0003oP0001P000?l0103oP000003o0000o`3oP0030000o`<0oh001`000?l3
0?n000<0003o0P3oP0060000o`030?n000000?l0003o00H0oh0000@0003o0?n0003oP000oh000`00
0?l00`3oP000003o0000o`030?n000L0003o0P3oP0040000o`80oh0000@0003o0?n0003oP000oh00
0P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0101WIfL0WIfM09fMW@1bLW8204A4A004
071`L01kNg/0Ng]k06EUI@80CDe=00@0Jf][06QXJ01XJ6P0NGUi0P1/K6`0101cLg<0Fe]K05]KF`0l
?3`205aLG00407alO027QhL0QhN707inOP80KFe]00@0D51@05QHF01HF5P0EUIF0P1lO7`0101_Kfl0
V9RH09RHV02;Rh/207YjNP0409BDU01>CTh0CTi>071`L080IVIV00D0MWIf0;6a/@1/K6`0K6a/05eM
G@0205UIF@03061PH02PX:00X:2P00<0Vi^K0`2FUYH01027QhL0TI6A096AT@29RHT207EeM@0405YJ
FP21PH40PH610820P080UiNG00@0alO7065QH@1QHF40X:2P0P25QHD0102g]kL0_kno0;no_`3Cdm<2
08b<S004096AT@2n_[h0_[jn0;Ng]`80Q8B400D0N7Qh06m_K`1kNg/0Ng]k07UiN@0208b<S00405aL
G01^KVh0KVi^0<?3``80WinO00@0MWIf08n?S`2?Shl0GUiN0P2e]KD0102ZZZX0_;bl0;bl_02IVIT2
061PH004051@D03Fe]H0e]KF07=cL`80QhN700@0Ph>308J6QP26QXH0T92@0P2/[:`0103Cdm<0XZ:R
0::RXP1]KFd20;>c/`0409bLW02HV9P0V9RH07QhN080U9BD00D0clo?06QXJ010@400@41003Xj>P02
03Ph>00404a<C01mOGd0OGem05ADE080J6QX00@0FEUI06UYJ@1YJFT0GEeM0P1^KVh0101?Cdl0HF5Q
065QH@1ZJVX207UiN@040:VYZ@2/[:`0[:b/09^KV`80`<3000@0UiNG096AT@2ATI40/K6a0P2_[jl0
101nOWh0GemO05mOG`1PH60206UYJ@0405ADE01fMWH0MWIf05YJFP;ooooo10000?l20?n000@0003o
0P3oP0070000o`D0oh001P000?l40?n000T0003o00<0oh000000o`000?l00`000?l00`3oP000003o
0000o`030?n000h0003o0P3oP0040000o`80oh0010000?l50?n000<0003o0`3oP0080000o`80oh00
00<0003o0?n0003oP00010000?l30?n00080003o00@0oh000000o`000?l0003o0`3oP0090000o`04
0?n000000?l0003o0000o`80oh001P000?l00`3oP000003o0000o`060?n000040000o`3oP000oh00
0000o`80oh0000D0003o0?n000000?l0003o0?n000090000o`80oh000`000?l30?n000H0003o00@0
oh000000o`000?l0oh002_ooool000Wooooo00@0IfMW09fMW@2MWId0LW9b0P14A4@0101`L700Ng]k
07]kN`1UIFD204e=C@0406][J`1XJ6P0J6QX07UiN@80K6a/00@0Lg=c05]KF`1KFe/0?3`l0P1LG5`0
101lO7`0QhN708N7Q`1nOWh206e]K@04051@D01HF5P0F5QH05IFEP80O7al00@0Kfm_09RHV02HV9P0
Rh^;0P1jNWX0102DU9@0CTi>04i>CP1`L70206IVIP0507IfMP2a/K40K6a/06a/K01MGEd00P1IFET0
0`1PH600X:2P0:2PX00309^KV`<0UYJF00@0QhN7096AT@2ATI40RHV90P1eMGD0101JFUX0PH610861
P@20P80209NGU`040<O7a`1QHF40HF5Q0:2PX080QHF500@0]kNg0;no_`2o_kl0dm?C0P2<S8`0102A
TI40_[jn0;jn_P2g]kL208B4Q00507QhN01_Kfl0Ng]k07]kN`1iNGT00P2<S8`0101LG5`0KVi^06i^
KP33`l<209nOW`0407IfMP2?Shl0Shn?05iNGP80]KFe00@0ZZZZ0;bl_02l_;`0VIVI0P1PH600101@
D500e]KF0=KFeP1cLg<208N7Q`0408>3P`26QXH0QXJ6092@T080[:b/00@0dm?C0::RXP2RXZ80KFe]
0P2c/k<0102LW9`0V9RH09RHV01hN7P209BDU0050<o?c`1XJ6P0@4100410@00j>SX00P0h>3P0101<
C4`0OGem07emO@1DE5@206QXJ00405UIF@1YJFT0JFUY05eMG@80KVi^00@0Cdm?065QH@1QHF40JVYZ
0P1iNGT0102YZJT0[:b/0:b/[02KVi/20<30`00409NGU`2ATI40TI6A0;6a/@80[jn_00@0OWin05mO
G`1OGel0H61P0P1YJFT0101DE5@0MWIf07IfMP1JFUX2ooooo`@0003o0P3oP0040000o`80oh001`00
0?l50?n000H0003o103oP0090000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l00`3o
P00>0000o`80oh0010000?l20?n000@0003o1@3oP0030000o`<0oh0020000?l20?n000030000o`3o
P000oh0000@0003o0`3oP0020000o`040?n000000?l0003o0000o`<0oh002@000?l0103oP000003o
0000o`000?l20?n000H0003o00<0oh000000o`000?l01P3oP00010000?l0oh000?n000000?l20?n0
00050000o`3oP000003o0000o`3oP0002@000?l20?n000<0003o0`3oP0060000o`040?n000000?l0
003o0?n000[ooooo0009ooooo`0406YZJP2YZJT0ZJVY06a/K080@T9200@0KFe]07EeM@1eMGD0IFEU
0P1IFET0101oOgl0JFUY06UYJ@20P80208b<S00408Z:RP1JFUX0FUYJ03Ti>@80GUiN00@0Hf=S0861
P@21PH40SHf=0P1iNGT0101NGUh0F5QH05QHF019BDT207UiN@04061PH02OWil0WinO0:BTY080Ph>3
00@0ZZZZ05eMG@1MGEd0MgMg0`1^KVh0102n_[h0SHf=08f=S@1KFe/205UIF@0407=cL`2j^[X0^[Zj
0<C4a080][Jf00@0[Zj^0;:b/P2b/[80W9bL0P2TY:@0102;Rh/0M7Ad07AdM01FEUH2071`L00408>3
P`2NWYh0WYjN0<?3``80GUiN00@0[:b/08f=S@2=SHd0^[Zj0P30`<00103Fe]H0Ti>C09>CT`29RHT2
0;6a/@050;>c/`2=SHd0SHf=07IfMP1`L7000P1gMgL0101fMWH0S8b<08b<S01SHf<207=cL`040<30
`02IVIT0VIVI06m_K`80QhN700@0H61P0;jn_P2n_[h0[:b/0P2^[Zh0102_[jl0LG5a075aL@1;Bd/2
0=KFeP0407=cL`2CTi<0Ti>C07EeM@80Ng]k00@0LG5a09fMW@2MWId0c/k>0P28R8P0101RHV80_Kfm
0;fm_@2TY:@209JFUP0507UiN@2<S8`0S8b<0<O7a`1/K6`00P11@D4303Lg=`0405=CD`1_Kfl0Kfm_
06EUI@80J6QX00@0Kfm_06QXJ01XJ6P0MGEe0P1iNGT0101ADE40J6QX06QXJ01LG5`208R8R00409^K
V`2[Zj/0Zj^[09BDU080]kNg00@0WinO05]KF`1KFe/0O7al0P2HV9P0101kNg/0Jf][06][J`1NGUh2
069RHP0405]KF`2ATI40TI6A061PH0;ooooo10000?l20?n000@0003o0P3oP0070000o`D0oh001P00
0?l40?n000T0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`030?n000030000o`3o
P000oh0000D0oh001P000?l20?n000@0003o0`3oP0030000o`D0oh000`000?l30?n000/0003o0P3o
P0060000o`030?n000000?l0003o00<0oh0000@0003o0?n0003oP000oh002@000?l0103oP000003o
0000o`000?l20?n000H0003o00<0oh000000o`000?l01P3oP00:0000o`040?n000000?l0003o0?n0
00H0003o0P3oP0000`000?l0oh000?n000060000o`040?n000000?l0003o0?n000<0003o2_ooool0
00Wooooo00@0KVi^0:BTY02TY:@0LG5a0P16ATH0101fMWH0Ph>308>3P`1cLg<206IVIP0407moO`1e
MGD0MGEe09:BTP80Q8B400@0P82005]KF`1KFe/0@T920P1]KFd0101KFe/0LW9b079bLP1jNWX206e]
K@0404a<C013@d<0@d=304e=C@80GUiN00@0D51@08:2PP22PX80RHV90P1mOGd0102EUID0EUIF05IF
EP1_Kfl207UiN@050820P03EeMD0T92@092@T01TI6@00P1LG5`0101`L700Z:RX0:RXZ02e]KD20;^k
^`040:n_[`2ZZZX0ZZZZ09^KV`80Ti>C00@0QhN707MgM`1gMgL0Hf=S0P1jNWX0101eMGD0PH610861
P@2_[jl205MGE`040:JVYP2JVYX0VYZJ0;Rh^080`/;200@0b/[:096AT@2ATI40QHF50P2f][H01@2c
/k<0V9RH09RHV01_Kfl0Lg=c0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01035aLD0Xj>S0:>S
X`1RHV82075aL@04059BDP2k^k/0^k^k0:j^[P80a/K600@0/k>c07YjNP1jNWX0AdM70P3Ph>001021
PH40T92@092@T022PX8208b<S00408^;R`2d];@0];Bd0=gMg@80Ti>C00@0Jf][0;Rh^02h^;P0ZJVY
0P2CTi<01@1aLG40OGem07emO@34a<@0MWIf0080B4Q80`0i>CT01010@400HV9R069RHP1hN7P205mO
G`0408>3P`1gMgL0MgMg07alO080JVYZ00@0GUiN06YZJP1ZJVX0Hf=S0P20P800102ZZZX0Zj^[0:^[
Z`25QHD20;Ng]`040;bl_01dM7@0M7Ad08n?S`80Xj>S00@0Q8B405]KF`1KFe/0Jf][0P1ZJVX0101W
IfL0RXZ:08Z:RP1gMgL2ooooo`@0003o0P3oP00=0000o`<0oh000P000?l00`3oP000003o0000o`03
0000o`L0oh001P000?l00`3oP000003o0000o`030000o`040?n000000?l0003o0000o`80oh000`00
0?l40?n000d0003o0`3oP0030000o`D0oh000`000?l30?n000/0003o0P3oP0040000o`P0oh0000@0
003o0?n0003oP000oh001`000?l30?n000<0003o0P3oP0060000o`030?n000000?l0003o00H0oh00
2P000?l00`3oP000003o0000o`070000o`<0oh001P000?l20?n000L0003o2_ooool000Wooooo00@0
KVi^0:BTY02TY:@0LG5a0P16ATH0101fMWH0Ph>308>3P`1cLg<206IVIP0407moO`1eMGD0MGEe09:B
TP80Q8B400@0P82005]KF`1KFe/0@T920P1]KFd0101KFe/0LW9b079bLP1jNWX206e]K@0404a<C013
@d<0@d=304e=C@80GUiN00@0D51@08:2PP22PX80RHV90P1mOGd0102EUID0EUIF05IFEP1_Kfl207Ui
N@050820P03EeMD0T92@092@T01TI6@00P1LG5`0101`L700Z:RX0:RXZ02e]KD20;^k^`040:n_[`2Z
ZZX0ZZZZ09^KV`80Ti>C00@0QhN707MgM`1gMgL0Hf=S0P1jNWX0101eMGD0PH610861P@2_[jl205MG
E`040:JVYP2JVYX0VYZJ0;Rh^080`/;200@0b/[:096AT@2ATI40QHF50P2f][H01@2c/k<0V9RH09RH
V01_Kfl0Lg=c0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01035aLD0Xj>S0:>SX`1RHV82075a
L@04059BDP2k^k/0^k^k0:j^[P80a/K600@0/k>c07YjNP1jNWX0AdM70P3Ph>001021PH40T92@092@
T022PX8208b<S00408^;R`2d];@0];Bd0=gMg@80Ti>C00@0Jf][0;Rh^02h^;P0ZJVY0P2CTi<01@1a
LG40OGem07emO@34a<@0MWIf0080B4Q80`0i>CT01010@400HV9R069RHP1hN7P205mOG`0408>3P`1g
MgL0MgMg07alO080JVYZ00@0GUiN06YZJP1ZJVX0Hf=S0P20P800102ZZZX0Zj^[0:^[Z`25QHD20;Ng
]`040;bl_01dM7@0M7Ad08n?S`80Xj>S00@0Q8B405]KF`1KFe/0Jf][0P1ZJVX0101WIfL0RXZ:08Z:
RP1gMgL2ooooo`@0003o0P3oP00=0000o`<0oh000P000?l00`3oP000003o0000o`030000o`L0oh00
1P000?l00`3oP000003o0000o`030000o`040?n000000?l0003o0000o`80oh000`000?l40?n000d0
003o0`3oP0030000o`D0oh000`000?l30?n000/0003o0P3oP0040000o`P0oh0000@0003o0?n0003o
P000oh001`000?l30?n000<0003o0P3oP0060000o`030?n000000?l0003o00H0oh002P000?l00`3o
P000003o0000o`070000o`<0oh001P000?l20?n000L0003o2_ooool000Wooooo00@0GemO09JFUP2F
UYH0Ng]k0P1<C4`0101cLg<0MWIf07IfMP1cLg<205iNGP0407moO`1fMWH0MWIf08^;R`80IFEU00@0
IVIV04i>CP1>CTh0>3Ph0P1aLG40101YJFT0QhN708N7Q`2;Rh/207AdM00405YJFP1EEED0EEEE0410
@080LW9b00@0EEEE09:BTP2BTY80SXj>0P1nOWh0102LW9`0I6AT06ATI01fMWH207EeM@0507]kN`3<
c<`0Rh^;08^;R`1PH6000P1ADE400`1^KVh0ZJVY0:VYZ@030;:b/P040::RXP2VYZH0YZJV092@T080
TI6A00@0OWin06i^KP1^KVh0FEUI0P1/K6`0101iNGT0Ti>C09>CT`2m_Kd205eMG@0408b<S02?Shl0
Shn?0;Fe]@80_Kfm00@0aLG508b<S02<S8`0NGUi0P2[Zj/01@2QXJ40UiNG09NGU`1hN7P0KFe]0080
MgMg00@0Ti>C08B4Q024Q8@0MgMg0P28R8P0102h^;P0WinO09nOW`1GEeL2079bLP04051@D033`l<0
`l?30;Zj^P80][Jf00@0ZJVY06YZJP1ZJVX0@4100P3@d=00101jNWX0WYjN09jNWP21PH4207MgM`04
06QXJ02GUiL0UiNG0<O7a`80T92@00@0Lg=c0;jn_P2n_[h0]kNg0P22PX801@1^KVh0RXZ:08Z:RP3:
b/X0Shn?0080Cdm?00@0?Shn02h^;P0^;Rh0A4A40P1aLG40102EUID0J6QX06QXJ020P80207IfMP04
07emO@1fMWH0MWIf05UIF@80N7Qh00@0H61P07moO`1oOgl0ZZZZ0P2VYZH0102ATI40_[jn0;jn_P2f
][H2071`L00409JFUP2VYZH0YZJV096AT@80J6QX00@0MWIf05mOG`1OGel0M7Ad0P2=SHd00`1iNGWo
ooooooooo`040000o`80oh0010000?l20?n000L0003o0`3oP0080000o`@0oh0000<0003o0?n0003o
P00030000?l0103oP000003o0000o`000?l20?n000<0003o0`3oP0080000o`80oh0010000?l30?n0
00<0003o1@3oP00A0000o`80oh0000@0003o0?n0003oP000003o1P3oP0030000o`<0oh002@000?l0
103oP000003o0000o`000?l30?n000D0003o00<0oh000000o`000?l01P3oP00:0000o`030?n00000
0?l0003o00L0003o0`3oP00?0000o`[ooooo0009ooooo`0406MWI`2<S8`0S8b<07]kN`80ATI600@0
MGEe0861P@21PH40M7Ad0P1GEeL0101gMgL0JFUY06UYJ@1oOgl207QhN00407]kN`13@d<0@d=304E5
A@80H61P00@0De=C07inOP1nOWh0PH610P1XJ6P0101CDe<0D51@051@D014A4@207MgM`04061PH02J
VYX0VYZJ08j>SP80QhN700@0WIfM07IfMP1fMWH0N7Qh0P1fMWH0101mOGd0cLg=09NGU`2GUiL3069R
HP04079bLP2SXj<0Xj>S0;Vi^@80^;Rh00@0/k>c0;2`/02`/;00VYZJ0P2UYJD0102<S8`0OWin07in
OP1QHF4207inOP0408>3P`2@T900T92@0;bl_080HF5Q00@0UIFE08N7Q`27QhL0][Jf0P2l_;`01032
`/80Shn?08n?S`2BTY820:n_[`050;Rh^02@T900T92@075aL@1bLW800P1hN7P0102BTY80PH610861
P@1mOGd2096AT@040;bl_02VYZH0YZJV069RHP80NWYj00@0FEUI0<;2`P32`/80/k>c0P2YZJT0102/
[:`0O7al07alO01;Bd/20=_Kf`0407IfMP2?Shl0Shn?07EeM@80Q8B400@0PX:20:f][@2][Jd0a/K6
0P1oOgl0101WIfL0WYjN09jNWP2b/[8207AdM00506UYJ@26QXH0QXJ60<c<c02EUID00P1JFUX01017
AdL05QHF01HF5P0g=cL208Z:RP0408j>SP1NGUh0GUiN07emO@80OWin00@0S8b<0820P020P800HV9R
0P1TI6@0101@D500SXj>08j>SP2c/k<20::RXP0409nOW`2PX:00X:2P09nOW`80I6AT00@0QXJ608R8
R028R8P0RXZ:0P1KFe/0101kNg/0M7Ad07AdM021PH4209VIV@0307IfM_oooooooooo00@0003o0P3o
P0040000o`80oh001`000?l30?n00080003o00<0oh000000o`000?l00`000?l40?n000l0003o00<0
oh000000o`000?l01P000?l50?n000`0003o0P3oP0040000o`D0oh000`000?l30?n000/0003o0P3o
P0040000o`D0oh0010000?l30?n000L0003o0`3oP0050000o`030?n000000?l0003o00<0003o00<0
oh000000o`000?l01P3oP0030000o`030?n000000?l0003o00L0003o00@0oh000000o`000?l0oh00
30000?l20?n000L0003o2_ooool000Wooooo00@0IfMW08b<S02<S8`0Ng]k0P16ATH0101eMGD0PH61
0861P@1dM7@205MGE`0407MgM`1YJFT0JFUY07moO`80N7Qh00@0Ng]k04=3@`13@d<0ADE50P1PH600
101CDe<0OWin07inOP21PH4206QXJ00405=CD`1@D500D51@04A4A080MgMg00@0H61P09ZJVP2JVYX0
SXj>0P27QhL0102MWId0MWIf07IfMP1hN7P207IfMP0407emO@3=cLd0UiNG09NGU`<0HV9R00@0LW9b
0:>SX`2SXj<0^KVi0P2h^;P0102c/k<0/;2`0;2`/02JVYX20:FUY@0408b<S01nOWh0OWin065QH@80
OWin00@0Ph>3092@T02@T900_;bl0P1QHF40102EUID0QhN708N7Q`2f][H20;bl_0040<;2`P2?Shl0
Shn?09:BTP80[jn_00D0^;Rh092@T02@T900LG5a079bLP0207QhN00409:BTP21PH40PH6107emO@80
TI6A00@0_;bl0:JVYP2VYZH0HV9R0P1jNWX0101IFET0`/;20<;2`P2c/k<20:VYZ@040:b/[01lO7`0
O7al04];B`80fm_K00@0MWIf08n?S`2?Shl0MGEe0P24Q8@01022PX80[Jf]0:f][@36a/H207moO`04
06MWI`2NWYh0WYjN0;:b/P80M7Ad00D0JFUY08J6QP26QXH0c<c<09FEU@0205YJFP0404M7A`0F5QH0
5QHF03Lg=`80RXZ:00@0SXj>05iNGP1NGUh0OGem0P1nOWh0102<S8`0P8200820P01RHV8206ATI004
051@D02>SXh0SXj>0;>c/`80XZ:R00@0WinO0:2PX02PX:00WinO0P1TI6@01026QXH0R8R808R8R02:
RXX205]KF`0407]kN`1dM7@0M7Ad0861P@80VIVI00<0MWIfooooooooool010000?l20?n000@0003o
0P3oP0070000o`<0oh000P000?l00`3oP000003o0000o`030000o`@0oh003`000?l00`3oP000003o
0000o`060000o`D0oh0030000?l20?n000@0003o1@3oP0030000o`<0oh002`000?l20?n000@0003o
1@3oP0040000o`<0oh001`000?l30?n000D0003o00<0oh000000o`000?l00`000?l00`3oP000003o
0000o`060?n000<0003o00<0oh000000o`000?l01`000?l0103oP000003o0000o`3oP00<0000o`80
oh001`000?l:ooooo`002Oooool0101MGEd0Rh^;08^;R`1jNWX2055AD@0407MgM`25QHD0QHF50820
P080GUiN00@0P82007alO01lO7`0NGUi0P1aLG40101fMWH0Cdm?04m?C`1=CDd205UIF@0405EEE@1i
NGT0NGUi092@T080HF5Q00@0De=C05YJFP1JFUX0A4A40P1kNg/0101SHf<0WYjN09jNWP2WYjL208B4
Q00409FEU@1`L700L71`07=cL`80MWIf00D0Lg=c0<C4a01oOgl0Ogmo05YJFP0307=cL`80UIFE00@0
^;Rh0<71`@31`L40][Jf0P2MWId0101iNGT0SXj>08j>SP20P80207EeM@0405IFEP1bLW80LW9b07al
O080W9bL00@0]kNg06e]K@1]KFd0U9BD0P21PH40102b/[80_Kfm0;fm_@33`l<2092@T00407emO@2_
[jl0[jn_0:n_[`80SXj>00D0MGEe071`L021PH40PH6109:BTP0207inOP0407]kN`2>SXh0SXj>0;Ng
]`80U9BD00@0FEUI07MgM`1gMgL0FUYJ0P36a/H01032`/80VYZJ09ZJVP2][Jd20861P@0404Q8B03N
g]h0g]kN08R8R080RHV900@0Ng]k08>3P`23Ph<0RHV90P2^[Zh0103EeMD0UiNG09NGU`1mOGd20:b/
[0040;Rh^01WIfL0IfMW07alO080LG5a00D0/k>c09VIV@1LG5`0G5aL0451@@0203<c<`0402@T901_
Kfl0Kfm_06UYJ@80De=C00@0K6a/07=cL`1cLg<0QHF50P1iNGT0101FEUH0J6QX06QXJ012@T82061P
H00409BDU02KVi/0Vi^K08R8R080PH6100@0^;Rh07=cL`1cLg<0S8b<0P2KVi/01029RHT0DE5A055A
D@1`L70206UYJ@0407]kN`2MWId0WIfM08B4Q0;ooooo00@0oh000000o`000?l0003o0P3oP0040000
o`80oh001`000?l60?n000D0003o103oP00?0000o`040?n000000?l0003o0?n000D0003o103oP007
0000o`80oh0010000?l20?n000@0003o1@3oP0030000o`<0oh002`000?l20?n000040000o`3oP000
oh000000o`D0oh0000@0003o0?n0003oP000003o0`3oP0070000o`<0oh001@000?l00`3oP000003o
0000o`030000o`030?n000000?l0003o00H0oh000`000?l00`3oP000003o0000o`040000o`040?n0
00000?l0003o0?n000P0003o00<0oh000000o`000?l010000?l20?n000L0003o2_ooool000Wooooo
00@0IFEU0:>SX`2SXj<0M7Ad0P1:BTX0101mOGd0WYjN09jNWP27QhL205iNGP0407alO01mOGd0OGem
09BDU080PX:200@0O7al05aLG01LG5`0AdM70P1UIFD0101WIfL0Ng]k07]kN`1`L70204];B`0405eM
G@1>CTh0CTi>0492@P80Kfm_00@0F5QH09JFUP2FUYH0YjNW0P2<S8`0102NWYh0MWIf07IfMP1cLg<2
07UiN@0506YZJP2m_Kd0NGUi07UiN@1FEUH00P1PH600101JFUX0NWYj07YjNP2PX:020:NWY`040:JV
YP2EUID0UIFE07YjNP80S8b<00@0OGem079bLP1bLW80EeMG0P1hN7P0101oOgl0VYZJ09ZJVP2j^[X2
07=cL`0409RHV02;Rh/0Rh^;0::RXP80^[Zj00@0aLG509FEU@2EUID0N7Qh0P2h^;P01@2j^[X0WIfM
09fMW@1nOWh0I6AT0080MgMg00@0Ti>C08B4Q024Q8@0QHF50P2BTY80102j^[X0X:2P0:2PX01LG5`2
07AdM00405iNGP2n_[h0_[jn0<O7a`80]kNg00@0Zj^[08B4Q024Q8@0A4A40P3GemL0102EUID0S8b<
08b<S024Q8@207]kN`0407inOP2[Zj/0Zj^[0=GEe@80T92@00@0Q8B40:6QX@2QXJ40_[jn0P1WIfL0
1@1dM7@0Fe]K05]KF`30`<00VIVI0080C4a<00@0@d=303De=@0e=CD0=3@d0P1XJ6P0101QHF40DU9B
059BDP1HF5P207moO`0407=cL`1bLW80LW9b05YJFP80IfMW00@0DE5A06YZJP1ZJVX0RHV90P2FUYH0
102EUID0U9BD09BDU02][Jd206UYJ@040:2PX02HV9P0V9RH09RHV080EeMG00@0FEUI04Q8B018B4P0
GEeM0P2:RXX00`1hN7Soooooooooo`040000o`80oh0010000?l20?n000L0003o0`3oP0060000o`H0
oh0000<0003o0?n0003oP00030000?l0103oP000003o0000o`3oP0020000o`030?n000000?l0003o
00/0003o0P3oP0040000o`80oh001P000?l30?n000<0003o0`3oP00;0000o`80oh0000@0003o0?n0
003oP000003o1P3oP0030000o`<0oh002@000?l00`3oP000003o0000o`030000o`040?n000000?l0
003o0000o`<0oh000P000?l60?n000<0003o0`3oP0040000o`040?n000000?l0003o0?n000P0003o
00<0oh000000o`000?l010000?l60?n000<0003o2_ooool000Wooooo00@0GUiN09>CT`2CTi<0Jf][
0P18B4P0101fMWH0RHV908V9R@1_Kfl205IFEP040861P@1mOGd0OGem09BDU080PH6100@0Ng]k069R
HP1RHV80F5QH0`1XJ6P208V9R@040:FUY@1BDU80DU9B051@D080EEEE00@0BDU907YjNP1jNWX0DU9B
0P2GUiL0102MWId0U9BD09BDU02SXj<207=cL`0507EeM@1lO7`0O7al079bLP3<c<`00P24Q8@0101N
GUh0LG5a075aL@1YJFT207moO`040:VYZ@2/[:`0[:b/0;6a/@80RXZ:00@0PH6109:BTP2BTY80Ph>3
0P21PH40101CDe<0Lg=c07=cL`2FUYH209VIV@040;no_`2>SXh0SXj>09jNWP80UIFE00@0XZ:R0<C4
a034a<@0`/;20P2LW9`0101dM7@0ZJVY0:VYZ@2^[Zh20:f][@0507UiN@1aLG40U9BD09BDU02VYZH0
0P1nOWh01028R8P0QXJ608J6QP2m_Kd20:^[Z`0406=SH`1ZJVX0JVYZ07QhN080XZ:R00@0/;2`0:BT
Y02TY:@0UYJF0P1fMWH01012@T80bLW90<W9b@26QXH2092@T00407inOP1`L700L71`06i^KP80WIfM
00@0aLG508B4Q024Q8@0QhN70P2/[:`0102^[Zh0KVi^06i^KP22PX8205eMG@050:6QX@2LW9`0DE5A
055AD@13@d<00P1:BTX0101ADE40Hf=S06=SH`1/K6`206ATI00404M7A`1LG5`0G5aL05IFEP80Lg=c
00@0D51@06a/K01/K6`0C4a<0P1OGel0101kNg/0XJ6Q0:6QX@25QHD209VIV@040:^[Z`1TI6@0I6AT
08j>SP80Ogmo00@0W9bL05UIF@1IFET0LW9b0P1MGEd0101mOGd0SXj>08j>SP1_Kfl2ooooo`040?n0
00000?l0003o0000o`80oh0010000?l20?n000T0003o00<0oh000000o`000?l010000?l60?n00003
0000o`3oP000oh0000`0003o00@0oh000000o`000?l0oh0020000?l00`3oP000003o0000o`050000
o`80oh0010000?l20?n000H0003o0`3oP0040000o`<0oh002P000?l20?n000L0003o0P3oP0040000
o`<0oh002@000?l00`3oP000003o0000o`030000o`040?n000000?l0003o0000o`80oh000`000?l6
0?n000@0003o103oP0020000o`040?n000000?l0003o0?n000l0003o0P3oP0000`000?l0oh000?n0
00040000o`[ooooo0009ooooo`0405iNGP2CTi<0Ti>C06][J`80B4Q800@0MWIf08V9R@29RHT0Kfm_
0P1FEUH01021PH40OGem07emO@2DU9@20861P@0407]kN`1RHV80HV9R05QHF0<0J6QX0P29RHT0102U
YJD0DU9B059BDP1@D50205EEE@0404U9B@1jNWX0NWYj059BDP80UiNG00@0WIfM09BDU02DU9@0Xj>S
0P1cLg<01@1eMGD0O7al07alO01bLW80c<c<0080Q8B400@0GUiN075aL@1aLG40JFUY0P1oOgl0102Y
ZJT0[:b/0:b/[02a/K4208Z:RP040861P@2BTY80TY:B08>3P`80PH6100@0De=C07=cL`1cLg<0UYJF
0P2IVIT0102o_kl0SXj>08j>SP2NWYh209FEU@040::RXP34a<@0a<C40<;2`P80W9bL00@0M7Ad0:VY
Z@2YZJT0[Zj^0P2][Jd01@1iNGT0LG5a09BDU02DU9@0YZJV0080OWin00@0R8R808J6QP26QXH0_Kfm
0P2[Zj/0101SHf<0JVYZ06YZJP1hN7P20::RXP040;2`/02TY:@0Y:BT09JFUP80MWIf00@0@T920<W9
b@39bLT0QXJ60P2@T900101nOWh0L71`071`L01^KVh209fMW@040<G5a@24Q8@0Q8B408N7Q`80[:b/
00@0[Zj^06i^KP1^KVh0PX:20P1MGEd01@2QXJ40W9bL055AD@1ADE40@d=30080BTY:00@0DE5A06=S
H`1SHf<0K6a/0P1TI6@01017AdL0G5aL05aLG01FEUH207=cL`04051@D01/K6`0K6a/04a<C080GemO
00@0Ng]k0:6QX@2QXJ40QHF50P2IVIT0102[Zj/0I6AT06ATI02>SXh207moO`0409bLW01IFET0FEUI
079bLP80GEeM00@0OGem08j>SP2>SXh0Kfm_0_ooool0103oP000003o0000o`000?l20?n000@0003o
0P3oP0090000o`030?n000000?l0003o00@0003o1P3oP0000`000?l0oh000?n0000<0000o`040?n0
00000?l0003o0?n000P0003o00<0oh000000o`000?l01@000?l20?n000@0003o0P3oP0060000o`<0
oh0010000?l30?n000X0003o0P3oP0070000o`80oh0010000?l30?n000T0003o00<0oh000000o`00
0?l00`000?l0103oP000003o0000o`000?l20?n000<0003o1P3oP0040000o`@0oh000P000?l0103o
P000003o0000o`3oP00?0000o`80oh0000<0003o0?n0003oP00010000?l:ooooo`002Oooool0101T
I6@0WYjN09jNWP1ZJVX204A4A00406a/K02NWYh0WYjN08n?S`80MGEe00@0VYZJ08^;R`2;Rh/0XZ:R
0P2>SXh0101iNGT0De=C05=CD`1KFe/206MWI`0406QXJ02?Shl0Shn?09fMW@80GemO00@0GEeM05YJ
FP1JFUX0ATI60P1mOGd0101EEED0X:2P0:2PX02EUID208N7Q`040:b/[01gMgL0MgMg07IfMP80PH61
00D0Kfm_0=?Cd`2LW9`0W9bL06ATI00207UiN@0406][J`2MWId0WIfM0<G5a@80`<3000@0alO708n?
S`2?Shl0S8b<0P2>SXh0101gMgL0N7Qh07QhN01KFe/208J6QP04096AT@2OWil0WinO0;:b/P80W9bL
00@0YJFU08j>SP2>SXh0VIVI0P3EeMD0102d];@0ZJVY0:VYZ@2>SXh20:j^[P050:>SX`2?Shl0Shn?
07emO@1kNg/00P2DU9@0102ZZZX0QXJ608J6QP2HV9P2096AT@040;no_`2k^k/0^k^k07UiN@80FEUI
00@0O7al0:^[Z`2[Zj/0a<C40P2[Zj/0102JVYX0Kfm_06m_K`0n?Sh20<[:bP0408F5Q@29RHT0RHV9
0861P@80L71`00@0KVi^0:FUY@2UYJD0alO70P27QhL01021PH40Vi^K09^KV`2;Rh/207AdM00504a<
C01FEUH0EUIF09ZJVP29RHT00P1;Bd/0100c<c<0=3@d03@d=01;Bd/206=SH`04065QH@1ZJVX0JVYZ
04Y:BP80J6QX00@0GEeM06a/K01/K6`0EeMG0P1VIVH0101>CTh0FEUI05UIF@2EUID209bLW00409:B
TP2;Rh/0Rh^;09ZJVP80Hf=S00@0YZJV092@T02@T900YJFU0P1KFe/0101VIVH0IfMW06MWI`1nOWh2
08F5Q@0307AdM?oooooooooo00@0003o0P3oP00=0000o`<0oh0020000?l40?n000030000o`3oP000
oh0000`0003o00<0oh000000o`000?l01P000?l40?n000L0003o0P3oP0040000o`80oh001P000?l3
0?n000<0003o00<0oh000000o`000?l02`000?l30?n00080003o00@0oh000000o`000?l0003o0P3o
P0040000o`<0oh002@000?l00`3oP000003o0000o`060000o`<0oh000`000?l60?n000@0003o0P3o
P0001@000?l0oh000000o`000?l0oh000080003o0`3oP00=0000o`80oh001`000?l:ooooo`002Ooo
ool0101UIFD0TI6A096AT@1bLW8204I6AP0406a/K01nOWh0OWin08R8R080QHF500@0Vi^K0820P020
P800Shn?0P22PX80101]KFd0Fe]K05]KF`1?Cdl206UYJ@0404m?C`1eMGD0MGEe08b<S0<0FEUI0P1A
DE401013@d<0Hf=S06=SH`1CDe<209JFUP0408^;R`23Ph<0Ph>30:>SX`80LG5a00D0GemO07=cL`1c
Lg<0KFe]0<[:bP0208>3P`0406YZJP26QXH0QXJ605eMG@80R8R800@0_Kfm0;Ng]`2g]kL0`L710P2B
TY800`2KVi/0T92@092@T0030861P@0405EEE@20P800P8200861P@80Zj^[00@0VYZJ09RHV02HV9P0
Ti>C0P2>SXh01021PH40f][J0=[JfP2e]KD20;Zj^P0408n?S`32`/80`/;20<;2`P80WYjN00D0Ogmo
07=cL`1iNGT0NGUi096AT@020861P@0409ZJVP2>SXh0SXj>0;Ng]`80][Jf00@0LW9b05IFEP1FEUH0
U9BD0P2ZZZX0102m_Kd0_kno0;no_`2PX:0207UiN@0304=3@`3Fe]H0e]KF00<0SHf=00@0OGem06i^
KP1^KVh0K6a/0P2NWYh0102h^;P0S8b<08b<S02;Rh/209jNWP0408N7Q`2CTi<0Ti>C06YZJP80GEeM
00D0TY:B09NGU`1DE5@0E5AD03hn?P0203/k>`0405]KF`1JFUX0FUYJ05UIF@80IVIV00@0C4a<06MW
I`1WIfL0G5aL0P24Q8@01015ADD0GEeM05eMG@1PH60204E5A@0407QhN02PX:00X:2P08n?S`80QHF5
00@0W9bL06m_K`1_Kfl0ZJVY0P25QHD0102ZZZX0EEEE05EEE@1OGel207AdM00408N7Q`2=SHd0SHf=
08f=S@;ooooo10000?l20?n000d0003o0`3oP0020000o`040?n000000?l0003o0000o`H0oh0000<0
003o0?n0003oP00030000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00@0oh001`00
0?l20?n000`0003o103oP0020000o`<0oh002`000?l30?n00080003o00@0oh000000o`000?l0003o
0`3oP0030000o`<0oh002@000?l00`3oP000003o0000o`070000o`80oh000`000?l90?n000050000
o`3oP000oh000000o`3oP0000P000?l30?n000030000o`3oP000oh0000d0003o0P3oP0070000o`[o
oooo0009ooooo`0406EUI@2ATI40TI6A079bLP80ATI600@0K6a/07inOP1nOWh0R8R80P25QHD0102K
Vi/0P8200820P02?Shl208:2PP0406e]K@1KFe/0Fe]K04m?C`80JFUY00@0Cdm?07EeM@1eMGD0S8b<
0`1IFET2055AD@0404=3@`1SHf<0Hf=S05=CD`80UYJF00@0Rh^;08>3P`23Ph<0Xj>S0P1aLG401@1O
Gel0Lg=c07=cL`1]KFd0b/[:0080Ph>300@0JVYZ08J6QP26QXH0GEeM0P28R8P0102m_Kd0]kNg0;Ng
]`31`L4209:BTP0309^KV`2@T900T92@00<0PH6100@0EEEE0820P020P800PH610P2[Zj/0102JVYX0
V9RH09RHV02CTi<208j>SP040861P@3Jf]X0f][J0;Fe]@80^[Zj00@0Shn?0<;2`P32`/80`/;20P2N
WYh01@1oOgl0Lg=c07UiN@1iNGT0TI6A0080PH6100@0VYZJ08j>SP2>SXh0]kNg0P2f][H0101bLW80
EUIF05IFEP2DU9@20:ZZZP040;fm_@2o_kl0_kno0:2PX080NGUi00<0@d=30=KFeP3Fe]H00`2=SHd0
101mOGd0KVi^06i^KP1/K6`209jNWP040;Rh^02<S8`0S8b<08^;R`80WYjN00@0QhN709>CT`2CTi<0
JVYZ0P1MGEd01@2BTY80UiNG05ADE01DE5@0?Shn0080>c/k00@0Fe]K05YJFP1JFUX0FEUI0P1VIVH0
101<C4`0IfMW06MWI`1LG5`208B4Q00404E5A@1MGEd0GEeM061PH080ADE500@0N7Qh0:2PX02PX:00
Shn?0P25QHD0102LW9`0Kfm_06m_K`2YZJT208F5Q@040:ZZZP1EEED0EEEE05mOG`80M7Ad00@0QhN7
08f=S@2=SHd0SHf=0_ooool40000o`80oh003@000?l30?n00080003o00@0oh000000o`000?l0003o
1P3oP0000`000?l0oh000?n0000<0000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l0
103oP0070000o`80oh0030000?l40?n00080003o0`3oP00;0000o`<0oh000P000?l0103oP000003o
0000o`000?l30?n000<0003o0`3oP0090000o`030?n000000?l0003o00L0003o0P3oP0030000o`T0
oh0000D0003o0?n0003oP000003o0?n000020000o`<0oh0000<0003o0?n0003oP0003@000?l20?n0
00L0003o2_ooool000Wooooo00@0JFUY0:j^[P2^[Zh0O7al0P1EEED0102:RXX0YJFU0:FUY@2CTi<2
07MgM`0409bLW01nOWh0OWin096AT@80Ogmo00@0P820055AD@1ADE40?clo0P1LG5`0101NGUh0Lg=c
07=cL`1hN7P205ADE00405eMG@1?Cdl0Cdm?0451@@80Ogmo00@0HV9R09nOW`2OWil0SHf=0P2@T900
102SXj<0Jf][06][J`1UIFD2061PH00505eMG@35aLD0SHf=08f=S@1VIVH00P1kNg/0101JFUX0Lg=c
07=cL`2][Jd20;Fe]@040;6a/@24Q8@0Q8B408j>SP80RXZ:00@0OWin08^;R`2;Rh/0L71`0P2?Shl0
1028R8P0/;2`0;2`/02SXj<209JFUP04092@T02IVIT0VIVI07UiN@80gmoO00@0ZJVY0:b/[02/[:`0
QHF50P31`L401@2n_[h0UiNG09NGU`1gMgL0Lg=c0080Q8B400@0UYJF0861P@21PH40[Zj^0P27QhL0
102_[jl0_Kfm0;fm_@1fMWH205QHF004096AT@2/[:`0[:b/0;Vi^@80Xj>S00@0NWYj06][J`1[Jf/0
?clo0P3?cll0102GUiL0RXZ:08Z:RP29RHT207QhN00407inOP2h^;P0^;Rh0<g=c@80UIFE00@0UYJF
0:BTY02TY:@0QHF50P2TY:@01@1RHV80SHf=08f=S@2RXZ80WYjN0080CTi>00@0=cLg03De=@0e=CD0
Cdm?0P1FEUH0101:BTX0Jf][06][J`1IFET2069RHP0405=CD`29RHT0RHV904=3@`80D51@00@0GUiN
04m?C`1?Cdl0MWIf0P2<S8`0102IVIT0RXZ:08Z:RP28R8P207alO0040;Ng]`2IVIT0VIVI09:BTP80
HV9R00@0G5aL07UiN@1iNGT0RXZ:0P24Q8@0101cLg?oooooooooo`000?l20?n000030000o`3oP000
oh0000d0003o1P3oP0030000o`H0oh003@000?l30?n000D0003o00<0oh000000o`000?l0103oP00<
0000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l00`000?l30?n000P0003o0P3oP000
10000?l0oh000?n0003oP0020000o`040?n000000?l0003o0000o`80oh0010000?l30?n000L0003o
0`3oP00>0000o`T0oh0000D0003o0?n0003oP000003o0?n000020000o`H0oh002@000?l00`3oP000
003o0000o`030000o`030?n000000?l0003o00@0003o2_ooool000Wooooo00@0E5AD09>CT`2CTi<0
IFEU0P14A4@0101jNWX0X:2P0:2PX02PX:0208B4Q00409FEU@2=SHd0SHf=07emO@80OWin00@0Kfm_
05MGE`1GEeL0ATI60P1LG5`0101NGUh0P8200820P024Q8@204Q8B00406EUI@1IFET0FEUI04M7A`80
PX:200@0MWIf0::RXP2RXZ80SHf=0P2EUID0102][Jd0NWYj07YjNP1_Kfl206YZJP0505eMG@2l_;`0
QHF508F5Q@1eMGD00P1kNg/0101QHF40SXj>08j>SP2i^KT20<G5a@040;^k^`29RHT0RHV909fMW@80
T92@00@0Ph>3092@T02@T900N7Qh0P1jNWX00`1gMgL0YjNW0:NWY`0309VIV@0406a/K02ATI40TI6A
05iNGP80f=SH00@0YJFU0:JVYP2VYZH0UYJF0P2k^k/01@2m_Kd0PH610861P@1/K6`0HF5Q0080Ng]k
00@0QHF507EeM@1eMGD0X:2P0P1]KFd0102IVIT0X:2P0:2PX01bLW82055AD@0408b<S02][Jd0[Jf]
0;^k^`80YZJV00@0Shn?06][J`1[Jf/0@d=30P3Bd]80102FUYH0Ogmo07moO`20P80206m_K`04079b
LP2^[Zh0[Zj^0<?3``80WinO00@0VYZJ0;:b/P2b/[80Shn?0P2e]KD01@1dM7@0TY:B09:BTP2NWYh0
S8b<0080ATI600@0=CDe03<c<`0c<c<0@d=30P1<C4`01016ATH0KVi^06i^KP1ZJVX205ADE00404m?
C`23Ph<0Ph>304Q8B080BTY:00@0M7Ad05IFEP1FEUH0NWYj0P2BTY8308Z:RP0408^;R`28R8P0R8R8
0:ZZZP80WIfM00@0WYjN05iNGP1NGUh0EEEE0P1lO7`0101ZJVX0JFUY06UYJ@1[Jf/2ooooo`040?n0
00000?l0003o0000o`80oh003@000?l60?n000<0003o0P3oP00010000?l0oh000?n0003oP0070000
o`80oh0010000?l30?n000P0003o103oP00C0000o`<0oh001@000?l30?n00100003o00<0oh000000
o`000?l00`3oP0040000o`<0oh001`000?l30?n000<0003o0P3oP0000`000?l0oh000?n000060000
o`T0oh000`000?l20?n00080003o0`3oP0000`000?l0oh000?n0000=0000o`<0oh001P000?l:oooo
o`002Oooool0101DE5@0Ti>C09>CT`1UIFD204A4A00407YjNP2PX:00X:2P0:2PX080Q8B400@0UIFE
08f=S@2=SHd0OGem0P1nOWh0101_Kfl0EeMG05MGE`16ATH205aLG00405iNGP20P800P82008B4Q080
B4Q800@0IFEU05UIF@1IFET0AdM70P22PX80101fMWH0XZ:R0::RXP2=SHd209FEU@040:f][@1jNWX0
NWYj06m_K`80JVYZ00D0GEeM0;bl_025QHD0QHF507EeM@0207]kN`04065QH@2>SXh0SXj>0;Vi^@80
aLG500@0^k^k08V9R@29RHT0WIfM0P2@T9001023Ph<0T92@092@T01hN7P207YjNP0307MgM`2WYjL0
YjNW00<0VIVI00@0K6a/096AT@2ATI40GUiN0P3Hf=P0102UYJD0YZJV0:JVYP2FUYH20;^k^`050;fm
_@21PH40PH6106a/K01QHF400P1kNg/01025QHD0MGEe07EeM@2PX:0206e]K@0409VIV@2PX:00X:2P
079bLP80DE5A00@0S8b<0:f][@2][Jd0^k^k0P2VYZH0102?Shl0Jf][06][J`13@d<20=;BdP0409JF
UP1oOgl0Ogmo0820P080Kfm_00@0LW9b0:j^[P2^[Zh0`l?30P2OWil0102JVYX0/[:b0;:b/P2?Shl2
0;Fe]@0507AdM02BTY80TY:B09jNWP2<S8`00P16ATH0100e=CD0<c<c03<c<`13@d<204a<C00404I6
AP1^KVh0KVi^06YZJP80E5AD00@0Cdm?08>3P`23Ph<0B4Q80P1:BTX0101dM7@0EUIF05IFEP1jNWX2
09:BTP<0RXZ:00@0Rh^;08R8R028R8P0ZZZZ0P2MWId0102NWYh0GUiN05iNGP1EEED207alO00406YZ
JP1YJFT0JFUY06][J`;ooooo00@0oh000000o`000?l0003o0P3oP00=0000o`H0oh000`000?l20?n0
00040000o`3oP000oh000?n000L0003o0P3oP0040000o`<0oh0020000?l40?n001<0003o0`3oP005
0000o`<0oh0040000?l00`3oP000003o0000o`030?n000@0003o0`3oP0070000o`<0oh000`000?l2
0?n000030000o`3oP000oh0000H0003o2@3oP0030000o`80oh000P000?l30?n000030000o`3oP000
oh0000d0003o0`3oP0060000o`[ooooo0009ooooo`0406IVIP2PX:00X:2P07UiN@80DE5A00@0Ogmo
0:>SX`2SXj<0WinO0P20P800101/K6`0OWin07inOP1VIVH207=cL`0406e]K@1OGel0GemO03Xj>P80
EEEE00@0GUiN06e]K@1]KFd0JVYZ0P16ATH0101[Jf/0FEUI05UIF@14A4@206QXJ00405YJFP2CTi<0
Ti>C09>CT`80X:2P00@0Xj>S07alO01lO7`0Kfm_0P1/K6`01@1JFUX0/k>c08V9R@29RHT0O7al0080
MgMg00@0FUYJ07]kN`1kNg/0[Zj^0P36a/H0102e]KD0RHV908V9R@2=SHd2092@T00408:2PP2ATI40
TI6A08F5Q@80Ng]k00@0P8200;:b/P2b/[80UYJF0P2IVIT01023Ph<0Vi^K09^KV`1/K6`20<K6aP04
0:FUY@2OWil0WinO0:BTY080[Jf]00D0`L71096AT@2ATI40NGUi07IfMP0208N7Q`040820P01cLg<0
Lg=c08J6QP80HF5Q00@0XJ6Q0:VYZ@2YZJT0Jf][0P1@D5001020P800[Jf]0:f][@2g]kL209ZJVP04
09FEU@1ZJVX0JVYZ04m?C`80gMgM00@0OWin07]kN`1kNg/0KFe]0P1UIFD0101]KFd0]KFe0;Fe]@2h
^;P209ZJVP040820P02WYjL0YjNW09:BTP80ZZZZ00D0G5aL08n?S`2?Shl0WYjN08V9R@0204e=C@04
03Ti>@0Y:BT0:BTY0451@@80BTY:00@0?Shn07emO@1mOGd0K6a/0P1KFe/0101/K6`0MGEe07EeM@1W
IfL204m?C`0407QhN01iNGT0NGUi07]kN`<0VIVI0P2>SXh00`24Q8@0TI6A096AT@0309ZJVP0409nO
W`1HF5P0F5QH05eMG@80I6AT00@0De=C07AdM01dM7@0Kfm_0_ooool40000o`80oh003`000?l40?n0
00<0003o0P3oP0001@000?l0oh000?n0003oP000003o0080oh002P000?l30?n000D0003o00<0oh00
0000o`000?l0103oP00<0000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l00`000?l3
0?n00100003o00<0oh000000o`000?l00`3oP0040000o`<0oh001`000?l30?n000P0003o00<0oh00
0000o`000?l00`000?l90?n000<0003o00<0oh000000o`000?l00P000?l20?n00100003o0`3oP002
0000o`040?n000000?l0003o0000o`[ooooo0009ooooo`0406MWI`2ATI40TI6A079bLP80IVIV00@0
PH6109^KV`2KVi/0W9bL0P29RHT0101kNg/0UIFE09FEU@1]KFd207emO@0407MgM`1VIVH0IVIV04e=
C@80FUYJ00@0Ph>307YjNP1jNWX0HV9R0P0_;bl0101BDU80ATI604I6AP19BDT208N7Q`0405ADE029
RHT0RHV909BDU080Xj>S00@0Y:BT07]kN`1kNg/0KVi^0P1`L7001@1UIFD0`<3008N7Q`27QhL0PX:2
0080Kfm_00@0Fe]K08B4Q024Q8@0^;Rh0P3Fe]H0102^[Zh0KFe]06e]K@20P80208V9R@0407QhN02D
U9@0U9BD0820P080KFe]00@0IFEU0::RXP2RXZ80Lg=c0P2[Zj/0102IVIT0YjNW0:NWY`1OGel20=CD
e00409jNWP2DU9@0U9BD0:6QX@80VYZJ00D0][Jf09:BTP2BTY80MgMg07inOP0208f=S@0408j>SP22
PX80PX:208b<S080Lg=c00@0WYjN0:NWY`2WYjL0MWIf0P1]KFd0101gMgL0WIfM09fMW@2VYZH209JF
UP0409>CT`1QHF40HF5Q055AD@80f][J00@0T92@07=cL`1cLg<0NGUi0P1VIVH0101hN7P0`<300<30
`02e]KD20:FUY@0408N7Q`2SXj<0Xj>S0820P080Zj^[00D0Hf=S08>3P`23Ph<0Shn?092@T002061P
H00403@d=00[:b/0:b/[03lo?`80@D5100@0=3@d05UIF@1IFET0IVIV0P1JFUX0101WIfL0JVYZ06YZ
JP1PH602055AD@04069RHP1`L700L71`07QhN080WIfM00@0UIFE08R8R028R8P0Ng]k0P2;Rh/0102U
YJD0YZJV0:JVYP29RHT2071`L00406YZJP1kNg/0Ng]k05aLG080Lg=c00<0IFEUooooooooool05@00
0?l30?n000@0003o1P3oP0000`000?l0oh000?n0000<0000o`030?n000000?l0003o00<0003o00<0
oh000000o`000?l0103oP00E0000o`030?n000000?l0003o00@0003o0P3oP00J0000o`<0oh001`00
0?l30?n000l0003o2@3oP0020000o`030?n000000?l0003o0080003o0P3oP00E0000o`040?n00000
0?l0003o0000o`[ooooo0009ooooo`0406MWI`2ATI40TI6A079bLP80IVIV00@0PH6109^KV`2KVi/0
W9bL0P29RHT0101kNg/0UIFE09FEU@1]KFd207emO@0407MgM`1VIVH0IVIV04e=C@80FUYJ00@0Ph>3
07YjNP1jNWX0HV9R0P0_;bl0101BDU80ATI604I6AP19BDT208N7Q`0405ADE029RHT0RHV909BDU080
Xj>S00@0Y:BT07]kN`1kNg/0KVi^0P1`L7001@1UIFD0`<3008N7Q`27QhL0PX:20080Kfm_00@0Fe]K
08B4Q024Q8@0^;Rh0P3Fe]H0102^[Zh0KFe]06e]K@20P80208V9R@0407QhN02DU9@0U9BD0820P080
KFe]00@0IFEU0::RXP2RXZ80Lg=c0P2[Zj/0102IVIT0YjNW0:NWY`1OGel20=CDe00409jNWP2DU9@0
U9BD0:6QX@80VYZJ00D0][Jf09:BTP2BTY80MgMg07inOP0208f=S@0408j>SP22PX80PX:208b<S080
Lg=c00@0WYjN0:NWY`2WYjL0MWIf0P1]KFd0101gMgL0WIfM09fMW@2VYZH209JFUP0409>CT`1QHF40
HF5Q055AD@80f][J00@0T92@07=cL`1cLg<0NGUi0P1VIVH0101hN7P0`<300<30`02e]KD20:FUY@04
08N7Q`2SXj<0Xj>S0820P080Zj^[00D0Hf=S08>3P`23Ph<0Shn?092@T002061PH00403@d=00[:b/0
:b/[03lo?`80@D5100@0=3@d05UIF@1IFET0IVIV0P1JFUX0101WIfL0JVYZ06YZJP1PH602055AD@04
069RHP1`L700L71`07QhN080WIfM00@0UIFE08R8R028R8P0Ng]k0P2;Rh/0102UYJD0YZJV0:JVYP29
RHT2071`L00406YZJP1kNg/0Ng]k05aLG080Lg=c00<0IFEUooooooooool05@000?l30?n000@0003o
1P3oP0000`000?l0oh000?n0000<0000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l0
103oP00E0000o`030?n000000?l0003o00@0003o0P3oP00J0000o`<0oh001`000?l30?n000l0003o
2@3oP0020000o`030?n000000?l0003o0080003o0P3oP00E0000o`040?n000000?l0003o0000o`[o
oooo0009ooooo`0407AdM02JVYX0VYZJ07alO080GEeM00@0NWYj092@T02@T900WYjN0P2QXJ40101[
Jf/0Ogmo07moO`1VIVH207IfMP0407=cL`1PH600H61P04i>CP80I6AT00@0Shn?09NGU`2GUiL0Ph>3
0P0i>CT0101`L700LW9b079bLP1OGel207emO@0405EEE@2?Shl0Shn?08f=S@80Vi^K00@0XZ:R07Yj
NP1jNWX0Jf][0P1bLW801@1JFUX0`/;208R8R028R8P0PH610080Ogmo00@0GEeM09>CT`2CTi<0^k^k
0P3Jf]X0102[Zj/0De=C05=CD`1=CDd20820P00406e]K@24Q8@0Q8B407IfMP80IVIV00@0KVi^0;6a
/@2a/K40Ph>30P2][Jd0102FUYH0XJ6Q0:6QX@1IFET20=oOg`040::RXP2KVi/0Vi^K0;Rh^080UiNG
00D0bLW908f=S@2=SHd0O7al0861P@0209>CT`0408^;R`2OWil0WinO0::RXP80P82000@0YjNW0;^k
^`2k^k/0NGUi0P21PH40101oOgl0WYjN09jNWP2YZJT20:n_[`0408^;R`1HF5P0F5QH051@D080d];B
00@0R8R806=SH`1SHf<0KVi^0P1FEUH0101aLG40bl_;0<_;b`2n_[h20:VYZ@0408>3P`2KVi/0Vi^K
08f=S@80]KFe00D0Hf=S07inOP1nOWh0WinO0:BTY00207IfMP0404=3@`0n?Sh0?Shn05=CD`80DU9B
00@0@T9207]kN`1kNg/0C4a<0P1?Cdl0101[Jf/0IVIV06IVIP1FEUH204E5A@0404A4A01@D500D51@
07moO`80XJ6Q00@0UiNG08V9R@29RHT0TI6A0P2>SXh0101oOgl0UIFE09FEU@1nOWh206i^KP04079b
LP26QXH0QXJ606=SH`80LG5a00<0MgMgooooooooool010000?l20?n000l0003o00<0oh000000o`00
0?l010000?l20?n000D0003o0P3oP00:0000o`<0oh001@000?l00`3oP000003o0000o`030?n00004
0000o`3oP000oh000?n000T0003o00@0oh000000o`000?l0oh000`000?l30?n000<0003o0P3oP000
0`000?l0oh000?n0000=0000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l0103oP005
0000o`030?n000000?l0oh000080oh001P000?l20?n000L0003o203oP00010000?l0oh000?n0003o
P0030000o`H0oh005P000?l:ooooo`002Oooool0101UIFD0SHf=08f=S@1fMWH204Y:BP0408>3P`2P
X:00X:2P09fMW@80P82000@0N7Qh07YjNP1jNWX0EUIF0P1dM7@0101cLg<0Fe]K05]KF`0c<c<203/k
>`0406QXJ01oOgl0Ogmo07AdM080<c<c00@0FUYJ06=SH`1SHf<0DU9B0P1fMWH0101JFUX0TI6A096A
T@2DU9@20:^[Z`040;Bd]02ATI40TI6A07AdM080K6a/00D0CDe=0;Zj^P2;Rh/0Rh^;0820P00208B4
Q00405YJFP2?Shl0Shn?0;Bd]080dM7A00@0WYjN07YjNP1jNWX0G5aL0P1mOGd0101aLG40QHF508F5
Q@2CTi<205mOG`0406a/K02a/K40/K6a08^;R`80YZJV00@0UIFE0:^[Z`2[Zj/0G5aL0P3;bl/0102D
U9@0TY:B09:BTP2VYZH208V9R@050;bl_027QhL0QhN707=cL`1VIVH00P1iNGT0101cLg<0R8R808R8
R02GUiL207MgM`040:FUY@2YZJT0ZJVY079bLP80PH6100@0O7al092@T02@T900X:2P0P2i^KT0102F
UYH0LG5a075aL@1RHV820>7Qh@0409>CT`1TI6@0I6AT08N7Q`80IfMW00@0Ogmo0=GEe@3EeMD0`<30
0P2e]KD0101mOGd0WYjN09jNWP21PH420;Ng]`05079bLP1mOGd0OGem09fMW@2WYjL00P1gMgL0100k
>c/0>SXj03Xj>P16ATH204i>CP040410@01jNWX0NWYj05eMG@80D51@00@0EeMG051@D01@D500Fe]K
0P1SHf<0101KFe/0D51@051@D01[Jf/20::RXP0408V9R@2MWId0WIfM0:FUY@80TY:B00@0V9RH0;bl
_02l_;`0RHV90P1mOGd0101/K6`0MgMg07MgM`1ADE4207moO`03075aLOoooooooooo00@0003o0P3o
P0090000o`040?n000000?l0003o0000o`D0oh0010000?l30?n000040000o`3oP000oh000000o`80
oh0010000?l20?n000@0003o0`3oP0050000o`030?n000000?l0003o00<0oh000P000?l20?n000T0
003o00<0oh000000o`000?l010000?l30?n000H0003o0P3oP00F0000o`030?n000000?l0003o00<0
003o00<0oh000000o`000?l01@000?l50?n000@0003o0P3oP0070000o`P0oh0000<0003o0?n0003o
P0001@3oP0020000o`<0oh002P000?l20?n000H0003o00@0oh000000o`000?l0003o2_ooool000Wo
oooo00@0IFEU08f=S@2=SHd0MWIf0P1:BTX01023Ph<0X:2P0:2PX02MWId20820P00407QhN01jNWX0
NWYj05IFEP80M7Ad00@0Lg=c05]KF`1KFe/0<c<c0P0k>c/0101XJ6P0Ogmo07moO`1dM7@203<c<`04
05YJFP1SHf<0Hf=S059BDP80MWIf00@0FUYJ096AT@2ATI40U9BD0P2[Zj/0102d];@0TI6A096AT@1d
M7@206a/K00504e=C@2j^[X0Rh^;08^;R`20P8000P24Q8@0101JFUX0Shn?08n?S`2d];@20=7Ad@04
09jNWP1jNWX0NWYj05aLG080OGem00@0LG5a08F5Q@25QHD0Ti>C0P1OGel0101/K6`0/K6a0;6a/@2;
Rh/20:JVYP0409FEU@2[Zj/0Zj^[05aLG080bl_;00@0U9BD09:BTP2BTY80YZJV0P29RHT01@2l_;`0
QhN708N7Q`1cLg<0IVIV0080NGUi00@0Lg=c08R8R028R8P0UiNG0P1gMgL0102UYJD0ZJVY0:VYZ@1b
LW820861P@0407alO02@T900T92@0:2PX080^KVi00@0UYJF075aL@1aLG40HV9R0P3QhN40102CTi<0
I6AT06ATI027QhL206MWI`0407moO`3EeMD0eMGE0<30`080]KFe00@0OGem09jNWP2NWYh0PH610P2g
]kL01@1bLW80OGem07emO@2MWId0YjNW0080MgMg00@0>c/k03Xj>P0j>SX0ATI60P1>CTh01010@400
NWYj07YjNP1MGEd2051@D00405MGE`1@D500D51@05]KF`80Hf=S00@0Fe]K051@D01@D500Jf][0P2R
XZ801029RHT0WIfM09fMW@2UYJD209:BTP0409RHV02l_;`0_;bl08V9R@80OGem00@0K6a/07MgM`1g
MgL0DE5A0P1oOgl00`1aLG7oooooooooo`040000o`80oh002@000?l0103oP000003o0000o`000?l5
0?n000@0003o0`3oP00010000?l0oh000?n000000?l20?n000@0003o0P3oP0040000o`<0oh001@00
0?l00`3oP000003o0000o`030?n00080003o0P3oP0090000o`030?n000000?l0003o00@0003o0`3o
P0060000o`80oh005P000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00D0003o1@3o
P0040000o`80oh001`000?l80?n000030000o`3oP000oh0000D0oh000P000?l30?n000X0003o0P3o
P0060000o`040?n000000?l0003o0000o`[ooooo0009ooooo`0406MWI`25QHD0QHF507AdM080ATI6
00@0SXj>0:6QX@2QXJ40Vi^K0P2?Shl0102FUYH0OGem07emO@1VIVH208F5Q@0407moO`1QHF40HF5Q
04E5A@80Cdm?00@0Jf][096AT@2ATI40Jf][0P0a<C40101OGel0JVYZ06YZJP1UIFD208Z:RP04065Q
H@2GUiL0UiNG09VIV@80YZJV00@0/;2`08^;R`2;Rh/0Jf][0P1/K6`01@1GEeL0`l?308R8R028R8P0
O7al0080S8b<00@0Cdm?092@T02@T900_;bl0P3Fe]H0102OWil0LW9b079bLP1QHF4208B4Q00407Yj
NP27QhL0QhN708Z:RP80Fe]K00@0JVYZ0::RXP2RXZ80Ph>30P2QXJ40102CTi<0VIVI09VIV@1WIfL2
0=oOg`040:>SX`2LW9`0W9bL0;>c/`80Vi^K00D0c/k>08j>SP2>SXh0Q8B407]kN`0208J6QP0407Ui
N@2SXj<0Xj>S08N7Q`80GUiN00@0Xj>S0;Bd]02d];@0OGem0P1nOWh0101gMgL0RHV908V9R@2PX:02
0:b/[0040820P01^KVh0KVi^069RHP80g=cL00@0V9RH06m_K`1_Kfl0Ng]k0P1ZJVX0101gMgL0aLG5
0<G5a@2k^k/20;Vi^@040861P@2OWil0WinO07moO`80ZJVY00D0Ogmo08>3P`23Ph<0XZ:R0;6a/@02
07inOP0404A4A010@400@410061PH080JVYZ00@0FUYJ08Z:RP2:RXX0M7Ad0P1SHf<0101TI6@0FUYJ
05YJFP1RHV8205iNGP0404M7A`11@D40@D510820P080Vi^K00@0XZ:R08n?S`2?Shl0Xj>S0P1nOWh0
1024Q8@0/K6a0;6a/@20P80209JFUP0406UYJ@1gMgL0MgMg05aLG080NWYj00<0Ng]kooooooooool0
10000?l20?n000l0003o0`3oP0040000o`80oh002`000?l20?n000@0003o0`3oP0050000o`030?n0
00000?l0003o00<0oh002P000?l00`3oP000003o0000o`090000o`040?n000000?l0003o0000o`80
oh0000<0003o0?n0003oP0002P000?l0103oP000003o0000o`3oP00>0000o`030?n000000?l0003o
00D0003o1@3oP00:0000o`80oh0000@0003o0?n0003oP000oh000`000?l20?n000D0003o0P3oP000
0`000?l0oh000?n000030?n000X0003o0P3oP0060000o`040?n000000?l0003o0000o`[ooooo0009
ooooo`0406QXJ02=SHd0SHf=07inOP80CDe=00@0U9BD09VIV@2IVIT0UYJF0P2:RXX0102DU9@0P820
0820P01gMgL208F5Q@0408:2PP1RHV80HV9R05=CD`80GemO00@0KVi^09>CT`2CTi<0MgMg0P0e=CD0
101IFET0KVi^06i^KP1UIFD207EeM@0405aLG02=SHd0SHf=09FEU@80YZJV00@0/K6a09JFUP2FUYH0
M7Ad0P1`L7001@1MGEd0b/[:08V9R@29RHT0QXJ60080Shn?00@0BDU909VIV@2IVIT0`l?30P3Cdm<0
102QXJ40KFe]06e]K@1VIVH208f=S@0408F5Q@26QXH0QXJ608R8R080EEEE00@0J6QX09^KV`2KVi/0
S8b<0P2?Shl01024Q8@0X:2P0:2PX01^KVh20=WIf@040;:b/P2GUiL0UiNG0;jn_P80UYJF00D0_[jn
07MgM`1gMgL0M7Ad075aL@020861P@0406e]K@2PX:00X:2P07moO`80Fe]K00@0Y:BT0:f][@2][Jd0
NGUi0P27QhL0101eMGD0Ogmo07moO`2UYJD20:f][@0407alO01cLg<0Lg=c05EEE@80h>3P00@0S8b<
06a/K01/K6`0M7Ad0P1YJFT01026QXH0`l?30<?3``2j^[X20;Ng]`0406m_K`2YZJT0ZJVY0820P080
VYZJ00D0QHF507]kN`1kNg/0V9RH0;Vi^@0207IfMP040410@00l?3`0?3`l05MGE`80KVi^00@0GemO
06i^KP1^KVh0KFe]0P1XJ6P0101NGUh0EeMG05MGE`1[Jf/2069RHP0405UIF@16ATH0ATI606=SH`80
TI6A00@0WYjN09JFUP2FUYH0][Jf0P1gMgL0102?Shl0[:b/0:b/[020P80208:2PP0405eMG@1dM7@0
M7Ad079bLP80R8R800<0MGEeooooooooool010000?l20?n000l0003o00<0oh000000o`000?l01000
0?l30?n000@0003o0P3oP0040000o`80oh0010000?l30?n000D0003o00<0oh000000o`000?l00`3o
P00:0000o`030?n000000?l0003o00T0003o0`3oP00010000?l0oh000?n000000?l20?n000X0003o
00@0oh000000o`000?l0oh0020000?l0103oP000003o0000o`000?l30?n000L0003o1@3oP00:0000
o`80oh0000<0003o0?n0003oP0000`3oP0070000o`<0oh000`000?l30?n000H0003o00<0oh000000
o`000?l01P000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0406QXJ02=SHd0SHf=07in
OP80CDe=00@0U9BD09VIV@2IVIT0UYJF0P2:RXX0102DU9@0P8200820P01gMgL208F5Q@0408:2PP1R
HV80HV9R05=CD`80GemO00@0KVi^09>CT`2CTi<0MgMg0P0e=CD0101IFET0KVi^06i^KP1UIFD207Ee
M@0405aLG02=SHd0SHf=09FEU@80YZJV00@0/K6a09JFUP2FUYH0M7Ad0P1`L7001@1MGEd0b/[:08V9
R@29RHT0QXJ60080Shn?00@0BDU909VIV@2IVIT0`l?30P3Cdm<0102QXJ40KFe]06e]K@1VIVH208f=
S@0408F5Q@26QXH0QXJ608R8R080EEEE00@0J6QX09^KV`2KVi/0S8b<0P2?Shl01024Q8@0X:2P0:2P
X01^KVh20=WIf@040;:b/P2GUiL0UiNG0;jn_P80UYJF00D0_[jn07MgM`1gMgL0M7Ad075aL@020861
P@0406e]K@2PX:00X:2P07moO`80Fe]K00@0Y:BT0:f][@2][Jd0NGUi0P27QhL0101eMGD0Ogmo07mo
O`2UYJD20:f][@0407alO01cLg<0Lg=c05EEE@80h>3P00@0S8b<06a/K01/K6`0M7Ad0P1YJFT01026
QXH0`l?30<?3``2j^[X20;Ng]`0406m_K`2YZJT0ZJVY0820P080VYZJ00D0QHF507]kN`1kNg/0V9RH
0;Vi^@0207IfMP040410@00l?3`0?3`l05MGE`80KVi^00@0GemO06i^KP1^KVh0KFe]0P1XJ6P0101N
GUh0EeMG05MGE`1[Jf/2069RHP0405UIF@16ATH0ATI606=SH`80TI6A00@0WYjN09JFUP2FUYH0][Jf
0P1gMgL0102?Shl0[:b/0:b/[020P80208:2PP0405eMG@1dM7@0M7Ad079bLP80R8R800<0MGEeoooo
ooooool010000?l20?n000l0003o00<0oh000000o`000?l010000?l30?n000@0003o0P3oP0040000
o`80oh0010000?l30?n000D0003o00<0oh000000o`000?l00`3oP00:0000o`030?n000000?l0003o
00T0003o0`3oP00010000?l0oh000?n000000?l20?n000X0003o00@0oh000000o`000?l0oh002000
0?l0103oP000003o0000o`000?l30?n000L0003o1@3oP00:0000o`80oh0000<0003o0?n0003oP000
0`3oP0070000o`<0oh000`000?l30?n000H0003o00<0oh000000o`000?l01P000?l00`3oP000003o
0000o`040000o`[ooooo0009ooooo`0407YjNP2=SHd0SHf=08B4Q080DU9B0`2LW9`0102>SXh0S8b<
08b<S02?Shl2071`L00406e]K@1XJ6P0J6QX06YZJP80GEeM00@0CTi>05aLG01LG5`0JVYZ0P2@T900
101]KFd0<S8b038b<P1DE5@205UIF@0405ADE01fMWH0MWIf05IFEP80UYJF00@0UIFE0:FUY@2UYJD0
YZJV0P2CTi<01@1`L700MGEe07EeM@1LG5`0a/K60080W9bL00@0OGem07IfMP1fMWH0ATI60P2DU9@0
102e]KD0e=CD0=CDe02CTi<207AdM00406QXJ02OWil0WinO09:BTP80O7al00@0W9bL06IVIP1VIVH0
Kfm_0P2a/K40102][Jd0/;2`0;2`/02RXZ820:n_[`0407IfMP3Hf=P0f=SH0:ZZZP80X:2P00@0`<30
0:^[Z`2[Zj/0alO70P1iNGT01@1fMWH0Lg=c06m_K`1_Kfl0CTi>0080O7al00@0LW9b06EUI@1UIFD0
YZJV0P2f][H0102@T900QXJ608J6QP1dM7@208J6QP040:NWY`2m_Kd0_Kfm06m_K`80P82000@0F5QH
0=kNgP3Ng]h0VIVI0P1gMgL01022PX80KVi^06i^KP2?Shl20<g=c@040<?3``2c/k<0/k>c06e]K@80
XJ6Q00@0RHV909ZJVP2JVYX0N7Qh0P1mOGd01@27QhL0_;bl06MWI`1WIfL0>3Ph0080;Rh^00@0ADE5
05aLG01LG5`0H61P0P1KFe/0101ZJVX0FUYJ05YJFP1IFET205QHF00405mOG`1^KVh0KVi^079bLP80
EUIF00@0NGUi09RHV02HV9P0YJFU0P2=SHd0102o_kl0Kfm_06m_K`27QhL20:ZZZP0407inOP1_Kfl0
Kfm_05ADE080C4a<00@0FUYJ05aLG01LG5`0Fe]K0_ooool40000o`80oh003@000?l50?n000@0003o
1P3oP0000`000?l0oh000?n0000:0000o`<0oh001@000?l00`3oP000003o0000o`030?n000d0003o
103oP0020000o`040?n000000?l0003o0?n000<0003o0P3oP0000`000?l0oh000?n000050000o`80
oh001P000?l00`3oP000003o0000o`060000o`040?n000000?l0003o0000o`<0oh001`000?l50?n0
00X0003o0P3oP0000`000?l0oh000?n000040?n00080003o00<0oh000000o`000?l0103oP0040000
o`80oh001P000?l00`3oP000003o0000o`060000o`L0oh002_ooool000Wooooo00@0LG5a08R8R028
R8P0O7al0P1BDU80102>SXh0Vi^K09^KV`1dM7@208:2PP0408j>SP1/K6`0K6a/071`L080NGUi00@0
Fe]K05UIF@1IFET0BTY:0P1EEED0101fMWH0V9RH09RHV025QHD203`l?00406IVIP1IFET0FEUI05=C
D`80Ng]k00@0F5QH09jNWP2NWYh0WIfM0P2/[:`0102[Zj/0UiNG09NGU`1^KVh2079bLP0505]KF`3?
cll0ZJVY0:VYZ@2;Rh/00P1kNg/0101PH600N7Qh07QhN02=SHd20<?3``0409ZJVP1gMgL0MgMg05iN
GP80SHf=00@0UIFE07MgM`1gMgL0WinO0P1NGUh0101VIVH0bl_;0<_;b`2j^[X20:^[Z`0409bLW02a
/K40/K6a07emO@80h>3P00@0/K6a0:ZZZP2ZZZX0[:b/0P2[Zj/01@2o_kl0O7al07alO025QHD0KVi^
0080Ng]k00@0Cdm?09RHV02HV9P0N7Qh0P1bLW80102g]kL0`l?30<?3``2TY:@209JFUP0407inOP2;
Rh/0Rh^;0:VYZ@80^[Zj00@0H61P07emO@1mOGd0G5aL0P3MgMd0102IVIT0Kfm_06m_K`1eMGD206EU
I@0407=cL`2i^KT0^KVi0;>c/`80[jn_00@0OWin08>3P`23Ph<0P8200P2FUYH01@23Ph<0S8b<08b<
S027QhL0`L710080FEUI00@0=cLg02/[:`0[:b/0AdM70P1KFe/0101IFET0DE5A055AD@1>CTh205AD
E00405EEE@1:BTX0BTY:07IfMP80JFUY00@0P82006ATI01TI6@0JFUY0P2@T900102^[Zh0Vi^K09^K
V`3Fe]H205mOG`0408b<S02UYJD0YJFU09BDU080K6a/00@0AdM7055AD@1ADE40Kfm_0P1OGel00`1D
E5Coooooooooo`040000o`80oh0030000?l60?n000@0003o0P3oP0001@000?l0oh000?n0003oP000
003o0080oh002P000?l30?n000T0003o0P3oP0020000o`80oh001P000?l00`3oP000003o0000o`03
0?n000<0003o00<0oh000000o`000?l00`3oP0040000o`80oh001@000?l20?n000@0003o0`3oP008
0000o`040?n000000?l0003o0000o`<0oh001`000?l50?n000X0003o4P3oP0090000o`040?n00000
0?l0003o0?n000P0003o0`3oP0030000o`030?n00?oooooooooo00Sooooo0009ooooo`04075aL@28
R8P0R8R807alO080DU9B00@0SXj>09^KV`2KVi/0M7Ad0P22PX80102>SXh0K6a/06a/K01`L70207Ui
N@0405]KF`1IFET0FEUI04Y:BP80EEEE00@0MWIf09RHV02HV9P0QHF50P0l?3`0101VIVH0FEUI05UI
F@1CDe<207]kN`0405QHF02NWYh0WYjN09fMW@80[:b/00@0Zj^[09NGU`2GUiL0KVi^0P1bLW801@1K
Fe/0clo?0:VYZ@2YZJT0Rh^;0080Ng]k00@0H61P07QhN01hN7P0SHf=0P33`l<0102JVYX0MgMg07Mg
M`1NGUh208f=S@0409FEU@1gMgL0MgMg09nOW`80GUiN00@0IVIV0<_;b`3;bl/0^[Zj0P2[Zj/0102L
W9`0/K6a0;6a/@1mOGd20>3Ph0040;6a/@2ZZZX0ZZZZ0:b/[080Zj^[00D0_kno07alO01lO7`0QHF5
06i^KP0207]kN`0404m?C`2HV9P0V9RH07QhN080LW9b00@0]kNg0<?3``33`l<0Y:BT0P2FUYH0101n
OWh0Rh^;08^;R`2YZJT20;Zj^P04061PH01mOGd0OGem05aLG080gMgM00@0VIVI06m_K`1_Kfl0MGEe
0P1UIFD0101cLg<0^KVi0;Vi^@2c/k<20:n_[`0407inOP23Ph<0Ph>30820P080UYJF00D0Ph>308b<
S02<S8`0QhN70<71`@0205UIF@0403Lg=`0[:b/0:b/[04M7A`80Fe]K00@0FEUI055AD@1ADE40CTi>
0P1DE5@0101EEED0BTY:04Y:BP1fMWH206UYJ@040820P01TI6@0I6AT06UYJ@80T92@00@0[Zj^09^K
V`2KVi/0e]KF0P1OGel0102<S8`0YJFU0:FUY@2DU9@206a/K00404M7A`1ADE40DE5A06m_K`80GemO
00<0E5ADooooooooool010000?l20?n000`0003o1P3oP0040000o`80oh0000D0003o0?n0003oP000
oh000000o`020?n000X0003o0`3oP0090000o`80oh000P000?l20?n000H0003o00<0oh000000o`00
0?l00`3oP0030000o`030?n000000?l0003o00<0oh0010000?l20?n000D0003o0P3oP0040000o`<0
oh0020000?l0103oP000003o0000o`000?l30?n000L0003o1@3oP00:0000oa80oh002@000?l0103o
P000003o0000o`3oP0080000o`<0oh000`000?l00`3oP03oooooooooo`08ooooo`002Oooool0101m
OGd0Vi^K09^KV`2=SHd204m?C`0409:BTP2NWYh0WYjN0820P080RXZ:00@0WinO07UiN@1iNGT0Ng]k
0P1nOWh0101LG5`0GEeM05eMG@0i>CT205UIF@0408>3P`2BTY80TY:B06YZJP80<C4a00@0ADE503/k
>`0k>c/0EUIF0P1]KFd0101=CDd0VIVI09VIV@2?Shl20;:b/P040:>SX`2?Shl0Shn?05UIF@80Fe]K
00D0EUIF0<W9b@2FUYH0UYJF08F5Q@0207=cL`0406m_K`27QhL0QhN70:ZZZP80dm?C00@0T92@08n?
S`2?Shl0L71`0P2LW9`0102QXJ40QHF508F5Q@2RXZ8206=SH`0405eMG@2f][H0][Jf0:NWY`80V9RH
00@0Rh^;09^KV`2KVi/0Ng]k0P3@d=00102a/K40U9BD09BDU02FUYH209BDU0050:n_[`24Q8@0Q8B4
07QhN01eMGD00P1lO7`0101ADE40W9bL09bLW01eMGD208B4Q0040;Jf]P31`L40`L7108f=S@80VYZJ
00@0Jf][07moO`1oOgl0V9RH0P3Fe]H0101TI6@0PX:208:2PP1SHf<20>7Qh@0409>CT`1YJFT0JFUY
07]kN`<0Jf][0P2`/;00102m_Kd0ZJVY0:VYZ@1NGUh208b<S004096AT@2JVYX0VYZJ07alO080Rh^;
00D0QHF50;no_`1=CDd0CDe=03Xj>P0202XZ:P0404Q8B01MGEd0GEeM06i^KP80CTi>00@0FUYJ051@
D01@D500DU9B0P1JFUX0101bLW80K6a/06a/K02BTY8205ADE00406UYJ@2ATI40TI6A0:6QX@80LW9b
00@0`L7105IFEP1FEUH0WinO0P2QXJ40102>SXh0OWin07inOP1JFUX2061PH00408F5Q@1dM7@0M7Ad
06QXJ0;ooooo10000?l20?n000`0003o1P3oP0040000o`H0oh0000<0003o0?n0003oP0000`000?l0
103oP000003o0000o`000?l60?n000T0003o0P3oP00;0000o`<0oh0020000?l30?n000@0003o0P3o
P0050000o`80oh0010000?l30?n000P0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000
o`050000o`<0oh000P000?l00`3oP000003o0000o`070000o`T0oh000P000?l70?n000@0003o0P3o
P0060000o`<0oh001P000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0406e]K@27QhL0
QhN707moO`80AdM700@0QhN709VIV@2IVIT0Ng]k0P28R8P0102CTi<0LG5a075aL@1UIFD207=cL`04
05EEE@1QHF40HF5Q06IVIP80GUiN00@0IVIV07UiN@1iNGT0E5AD0P0Q8B401014A4@0EEEE05EEE@1E
EED206][J`04061PH02>SXh0SXj>08R8R080ZZZZ00@0YZJV09^KV`2KVi/0JVYZ0P1RHV801@1JFUX0
^[Zj09NGU`2GUiL0OGem0080QHF500@0F5QH07inOP1nOWh0ZJVY0P3Cdm<01023Ph<0T92@092@T01e
MGD20:BTY0040::RXP2:RXX0RXZ:08f=S@80H61P00@0DU9B0:RXZ02XZ:P0YZJV0P2KVi/0102@T900
XJ6Q0:6QX@29RHT20=OGe`040<_;b`2HV9P0V9RH09VIV@80V9RH00D0/[:b08b<S02<S8`0R8R806EU
I@0207AdM004059BDP1kNg/0Ng]k06YZJP80Shn?00@0Y:BT0<k>cP3>c/h0Ph>30P20P800101SHf<0
PX:208:2PP2DU9@20<o?c`0405=CD`1kNg/0Ng]k06IVIP80g=cL00@0Shn?06][J`1[Jf/0LG5a0P1L
G5`0101/K6`0]KFe0;Fe]@2k^k/20;Bd]00406QXJ02JVYX0VYZJ09jNWP80V9RH00D0PH6108j>SP2>
SXh0Shn?0<[:bP0205ADE0040451@@0Z:RX0:RXZ04a<C080MGEe00@0I6AT05]KF`1KFe/0JFUY0P1V
IVH0101JFUX0C4a<04a<C01kNg/205QHF00407MgM`18B4P0B4Q8059BDP80MgMg00@0QXJ608f=S@2=
SHd0bl_;0P1PH600102KVi/0VIVI09VIV@2MWId205iNGP0405MGE`1TI6@0I6AT08B4Q080JVYZ00<0
Fe]Kooooooooool010000?l20?n000`0003o00@0oh000000o`000?l0003o0P3oP0030000o`L0oh00
3@000?l30?n000D0003o00@0oh000000o`000?l0003o0P3oP00;0000o`80oh002@000?l30?n000@0
003o0P3oP0050000o`80oh001P000?l00`3oP000003o0000o`060000o`<0oh000`000?l00`3oP000
003o0000o`030000o`030?n000000?l0oh0000@0oh002P000?l80?n000<0003o00@0oh000000o`00
0?l0003o0`3oP00010000?l0oh000?n000000?l30?n000D0003o00<0oh000000o`000?l010000?l3
0?n000D0003o00<0oh00ooooooooool02?ooool000Wooooo00@0KFe]08N7Q`27QhL0Ogmo0P17AdL0
1027QhL0VIVI09VIV@1kNg/208R8R00409>CT`1aLG40LG5a06EUI@80Lg=c00@0EEEE065QH@1QHF40
IVIV0P1NGUh0101VIVH0NGUi07UiN@1DE5@2024Q8@0404A4A01EEED0EEEE05EEE@80Jf][00@0H61P
08j>SP2>SXh0R8R80P2ZZZX0102VYZH0Vi^K09^KV`1ZJVX2069RHP0505YJFP2j^[X0UiNG09NGU`1m
OGd00P25QHD0101HF5P0OWin07inOP2YZJT20=?Cd`0408>3P`2@T900T92@07EeM@80Y:BT00@0XZ:R
08Z:RP2:RXX0SHf=0P1PH600101BDU80Z:RX0:RXZ02VYZH209^KV`04092@T02QXJ40XJ6Q08V9R@80
emOG00@0bl_;09RHV02HV9P0VIVI0P2HV9P01@2b/[80S8b<08b<S028R8P0IFEU0080M7Ad00@0DU9B
07]kN`1kNg/0JVYZ0P2?Shl0102TY:@0c/k>0<k>cP23Ph<20820P00406=SH`22PX80PX:209BDU080
clo?00@0De=C07]kN`1kNg/0IVIV0P3Lg=`0102?Shl0Jf][06][J`1aLG4205aLG00406a/K02e]KD0
]KFe0;^k^`80];Bd00@0J6QX09ZJVP2JVYX0WYjN0P2HV9P01@21PH40SXj>08j>SP2?Shl0b/[:0080
E5AD00@0@D5102XZ:P0Z:RX0C4a<0P1eMGD0101TI6@0Fe]K05]KF`1YJFT206IVIP0405YJFP1<C4`0
C4a<07]kN`80F5QH00@0MgMg04Q8B018B4P0DU9B0P1gMgL01026QXH0SHf=08f=S@3;bl/2061PH004
09^KV`2IVIT0VIVI09fMW@80GUiN00@0EeMG06ATI01TI6@0Q8B40P1ZJVX00`1KFe_oooooooooo`04
0000o`80oh0030000?l0103oP000003o0000o`000?l20?n000<0003o1`3oP00=0000o`<0oh001@00
0?l0103oP000003o0000o`000?l20?n000/0003o0P3oP0090000o`<0oh0010000?l20?n000D0003o
0P3oP0060000o`030?n000000?l0003o00H0003o0`3oP0030000o`030?n000000?l0003o00<0003o
00<0oh000000o`3oP000103oP00:0000o`P0oh000`000?l0103oP000003o0000o`000?l30?n00004
0000o`3oP000oh000000o`<0oh001@000?l00`3oP000003o0000o`040000o`<0oh001@000?l00`3o
P03oooooooooo`08ooooo`002Oooool0101oOgl0TI6A096AT@20P80204];B`0408Z:RP2IVIT0VIVI
07emO@80Ng]k00@0RHV9065QH@1QHF40J6QX0P1gMgL0101JFUX0H61P061PH01KFe/206MWI`04071`
L01dM7@0M7Ad065QH@80<S8b00@0E5AD05]KF`1KFe/0EeMG0P1lO7`01014A4@0S8b<08b<S028R8P2
0:^[Z`040:RXZ02KVi/0Vi^K06QXJ080IFEU00D0GemO0<30`02JVYX0VYZJ08Z:RP0206e]K@0404=3
@`2<S8`0S8b<0:VYZ@80c<c<00@0RXZ:09JFUP2FUYH0Kfm_0P2VYZH0102RXZ80Rh^;08^;R`2;Rh/2
06e]K@0406YZJP2WYjL0YjNW0:^[Z`80VYZJ00@0TY:B0:RXZ02XZ:P0UiNG0P39bLT0103:b/X0SXj>
08j>SP2CTi<209JFUP050:b/[02EUID0UIFE08b<S01^KVh00P1dM7@0101FEUH0VIVI09VIV@1hN7P2
08n?S`040:>SX`34a<@0a<C407EeM@80P82000@0FEUI07]kN`1kNg/0WIfM0P3Lg=`0101HF5P0Ogmo
07moO`1`L7020>;RhP0409VIV@1aLG40LG5a07YjNP80Fe]K00@0IfMW0:FUY@2UYJD0ZJVY0P2^[Zh0
101UIFD0SXj>08j>SP2BTY8209FEU@0508j>SP2HV9P0V9RH09VIV@3<c<`00P1GEeL01013@d<0;2`/
02`/;00k>c/206EUI@<0EeMG00<0LG5a06IVIP1VIVH00`1IFET0101YJFT0H61P061PH028R8P202h^
;P0405eMG@25QHD0QHF508f=S@80KVi^00@0YZJV06UYJ@1YJFT0SXj>0P2PX:00102QXJ40Fe]K05]K
F`1MGEd206e]K@0407alO01DE5@0E5AD069RHP;ooooo10000?l20?n000`0003o00@0oh000000o`00
0?l0oh001P000?l60?n000030000o`3oP000oh0000`0003o00<0oh000000o`000?l00`000?l0103o
P000003o0000o`000?l20?n001H0003o0`3oP00;0000o`80oh001P000?l0103oP000003o0000o`00
0?l20?n000<0003o0`3oP0030000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l00P00
0?l20?n000X0003o203oP00010000?l0oh000?n0003oP0030000o`<0oh0010000?l30?n000`0003o
0`3oP0030000o`80oh0000<0003oooooooooool02?ooool000Wooooo00@0Lg=c09BDU02DU9@0QXJ6
0P1<C4`0102ATI40Xj>S0:>SX`26QXH208>3P`0409BDU01bLW80LW9b06ATI080L71`00@0GUiN05aL
G01LG5`0HF5Q0P1SHf<01024Q8@0VYZJ09ZJVP1oOgl203`l?00406i^KP1`L700L71`05aLG080RHV9
00@0Bd];0:2PX02PX:00U9BD0P2[Zj/0102XZ:P0WYjN09jNWP1NGUh206ATI005069RHP2k^k/0UiNG
09NGU`27QhL00P1WIfL01013@d<0O7al07alO02[Zj/20<[:bP04092@T02FUYH0UYJF06a/K080XJ6Q
00@0/;2`08B4Q024Q8@0Q8B40P1UIFD0101[Jf/0[jn_0:n_[`2l_;`20:>SX`040:BTY02ZZZX0ZZZZ
09JFUP80alO700@0fMWI09NGU`2GUiL0Shn?0P2VYZH01@2XZ:P0YjNW0:NWY`2?Shl0Lg=c0080MWIf
00@0GUiN09^KV`2KVi/0O7al0P2GUiL0102?Shl0/K6a0;6a/@1_Kfl208N7Q`0405iNGP1_Kfl0Kfm_
096AT@80d];B00@0CTi>06MWI`1WIfL0Fe]K0P2f][H0101mOGd0IFEU06EUI@1dM7@2061PH00407If
MP37alL0alO70<o?c`80_;bl00@0LG5a08J6QP26QXH0R8R80P2ATI401@22PX80O7al07alO025QHD0
`L710080E5AD00@0@41002LW9`0W9bL0>SXj0P1JFUX0101CDe<0EeMG05MGE`1cLg<206=SH`0406UY
J@1LG5`0G5aL05mOG`80DE5A00@0Ph>303Xj>P0j>SX0>SXj0P1RHV80101nOWh0PH610861P@2f][H2
07emO@0408>3P`2HV9P0V9RH0:^[Z`80Cdm?00@0G5aL06YZJP1ZJVX0Jf][0P1CDe<00`1SHf?ooooo
ooooo`040000o`80oh0030000?l30?n000L0003o0P3oP0020000o`80oh0000<0003o0?n0003oP000
1`000?l20?n000<0003o00<0oh000000o`000?l00`000?l0103oP000003o0000o`000?l20?n000D0
003o0P3oP0060000o`<0oh001P000?l30?n000/0003o0P3oP0060000o`040?n000000?l0003o0000
o`80oh000`000?l30?n000040000o`3oP000oh000?n000L0003o1@3oP00:0000o``0oh0010000?l2
0?n000040000o`3oP000oh000000o`<0oh001@000?l00`3oP000003o0000o`040000o`<0oh000`00
0?l20?n000030000oooooooooooo00Sooooo0009ooooo`0407=cL`2DU9@0U9BD08J6QP80C4a<00@0
TI6A0:>SX`2SXj<0QXJ60P23Ph<0102DU9@0LW9b079bLP1TI6@2071`L00405iNGP1LG5`0G5aL065Q
H@80Hf=S00@0Q8B409ZJVP2JVYX0Ogmo0P0l?3`0101^KVh0L71`071`L01LG5`208V9R@0404];B`2P
X:00X:2P09BDU080Zj^[00@0Z:RX09jNWP2NWYh0GUiN0P1TI6@01@1RHV80^k^k09NGU`2GUiL0QhN7
0080IfMW00@0@d=307alO01lO7`0Zj^[0P3:b/X0102@T900UYJF09JFUP1/K6`20:6QX@040;2`/024
Q8@0Q8B408B4Q080IFEU00@0Jf][0:n_[`2_[jl0_;bl0P2SXj<0102TY:@0ZZZZ0:ZZZP2FUYH20<O7
a`040=WIf@2GUiL0UiNG08n?S`80YZJV00D0Z:RX0:NWY`2WYjL0Shn?07=cL`0207IfMP0405iNGP2K
Vi/0Vi^K07alO080UiNG00@0Shn?0;6a/@2a/K40Kfm_0P27QhL0101NGUh0Kfm_06m_K`2ATI420=;B
dP0404i>CP1WIfL0IfMW05]KF`80][Jf00@0OGem06EUI@1UIFD0M7Ad0P1PH600101fMWH0alO70<O7
a`3?cll20;bl_004075aL@26QXH0QXJ608R8R080TI6A00D0PX:207alO01lO7`0QHF50<71`@0205AD
E0040410@00W9bL09bLW03Xj>P80FUYJ00@0De=C05MGE`1GEeL0Lg=c0P1SHf<0101YJFT0G5aL05aL
G01OGel2055AD@0408>3P`0j>SX0>SXj03Xj>P80HV9R00@0OWin0861P@21PH40][Jf0P1mOGd01023
Ph<0V9RH09RHV02[Zj/204m?C`0405aLG01ZJVX0JVYZ06][J`80De=C00<0Hf=Sooooooooool01000
0?l20?n000`0003o0`3oP0070000o`80oh000P000?l20?n000030000o`3oP000oh0000L0003o0P3o
P0030000o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0003o0P3oP0050000o`80oh00
1P000?l30?n000H0003o0`3oP00;0000o`80oh001P000?l0103oP000003o0000o`000?l20?n000<0
003o0`3oP00010000?l0oh000?n0003oP0070000o`D0oh002P000?l<0?n000@0003o0P3oP0001000
0?l0oh000?n000000?l30?n000D0003o00<0oh000000o`000?l010000?l30?n000<0003o0P3oP000
0`000?ooooooooooo`08ooooo`002Oooool0101SHf<0R8R808R8R01gMgL204m?C`0409:BTP2KVi/0
Vi^K08B4Q080RHV900@0SHf=06ATI01TI6@0J6QX0P1^KVh0101FEUH0DE5A055AD@1RHV82061PH004
07YjNP2=SHd0SHf=075aL@80>SXj00@0IfMW065QH@1QHF40De=C0P1oOgl0101LG5`0PX:208:2PP2E
UID20;Bd]0040:VYZ@2MWId0WIfM06EUI@80JFUY00D0KVi^0<K6aP2e]KD0]KFe09RHV00207=cL`04
05]KF`1mOGd0OGem092@T080`/;200@0Y:BT08j>SP2>SXh0Jf][0P2FUYH0102OWil0Ng]k07]kN`1]
KFd206QXJ00406ATI02YZJT0ZJVY0;jn_P80YJFU00@0XZ:R0:n_[`2_[jl0U9BD0P36a/H0103@d=00
SXj>08j>SP2?Shl20:j^[P050:6QX@2UYJD0YJFU08:2PP1[Jf/00P1^KVh0101HF5P0VIVI09VIV@1b
LW8209:BTP0408V9R@39bLT0bLW906YZJP80O7al00@0EEEE075aL@1aLG40_;bl0P2j^[X0101HF5P0
MWIf07IfMP1_Kfl20>;RhP0409FEU@1ZJVX0JVYZ06][J`80GemO00@0KVi^0;Bd]02d];@0c<c<0P2^
[Zh0101TI6@0VIVI09VIV@2LW9`208b<S00508F5Q@1kNg/0Ng]k07AdM02YZJT00P1:BTX0100l?3`0
9RHV02HV9P0e=CD204U9B@0404a<C018B4P0B4Q8075aL@80J6QX00@0HF5Q05mOG`1OGel0Jf][0P1V
IVH0101eMGD0@D510451@@1[Jf/20:ZZZP0409bLW02XZ:P0Z:RX0<G5a@80WIfM00@0V9RH0:ZZZP2Z
ZZX0`<300P1nOWh307]kN`0406m_K`1WIfL0IfMW07inOP;ooooo10000?l20?n000`0003o0`3oP007
0000o`80oh000P000?l20?n000030000o`3oP000oh0000<0003o00<0oh000000o`000?l01P000?l3
0?n000<0003o00@0oh000000o`000?l0003o0P3oP00>0000o`80oh000`000?l00`3oP000003o0000
o`030?n000<0003o00<0oh000000o`000?l01@000?l20?n000H0003o00@0oh000000o`000?l0003o
0P3oP0000`000?l0oh000?n000030?n000<0003o00<0oh000000o`000?l01@000?l50?n000`0003o
2P3oP00:0000o`80oh001P000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00L0003o
2_ooool000Wooooo00@0GUiN08V9R@29RHT0NWYj0P1ADE40102?Shl0XZ:R0::RXP2=SHd208V9R@04
08f=S@1`L700L71`06UYJ@80M7Ad00@0Ng]k04e=C@1=CDd0CTi>0P1FEUH3071`L00406UYJ@11@D40
@D51069RHP80Hf=S00@0I6AT08Z:RP2:RXX0WIfM0P2SXj<0102BTY80];Bd0;Bd]02OWil209FEU@05
07AdM01PH600H61P06MWI`31`L400P2[Zj/01029RHT0GEeM05eMG@1PH60207IfMP0409VIV@2c/k<0
/k>c09:BTP80Rh^;00@0L71`09BDU02DU9@0TI6A0P1aLG40101CDe<0LW9b079bLP1dM7@209nOW`04
0:n_[`2CTi<0Ti>C09FEU@80/;2`00@0UiNG0;no_`2o_kl0`L710P23Ph<0102:RXX0ZJVY0:VYZ@2H
V9P20:n_[`0507emO@26QXH0Ng]k07]kN`1PH6000P2LW9`0101aLG40UYJF09JFUP26QXH20<_;b`04
08J6QP1nOWh0OWin05EEE@80NGUi00@0V9RH0=gMg@3MgMd0K6a/0P1^KVh0101YJFT0hn?S0>?Sh`2C
Ti<2079bLP0407=cL`1SHf<0Hf=S07]kN`80a/K600@0cLg=0:n_[`2_[jl0M7Ad0P1kNg/0102BTY80
S8b<08b<S02BTY820861P@0508J6QP2m_Kd0GUiN05iNGP0k>c/00P0c<c<0100];Bd0CTi>04i>CP1O
Gel205UIF@0407=cL`2<S8`0S8b<0861P@80L71`00@0JFUY05aLG01LG5`0J6QX0P0g=cL0101<C4`0
XJ6Q0:6QX@28R8P208B4Q0040;Vi^@2NWYh0WYjN06EUI@80RXZ:00@0TY:B06YZJP1ZJVX0P8200P2W
YjL0101ZJVX0Hf=S06=SH`1hN7P2ooooo`040?n000000?l0003o0000o`80oh003@000?l50?n000@0
003o0P3oP00:0000o`030?n000000?l0003o00H0003o00@0oh000000o`000?l0003o0P3oP0040000
o`80oh0020000?l20?n000@0003o0P3oP0030000o`030?n000000?l0003o00<0oh001P000?l00`3o
P000003o0000o`0:0000o`040?n000000?l0003o0000o`80oh000`000?l00`3oP000003o0000o`03
0000o`030?n000000?l0003o00D0003o1@3oP00:0000o`T0oh000P000?l00`3oP000003o0000o`05
0000o`80oh0000@0003o0?n0003oP000oh001@000?l00`3oP000003o0000o`0=0000o`[ooooo0009
ooooo`0405iNGP29RHT0RHV907YjNP80DE5A00@0Shn?0::RXP2RXZ80SHf=0P29RHT0102=SHd0L71`
071`L01YJFT207AdM00407]kN`1=CDd0CDe=04i>CP80EUIF0`1`L700101YJFT0@D510451@@1RHV82
06=SH`0406ATI02:RXX0RXZ:09fMW@80Xj>S00@0TY:B0;Bd]02d];@0WinO0P2EUID01@1dM7@0H61P
061PH01WIfL0`L710080Zj^[00@0RHV905eMG@1MGEd0H61P0P1fMWH0102IVIT0/k>c0;>c/`2BTY82
08^;R`04071`L02DU9@0U9BD096AT@80LG5a00@0De=C079bLP1bLW80M7Ad0P2OWil0102_[jl0Ti>C
09>CT`2EUID20;2`/00409NGU`2o_kl0_kno0<71`@80Ph>300@0RXZ:0:VYZ@2YZJT0V9RH0P2_[jl0
1@1mOGd0QXJ607]kN`1kNg/0H61P0080W9bL00@0LG5a09JFUP2FUYH0QXJ60P3;bl/01026QXH0OWin
07inOP1EEED207UiN@0409RHV03MgMd0gMgM06a/K080KVi^00@0JFUY0>?Sh`3Shn<0Ti>C0P1bLW80
101cLg<0Hf=S06=SH`1kNg/20<K6aP040<g=c@2_[jl0[jn_07AdM080Ng]k00@0TY:B08b<S02<S8`0
TY:B0P21PH401@26QXH0_Kfm05iNGP1NGUh0>c/k0080<c<c00@0;Bd]04i>CP1>CTh0GemO0P1IFET0
101cLg<0S8b<08b<S021PH42071`L00406UYJ@1LG5`0G5aL06QXJ080=cLg00@0C4a<0:6QX@2QXJ40
R8R80P24Q8@0102i^KT0WYjN09jNWP1UIFD208Z:RP0409:BTP1ZJVX0JVYZ0820P080YjNW00@0JVYZ
06=SH`1SHf<0N7Qh0_ooool0103oP000003o0000o`000?l20?n000d0003o1@3oP0040000o`80oh00
2P000?l00`3oP000003o0000o`060000o`040?n000000?l0003o0000o`80oh0010000?l20?n000P0
003o0P3oP0040000o`80oh000`000?l00`3oP000003o0000o`030?n000H0003o00<0oh000000o`00
0?l02P000?l0103oP000003o0000o`000?l20?n000<0003o00<0oh000000o`000?l00`000?l00`3o
P000003o0000o`050000o`D0oh002P000?l90?n00080003o00<0oh000000o`000?l01@000?l20?n0
00040000o`3oP000oh000?n000D0003o00<0oh000000o`000?l03@000?l:ooooo`002Oooool0101L
G5`0TY:B09:BTP1jNWX204Q8B00407]kN`2?Shl0Shn?07MgM`80RHV900@0P82005iNGP1NGUh0BDU9
0P1XJ6P0101VIVH0FUYJ05YJFP1KFe/206i^KP04096AT@2FUYH0UYJF07emO@80@T9200@0HF5Q06a/
K01/K6`0GemO0P2FUYH0102WYjL0/k>c0;>c/`2IVIT20;Vi^@040:b/[02CTi<0Ti>C05iNGP80DU9B
00D0K6a/0;fm_@2a/K40/K6a096AT@0206UYJ@0406=SH`1gMgL0MgMg08b<S080Zj^[00@0VIVI08j>
SP2>SXh0Kfm_0P2OWil01026QXH0O7al07alO01DE5@208N7Q`0406m_K`2IVIT0VIVI0::RXP80Ti>C
00@0XJ6Q0;Zj^P2j^[X0QXJ60P2NWYh0102o_kl0V9RH09RHV02DU9@20;6a/@050;Fe]@30`<00`<30
0820P02=SHd00P21PH40101YJFT0WYjN09jNWP29RHT20:f][@040861P@3De=@0e=CD08N7Q`80PX:2
00@0F5QH07QhN01hN7P0Xj>S0P3QhN40101cLg<0I6AT06ATI01TI6@20=oOg`04096AT@1gMgL0MgMg
06e]K@80J6QX00@0LG5a0;bl_02l_;`0bl_;0P2^[Zh0101fMWH0RXZ:08Z:RP2ATI4207YjNP0507=c
L`1/K6`0K6a/08:2PP2QXJ400P1TI6@0100i>CT0<S8b038b<P0`<302051@D00405UIF@1>CTh0CTi>
06YZJP80Q8B400@0N7Qh07YjNP1jNWX0KVi^0P1`L700101PH600DU9B059BDP0o?cl2096AT@0409nO
W`2<S8`0S8b<0;2`/080X:2P00@0HF5Q08R8R028R8P0VYZJ0P22PX8305eMG@0403Lg=`1DE5@0E5AD
06a/K0;ooooo00@0oh000000o`000?l0003o0P3oP0070000o`<0oh000`000?l30?n000H0003o0P3o
P0070000o`040?n000000?l0003o0?n000<0003o0`3oP0020000o`<0oh004@000?l20?n000T0003o
00@0oh000000o`000?l0003o0P3oP0030000o`@0oh002@000?l0103oP000003o0000o`3oP0030000
o`80oh000`000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00D0003o1@3oP00=0000
o`T0oh002P000?l30?n000D0003o00<0oh000000o`000?l01P000?l60?n000030000oooooooooooo
00Sooooo0009ooooo`04061PH02IVIT0VIVI07=cL`80A4A400@0O7al0861P@21PH40MGEe0P1mOGd0
101nOWh0NGUi07UiN@1EEED2071`L004061PH019BDT0BDU905ADE080IVIV00@0RHV908R8R028R8P0
NWYj0P11@D40101WIfL0Fe]K05]KF`1RHV8208Z:RP0409NGU`2/[:`0[:b/09VIV@80^[Zj00@0YJFU
09RHV02HV9P0M7Ad0P1DE5@01@1dM7@0`<300<71`@31`L40UYJF0080J6QX00@0KFe]08F5Q@25QHD0
V9RH0P3>c/h0102][Jd0Vi^K09^KV`21PH420;Vi^@0408V9R@1mOGd0OGem065QH@80TY:B00@0P820
09ZJVP2JVYX0/K6a0P2`/;00102e]KD0bl_;0<_;b`2>SXh20:JVYP040;Jf]P2DU9@0U9BD08>3P`80
Zj^[00D0[:b/0<;2`P32`/80MWIf08R8R00208B4Q00407MgM`2DU9@0U9BD08>3P`80V9RH00@0KVi^
0=cLg03Lg=`0OWin0P1]KFd0101SHf<0RHV908V9R@2OWil20=[JfP0406EUI@1ADE40DE5A06QXJ080
h>3P00@0V9RH07IfMP1fMWH0NWYj0P1mOGd0101jNWX0c<c<0<c<c03GemL20;^k^`04092@T02LW9`0
W9bL0:FUY@80Shn?00D0VYZJ08:2PP22PX80WYjN0<W9b@0207]kN`0403Xj>P0d=3@0=3@d02l_;`80
C4a<00@0FEUI05MGE`1GEeL0MWIf0P1eMGD0101iNGT0IfMW06MWI`1UIFD206i^KP0404];B`1KFe/0
Fe]K05IFEP80Rh^;00@0UiNG08R8R028R8P0^k^k0P2UYJD0101UIFD0QhN708N7Q`2HV9P208R8R004
06YZJP1SHf<0Hf=S04a<C080Jf][00<0QXJ6ooooooooool010000?l20?n000T0003o00@0oh000000
o`000?l0003o0`3oP0060000o`80oh0000<0003o0?n000000?l01`000?l00`3oP000003o0000o`03
0000o`030?n000000?l0003o00<0oh001`000?l30?n000<0003o00<0oh000000o`000?l01`000?l6
0?n000<0003o0P3oP0060000o`030?n000000?l0003o00X0003o00<0oh000000o`000?l01P000?l0
103oP000003o0000o`3oP0020000o`030?n000000?l0003o00D0003o1@3oP00:0000o`80oh0000<0
003o0?n0003oP0001`3oP0090000o`@0oh001@000?l00`3oP000003o0000o`090000o`040?n00000
0?l0003o0000o`[ooooo0009ooooo`04061PH02IVIT0VIVI07=cL`80A4A400@0O7al0861P@21PH40
MGEe0P1mOGd0101nOWh0NGUi07UiN@1EEED2071`L004061PH019BDT0BDU905ADE080IVIV00@0RHV9
08R8R028R8P0NWYj0P11@D40101WIfL0Fe]K05]KF`1RHV8208Z:RP0409NGU`2/[:`0[:b/09VIV@80
^[Zj00@0YJFU09RHV02HV9P0M7Ad0P1DE5@01@1dM7@0`<300<71`@31`L40UYJF0080J6QX00@0KFe]
08F5Q@25QHD0V9RH0P3>c/h0102][Jd0Vi^K09^KV`21PH420;Vi^@0408V9R@1mOGd0OGem065QH@80
TY:B00@0P82009ZJVP2JVYX0/K6a0P2`/;00102e]KD0bl_;0<_;b`2>SXh20:JVYP040;Jf]P2DU9@0
U9BD08>3P`80Zj^[00D0[:b/0<;2`P32`/80MWIf08R8R00208B4Q00407MgM`2DU9@0U9BD08>3P`80
V9RH00@0KVi^0=cLg03Lg=`0OWin0P1]KFd0101SHf<0RHV908V9R@2OWil20=[JfP0406EUI@1ADE40
DE5A06QXJ080h>3P00@0V9RH07IfMP1fMWH0NWYj0P1mOGd0101jNWX0c<c<0<c<c03GemL20;^k^`04
092@T02LW9`0W9bL0:FUY@80Shn?00D0VYZJ08:2PP22PX80WYjN0<W9b@0207]kN`0403Xj>P0d=3@0
=3@d02l_;`80C4a<00@0FEUI05MGE`1GEeL0MWIf0P1eMGD0101iNGT0IfMW06MWI`1UIFD206i^KP04
04];B`1KFe/0Fe]K05IFEP80Rh^;00@0UiNG08R8R028R8P0^k^k0P2UYJD0101UIFD0QhN708N7Q`2H
V9P208R8R00406YZJP1SHf<0Hf=S04a<C080Jf][00<0QXJ6ooooooooool010000?l20?n000T0003o
00@0oh000000o`000?l0003o0`3oP0060000o`80oh0000<0003o0?n000000?l01`000?l00`3oP000
003o0000o`030000o`030?n000000?l0003o00<0oh001`000?l30?n000<0003o00<0oh000000o`00
0?l01`000?l60?n000<0003o0P3oP0060000o`030?n000000?l0003o00X0003o00<0oh000000o`00
0?l01P000?l0103oP000003o0000o`3oP0020000o`030?n000000?l0003o00D0003o1@3oP00:0000
o`80oh0000<0003o0?n0003oP0001`3oP0090000o`@0oh001@000?l00`3oP000003o0000o`090000
o`040?n000000?l0003o0000o`[ooooo0009ooooo`0405eMG@1mOGd0OGem06m_K`80ADE500@0QXJ6
09bLW02LW9`0QHF50P28R8P0102@T900NWYj07YjNP1EEED207alO00407=cL`1CDe<0De=C04I6AP80
JVYZ00@0QhN706MWI`1WIfL0F5QH0P0j>SX0101NGUh0KFe]06e]K@1QHF4208:2PP0408Z:RP2QXJ40
XJ6Q08:2PP80/[:b00@0XJ6Q09^KV`2KVi/0Lg=c0P19BDT01@1jNWX0cLg=0<C4a034a<@0RXZ:0080
HF5Q00@0K6a/08:2PP22PX80VIVI0P33`l<0102/[:`0VYZJ09ZJVP1aLG420;Jf]P0408J6QP27QhL0
QhN706i^KP80UIFE00@0NGUi0:2PX02PX:00/[:b0P34a<@0102g]kL0a<C40<C4a02>SXh20:VYZ@04
0<c<c02UYJD0YJFU09>CT`80];Bd00D0ZZZZ0<G5a@35aLD0H61P07emO@0208F5Q@0408N7Q`2VYZH0
YZJV08n?S`80T92@00@0K6a/0=WIf@3IfMT0Q8B40P1TI6@0101QHF40NWYj07YjNP2QXJ420=CDe004
05eMG@1CDe<0De=C05QHF080alO700@0TY:B06e]K@1]KFd0N7Qh0P1lO7`0101fMWH0`l?30<?3``3;
bl/20::RXP0407alO02XZ:P0Z:RX0:RXZ080TI6A00D0UiNG08R8R028R8P0Y:BT0<G5a@0207AdM004
03Ti>@0l?3`0?3`l034a<@80DE5A00@0E5AD05YJFP1JFUX0MGEe0P1UIFD0101cLg<0IfMW06MWI`1H
F5P2051@D00404];B`1NGUh0GUiN04a<C080GemO00@0V9RH07UiN@1iNGT0UIFE0P26QXH0101dM7@0
NGUi07UiN@24Q8@209RHV0<0L71`00@0GEeM075aL@1aLG40RXZ:0_ooool0103oP000003o0000o`00
0?l20?n000T0003o00@0oh000000o`000?l0003o0`3oP0050000o`@0oh002@000?l00`3oP000003o
0000o`030000o`030?n000000?l0003o00<0oh001`000?l20?n000@0003o00<0oh000000o`000?l0
1`000?l60?n000<0003o0P3oP0030000o`040?n000000?l0003o0?n000`0003o00<0oh000000o`00
0?l01P000?l70?n000L0003o0`3oP00<0000o`80oh0000<0003o0?n0003oP0001`3oP0060000o`L0
oh004@000?l0103oP000003o0000o`000?l:ooooo`002Oooool0101]KFd0T92@092@T01lO7`204];
B`0408f=S@2>SXh0SXj>08F5Q@80RHV900@0Vi^K06YZJP1ZJVX0B4Q80P1[Jf/0101jNWX0HV9R069R
HP14A4@2071`L00408Z:RP22PX80PX:207=cL`80@D5100@0De=C06][J`1[Jf/0LG5a0P26QXH0102T
Y:@0WYjN09jNWP27QhL20;2`/00409bLW02BTY80TY:B06e]K@80Bd];00D0MgMg0<K6aP2i^KT0^KVi
08:2PP02069RHP0406EUI@1oOgl0Ogmo09jNWP80aLG500@0[Jf]09jNWP2NWYh0K6a/0P2/[:`0101k
Ng/0PH610861P@1bLW8209jNWP04079bLP2:RXX0RXZ:0:FUY@80_;bl00@0XJ6Q0:NWY`2WYjL0PH61
0P2LW9`0102n_[h0/K6a0;6a/@2/[:`20;Rh^0050;bl_03:b/X0b/[:05MGE`27QhL00P2FUYH0102:
RXX0S8b<08b<S022PX8208J6QP04079bLP3MgMd0gMgM07]kN`80Hf=S00@0Lg=c08N7Q`27QhL0[:b/
0P3Lg=`0101QHF40B4Q804Q8B01TI6@20=OGe`0408J6QP1MGEd0GEeM07AdM080Kfm_00@0NGUi0;fm
_@2m_Kd0alO70P2QXJ40101/K6`0RHV908V9R@2PX:0207inOP0508f=S@27QhL0QhN709RHV032`/80
0P1iNGT0100k>c/0?Cdm03dm?@0f=SH204Y:BP04065QH@1UIFD0IFEU0820P080K6a/00@0MgMg071`
L01`L700MGEe0P1JFUX0101QHF40JVYZ06YZJP1KFe/206IVIP0409bLW01jNWX0NWYj09RHV080Lg=c
00@0Hf=S075aL@1aLG40Shn?0P2BTY80101VIVH0J6QX06QXJ01`L70206a/K00308Z:R_oooooooooo
00@0003o0P3oP0090000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l010000?l30?n0
00T0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`030?n000L0003o0`3oP00?0000
o`030?n000000?l0003o00@0003o0`3oP0020000o`H0oh002P000?l00`3oP000003o0000o`060000
o`040?n000000?l0003o0?n00080003o00@0oh000000o`000?l0oh0010000?l30?n000`0003o0P3o
P0000`000?l0oh000?n000040?n000X0003o0P3oP0030000o`030?n000000?l0003o01<0003o2_oo
ool000Wooooo00@0KFe]092@T02@T900O7al0P1;Bd/0102=SHd0SXj>08j>SP25QHD208V9R@0409^K
V`1ZJVX0JVYZ04Q8B080Jf][00@0NWYj069RHP1RHV80A4A40P1`L700102:RXX0PX:208:2PP1cLg<2
0451@@0405=CD`1[Jf/0Jf][075aL@80QXJ600@0Y:BT09jNWP2NWYh0QhN70P2`/;00102LW9`0TY:B
09:BTP1]KFd204];B`0507MgM`36a/H0^KVi0;Vi^@22PX800P1RHV80101UIFD0Ogmo07moO`2NWYh2
0<G5a@040:f][@2NWYh0WYjN06a/K080[:b/00@0Ng]k0861P@21PH40LW9b0P2NWYh0101bLW80RXZ:
08Z:RP2UYJD20;bl_0040:6QX@2WYjL0YjNW0861P@80W9bL00@0_[jn0;6a/@2a/K40[:b/0P2h^;P0
1@2l_;`0b/[:0<[:bP1GEeL0QhN70080UYJF00@0RXZ:08b<S02<S8`0PX:20P26QXH0101bLW80gMgM
0=gMg@1kNg/206=SH`0407=cL`27QhL0QhN70:b/[080g=cL00@0HF5Q04Q8B018B4P0I6AT0P3GemL0
1026QXH0GEeM05eMG@1dM7@206m_K`0407UiN@2m_Kd0_Kfm0<O7a`80XJ6Q00@0K6a/08V9R@29RHT0
X:2P0P1nOWh01@2=SHd0QhN708N7Q`2HV9P0`/;20080NGUi00@0>c/k03dm?@0m?Cd0=SHf0P1:BTX0
101QHF40IFEU06EUI@20P80206a/K00407MgM`1`L700L71`07EeM@80FUYJ00@0HF5Q06YZJP1ZJVX0
Fe]K0P1VIVH0102LW9`0NWYj07YjNP2HV9P207=cL`0406=SH`1aLG40LG5a08n?S`80TY:B00@0IVIV
06QXJ01XJ6P0L71`0P1/K6`00`2:RX[oooooooooo`040000o`80oh002@000?l00`3oP000003o0000
o`030000o`030?n000000?l0003o00@0003o0`3oP0090000o`030?n000000?l0003o00<0003o00<0
oh000000o`000?l00`3oP0070000o`<0oh003`000?l00`3oP000003o0000o`040000o`<0oh000P00
0?l60?n000X0003o00<0oh000000o`000?l01P000?l0103oP000003o0000o`3oP0020000o`040?n0
00000?l0003o0?n000@0003o0`3oP00<0000o`80oh0000<0003o0?n0003oP000103oP00:0000o`80
oh000`000?l00`3oP000003o0000o`0C0000o`[ooooo0009ooooo`04071`L02=SHd0SHf=07emO@80
BDU900@0TI6A0;:b/P2b/[80WIfM0P2EUID0102GUiL0J6QX06QXJ01<C4`2079bLP0406MWI`1MGEd0
GEeM04Y:BP80K6a/00@0NWYj08F5Q@25QHD0LG5a0P17AdL0101MGEd0Kfm_06m_K`1NGUh207AdM004
092@T02YZJT0ZJVY096AT@80]kNg00@0XJ6Q08b<S02<S8`0KFe]0P1GEeL01@1kNg/0c/k>0;no_`2o
_kl0QHF50080HF5Q00@0NGUi09bLW02LW9`0/;2`0P3Hf=P01030`<00Zj^[0:^[Z`1eMGD20;2`/004
079bLP23Ph<0Ph>307YjNP80Vi^K00@0K6a/07emO@1mOGd0X:2P0P2e]KD00`2;Rh/0Shn?08n?S`03
08J6QP040:^[Z`2SXj<0Xj>S0:BTY080Z:RX00D0/;2`0;Ng]`2g]kL0EUIF08j>SP0208^;R`0408N7
Q`24Q8@0Q8B407UiN@80PX:200@0Jf][0=_Kf`3Kfm/0Ng]k0P1MGEd0101iNGT0U9BD09BDU02[Zj/2
0=cLg0040820P01GEeL0EeMG06e]K@80i^KV00@0VYZJ06QXJ01XJ6P0PH610P1^KVh01023Ph<0aLG5
0<G5a@3@d=020;Zj^P0407YjNP2>SXh0SXj>0:RXZ080SHf=00D0SXj>08b<S02<S8`0Xj>S0<?3``02
0820P00404=3@`17AdL0AdM703lo?`80EEEE00@0J6QX07inOP1nOWh0R8R80P1iNGT01023Ph<0LG5a
075aL@22PX82061PH00406ATI01fMWH0MWIf069RHP80De=C00@0OGem096AT@2ATI40ZZZZ0P24Q8@0
101_Kfl0T92@092@T020P802096AT@04075aL@1]KFd0KFe]079bLP80PH6100<0R8R8ooooooooool0
10000?l20?n000030000o`3oP000oh0000H0003o00@0oh000000o`000?l0003o0`3oP0060000o`<0
oh0000<0003o0?n0003oP0001P000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00<0
oh001P000?l40?n000<0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`0:0000o`D0
oh002P000?l0103oP000003o0000o`3oP0050000o`040?n000000?l0003o0?n00080003o00<0oh00
0000o`000?l01@000?l50?n000X0003o0P3oP0000`000?l0oh000?n000040?n00100003o0P3oP00C
0000o`[ooooo0009ooooo`04079bLP2ATI40TI6A07moO`80DU9B00@0Q8B409nOW`2OWil0Rh^;0`2A
TI4207MgM`0404i>CP1mOGd0OGem07]kN`80DU9B00@0@41005eMG@1MGEd0Kfm_0P1]KFd0101OGel0
DE5A055AD@1SHf<206UYJ@0405eMG@1XJ6P0J6QX07moO`80SXj>00@0QHF50:BTY02TY:@0Ti>C0P1_
Kfl01@1LG5`0B4Q804Q8B01SHf<0/k>c0080Y:BT00@0KFe]05IFEP1FEUH0Kfm_0P2DU9@0102][Jd0
emOG0=OGe`2n_[h20:FUY@0407AdM02a/K40/K6a07MgM`80RXZ:00@0PH6108j>SP2>SXh0GemO0P2=
SHd0102ZZZX0]kNg0;Ng]`23Ph<20:6QX@0409JFUP2GUiL0UiNG0;no_`80YjNW00@0/K6a0:FUY@2U
YJD0^k^k0P2e]KD01@1OGel0SXj>08B4Q024Q8@0Vi^K0080PH6100@0WYjN07]kN`1kNg/0KFe]0P3K
fm/0102<S8`0Fe]K05]KF`1kNg/209:BTP0409bLW03Ogml0gmoO08b<S080EUIF00@0K6a/0>CTi03T
i>@0XZ:R0P1/K6`01026QXH0JVYZ06YZJP20P8020<30`0040<;2`P2QXJ40XJ6Q06m_K`80QHF500@0
XZ:R08b<S02<S8`0SXj>0P2GUiL01@2ZZZX0`l?308F5Q@25QHD0DU9B00<0ATI60P1?Cdl0101QHF40
S8b<08b<S025QHD207YjNP0407MgM`1/K6`0K6a/08b<S080IVIV00@0IFEU07alO01lO7`0IfMW0P1^
KVh01022PX80RXZ:08Z:RP2GUiL208>3P`0407alO02FUYH0UYJF09JFUP80Ogmo00@0IfMW06a/K01/
K6`0TY:B0P2<S8`00`2VYZKoooooooooo`040000o`80oh002@000?l0103oP000003o0000o`000?l5
0?n000@0003o0P3oP0020000o`80oh002P000?l30?n00080003o00@0oh000000o`000?l0003o0P3o
P0030000o`@0oh000`000?l00`3oP000003o0000o`090000o`030?n000000?l0003o00@0003o0P3o
P00010000?l0oh000?n000000?l30?n000`0003o00@0oh000000o`000?l0oh001@000?l0103oP000
003o0000o`3oP0020000o`030?n000000?l0003o00D0003o0`3oP00<0000o`80oh0000<0003o0?n0
003oP000103oP00U0000o`[ooooo0009ooooo`04079bLP2ATI40TI6A07moO`80DU9B00@0Q8B409nO
W`2OWil0Rh^;0`2ATI4207MgM`0404i>CP1mOGd0OGem07]kN`80DU9B00@0@41005eMG@1MGEd0Kfm_
0P1]KFd0101OGel0DE5A055AD@1SHf<206UYJ@0405eMG@1XJ6P0J6QX07moO`80SXj>00@0QHF50:BT
Y02TY:@0Ti>C0P1_Kfl01@1LG5`0B4Q804Q8B01SHf<0/k>c0080Y:BT00@0KFe]05IFEP1FEUH0Kfm_
0P2DU9@0102][Jd0emOG0=OGe`2n_[h20:FUY@0407AdM02a/K40/K6a07MgM`80RXZ:00@0PH6108j>
SP2>SXh0GemO0P2=SHd0102ZZZX0]kNg0;Ng]`23Ph<20:6QX@0409JFUP2GUiL0UiNG0;no_`80YjNW
00@0/K6a0:FUY@2UYJD0^k^k0P2e]KD01@1OGel0SXj>08B4Q024Q8@0Vi^K0080PH6100@0WYjN07]k
N`1kNg/0KFe]0P3Kfm/0102<S8`0Fe]K05]KF`1kNg/209:BTP0409bLW03Ogml0gmoO08b<S080EUIF
00@0K6a/0>CTi03Ti>@0XZ:R0P1/K6`01026QXH0JVYZ06YZJP20P8020<30`0040<;2`P2QXJ40XJ6Q
06m_K`80QHF500@0XZ:R08b<S02<S8`0SXj>0P2GUiL01@2ZZZX0`l?308F5Q@25QHD0DU9B00<0ATI6
0P1?Cdl0101QHF40S8b<08b<S025QHD207YjNP0407MgM`1/K6`0K6a/08b<S080IVIV00@0IFEU07al
O01lO7`0IfMW0P1^KVh01022PX80RXZ:08Z:RP2GUiL208>3P`0407alO02FUYH0UYJF09JFUP80Ogmo
00@0IfMW06a/K01/K6`0TY:B0P2<S8`00`2VYZKoooooooooo`040000o`80oh002@000?l0103oP000
003o0000o`000?l50?n000@0003o0P3oP0020000o`80oh002P000?l30?n00080003o00@0oh000000
o`000?l0003o0P3oP0030000o`@0oh000`000?l00`3oP000003o0000o`090000o`030?n000000?l0
003o00@0003o0P3oP00010000?l0oh000?n000000?l30?n000`0003o00@0oh000000o`000?l0oh00
1@000?l0103oP000003o0000o`3oP0020000o`030?n000000?l0003o00D0003o0`3oP00<0000o`80
oh0000<0003o0?n0003oP000103oP00U0000o`[ooooo0009ooooo`0407QhN02VYZH0YZJV07inOP80
GUiN00@0PH610:JVYP2VYZH0Ti>C0P2FUYH01022PX80I6AT06ATI01:BTX206e]K@0406m_K`1MGEd0
GEeM04=3@`80GEeM00@0PH61075aL@1aLG40Lg=c0P1HF5P0101MGEd0JFUY06UYJ@1RHV8207QhN004
08f=S@2RXZ80XZ:R09>CT`80[Jf]00@0Y:BT08:2PP22PX80HV9R0P0n?Sh01@1PH600_[jn0;Zj^P2j
^[X0LW9b0080Fe]K00@0LW9b08:2PP22PX80W9bL0P32`/80102/[:`0SXj>08j>SP1RHV8209^KV`03
06ATI01kNg/0Ng]k00<0NWYj00@0FUYJ08:2PP22PX80Y:BT0P2j^[X0102<S8`0VIVI09VIV@2IVIT2
0:6QX@040;6a/@2ZZZX0ZZZZ0;jn_P80TY:B00D0_kno0;:b/P2b/[80IfMW0:FUY@0208Z:RP040::R
XP1kNg/0Ng]k09jNWP80R8R800@0KFe]0=_Kf`3Kfm/0Vi^K0P1OGel0102>SXh0YZJV0:JVYP2>SXh2
0=CDe00407moO`1?Cdl0Cdm?05YJFP80fm_K00@0VIVI06EUI@1UIFD0OGem0P1ZJVX0101kNg/0_[jn
0;jn_P38b<P20:^[Z`0406a/K02:RXX0RXZ:0:FUY@80RHV900D0S8b<09RHV02HV9P0Y:BT0<?3``02
08J6QP0404A4A011@D40@D5104e=C@80BTY:00@0DU9B07inOP1nOWh0SXj>0P1`L700101/K6`0JVYZ
06YZJP2:RXX206MWI`0406][J`1QHF40HF5Q055AD@80Vi^K00@0WinO09^KV`2KVi/0TI6A0P1aLG40
101/K6`0Vi^K09^KV`2CTi<206e]K@0405IFEP1HF5P0F5QH07inOP80Ph>300<0XJ6Qooooooooool0
10000?l20?n000T0003o00@0oh000000o`000?l0003o1@3oP0040000o`<0oh002@000?l00`3oP000
003o0000o`030000o`030?n000000?l0003o00<0oh0000<0003o0?n0003oP00010000?l20?n000/0
003o0P3oP0030000o`030?n000000?l0003o00@0003o0P3oP00010000?l0oh000?n000000?l30?n0
00`0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`040?n000L0003o0`3oP00<0000
o`80oh0000<0003o0?n0003oP0001P3oP00=0000o`030?n000000?l0003o00`0003o0`3oP0040000
o`[ooooo0009ooooo`0406e]K@2@T900T92@07IfMP80HV9R00@0PH6109^KV`2KVi/0Shn?0P2=SHd0
101kNg/0Jf][06][J`1EEED207YjNP04071`L01GEeL0EeMG05=CD`80K6a/00@0Ti>C0820P020P800
LW9b0P1@D500101ADE40JVYZ06YZJP1WIfL207UiN@0408B4Q02a/K40/K6a09nOW`80Xj>S00@0TI6A
07QhN01hN7P0IfMW0P1;Bd/01@1UIFD0Zj^[0:BTY02TY:@0IVIV0080DU9B00@0Hf=S08Z:RP2:RXX0
Ti>C0P39bLT0103:b/X0UYJF09JFUP1/K6`20:f][@0406i^KP2@T900T92@08F5Q@80LG5a00@0IFEU
07inOP1nOWh0XZ:R0P31`L401023Ph<0VIVI09VIV@2;Rh/209fMW@040;Zj^P2WYjL0YjNW0<k>cP80
R8R800D0[Jf]0;Bd]02d];@0Hf=S09VIV@0206][J`0407EeM@1fMWH0MWIf09BDU080JVYZ00@0IFEU
0=KFeP3Fe]H0[Jf]0P1NGUh0102BTY80S8b<08b<S02;Rh/20=kNgP0409FEU@1IFET0FEUI05MGE`80
hn?S00@0ZZZZ06IVIP1VIVH0R8R80P1^KVh01026QXH0a<C40<C4a03>c/h20:b/[00406YZJP27QhL0
QhN70:6QX@80Q8B400D0R8R8096AT@2ATI40U9BD0:^[Z`0207MgM`0404E5A@0n?Sh0?Shn04];B`80
A4A400@0B4Q806i^KP1^KVh0Ng]k0P1JFUX0101BDU80HF5Q065QH@1nOWh207IfMP0407=cL`1TI6@0
I6AT05MGE`80K6a/00@0Ng]k09bLW02LW9`0UYJF0P2<S8`01022PX80YJFU0:FUY@2VYZH207inOP03
071`L01_Kfl0Kfm_00<0P82000<0O7alooooooooool03`000?l0103oP000003o0000o`000?l30?n0
00H0003o0`3oP0060000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l010000?l20?n0
00@0003o0`3oP0030000o`030?n000000?l0003o00T0003o00<0oh000000o`000?l010000?l20?n0
00040000o`3oP000oh000000o`<0oh0030000?l40?n000D0003o00<0oh000000o`000?l0103oP007
0000o`<0oh003`000?l80?n000<0003o0P3oP0080000o`030?n000000?l0003o01<0003o2_ooool0
00Wooooo00@0KFe]092@T02@T900MWIf0P1RHV801021PH40Vi^K09^KV`2?Shl208f=S@0407]kN`1[
Jf/0Jf][05EEE@80NWYj00@0L71`05MGE`1GEeL0De=C0P1/K6`0102CTi<0P8200820P01bLW82051@
D004055AD@1ZJVX0JVYZ06MWI`80NGUi00@0Q8B40;6a/@2a/K40WinO0P2SXj<0102ATI40N7Qh07Qh
N01WIfL204];B`0506EUI@2[Zj/0Y:BT0:BTY01VIVH00P1BDU80101SHf<0RXZ:08Z:RP2CTi<20<W9
b@040<[:bP2FUYH0UYJF06a/K080[Jf]00@0KVi^092@T02@T900QHF50P1aLG40101UIFD0OWin07in
OP2RXZ820<71`@0408>3P`2IVIT0VIVI08^;R`80WIfM00@0^[Zj0:NWY`2WYjL0c/k>0P28R8P01@2]
[Jd0];Bd0;Bd]01SHf<0VIVI0080Jf][00@0MGEe07IfMP1fMWH0U9BD0P1ZJVX0101UIFD0e]KF0=KF
eP2][Jd205iNGP0409:BTP2<S8`0S8b<08^;R`80g]kN00@0UIFE05UIF@1IFET0EeMG0P3Shn<0102Z
ZZX0IVIV06IVIP28R8P206i^KP0408J6QP34a<@0a<C40<k>cP80[:b/00@0JVYZ08N7Q`27QhL0XJ6Q
0P24Q8@01@28R8P0TI6A096AT@2DU9@0Zj^[0080MgMg00@0ADE503hn?P0n?Sh0Bd];0P14A4@01018
B4P0KVi^06i^KP1kNg/205YJFP04059BDP1QHF40HF5Q07inOP80MWIf00@0Lg=c06ATI01TI6@0EeMG
0P1/K6`0101kNg/0W9bL09bLW02FUYH208b<S00408:2PP2UYJD0YJFU0:JVYP80OWin00<0L71`06m_
K`1_Kfl00`20P8000`1lO7coooooooooo`0?0000o`040?n000000?l0003o0000o`<0oh001P000?l3
0?n000H0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`040000o`80oh0010000?l3
0?n000<0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`040000o`80oh0000@0003o
0?n0003oP000003o0`3oP00<0000o`@0oh001@000?l00`3oP000003o0000o`040?n000L0003o0`3o
P00?0000o`P0oh000`000?l20?n000P0003o00<0oh000000o`000?l04`000?l:ooooo`002Oooool0
101ZJVX0QHF508F5Q@1cLg<2051@D00408Z:RP2MWId0WIfM08b<S080T92@00@0MGEe06a/K01/K6`0
CDe=0P22PX80101hN7P0EeMG05MGE`1@D50205iNGP04075aL@1`L700L71`06e]K@80@T9200@0EeMG
07UiN@1iNGT0JVYZ0P1gMgL01028R8P0^;Rh0;Rh^02VYZH20:>SX`0409jNWP1dM7@0M7Ad05mOG`80
EeMG00D0Jf][0;Fe]@2h^;P0^;Rh079bLP0205eMG@0405aLG01fMWH0MWIf08N7Q`80_Kfm00@0^;Rh
08b<S02<S8`0De=C0P2CTi<0101XJ6P0PH610861P@26QXH2061PH004069RHP1jNWX0NWYj09nOW`80
];Bd00@0Ng]k092@T02@T900R8R80P2MWId0102YZJT0UIFE09FEU@2_[jl207=cL`050:6QX@2GUiL0
UiNG05ADE01dM7@00P1SHf<01023Ph<0NGUi07UiN@29RHT206UYJ@0405mOG`3AdM40dM7A09jNWP80
De=C00@0SXj>07]kN`1kNg/0QhN70P3<c<`0102EUID0DE5A055AD@1@D5020>7Qh@040;bl_01cLg<0
Lg=c08b<S080IFEU00@0N7Qh0;>c/`2c/k<0`L710P2c/k<0101bLW80U9BD09BDU02NWYh208N7Q`05
0861P@2ATI40TI6A0;6a/@38b<P00P1fMWH01011@D40@T920492@P16ATH204U9B@0405MGE`1cLg<0
Lg=c07]kN`80J6QX00@0GUiN06EUI@1UIFD0N7Qh0P1[Jf/0101gMgL0M7Ad07AdM01SHf<20:>SX`04
09:BTP2ZZZX0ZZZZ0:2PX080PH6100@0Q8B40:2PX02PX:00YZJV0P1QHF40101NGUh0LW9b079bLP24
Q8@207inOP03096ATOoooooooooo00@0003o0P3oP0090000o`040?n000000?l0003o0000o`D0oh00
10000?l30?n000H0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`030?n000040000
o`3oP000oh000?n000<0003o0`3oP0000`000?l0oh000?n0000<0000o`030?n000000?l0003o00L0
003o0P3oP0040000o`80oh002P000?l0103oP000003o0000o`3oP0050000o`030?n000000?l0003o
00H0oh001@000?l50?n000T0003o0`3oP0000`000?l0oh000?n000060?n000@0003o00<0oh000000
o`000?l05@000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0407AdM021PH40PH6108B4
Q080B4Q800@0NWYj07alO01lO7`0Kfm_0P1eMGD0101oOgl0HV9R069RHP12@T8206a/K004079bLP1F
EUH0EUIF04=3@`80O7al00@0QhN706][J`1[Jf/0HV9R0P12@T80101BDU80MGEe07EeM@1IFET205aL
G0040861P@2^[Zh0[Zj^09VIV@80S8b<00@0QXJ6075aL@1aLG40H61P0P1EEED01@1aLG40/;2`0;Ng
]`2g]kL0NGUi0080J6QX00@0MGEe08Z:RP2:RXX0Rh^;0P3EeMD0103Cdm<0UiNG09NGU`0n?Sh209VI
V@0407moO`2=SHd0SHf=08n?S`80Fe]K00@0JVYZ07emO@1mOGd0YJFU0P2YZJT01024Q8@0Xj>S0:>S
X`2@T9020:2PX0040:n_[`2QXJ40XJ6Q0<G5a@80NWYj00D0/[:b0:j^[P2^[Zh0K6a/096AT@0207Ee
M@0408B4Q02EUID0UIFE0:FUY@80NWYj00@0N7Qh0=;BdP3Bd]80`L710P1IFET01029RHT0Rh^;08^;
R`2QXJ420=WIf@0409RHV014A4@0A4A404m?C`80eMGE00@0Z:RX06m_K`1_Kfl0Q8B40P1SHf<0101b
LW80WIfM09fMW@2a/K4209jNWP0406=SH`21PH40PH6109FEU@80Ng]k00D0N7Qh08Z:RP2:RXX0]kNg
0<G5a@0207inOP<0ATI600@0@T9204e=C@1=CDd0GemO0P22PX80102;Rh/0NWYj07YjNP1QHF42069R
HP0407alO01aLG40LG5a061PH080HF5Q00@0Jf][09NGU`2GUiL0UIFE0P2a/K40102TY:@0PX:208:2
PP2ATI420:ZZZP040;:b/P20P800P82006a/K080IFEU00@0IfMW05]KF`1KFe/0MWIf0_ooool40000
o`80oh002@000?l0103oP000003o0000o`000?l30?n000H0003o0`3oP00010000?l0oh000?n0003o
P0020000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l00`3oP0070000o`<0oh0000<0
003o0?n0003oP0001P000?l00`3oP000003o0000o`0:0000o`80oh0000@0003o0?n0003oP000003o
0`3oP00<0000o`@0oh001@000?l00`3oP000003o0000o`040?n000T0003o00<0oh000000o`000?l0
2@000?l30?n000030000o`3oP000oh0000@0oh004`000?l20?n000H0003o00<0oh000000o`000?l0
10000?l20?n000030000oooooooooooo00Sooooo0009ooooo`0407AdM021PH40PH6108B4Q080B4Q8
00@0NWYj07alO01lO7`0Kfm_0P1eMGD0101oOgl0HV9R069RHP12@T8206a/K004079bLP1FEUH0EUIF
04=3@`80O7al00@0QhN706][J`1[Jf/0HV9R0P12@T80101BDU80MGEe07EeM@1IFET205aLG0040861
P@2^[Zh0[Zj^09VIV@80S8b<00@0QXJ6075aL@1aLG40H61P0P1EEED01@1aLG40/;2`0;Ng]`2g]kL0
NGUi0080J6QX00@0MGEe08Z:RP2:RXX0Rh^;0P3EeMD0103Cdm<0UiNG09NGU`0n?Sh209VIV@0407mo
O`2=SHd0SHf=08n?S`80Fe]K00@0JVYZ07emO@1mOGd0YJFU0P2YZJT01024Q8@0Xj>S0:>SX`2@T902
0:2PX0040:n_[`2QXJ40XJ6Q0<G5a@80NWYj00D0/[:b0:j^[P2^[Zh0K6a/096AT@0207EeM@0408B4
Q02EUID0UIFE0:FUY@80NWYj00@0N7Qh0=;BdP3Bd]80`L710P1IFET01029RHT0Rh^;08^;R`2QXJ42
0=WIf@0409RHV014A4@0A4A404m?C`80eMGE00@0Z:RX06m_K`1_Kfl0Q8B40P1SHf<0101bLW80WIfM
09fMW@2a/K4209jNWP0406=SH`21PH40PH6109FEU@80Ng]k00D0N7Qh08Z:RP2:RXX0]kNg0<G5a@02
07inOP<0ATI600@0@T9204e=C@1=CDd0GemO0P22PX80102;Rh/0NWYj07YjNP1QHF42069RHP0407al
O01aLG40LG5a061PH080HF5Q00@0Jf][09NGU`2GUiL0UIFE0P2a/K40102TY:@0PX:208:2PP2ATI42
0:ZZZP040;:b/P20P800P82006a/K080IFEU00@0IfMW05]KF`1KFe/0MWIf0_ooool40000o`80oh00
2@000?l0103oP000003o0000o`000?l30?n000H0003o0`3oP00010000?l0oh000?n0003oP0020000
o`030?n000000?l0003o00H0003o00<0oh000000o`000?l00`3oP0070000o`<0oh0000<0003o0?n0
003oP0001P000?l00`3oP000003o0000o`0:0000o`80oh0000@0003o0?n0003oP000003o0`3oP00<
0000o`@0oh001@000?l00`3oP000003o0000o`040?n000T0003o00<0oh000000o`000?l02@000?l3
0?n000030000o`3oP000oh0000@0oh004`000?l20?n000H0003o00<0oh000000o`000?l010000?l2
0?n000030000oooooooooooo00Sooooo0009ooooo`0407alO025QHD0QHF509FEU@80GUiN00@0Xj>S
0:ZZZP2ZZZX0R8R80P2ATI40102JVYX0PX:208:2PP1FEUH208R8R00408^;R`1EEED0EEEE03dm?@80
Hf=S00@0U9BD07EeM@1eMGD0Fe]K0P1JFUX0101@D500GUiN05iNGP1QHF4206ATI00408F5Q@30`<00
`<300::RXP80WIfM00@0YjNW07QhN01hN7P0IVIV0P1LG5`01@1SHf<0WYjN09BDU02DU9@0HV9R0080
Hf=S00@0Lg=c08F5Q@25QHD0SHf=0P3<c<`01039bLT0TI6A096AT@10@4020:RXZ00408n?S`2JVYX0
VYZJ08n?S`80F5QH00@0KVi^07UiN@1iNGT0Zj^[0P2^[Zh0102IVIT0Zj^[0:^[Z`2XZ:P20::RXP04
0;Jf]P2SXj<0Xj>S09bLW080LW9b00D0^k^k0;bl_02l_;`0MGEe08f=S@0207EeM@0407UiN@29RHT0
RHV909ZJVP80N7Qh00@0MGEe0<_;b`3;bl/0][Jf0P1KFe/0101gMgL0SHf=08f=S@2?Shl20=CDe004
0:f][@0j>SX0>SXj05ADE080g]kN00@0TY:B07MgM`1gMgL0RHV90P1YJFT01022PX80_;bl0;bl_035
aLD20:ZZZP04065QH@26QXH0QXJ608b<S080RHV900D0NWYj08B4Q024Q8@0_;bl0<W9b@0208N7Q`04
04U9B@1>CTh0CTi>04Q8B080D51@00@0Fe]K0820P020P800LW9b0P1iNGT0101LG5`0Hf=S06=SH`27
QhL206m_K`04071`L01VIVH0IVIV04e=C@80L71`00@0PX:209jNWP2NWYh0YZJV0P26QXH01027QhL0
ZZZZ0:ZZZP2f][H208J6QP0408b<S01mOGd0OGem06EUI@80GUiN00<0Hf=Sooooooooool010000?l2
0?n000T0003o00@0oh000000o`000?l0003o0`3oP0050000o`D0oh001@000?l00`3oP000003o0000
o`060000o`030?n000000?l0003o00X0003o0`3oP0000`000?l0oh000?n000060000o`030?n00000
0?l0003o00<0003o00<0oh000000o`000?l010000?l20?n000@0003o0`3oP00<0000o`@0oh001@00
0?l70?n000L0003o0`3oP00;0000o`<0oh0000<0003o0?n0003oP0001P3oP0040000o`030?n00000
0?l0003o00H0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`040000o`80oh0000<0
003oooooooooool02?ooool000Wooooo0`1_Kfl0101oOgl0C4a<04a<C02YZJT20;2`/00409JFUP2>
SXh0SXj>09NGU`80LW9b00@0De=C06QXJ01XJ6P0K6a/0P1IFET0100n?Sh0LG5a075aL@2HV9P208Z:
RP0406m_K`1IFET0FEUI04a<C080DU9B00@0IFEU065QH@1QHF40MWIf0P33`l<0102PX:00RHV908V9
R@2_[jl207emO@0506e]K@1aLG40LG5a075aL@2QXJ400P2XZ:P01027QhL0Kfm_06m_K`1kNg/208B4
Q00408N7Q`36a/H0a/K60<30`080RHV900@0AdM70:FUY@2UYJD0T92@0P2RXZ80102;Rh/0E5AD05AD
E01bLW8207inOP040:VYZ@2c/k<0/k>c09ZJVP80ZJVY00@0VYZJ0:6QX@2QXJ40`<300P2GUiL01026
QXH0IVIV06IVIP2RXZ820:NWY`0505UIF@1dM7@0KVi^06i^KP1nOWh00P23Ph<01029RHT0MGEe07Ee
M@1hN7P20<c<c0040;Ng]`1kNg/0Ng]k08Z:RP80T92@00@0YJFU0=7Ad@3AdM40_kno0P1TI6@0101M
GEd0hN7Q0>7Qh@2c/k<207]kN`0408J6QP1[Jf/0Jf][08R8R080b/[:00@0`/;20;Fe]@2e]KD0KVi^
0P2@T900102MWId0Vi^K09^KV`2>SXh2096AT@050;fm_@2MWId0Y:BT0:BTY01DE5@00`1BDU8205EE
E@0405eMG@25QHD0QHF508N7Q`80KVi^00@0Hf=S05]KF`1KFe/0R8R80P1aLG40101mOGd0I6AT06AT
I010@40206a/K00407MgM`1nOWh0OWin08Z:RP80Q8B400@0P820092@T02@T900WIfM0P27QhL0102Q
XJ40IfMW06MWI`1YJFT206YZJP0306m_Kooooooooooo00@0003o0P3oP0000`000?l0oh000?n00006
0000o`040?n000000?l0003o0000o`<0oh001P000?l40?n000D0003o00@0oh000000o`000?l0003o
0P3oP00@0000o`<0oh0000<0003o0?n0003oP0001P000?l00`3oP000003o0000o`030000o`030?n0
00000?l0003o00@0003o0P3oP0070000o`80oh002P000?l30?n000H0003o0`3oP0000`000?l0oh00
0?n000030?n000D0003o1@3oP0090000o`040?n000000?l0003o0000o`P0oh001@000?l20?n000H0
003o00<0oh000000o`000?l04`000?l:ooooo`002Oooool306m_K`0407moO`1<C4`0C4a<0:VYZ@80
/;2`00@0UYJF08j>SP2>SXh0UiNG0P1bLW80101CDe<0J6QX06QXJ01/K6`205UIF@0403hn?P1aLG40
LG5a09RHV080RXZ:00@0Kfm_05UIF@1IFET0C4a<0P1BDU80101UIFD0HF5Q065QH@1fMWH20<?3``04
0:2PX029RHT0RHV90:n_[`80OGem00D0KFe]075aL@1aLG40LG5a0:6QX@020:RXZ00408N7Q`1_Kfl0
Kfm_07]kN`80Q8B400@0QhN70<K6aP36a/H0`<300P29RHT01017AdL0YJFU0:FUY@2@T9020::RXP04
08^;R`1DE5@0E5AD079bLP80OWin00@0ZJVY0;>c/`2c/k<0VYZJ0P2YZJT0102JVYX0XJ6Q0:6QX@30
`<0209NGU`0408J6QP1VIVH0IVIV0::RXP80YjNW00D0FEUI07AdM01^KVh0KVi^07inOP0208>3P`04
08V9R@1eMGD0MGEe07QhN080c<c<00@0]kNg07]kN`1kNg/0RXZ:0P2@T900102UYJD0dM7A0=7Ad@2o
_kl206ATI00405eMG@3QhN40hN7Q0;>c/`80Ng]k00@0QXJ606][J`1[Jf/0R8R80P3:b/X01032`/80
]KFe0;Fe]@1^KVh2092@T00409fMW@2KVi/0Vi^K08j>SP80TI6A00D0_Kfm09fMW@2TY:@0Y:BT05AD
E003059BDP80EEEE00@0GEeM08F5Q@25QHD0QhN70P1^KVh0101SHf<0Fe]K05]KF`28R8P2075aL@04
07emO@1TI6@0I6AT0410@080K6a/00@0MgMg07inOP1nOWh0RXZ:0P24Q8@01020P800T92@092@T02M
WId208N7Q`040:6QX@1WIfL0IfMW06UYJ@80JVYZ00<0Kfm_ooooooooool010000?l20?n000030000
o`3oP000oh0000H0003o00@0oh000000o`000?l0003o0`3oP0060000o`@0oh001@000?l0103oP000
003o0000o`000?l20?n00100003o0`3oP0000`000?l0oh000?n000060000o`030?n000000?l0003o
00<0003o00<0oh000000o`000?l010000?l20?n000L0003o0P3oP00:0000o`<0oh001P000?l30?n0
00030000o`3oP000oh0000<0oh001@000?l50?n000T0003o00@0oh000000o`000?l0003o203oP005
0000o`80oh001P000?l00`3oP000003o0000o`0C0000o`[ooooo0009ooooo`04071`L01gMgL0MgMg
09FEU@80CTi>0`2QXJ40102CTi<0Shn?08n?S`2SXj<306MWI`80PH6100@0I6AT04Y:BP1:BTX0<S8b
0P1GEeL0101^KVh0MGEe07EeM@1NGUh204i>CP0404m?C`1ADE40DE5A07MgM`80FEUI00@0QXJ60<S8
b038b<P0YZJV0P28R8P0102[Zj/0NGUi07UiN@1dM7@2075aL@0508j>SP2[Zj/0]KFe0;Fe]@25QHD0
0P1nOWh01024Q8@0TI6A096AT@2^[Zh20<k>cP040<?3``2DU9@0U9BD04Q8B080[:b/00@0UYJF09nO
W`2OWil0U9BD0P1:BTX0101mOGd0T92@092@T02b/[820;fm_@040:FUY@2i^KT0^KVi08V9R@80U9BD
00@0`L710:n_[`2_[jl0WinO0P1iNGT01@2o_kl0`<300<30`01kNg/0VYZJ0080LG5a00@0PX:209RH
V02HV9P0[Jf]0P1_Kfl0101lO7`0_;bl0;bl_02f][H209^KV`0407AdM022PX80PX:209^KV`80a<C4
00@0^[Zj05YJFP1JFUX0H61P0P3Ogml0102NWYh0P8200820P029RHT206ATI00407emO@34a<@0a<C4
0;bl_080^[Zj00@0MWIf09RHV02HV9P0W9bL0P2UYJD01@29RHT0TY:B09:BTP2g]kL0U9BD0080Vi^K
00@0GEeM059BDP1BDU80BDU90P1;Bd/0101FEUH0IVIV06IVIP1dM7@2065QH@0406][J`1?Cdl0Cdm?
07moO`80MGEe00@0GemO07AdM01dM7@0CDe=0P1]KFd0101kNg/0[Zj^0:j^[P2HV9P20820P00407em
O@2RXZ80XZ:R09JFUP80Ng]k00@0YJFU06QXJ01XJ6P0F5QH0P1WIfL00`1HF5Soooooooooo`040000
o`80oh003@000?l50?n000<0003o1@3oP0020000o`040?n000000?l0003o0?n000`0003o0P3oP006
0000o`@0oh0000<0003o0?n0003oP0001P000?l0103oP000003o0000o`000?l30?n00080003o00@0
oh000000o`000?l0003o0`3oP0030000o`<0oh001`000?l20?n000<0003o0`3oP0060000o`@0oh00
0P000?l00`3oP000003o0000o`050000o`D0oh002@000?l0103oP000003o0000o`000?l80?n000D0
003o0P3oP0060000o`040?n000000?l0003o0000o`80oh0030000?l0103oP000003o0000o`3oP00:
ooooo`002Oooool0101lO7`0QXJ608J6QP2HV9P2055AD@0409ZJVP2YZJT0ZJVY09NGU`80TY:B00@0
Vi^K06a/K01/K6`0GemO0P20P800101kNg/0Fe]K05]KF`14A4@206IVIP0407moO`22PX80PX:207=c
L`80L71`00@0KVi^05YJFP1JFUX0T92@0P1XJ6P01026QXH0^k^k0;^k^`2MWId208B4Q0040;Fe]@1h
N7P0N7Qh07QhN080OGem00D0SXj>0;Bd]039bLT0bLW9092@T00208f=S@040820P029RHT0RHV90:6Q
X@80c<c<00@0_;bl09>CT`2CTi<0A4A40P2IVIT01029RHT0Shn?08n?S`29RHT204U9B@0407alO02;
Rh/0Rh^;0;Rh^080c/k>00@0Y:BT0;fm_@2m_Kd0Ti>C0P2@T900103:b/X0Zj^[0:^[Z`2OWil2079b
LP050:RXZ02m_Kd0_Kfm07alO02ATI400P1]KFd307emO@0409bLW022PX80PX:208Z:RP80`L7100@0
[Jf]09^KV`2KVi/0KFe]0P1oOgl0102VYZH0^[Zj0;Zj^P2KVi/20451@@0405]KF`33`l<0`l?309RH
V080PX:200@0MWIf065QH@1QHF40NGUi0P2n_[h0102f][H0_;bl0;bl_01bLW8209^KV`04092@T02X
Z:P0Z:RX06YZJP80V9RH00D0Y:BT0:2PX02:RXX0RXZ:06UYJ@0205UIF@04055AD@1;Bd/0Bd];055A
D@80M7Ad00@0Q8B407]kN`1kNg/0N7Qh0P1FEUH0102:RXX0QhN708N7Q`1YJFT207QhN004051@D026
QXH0QXJ608Z:RP80Rh^;00@0UIFE09BDU02DU9@0M7Ad0P1eMGD0101jNWX0Ph>308>3P`2EUID2059B
DP0405]KF`1VIVH0IVIV05YJFP;ooooo10000?l20?n000d0003o0`3oP0090000o`030?n000000?l0
003o00<0003o00@0oh000000o`000?l0003o0P3oP0060000o`<0oh001`000?l30?n000030000o`3o
P000oh0000H0003o00@0oh000000o`000?l0003o0`3oP0020000o`040?n000000?l0003o0000o`80
oh001P000?l00`3oP000003o0000o`0:0000o`<0oh001P000?l00`3oP000003o0000o`040?n000L0
003o1@3oP00?0000o`H0oh001@000?l20?n000H0003o00<0oh000000o`000?l03@000?l30?n00080
003o00<0oh00ooooooooool02?ooool000Wooooo00@0KVi^07=cL`1cLg<0QHF50P14A4@0102:RXX0
T92@092@T020P80208N7Q`04092@T01/K6`0K6a/05MGE`80LW9b00@0L71`05MGE`1GEeL0BDU90P1b
LW801021PH40QHF508F5Q@1_Kfl207]kN`0406e]K@1EEED0EEEE08>3P`80FUYJ00@0Q8B40;Ng]`2g
]kL0V9RH0P28R8P0102^[Zh0Ng]k07]kN`1kNg/20861P@0407]kN`2b/[80_;bl0;bl_0<0Ph>300@0
OGem092@T02@T900VIVI0P3De=@0102k^k/0Ti>C09>CT`10@40209>CT`0408R8R02BTY80TY:B08:2
PP80ATI600@0Ng]k08:2PP22PX80Xj>S0P2i^KT0102YZJT0/;2`0;2`/02EUID208V9R@040<W9b@2e
]KD0]KFe0:6QX@80MWIf00D0_kno0<C4a034a<@0Ogmo08J6QP0206m_K`0407QhN026QXH0QXJ609^K
V`80N7Qh00@0RHV90;^k^`2k^k/0Xj>S0P2:RXX0101YJFT0NGUi07UiN@2TY:@20;Rh^0040;Vi^@1A
DE40DE5A06YZJP80h^;R00@0QHF508J6QP26QXH0MGEe0P1VIVH0101aLG40^;Rh0;Rh^02[Zj/20;:b
/P0407IfMP2<S8`0S8b<07AdM080Zj^[00D0GemO09NGU`2GUiL0[:b/09bLW002096AT@0405IFEP1>
CTh0CTi>04i>CP80BDU900@0EEEE06IVIP1VIVH0NWYj0P1`L700101ZJVX0EUIF05IFEP2;Rh/2096A
T@0406QXJ01VIVH0IVIV059BDP80LW9b00@0RXZ:09VIV@2IVIT0VYZJ0P2WYjL0101lO7`0MGEe07Ee
M@1nOWh209:BTP040820P015ADD0ADE506ATI080JFUY00<0IFEUooooooooool010000?l20?n000T0
003o00@0oh000000o`000?l0003o0`3oP0090000o`040?n000000?l0003o0?n00080003o00@0oh00
0000o`000?l0003o0P3oP0060000o`<0oh001`000?l30?n000030000o`3oP000oh0000H0003o00<0
oh000000o`000?l00`000?l0103oP000003o0000o`3oP0030000o`<0oh000`000?l30?n000`0003o
00<0oh000000o`000?l01P000?l40?n00080003o00<0oh000000o`000?l01@000?l20?n000030000
o`3oP000oh0000d0003o203oP0050000o`80oh001P000?l00`3oP000003o0000o`0=0000o`80oh00
10000?l:ooooo`002Oooool0101^KVh0Lg=c07=cL`25QHD204A4A00408Z:RP2@T900T92@0820P080
QhN700@0T92@06a/K01/K6`0EeMG0P1bLW80101`L700EeMG05MGE`19BDT2079bLP040861P@25QHD0
QHF506m_K`80Ng]k00@0KFe]05EEE@1EEED0Ph>30P1JFUX01024Q8@0]kNg0;Ng]`2HV9P208R8R004
0:j^[P1kNg/0Ng]k07]kN`80PH6100@0Ng]k0;:b/P2l_;`0_;bl0`23Ph<0101mOGd0T92@092@T02I
VIT20=CDe0040;^k^`2CTi<0Ti>C0410@080Ti>C00@0R8R809:BTP2BTY80PX:20P16ATH0101kNg/0
PX:208:2PP2SXj<20;Vi^@040:VYZ@2`/;00/;2`09FEU@80RHV900@0bLW90;Fe]@2e]KD0XJ6Q0P1f
MWH01@2o_kl0a<C40<C4a01oOgl0QXJ60080Kfm_00@0N7Qh08J6QP26QXH0Vi^K0P1hN7P01029RHT0
^k^k0;^k^`2SXj<208Z:RP0406UYJ@1iNGT0NGUi0:BTY080^;Rh00@0^KVi055AD@1ADE40JVYZ0P3R
h^801025QHD0QXJ608J6QP1eMGD206IVIP04075aL@2h^;P0^;Rh0:^[Z`80/[:b00@0MWIf08b<S02<
S8`0M7Ad0P2[Zj/01@1OGel0UiNG09NGU`2/[:`0W9bL0080TI6A00@0EUIF04i>CP1>CTh0CTi>0P19
BDT0101EEED0IVIV06IVIP1jNWX2071`L00406YZJP1FEUH0EUIF08^;R`80TI6A00@0J6QX06IVIP1V
IVH0DU9B0P1bLW80102:RXX0VIVI09VIV@2JVYX20:NWY`0407alO01eMGD0MGEe07inOP80TY:B00@0
P82004E5A@15ADD0I6AT0P1YJFT00`1UIFGoooooooooo`040000o`80oh002@000?l0103oP000003o
0000o`000?l30?n000T0003o00@0oh000000o`000?l0oh000P000?l0103oP000003o0000o`000?l2
0?n000H0003o0`3oP0070000o`<0oh0000<0003o0?n0003oP0001P000?l00`3oP000003o0000o`03
0000o`040?n000000?l0003o0?n000<0003o0`3oP0030000o`<0oh0030000?l00`3oP000003o0000
o`060000o`@0oh000P000?l00`3oP000003o0000o`050000o`80oh0000<0003o0?n0003oP0003@00
0?l80?n000D0003o0P3oP0060000o`030?n000000?l0003o00d0003o0P3oP0040000o`[ooooo0009
ooooo`0407IfMP20P800P82008J6QP80BTY:00@0SXj>09RHV02HV9P0RXZ:0P2FUYH0102HV9P0NGUi
07UiN@1EEED207alO00406MWI`1:BTX0BTY:0451@@80K6a/00@0TI6A08R8R028R8P0LG5a0P1_Kfl0
101@D500Cdm?04m?C`1MGEd205ADE00406QXJ02RXZ80XZ:R08n?S`80PX:200@0Y:BT07=cL`1cLg<0
Ogmo0P1kNg/01@1WIfL0[:b/0:NWY`2WYjL0KVi^0080Ogmo00@0LW9b0820P020P800WYjN0P3Jf]X0
1035aLD0TY:B09:BTP1MGEd20:VYZ@0409RHV02MWId0WIfM08N7Q`80B4Q800@0NWYj08Z:RP2:RXX0
Zj^[0P33`l<0102g]kL0[Jf]0:f][@2ATI420820P0040<C4a02c/k<0/k>c0::RXP80QXJ600<0`/;2
0<C4a034a<@00P29RHT207alO0040820P028R8P0R8R809RHV080Ph>300@0MgMg0:j^[P2^[Zh0];Bd
0P2ATI40101gMgL0O7al07alO02k^k/20;Rh^0040;2`/01BDU80DU9B06=SH`80gMgM00@0TY:B08Z:
RP2:RXX0OGem0P1iNGT0101nOWh0^k^k0;^k^`2d];@20:FUY@0406i^KP1mOGd0OGem07AdM080TI6A
00D0FEUI08b<S02<S8`0Ti>C06MWI`0209NGU`0405MGE`1;Bd/0Bd];0451@@80A4A400@0Fe]K071`
L01`L700O7al0P1^KVh0101JFUX0EeMG05MGE`1oOgl208F5Q@0405UIF@1MGEd0GEeM04m?C`80KFe]
00@0P820061PH01PH600L71`0P2LW9`0101TI6@0OGem07emO@1fMWH208f=S@0407MgM`11@D40@D51
06ATI080LW9b00<0Lg=cooooooooool010000?l20?n000T0003o00@0oh000000o`000?l0003o0`3o
P0080000o`D0oh0060000?l30?n000030000o`3oP000oh0000H0003o00<0oh000000o`000?l00`00
0?l40?n000<0003o0`3oP0030000o`<0oh0030000?l30?n000@0003o1P3oP0020000o`030?n00000
0?l0003o00D0003o0`3oP0080000o`030?n000000?l0003o00@0003o203oP0040000o`<0oh000`00
0?l40?n000l0003o0P3oP0040000o`[ooooo0009ooooo`04075aL@23Ph<0Ph>308J6QP80Cdm?00@0
RHV909FEU@2EUID0R8R80P2DU9@0102FUYH0Lg=c07=cL`1CDe<208^;R`0407AdM01ADE40DE5A0451
@@80IVIV00@0MgMg07]kN`1kNg/0KFe]0P1bLW801019BDT0D51@051@D01OGel2061PH00407emO@2h
^;P0^;Rh0:NWY`80Ph>300@0^[Zj0820P020P800QhN70P2?Shl01@1`L700ZZZZ0;2`/02`/;00MWIf
0080Ti>C00@0HF5Q075aL@1aLG40VYZJ0P3Cdm<0102f][H0VYZJ09ZJVP1RHV820:6QX@0409ZJVP2F
UYH0UYJF08N7Q`80Bd];00@0O7al096AT@2ATI40[Jf]0P2/[:`0102_[jl0Xj>S0:>SX`28R8P208Z:
RP040<S8b02^[Zh0[Zj^09ZJVP80Rh^;00D0alO70<c<c03<c<`0Shn?08R8R00207IfMP0406m_K`2A
TI40TI6A0:FUY@80TY:B00@0RHV90<;2`P32`/80/;2`0P2ATI401020P800Lg=c07=cL`2h^;P20;Bd
]0040:j^[P0k>c/0>c/k06EUI@80g=cL00@0VIVI09FEU@2EUID0T92@0P1_Kfl0101lO7`0`<300<30
`02o_kl20:FUY@0407MgM`28R8P0R8R808>3P`80PX:200D0MgMg09^KV`2KVi/0YZJV06i^KP0209:B
TP0404i>CP1BDU80DU9B03dm?@80ATI600@0H61P07UiN@1iNGT0QhN70P1dM7@0101LG5`0JFUY06UY
J@27QhL208j>SP0405UIF@1LG5`0G5aL04Y:BP80EUIF00@0MGEe08J6QP26QXH0QHF50P2YZJT0101_
Kfl0MWIf07IfMP1mOGd209BDU00406=SH`11@D40@D5106=SH`80EEEE00<0I6ATooooooooool01000
0?l20?n000T0003o00@0oh000000o`000?l0003o0`3oP0080000o`80oh001@000?l0103oP000003o
0000o`000?l20?n000L0003o0P3oP0070000o`<0oh002@000?l0103oP000003o0000o`000?l20?n0
00030000o`3oP000oh0000@0003o0`3oP0030000o`<0oh0030000?l30?n000@0003o1P3oP0020000
o`030?n000000?l0003o00D0003o0`3oP00?0000o`H0oh001P000?l00`3oP000003o0000o`030000
o`H0oh003@000?l20?n000040000o`3oP000oh000000o`[ooooo0009ooooo`04075aL@23Ph<0Ph>3
08J6QP80Cdm?00@0RHV909FEU@2EUID0R8R80P2DU9@0102FUYH0Lg=c07=cL`1CDe<208^;R`0407Ad
M01ADE40DE5A0451@@80IVIV00@0MgMg07]kN`1kNg/0KFe]0P1bLW801019BDT0D51@051@D01OGel2
061PH00407emO@2h^;P0^;Rh0:NWY`80Ph>300@0^[Zj0820P020P800QhN70P2?Shl01@1`L700ZZZZ
0;2`/02`/;00MWIf0080Ti>C00@0HF5Q075aL@1aLG40VYZJ0P3Cdm<0102f][H0VYZJ09ZJVP1RHV82
0:6QX@0409ZJVP2FUYH0UYJF08N7Q`80Bd];00@0O7al096AT@2ATI40[Jf]0P2/[:`0102_[jl0Xj>S
0:>SX`28R8P208Z:RP040<S8b02^[Zh0[Zj^09ZJVP80Rh^;00D0alO70<c<c03<c<`0Shn?08R8R002
07IfMP0406m_K`2ATI40TI6A0:FUY@80TY:B00@0RHV90<;2`P32`/80/;2`0P2ATI401020P800Lg=c
07=cL`2h^;P20;Bd]0040:j^[P0k>c/0>c/k06EUI@80g=cL00@0VIVI09FEU@2EUID0T92@0P1_Kfl0
101lO7`0`<300<30`02o_kl20:FUY@0407MgM`28R8P0R8R808>3P`80PX:200D0MgMg09^KV`2KVi/0
YZJV06i^KP0209:BTP0404i>CP1BDU80DU9B03dm?@80ATI600@0H61P07UiN@1iNGT0QhN70P1dM7@0
101LG5`0JFUY06UYJ@27QhL208j>SP0405UIF@1LG5`0G5aL04Y:BP80EUIF00@0MGEe08J6QP26QXH0
QHF50P2YZJT0101_Kfl0MWIf07IfMP1mOGd209BDU00406=SH`11@D40@D5106=SH`80EEEE00<0I6AT
ooooooooool010000?l20?n000T0003o00@0oh000000o`000?l0003o0`3oP0080000o`80oh001@00
0?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0070000o`<0oh002@000?l0103oP000003o
0000o`000?l20?n000030000o`3oP000oh0000@0003o0`3oP0030000o`<0oh0030000?l30?n000@0
003o1P3oP0020000o`030?n000000?l0003o00D0003o0`3oP00?0000o`H0oh001P000?l00`3oP000
003o0000o`030000o`H0oh003@000?l20?n000040000o`3oP000oh000000o`[ooooo0009ooooo`04
069RHP1lO7`0O7al07emO@80BTY:00@0QHF509ZJVP2JVYX0TI6A0P2IVIT0102DU9@0NWYj07YjNP1A
DE4207alO00406i^KP1PH600H61P04a<C080L71`00@0SHf=08n?S`2?Shl0NWYj0P1iNGT01019BDT0
EeMG05MGE`1[Jf/206QXJ00408F5Q@2c/k<0/k>c09fMW@80Ogmo00@0_kno08^;R`2;Rh/0Shn?0P22
PX801@1`L700WinO0:BTY02TY:@0OWin0080QXJ600@0Hf=S06a/K01/K6`0XZ:R0P3EeMD0102YZJT0
XJ6Q0:6QX@1WIfL209ZJVP040:NWY`20P800P82008>3P`80CTi>00@0PH6109FEU@2EUID0YJFU0P2V
YZH0102l_;`0XZ:R0::RXP2BTY8206a/K0040;Zj^P2WYjL0YjNW08j>SP80Ph>30`2o_kl01@21PH40
N7Qh07AdM01dM7@0JVYZ0080Ph>300@0TY:B08j>SP2>SXh0R8R80P2m_Kd0102YZJT0PX:208:2PP1k
Ng/206IVIP040;Zj^P2^[Zh0[Zj^0:VYZ@809RHV00@0KFe]0=kNgP3Ng]h0Q8B40P2RXZ801022PX80
JFUY06UYJ@1`L7020:b/[0040:JVYP2JVYX0VYZJ08F5Q@80Ogmo00@0S8b<07UiN@1iNGT0K6a/0P23
Ph<01@2PX:00LG5a09VIV@2IVIT0GUiN0080K6a/00@0@41004m?C`1?Cdl0HF5Q0P26QXH0102DU9@0
MGEe07EeM@1QHF42069RHP0408b<S02QXJ40XJ6Q05ADE080GEeM00@0EUIF06QXJ01XJ6P0OWin0P1m
OGd01023Ph<0[jn_0:n_[`1eMGD207YjNP0408>3P`29RHT0RHV907EeM@80EUIF00@0KVi^06EUI@1U
IFD0GUiN0_ooool40000o`80oh002@000?l00`3oP000003o0000o`030000o`030?n000000?l0003o
00H0003o0P3oP0050000o`040?n000000?l0003o0000o`80oh0040000?l20?n000X0003o00<0oh00
0000o`000?l010000?l20?n000@0003o0P3oP0040000o`<0oh0030000?l00`3oP000003o0000o`04
0000o`<0oh000P000?l0103oP000003o0000o`3oP00I0000o`80oh0000@0003o0?n0003oP000oh00
30000?l40?n000H0003o0P3oP0070000o`80oh000`000?l00`3oP03oooooooooo`08ooooo`002Ooo
ool0101MGEd0PH610861P@1oOgl205=CD`03079bLP2<S8`0S8b<00<0SXj>00@0OWin06YZJP1ZJVX0
DU9B0P1mOGd0101OGel0IVIV06IVIP1GEeL207]kN`0408R8R02GUiL0UiNG07IfMP80P82000@0G5aL
05mOG`1OGel0MWIf0P1WIfL0102:RXX0/K6a0;6a/@2QXJ4208Z:RP030;^k^`22PX80PX:200<0PH61
00D0L71`09bLW02e]KD0]KFe08V9R@0209bLW00404i>CP1QHF40HF5Q09RHV080b<S800@0ZJVY09RH
V02HV9P0L71`0P2GUiL0102a/K40PX:208:2PP1`L702059BDP04079bLP2GUiL0UiNG08n?S`80Y:BT
00@0^[Zj0:ZZZP2ZZZX0UYJF0P1mOGd0102l_;`0TY:B09:BTP2?Shl208f=S@050;Ng]`37alL0alO7
08b<S01dM7@00P1mOGd0101^KVh0TY:B09:BTP2KVi/209bLW00408J6QP2n_[h0_[jn0:b/[080PX:2
00@0M7Ad05mOG`1OGel0]kNg0P2SXj<0102XZ:P0;Rh^02h^;P1]KFd20=CDe00407]kN`2GUiL0UiNG
0861P@80KFe]00@0Lg=c0;jn_P2n_[h0_kno0P2WYjL0102i^KT0MGEe07EeM@2>SXh208Z:RP050861
P@20P800P82008>3P`2;Rh/00P2HV9P0101/K6`0GUiN05iNGP0m?Cd2051@D00405YJFP1XJ6P0J6QX
08^;R`80QXJ600@0IfMW05eMG@1MGEd0QhN70P1nOWh0101HF5P0EEEE05EEE@17AdL205aLG00406m_
K`1iNGT0NGUi08^;R`80[Zj^00<0O7al07moO`1oOgl0101iNGT204Q8B0<0GemO00@0KFe]oooooooo
ool0oh000`000?l20?n000T0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`060000
o`030?n000000?l0003o00@0003o00@0oh000000o`000?l0003o0P3oP0070000o`80oh000`000?l0
103oP000003o0000o`000?l20?n000D0003o0P3oP0030000o`030?n000000?l0003o00@0003o0P3o
P0040000o`80oh0010000?l30?n000`0003o00<0oh000000o`000?l010000?l20?n000<0003o00@0
oh000000o`000?l0oh001`000?l30?n00080003o00<0oh000000o`000?l030000?l60?n000D0003o
0P3oP0030000o`H0oh0010000?l20?n000L0003o0P3oP0040000o`[ooooo0009ooooo`0405eMG@21
PH40PH6107moO`80De=C00<0LW9b08b<S02<S8`00`2>SXh0101nOWh0JVYZ06YZJP1BDU8207emO@04
05mOG`1VIVH0IVIV05MGE`80Ng]k00@0R8R809NGU`2GUiL0MWIf0P20P800101LG5`0GemO05mOG`1f
MWH206MWI`0408Z:RP2a/K40/K6a0:6QX@80RXZ:00<0^k^k08:2PP22PX800`21PH401@1`L700W9bL
0;Fe]@2e]KD0RHV90080W9bL00@0CTi>065QH@1QHF40V9RH0P38b<P0102YZJT0V9RH09RHV01`L702
09NGU`040;6a/@22PX80PX:2071`L080DU9B00@0LW9b09NGU`2GUiL0Shn?0P2TY:@0102j^[X0ZZZZ
0:ZZZP2FUYH207emO@040;bl_02BTY80TY:B08n?S`80SHf=00D0]kNg0<O7a`37alL0S8b<07AdM002
07emO@0406i^KP2BTY80TY:B09^KV`80W9bL00@0QXJ60;jn_P2n_[h0[:b/0P22PX80101dM7@0GemO
05mOG`2g]kL20:>SX`040:RXZ00^;Rh0;Rh^06e]K@80e=CD00@0Ng]k09NGU`2GUiL0PH610P1]KFd0
101cLg<0_[jn0;jn_P2o_kl20:NWY`040;Vi^@1eMGD0MGEe08j>SP80RXZ:00D0PH610820P020P800
Ph>308^;R`0209RHV00406a/K01NGUh0GUiN03dm?@80D51@00@0FUYJ06QXJ01XJ6P0Rh^;0P26QXH0
101WIfL0GEeM05eMG@27QhL207inOP0405QHF01EEED0EEEE04M7A`80G5aL00@0Kfm_07UiN@1iNGT0
Rh^;0P2^[Zh00`1lO7`0Ogmo07moO`0407UiN@80B4Q80`1OGel0101]KFgoooooooooo`3oP0030000
o`80oh002@000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00H0003o00<0oh000000
o`000?l010000?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0030000o`040?n000000?l0
003o0000o`80oh001@000?l20?n000<0003o00<0oh000000o`000?l010000?l20?n000@0003o0P3o
P0040000o`<0oh0030000?l00`3oP000003o0000o`040000o`80oh000`000?l0103oP000003o0000
o`3oP0070000o`<0oh000P000?l00`3oP000003o0000o`0<0000o`H0oh001@000?l20?n000<0003o
1P3oP0040000o`80oh001`000?l20?n000@0003o2_ooool000Wooooo00@0IFEU08b<S02<S8`0Q8B4
0P1BDU80101lO7`0X:2P0:2PX02MWId209>CT`0408R8R01iNGT0NGUi065QH@80O7al00@0JVYZ06IV
IP1VIVH0FUYJ0P1[Jf/0101cLg<0Ph>308>3P`1?Cdl20820P00405YJFP1=CDd0CDe=06m_K`80Hf=S
00@0RXZ:0:f][@2][Jd0VYZJ0P26QXH0102`/;00Ph>308>3P`2@T90207moO`0506EUI@2?Shl0[:b/
0:b/[02FUYH00P2OWil0101FEUH0KFe]06e]K@2_[jl20<g=c@040;Ng]`2e]KD0]KFe07MgM`80V9RH
00@0`<3007moO`1oOgl0MgMg0P1@D5001024Q8@0Xj>S0:>SX`2KVi/20;>c/`040<C4a02`/;00/;2`
0:b/[080PX:200@0bLW909jNWP2NWYh0SHf=0P2BTY801@2ZZZX0_;bl0;bl_028R8P0H61P0080Lg=c
00@0JFUY07emO@1mOGd0TI6A0P2IVIT0102?Shl0`/;20<;2`P2VYZH207emO@0407YjNP1HF5P0F5QH
0;Zj^P80YjNW00@0/;2`03hn?P0n?Sh0KFe]0P3Lg=`01025QHD0XJ6Q0:6QX@1gMgL3075aL@80_;bl
00@0^KVi0:NWY`2WYjL0/[:b0P2;Rh/0102NWYh0Q8B408B4Q01WIfL207inOP0507AdM02FUYH0U9BD
09BDU01ZJVX00P19BDT0100e=CD0B4Q804Q8B01JFUX205IFEP0407UiN@1nOWh0OWin06YZJP80GEeM
00@0Rh^;08f=S@2=SHd0IFEU0P1XJ6P0101`L700Kfm_06m_K`1lO7`209BDU00409>CT`2c/k<0/k>c
08N7Q`<0Ph>30P26QXH0101YJFT0CDe=04e=C@1QHF4205MGE`0306][Jooooooooooo00@0003o0P3o
P00?0000o`030?n000000?l0003o00<0003o00<0oh000000o`000?l00P3oP0050000o`040?n00000
0?l0003o0000o`80oh0030000?l00`3oP000003o0000o`050?n000<0003o0P3oP0030000o`030?n0
00000?l0003o00<0003o103oP0030000o`80oh001P000?l00`3oP000003o0000o`0:0000o`030?n0
00000?l0003o00<0003o0`3oP00010000?l0oh000?n0003oP0020000o`030?n000000?l0003o00D0
003o0`3oP0020000o`030?n000000?l0003o00`0003o1`3oP0040000o`80oh003@000?l20?n000L0
003o0P3oP00010000?l0oh000?n000000?l:ooooo`002Oooool0101`L700SHf=08f=S@1lO7`2055A
D@04071`L02BTY80TY:B09:BTP80VIVI00@0TY:B07emO@1mOGd0GemO0P1hN7P306EUI@04051@D01D
E5@0E5AD04=3@`80PX:200@0Jf][07QhN01hN7P0@T920P0h>3P0101ZJVX0GEeM05eMG@1cLg<20:JV
YP0409fMW@1kNg/0Ng]k0:f][@80Ph>300D0PX:20861P@21PH40KFe]09BDU0020;6a/@0408^;R`2F
UYH0UYJF055AD@80E5AD00@0T92@0:JVYP2VYZH0UYJF0P2EUID0101^KVh0OWin07inOP2RXZ8207Qh
N00407UiN@1CDe<0De=C08^;R`80][Jf00@0UIFE0:n_[`2_[jl0aLG50P2TY:@0102LW9`0QhN708N7
Q`3Hf=P20:f][@0408n?S`2@T900T92@0;Vi^@80d=3@00D0Xj>S07]kN`1oOgl0Ogmo07IfMP0208b<
S00407YjNP2?Shl0Shn?08>3P`80Z:RX00@0UYJF07=cL`1cLg<0IFEU0P1=CDd0102ZZZX0][Jf0;Jf
]P2^[Zh204=3@`0406m_K`3Jf]X0f][J07UiN@80UiNG00@0MGEe06a/K01/K6`0Jf][0P2c/k<0102o
_kl0Y:BT0:BTY02CTi<209:BTP0408Z:RP2EUID0UIFE06m_K`80UYJF00D0Kfm_0:JVYP2GUiL0UiNG
07YjNP0205UIF@0403/k>`1ADE40DE5A04m?C`80HF5Q00@0KFe]06a/K01/K6`0Kfm_0P1TI6@0102:
RXX0Q8B408B4Q01aLG4206e]K@04069RHP24Q8@0Q8B40861P@80S8b<00@0QhN70;Jf]P2f][H0P820
0P23Ph<01026QXH0U9BD09BDU01[Jf/20492@P0405MGE`1PH600H61P05ADE0;ooooo10000?l20?n0
00l0003o103oP0050000o`80oh000P000?l00`3oP000003o0000o`040000o`80oh001`000?l20?n0
00<0003o0`3oP00=0000o`040?n000000?l0003o0?n00080003o0`3oP0040000o`<0oh000`000?l3
0?n00180003o00<0oh000000o`000?l0103oP0020000o`030?n000000?l0003o00D0003o0`3oP00A
0000o`H0oh0050000?l20?n000L0003o0`3oP0020000o`030?n00?oooooooooo00Sooooo0009oooo
o`04071`L02=SHd0SHf=07alO080DE5A00@0L71`09:BTP2BTY80TY:B0P2IVIT0102BTY80OGem07em
O@1OGel207QhN0<0IFEU00@0D51@05ADE01DE5@0@d=30P22PX80101[Jf/0N7Qh07QhN012@T8203Ph
>00406YZJP1MGEd0GEeM07=cL`80YZJV00@0WIfM07]kN`1kNg/0[Jf]0P23Ph<01@22PX80PH610861
P@1]KFd0U9BD0080/K6a00@0Rh^;09JFUP2FUYH0DE5A0P1DE5@0102@T900YZJV0:JVYP2FUYH209FE
U@0406i^KP1nOWh0OWin0::RXP80N7Qh00@0NGUi05=CD`1CDe<0Rh^;0P2f][H0102EUID0[jn_0:n_
[`35aLD20:BTY00409bLW027QhL0QhN70=SHf080[Jf]00@0Shn?092@T02@T900^KVi0P3@d=001@2S
Xj<0Ng]k07moO`1oOgl0MWIf0080S8b<00@0NWYj08n?S`2?Shl0Ph>30P2XZ:P0102FUYH0Lg=c07=c
L`1UIFD204e=C@040:ZZZP2f][H0][Jf0:j^[P80@d=300@0Kfm_0=[JfP3Jf]X0NGUi0P2GUiL0101e
MGD0K6a/06a/K01[Jf/20;>c/`040;no_`2TY:@0Y:BT09>CT`80TY:B00@0RXZ:09FEU@2EUID0Kfm_
0P2FUYH01@1_Kfl0YZJV09NGU`2GUiL0NWYj0080FEUI00@0>c/k055AD@1ADE40Cdm?0P1QHF40101]
KFd0K6a/06a/K01_Kfl206ATI00408Z:RP24Q8@0Q8B4075aL@80KFe]00@0HV9R08B4Q024Q8@0PH61
0P2<S8`01027QhL0][Jf0;Jf]P20P80208>3P`0408J6QP2DU9@0U9BD06][J`80@T9200@0EeMG061P
H01PH600E5AD0_ooool40000o`80oh003`000?l40?n000D0003o0P3oP0020000o`030?n000000?l0
003o00@0003o0P3oP0070000o`80oh000`000?l30?n000d0003o00@0oh000000o`000?l0oh000P00
0?l30?n000@0003o0`3oP0030000o`<0oh004P000?l00`3oP000003o0000o`040?n00080003o00<0
oh000000o`000?l01@000?l30?n00140003o1P3oP00D0000o`80oh001`000?l30?n00080003o00<0
oh00ooooooooool02?ooool000Wooooo00@0L71`08R8R028R8P0Ti>C0P1IFET0101oOgl0UYJF09JF
UP2FUYH209NGU`0408f=S@1mOGd0OGem05]KF`80KVi^00@0L71`06m_K`1_Kfl0MWIf0P23Ph<0101Y
JFT0P8200820P01/K6`206UYJ@0404E5A@0f=SH0=SHf079bLP80Lg=c00@0S8b<0:NWY`2WYjL0S8b<
0P1`L7000`2d];@0U9BD09BDU00308R8R00506=SH`2?Shl0/k>c0;>c/`2ATI400P2HV9P0101OGel0
Hf=S06=SH`2/[:`20;Fe]@040;>c/`2UYJD0YJFU08B4Q080QXJ600@0/K6a0820P020P800NWYj0P1@
D5001024Q8@0WinO09nOW`2=SHd20;jn_P040<G5a@2RXZ80XZ:R09NGU`80PH6100@0f=SH0:f][@2]
[Jd0V9RH0P2KVi/01@2j^[X0clo?0<o?c`2ZZZX0MWIf0080MgMg00@0IVIV09>CT`2CTi<0PH610P2I
VIT0102>SXh0[Zj^0:j^[P2VYZH2092@T00406i^KP1FEUH0EUIF0<K6aP80^[Zj00@0[jn_04a<C01<
C4`0Jf][0P3Ng]h0101fMWH0Zj^[0:^[Z`29RHT206a/K00406QXJ02YZJT0ZJVY0<K6aP80Zj^[00@0
O7al092@T02@T900SHf=0P2BTY801@1bLW80Ti>C09>CT`1XJ6P0ZJVY0080Xj>S00@0Lg=c04Y:BP1:
BTX0=cLg0P1<C4`0101;Bd/0NGUi07UiN@1UIFD206QXJ00406][J`1VIVH0IVIV08:2PP80NWYj00@0
JFUY06a/K01/K6`0LW9b0P23Ph<0102=SHd0Xj>S0:>SX`2XZ:P20;Zj^P0408b<S025QHD0QHF507Qh
N080Ti>C00@0OWin05IFEP1FEUH0FUYJ0P1KFe/00`1IFEWoooooooooo`040000o`80oh002@000?l0
0`3oP000003o0000o`0<0000o`80oh002@000?l20?n000L0003o0P3oP0070000o`<0oh0010000?l2
0?n000<0003o00<0oh000000o`000?l00`000?l30?n000@0003o0`3oP0030000o`<0oh0030000?l0
0`3oP000003o0000o`030000o`L0oh000P000?l00`3oP000003o0000o`070000o`030?n000000?l0
003o00l0003o1P3oP00D0000o`80oh001`000?l60?n000[ooooo0009ooooo`0407MgM`2CTi<0Ti>C
09RHV080FUYJ00@0R8R809jNWP2NWYh0XJ6Q0P2LW9`0102>SXh0MGEe07EeM@1IFET206][J`0406QX
J01RHV80HV9R06UYJ@80MGEe00@0K6a/08:2PP22PX80IVIV0P1cLg<0101HF5P0BTY:04Y:BP1VIVH2
07QhN00408j>SP2ZZZX0ZZZZ08V9R@80OGem00@0Xj>S07]kN`1kNg/0IfMW0P1gMgL01@1JFUX0QhN7
0;Rh^02h^;P0UiNG0080U9BD00@0I6AT069RHP1RHV80_kno0P2e]KD01034a<@0YjNW0:NWY`2CTi<2
07moO`040:NWY`25QHD0QHF507inOP80EEEE00@0SHf=0:VYZ@2YZJT0VYZJ0P33`l<01039bLT0Y:BT
0:BTY02IVIT20820P0040>3Ph02_[jl0[jn_0:6QX@80X:2P00D0_kno0=;BdP3Bd]80VYZJ07EeM@02
08F5Q@0406EUI@2UYJD0YJFU08>3P`80Vi^K00@0SHf=0;2`/02`/;00ZJVY0P2>SXh0101WIfL0CTi>
04i>CP2g]kL20:^[Z`040:FUY@1CDe<0De=C05YJFP80d=3@00@0KVi^0:BTY02TY:@0P8200P1^KVh0
101QHF40/[:b0;:b/P3=cLd20;:b/P0408>3P`2:RXX0RXZ:08b<S080QXJ600D0NGUi09bLW02LW9`0
HV9R09nOW`020::RXP0407=cL`18B4P0B4Q803Ph>080AdM700@0B4Q80820P020P800DU9B0P1oOgl0
101hN7P0J6QX06QXJ028R8P306i^KP80Hf=S00@0MGEe09RHV02HV9P0UYJF0P2;Rh/0102FUYH0`<30
0<30`02CTi<208b<S00408n?S`2SXj<0Xj>S09BDU080Jf][00@0JVYZ06EUI@1UIFD0IFEU0_ooool4
0000o`80oh002@000?l00`3oP000003o0000o`0<0000o`80oh003`000?l20?n000030000o`3oP000
oh0000H0003o103oP0090000o`030?n000000?l0003o00<0003o0`3oP0040000o`<0oh000`000?l3
0?n000`0003o00<0oh000000o`000?l00`000?l30?n000<0003o103oP0070000o`D0oh003`000?l6
0?n000030000o`3oP000oh000140003o0P3oP00=0000o`[ooooo0009ooooo`0407MgM`2CTi<0Ti>C
09RHV080FUYJ00@0R8R809jNWP2NWYh0XJ6Q0P2LW9`0102>SXh0MGEe07EeM@1IFET206][J`0406QX
J01RHV80HV9R06UYJ@80MGEe00@0K6a/08:2PP22PX80IVIV0P1cLg<0101HF5P0BTY:04Y:BP1VIVH2
07QhN00408j>SP2ZZZX0ZZZZ08V9R@80OGem00@0Xj>S07]kN`1kNg/0IfMW0P1gMgL01@1JFUX0QhN7
0;Rh^02h^;P0UiNG0080U9BD00@0I6AT069RHP1RHV80_kno0P2e]KD01034a<@0YjNW0:NWY`2CTi<2
07moO`040:NWY`25QHD0QHF507inOP80EEEE00@0SHf=0:VYZ@2YZJT0VYZJ0P33`l<01039bLT0Y:BT
0:BTY02IVIT20820P0040>3Ph02_[jl0[jn_0:6QX@80X:2P00D0_kno0=;BdP3Bd]80VYZJ07EeM@02
08F5Q@0406EUI@2UYJD0YJFU08>3P`80Vi^K00@0SHf=0;2`/02`/;00ZJVY0P2>SXh0101WIfL0CTi>
04i>CP2g]kL20:^[Z`040:FUY@1CDe<0De=C05YJFP80d=3@00@0KVi^0:BTY02TY:@0P8200P1^KVh0
101QHF40/[:b0;:b/P3=cLd20;:b/P0408>3P`2:RXX0RXZ:08b<S080QXJ600D0NGUi09bLW02LW9`0
HV9R09nOW`020::RXP0407=cL`18B4P0B4Q803Ph>080AdM700@0B4Q80820P020P800DU9B0P1oOgl0
101hN7P0J6QX06QXJ028R8P306i^KP80Hf=S00@0MGEe09RHV02HV9P0UYJF0P2;Rh/0102FUYH0`<30
0<30`02CTi<208b<S00408n?S`2SXj<0Xj>S09BDU080Jf][00@0JVYZ06EUI@1UIFD0IFEU0_ooool4
0000o`80oh002@000?l00`3oP000003o0000o`0<0000o`80oh003`000?l20?n000030000o`3oP000
oh0000H0003o103oP0090000o`030?n000000?l0003o00<0003o0`3oP0040000o`<0oh000`000?l3
0?n000`0003o00<0oh000000o`000?l00`000?l30?n000<0003o103oP0070000o`D0oh003`000?l6
0?n000030000o`3oP000oh000140003o0P3oP00=0000o`[ooooo0009ooooo`04079bLP27QhL0QhN7
0820P080CDe=00@0R8R809ZJVP2JVYX0UiNG0P2?Shl0102BTY80MgMg07MgM`1NGUh206][J`04071`
L01[Jf/0Jf][06=SH`80NGUi00@0G5aL0820P020P800OGem0P1ADE40100];Bd0DE5A055AD@1TI6@2
07MgM`0408J6QP2b/[80/[:b08b<S080QXJ600@0[jn_09FEU@2EUID0O7al0P1_Kfl01@1:BTX0Kfm_
0::RXP2RXZ80SXj>0080PX:200@0GEeM051@D01@D500[Jf]0P2^[Zh0102j^[X0Vi^K09^KV`2RXZ82
07QhN00409^KV`24Q8@0Q8B407AdM080Fe]K00@0P8200:b/[02/[:`0UiNG0P2m_Kd01031`L40ZJVY
0:VYZ@2KVi/207emO@040=gMg@2[Zj/0Zj^[09RHV080WYjN00D0]kNg0=3@d03@d=00WinO06e]K@02
06][J`0405IFEP2GUiL0UiNG08:2PP80VIVI00@0Rh^;0;6a/@2a/K40[Jf]0P2LW9`0101UIFD0Bd];
04];B`2n_[h20;Ng]`040<71`@1CDe<0De=C05aLG080e=CD00@0JVYZ0::RXP2RXZ80O7al0P1UIFD0
101SHf<0VIVI09VIV@2_[jl209jNWP0408N7Q`22PX80PX:20820P080UIFE00D0NGUi0:BTY02TY:@0
H61P0:VYZ@0209^KV`0406a/K010@400@41003De=@80B4Q800@0CTi>07IfMP1fMWH0Fe]K0P1aLG40
101eMGD0NGUi07UiN@2FUYH207EeM@0407UiN@1RHV80HV9R06UYJ@80P82000@0LG5a07]kN`1kNg/0
NGUi0P2JVYX0101dM7@0Ogmo07moO`1iNGT209JFUP0408f=S@1aLG40LG5a07MgM`80NWYj00<0NGUi
ooooooooool010000?l20?n000T0003o00<0oh000000o`000?l01P000?l0103oP000003o0000o`00
0?l40?n000D0003o00@0oh000000o`000?l0003o0P3oP0040000o`80oh001P000?l70?n000T0003o
00<0oh000000o`000?l00`000?l30?n000@0003o0P3oP0040000o`<0oh0010000?l20?n000H0003o
0`3oP0030000o`X0oh002@000?l00`3oP000003o0000o`0?0000o`H0oh0000<0003o0?n0003oP000
80000?l:ooooo`002Oooool0101[Jf/0TI6A096AT@1mOGd204i>CP0308>3P`2JVYX0VYZJ00<0VYZJ
00@0TI6A07MgM`1gMgL0H61P0P1dM7@0101^KVh0DU9B059BDP1`L70206e]K@0405eMG@20P800P820
07EeM@80ADE500@0EUIF04m?C`1?Cdl0E5AD0P1kNg/01029RHT0[Jf]0:f][@2?Shl2079bLP040:b/
[02PX:00X:2P08J6QP80KFe]00D0EeMG09FEU@2j^[X0^[Zj09:BTP0208>3P`0406MWI`16ATH0ATI6
0:NWY`80X:2P00@0_Kfm0:FUY@2UYJD0Xj>S0P1jNWX0102FUYH0RXZ:08Z:RP1iNGT2079bLP0408^;
R`2QXJ40XJ6Q0:FUY@80];Bd00@0^;Rh0:VYZ@2YZJT0TY:B0P1lO7`0103De=@0Zj^[0:^[Z`2SXj<2
0:JVYP050<S8b03EeMD0eMGE09bLW01hN7P00P20P800101LG5`0TY:B09:BTP27QhL20:6QX@0408R8
R02g]kL0]kNg0:BTY080Ti>C00@0GemO051@D01@D500_Kfm0P2g]kL0103?cll0EEEE05EEE@1_Kfl2
0=gMg@0407EeM@2`/;00/;2`07alO080HF5Q00@0Kfm_0:^[Z`2[Zj/0`/;20P2MWId0101hN7P0QHF5
08F5Q@2JVYX209RHV00507EeM@2PX:00X:2P05eMG@2ZZZX00P2OWil0101RHV80?3`l03`l?00h>3P2
05UIF@0405=CD`1GEeL0EeMG05]KF`80IVIV00@0KFe]05aLG01LG5`0SXj>0P1]KFd0101ADE40Lg=c
07=cL`1mOGd209VIV@0409FEU@2;Rh/0Rh^;08R8R080][Jf00@0Ph>308F5Q@25QHD0QXJ60P28R8P0
101nOWh0EUIF05IFEP1NGUh205eMG@0307=cLooooooooooo00@0003o0P3oP00=0000o`80oh000`00
0?l0103oP000003o0000o`000?l60?n000<0003o00<0oh000000o`000?l01`000?l20?n000030000
o`3oP000oh0000@0003o0P3oP0030000o`030?n000000?l0003o00d0003o0`3oP0040000o`80oh00
10000?l30?n000@0003o0P3oP0060000o`030?n000000?l0003o00<0003o1`3oP0020000o`040?n0
00000?l0003o0?n000H0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`030000o`T0
oh000P000?l20?n000<0003o00<0oh000000o`000?l01`000?l20?n000L0003o1@3oP0000`000?oo
ooooooooo`08ooooo`002Oooool0101[Jf/0TI6A096AT@1mOGd204i>CP0308>3P`2JVYX0VYZJ00<0
VYZJ00@0TI6A07MgM`1gMgL0H61P0P1dM7@0101^KVh0DU9B059BDP1`L70206e]K@0405eMG@20P800
P82007EeM@80ADE500@0EUIF04m?C`1?Cdl0E5AD0P1kNg/01029RHT0[Jf]0:f][@2?Shl2079bLP04
0:b/[02PX:00X:2P08J6QP80KFe]00D0EeMG09FEU@2j^[X0^[Zj09:BTP0208>3P`0406MWI`16ATH0
ATI60:NWY`80X:2P00@0_Kfm0:FUY@2UYJD0Xj>S0P1jNWX0102FUYH0RXZ:08Z:RP1iNGT2079bLP04
08^;R`2QXJ40XJ6Q0:FUY@80];Bd00@0^;Rh0:VYZ@2YZJT0TY:B0P1lO7`0103De=@0Zj^[0:^[Z`2S
Xj<20:JVYP050<S8b03EeMD0eMGE09bLW01hN7P00P20P800101LG5`0TY:B09:BTP27QhL20:6QX@04
08R8R02g]kL0]kNg0:BTY080Ti>C00@0GemO051@D01@D500_Kfm0P2g]kL0103?cll0EEEE05EEE@1_
Kfl20=gMg@0407EeM@2`/;00/;2`07alO080HF5Q00@0Kfm_0:^[Z`2[Zj/0`/;20P2MWId0101hN7P0
QHF508F5Q@2JVYX209RHV00507EeM@2PX:00X:2P05eMG@2ZZZX00P2OWil0101RHV80?3`l03`l?00h
>3P205UIF@0405=CD`1GEeL0EeMG05]KF`80IVIV00@0KFe]05aLG01LG5`0SXj>0P1]KFd0101ADE40
Lg=c07=cL`1mOGd209VIV@0409FEU@2;Rh/0Rh^;08R8R080][Jf00@0Ph>308F5Q@25QHD0QXJ60P28
R8P0101nOWh0EUIF05IFEP1NGUh205eMG@0307=cLooooooooooo00@0003o0P3oP00=0000o`80oh00
0`000?l0103oP000003o0000o`000?l60?n000<0003o00<0oh000000o`000?l01`000?l20?n00003
0000o`3oP000oh0000@0003o0P3oP0030000o`030?n000000?l0003o00d0003o0`3oP0040000o`80
oh0010000?l30?n000@0003o0P3oP0060000o`030?n000000?l0003o00<0003o1`3oP0020000o`04
0?n000000?l0003o0?n000H0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`030000
o`T0oh000P000?l20?n000<0003o00<0oh000000o`000?l01`000?l20?n000L0003o1@3oP0000`00
0?ooooooooooo`08ooooo`002Oooool0101gMgL0X:2P0:2PX01mOGd204m?C`04096AT@2LW9`0W9bL
0:2PX080UIFE00@0SHf=07moO`1oOgl0GemO0P1[Jf/0101fMWH0?Cdm03dm?@1[Jf/207]kN`0406UY
J@2QXJ40XJ6Q08F5Q@80MgMg00@0O7al05eMG@1MGEd0DE5A0P23Ph<01027QhL0/[:b0;:b/P2?Shl2
06a/K0040:j^[P2RXZ80XZ:R08V9R@80LW9b00D0E5AD08J6QP2e]KD0]KFe09nOW`0307EeM@80BDU9
00@0`L710;Vi^@2i^KT0a/K60P2/[:`0102TY:@0OGem07emO@2HV9P209NGU`0407IfMP1eMGD0MGEe
08V9R@80YJFU00@0[:b/0;bl_02l_;`0c/k>0P2`/;00102CTi<0O7al07alO03GemL20;2`/00409nO
W`2MWId0WIfM0;Rh^080e]KF00D0TI6A079bLP20P800P820065QH@0209VIV@0408N7Q`2HV9P0V9RH
07alO080/[:b00@0VYZJ08f=S@2=SHd0Fe]K0P1EEED01035aLD0YjNW0:NWY`2VYZH203hn?P04061P
H03GemL0emOG07AdM080^KVi00@0Ogmo07QhN01hN7P0MWIf0P2c/k<0103GemL0YJFU0:FUY@1cLg<2
096AT@040:BTY02GUiL0UiNG07YjNP80VIVI00D0G5aL0:n_[`2IVIT0VIVI06i^KP0203Xj>P0404A4
A01WIfL0IfMW07AdM080Fe]K00@0JVYZ07AdM01dM7@0NWYj0P1dM7@0102EUID0MGEe07EeM@1hN7P2
07YjNP04071`L02OWil0WinO08F5Q@80YZJV00@0WYjN0;2`/02`/;00M7Ad0P1eMGD01026QXH0N7Qh
07QhN01cLg<207AdM00407QhN01;Bd/0Bd];075aL@;ooooo10000?l20?n000d0003o0P3oP00:0000
o`<0oh000`000?l0103oP000003o0000o`000?l20?n000@0003o0P3oP0000`000?l0oh000?n00004
0000o`H0oh003`000?l40?n000<0003o0`3oP0030000o`<0oh0030000?l0103oP000003o0000o`00
0?l50?n000<0003o00@0oh000000o`000?l0oh000P000?l00`3oP000003o0000o`020000o`<0oh00
2`000?l30?n000<0003o0`3oP0030000o`030?n000000?l0003o0140003o0P3oP00:0000o`80oh00
00<0003oooooooooool02?ooool000Wooooo00@0IVIV09VIV@2IVIT0Ng]k0P1;Bd/0102CTi<0W9bL
09bLW02NWYh20:6QX@0408b<S01kNg/0Ng]k05]KF`80MWIf00@0NGUi08B4Q024Q8@0NGUi0P1gMgL0
101RHV80WIfM09fMW@1kNg/206MWI`04071`L01GEeL0EeMG04i>CP80O7al00@0QXJ60;>c/`2c/k<0
Shn?0P1jNWX0102YZJT0YJFU0:FUY@2;Rh/207=cL`0506a/K02UYJD0c<c<0<c<c02WYjL00P1nOWh0
101kNg/0Bd];04];B`2l_;`20:j^[P040<O7a`2WYjL0YjNW09BDU080QHF500@0P82007=cL`1cLg<0
JVYZ0P1eMGD01022PX80TY:B09:BTP2LW9`209nOW`040;jn_P2RXZ80XZ:R08^;R`80OWin00@0f][J
0;Bd]02d];@0V9RH0P2NWYh01@2`/;00f][J0=[JfP2DU9@0MgMg0080QHF500@0IVIV09:BTP2BTY80
QHF50P2LW9`0101oOgl0Y:BT0:BTY02RXZ820:VYZ@0406ATI01OGel0GemO0<W9b@80]kNg00@0a/K6
04I6AP16ATH0L71`0P3GemL0101fMWH0YZJV0:JVYP1lO7`20820P004075aL@2_[jl0[jn_0=3@d080
YZJV00@0O7al0;2`/02`/;00[jn_0P2OWil01@26QXH0[Jf]0:f][@1LG5`0];Bd0080XJ6Q00@0Ph>3
03Ti>@0i>CT0@4100P1SHf<0101]KFd0Bd];04];B`1]KFd206MWI`0407=cL`22PX80PX:209RHV080
Lg=c00@0MGEe07emO@1mOGd0PH610P2QXJ40102UYJD0WYjN09jNWP28R8P20:j^[P0406e]K@1`L700
L71`08>3P`80Ogmo00@0S8b<07AdM01dM7@0KFe]0P1NGUh00`22PX;oooooooooo`040000o`80oh00
2@000?l00`3oP000003o0000o`0=0000o`<0oh000`000?l00`3oP000003o0000o`0:0000o`80oh00
10000?l60?n00100003o0P3oP0040000o`<0oh000`000?l30?n001<0003o1P3oP0020000o`030?n0
00000?l0003o00D0003o0`3oP0030000o`<0oh000`000?l50?n000<0003o0`3oP0030000o`030?n0
00000?l0003o0140003o0P3oP00:0000o`80oh0000<0003oooooooooool02?ooool000Wooooo00@0
IVIV09VIV@2IVIT0Ng]k0P1;Bd/0102CTi<0W9bL09bLW02NWYh20:6QX@0408b<S01kNg/0Ng]k05]K
F`80MWIf00@0NGUi08B4Q024Q8@0NGUi0P1gMgL0101RHV80WIfM09fMW@1kNg/206MWI`04071`L01G
EeL0EeMG04i>CP80O7al00@0QXJ60;>c/`2c/k<0Shn?0P1jNWX0102YZJT0YJFU0:FUY@2;Rh/207=c
L`0506a/K02UYJD0c<c<0<c<c02WYjL00P1nOWh0101kNg/0Bd];04];B`2l_;`20:j^[P040<O7a`2W
YjL0YjNW09BDU080QHF500@0P82007=cL`1cLg<0JVYZ0P1eMGD01022PX80TY:B09:BTP2LW9`209nO
W`040;jn_P2RXZ80XZ:R08^;R`80OWin00@0f][J0;Bd]02d];@0V9RH0P2NWYh01@2`/;00f][J0=[J
fP2DU9@0MgMg0080QHF500@0IVIV09:BTP2BTY80QHF50P2LW9`0101oOgl0Y:BT0:BTY02RXZ820:VY
Z@0406ATI01OGel0GemO0<W9b@80]kNg00@0a/K604I6AP16ATH0L71`0P3GemL0101fMWH0YZJV0:JV
YP1lO7`20820P004075aL@2_[jl0[jn_0=3@d080YZJV00@0O7al0;2`/02`/;00[jn_0P2OWil01@26
QXH0[Jf]0:f][@1LG5`0];Bd0080XJ6Q00@0Ph>303Ti>@0i>CT0@4100P1SHf<0101]KFd0Bd];04];
B`1]KFd206MWI`0407=cL`22PX80PX:209RHV080Lg=c00@0MGEe07emO@1mOGd0PH610P2QXJ40102U
YJD0WYjN09jNWP28R8P20:j^[P0406e]K@1`L700L71`08>3P`80Ogmo00@0S8b<07AdM01dM7@0KFe]
0P1NGUh00`22PX;oooooooooo`040000o`80oh002@000?l00`3oP000003o0000o`0=0000o`<0oh00
0`000?l00`3oP000003o0000o`0:0000o`80oh0010000?l60?n00100003o0P3oP0040000o`<0oh00
0`000?l30?n001<0003o1P3oP0020000o`030?n000000?l0003o00D0003o0`3oP0030000o`<0oh00
0`000?l50?n000<0003o0`3oP0030000o`030?n000000?l0003o0140003o0P3oP00:0000o`80oh00
00<0003oooooooooool02?ooool000Wooooo00@0KFe]0::RXP2RXZ80Ng]k0P1;Bd/0102EUID0VIVI
09VIV@2NWYh20:BTY00408^;R`1iNGT0NGUi05MGE`80Ogmo00@0O7al07MgM`1gMgL0L71`0P1VIVH0
101HF5P0UIFE09FEU@1hN7P205IFEP0406][J`1KFe/0Fe]K05EEE@<0NWYj0P2b/[80102=SHd0QhN7
08N7Q`2XZ:P20:FUY@0508b<S01TI6@0I6AT05QHF02IVIT00P3>c/h0102RXZ80NWYj07YjNP1iNGT2
04I6AP040;bl_02TY:@0Y:BT0;jn_P80YZJV00@0Ogmo07]kN`1kNg/0OWin0P20P800101hN7P0R8R8
08R8R02=SHd208b<S00409:BTP2f][H0][Jf0<c<c080]KFe00@0VIVI07QhN01hN7P0fm_K0P2f][H0
102GUiL0X:2P0:2PX02h^;P20=CDe0050::RXP1fMWH0S8b<08b<S01WIfL00P2FUYH01027QhL0XJ6Q
0:6QX@2;Rh/20:n_[`040:NWY`2ATI40TI6A05UIF@80GUiN00@0Zj^[0:j^[P2^[Zh0^k^k0P0j>SX0
101jNWX0e=CD0=CDe01iNGT20;Fe]@0407MgM`24Q8@0Q8B407inOP80[Jf]00@0fm_K0:FUY@2UYJD0
NWYj0P2BTY80102XZ:P0VIVI09VIV@24Q8@209>CT`0505YJFP2n_[h0UIFE09FEU@1nOWh00P0e=CD0
100m?Cd0G5aL05aLG01KFe/204a<C00405=CD`1@D500D51@05YJFP80GEeM00@0MgMg05IFEP1FEUH0
Jf][0P1RHV80101/K6`0RHV908V9R@2NWYh209nOW`0408R8R02d];@0];Bd08R8R0<0QhN70P1bLW80
102?Shl0L71`071`L01cLg<206YZJP0307emOOoooooooooo00@0003o0P3oP0090000o`030?n00000
0?l0003o00H0003o00@0oh000000o`000?l0003o0P3oP00010000?l0oh000?n0003oP0030000o`03
0?n000000?l0003o00L0003o0P3oP0000`000?l0oh000?n000040000o`<0oh000P000?l00`3oP000
003o0000o`0=0000o`@0oh000`000?l30?n000<0003o0`3oP00<0000o`040?n000000?l0003o0000
o`<0oh000P000?l40?n00080003o00@0oh000000o`000?l0oh0010000?l30?n000/0003o0`3oP003
0000o`d0oh0000<0003o0?n0003oP0002P000?l20?n000d0003o2_ooool000Wooooo00@0JVYZ09JF
UP2FUYH0O7al0P15ADD0102:RXX0U9BD09BDU02FUYH20:JVYP0408>3P`1dM7@0M7Ad05UIF@80Q8B4
00@0MgMg07EeM@1eMGD0Hf=S0P1]KFd0101HF5P0S8b<08b<S01nOWh204Y:BP0405aLG01GEeL0EeMG
04a<C080MGEe00@0LG5a0:^[Z`2[Zj/0QXJ60P2?Shl0102RXZ80X:2P0:2PX023Ph<206IVIP0505MG
E`29RHT0alO70<O7a`2MWId00P1ZJVX0101RHV80@T920492@P2d];@209^KV`040;Vi^@2VYZH0YZJV
08J6QP80O7al00@0OWin07=cL`1cLg<0GemO0P20P800101lO7`0U9BD09BDU029RHT20;Fe]@040;fm
_@2a/K40/K6a09BDU080Ogmo00@0d];B0;Rh^02h^;P0ZZZZ0P2QXJ401@2j^[X0c<c<0<c<c02QXJ40
NGUi0080OWin00@0HF5Q09FEU@2EUID0T92@0P2PX:00102ATI40Zj^[0:^[Z`2VYZH208Z:RP0405=C
D`1QHF40HF5Q09NGU`80ZJVY00@0dM7A03lo?`0o?cl0TI6A0P3Ti>@0101nOWh0[:b/0:b/[01jNWX2
08>3P`0407YjNP2][Jd0[Jf]0=[JfP80Y:BT00@0VYZJ08^;R`2;Rh/0[Zj^0P2?Shl01@2GUiL0T92@
092@T01cLg<0a<C40080XZ:R00@0Ogmo03dm?@0m?Cd0@4100P1SHf<0101RHV80GemO05mOG`1WIfL2
06QXJ00407EeM@1]KFd0KFe]07inOP80H61P00@0IFEU06][J`1[Jf/0G5aL0P1iNGT0102FUYH0Rh^;
08^;R`2:RXX20;Fe]@0408B4Q01nOWh0OWin09:BTP80P82000<0QHF507AdM01dM7@00`1gMgL00`2?
Shooooooooooo`040000o`80oh002@000?l00`3oP000003o0000o`060000o`040?n000000?l0003o
0000o`H0oh003@000?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000o`030?n000000?l0
003o00d0003o103oP0030000o`<0oh000`000?l30?n00100003o0P3oP0040000o`<0oh000P000?l0
0`3oP000003o0000o`050000o`<0oh001@000?l00`3oP000003o0000o`040000o`80oh000`000?l3
0?n00100003o00<0oh000000o`000?l010000?l20?n000d0003o2_ooool000Wooooo00@0JVYZ09JF
UP2FUYH0O7al0P15ADD0102:RXX0U9BD09BDU02FUYH20:JVYP0408>3P`1dM7@0M7Ad05UIF@80Q8B4
00@0MgMg07EeM@1eMGD0Hf=S0P1]KFd0101HF5P0S8b<08b<S01nOWh204Y:BP0405aLG01GEeL0EeMG
04a<C080MGEe00@0LG5a0:^[Z`2[Zj/0QXJ60P2?Shl0102RXZ80X:2P0:2PX023Ph<206IVIP0505MG
E`29RHT0alO70<O7a`2MWId00P1ZJVX0101RHV80@T920492@P2d];@209^KV`040;Vi^@2VYZH0YZJV
08J6QP80O7al00@0OWin07=cL`1cLg<0GemO0P20P800101lO7`0U9BD09BDU029RHT20;Fe]@040;fm
_@2a/K40/K6a09BDU080Ogmo00@0d];B0;Rh^02h^;P0ZZZZ0P2QXJ401@2j^[X0c<c<0<c<c02QXJ40
NGUi0080OWin00@0HF5Q09FEU@2EUID0T92@0P2PX:00102ATI40Zj^[0:^[Z`2VYZH208Z:RP0405=C
D`1QHF40HF5Q09NGU`80ZJVY00@0dM7A03lo?`0o?cl0TI6A0P3Ti>@0101nOWh0[:b/0:b/[01jNWX2
08>3P`0407YjNP2][Jd0[Jf]0=[JfP80Y:BT00@0VYZJ08^;R`2;Rh/0[Zj^0P2?Shl01@2GUiL0T92@
092@T01cLg<0a<C40080XZ:R00@0Ogmo03dm?@0m?Cd0@4100P1SHf<0101RHV80GemO05mOG`1WIfL2
06QXJ00407EeM@1]KFd0KFe]07inOP80H61P00@0IFEU06][J`1[Jf/0G5aL0P1iNGT0102FUYH0Rh^;
08^;R`2:RXX20;Fe]@0408B4Q01nOWh0OWin09:BTP80P82000<0QHF507AdM01dM7@00`1gMgL00`2?
Shooooooooooo`040000o`80oh002@000?l00`3oP000003o0000o`060000o`040?n000000?l0003o
0000o`H0oh003@000?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000o`030?n000000?l0
003o00d0003o103oP0030000o`<0oh000`000?l30?n00100003o0P3oP0040000o`<0oh000P000?l0
0`3oP000003o0000o`050000o`<0oh001@000?l00`3oP000003o0000o`040000o`80oh000`000?l3
0?n00100003o00<0oh000000o`000?l010000?l20?n000d0003o2_ooool000Wooooo00@0OWin09bL
W02LW9`0P8200P1=CDd0102>SXh0UYJF09JFUP2IVIT20;6a/@0409>CT`1nOWh0OWin05UIF@80Rh^;
00@0Ng]k07moO`1oOgl0N7Qh0P27QhL0101QHF40TY:B09:BTP1`L702069RHP0406i^KP1BDU80DU9B
04Y:BP80NGUi00@0QXJ60:j^[P2^[Zh0RXZ:0P28R8P0102PX:00VIVI09VIV@1cLg<205]KF`0505MG
E`2>SXh0]KFe0;Fe]@2GUiL00P1VIVH0101eMGD0AdM704M7A`2WYjL209^KV`040<;2`P2/[:`0[:b/
08V9R@80MgMg00@0QHF508J6QP26QXH0MGEe0P2?Shl0101cLg<0Vi^K09^KV`2CTi<20;>c/`040<71
`@2c/k<0/k>c09^KV`80PH6100@0h>3P0;:b/P2b/[80XJ6Q0P2MWId01@2j^[X0c/k>0<k>cP2XZ:P0
MGEe0080SXj>00@0J6QX09VIV@2IVIT0S8b<0P2QXJ40102ATI40ZZZZ0:ZZZP2^[Zh209NGU`0405aL
G01gMgL0MgMg0:JVYP80[Zj^00@0clo?02l_;`0_;bl0SHf=0P3MgMd0101nOWh0/[:b0;:b/P28R8P2
07moO`0407IfMP2d];@0];Bd0=GEe@80WYjN0`2FUYH0102`/;00Ti>C09>CT`2NWYh208^;R`0507Yj
NP2o_kl0X:2P0:2PX01dM7@00P1;Bd/01013@d<0H61P061PH01RHV8205ADE00406i^KP1eMGD0MGEe
07EeM@80LG5a00@0MWIf075aL@1aLG40LW9b0P1/K6`01025QHD0UiNG09NGU`2SXj<208V9R@0408Z:
RP2a/K40/K6a09JFUP80QXJ600@0WYjN07UiN@1iNGT0R8R80P1eMGD306][J`0308Z:R_oooooooooo
00@0003o0P3oP0040000o`80oh000`000?l00`3oP000003o0000o`0=0000o`<0oh000`000?l00`3o
P000003o0000o`060000o`<0oh0000<0003o0?n0003oP00010000?l20?n000<0003o00<0oh000000
o`000?l03@000?l40?n000<0003o0`3oP0030000o`<0oh003@000?l20?n000030000o`3oP000oh00
00<0003o103oP0020000o`040?n000000?l0003o0?n000@0003o0`3oP0050000o`030?n000000?l0
003o00@0003o0P3oP0030000o`<0oh000`000?l00`3oP000003o0000o`0A0000o`80oh003@000?l:
ooooo`002Oooool0101fMWH0UiNG09NGU`21PH4205EEE@0409jNWP2SXj<0Xj>S0::RXP80]kNg00@0
UiNG07MgM`1gMgL0FUYJ0P2CTi<0101iNGT0LW9b079bLP1bLW8207MgM`0405aLG02?Shl0Shn?08B4
Q080FUYJ00@0MgMg06UYJ@1YJFT0H61P0P2?Shl0102@T900/K6a0;6a/@2HV9P209^KV`040;Rh^02/
[:`0[:b/08B4Q080JVYZ00D0GemO0:JVYP3@d=00d=3@0;6a/@0206i^KP0407QhN01CDe<0De=C0:2P
X080Ti>C00@0a<C40;6a/@2a/K40P8200P1[Jf/0101hN7P0R8R808R8R01fMWH209^KV`0406EUI@2;
Rh/0Rh^;096AT@80Xj>S00@0Y:BT0:NWY`2WYjL0SXj>0P1hN7P0103EeMD0/k>c0;>c/`2UYJD20:^[
Z`050;Zj^P3Hf=P0f=SH0:f][@1kNg/00P26QXH0101PH600UYJF09JFUP26QXH20:BTY00408^;R`2L
W9`0W9bL09VIV@80M7Ad00@0DU9B06m_K`1_Kfl0Shn?0P2VYZH01030`<00<S8b038b<P2LW9`20=SH
f00407alO02PX:00X:2P08>3P`80NWYj00@0Lg=c0;Vi^@2i^KT0dM7A0P2JVYX0101jNWX0/K6a0;6a
/@2][Jd20::RXP050:VYZ@2?Shl0Shn?0861P@2n_[h00P29RHT0101SHf<0DE5A055AD@0m?Cd2065Q
H@0405mOG`1;Bd/0Bd];065QH@80OGem00@0Jf][06UYJ@1YJFT0Lg=c0P1^KVh0101[Jf/0Lg=c07=c
L`1oOgl208Z:RP040:6QX@2FUYH0UYJF09^KV`80/[:b00@0SXj>07inOP1nOWh0PX:20P1NGUh0101U
IFD0K6a/06a/K01JFUX205aLG00307moOooooooooooo00@0003o0P3oP0040000o`80oh000`000?l0
0`3oP000003o0000o`060000o`040?n000000?l0003o0000o`80oh001`000?l0103oP000003o0000
o`000?l20?n000L0003o0`3oP0030000o`80oh000`000?l20?n001D0003o0`3oP0030000o`D0oh00
3P000?l20?n000@0003o0`3oP0020000o`030?n000000?l0003o00D0003o0`3oP0030000o`<0oh00
1P000?l20?n000<0003o0`3oP0030000o`030?n000000?l0003o0140003o0P3oP0040000o`80oh00
0`000?l30?n000030000oooooooooooo00Sooooo0009ooooo`0407IfMP2GUiL0UiNG0861P@80EEEE
00@0WYjN0:>SX`2SXj<0XZ:R0P2g]kL0102GUiL0MgMg07MgM`1JFUX209>CT`0407UiN@1bLW80LW9b
079bLP80MgMg00@0G5aL08n?S`2?Shl0Q8B40P1JFUX0101gMgL0JFUY06UYJ@1PH60208n?S`04092@
T02a/K40/K6a09RHV080Vi^K00@0^;Rh0:b/[02/[:`0Q8B40P1ZJVX01@1OGel0YZJV0=3@d03@d=00
/K6a0080KVi^00@0N7Qh05=CD`1CDe<0X:2P0P2CTi<01034a<@0/K6a0;6a/@20P80206][J`0407Qh
N028R8P0R8R807IfMP80Vi^K00@0IFEU08^;R`2;Rh/0TI6A0P2SXj<0102TY:@0YjNW0:NWY`2>SXh2
07QhN0040=GEe@2c/k<0/k>c0:FUY@80Zj^[00D0^[Zj0=SHf03Hf=P0[Jf]07]kN`0208J6QP04061P
H02FUYH0UYJF08J6QP80Y:BT00@0Rh^;09bLW02LW9`0VIVI0P1dM7@0101BDU80Kfm_06m_K`2?Shl2
0:JVYP040<30`00b<S80<S8b09bLW080f=SH00@0O7al0:2PX02PX:00Ph>30P1jNWX0101cLg<0^KVi
0;Vi^@3AdM4209ZJVP0407YjNP2a/K40/K6a0:f][@80XZ:R00D0ZJVY08n?S`2?Shl0PH610;jn_P02
08V9R@0406=SH`1ADE40DE5A03dm?@80HF5Q00@0GemO04];B`1;Bd/0HF5Q0P1mOGd0101[Jf/0JFUY
06UYJ@1cLg<206i^KP0406][J`1cLg<0Lg=c07moO`80RXZ:00@0XJ6Q09JFUP2FUYH0Vi^K0P2b/[80
102>SXh0OWin07inOP22PX8205iNGP0406EUI@1/K6`0K6a/05YJFP80G5aL00<0Ogmoooooooooool0
10000?l20?n000@0003o0P3oP0030000o`030?n000000?l0003o00H0003o00@0oh000000o`000?l0
003o0P3oP0070000o`040?n000000?l0003o0000o`80oh001`000?l30?n000<0003o0P3oP0030000
o`80oh005@000?l30?n000<0003o1@3oP00>0000o`80oh0010000?l30?n00080003o00<0oh000000
o`000?l01@000?l30?n000<0003o0`3oP0060000o`80oh000`000?l30?n000<0003o00<0oh000000
o`000?l04@000?l20?n000@0003o0P3oP0030000o`<0oh0000<0003oooooooooool02?ooool000Wo
oooo00@0LW9b09JFUP2FUYH0PX:20P1GEeL0102HV9P0UYJF09JFUP2OWil20:f][@0407EeM@1_Kfl0
Kfm_05UIF@80PX:200@0Jf][07MgM`1gMgL0NGUi0P1cLg<0101fMWH0X:2P0:2PX022PX8205=CD`04
06=SH`1]KFd0KFe]05aLG080LG5a00@0N7Qh0:JVYP2VYZH0RHV90P2ATI40102[Zj/0XJ6Q0:6QX@1f
MWH206][J`0505mOG`2[Zj/0gMgM0=gMg@2k^k/00P1XJ6P0101oOgl0D51@051@D02OWil209ZJVP04
0<30`02l_;`0_;bl08:2PP80KVi^00@0PH61096AT@2ATI40OWin0P2JVYX0101WIfL0Rh^;08^;R`2K
Vi/20;Fe]@040<;2`P2c/k<0/k>c09jNWP80Lg=c00@0^;Rh0:FUY@2UYJD0Vi^K0P2ZZZX01@2WYjL0
b/[:0<[:bP20P800LW9b0080O7al00@0JFUY0:JVYP2VYZH0SXj>0P2WYjL0102<S8`0ZZZZ0:ZZZP2S
Xj<208^;R`0405UIF@1kNg/0Ng]k0:JVYP80/K6a00@0a<C403/k>`0k>c/0YjNW0P3Ph>001022PX80
UiNG09NGU`1mOGd2079bLP04069RHP2RXZ80XZ:R0;bl_080Rh^;00@0J6QX0:n_[`2_[jl0WIfM0P2?
Shl01@2>SXh0S8b<08b<S02PX:00b<S80080RXZ:00@0Fe]K05YJFP1JFUX0@d=30P1XJ6P0101TI6@0
FEUI05UIF@1aLG4208B4Q00407]kN`1dM7@0M7Ad06IVIP80K6a/00@0Jf][07moO`1oOgl0QXJ60P2N
WYh0102XZ:P0NGUi07UiN@2CTi<20;>c/`0308n?S`1oOgl0Ogmo00<0Rh^;00@0FEUI04a<C01<C4`0
I6AT0P1VIVH00`1ZJV[oooooooooo`040000o`80oh0010000?l20?n000<0003o00<0oh000000o`00
0?l02P000?l20?n00080003o0P3oP00@0000o`<0oh000`000?l20?n000<0003o0P3oP00>0000o`@0
oh000`000?l20?n000H0003o00<0oh000000o`000?l03P000?l20?n000<0003o103oP0020000o`03
0?n000000?l0003o00L0003o00@0oh000000o`000?l0003o0P3oP0070000o`80oh0000<0003o0?n0
003oP0000`3oP0030000o`030?n000000?l0003o0140003o0P3oP0060000o`<0oh0010000?l:oooo
o`002Oooool0101JFUX0Ph>308>3P`1iNGT204Y:BP0409NGU`2KVi/0Vi^K09fMW@80UYJF00@0W9bL
07IfMP1fMWH0E5AD0P1iNGT0101lO7`0IVIV06IVIP1EEED204M7A`0405=CD`29RHT0RHV906e]K@80
@T9200@0FUYJ04a<C01<C4`0EUIF0P1cLg<0101nOWh0W9bL09bLW029RHT209NGU`040:^[Z`2XZ:P0
Z:RX07=cL`80LG5a00D0G5aL09BDU03AdM40dM7A09VIV@0206=SH`0407emO@1GEeL0EeMG09FEU@80
V9RH00@0a<C40;2`/02`/;00NWYj0P1]KFd0101aLG40Rh^;08^;R`1cLg<209RHV00407=cL`2@T900
T92@09VIV@80]KFe00@0`l?30;Bd]02d];@0WIfM0P1gMgL0103EeMD0`<300<30`02b/[820;Vi^@05
0:VYZ@3Jf]X0f][J08j>SP1oOgl00P28R8P0101ZJVX0Vi^K09^KV`26QXH20:RXZ00407inOP2VYZH0
YZJV08n?S`80PX:200@0G5aL07inOP1nOWh0Vi^K0P2^[Zh01037alL0?clo03lo?`2SXj<20>3Ph003
08f=S@2KVi/0Vi^K00<0Ogmo00@0Kfm_0;:b/P2b/[80bl_;0P2NWYh0101RHV80G5aL05aLG027QhL2
0:6QX@0508j>SP2=SHd0SHf=08n?S`2ZZZX00P24Q8@0101CDe<0AdM704M7A`0l?3`2059BDP0405QH
F01FEUH0EUIF06QXJ080NGUi00@0MGEe06YZJP1ZJVX0MWIf0P1MGEd0101ZJVX0K6a/06a/K01[Jf/2
08:2PP0408b<S01FEUH0EUIF07]kN`80Vi^K00@0M7Ad071`L01`L700RHV90P23Ph<0101RHV80Kfm_
06m_K`1bLW8207YjNP0409bLW?oooooooooo0?n000<0003o0P3oP0090000o`030?n000000?l0003o
00<0003o103oP0030000o`H0oh003@000?l20?n000030000o`3oP000oh0000@0003o0P3oP0030000
o`80oh003P000?l40?n000<0003o1P3oP0020000o`030?n000000?l0003o00h0003o0P3oP0030000
o`@0oh000P000?l00`3oP000003o0000o`050000o`<0oh000`000?l20?n000X0003o2@3oP0070000
o`80oh001`000?l20?n00100003o2_ooool000Wooooo00@0FUYJ08>3P`23Ph<0NGUi0P1:BTX0102G
UiL0Vi^K09^KV`2MWId209JFUP0409bLW01fMWH0MWIf05ADE080NGUi00@0O7al06IVIP1VIVH0EEEE
0P17AdL0101CDe<0RHV908V9R@1]KFd20492@P0405YJFP1<C4`0C4a<05IFEP80Lg=c00@0OWin09bL
W02LW9`0RHV90P2GUiL0102[Zj/0Z:RX0:RXZ01cLg<2075aL@0505aLG02DU9@0dM7A0=7Ad@2IVIT0
0P1SHf<0101mOGd0EeMG05MGE`2EUID209RHV0040<C4a02`/;00/;2`07YjNP80KFe]00@0LG5a08^;
R`2;Rh/0Lg=c0P2HV9P0101cLg<0T92@092@T02IVIT20;Fe]@040<?3``2d];@0];Bd09fMW@80MgMg
00@0eMGE0<30`030`<00/[:b0P2i^KT01@2YZJT0f][J0=[JfP2>SXh0Ogmo0080R8R800@0JVYZ09^K
V`2KVi/0QXJ60P2XZ:P0101nOWh0YZJV0:JVYP2?Shl208:2PP0405aLG01nOWh0OWin09^KV`80[Zj^
00@0alO703lo?`0o?cl0Xj>S0P3Ph>000`2=SHd0Vi^K09^KV`0307moO`0406m_K`2b/[80/[:b0<_;
b`80WYjN00@0HV9R05aLG01LG5`0QhN70P2QXJ401@2>SXh0SHf=08f=S@2?Shl0ZZZZ0080Q8B400@0
De=C04M7A`17AdL0?3`l0P1BDU80101HF5P0EUIF05IFEP1XJ6P207UiN@0407EeM@1ZJVX0JVYZ07If
MP80GEeM00@0JVYZ06a/K01/K6`0Jf][0P22PX80102<S8`0EUIF05IFEP1kNg/209^KV`0407AdM01`
L700L71`08V9R@80Ph>300@0HV9R06m_K`1_Kfl0LW9b0P1jNWX0102LW9coooooooooo`3oP0030000
o`80oh002@000?l00`3oP000003o0000o`030000o`@0oh000`000?l60?n000d0003o0P3oP0000`00
0?l0oh000?n000040000o`80oh000`000?l20?n000h0003o103oP0030000o`H0oh000P000?l00`3o
P000003o0000o`0>0000o`80oh000`000?l40?n00080003o00<0oh000000o`000?l01@000?l30?n0
00<0003o0P3oP00:0000o`T0oh001`000?l20?n000L0003o0P3oP00@0000o`[ooooo0009ooooo`04
06a/K02EUID0UIFE07inOP80DU9B00@0SXj>092@T02@T900UiNG0P2=SHd0102<S8`0Kfm_06m_K`1:
BTX206a/K00407=cL`1XJ6P0J6QX06YZJP80IfMW00@0De=C08b<S02<S8`0LW9b0P11@D40101UIFD0
AdM704M7A`19BDT206YZJP0407UiN@2RXZ80XZ:R07inOP80Vi^K00@0XJ6Q09BDU02DU9@0I6AT0P1/
K6`01@1PH600SXj>0<30`030`<00UYJF0080GUiN00@0P82005QHF01HF5P0W9bL0P2WYjL01036a/H0
ZJVY0:VYZ@1gMgL2075aL@0406e]K@22PX80PX:2075aL@80TI6A00@0KVi^08N7Q`27QhL0U9BD0P2d
];@0102RXZ80Xj>S0:>SX`2ATI4206EUI@040=;BdP2k^k/0^k^k09:BTP80[jn_00D0/;2`0>3Ph03P
h>00U9BD08V9R@0208:2PP04061PH02MWId0WIfM08F5Q@80Z:RX00@0OGem0:b/[02/[:`0Y:BT0P2<
S8`0101NGUh0Ogmo07moO`2JVYX209jNWP040=;BdP16ATH0ATI60:>SX`80hn?S00@0PH6108j>SP2>
SXh0OWin0P25QHD0101cLg<0[jn_0:n_[`3?cll20:FUY@0405EEE@1MGEd0GEeM08J6QP80VIVI00D0
RHV909JFUP2FUYH0W9bL0;^k^`0207UiN@040410@014A4@0A4A403Hf=P80G5aL00@0FUYJ069RHP1R
HV80K6a/0P1iNGT0101`L700JFUY06UYJ@1]KFd206QXJ00405aLG01/K6`0K6a/07MgM`80TY:B00@0
Rh^;069RHP1RHV80O7al0P2HV9P01023Ph<0OWin07inOP1fMWH206m_K`0406=SH`1^KVh0KVi^06m_
K`80K6a/00<0N7Qhooooooooool010000?l20?n000T0003o00<0oh000000o`000?l01P000?l0103o
P000003o0000o`000?l20?n000040000o`3oP000oh000?n00100003o0P3oP00010000?l0oh000?n0
00000?l20?n000<0003o00<0oh000000o`000?l03@000?l00`3oP000003o0000o`040000o`<0oh00
0P000?l40?n00100003o0P3oP0040000o`<0oh000P000?l00`3oP000003o0000o`050000o`<0oh00
0P000?l30?n000L0003o0P3oP0000`000?l0oh000?n000060?n000X0003o00<0oh000000o`000?l0
5P000?l:ooooo`002Oooool0101WIfL0YZJV0:JVYP1iNGT205ADE004096AT@2LW9`0W9bL0:2PX080
XZ:R00@0PX:207MgM`1gMgL0EeMG0P1jNWX0101eMGD0F5QH05QHF01bLW8206ATI004071`L028R8P0
R8R806e]K@80?Shn00@0JVYZ05IFEP1FEUH0E5AD0P1hN7P0101bLW80Vi^K09^KV`1oOgl209VIV@04
0:b/[02SXj<0Xj>S06EUI@80IVIV00D0HF5Q08^;R`33`l<0`l?3092@T00205EEE@0407YjNP1CDe<0
De=C07emO@80Ti>C00@0b<S80:n_[`2_[jl0OGem0P1_Kfl0101SHf<0Ogmo07moO`1bLW8208R8R004
071`L027QhL0QhN708b<S080]KFe00@0Zj^[09RHV02HV9P0UIFE0P1]KFd0103Jf]X0aLG50<G5a@2L
W9`207YjNP0508b<S02VYZH0YZJV07alO01gMgL00P1bLW80101KFe/0T92@092@T022PX820:JVYP04
07emO@2b/[80/[:b0:f][@80QXJ600@0I6AT08F5Q@25QHD0[Jf]0P2^[Zh0103:b/X0@4100410@02U
YJD20>CTi00408B4Q02CTi<0Ti>C08>3P`80QXJ600@0M7Ad0;Rh^02h^;P0d=3@0P2WYjL0101OGel0
TI6A096AT@2@T90209:BTP0508>3P`2KVi/0Vi^K08^;R`2h^;P00P1/K6`0101=CDd0A4A404A4A00g
=cL205MGE`0405YJFP1RHV80HV9R06MWI`80O7al00@0JFUY06e]K@1]KFd0MGEe0P1ADE40101RHV80
EeMG05MGE`1KFe/207MgM`0409ZJVP1ZJVX0JVYZ08^;R`80TI6A00<0HF5Q05iNGP1NGUh00`1WIfL0
101BDU80H61P061PH01SHf<206i^KP030820P?oooooooooo00@0003o0P3oP0090000o`040?n00000
0?l0003o0000o`80oh001`000?l20?n000040000o`3oP000oh000?n00100003o0P3oP00010000?l0
oh000?n000000?l20?n000<0003o0P3oP00>0000o`030?n000000?l0003o00@0003o0`3oP00:0000
o`80oh001P000?l30?n000@0003o1P3oP0020000o`030?n000000?l0003o00D0003o0`3oP00<0000
o`80oh0000<0003o0?n0003oP0001P3oP0080000o`80oh0000@0003o0?n0003oP000oh002@000?l2
0?n000<0003o00<0oh000000o`000?l010000?l:ooooo`002Oooool0101WIfL0YZJV0:JVYP1iNGT2
05ADE004096AT@2LW9`0W9bL0:2PX080XZ:R00@0PX:207MgM`1gMgL0EeMG0P1jNWX0101eMGD0F5QH
05QHF01bLW8206ATI004071`L028R8P0R8R806e]K@80?Shn00@0JVYZ05IFEP1FEUH0E5AD0P1hN7P0
101bLW80Vi^K09^KV`1oOgl209VIV@040:b/[02SXj<0Xj>S06EUI@80IVIV00D0HF5Q08^;R`33`l<0
`l?3092@T00205EEE@0407YjNP1CDe<0De=C07emO@80Ti>C00@0b<S80:n_[`2_[jl0OGem0P1_Kfl0
101SHf<0Ogmo07moO`1bLW8208R8R004071`L027QhL0QhN708b<S080]KFe00@0Zj^[09RHV02HV9P0
UIFE0P1]KFd0103Jf]X0aLG50<G5a@2LW9`207YjNP0508b<S02VYZH0YZJV07alO01gMgL00P1bLW80
101KFe/0T92@092@T022PX820:JVYP0407emO@2b/[80/[:b0:f][@80QXJ600@0I6AT08F5Q@25QHD0
[Jf]0P2^[Zh0103:b/X0@4100410@02UYJD20>CTi00408B4Q02CTi<0Ti>C08>3P`80QXJ600@0M7Ad
0;Rh^02h^;P0d=3@0P2WYjL0101OGel0TI6A096AT@2@T90209:BTP0508>3P`2KVi/0Vi^K08^;R`2h
^;P00P1/K6`0101=CDd0A4A404A4A00g=cL205MGE`0405YJFP1RHV80HV9R06MWI`80O7al00@0JFUY
06e]K@1]KFd0MGEe0P1ADE40101RHV80EeMG05MGE`1KFe/207MgM`0409ZJVP1ZJVX0JVYZ08^;R`80
TI6A00<0HF5Q05iNGP1NGUh00`1WIfL0101BDU80H61P061PH01SHf<206i^KP030820P?oooooooooo
00@0003o0P3oP0090000o`040?n000000?l0003o0000o`80oh001`000?l20?n000040000o`3oP000
oh000?n00100003o0P3oP00010000?l0oh000?n000000?l20?n000<0003o0P3oP00>0000o`030?n0
00000?l0003o00@0003o0`3oP00:0000o`80oh001P000?l30?n000@0003o1P3oP0020000o`030?n0
00000?l0003o00D0003o0`3oP00<0000o`80oh0000<0003o0?n0003oP0001P3oP0080000o`80oh00
00@0003o0?n0003oP000oh002@000?l20?n000<0003o00<0oh000000o`000?l010000?l:ooooo`00
2Oooool0101]KFd0[Jf]0:f][@1mOGd206MWI`0408N7Q`2OWil0WinO0:NWY`80];Bd00@0SXj>07al
O01lO7`0H61P0P29RHT0102?Shl0Fe]K05]KF`1gMgL206IVIP0407emO@2@T900T92@06m_K`80B4Q8
00@0EeMG0410@010@400AdM70P1UIFD0101`L700];Bd0;Bd]028R8P209BDU0040:JVYP2HV9P0V9RH
05aLG080I6AT00D0MgMg09^KV`3@d=00d=3@09fMW@0205aLG0040820P01HF5P0F5QH08N7Q`80UIFE
00@0bl_;0;Fe]@2e]KD0PX:20P1iNGT0101OGel0O7al07alO01dM7@208B4Q00406ATI01nOWh0OWin
08Z:RP80ZZZZ00@0V9RH08J6QP26QXH0Shn?0P1aLG40103Fe]H0_kno0;no_`2c/k<206EUI@050<O7
a`2GUiL0UiNG06IVIP1fMWH00P1hN7P0101SHf<0TY:B09:BTP20P8020:>SX`0408J6QP2ZZZX0ZZZZ
0:j^[P80Rh^;00@0HV9R08N7Q`27QhL0YjNW0P2_[jl0102m_Kd0@4100410@02RXZ820>;RhP0408n?
S`2IVIT0VIVI07emO@80Ogmo00@0Ng]k0;2`/02`/;00d=3@0P2VYZH0101TI6@0/;2`0;2`/02BTY82
0:BTY00508n?S`2XZ:P0Z:RX092@T02XZ:P00P1[Jf/0101IFET0>SXj03Xj>P1;Bd/208:2PP0406EU
I@1`L700L71`07]kN`80PX:200@0Lg=c08B4Q024Q8@0KFe]0P1`L700101cLg<0MWIf07IfMP1gMgL2
09ZJVP040;no_`1nOWh0OWin0:j^[P80/K6a00@0S8b<07EeM@1eMGD0QHF50P1nOWh0101dM7@0DE5A
055AD@1VIVH2079bLP0407YjN_oooooooooo0000o`80oh001`000?l20?n000L0003o0P3oP0070000
o`H0oh000`000?l00`3oP000003o0000o`040000o`80oh0010000?l20?n000040000o`3oP000oh00
0000o`80oh000`000?l20?n001D0003o1@3oP0000`000?l0oh000?n0000>0000o`80oh001P000?l4
0?n00080003o00<0oh000000o`000?l01@000?l30?n000<0003o0P3oP00:0000o`D0oh004`000?l0
0`3oP000003o0000o`030?n000L0003o0P3oP0040000o`[ooooo0009ooooo`0407YjNP2n_[h0_[jn
08J6QP80IFEU00@0Q8B40:2PX02PX:00YZJV0P2^[Zh0102>SXh0Ogmo07moO`1LG5`208>3P`0409>C
T`1VIVH0IVIV06=SH`80Fe]K00@0LW9b07YjNP1jNWX0@D510P14A4@0101mOGd0G5aL05aLG01HF5P3
06MWI`80Zj^[00@0QhN7092@T02@T900];Bd0P2TY:@01@1RHV80JFUY06UYJ@1aLG40Z:RX0080c<c<
00@0Xj>S06YZJP1ZJVX0SHf=0P1LG5`01021PH40XZ:R0::RXP3:b/X20;:b/P0407alO01hN7P0N7Qh
05mOG`80Ph>300@0LW9b08F5Q@25QHD0I6AT0P1hN7P0102>SXh0/k>c0;>c/`2SXj<208b<S0040:>S
X`1eMGD0MGEe0<C4a080]kNg00@0]KFe08^;R`2;Rh/0_;bl0P2c/k<01@28R8P0PX:207UiN@1iNGT0
DU9B0080P82000@0OGem09VIV@2IVIT0QXJ60P2UYJD0102][Jd0PX:208:2PP1NGUh208R8R00409ZJ
VP2a/K40/K6a0<71`@80@T9200@0XJ6Q0=SHf03Hf=P0QHF50P2>SXh0101fMWH0Ogmo07moO`1dM7@2
0:n_[`040=7Ad@2OWil0WinO06UYJ@80][Jf00@0S8b<09NGU`2GUiL0P8200P2XZ:P01@22PX80[jn_
075aL@1aLG40D51@0080?3`l00@0G5aL08B4Q024Q8@0HV9R0P2CTi<0101`L700MGEe07EeM@1iNGT2
07inOP0408>3P`1bLW80LW9b07IfMP80KFe]00@0OWin09VIV@2IVIT0/K6a0P1QHF40102CTi<0ZJVY
0:VYZ@2@T90208j>SP0409JFUP1oOgl0Ogmo08B4Q080OGem00@0Kfm_07YjNP1jNWX0Q8B40_ooool0
0`000?l0oh000?n000070000o`80oh000`000?l00`3oP000003o0000o`040000o`80oh000`000?l3
0?n000040000o`3oP000oh000?n000L0003o0P3oP0070000o`80oh0010000?l20?n000<0003o0P3o
P00>0000o`030?n000000?l0003o00@0003o1@3oP00010000?l0oh000?n0003oP0040000o`80oh00
1`000?l20?n000030000o`3oP000oh0000<0003o103oP0020000o`030?n000000?l0003o00D0003o
0`3oP0030000o`80oh001`000?l20?n000030000o`3oP000oh0000<0oh004`000?l00`3oP000003o
0000o`0@0000o`[ooooo0009ooooo`0407YjNP2n_[h0_[jn08J6QP80IFEU00@0Q8B40:2PX02PX:00
YZJV0P2^[Zh0102>SXh0Ogmo07moO`1LG5`208>3P`0409>CT`1VIVH0IVIV06=SH`80Fe]K00@0LW9b
07YjNP1jNWX0@D510P14A4@0101mOGd0G5aL05aLG01HF5P306MWI`80Zj^[00@0QhN7092@T02@T900
];Bd0P2TY:@01@1RHV80JFUY06UYJ@1aLG40Z:RX0080c<c<00@0Xj>S06YZJP1ZJVX0SHf=0P1LG5`0
1021PH40XZ:R0::RXP3:b/X20;:b/P0407alO01hN7P0N7Qh05mOG`80Ph>300@0LW9b08F5Q@25QHD0
I6AT0P1hN7P0102>SXh0/k>c0;>c/`2SXj<208b<S0040:>SX`1eMGD0MGEe0<C4a080]kNg00@0]KFe
08^;R`2;Rh/0_;bl0P2c/k<01@28R8P0PX:207UiN@1iNGT0DU9B0080P82000@0OGem09VIV@2IVIT0
QXJ60P2UYJD0102][Jd0PX:208:2PP1NGUh208R8R00409ZJVP2a/K40/K6a0<71`@80@T9200@0XJ6Q
0=SHf03Hf=P0QHF50P2>SXh0101fMWH0Ogmo07moO`1dM7@20:n_[`040=7Ad@2OWil0WinO06UYJ@80
][Jf00@0S8b<09NGU`2GUiL0P8200P2XZ:P01@22PX80[jn_075aL@1aLG40D51@0080?3`l00@0G5aL
08B4Q024Q8@0HV9R0P2CTi<0101`L700MGEe07EeM@1iNGT207inOP0408>3P`1bLW80LW9b07IfMP80
KFe]00@0OWin09VIV@2IVIT0/K6a0P1QHF40102CTi<0ZJVY0:VYZ@2@T90208j>SP0409JFUP1oOgl0
Ogmo08B4Q080OGem00@0Kfm_07YjNP1jNWX0Q8B40_ooool00`000?l0oh000?n000070000o`80oh00
0`000?l00`3oP000003o0000o`040000o`80oh000`000?l30?n000040000o`3oP000oh000?n000L0
003o0P3oP0070000o`80oh0010000?l20?n000<0003o0P3oP00>0000o`030?n000000?l0003o00@0
003o1@3oP00010000?l0oh000?n0003oP0040000o`80oh001`000?l20?n000030000o`3oP000oh00
00<0003o103oP0020000o`030?n000000?l0003o00D0003o0`3oP0030000o`80oh001`000?l20?n0
00030000o`3oP000oh0000<0oh004`000?l00`3oP000003o0000o`0@0000o`[ooooo0009ooooo`04
0820P02f][H0][Jf08R8R080Jf][00@0S8b<09jNWP2NWYh0/[:b0P2][Jd0102<S8`0Ph>308>3P`1V
IVH208J6QP0409:BTP1aLG40LG5a06UYJ@80B4Q800@0Kfm_08V9R@29RHT0>SXj0P1FEUH0101mOGd0
IfMW06MWI`1]KFd207AdM004071`L02_[jl0[jn_09>CT`80Shn?00@0WIfM09^KV`2KVi/0J6QX0P1J
FUX01@1SHf<0V9RH0<?3``33`l<0UIFE0080GUiN00@0Ogmo06ATI01TI6@0R8R80P2b/[80103Bd]80
/[:b0;:b/P2:RXX208>3P`0406=SH`2>SXh0SXj>07emO@80TI6A00@0Kfm_061PH01PH600OWin0P2Q
XJ40102GUiL0N7Qh07QhN025QHD207MgM`040=7Ad@33`l<0`l?30;Rh^080UIFE00D0WIfM0;:b/P2b
/[80S8b<08J6QP0207emO@0405iNGP2;Rh/0Rh^;07alO080Ti>C00@0N7Qh0:BTY02TY:@0/K6a0P26
QXH0101JFUX0QhN708N7Q`2QXJ420:n_[`040<[:bP1:BTX0BTY:0:NWY`80fm_K00@0MGEe08B4Q024
Q8@0P8200P25QHD0101cLg<0/K6a0;6a/@3:b/X209BDU00406][J`2n_[h0_[jn08j>SP80UYJF00D0
Q8B40:b/[02/[:`0P8200;Zj^P0206i^KP0404m?C`0l?3`0?3`l05iNGP80Ph>300@0J6QX08Z:RP2:
RXX0IVIV0P1`L700101YJFT0OGem07emO@1iNGT206][J`0406m_K`1NGUh0GUiN07=cL`80PX:200@0
VYZJ05]KF`1KFe/0U9BD0P2NWYh0101iNGT0IfMW06MWI`1lO7`206UYJ@0407alO01YJFT0JFUY06=S
H`80N7Qh00@0PX:2ooooooooool0003o0P3oP0060000o`<0oh002P000?l20?n000<0003o0`3oP007
0000o`030?n000000?l0003o00H0003o00@0oh000000o`000?l0003o0P3oP0000`000?l0oh000?n0
00040000o`@0oh005@000?l50?n000<0003o00<0oh000000o`000?l00P000?l20?n000L0003o0P3o
P0000`000?l0oh000?n000030000o`@0oh000P000?l00`3oP000003o0000o`050000o`<0oh000`00
0?l20?n000L0003o0P3oP0000`000?l0oh000?n000030?n000h0003o0P3oP0040000o`80oh004000
0?l:ooooo`002Oooool0101^KVh0ZZZZ0:ZZZP24Q8@206=SH`040861P@2XZ:P0Z:RX0<30`080Y:BT
00@0S8b<08V9R@29RHT0K6a/0P23Ph<0102NWYh0PX:208:2PP1bLW8205ADE00407moO`2MWId0WIfM
061PH080FUYJ00@0Rh^;07alO01lO7`0L71`0P1mOGd0101hN7P0]KFe0;Fe]@2GUiL209fMW@040;:b
/P2k^k/0^k^k075aL@80HF5Q00D0KVi^0:BTY03Bd]80d];B0:BTY00206EUI@040861P@1mOGd0OGem
09FEU@80];Bd00@0gMgM0;Fe]@2e]KD0Shn?0P27QhL0101QHF40SXj>08j>SP1eMGD208B4Q00406a/
K01fMWH0MWIf0:JVYP80];Bd00@0YjNW09>CT`2CTi<0UiNG0P22PX801038b<P0^KVi0;Vi^@2f][H2
09FEU@0509NGU`2][Jd0[Jf]08>3P`1lO7`00P1hN7P0101LG5`0UYJF09JFUP2BTY8209RHV00406m_
K`2QXJ40XJ6Q0:f][@80N7Qh00@0GEeM08J6QP26QXH0SXj>0P2c/k<01038b<P0Bd];04];B`2WYjL2
0>?Sh`0407=cL`2FUYH0UYJF08F5Q@80Shn?00@0Ph>30;Rh^02h^;P0fMWI0P2JVYX0101YJFT0][Jf
0;Jf]P2GUiL208b<S0050861P@2WYjL0YjNW06IVIP2k^k/00P1YJFT0100n?Sh0;2`/02`/;01ADE42
07]kN`0305QHF02ATI40TI6A00<0KVi^00@0J6QX06ATI01TI6@0LG5a0P1[Jf/0101ADE40EeMG05MG
E`1XJ6P208^;R`040:^[Z`1XJ6P0J6QX08n?S`80QhN700@0JVYZ05eMG@1MGEd0I6AT0P1]KFd0101Y
JFT0IVIV06IVIP1MGEd208Z:RP0308^;Rooooooooooo00T0003o00<0oh000000o`000?l02P000?l2
0?n000@0003o0P3oP0070000o`040?n000000?l0003o0000o`<0oh001P000?l20?n000L0003o103o
P00>0000o`030?n000000?l0003o00@0003o1@3oP0030000o`030?n000000?l0003o0080003o0P3o
P0070000o`80oh0000<0003o0?n0003oP0000`000?l40?n00080003o00<0oh000000o`000?l01@00
0?l30?n000<0003o0P3oP0070000o`80oh0000<0003o0?n0003oP0000`3oP0000`000?l0oh000?n0
000:0000o`<0oh002P000?l20?n000H0003o00@0oh000000o`000?l0003o2_ooool000Wooooo00@0
KVi^0:ZZZP2ZZZX0Q8B40P1SHf<01021PH40Z:RX0:RXZ030`<020:BTY00408b<S029RHT0RHV906a/
K080Ph>300@0WYjN08:2PP22PX80LW9b0P1DE5@0101oOgl0WIfM09fMW@1PH60205YJFP0408^;R`1l
O7`0O7al071`L080OGem00@0N7Qh0;Fe]@2e]KD0UiNG0P2MWId0102b/[80^k^k0;^k^`1aLG42065Q
H@0506i^KP2TY:@0d];B0=;BdP2TY:@00P1UIFD01021PH40OGem07emO@2EUID20;Bd]0040=gMg@2e
]KD0]KFe08n?S`80QhN700@0HF5Q08j>SP2>SXh0MGEe0P24Q8@0101/K6`0MWIf07IfMP2VYZH20;Bd
]0040:NWY`2CTi<0Ti>C09NGU`80PX:200@0b<S80;Vi^@2i^KT0][Jf0P2EUID01@2GUiL0[Jf]0:f]
[@23Ph<0O7al0080N7Qh00@0G5aL09JFUP2FUYH0TY:B0P2HV9P0101_Kfl0XJ6Q0:6QX@2][Jd207Qh
N00405eMG@26QXH0QXJ608j>SP80/k>c00@0b<S804];B`1;Bd/0YjNW0P3Shn<0101cLg<0UYJF09JF
UP25QHD208n?S`0408>3P`2h^;P0^;Rh0=WIf@80VYZJ00@0JFUY0;Jf]P2f][H0UiNG0P2<S8`01@21
PH40YjNW0:NWY`1VIVH0^k^k0080JFUY00@0?Shn02`/;00/;2`0DE5A0P1kNg/00`1HF5P0TI6A096A
T@0306i^KP0406QXJ01TI6@0I6AT075aL@80Jf][00@0DE5A05MGE`1GEeL0J6QX0P2;Rh/0102[Zj/0
J6QX06QXJ02?Shl208N7Q`0406YZJP1MGEd0GEeM06ATI080KFe]00@0JFUY06IVIP1VIVH0GEeM0P2:
RXX00`2;Rh_oooooooooo`090000o`030?n000000?l0003o00X0003o0P3oP0040000o`80oh001`00
0?l0103oP000003o0000o`000?l30?n000H0003o0P3oP0070000o`@0oh003P000?l00`3oP000003o
0000o`040000o`D0oh000`000?l00`3oP000003o0000o`020000o`80oh001`000?l20?n000030000
o`3oP000oh0000<0003o103oP0020000o`030?n000000?l0003o00D0003o0`3oP0030000o`80oh00
1`000?l20?n000030000o`3oP000oh0000<0oh0000<0003o0?n0003oP0002P000?l30?n000X0003o
0P3oP0060000o`040?n000000?l0003o0000o`[ooooo0009ooooo`0406i^KP23Ph<0Ph>306i^KP80
GEeM00@0P82009VIV@2IVIT0YZJV0P26QXH0101mOGd0NWYj07YjNP1ZJVX208j>SP0409RHV01hN7P0
N7Qh04Q8B080CDe=00@0K6a/0861P@21PH40JFUY0P1EEED0102>SXh0JFUY06UYJ@1WIfL207IfMP04
075aL@2h^;P0^;Rh092@T080WIfM00@0/K6a0;:b/P2b/[80IfMW0P1OGel01@1aLG40Y:BT0<S8b038
b<P0Zj^[0080GemO00@0PX:206m_K`1_Kfl0R8R80P2l_;`00`3Lg=`0/K6a0;6a/@030861P@0405eM
G@2<S8`0S8b<08:2PP80Q8B400@0IFEU05mOG`1OGel0S8b<0P2RXZ80102KVi/0Q8B408B4Q02?Shl2
07moO`040<K6aP2f][H0][Jf0;Zj^P80VIVI00D0YZJV09ZJVP2JVYX0Q8B4075aL@02079bLP0305EE
E@2IVIT0VIVI00<0V9RH00@0OWin0:BTY02TY:@0ZZZZ0P1aLG40101KFe/0QXJ608J6QP2NWYh20:j^
[P040<C4a019BDT0BDU90:f][@80gmoO00@0I6AT09BDU02DU9@0N7Qh0P1eMGD0101oOgl0[Zj^0:j^
[P33`l<208F5Q@0406IVIP2/[:`0[:b/09FEU@80QhN700D0Q8B408j>SP2>SXh0Fe]K0<71`@0206i^
KP0404A4A00];Bd0;Bd]05=CD`80NGUi00@0De=C08Z:RP2:RXX0LG5a0`1YJFT307AdM080KFe]00@0
IFEU071`L01`L700S8b<0P2LW9`0102RXZ80NGUi07UiN@2EUID2096AT@0407QhN01QHF40HF5Q071`
L080JVYZ00@0EEEE075aL@1aLG40DE5A0P1bLW800`2<S8coooooooooo`040000o`80oh003`000?l3
0?n000@0003o0P3oP0070000o`040?n000000?l0003o0000o`<0oh001P000?l20?n000L0003o103o
P0030000o`80oh0040000?l50?n000P0003o0P3oP00:0000o`80oh000`000?l70?n000L0003o0`3o
P00;0000o`<0oh0000<0003o0?n0003oP0000`3oP0000`000?l0oh000?n0000L0000o`040?n00000
0?l0003o0?n000<0003o2_ooool000Wooooo00@0PX:20;2`/02`/;00Q8B40P1nOWh0102JVYX0/[:b
0;:b/P2UYJD208Z:RP0407MgM`29RHT0RHV907=cL`80G5aL00@0Ng]k07inOP1nOWh0KVi^0P25QHD0
1023Ph<0QhN708N7Q`1HF5P204U9B@0408Z:RP1WIfL0IfMW05UIF@80MgMg00@0IfMW0:>SX`2SXj<0
P8200P2EUID0102^[Zh0X:2P0:2PX01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/0
1025QHD0Rh^;08^;R`28R8P20<30`0040=OGe`2f][H0][Jf08J6QP80RHV900@0GEeM08Z:RP2:RXX0
PH610P1mOGd0101fMWH0Hf=S06=SH`2RXZ820:2PX0040;2`/02GUiL0UiNG09BDU080SXj>00@0cLg=
0<30`030`<00`/;20P2TY:@01@2`/;00X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0
T92@0P2UYJD01024Q8@0X:2P0:2PX02VYZH206i^KP04069RHP1kNg/0Ng]k09RHV080[Jf]00@0emOG
04Q8B018B4P0V9RH0P3Rh^800`1lO7`0X:2P0:2PX00308R8R0040861P@2b/[80/[:b0=GEe@80Y:BT
00@0J6QX09jNWP2NWYh0QXJ60P2@T9001@2=SHd0S8b<08b<S01CDe<0/K6a0080PH6100@0GUiN03hn
?P0n?Sh0E5AD0P29RHT0101LG5`0Shn?08n?S`1eMGD2065QH@0305UIF@1]KFd0KFe]00<0OWin00@0
E5AD06ATI01TI6@0QXJ60P2ATI40102SXj<0Ph>308>3P`2CTi<208b<S00407MgM`1_Kfl0Kfm_08V9
R@80Jf][00@0F5QH05aLG01LG5`0DE5A0P1_Kfl0101^KVkoooooooooo`000?l20?n000@0003o0P3o
P0070000o`80oh002@000?l30?n00080003o0P3oP0070000o`80oh0000@0003o0?n0003oP000oh00
0`000?l50?n000@0003o103oP0030000o`80oh002P000?l20?n000@0003o1@3oP0000`000?l0oh00
0?n000050000o`80oh003`000?l40?n00080003o00<0oh000000o`000?l01@000?l30?n000/0003o
0`3oP0000`000?l0oh000?n000030?n000030000o`3oP000oh0000@0003o00<0oh000000o`000?l0
0`000?l00`3oP000003o0000o`0?0000o`@0oh000`000?l:ooooo`002Oooool01022PX80/;2`0;2`
/024Q8@207inOP0409ZJVP2b/[80/[:b0:FUY@80RXZ:00@0MgMg08V9R@29RHT0Lg=c0P1LG5`0101k
Ng/0OWin07inOP1^KVh208F5Q@0408>3P`27QhL0QhN705QHF080BDU900@0RXZ:06MWI`1WIfL0FEUI
0P1gMgL0101WIfL0Xj>S0:>SX`20P80209FEU@040:j^[P2PX:00X:2P05iNGP80FEUI00D0MGEe09VI
V@3Hf=P0f=SH0;Jf]P0205]KF`0408F5Q@2;Rh/0Rh^;08R8R080`<3000@0emOG0;Jf]P2f][H0QXJ6
0P29RHT0101MGEd0RXZ:08Z:RP21PH4207emO@0407IfMP1SHf<0Hf=S0::RXP80X:2P00@0/;2`09NG
U`2GUiL0U9BD0P2>SXh0103=cLd0`<300<30`032`/820:BTY0050;2`/02PX:00X:2P08Z:RP1bLW80
0P1fMWH0101@D500WIfM09fMW@2@T9020:FUY@0408B4Q02PX:00X:2P0:JVYP80KVi^00@0HV9R07]k
N`1kNg/0V9RH0P2][Jd0103GemL0B4Q804Q8B02HV9P20>;RhP0307alO02PX:00X:2P00<0R8R800@0
PH610;:b/P2b/[80eMGE0P2TY:@0101XJ6P0WYjN09jNWP26QXH2092@T00508f=S@2<S8`0S8b<05=C
D`2a/K400P21PH40101NGUh0?Shn03hn?P1DE5@208V9R@0405aLG02?Shl0Shn?07EeM@80HF5Q00<0
FEUI06e]K@1]KFd00`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@040:>SX`23Ph<0Ph>309>CT`80
S8b<00@0MgMg06m_K`1_Kfl0RHV90P1[Jf/0101HF5P0G5aL05aLG01ADE4206m_K`0406i^K_oooooo
oooo0000o`80oh0010000?l20?n000L0003o0P3oP0090000o`<0oh000P000?l20?n000L0003o0P3o
P00010000?l0oh000?n0003oP0030000o`D0oh0010000?l40?n000<0003o0P3oP00:0000o`80oh00
10000?l50?n000030000o`3oP000oh0000D0003o0P3oP00?0000o`@0oh000P000?l00`3oP000003o
0000o`050000o`<0oh002`000?l30?n000030000o`3oP000oh0000<0oh0000<0003o0?n0003oP000
10000?l00`3oP000003o0000o`030000o`030?n000000?l0003o00l0003o103oP0030000o`[ooooo
0009ooooo`0408J6QP2c/k<0/k>c08V9R@80TY:B00@0Vi^K0:^[Z`2[Zj/0ZJVY0P2FUYH0102=SHd0
S8b<08b<S01lO7`207]kN`<0QhN700@0Hf=S05iNGP1NGUh0M7Ad0P2OWil0101UIFD0Cdm?04m?C`23
Ph<206MWI`04055AD@1_Kfl0Kfm_06m_K`80YJFU00@0U9BD0::RXP2RXZ80Z:RX0P2KVi/01@1QHF40
CDe=04e=C@1aLG40WYjN0080b/[:00@0UIFE05EEE@1EEED0P8200P27QhL0102;Rh/0^[Zj0;Zj^P3D
e=@20:JVYP0408:2PP2>SXh0SXj>06=SH`80PH6100@0RHV908J6QP26QXH0RXZ:0P1^KVh01034a<@0
Y:BT0:BTY02d];@209jNWP0409JFUP27QhL0QhN70<71`@80aLG500@0^KVi09^KV`2KVi/0/K6a0P2V
YZH01@2=SHd0QHF50820P020P800F5QH0080X:2P00@0T92@09fMW@2MWId0Q8B40P2OWil0102UYJD0
LW9b079bLP1SHf<208:2PP0409fMW@2HV9P0V9RH0=3@d080ATI600@0RHV90=[JfP3Jf]X0Shn?0P2G
UiL01024Q8@0MWIf07IfMP1kNg/20:NWY`040=7Ad@2SXj<0Xj>S09VIV@80Z:RX00@0XZ:R09fMW@2M
WId0XZ:R0P2MWId01@1EEED0Shn?08n?S`2?Shl0EEEE0080>3Ph00@0D51@07QhN01hN7P0D51@0P25
QHD0101_Kfl0K6a/06a/K01BDU8206ATI00407inOP1dM7@0M7Ad06UYJ@80De=C00@0O7al07MgM`1g
MgL0WIfM0P20P800102OWil0Ti>C09>CT`1^KVh207AdM00409fMW@1cLg<0Lg=c065QH@80Fe]K00@0
EUIF06QXJ01XJ6P0Kfm_0_ooool00`000?l0oh000?n0000C0000o`80oh0010000?l20?n00080003o
0P3oP00<0000o`040?n000000?l0003o0000o`80oh0000<0003o0?n0003oP00010000?l30?n000d0
003o0P3oP0000`000?l0oh000?n000040000o`D0oh0000<0003o0?n0003oP0001@000?l20?n00100
003o0`3oP0020000o`030?n000000?l0003o00L0003o00<0oh000000o`000?l02@000?l0103oP000
003o0000o`000?l50?n000030000o`3oP000oh0000@0003o00<0oh000000o`000?l010000?l20?n0
0100003o0`3oP0030000o`[ooooo0009ooooo`0407emO@2YZJT0ZJVY08:2PP80WIfM00@0U9BD0:JV
YP2VYZH0Zj^[0P2CTi<01025QHD0N7Qh07QhN01lO7`207MgM`<0Ph>30`1kNg/0101gMgL0Ti>C09>C
T`1PH60204e=C@0408J6QP1KFe/0Fe]K05UIF@80IfMW00@0KFe]0:^[Z`2[Zj/0UiNG0P2TY:@0102Z
ZZX0WYjN09jNWP1UIFD205aLG00507moO`2VYZH0d];B0=;BdP2SXj<00P1PH600102=SHd0UYJF09JF
UP1mOGd20:JVYP040<[:bP28R8P0R8R806a/K080QXJ600@0IFEU08:2PP22PX80P8200P1_Kfl0101g
MgL0GUiN05iNGP30`<020::RXP040:FUY@2DU9@0U9BD096AT@80Ng]k00@0bLW90<C4a034a<@0_;bl
0P2XZ:P0102n_[h0Z:RX0:RXZ02;Rh/307inOP0405eMG@2FUYH0UYJF08^;R`80ZJVY00@0Rh^;0:>S
X`2SXj<0]kNg0P1mOGd0101/K6`0SHf=08f=S@2e]KD20:n_[`040=GEe@16ATH0ATI609nOW`80e=CD
00@0[:b/09VIV@2IVIT0RHV90P1`L7001027QhL0Y:BT0:BTY03<c<`208b<S00408J6QP2QXJ40XJ6Q
0:JVYP80QhN700D0W9bL09jNWP2NWYh0HV9R0:ZZZP0208b<S00405MGE`0i>CT0>CTi05eMG@80OWin
00@0E5AD0861P@21PH40IVIV0P1PH600101DE5@0IVIV06IVIP24Q8@206m_K`0405iNGP1CDe<0De=C
07alO080PH6100@0^;Rh0820P020P800YJFU0P2ATI40101fMWH0RXZ:08Z:RP2PX:0207IfMP0406EU
I@1ZJVX0JVYZ06IVIP80M7Ad00<0Q8B4ooooooooool070000?l20?n000040000o`3oP000oh000?n0
00`0003o00@0oh000000o`000?l0003o0P3oP0090000o`030?n000000?l0003o00X0003o0`3oP007
0000o`D0oh0000<0003o0?n0003oP0001@000?l20?n000L0003o0P3oP0040000o`H0oh000P000?l0
0`3oP000003o0000o`070000o`030?n000000?l0003o00d0003o1@3oP0000`000?l0oh000?n00004
0000o`030?n000000?l0003o00<0003o0`3oP0030000o`030?n000000?l0003o0100003o2_ooool0
00Wooooo00@0OGem0:VYZ@2YZJT0PX:20P2MWId0102DU9@0YZJV0:JVYP2[Zj/209>CT`0408F5Q@1h
N7P0N7Qh07alO080MgMg0`23Ph<307]kN`0407MgM`2CTi<0Ti>C061PH080CDe=00@0QXJ605]KF`1K
Fe/0FEUI0P1WIfL0101]KFd0Zj^[0:^[Z`2GUiL20:BTY0040:ZZZP2NWYh0WYjN06EUI@80G5aL00D0
Ogmo0:JVYP3Bd]80d];B0:>SX`02061PH00408f=S@2FUYH0UYJF07emO@80YZJV00@0b/[:08R8R028
R8P0K6a/0P26QXH0101UIFD0PX:208:2PP20P80206m_K`0407MgM`1NGUh0GUiN0<30`080XZ:R00@0
YJFU09BDU02DU9@0TI6A0P1kNg/01039bLT0a<C40<C4a02l_;`20:RXZ0040;jn_P2XZ:P0Z:RX08^;
R`<0OWin00@0GEeM09JFUP2FUYH0Rh^;0P2YZJT0102;Rh/0Xj>S0:>SX`2g]kL207emO@0406a/K02=
SHd0SHf=0;Fe]@80[jn_00@0eMGE04I6AP16ATH0WinO0P3De=@0102/[:`0VIVI09VIV@29RHT2071`
L00408N7Q`2TY:@0Y:BT0<c<c080S8b<00@0QXJ60:6QX@2QXJ40YZJV0P27QhL01@2LW9`0WYjN09jN
WP1RHV80ZZZZ0080S8b<00@0EeMG03Ti>@0i>CT0GEeM0P1nOWh0101DE5@0PH610861P@1VIVH2061P
H00405ADE01VIVH0IVIV08B4Q080Kfm_00@0GUiN05=CD`1CDe<0O7al0P21PH40102h^;P0P8200820
P02UYJD2096AT@0407IfMP2:RXX0RXZ:0:2PX080MWIf00@0IFEU06YZJP1ZJVX0IVIV0P1dM7@00`24
Q8Coooooooooo`0L0000o`80oh0000@0003o0?n0003oP000oh0030000?l0103oP000003o0000o`00
0?l20?n000T0003o00<0oh000000o`000?l02P000?l30?n000L0003o1@3oP0000`000?l0oh000?n0
00050000o`80oh001`000?l20?n000@0003o1P3oP0020000o`030?n000000?l0003o00L0003o00<0
oh000000o`000?l03@000?l50?n000030000o`3oP000oh0000@0003o00<0oh000000o`000?l00`00
0?l30?n000<0003o00<0oh000000o`000?l040000?l:ooooo`002Oooool01027QhL0[:b/0:b/[023
Ph<208^;R`040861P@2XZ:P0Z:RX0::RXP80VIVI00@0S8b<08:2PP22PX80MgMg0P1[Jf/01025QHD0
T92@092@T028R8P20861P@0408B4Q02FUYH0UYJF06m_K`80EEEE00@0NGUi075aL@1aLG40HF5Q0P1l
O7`0101]KFd0[Jf]0:f][@2LW9`20:6QX@040;2`/02SXj<0Xj>S06IVIP80JFUY00D0RHV90:n_[`3F
e]H0e]KF09jNWP0205eMG@0408>3P`27QhL0QhN708B4Q080ZZZZ00@0emOG0;>c/`2c/k<0QhN70P2M
WId0101JFUX0Q8B408B4Q01kNg/207emO@0408F5Q@1`L700L71`0<;2`P80/;2`00@0/K6a09RHV02H
V9P0X:2P0P28R8P0103:b/X0`l?30<?3``2SXj<209VIV@050;jn_P2NWYh0WYjN08j>SP20P8000P1n
OWh0101WIfL0TY:B09:BTP2FUYH20:6QX@0408V9R@2XZ:P0Z:RX0:ZZZP80Kfm_00@0IfMW07inOP1n
OWh0YJFU0P2d];@0103>c/h0A4A404A4A02TY:@20>?Sh`040:n_[`2BTY80TY:B08b<S080QXJ600@0
XZ:R0;bl_02l_;`0dm?C0P2GUiL01021PH40[Jf]0:f][@2/[:`207moO`0509ZJVP2OWil0WinO069R
HP2ZZZX00P2DU9@01018B4P0<30`030`<01PH60208Z:RP0405mOG`1hN7P0N7Qh06IVIP80FEUI00@0
DE5A06YZJP1ZJVX0QXJ60P24Q8@0102;Rh/0EUIF05IFEP20P80209FEU@040:f][@1eMGD0MGEe09ZJ
VP80NGUi00@0O7al08b<S02<S8`0_;bl0P2@T900101LG5`0CTi>04i>CP1PH602075aL@0307emOOoo
oooooooo01`0003o0P3oP0070000o`040?n000000?l0003o0000o`80oh001P000?l30?n000030000
o`3oP000oh0000H0003o0P3oP0030000o`80oh001`000?l50?n000@0003o0`3oP0030000o`80oh00
5P000?l40?n00080003o0`3oP0050000o`<0oh000`000?l20?n000X0003o0`3oP0080000o`80oh00
1P000?l20?n000<0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`030?n000@0003o
2_ooool000Wooooo00@0NWYj0:FUY@2UYJD0QHF50P26QXH0102:RXX0[jn_0:n_[`2^[Zh209FEU@<0
SHf=00@0LW9b06=SH`1SHf<0NWYj0P24Q8@0101cLg<0OWin07inOP27QhL20:VYZ@0407MgM`1BDU80
DU9B08V9R@80NGUi00@0JVYZ08J6QP26QXH0Ogmo0P2h^;P0102IVIT0RXZ:08Z:RP2ZZZX20:2PX005
06IVIP1TI6@0I6AT06QXJ02RXZ800P3@d=00102IVIT0GUiN05iNGP29RHT208f=S@0408V9R@2a/K40
/K6a0=?Cd`80YjNW00@0MgMg07EeM@1eMGD0AdM70P1cLg<0101jNWX0N7Qh07QhN01TI6@205QHF004
07emO@2PX:00X:2P09^KV`80VYZJ00@0WYjN08R8R028R8P0a/K60P2l_;`0102`/;00RHV908V9R@2n
_[h209RHV00508R8R02;Rh/0NGUi07UiN@1gMgL00P2@T900102NWYh0XJ6Q0:6QX@2<S8`20:j^[P04
0;2`/01`L700L71`06QXJ080M7Ad00@0UiNG0;6a/@2a/K40bl_;0P13@d<0102IVIT0hn?S0>?Sh`2e
]KD209FEU@0408V9R@2;Rh/0Rh^;0:RXZ080_[jn00@0eMGE09bLW02LW9`0Ph>30P2b/[80102][Jd0
QhN708N7Q`2RXZ8209jNWP0505]KF`2[Zj/0U9BD09BDU01PH6000P0h>3P0101bLW80XJ6Q0:6QX@27
QhL208B4Q004079bLP1`L700L71`04i>CP80I6AT00@0Lg=c071`L01`L700PH610P1;Bd/0101bLW80
Ph>308>3P`2][Jd208f=S@040:f][@2?Shl0Shn?07moO`80U9BD00@0[Jf]09FEU@2EUID0GUiN0P1V
IVH0101KFe/0JFUY06UYJ@1fMWH2ooooo`L0003o0`3oP00B0000o`80oh001`000?l00`3oP000003o
0000o`0:0000o`80oh0000<0003o0?n0003oP00010000?l30?n000@0003o0P3oP0060000o`030?n0
00000?l0003o00L0003o1@3oP0000`000?l0oh000?n0000=0000o`<0oh001P000?l40?n00080003o
0`3oP0050000o`<0oh000`000?l30?n000D0003o00<0oh000000o`000?l00`000?l00`3oP000003o
0000o`070000o`030?n000000?l0003o00@0003o0P3oP0030000o`040?n000000?l0003o0?n000D0
003o00@0oh000000o`000?l0oh000P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0102:
RXX0YZJV0:JVYP2;Rh/208:2PP0409fMW@2/[:`0[:b/0:n_[`80WYjN00@0PX:208Z:RP2:RXX0Lg=c
0P1QHF40101mOGd0Rh^;08^;R`1`L70208F5Q@0407YjNP2KVi/0Vi^K07]kN`80EUIF00@0Ogmo065Q
H@1QHF40H61P0P1kNg/0101]KFd0];Bd0;Bd]02DU9@208F5Q@040;6a/@2XZ:P0Z:RX06a/K080J6QX
00D0HF5Q09ZJVP3GemL0emOG0:NWY`0206UYJ@<0Q8B400@0Shn?0;Jf]P2f][H0eMGE0P2_[jl0101m
OGd0Q8B408B4Q01OGel209:BTP0407UiN@2EUID0UIFE06EUI@80NGUi00@0/K6a0;Ng]`2g]kL0/[:b
0P2EUID0102NWYh0QhN708N7Q`3@d=020<C4a0040:^[Z`28R8P0R8R80;Fe]@80Rh^;00D0O7al0861
P@1eMGD0MGEe07inOP0208^;R`040:>SX`2QXJ40XJ6Q08:2PP80_;bl00@0Y:BT0820P020P800JVYZ
0P1WIfL0102MWId0]kNg0;Ng]`3:b/X204];B`0409jNWP3Ti>@0i>CT0;6a/@80QXJ600@0L71`0820
P020P800YjNW0P2b/[80103>c/h0WIfM09fMW@1nOWh20;2`/0030:JVYP1oOgl0Ogmo00<0U9BD00D0
Kfm_0<;2`P2ATI40TI6A04m?C`0202`/;00407=cL`2LW9`0W9bL07]kN`80LW9b00@0MGEe07QhN01h
N7P0J6QX0P1_Kfl0101bLW80MgMg07MgM`2:RXX204i>CP0407]kN`2OWil0WinO0:BTY080WYjN00@0
^KVi08b<S02<S8`0TY:B0P2VYZH0102d];@0V9RH09RHV01IFET205mOG`0405eMG@1OGel0GemO0820
P0;ooooo2@000?l00`3oP000003o0000o`0@0000o`80oh001`000?l0103oP000003o0000o`000?l2
0?n000L0003o0P3oP0070000o`@0oh0030000?l50?n000@0003o0`3oP0030000o`80oh003@000?l0
0`3oP000003o0000o`060000o`@0oh000P000?l30?n000D0003o0`3oP0030000o`80oh001`000?l2
0?n000040000o`3oP000oh000?n00100003o0P3oP0060000o`030?n000000?l0003o00<0003o00@0
oh000000o`000?l0oh000P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0102:RXX0YZJV
0:JVYP2;Rh/208:2PP0409fMW@2/[:`0[:b/0:n_[`80WYjN00@0PX:208Z:RP2:RXX0Lg=c0P1QHF40
101mOGd0Rh^;08^;R`1`L70208F5Q@0407YjNP2KVi/0Vi^K07]kN`80EUIF00@0Ogmo065QH@1QHF40
H61P0P1kNg/0101]KFd0];Bd0;Bd]02DU9@208F5Q@040;6a/@2XZ:P0Z:RX06a/K080J6QX00D0HF5Q
09ZJVP3GemL0emOG0:NWY`0206UYJ@<0Q8B400@0Shn?0;Jf]P2f][H0eMGE0P2_[jl0101mOGd0Q8B4
08B4Q01OGel209:BTP0407UiN@2EUID0UIFE06EUI@80NGUi00@0/K6a0;Ng]`2g]kL0/[:b0P2EUID0
102NWYh0QhN708N7Q`3@d=020<C4a0040:^[Z`28R8P0R8R80;Fe]@80Rh^;00D0O7al0861P@1eMGD0
MGEe07inOP0208^;R`040:>SX`2QXJ40XJ6Q08:2PP80_;bl00@0Y:BT0820P020P800JVYZ0P1WIfL0
102MWId0]kNg0;Ng]`3:b/X204];B`0409jNWP3Ti>@0i>CT0;6a/@80QXJ600@0L71`0820P020P800
YjNW0P2b/[80103>c/h0WIfM09fMW@1nOWh20;2`/0030:JVYP1oOgl0Ogmo00<0U9BD00D0Kfm_0<;2
`P2ATI40TI6A04m?C`0202`/;00407=cL`2LW9`0W9bL07]kN`80LW9b00@0MGEe07QhN01hN7P0J6QX
0P1_Kfl0101bLW80MgMg07MgM`2:RXX204i>CP0407]kN`2OWil0WinO0:BTY080WYjN00@0^KVi08b<
S02<S8`0TY:B0P2VYZH0102d];@0V9RH09RHV01IFET205mOG`0405eMG@1OGel0GemO0820P0;ooooo
2@000?l00`3oP000003o0000o`0@0000o`80oh001`000?l0103oP000003o0000o`000?l20?n000L0
003o0P3oP0070000o`@0oh0030000?l50?n000@0003o0`3oP0030000o`80oh003@000?l00`3oP000
003o0000o`060000o`@0oh000P000?l30?n000D0003o0`3oP0030000o`80oh001`000?l20?n00004
0000o`3oP000oh000?n00100003o0P3oP0060000o`030?n000000?l0003o00<0003o00@0oh000000
o`000?l0oh000P000?l0103oP000003o0000o`000?l:ooooo`002Oooool01023Ph<0Ti>C09>CT`1i
NGT207IfMP0409ZJVP2VYZH0YZJV0;>c/`80WinO00@0PX:209>CT`2CTi<0PX:20P1/K6`0101lO7`0
RHV908V9R@1cLg<208b<S004071`L02IVIT0VIVI071`L080E5AD00@0NWYj05QHF01HF5P0CDe=0P1c
Lg<0101hN7P0YZJV0:JVYP26QXH207IfMP040:6QX@2JVYX0VYZJ06i^KP80JFUY00D0IFEU09nOW`3M
gMd0gMgM0;>c/`02075aL@0408V9R@25QHD0QHF50:2PX080`L7100@0emOG0;^k^`2k^k/0Shn?0P26
QXH0101SHf<0TY:B09:BTP25QHD208^;R`0406MWI`1lO7`0O7al0;bl_0<0];Bd0P2GUiL0102MWId0
Shn?08n?S`3EeMD20<K6aP040:RXZ02?Shl0Shn?0<S8b080V9RH00D0SHf=096AT@1cLg<0Lg=c08:2
PP0208b<S0040:JVYP2IVIT0VIVI0820P080a<C400@0/K6a09:BTP2BTY80IFEU0P1/K6`0102NWYh0
Zj^[0:^[Z`3Cdm<204I6AP0409NGU`3Ph>00h>3P0:NWY`80MgMg00@0IFEU07MgM`1gMgL0YZJV0P2`
/;00103AdM40Ti>C09>CT`1YJFT20:VYZ@0409VIV@2<S8`0S8b<08V9R@80UIFE00D0S8b<0<?3``25
QHD0QHF503lo?`0202TY:@0407UiN@29RHT0RHV907=cL`80JVYZ00@0J6QX05QHF01HF5P0HF5Q0P1c
Lg<01025QHD0QhN708N7Q`2DU9@205UIF@0407=cL`2NWYh0WYjN09nOW`80RXZ:00@0/;2`08Z:RP2:
RXX0UIFE0P2VYZH0102a/K40Ti>C09>CT`1RHV82079bLP04065QH@1PH600H61P071`L0;ooooo2@00
0?l00`3oP000003o0000o`0@0000o`80oh0000@0003o0?n0003oP000oh0040000?l30?n000H0003o
103oP00<0000o`D0oh0010000?l30?n000<0003o0P3oP00=0000o`<0oh001`000?l30?n00080003o
00<0oh000000o`000?l01@000?l30?n000`0003o0P3oP00010000?l0oh000?n0003oP0080000o`03
0?n000000?l0003o00D0003o0P3oP0060000o`030?n000000?l0003o00<0003o00<0oh000000o`00
0?l01`000?l:ooooo`002Oooool0101hN7P0TI6A096AT@23Ph<206m_K`040:BTY02SXj<0Xj>S0::R
XP80VYZJ00@0S8b<09bLW02LW9`0Ng]k0P1oOgl0101nOWh0SHf=08f=S@1hN7P207IfMP0405UIF@2B
TY80TY:B06QXJ080EEEE00@0Kfm_04e=C@1=CDd0EeMG0P1nOWh0101hN7P0[Jf]0:f][@2@T90207Ui
N@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0GemO09NGU`3?cll0clo?0:FUY@02061PH0040861P@1T
I6@0I6AT09NGU`80YJFU00@0bl_;0:ZZZP2ZZZX0P8200P22PX80101QHF40SHf=08f=S@20P80208N7
Q`0405iNGP1^KVh0KVi^09VIV@<0WinO0P2@T900102EUID0MGEe07EeM@3IfMT20=;BdP040::RXP24
Q8@0Q8B40<?3``80X:2P00D0QHF50820P01YJFT0JFUY0820P00207AdM00409BDU027QhL0QhN70820
P080dM7A00@0Xj>S09fMW@2MWId0Kfm_0P1XJ6P0102WYjL0XZ:R0::RXP3;bl/204];B`04096AT@3L
g=`0g=cL08f=S@80NGUi00@0JFUY07]kN`1kNg/0]KFe0P2j^[X0103?cll0UiNG09NGU`1MGEd20:n_
[`0408n?S`2CTi<0Ti>C06IVIP80PH6100D0Y:BT0;no_`1hN7P0N7Qh03Ph>002034a<@0408B4Q02@
T900T92@055AD@80Lg=c00@0MgMg061PH01PH600LG5a0P1JFUX0101lO7`0N7Qh07QhN025QHD205IF
EP0407YjNP2UYJD0YJFU09NGU`80Ph>300@0[Jf]07alO01lO7`0SHf=0P2e]KD0102`/;00RXZ:08Z:
RP1NGUh207EeM@0406YZJP1QHF40HF5Q06MWI`;ooooo60000?l0103oP000003o0000o`000?l20?n0
00040000o`3oP000oh000?n000<0003o00<0oh000000o`000?l02P000?l20?n000T0003o00<0oh00
0000o`000?l020000?l20?n000X0003o0`3oP0030000o`80oh003@000?l00`3oP000003o0000o`07
0000o`<0oh000P000?l00`3oP000003o0000o`040000o`@0oh000P000?l30?n000L0003o0P3oP000
10000?l0oh000?n0003oP0030000o`80oh001@000?l20?n000@0003o0P3oP0060000o`040?n00000
0?l0003o0000o`<0oh000P000?l00`3oP000003o0000o`040000o`[ooooo0009ooooo`0407QhN02A
TI40TI6A08>3P`80Kfm_00@0Y:BT0:>SX`2SXj<0XZ:R0P2JVYX0102<S8`0W9bL09bLW01kNg/207mo
O`0407inOP2=SHd0SHf=07QhN080MWIf00@0FEUI09:BTP2BTY80J6QX0P1EEED0101_Kfl0CDe=04e=
C@1GEeL207inOP0407QhN02][Jd0[Jf]092@T080NGUi00@0Zj^[0:2PX02PX:00J6QX0P1VIVH01@1O
Gel0UiNG0<o?c`3?cll0YJFU0080H61P00@0PH6106ATI01TI6@0UiNG0P2UYJD0103;bl/0ZZZZ0:ZZ
ZP20P80208:2PP04065QH@2=SHd0SHf=0820P080QhN700@0GUiN06i^KP1^KVh0VIVI0`2OWil2092@
T00409FEU@1eMGD0MGEe0=WIf@80d];B00@0XZ:R08B4Q024Q8@0`l?30P2PX:001@25QHD0P82006UY
J@1YJFT0P8200080M7Ad00@0U9BD08N7Q`27QhL0P8200P3AdM40102SXj<0WIfM09fMW@1_Kfl206QX
J0040:NWY`2RXZ80XZ:R0<_;b`80Bd];00@0TI6A0=cLg03Lg=`0SHf=0P1iNGT0101YJFT0Ng]k07]k
N`2e]KD20;Zj^P040<o?c`2GUiL0UiNG05eMG@80[jn_00@0Shn?09>CT`2CTi<0IVIV0P21PH401@2T
Y:@0_kno07QhN01hN7P0>3Ph0080<C4a00@0Q8B4092@T02@T900DE5A0P1cLg<0101gMgL0H61P061P
H01aLG4205YJFP0407alO01hN7P0N7Qh08F5Q@80EUIF00@0NWYj0:FUY@2UYJD0UiNG0P23Ph<0102]
[Jd0O7al07alO02=SHd20;Fe]@040;2`/02:RXX0RXZ:05iNGP80MGEe00@0JVYZ065QH@1QHF40IfMW
0_oooolH0000o`040?n000000?l0003o0000o`80oh0000@0003o0?n0003oP000oh000`000?l00`3o
P000003o0000o`0:0000o`80oh002@000?l00`3oP000003o0000o`080000o`80oh002P000?l30?n0
00<0003o0P3oP00=0000o`030?n000000?l0003o00L0003o0`3oP0020000o`030?n000000?l0003o
00@0003o103oP0020000o`<0oh001`000?l20?n000040000o`3oP000oh000?n000<0003o0P3oP005
0000o`80oh0010000?l20?n000H0003o00@0oh000000o`000?l0003o0`3oP0020000o`030?n00000
0?l0003o00@0003o2_ooool000Wooooo00@0IVIV0820P020P800O7al0P2CTi<0101aLG40UiNG09NG
U`2PX:0208^;R`0408f=S@2CTi<0Ti>C07=cL`80QHF500@0PH610820P020P800Q8B40P2NWYh0101Y
JFT0WIfM09fMW@1YJFT206=SH`0407inOP1DE5@0E5AD065QH@80PH6100@0NGUi0:>SX`2SXj<0QXJ6
0P1eMGD0102TY:@0UiNG09NGU`1mOGd206m_K`0505mOG`2XZ:P0f=SH0=SHf02][Jd00P1NGUh01022
PX80FUYJ05YJFP2`/;020:NWY`040=GEe@2j^[X0^[Zj08>3P`80PX:200@0Jf][09FEU@2EUID0OGem
0P2:RXX0101XJ6P0L71`071`L02OWil209jNWP0409VIV@28R8P0R8R809:BTP80I6AT00@0b<S80;:b
/P2b/[80SHf=0P1oOgl01@34a<@0[Zj^0:j^[P20P800RHV90080KVi^00@0RHV907moO`1oOgl0UIFE
0P1eMGD0101kNg/0e=CD0=CDe02LW9`20::RXP0407=cL`1SHf<0Hf=S0;:b/P80[Jf]00@0_kno04A4
A014A4@0VYZJ0P3Ng]h0102b/[80Kfm_06m_K`1ZJVX207emO@040;Vi^@37alL0alO70=3@d080^[Zj
00<0HF5Q0:b/[02/[:`00`28R8P01@1QHF40R8R808R8R02g]kL0TY:B0080OGem00@0A4A403@d=00d
=3@0MGEe0P1lO7`0100l?3`0O7al07alO01lO7`207YjNP0407AdM01RHV80HV9R08B4Q080Ph>300@0
Ti>C05UIF@1IFET0L71`0P2PX:00102IVIT0QHF508F5Q@37alL208Z:RP04096AT@2WYjL0YjNW0:ZZ
ZP80Ng]k00@0IVIV07alO01lO7`0L71`0P1VIVH00`1dM7Coooooooooo`0O0000o`030?n000000?l0
003o0100003o1@3oP00010000?l0oh000?n0003oP0020000o`80oh005@000?l30?n000<0003o0`3o
P00<0000o`030?n000000?l0003o00@0003o1P3oP0020000o`<0oh0010000?l60?n000T0003o00@0
oh000000o`000?l0003o0`3oP0030000o`80oh002`000?l20?n000H0003o00<0oh000000o`000?l0
3@000?l:ooooo`002Oooool01024Q8@0Ti>C09>CT`2<S8`20;Ng]`0408f=S@2UYJD0YJFU0;Rh^080
TI6A00@0RHV909:BTP2BTY80JFUY0P23Ph<01022PX80IVIV06IVIP24Q8@208f=S@0406EUI@2SXj<0
Xj>S071`L080Kfm_00@0QHF506a/K01/K6`0JFUY0P1kNg/0101/K6`0XZ:R0::RXP2CTi<207IfMP04
0:RXZ02>SXh0SXj>07QhN080MGEe00D0EEEE09^KV`3De=@0e=CD09^KV`02071`L00407YjNP1<C4`0
C4a<0:ZZZP80YZJV00@0e=CD0<C4a034a<@0P8200P1mOGd0101_Kfl0UIFE09FEU@1lO7`209NGU`04
04e=C@1VIVH0IVIV09FEU@80Vi^K00@0V9RH092@T02@T900Shn?0P1[Jf/0103Jf]X0_Kfm0;fm_@2K
Vi/207YjNP050<30`02LW9`0W9bL07IfMP2BTY800P1eMGD0102ATI40P8200820P02IVIT207AdM004
06i^KP3De=@0e=CD09NGU`80T92@00@0K6a/05QHF01HF5P0][Jf0P2WYjL0103<c<`0ATI604I6AP2L
W9`20=oOg`040;no_`20P800P82006][J`80MGEe00@0/k>c0<g=c@3=cLd0d=3@0P2g]kL0101_Kfl0
Vi^K09^KV`2;Rh/2069RHP0507EeM@1lO7`0O7al0:n_[`1fMWH00P2<S8`0101KFe/0>SXj03Xj>P25
QHD207alO004069RHP1WIfL0IfMW079bLP80MGEe00@0P820069RHP1RHV80QHF50P1eMGD0102?Shl0
GUiN05iNGP2;Rh/20:b/[004092@T01gMgL0MgMg0<G5a@80QHF500@0UiNG0:n_[`2_[jl0ZJVY0P22
PX80101LG5`0K6a/06a/K01FEUH204i>CP0306a/K?oooooooooo00@0003o0P3oP0030000o`030?n0
00000?l0003o02<0003o0P3oP0000`000?l0oh000?n000040000o`80oh000`000?l20?n000T0003o
0P3oP00:0000o`<0oh000`000?l20?n000d0003o00<0oh000000o`000?l00`000?l30?n000040000
o`3oP000oh000?n00080003o0`3oP0040000o`H0oh002@000?l0103oP000003o0000o`000?l30?n0
0100003o0P3oP0060000o`040?n000000?l0003o0000o`80oh000`000?l00`3oP000003o0000o`03
0?n000030000oooooooooooo00Sooooo0009ooooo`0408B4Q02CTi<0Ti>C08b<S080]kNg00@0SHf=
0:FUY@2UYJD0^;Rh0P2ATI401029RHT0TY:B09:BTP1YJFT208>3P`0408:2PP1VIVH0IVIV08B4Q080
SHf=00@0IFEU0:>SX`2SXj<0L71`0P1_Kfl01025QHD0K6a/06a/K01YJFT207]kN`0406a/K02RXZ80
XZ:R09>CT`80MWIf00@0Z:RX08j>SP2>SXh0N7Qh0P1eMGD01@1EEED0Vi^K0=CDe03De=@0Vi^K0080
L71`00@0NWYj04a<C01<C4`0ZZZZ0P2VYZH0103De=@0a<C40<C4a020P80207emO@0406m_K`2EUID0
UIFE07alO080UiNG00@0CDe=06IVIP1VIVH0UIFE0P2KVi/0102HV9P0T92@092@T02?Shl206][J`04
0=[JfP2m_Kd0_Kfm09^KV`80NWYj00D0`<3009bLW02LW9`0MWIf09:BTP0207EeM@04096AT@20P800
P82009VIV@80M7Ad00@0KVi^0=CDe03De=@0UiNG0P2@T900101/K6`0F5QH05QHF02f][H20:NWY`04
0<c<c016ATH0ATI609bLW080gmoO00@0_kno0820P020P800Jf][0P1eMGD0102c/k<0cLg=0<g=c@3@
d=020;Ng]`0406m_K`2KVi/0Vi^K08^;R`80HV9R00D0MGEe07alO01lO7`0[jn_07IfMP0208b<S004
05]KF`0j>SX0>SXj08F5Q@80O7al00@0HV9R06MWI`1WIfL0LW9b0P1eMGD01020P800HV9R069RHP25
QHD207EeM@0408n?S`1NGUh0GUiN08^;R`80[:b/00@0T92@07MgM`1gMgL0aLG50P25QHD0102GUiL0
[jn_0:n_[`2YZJT208:2PP0405aLG01/K6`0K6a/05IFEP80CTi>00<0K6a/ooooooooool010000?l2
0?n000<0003o00<0oh000000o`000?l08`000?l20?n000030000o`3oP000oh0000@0003o0P3oP003
0000o`80oh002@000?l20?n000X0003o0`3oP0030000o`80oh003@000?l00`3oP000003o0000o`03
0000o`<0oh0000@0003o0?n0003oP000oh000P000?l30?n000@0003o1P3oP0090000o`040?n00000
0?l0003o0000o`<0oh0040000?l20?n000H0003o00@0oh000000o`000?l0003o0P3oP0030000o`03
0?n000000?l0003o00<0oh0000<0003oooooooooool02?ooool000Wooooo00@0OGem08n?S`2?Shl0
P8200P2`/;001022PX80ZJVY0:VYZ@2j^[X2096AT@0408>3P`2EUID0UIFE079bLP80QHF500@0PX:2
05EEE@1EEED0Rh^;0P2RXZ80101RHV80XJ6Q0:6QX@1_Kfl207=cL`040861P@1ZJVX0JVYZ05]KF`80
NWYj00@0Ng]k0;bl_02l_;`0Rh^;0P1gMgL0102UYJD0Vi^K09^KV`1iNGT206m_K`05051@D02:RXX0
bLW90<W9b@2SXj<00P1`L700101kNg/0B4Q804Q8B02i^KT20:^[Z`040=[JfP3Cdm<0dm?C08b<S080
Rh^;00@0OGem096AT@2ATI40Ogmo0P2MWId0101WIfL0MgMg07MgM`2^[Zh20;Bd]00409fMW@2NWYh0
WYjN09>CT`80MGEe00@0h>3P0<C4a034a<@0X:2P0P1mOGd01@2k^k/0U9BD09BDU01^KVh0VYZJ0080
Ng]k00@0Xj>S08b<S02<S8`0YJFU0P1kNg/0101[Jf/0d];B0=;BdP2NWYh209NGU`0407IfMP1HF5P0
F5QH0;Rh^080ZJVY00@0`<3003Ti>@0i>CT0Vi^K0P3Rh^80102h^;P0LG5a075aL@1[Jf/207EeM@04
0:b/[037alL0alO70;^k^`80Zj^[00@0NGUi08j>SP2>SXh0VYZJ0P1QHF401@2:RXX0Ph>308>3P`2F
UYH0U9BD0080IFEU00@0K6a/03lo?`0o?cl0S8b<0P1`L700102>SXh0LW9b079bLP1[Jf/207AdM004
08b<S01MGEd0GEeM07YjNP80LW9b00@0V9RH071`L01`L700QhN70P2XZ:P0102<S8`0NGUi07UiN@3<
c<`209:BTP040:6QX@2b/[80/[:b09jNWP80RHV900@0IfMW06QXJ01XJ6P0GUiN0P1^KVh00`2UYJGo
ooooooooo`040000o`80oh000`000?l00`3oP000003o0000o`070000o`80oh002`000?l20?n000<0
003o00<0oh000000o`000?l01`000?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000o`80
oh0030000?l30?n000H0003o0`3oP0030000o`80oh003@000?l00`3oP000003o0000o`030000o`<0
oh0000@0003o0?n0003oP000oh000P000?l30?n000D0003o0`3oP00A0000o`030?n000000?l0003o
00P0003o0P3oP00<0000o`040?n000000?l0003o0000o`80oh001P000?l0103oP000003o0000o`00
0?l:ooooo`002Oooool0101oOgl0TY:B09:BTP21PH4209ZJVP0407UiN@2QXJ40XJ6Q0;Ng]`80TY:B
00@0Rh^;09JFUP2FUYH0Ng]k0P21PH40102=SHd0Fe]K05]KF`25QHD20::RXP0406m_K`2TY:@0Y:BT
06m_K`80JFUY00@0MGEe05YJFP1JFUX0FUYJ0P1oOgl0101iNGT0^;Rh0;Rh^02CTi<208:2PP030:f]
[@2MWId0WIfM00<0O7al00D0FEUI09:BTP3?cll0clo?0:ZZZP0207UiN@0407emO@18B4P0B4Q80;bl
_080VIVI00@0dm?C0<W9b@39bLT0QHF50P1dM7@0101]KFd0R8R808R8R01gMgL209BDU00406e]K@1^
KVh0KVi^0::RXP80/[:b00@0X:2P09fMW@2MWId0V9RH0P1jNWX0103IfMT0^KVi0;Vi^@2HV9P208R8
R0050:n_[`2GUiL0UiNG06QXJ02MWId00P2;Rh/0102OWil0S8b<08b<S02VYZH207QhN00406ATI03C
dm<0dm?C0:2PX080Ph>300@0Ogmo05QHF01HF5P0`<300P2[Zj/01035aLD0=3@d03@d=02QXJ420>?S
h`040;bl_01ZJVX0JVYZ06QXJ080M7Ad00@0YjNW0;^k^`2k^k/0a/K60P2FUYH0101lO7`0RHV908V9
R@2IVIT207IfMP0507QhN020P800P82006QXJ02m_Kd00P1VIVH0101CDe<0;2`/02`/;01ZJVX206EU
I@0408R8R02:RXX0RXZ:079bLP80KVi^00@0OWin05eMG@1MGEd0Lg=c0P1MGEd01023Ph<0Lg=c07=c
L`21PH4209nOW`0408>3P`1]KFd0KFe]0<G5a@80T92@00@0Shn?0;2`/02`/;00Vi^K0P2RXZ80101a
LG40HV9R069RHP1YJFT207emO@030:>SXooooooooooo00T0003o00<0oh000000o`000?l01`000?l2
0?n000X0003o0`3oP0030000o`040?n000000?l0003o0000o`80oh0010000?l20?n000030000o`3o
P000oh0000@0003o0`3oP0020000o`80oh003P000?l00`3oP000003o0000o`040000o`<0oh000`00
0?l20?n000d0003o00<0oh000000o`000?l00`000?l30?n000040000o`3oP000oh000?n00080003o
0`3oP0050000o`<0oh0030000?l20?n000040000o`3oP000oh000?n000X0003o0P3oP0000`000?l0
oh000?n000090000o`040?n000000?l0003o0000o`80oh002P000?l:ooooo`002Oooool0101oOgl0
TY:B09:BTP21PH4209ZJVP0407UiN@2QXJ40XJ6Q0;Ng]`80TY:B00@0Rh^;09JFUP2FUYH0Ng]k0P21
PH40102=SHd0Fe]K05]KF`25QHD20::RXP0406m_K`2TY:@0Y:BT06m_K`80JFUY00@0MGEe05YJFP1J
FUX0FUYJ0P1oOgl0101iNGT0^;Rh0;Rh^02CTi<208:2PP030:f][@2MWId0WIfM00<0O7al00D0FEUI
09:BTP3?cll0clo?0:ZZZP0207UiN@0407emO@18B4P0B4Q80;bl_080VIVI00@0dm?C0<W9b@39bLT0
QHF50P1dM7@0101]KFd0R8R808R8R01gMgL209BDU00406e]K@1^KVh0KVi^0::RXP80/[:b00@0X:2P
09fMW@2MWId0V9RH0P1jNWX0103IfMT0^KVi0;Vi^@2HV9P208R8R0050:n_[`2GUiL0UiNG06QXJ02M
WId00P2;Rh/0102OWil0S8b<08b<S02VYZH207QhN00406ATI03Cdm<0dm?C0:2PX080Ph>300@0Ogmo
05QHF01HF5P0`<300P2[Zj/01035aLD0=3@d03@d=02QXJ420>?Sh`040;bl_01ZJVX0JVYZ06QXJ080
M7Ad00@0YjNW0;^k^`2k^k/0a/K60P2FUYH0101lO7`0RHV908V9R@2IVIT207IfMP0507QhN020P800
P82006QXJ02m_Kd00P1VIVH0101CDe<0;2`/02`/;01ZJVX206EUI@0408R8R02:RXX0RXZ:079bLP80
KVi^00@0OWin05eMG@1MGEd0Lg=c0P1MGEd01023Ph<0Lg=c07=cL`21PH4209nOW`0408>3P`1]KFd0
KFe]0<G5a@80T92@00@0Shn?0;2`/02`/;00Vi^K0P2RXZ80101aLG40HV9R069RHP1YJFT207emO@03
0:>SXooooooooooo00T0003o00<0oh000000o`000?l01`000?l20?n000X0003o0`3oP0030000o`04
0?n000000?l0003o0000o`80oh0010000?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000
o`80oh003P000?l00`3oP000003o0000o`040000o`<0oh000`000?l20?n000d0003o00<0oh000000
o`000?l00`000?l30?n000040000o`3oP000oh000?n00080003o0`3oP0050000o`<0oh0030000?l2
0?n000040000o`3oP000oh000?n000X0003o0P3oP0000`000?l0oh000?n000090000o`040?n00000
0?l0003o0000o`80oh002P000?l:ooooo`002Oooool01024Q8@0SHf=08f=S@1iNGT208Z:RP0408J6
QP2f][H0][Jf0;:b/P80TY:B00<0Q8B409^KV`2KVi/00`1eMGD0102=SHd0FUYJ05YJFP26QXH209VI
V@0407IfMP28R8P0R8R806YZJP80HV9R00@0PX:205]KF`1KFe/0Fe]K0P1cLg<0101oOgl0/;2`0;2`
/024Q8@207alO0<0Xj>S00D0Q8B407inOP1nOWh0GUiN0:2PX0020<c<c0040:RXZ01mOGd0OGem08B4
Q080A4A400@0^;Rh09fMW@2MWId0f][J0P3Bd]80102ATI40QhN708N7Q`1TI6@208b<S00407inOP2F
UYH0UYJF07moO`80MWIf00@0ZJVY0;>c/`2c/k<0XZ:R0P2PX:00102?Shl0NGUi07UiN@3De=@20;6a
/@0408n?S`1nOWh0OWin0:VYZ@80QhN700D0H61P09JFUP2=SHd0SHf=0:JVYP0208^;R`040:BTY01e
MGD0MGEe05iNGP80cLg=00@0VYZJ08R8R028R8P0QXJ60P1HF5P01032`/80Zj^[0:^[Z`36a/H202PX
:0040;2`/03Ti>@0i>CT0;2`/080Kfm_00@0MGEe079bLP1bLW80WYjN0P33`l<0103=cLd0XJ6Q0:6Q
X@2BTY8208n?S`040:JVYP1jNWX0NWYj08n?S`80P82000D0O7al0:BTY01]KFd0KFe]04U9B@02038b
<P04075aL@1VIVH0IVIV075aL@80T92@00@0NWYj07UiN@1iNGT0Lg=c0P1_Kfl0101[Jf/0KVi^06i^
KP1gMgL2075aL@0407YjNP2RXZ80XZ:R07AdM080IfMW00@0a<C409JFUP2FUYH0QhN70P2][Jd01027
QhL0K6a/06a/K01jNWX2079bLP0406][J`1iNGT0NGUi06i^KP;ooooo1`000?l30?n000T0003o0P3o
P00:0000o`<0oh000`000?l00`3oP000003o0000o`070000o`80oh0000<0003o0?n0003oP0001000
0?l30?n00080003o0P3oP00>0000o`030?n000000?l0003o00@0003o0`3oP00@0000o`<0oh001@00
0?l30?n000030000o`3oP000oh0000H0oh001@000?l30?n000l0003o0`3oP00H0000o`040?n00000
0?l0003o0000o`80oh002P000?l:ooooo`002Oooool01022PX80UYJF09JFUP23Ph<209:BTP0408R8
R02e]KD0]KFe0:VYZ@80UIFE00@0QXJ60:NWY`2WYjL0Ogmo0P1/K6`01029RHT0De=C05=CD`25QHD2
096AT@0407EeM@2MWId0WIfM0820P080Jf][00@0Lg=c059BDP1BDU80D51@0P1jNWX0101hN7P0/k>c
0;>c/`27QhL207inOP040:NWY`2NWYh0WYjN08B4Q080QXJ600D0IFEU08Z:RP37alL0alO70:VYZ@02
08:2PP0408V9R@18B4P0B4Q80;Ng]`80YJFU00@0gMgM0=CDe03De=@0TY:B0P23Ph<0101OGel0SHf=
08f=S@1]KFd208b<S00408>3P`1XJ6P0J6QX0:BTY080YJFU00@0WIfM0:6QX@2QXJ40SHf=0P21PH40
103Cdm<0Y:BT0:BTY02ATI4207emO@050:b/[028R8P0R8R806IVIP2DU9@00P23Ph<0102;Rh/0OGem
07emO@2DU9@207IfMP04065QH@3=cLd0cLg=09RHV080L71`00@0OGem05MGE`1GEeL0b/[:0P2ZZZX0
1032`/806QXJ01XJ6P2g]kL20>;RhP0409>CT`1nOWh0OWin07UiN@80MGEe00@0Xj>S0;jn_P2n_[h0
_;bl0P2;Rh/0102RXZ80SXj>08j>SP2ZZZX207]kN`0509ZJVP1/K6`0K6a/0:VYZ@2ATI400P1/K6`0
1017AdL0;bl_02l_;`1lO7`2069RHP0405UIF@2HV9P0V9RH06a/K080IfMW00@0GemO09:BTP2BTY80
Kfm_0P1aLG40101XJ6P0Ph>308>3P`1oOgl209VIV@0408>3P`1UIFD0IFEU0<71`@80WinO00@0OGem
0:6QX@2QXJ40SHf=0P24Q8@0101NGUh0IVIV06IVIP1IFET20861P@0306ATI?oooooooooo00L0003o
0P3oP00:0000o`80oh002P000?l30?n000<0003o00<0oh000000o`000?l02P000?l20?n000@0003o
0`3oP0020000o`80oh005@000?l20?n001<0003o00<0oh000000o`000?l00`000?l30?n000030000
o`3oP000oh0000@0oh001`000?l30?n000l0003o0`3oP0030000o`80oh004`000?l00`3oP000003o
0000o`060000o`040?n000000?l0003o0?n000<0003o2_ooool000Wooooo00@0PX:209JFUP2FUYH0
Ph>30P2BTY801028R8P0]KFe0;Fe]@2YZJT209FEU@0408J6QP2WYjL0YjNW07moO`80K6a/00@0RHV9
05=CD`1CDe<0QHF50P2ATI40101eMGD0WIfM09fMW@20P80206][J`0407=cL`1BDU80DU9B051@D080
NWYj00@0N7Qh0;>c/`2c/k<0QhN70P1nOWh0102WYjL0WYjN09jNWP24Q8@208J6QP0506EUI@2:RXX0
alO70<O7a`2YZJT00P22PX801029RHT0B4Q804Q8B02g]kL20:FUY@040=gMg@3De=@0e=CD09:BTP80
Ph>300@0GemO08f=S@2=SHd0KFe]0P2<S8`01023Ph<0J6QX06QXJ02TY:@20:FUY@0409fMW@2QXJ40
XJ6Q08f=S@80PH6100@0dm?C0:BTY02TY:@0TI6A0P1mOGd01@2/[:`0R8R808R8R01VIVH0U9BD0080
Ph>300@0Rh^;07emO@1mOGd0U9BD0P1fMWH0101QHF40cLg=0<g=c@2HV9P2071`L00407emO@1GEeL0
EeMG0<[:bP80ZZZZ00@0`/;201XJ6P0J6QX0]kNg0P3Rh^80102CTi<0OWin07inOP1iNGT207EeM@04
0:>SX`2n_[h0_[jn0;bl_080Rh^;00@0XZ:R08j>SP2>SXh0ZZZZ0P1kNg/01@2JVYX0K6a/06a/K02Y
ZJT0TI6A0080K6a/00@0AdM702l_;`0_;bl0O7al0P1RHV80101IFET0V9RH09RHV01/K6`206MWI`04
05mOG`2BTY80TY:B06m_K`80LG5a00@0J6QX08>3P`23Ph<0Ogmo0P2IVIT01023Ph<0IFEU06EUI@31
`L4209nOW`0407emO@2QXJ40XJ6Q08f=S@80Q8B400@0GUiN06IVIP1VIVH0FEUI0P21PH400`1TI6Co
ooooooooo`070000o`80oh002P000?l20?n000X0003o0`3oP0030000o`030?n000000?l0003o00X0
003o0P3oP0040000o`<0oh000P000?l20?n001D0003o0P3oP00C0000o`030?n000000?l0003o00<0
003o0`3oP0000`000?l0oh000?n000040?n000L0003o0`3oP00?0000o`<0oh000`000?l20?n001<0
003o00<0oh000000o`000?l01P000?l0103oP000003o0000o`3oP0030000o`[ooooo0009ooooo`04
08^;R`29RHT0RHV906a/K080N7Qh00@0O7al0:n_[`2_[jl0[Jf]0P2HV9P01020P800YZJV0:JVYP26
QXH207YjNP0408b<S01GEeL0EeMG08N7Q`80OGem00@0KVi^0:6QX@2QXJ40LG5a0P1PH600101_Kfl0
Bd];04];B`1<C4`2071`L00407EeM@2ZZZX0ZZZZ0861P@80MWIf00@0YjNW09bLW02LW9`0Ng]k0P25
QHD01@1YJFT0VYZJ0<[:bP3:b/X0Y:BT0080NWYj00@0PX:204Y:BP1:BTX0^;Rh0P2UYJD0103Kfm/0
b/[:0<[:bP2=SHd207]kN`04065QH@27QhL0QhN706i^KP80T92@00@0JVYZ069RHP1RHV80Vi^K0P1V
IVH01025QHD0UiNG09NGU`2?Shl207moO`040=WIf@2^[Zh0[Zj^08^;R`80KFe]00@0YZJV08j>SP2>
SXh0Kfm_0`2IVIT0102JVYX0T92@092@T02PX:0207]kN`04069RHP3<c<`0c<c<09VIV@80KFe]00@0
OWin055AD@1ADE40^k^k0P2RXZ801033`l<0?Shn03hn?P2UYJD20>?Sh`04092@T025QHD0QHF508F5
Q@80Ng]k00@0V9RH0<c<c03<c<`0b<S80P1jNWX0102WYjL0RHV908V9R@2VYZH207moO`0509BDU01/
K6`0K6a/09fMW@2FUYH00P1VIVH0101BDU80@4100410@01aLG4205aLG004061PH02BTY80TY:B09BD
U080O7al00@0Kfm_09fMW@2MWId0JFUY0P1WIfL0101@D500PH610861P@23Ph<209>CT`0408B4Q01X
J6P0J6QX0;Zj^P80WYjN00@0M7Ad08f=S@2=SHd0UiNG0P1mOGd0101KFe/0FEUI05UIF@1dM7@209BD
U00308J6Q_oooooooooo00L0003o0`3oP0090000o`80oh002P000?l30?n00100003o0P3oP0040000
o`<0oh000P000?l20?n001D0003o0`3oP00B0000o`030?n000000?l0003o00<0003o0`3oP0001000
0?l0oh000?n0003oP0020000o`030?n000000?l0003o00D0003o0`3oP00?0000o`<0oh000P000?l0
0`3oP000003o0000o`0:0000o`030?n000000?l0003o00H0003o00<0oh000000o`000?l01P000?l3
0?n000@0003o2_ooool000Wooooo00@0OGem08F5Q@25QHD0M7Ad0P2DU9@0102?Shl0/;2`0;2`/02i
^KT2096AT@040820P02NWYh0WYjN07]kN`80P82000@0UIFE05eMG@1MGEd0SHf=0P2EUID0101]KFd0
W9bL09bLW01^KVh205mOG`04069RHP1;Bd/0Bd];04Y:BP80MgMg00@0IVIV09bLW02LW9`0NWYj0P21
PH40102ZZZX0YJFU0:FUY@26QXH207]kN`0505UIF@2>SXh0a<C40<C4a02[Zj/00P1hN7P0101lO7`0
CDe=04e=C@2^[Zh208n?S`040=?Cd`3;bl/0bl_;08^;R`80Ogmo00@0K6a/08j>SP2>SXh0KFe]0P2?
Shl0101WIfL0JVYZ06YZJP2^[Zh208j>SP0409NGU`2MWId0WIfM08^;R`80MgMg00@0e=CD0:>SX`2S
Xj<0SHf=0P25QHD01@2^[Zh0VIVI09VIV@1iNGT0SXj>0080WYjN00@0TI6A08f=S@2=SHd0Y:BT0P22
PX80101NGUh0e=CD0=CDe02NWYh2079bLP0408b<S01KFe/0Fe]K0;^k^`80XJ6Q00@0_[jn05EEE@1E
EED0WinO0P3Rh^80102>SXh0Ogmo07moO`2;Rh/208Z:RP0409^KV`31`L40`L710;fm_@80Ph>300@0
ZJVY08j>SP2>SXh0W9bL0P2:RXX01@2DU9@0M7Ad07AdM02TY:@0UYJF0080KVi^00@0EEEE04a<C01<
C4`0NWYj0P1TI6@0101YJFT0MGEe07EeM@27QhL207IfMP0407]kN`2ATI40TI6A06m_K`80F5QH00@0
B4Q806MWI`1WIfL0NGUi0P2CTi<0102@T900I6AT06ATI02SXj<209NGU`0407alO02;Rh/0Rh^;09ZJ
VP80LG5a00@0PX:205QHF01HF5P0I6AT0P2>SXh00`1iNGWoooooooooo`070000o`<0oh002@000?l2
0?n000X0003o0`3oP00=0000o`80oh0000<0003o0?n0003oP00010000?l30?n00080003o0P3oP00<
0000o`80oh001`000?l20?n000@0003o0P3oP00;0000o`<0oh001@000?l30?n000040000o`3oP000
oh000?n00080003o00<0oh000000o`000?l01@000?l30?n000l0003o0`3oP00=0000o`<0oh004P00
0?l20?n000@0003o2_ooool000Wooooo00@0OGem08F5Q@25QHD0M7Ad0P2DU9@0102?Shl0/;2`0;2`
/02i^KT2096AT@040820P02NWYh0WYjN07]kN`80P82000@0UIFE05eMG@1MGEd0SHf=0P2EUID0101]
KFd0W9bL09bLW01^KVh205mOG`04069RHP1;Bd/0Bd];04Y:BP80MgMg00@0IVIV09bLW02LW9`0NWYj
0P21PH40102ZZZX0YJFU0:FUY@26QXH207]kN`0505UIF@2>SXh0a<C40<C4a02[Zj/00P1hN7P0101l
O7`0CDe=04e=C@2^[Zh208n?S`040=?Cd`3;bl/0bl_;08^;R`80Ogmo00@0K6a/08j>SP2>SXh0KFe]
0P2?Shl0101WIfL0JVYZ06YZJP2^[Zh208j>SP0409NGU`2MWId0WIfM08^;R`80MgMg00@0e=CD0:>S
X`2SXj<0SHf=0P25QHD01@2^[Zh0VIVI09VIV@1iNGT0SXj>0080WYjN00@0TI6A08f=S@2=SHd0Y:BT
0P22PX80101NGUh0e=CD0=CDe02NWYh2079bLP0408b<S01KFe/0Fe]K0;^k^`80XJ6Q00@0_[jn05EE
E@1EEED0WinO0P3Rh^80102>SXh0Ogmo07moO`2;Rh/208Z:RP0409^KV`31`L40`L710;fm_@80Ph>3
00@0ZJVY08j>SP2>SXh0W9bL0P2:RXX01@2DU9@0M7Ad07AdM02TY:@0UYJF0080KVi^00@0EEEE04a<
C01<C4`0NWYj0P1TI6@0101YJFT0MGEe07EeM@27QhL207IfMP0407]kN`2ATI40TI6A06m_K`80F5QH
00@0B4Q806MWI`1WIfL0NGUi0P2CTi<0102@T900I6AT06ATI02SXj<209NGU`0407alO02;Rh/0Rh^;
09ZJVP80LG5a00@0PX:205QHF01HF5P0I6AT0P2>SXh00`1iNGWoooooooooo`070000o`<0oh002@00
0?l20?n000X0003o0`3oP00=0000o`80oh0000<0003o0?n0003oP00010000?l30?n00080003o0P3o
P00<0000o`80oh001`000?l20?n000@0003o0P3oP00;0000o`<0oh001@000?l30?n000040000o`3o
P000oh000?n00080003o00<0oh000000o`000?l01@000?l30?n000l0003o0`3oP00=0000o`<0oh00
4P000?l20?n000@0003o2_ooool000Wooooo00@0RHV907]kN`1kNg/0Q8B40P2BTY801027QhL0Z:RX
0:RXZ02XZ:P2092@T00408f=S@2HV9P0V9RH07YjNP80Rh^;00@0SXj>06ATI01TI6@0T92@0P2HV9P0
101gMgL0WIfM09fMW@1nOWh206m_K`04079bLP19BDT0BDU9059BDP80NWYj00@0O7al0;6a/@2a/K40
QXJ60P2;Rh/0102VYZH0WinO09nOW`25QHD208>3P`0505UIF@2LW9`0b/[:0<[:bP2_[jl00P1kNg/0
1023Ph<0EEEE05EEE@33`l<20:RXZ0040=kNgP3@d=00d=3@092@T080Rh^;00@0M7Ad08f=S@2=SHd0
NWYj0P2OWil0101RHV80L71`071`L02l_;`208f=S@040:n_[`2PX:00X:2P08^;R`80Ph>300@0eMGE
0:6QX@2QXJ40SHf=0P20P8001@2a/K40Z:RX0:RXZ01iNGT0RXZ:0080WYjN00@0SHf=09FEU@2EUID0
X:2P0P22PX80101WIfL0gMgM0=gMg@2MWId206a/K00408n?S`1PH600H61P0<?3``80ZJVY00@0][Jf
02l_;`0_;bl0YJFU0P3Ti>@01028R8P0PH610861P@1fMWH207YjNP0409VIV@3?cll0clo?0<K6aP80
T92@00@0WYjN09nOW`2OWil0WYjN0P28R8P01@2DU9@0MgMg07MgM`2i^KT0Shn?0080Kfm_00@0@d=3
034a<@0a<C40K6a/0P1NGUh0101lO7`0Hf=S06=SH`1iNGT2061PH00407]kN`23Ph<0Ph>307moO`80
I6AT00@0MGEe08:2PP22PX80QXJ60P2<S8`0102HV9P0I6AT06ATI02m_Kd20:JVYP0407moO`2;Rh/0
Rh^;08n?S`80HV9R00@0Ph>304m?C`1?Cdl0CTi>0P1cLg<00`1_Kfooooooooooo`0O0000o`<0oh00
0`000?l00`3oP000003o0000o`070000o`80oh0000@0003o0?n0003oP000oh000`000?l30?n00080
003o0P3oP00<0000o`80oh0000<0003o0?n0003oP00010000?l20?n000@0003o0P3oP00=0000o`03
0?n000000?l0003o00@0003o0P3oP00010000?l0oh000?n0003oP0020000o`030?n000000?l0003o
00D0003o0`3oP00;0000o`040?n000000?l0003o0000o`<0oh000P000?l00`3oP000003o0000o`0C
0000o`030?n000000?l0003o00L0003o0`3oP0030000o`[ooooo0009ooooo`0409>CT`1jNWX0NWYj
07moO`80SXj>00@0RHV90;Fe]@2e]KD0/K6a0P2HV9P00`2DU9@0Xj>S0:>SX`0307alO00408f=S@1`
L700L71`0820P080R8R800@0Hf=S08J6QP26QXH0MWIf0P1YJFT0101_Kfl0AdM704M7A`1BDU8207If
MP0407inOP2[Zj/0Zj^[08B4Q080PX:200@0/K6a0:2PX02PX:00QhN70P2;Rh/01@1GEeL0SHf=0<C4
a034a<@0XZ:R0080NGUi00@0Ogmo059BDP1BDU80_[jn0P2KVi/0103IfMT0bLW90<W9b@2CTi<208V9
R@0406][J`1gMgL0MgMg071`L080U9BD0`1VIVH0102ZZZX0Ph>308>3P`2j^[X20:JVYP0409^KV`1o
Ogl0Ogmo0>CTi080[jn_00@0Ti>C07IfMP1fMWH0XZ:R0P2LW9`00`1aLG40PH6108R8R00208R8R080
RHV900@0XZ:R08F5Q@25QHD0FEUI0P3@d=00102<S8`0MGEe07EeM@2LW9`207UiN@040;fm_@2RXZ80
XZ:R09bLW0809BDU00@0h>3P0>KViP3Vi^H0T92@0P25QHD01028R8P0Ng]k07]kN`2ATI420<;2`P04
0;^k^`2=SHd0SHf=0:^[Z`80WYjN00@0[Jf]09BDU02DU9@0VIVI0P24Q8@01@2YZJT0PX:206MWI`1W
IfL0>3Ph0080?clo00@0SHf=051@D01@D500Ph>30P1HF5P01024Q8@0GemO05mOG`1dM7@208j>SP04
07emO@1_Kfl0Kfm_08^;R`80OWin00@0Rh^;09RHV02HV9P0X:2P0P1cLg<01038b<P0_;bl0;bl_01b
LW8209:BTP0409fMW@1OGel0GemO07AdM0<0?clo0P1QHF400`1NGUkoooooooooo`070000o`<0oh00
5@000?l30?n000L0003o0P3oP0040000o`80oh0000<0003o0?n0003oP00010000?l30?n00080003o
0P3oP00?0000o`80oh0010000?l30?n00100003o0`3oP0060000o`80oh000`000?l40?n000L0003o
0`3oP0050000o`030?n000000?l0003o00L0003o0`3oP0020000o`040?n000000?l0003o0?n00180
003o0`3oP0070000o`<0oh000P000?l00`3oP03oooooooooo`08ooooo`002Oooool0102CTi<0NWYj
07YjNP1oOgl208j>SP0408V9R@2e]KD0]KFe0;6a/@80V9RH00<0U9BD0:>SX`2SXj<00`1lO7`0102=
SHd0L71`071`L020P80208R8R00406=SH`26QXH0QXJ607IfMP80JFUY00@0Kfm_04M7A`17AdL0DU9B
0P1fMWH0101nOWh0Zj^[0:^[Z`24Q8@208:2PP040;6a/@2PX:00X:2P08N7Q`80Rh^;00D0EeMG08f=
S@34a<@0a<C40::RXP0207UiN@0407moO`1BDU80DU9B0;jn_P80Vi^K00@0fMWI0<W9b@39bLT0Ti>C
0P29RHT0101[Jf/0MgMg07MgM`1`L70209BDU0<0IVIV00@0ZZZZ08>3P`23Ph<0^[Zj0P2VYZH0102K
Vi/0Ogmo07moO`3Ti>@20:n_[`0409>CT`1fMWH0MWIf0::RXP80W9bL00<0LG5a0861P@28R8P00P28
R8P208V9R@040::RXP25QHD0QHF505UIF@80d=3@00@0S8b<07EeM@1eMGD0W9bL0P1iNGT0102m_Kd0
XZ:R0::RXP2LW9`202DU9@040>3Ph03Vi^H0i^KV092@T080QHF500@0R8R807]kN`1kNg/0TI6A0P32
`/80102k^k/0SHf=08f=S@2[Zj/209jNWP040:f][@2DU9@0U9BD09VIV@80Q8B400D0ZJVY08:2PP1W
IfL0IfMW03Ph>00203lo?`0408f=S@1@D500D51@08>3P`80F5QH00@0Q8B405mOG`1OGel0M7Ad0P2>
SXh0101mOGd0Kfm_06m_K`2;Rh/207inOP0408^;R`2HV9P0V9RH0:2PX080Lg=c00@0b<S80;bl_02l
_;`0LW9b0P2BTY80102MWId0GemO05mOG`1dM7@303lo?`80HF5Q00<0GUiNooooooooool01`000?l3
0?n001D0003o0`3oP0070000o`80oh0010000?l20?n000030000o`3oP000oh0000@0003o0`3oP002
0000o`80oh003`000?l20?n000@0003o0`3oP00@0000o`<0oh001P000?l20?n000<0003o103oP007
0000o`<0oh001@000?l00`3oP000003o0000o`070000o`<0oh000P000?l0103oP000003o0000o`3o
P00B0000o`<0oh001`000?l30?n00080003o00<0oh00ooooooooool02?ooool000Wooooo00@0Rh^;
079bLP1bLW80OGem0P27QhL0101kNg/0Vi^K09^KV`2^[Zh20:2PX00409NGU`2HV9P0V9RH0820P080
Shn?00@0QHF505]KF`1KFe/0MgMg0P2@T9000`1CDe<0Jf][06][J`0304U9B@0405aLG01EEED0EEEE
069RHP80Ng]k00@0R8R80;Bd]02d];@0SHf=0P20P800102_[jl0WIfM09fMW@21PH4209>CT`0505iN
GP2=SHd0a/K60<K6aP2WYjL00P1lO7`01022PX80CDe=04e=C@2n_[h2096AT@040=KFeP33`l<0`l?3
09ZJVP80PH6100@0LW9b0861P@21PH40N7Qh0P2KVi/0101aLG40Kfm_06m_K`2YZJT209NGU`040<G5
a@2SXj<0Xj>S0:FUY@80O7al00@0emOG0:JVYP2VYZH0Vi^K0P27QhL01@2[Zj/0YJFU0:FUY@1jNWX0
Ng]k0080SHf=00@0Q8B4096AT@2ATI40_;bl0P2ATI401026QXH0X:2P0:2PX02VYZH2079bLP040:2P
X020P800P8200;no_`80/k>c00@0ZJVY02XZ:P0Z:RX0g=cL0P3Shn<01025QHD0OGem07emO@1kNg/2
07UiN@0409BDU03=cLd0cLg=0;bl_080OWin00@0XJ6Q08n?S`2?Shl0UIFE0P2;Rh/01@1lO7`0TI6A
096AT@30`<00Rh^;0080J6QX00@0B4Q803hn?P0n?Sh0P8200P1=CDd0102:RXX0I6AT06ATI023Ph<2
07UiN@04071`L028R8P0R8R8075aL@80MgMg00@0HF5Q07IfMP1fMWH0QHF50P1nOWh0102<S8`0LW9b
079bLP2j^[X20<30`00406IVIP2?Shl0Shn?0;fm_@80Hf=S00@0QHF505UIF@1IFET0CTi>0P1aLG40
0`1OGeooooooooooo`090000o`030?n000000?l0003o00L0003o0P3oP0030000o`030?n000000?l0
003o00D0oh001@000?l0103oP000003o0000o`000?l20?n000@0003o0P3oP0000`000?l0oh000?n0
00040000o`<0oh000P000?l20?n000l0003o0P3oP0040000o`80oh003P000?l20?n000X0003o0`3o
P0020000o`@0oh001`000?l30?n000/0003o00@0oh000000o`000?l0003o0`3oP0020000o`030?n0
00000?l0003o01<0003o0`3oP0030000o`040?n000000?l0003o0000o`<0oh000`000?l:ooooo`00
2Oooool0102?Shl0N7Qh07QhN02:RXX209fMW@0408b<S02][Jd0[Jf]0<30`080[:b/00@0Shn?09^K
V`2KVi/0JFUY0P27QhL0102DU9@0HV9R069RHP26QXH209RHV00406][J`2KVi/0Vi^K07alO080K6a/
00@0IVIV04e=C@1=CDd0FUYJ0P1nOWh01029RHT0[jn_0:n_[`2>SXh20820P0040;2`/02MWId0WIfM
08F5Q@80Ogmo00D0Cdm?08n?S`2k^k/0^k^k0:FUY@0207IfMP0408^;R`1;Bd/0Bd];0<K6aP80WYjN
00@0h>3P0;jn_P2n_[h0YjNW0P24Q8@0101_Kfl0QXJ608J6QP20P8020:6QX@0407inOP1kNg/0Ng]k
09ZJVP80/[:b00@0^k^k09FEU@2EUID0WinO0P2BTY80103De=@0Z:RX0:RXZ02d];@208V9R@050:BT
Y02OWil0WinO0820P01lO7`00P1oOgl0101ZJVX0MGEe07EeM@2WYjL209ZJVP0407YjNP3>c/h0c/k>
09NGU`80HV9R00@0UYJF0861P@21PH40XZ:R0P2_[jl0102IVIT0>SXj03Xj>P3QhN420>GUi@0407Qh
N01kNg/0Ng]k08R8R080S8b<00@0Z:RX0<G5a@35aLD0^KVi0P1bLW80102XZ:P0U9BD09BDU023Ph<2
07IfMP0508:2PP28R8P0R8R80;Ng]`1fMWH00P1gMgL01013@d<0?Shn03hn?P1kNg/205QHF00407Ui
N@1RHV80HV9R07MgM`80P82000@0QHF509NGU`2GUiL0KFe]0P1nOWh0101VIVH0K6a/06a/K01nOWh2
08b<S0040:VYZ@1iNGT0NGUi0;Vi^@80`<3000@0HF5Q08j>SP2>SXh0aLG50P1KFe/0101/K6`0H61P
061PH01WIfL306e]K@;ooooo1`000?l30?n001D0003o0`3oP0030000o`040?n000000?l0003o0000
o`80oh0010000?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000o`80oh003P000?l30?n0
00@0003o0P3oP0000`000?l0oh000?n0000@0000o`030?n000000?l0003o00H0003o00<0oh000000
o`000?l0103oP0070000o`<0oh002`000?l0103oP000003o0000o`000?l30?n00080003o00<0oh00
0000o`000?l04`000?l30?n000<0003o0`3oP0070000o`[ooooo0009ooooo`0408n?S`1hN7P0N7Qh
08Z:RP80WIfM00@0S8b<0:f][@2][Jd0`<300P2/[:`0102?Shl0Vi^K09^KV`1YJFT208N7Q`0409BD
U01RHV80HV9R08J6QP80V9RH00@0Jf][09^KV`2KVi/0O7al0P1/K6`0101VIVH0CDe=04e=C@1JFUX2
07inOP0408V9R@2_[jl0[jn_08j>SP80P82000@0/;2`09fMW@2MWId0QHF50P1oOgl01@1?Cdl0Shn?
0;^k^`2k^k/0YJFU0080MWIf00@0Rh^;04];B`1;Bd/0a/K60P2NWYh0103Ph>00_[jn0;jn_P2WYjL2
08B4Q00406m_K`26QXH0QXJ60820P080XJ6Q00@0OWin07]kN`1kNg/0VYZJ0P2b/[80102k^k/0UIFE
09FEU@2OWil209:BTP040=CDe02XZ:P0Z:RX0;Bd]080RHV900D0Y:BT09nOW`2OWil0P82007alO002
07moO`0406YZJP1eMGD0MGEe0:NWY`80VYZJ00@0NWYj0<k>cP3>c/h0UiNG0P1RHV80102FUYH0PH61
0861P@2RXZ820:n_[`0409VIV@0j>SX0>SXj0>7Qh@80iNGU00@0N7Qh07]kN`1kNg/0R8R80P2<S8`0
102XZ:P0aLG50<G5a@2i^KT2079bLP040:RXZ02DU9@0U9BD08>3P`80MWIf00D0PX:208R8R028R8P0
]kNg07IfMP0207MgM`0404=3@`0n?Sh0?Shn07]kN`80F5QH00@0NGUi069RHP1RHV80MgMg0P20P800
1025QHD0UiNG09NGU`1]KFd207inOP0406IVIP1/K6`0K6a/07inOP80S8b<00@0ZJVY07UiN@1iNGT0
^KVi0P30`<00101QHF40SXj>08j>SP35aLD205]KF`0406a/K01PH600H61P06MWI`<0KFe]0_ooool7
0000o`<0oh005@000?l30?n000<0003o00@0oh000000o`000?l0003o0P3oP0040000o`80oh0000<0
003o0?n0003oP00010000?l30?n00080003o0P3oP00>0000o`<0oh0010000?l20?n000030000o`3o
P000oh000100003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`040?n000L0003o0`3o
P00;0000o`040?n000000?l0003o0000o`<0oh000P000?l00`3oP000003o0000o`0C0000o`<0oh00
0`000?l30?n000L0003o2_ooool000Wooooo00@0SXj>07QhN01hN7P0RHV90P2][Jd0102CTi<0[Jf]
0:f][@30`<020:f][@0409RHV02LW9`0W9bL07YjNP80SHf=00@0SXj>069RHP1RHV80PH610P2FUYH0
1025QHD0[:b/0:b/[01fMWH207AdM00407moO`1HF5P0F5QH069RHP80QXJ600@0Ng]k0;Fe]@2e]KD0
W9bL0P1lO7`0102d];@0Xj>S0:>SX`25QHD208n?S`0506ATI02@T900`<300<30`02VYZH00P1jNWX0
102:RXX0Bd];04];B`35aLD209JFUP040=;BdP2l_;`0_;bl0:f][@80PX:200@0KFe]08R8R028R8P0
Ng]k0P2EUID0101iNGT0OGem07emO@28R8P209^KV`040;^k^`1nOWh0OWin08^;R`80[Jf]00@0aLG5
0:FUY@2UYJD0^[Zj0P25QHD01@2/[:`0XJ6Q0:6QX@2=SHd0P8200080QhN700@0J6QX07moO`1oOgl0
R8R80P2OWil01021PH40cLg=0<g=c@2FUYH206IVIP0408R8R022PX80PX:20:j^[P80/[:b00@0Q8B4
03/k>`0k>c/0gMgM0P3QhN400`1UIFD0N7Qh07QhN00307AdM00409fMW@34a<@0a<C40;Rh^080KFe]
00@0X:2P08R8R028R8P0OWin0P1fMWH01@1YJFT0QhN708N7Q`2^[Zh0IfMW0080KVi^00@0ATI603`l
?00l?3`0Lg=c0P1HF5P0101UIFD0QHF508F5Q@2=SHd2079bLP0407AdM021PH40PH6105eMG@80MWIf
00@0K6a/06UYJ@1YJFT0Q8B40P21PH40102<S8`0Kfm_06m_K`2a/K420:>SX`0406e]K@2:RXX0RXZ:
0:NWY`80DE5A00@0EUIF06][J`1[Jf/0EUIF0P1^KVh00`1bLW;oooooooooo`040000o`80oh0000<0
003o0?n0003oP0000`3oP00C0000o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0003o
0P3oP0070000o`80oh0010000?l30?n00080003o103oP00=0000o`80oh000`000?l30?n000030000
o`3oP000oh000100003o00<0oh000000o`000?l010000?l30?n00080003o103oP0070000o`<0oh00
2`000?l0103oP000003o0000o`000?l30?n00080003o00<0oh000000o`000?l01`000?l00`3oP000
003o0000o`090000o`030?n000000?l0003o00@0003o0`3oP0020000o`040?n000000?l0003o0000
o`[ooooo0009ooooo`0408f=S@1lO7`0O7al09BDU080Zj^[00@0SHf=0:n_[`2_[jl0`<300P2SXj<0
102GUiL0W9bL09bLW01hN7P208J6QP0409BDU01IFET0FEUI07alO080V9RH00@0OWin0:JVYP2VYZH0
JVYZ0P1RHV80101kNg/0Cdm?04m?C`1TI6@207emO@0409:BTP2c/k<0/k>c09jNWP80OGem00@0_[jn
0:BTY02TY:@0R8R80P2<S8`01@1XJ6P0Ti>C0<O7a`37alL0ZZZZ0080OGem00@0RHV904Y:BP1:BTX0
alO70P2IVIT01039bLT0^KVi0;Vi^@2[Zj/208R8R0040861P@2;Rh/0Rh^;07emO@80UYJF00@0QXJ6
09BDU02DU9@0W9bL0P2`/;00102n_[h0Shn?08n?S`2OWil20:^[Z`040=?Cd`2QXJ40XJ6Q0<K6aP80
PH6100D0[Zj^0:>SX`2SXj<0OWin07]kN`0208F5Q@04069RHP2EUID0UIFE08b<S080Xj>S00@0YjNW
0=gMg@3MgMd0SHf=0P1^KVh01029RHT0TY:B09:BTP2GUiL20;^k^`0407moO`0a<C40<C4a0=KFeP80
gMgM00@0HV9R07=cL`1cLg<0Q8B40P22PX80102a/K40aLG50<G5a@2h^;P206YZJP040::RXP2?Shl0
Shn?08^;R`80NGUi00D0LW9b06][J`1[Jf/0^;Rh06UYJ@0206ATI0040451@@0h>3P0>3Ph07QhN080
JVYZ00@0IfMW0820P020P800QhN70P1^KVh0102?Shl0P8200820P01dM7@206e]K@0406=SH`1QHF40
HF5Q06][J`80Ogmo00@0UIFE07IfMP1fMWH0[Jf]0P28R8P0101cLg<0SHf=08f=S@2/[:`205YJFP04
04m?C`1IFET0FEUI05IFEP80IfMW00<0H61Pooooooooool01`000?l30?n000T0003o0P3oP00:0000
o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0003o0P3oP0070000o`80oh0010000?l3
0?n00080003o0P3oP00>0000o`<0oh0010000?l20?n000040000o`3oP000oh000000o`80oh003@00
0?l00`3oP000003o0000o`060000o`030?n000000?l0003o00@0oh001P000?l40?n000/0003o00@0
oh000000o`000?l0003o0`3oP00H0000o`030?n000000?l0003o00@0003o1P3oP0030000o`[ooooo
0009ooooo`0408f=S@1lO7`0O7al09BDU080Zj^[00@0SHf=0:n_[`2_[jl0`<300P2SXj<0102GUiL0
W9bL09bLW01hN7P208J6QP0409BDU01IFET0FEUI07alO080V9RH00@0OWin0:JVYP2VYZH0JVYZ0P1R
HV80101kNg/0Cdm?04m?C`1TI6@207emO@0409:BTP2c/k<0/k>c09jNWP80OGem00@0_[jn0:BTY02T
Y:@0R8R80P2<S8`01@1XJ6P0Ti>C0<O7a`37alL0ZZZZ0080OGem00@0RHV904Y:BP1:BTX0alO70P2I
VIT01039bLT0^KVi0;Vi^@2[Zj/208R8R0040861P@2;Rh/0Rh^;07emO@80UYJF00@0QXJ609BDU02D
U9@0W9bL0P2`/;00102n_[h0Shn?08n?S`2OWil20:^[Z`040=?Cd`2QXJ40XJ6Q0<K6aP80PH6100D0
[Zj^0:>SX`2SXj<0OWin07]kN`0208F5Q@04069RHP2EUID0UIFE08b<S080Xj>S00@0YjNW0=gMg@3M
gMd0SHf=0P1^KVh01029RHT0TY:B09:BTP2GUiL20;^k^`0407moO`0a<C40<C4a0=KFeP80gMgM00@0
HV9R07=cL`1cLg<0Q8B40P22PX80102a/K40aLG50<G5a@2h^;P206YZJP040::RXP2?Shl0Shn?08^;
R`80NGUi00D0LW9b06][J`1[Jf/0^;Rh06UYJ@0206ATI0040451@@0h>3P0>3Ph07QhN080JVYZ00@0
IfMW0820P020P800QhN70P1^KVh0102?Shl0P8200820P01dM7@206e]K@0406=SH`1QHF40HF5Q06][
J`80Ogmo00@0UIFE07IfMP1fMWH0[Jf]0P28R8P0101cLg<0SHf=08f=S@2/[:`205YJFP0404m?C`1I
FET0FEUI05IFEP80IfMW00<0H61Pooooooooool01`000?l30?n000T0003o0P3oP00:0000o`030?n0
00000?l0003o00<0003o00@0oh000000o`000?l0003o0P3oP0070000o`80oh0010000?l30?n00080
003o0P3oP00>0000o`<0oh0010000?l20?n000040000o`3oP000oh000000o`80oh003@000?l00`3o
P000003o0000o`060000o`030?n000000?l0003o00@0oh001P000?l40?n000/0003o00@0oh000000
o`000?l0003o0`3oP00H0000o`030?n000000?l0003o00@0003o1P3oP0030000o`[ooooo0009oooo
o`04096AT@1kNg/0Ng]k09FEU@80[:b/00@0T92@0:RXZ02XZ:P0_[jn0P2VYZH01026QXH0TY:B09:B
TP1dM7@208J6QP04096AT@1@D500D51@08>3P`80WYjN00@0RXZ:0:BTY02TY:@0H61P0P1TI6@0101l
O7`0E5AD05ADE01hN7P20820P00408j>SP30`<00`<3009NGU`80P82000@0_[jn0:2PX02PX:00QXJ6
0P2@T9001@1^KVh0T92@0;^k^`2k^k/0[Jf]0080QXJ600@0UYJF055AD@1ADE40^[Zj0P2FUYH0103C
dm<0^KVi0;Vi^@2ZZZX208F5Q@0406IVIP2=SHd0SHf=0820P080SXj>00@0S8b<09nOW`2OWil0U9BD
0P2TY:@0102a/K40TY:B09:BTP2CTi<20;Jf]P040=3@d02OWil0WinO0;Rh^080NGUi00@0SXj>08f=
S@2=SHd0MGEe0`21PH40101ADE40Shn?08n?S`1aLG4209RHV0040:RXZ03Fe]H0e]KF08V9R@80PX:2
00@0Ph>30;>c/`2c/k<0WinO0P3?cll0101gMgL0CDe=04e=C@3Rh^820=cLg00406YZJP21PH40PH61
07AdM080Jf][00@0_Kfm0<71`@31`L40^k^k0P1oOgl0102MWId0TY:B09:BTP2EUID206a/K00508f=
S@1NGUh0GUiN0:RXZ01aLG400P1QHF40101@D500?Cdm03dm?@1fMWH206UYJ@0405aLG01hN7P0N7Qh
07inOP80IFEU00<0Q8B4071`L01`L7000`1gMgL0101WIfL0K6a/06a/K01fMWH208J6QP0409BDU01d
M7@0M7Ad0<?3``80OGem00@0Ogmo096AT@2ATI40ZJVY0P1RHV80101GEeL0FEUI05UIF@1=CDd206][
J`0306=SHooooooooooo00T0003o00<0oh000000o`000?l01`000?l20?n000X0003o00<0oh000000
o`000?l00`000?l0103oP000003o0000o`000?l20?n000L0003o0`3oP0030000o`<0oh000P000?l2
0?n000l0003o0P3oP0030000o`<0oh0000<0003o0?n0003oP00020000?l20?n000H0003o00<0oh00
0000o`000?l00`000?l0103oP000003o0000o`3oP0020000o`@0oh001P000?l40?n000T0003o0P3o
P0040000o`<0oh000`000?l20?n001<0003o00<0oh000000o`000?l01P000?l40?n000<0003o2_oo
ool000Wooooo00@0TI6A07alO01lO7`0SXj>0P2KVi/0102?Shl0Z:RX0:RXZ02h^;P20:b/[00408J6
QP2KVi/0Vi^K06QXJ080SXj>00@0UIFE061PH01PH600OGem0P2LW9`01027QhL0V9RH09RHV01[Jf/2
06ATI004075aL@1=CDd0CDe=07IfMP80L71`00@0QhN70;Ng]`2g]kL0V9RH0P1eMGD0102m_Kd0Vi^K
09^KV`29RHT209FEU@0506UYJ@2EUID0`<300<30`02[Zj/00P2>SXh0102DU9@0BTY:04Y:BP32`/82
0:BTY0040<k>cP2d];@0];Bd0::RXP80Rh^;00@0IVIV0820P020P800Lg=c0P1iNGT0101nOWh0UiNG
09NGU`2`/;030:RXZ080TY:B00@0UYJF09VIV@2IVIT0WYjN0P2VYZH0102g]kL0Ogmo07moO`2XZ:P2
09^KV`0508>3P`2<S8`0PX:208:2PP1@D5000P2LW9`0101oOgl0TY:B09:BTP2a/K420=GEe@04096A
T@27QhL0QhN706e]K@80Zj^[00@0XJ6Q0=[JfP3Jf]X0JVYZ0P1:BTX30=kNgP0407UiN@1YJFT0JFUY
07MgM`80FEUI00@0bLW90:RXZ02XZ:P0/;2`0P28R8P0102FUYH0SHf=08f=S@2DU9@207EeM@05096A
T@1XJ6P0J6QX07moO`2CTi<00P1MGEd0101<C4`0?Cdm03dm?@1oOgl2061PH00405MGE`1]KFd0KFe]
07]kN`80G5aL00@0NWYj07=cL`1cLg<0L71`0P1jNWX0101]KFd0LW9b079bLP1oOgl209JFUP0408f=
S@1mOGd0OGem0=GEe@80LW9b00@0TY:B09ZJVP2JVYX0XZ:R0P1]KFd306=SH`04059BDP1dM7@0M7Ad
06][J`;ooooo2@000?l00`3oP000003o0000o`0C0000o`030?n000000?l0003o00<0003o00@0oh00
0000o`000?l0003o0P3oP0070000o`80oh0010000?l30?n00080003o0P3oP00<0000o`80oh002P00
0?l20?n000P0003o0P3oP0040000o`<0oh0020000?l00`3oP000003o0000o`040?n000D0003o0P3o
P0020000o`030?n000000?l0003o00`0003o103oP0030000o`80oh000`000?l00`3oP000003o0000
o`0=0000o`030?n000000?l0003o00T0003o00@0oh000000o`000?l0003o2_ooool000Wooooo00@0
TI6A07alO01lO7`0SXj>0P2KVi/0102?Shl0Z:RX0:RXZ02h^;P20:b/[00408J6QP2KVi/0Vi^K06QX
J080SXj>00@0UIFE061PH01PH600OGem0P2LW9`01027QhL0V9RH09RHV01[Jf/206ATI004075aL@1=
CDd0CDe=07IfMP80L71`00@0QhN70;Ng]`2g]kL0V9RH0P1eMGD0102m_Kd0Vi^K09^KV`29RHT209FE
U@0506UYJ@2EUID0`<300<30`02[Zj/00P2>SXh0102DU9@0BTY:04Y:BP32`/820:BTY0040<k>cP2d
];@0];Bd0::RXP80Rh^;00@0IVIV0820P020P800Lg=c0P1iNGT0101nOWh0UiNG09NGU`2`/;030:RX
Z080TY:B00@0UYJF09VIV@2IVIT0WYjN0P2VYZH0102g]kL0Ogmo07moO`2XZ:P209^KV`0508>3P`2<
S8`0PX:208:2PP1@D5000P2LW9`0101oOgl0TY:B09:BTP2a/K420=GEe@04096AT@27QhL0QhN706e]
K@80Zj^[00@0XJ6Q0=[JfP3Jf]X0JVYZ0P1:BTX30=kNgP0407UiN@1YJFT0JFUY07MgM`80FEUI00@0
bLW90:RXZ02XZ:P0/;2`0P28R8P0102FUYH0SHf=08f=S@2DU9@207EeM@05096AT@1XJ6P0J6QX07mo
O`2CTi<00P1MGEd0101<C4`0?Cdm03dm?@1oOgl2061PH00405MGE`1]KFd0KFe]07]kN`80G5aL00@0
NWYj07=cL`1cLg<0L71`0P1jNWX0101]KFd0LW9b079bLP1oOgl209JFUP0408f=S@1mOGd0OGem0=GE
e@80LW9b00@0TY:B09ZJVP2JVYX0XZ:R0P1]KFd306=SH`04059BDP1dM7@0M7Ad06][J`;ooooo2@00
0?l00`3oP000003o0000o`0C0000o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0003o
0P3oP0070000o`80oh0010000?l30?n00080003o0P3oP00<0000o`80oh002P000?l20?n000P0003o
0P3oP0040000o`<0oh0020000?l00`3oP000003o0000o`040?n000D0003o0P3oP0020000o`030?n0
00000?l0003o00`0003o103oP0030000o`80oh000`000?l00`3oP000003o0000o`0=0000o`030?n0
00000?l0003o00T0003o00@0oh000000o`000?l0003o2_ooool000Wooooo00@0T92@08>3P`23Ph<0
Shn?0P2IVIT0102>SXh0[jn_0:n_[`2XZ:P20;Fe]@0408J6QP2?Shl0Shn?05]KF`80TI6A00@0R8R8
06IVIP1VIVH0TY:B0P2=SHd01028R8P0VYZJ09ZJVP1_Kfl205iNGP04071`L01LG5`0G5aL06i^KP80
M7Ad00@0QhN70;Fe]@2e]KD0TY:B0P28R8P0103:b/X0X:2P0:2PX02@T90209>CT`0506IVIP2ATI40
`<300<30`02XZ:P00P29RHT01025QHD0BTY:04Y:BP2k^k/20:f][@040<_;b`2`/;00/;2`09VIV@80
Ogmo00@0KFe]08f=S@2=SHd0K6a/0P1cLg<01027QhL0Rh^;08^;R`2EUID209VIV@040:ZZZP2>SXh0
SXj>08R8R080]kNg00@0Zj^[0:ZZZP2ZZZX0];Bd0P2?Shl01@2f][H0RHV908V9R@27QhL0TY:B0080
OGem00@0EUIF08f=S@2=SHd0QhN70P20P800102_[jl0d];B0=;BdP2:RXX208n?S`04061PH02[Zj/0
Zj^[0:6QX@80g=cL00@0HV9R04e=C@1=CDd0f=SH0P3AdM40101kNg/0JFUY06UYJ@1gMgL2055AD@04
0<k>cP2j^[X0^[Zj0;Rh^080U9BD00@0MGEe06a/K01/K6`0RHV90P1ZJVX01@1oOgl0NWYj07YjNP1f
MWH0UiNG0080E5AD00@0@410051@D01@D500QHF50P1iNGT0101RHV80H61P061PH022PX8208F5Q@04
08N7Q`1[Jf/0Jf][06EUI@80JFUY00@0NGUi08>3P`23Ph<0Rh^;0P2a/K401024Q8@0NGUi07UiN@3G
emL207AdM00409FEU@2NWYh0WYjN09FEU@80FEUI00@0J6QX05eMG@1MGEd0CTi>0P1[Jf/00`1/K6co
ooooooooo`070000o`80oh0000<0003o0?n0003oP0000`000?l00`3oP000003o0000o`0:0000o`80
oh0000<0003o0?n000000?l010000?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0040000
o`L0oh0050000?l0103oP000003o0000o`000?l20?n000030000o`3oP000oh0000D0003o0P3oP004
0000o`<0oh0020000?l00`3oP000003o0000o`040?n000D0003o1@3oP00>0000o`@0oh004`000?l2
0?n000<0003o00<0oh000000o`000?l010000?l20?n000040000o`3oP000oh000?n000<0003o2_oo
ool000Wooooo00@0R8R807inOP1nOWh0R8R80P26QXH01025QHD0/k>c0;>c/`2QXJ420;jn_P0408n?
S`2;Rh/0Rh^;05]KF`80U9BD00@0RXZ:06UYJ@1YJFT0QHF50P2EUID01021PH40UIFE09FEU@1fMWH2
05mOG`04071`L01HF5P0F5QH06IVIP80MGEe00@0RXZ:0<C4a034a<@0Ti>C0P26QXH0102o_kl0SXj>
08j>SP25QHD207emO@05069RHP2@T900/K6a0;6a/@2GUiL00P2<S8`01020P800CTi>04i>CP2l_;`2
09^KV`040;bl_02b/[80/[:b09nOW`80OGem00@0KVi^08R8R028R8P0MGEe0P1_Kfl0102=SHd0Shn?
08n?S`2c/k<20:ZZZP040:JVYP2TY:@0Y:BT092@T080ZZZZ00@0a/K60::RXP2RXZ80WinO0P25QHD0
1@2k^k/0Ogmo07moO`2;Rh/0Shn?0080Rh^;00@0LG5a09ZJVP2JVYX0R8R80P1cLg<0102`/;00alO7
0<O7a`20P80209jNWP0405iNGP2PX:00X:2P09NGU`80gmoO00@0EeMG05eMG@1MGEd0hN7Q0P31`L40
102IVIT0N7Qh07QhN01mOGd205]KF`040<;2`P3;bl/0bl_;0:^[Z`80Vi^K00@0W9bL08V9R@29RHT0
YZJV0P1gMgL01@20P800Ti>C09>CT`2CTi<0VYZJ0080N7Qh00@0@D5105ADE01DE5@0P8200P1mOGd0
101oOgl0L71`071`L02:RXX2069RHP0407=cL`1[Jf/0Jf][06YZJP80IFEU00@0PH6108j>SP2>SXh0
SXj>0P2j^[X0101jNWX0RHV908V9R@3Lg=`205MGE`0409bLW02EUID0UIFE08V9R@80Ph>300@0MGEe
06YZJP1ZJVX0E5AD0P1bLW800`1iNGWoooooooooo`070000o`80oh0000<0003o0?n0003oP0000`00
0?l00`3oP000003o0000o`0=0000o`030?n000000?l0003o00<0003o00@0oh000000o`000?l0003o
0P3oP0070000o`80oh0010000?l30?n00080003o0P3oP00<0000o`80oh001`000?l20?n000@0003o
0P3oP00;0000o`<0oh000`000?l20?n000<0003o1`3oP0050000o`@0oh0040000?l30?n001<0003o
0P3oP0030000o`<0oh002@000?l0103oP000003o0000o`000?l:ooooo`002Oooool01028R8P0OWin
07inOP28R8P208J6QP0408F5Q@2c/k<0/k>c0:6QX@80_[jn00@0Shn?08^;R`2;Rh/0Fe]K0P2DU9@0
102:RXX0JFUY06UYJ@25QHD209FEU@040861P@2EUID0UIFE07IfMP80GemO00@0L71`05QHF01HF5P0
IVIV0P1eMGD0102:RXX0a<C40<C4a02CTi<208J6QP040;no_`2>SXh0SXj>08F5Q@80OGem00D0HV9R
092@T02a/K40/K6a09NGU`0208b<S0040820P01>CTh0CTi>0;bl_080Vi^K00@0_;bl0;:b/P2b/[80
WinO0P1mOGd0101^KVh0R8R808R8R01eMGD206m_K`0408f=S@2?Shl0Shn?0;>c/`80ZZZZ00@0YZJV
0:BTY02TY:@0T92@0P2ZZZX01036a/H0XZ:R0::RXP2OWil208F5Q@050;^k^`1oOgl0Ogmo08^;R`2?
Shl00P2;Rh/0101aLG40VYZJ09ZJVP28R8P207=cL`040;2`/037alL0alO70820P080WYjN00@0GUiN
0:2PX02PX:00UiNG0P3Ogml0101GEeL0GEeM05eMG@3QhN420<71`@0409VIV@1hN7P0N7Qh07emO@80
Fe]K00@0`/;20<_;b`3;bl/0Zj^[0P2KVi/0102LW9`0RHV908V9R@2VYZH207MgM`050820P02CTi<0
Ti>C09>CT`2JVYX00P1hN7P01011@D40E5AD05ADE020P80207emO@0407moO`1`L700L71`08Z:RP80
HV9R00@0Lg=c06][J`1[Jf/0JVYZ0P1UIFD01021PH40SXj>08j>SP2>SXh20;Zj^P0407YjNP29RHT0
RHV90=cLg080EeMG00@0W9bL09FEU@2EUID0RHV90P23Ph<0101eMGD0JVYZ06YZJP1DE5@2079bLP03
07UiNOoooooooooo00L0003o0P3oP0000`000?l0oh000?n000030000o`030?n000000?l0003o00d0
003o00<0oh000000o`000?l00`000?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0040000
o`<0oh000P000?l20?n000`0003o0P3oP0070000o`80oh0010000?l20?n000/0003o0`3oP0030000
o`80oh000`000?l70?n000D0003o103oP00@0000o`<0oh004`000?l20?n000<0003o0`3oP0090000
o`040?n000000?l0003o0000o`[ooooo0009ooooo`0409RHV02:RXX0RXZ:08N7Q`80P82000@0OWin
0:n_[`2_[jl0/k>c0P2d];@01023Ph<0QXJ608J6QP1JFUX209nOW`0409:BTP1PH600H61P06e]K@80
V9RH00@0QhN709:BTP2BTY80R8R80P1WIfL0101^KVh0D51@051@D01NGUh207YjNP0408R8R02^[Zh0
[Zj^09:BTP80OGem00@0`<3008>3P`23Ph<0PH610P2=SHd01@1XJ6P0UIFE0;Bd]02d];@0V9RH0080
VIVI00@0P82005MGE`1GEeL0][Jf0P2RXZ801038b<P0[Jf]0:f][@2YZJT207QhN004075aL@27QhL0
QhN707UiN@80DU9B00@0P820096AT@2ATI40_;bl0P2TY:@0102DU9@0WIfM09fMW@1oOgl20:f][@04
0=CDe02SXj<0Xj>S0:JVYP80RHV900D0`/;207]kN`1kNg/0MWIf08F5Q@0209:BTP040820P02>SXh0
SXj>09fMW@80IFEU00@0YZJV0;Zj^P2j^[X0Q8B40P2WYjL0101HF5P0TI6A096AT@2EUID20=oOg`04
051@D01cLg<0Lg=c0>CTi080_Kfm00@0UiNG07YjNP1jNWX0MgMg0P1[Jf/0102[Zj/0emOG0=OGe`2O
Wil20861P@0409^KV`2>SXh0SXj>09^KV`80Ng]k00D0RHV90:2PX02PX:00Z:RX09fMW@0207emO@04
0410@01JFUX0FUYJ096AT@80EUIF00@0X:2P079bLP1bLW80N7Qh0P1XJ6P0101bLW80LG5a075aL@1^
KVh206e]K@0407emO@2GUiL0UiNG096AT@80/k>c00@0KVi^09BDU02DU9@0d];B0P1CDe<0102:RXX0
T92@092@T02;Rh/209:BTP0404i>CP1/K6`0K6a/04i>CP80LG5a00<0JVYZooooooooool01`000?l5
0?n000<0003o00<0oh000000o`000?l03@000?l30?n000<0003o00@0oh000000o`000?l0003o0P3o
P0070000o`80oh0010000?l30?n00080003o0P3oP0080000o`040?n000000?l0003o0000o`80oh00
1P000?l30?n000@0003o0P3oP00=0000o`040?n000000?l0003o0000o`80oh000`000?l30?n00004
0000o`3oP000oh000?n000L0003o0P3oP00@0000o`<0oh000P000?l00`3oP000003o0000o`0>0000
o`80oh000`000?l30?n000H0003o00@0oh000000o`000?l0oh000`000?l:ooooo`002Oooool308f=
S@0408J6QP1nOWh0OWin07moO`80]KFe00@0bLW90<G5a@35aLD0UYJF0P29RHT0101OGel0VIVI09VI
V@1nOWh205iNGP0307AdM02GUiL0UiNG00<0RHV900@0Q8B406EUI@1UIFD0IfMW0P1<C4`0101BDU80
OWin07inOP20P8020:b/[00409BDU01jNWX0NWYj0;no_`80Rh^;00D0Q8B408F5Q@25QHD0KVi^08R8
R0020<71`@040:2PX02YZJT0ZJVY08B4Q080FEUI00@0_[jn0;6a/@2a/K40clo?0P2a/K40102e]KD0
Ng]k07]kN`1mOGd208j>SP0408V9R@1OGel0GemO08n?S`80YZJV00@0[:b/0:6QX@2QXJ40Ti>C0P2R
XZ80102;Rh/0YZJV0:JVYP3<c<`30:BTY080SXj>00D0]kNg07IfMP1fMWH0Lg=c0861P@0208j>SP04
09:BTP2JVYX0VYZJ0;Rh^080KVi^00@0ZJVY0;Fe]@2e]KD0TI6A0P2VYZH0101XJ6P0RXZ:08Z:RP2Z
ZZX20>GUi@0404m?C`1gMgL0MgMg0>?Sh`80[Zj^00@0VIVI08F5Q@25QHD0L71`0P1kNg/0102m_Kd0
g]kN0=kNgP2HV9P206EUI@040:2PX02GUiL0UiNG0820P080NWYj00D0Jf][096AT@2ATI40^KVi08n?
S`02075aL@0404U9B@1SHf<0Hf=S08Z:RP80BDU900@0XZ:R07IfMP1fMWH0JVYZ0P1hN7P0101[Jf/0
OWin07inOP1ZJVX206i^KP0407EeM@2:RXX0RXZ:096AT@80X:2P00@0Kfm_08f=S@2=SHd0d=3@0P1F
EUH0101kNg/0S8b<08b<S024Q8@2096AT@0406UYJ@1JFUX0FUYJ05]KF`80Ng]k00<0NGUioooooooo
ool01`000?l50?n000L0003o0P3oP00:0000o`<0oh001`000?l20?n000L0003o0P3oP0040000o`T0
oh004`000?l20?n000@0003o0P3oP0080000o`80oh000`000?l00`3oP000003o0000o`060000o`<0
oh0000@0003o0?n0003oP000oh001P000?l30?n000`0003o00@0oh000000o`000?l0003o0P3oP003
0000o`030?n000000?l0003o01<0003o0`3oP0070000o`<0oh000`000?l:ooooo`002Oooool308f=
S@0408J6QP1nOWh0OWin07moO`80]KFe00@0bLW90<G5a@35aLD0UYJF0P29RHT0101OGel0VIVI09VI
V@1nOWh205iNGP0307AdM02GUiL0UiNG00<0RHV900@0Q8B406EUI@1UIFD0IfMW0P1<C4`0101BDU80
OWin07inOP20P8020:b/[00409BDU01jNWX0NWYj0;no_`80Rh^;00D0Q8B408F5Q@25QHD0KVi^08R8
R0020<71`@040:2PX02YZJT0ZJVY08B4Q080FEUI00@0_[jn0;6a/@2a/K40clo?0P2a/K40102e]KD0
Ng]k07]kN`1mOGd208j>SP0408V9R@1OGel0GemO08n?S`80YZJV00@0[:b/0:6QX@2QXJ40Ti>C0P2R
XZ80102;Rh/0YZJV0:JVYP3<c<`30:BTY080SXj>00D0]kNg07IfMP1fMWH0Lg=c0861P@0208j>SP04
09:BTP2JVYX0VYZJ0;Rh^080KVi^00@0ZJVY0;Fe]@2e]KD0TI6A0P2VYZH0101XJ6P0RXZ:08Z:RP2Z
ZZX20>GUi@0404m?C`1gMgL0MgMg0>?Sh`80[Zj^00@0VIVI08F5Q@25QHD0L71`0P1kNg/0102m_Kd0
g]kN0=kNgP2HV9P206EUI@040:2PX02GUiL0UiNG0820P080NWYj00D0Jf][096AT@2ATI40^KVi08n?
S`02075aL@0404U9B@1SHf<0Hf=S08Z:RP80BDU900@0XZ:R07IfMP1fMWH0JVYZ0P1hN7P0101[Jf/0
OWin07inOP1ZJVX206i^KP0407EeM@2:RXX0RXZ:096AT@80X:2P00@0Kfm_08f=S@2=SHd0d=3@0P1F
EUH0101kNg/0S8b<08b<S024Q8@2096AT@0406UYJ@1JFUX0FUYJ05]KF`80Ng]k00<0NGUioooooooo
ool01`000?l50?n000L0003o0P3oP00:0000o`<0oh001`000?l20?n000L0003o0P3oP0040000o`T0
oh004`000?l20?n000@0003o0P3oP0080000o`80oh000`000?l00`3oP000003o0000o`060000o`<0
oh0000@0003o0?n0003oP000oh001P000?l30?n000`0003o00@0oh000000o`000?l0003o0P3oP003
0000o`030?n000000?l0003o01<0003o0`3oP0070000o`<0oh000`000?l:ooooo`002Oooool0102<
S8`0Z:RX0:RXZ01oOgl207UiN@040820P02h^;P0^;Rh0<S8b080`/;200@0VIVI08J6QP26QXH0GemO
0P2PX:00102@T900GEeM05eMG@1ZJVX208J6QP0408Z:RP2>SXh0SXj>08>3P`80Kfm_00@0J6QX04];
B`1;Bd/0FUYJ0P22PX801021PH40[:b/0:b/[02HV9P208Z:RP040<?3``2=SHd0SHf=08Z:RP80Shn?
00D0IfMW08J6QP30`<00`<3009fMW@020:VYZ@0407]kN`1HF5P0F5QH0:j^[P80YjNW00@0c/k>0:^[
Z`2[Zj/0[:b/0P1iNGT0101kNg/0Q8B408B4Q028R8P2051@D00408F5Q@2ZZZX0ZZZZ0<30`080VYZJ
00@0UYJF0:NWY`2WYjL0XJ6Q0P2UYJD0103?cll0[:b/0:b/[02MWId209BDU0050<;2`P1aLG40LG5a
07AdM021PH400P2:RXX0102IVIT0TI6A096AT@2f][H207=cL`040::RXP2TY:@0Y:BT08N7Q`80WinO
00@0LW9b08J6QP26QXH0YZJV0P3MgMd0101<C4`0R8R808R8R03UiND209bLW0<0Shn?00@0QXJ608F5
Q@25QHD0/[:b0P3Kfm/0102ATI40HV9R069RHP2OWil209ZJVP0408f=S@2OWil0WinO07moO`80QhN7
00D0/[:b07emO@27QhL0QhN705YJFP02065QH@0407]kN`12@T80@T9209ZJVP80N7Qh00@0HV9R07Ui
N@1iNGT0Lg=c0P2@T900101VIVH0VIVI09VIV@1YJFT20:2PX00409RHV02PX:00X:2P06EUI@80RXZ:
00@0`<3006EUI@1UIFD0NWYj0P2OWil01023Ph<0N7Qh07QhN01lO7`205]KF`0405YJFP24Q8@0Q8B4
07EeM@;ooooo1`000?l50?n000L0003o0P3oP00:0000o`<0oh001`000?l20?n000L0003o0P3oP004
0000o`<0oh000P000?l00`3oP000003o0000o`070000o`040?n000000?l0003o0000o`80oh001`00
0?l20?n000@0003o0P3oP0080000o`80oh0030000?l30?n000030000o`3oP000oh0000L0003o0`3o
P00<0000o`040?n000000?l0003o0000o`80oh000`000?l00`3oP000003o0000o`0C0000o`030?n0
00000?l0003o00L0003o0`3oP0030000o`[ooooo0009ooooo`0408^;R`2VYZH0YZJV07emO@80Lg=c
00@0OWin0:j^[P2^[Zh0`l?30P2WYjL0102CTi<0O7al07alO01MGEd209bLW00408f=S@1SHf<0Hf=S
079bLP80Ogmo00@0V9RH08J6QP26QXH0QXJ60P1dM7@0101YJFT0@T920492@P1>CTh207inOP0407If
MP2i^KT0^KVi09bLW080QXJ600@0^;Rh08f=S@2=SHd0RXZ:0P2;Rh/01@1MGEd0NGUi0;:b/P2b/[80
UiNG0080X:2P00@0Ph>305]KF`1KFe/0^[Zj0P2[Zj/0103;bl/0YZJV0:JVYP2TY:@207YjNP0408>3
P`25QHD0QHF508R8R080CDe=00@0P8200:>SX`2SXj<0/k>c0P2SXj<0102GUiL0XJ6Q0:6QX@2JVYX2
0:2PX0040<S8b02SXj<0Xj>S09VIV@80SHf=00D0_[jn07IfMP1fMWH0LW9b08:2PP0208n?S`0409JF
UP2LW9`0W9bL0<30`080O7al00@0Y:BT0:RXZ02XZ:P0SXj>0P2EUID0101oOgl0V9RH09RHV02ZZZX2
0>3Ph00403`l?02CTi<0Ti>C0>?Sh`80UYJF00@0OWin08:2PP22PX80TI6A0P2LW9`01036a/H0f][J
0=[JfP29RHT205MGE`0409BDU02IVIT0VIVI08B4Q080SXj>00D0Q8B40:>SX`2SXj<0_kno08j>SP02
07moO`0404I6AP1NGUh0GUiN0861P@80Bd];00@0RHV907IfMP1fMWH0O7al0P2:RXX01025QHD0RXZ:
08Z:RP1gMgL20;Bd]00406=SH`2=SHd0SHf=08^;R`80[Zj^00@0KFe]09^KV`2KVi/0YjNW0P1aLG40
101cLg<0[:b/0:b/[02:RXX207alO004065QH@1CDe<0De=C05=CD`80Ng]k00<0K6a/ooooooooool0
1`000?l30?n000D0003o00<0oh000000o`000?l03@000?l30?n000<0003o00@0oh000000o`000?l0
003o0P3oP0040000o`80oh0000<0003o0?n0003oP00010000?l30?n00080003o00<0oh000000o`00
0?l01`000?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0040000o`80oh0020000?l20?n0
00`0003o0`3oP0000`000?l0oh000?n000070000o`<0oh0000<0003o0?n0003oP0002@000?l0103o
P000003o0000o`000?l30?n00080003o00<0oh000000o`000?l020000?l20?n000@0003o0P3oP00=
0000o`<0oh000`000?l:ooooo`002Oooool0102;Rh/0YZJV0:JVYP1mOGd207=cL`0407inOP2^[Zh0
[Zj^0<?3``80YjNW00@0Ti>C07alO01lO7`0GEeM0P2LW9`0102=SHd0Hf=S06=SH`1bLW8207moO`04
09RHV026QXH0QXJ608J6QP80M7Ad00@0JFUY0492@P12@T80CTi>0P1nOWh0101fMWH0^KVi0;Vi^@2L
W9`208J6QP040;Rh^02=SHd0SHf=08Z:RP80Rh^;00D0GEeM07UiN@2b/[80/[:b09NGU`020:2PX004
08>3P`1KFe/0Fe]K0;Zj^P80Zj^[00@0bl_;0:JVYP2VYZH0Y:BT0P1jNWX01023Ph<0QHF508F5Q@28
R8P204e=C@040820P02SXj<0Xj>S0;>c/`80Xj>S00@0UiNG0:6QX@2QXJ40VYZJ0P2PX:001038b<P0
Xj>S0:>SX`2IVIT208f=S@050;jn_P1fMWH0MWIf079bLP22PX800P2?Shl0102FUYH0W9bL09bLW030
`<0207alO0040:BTY02XZ:P0Z:RX08j>SP80UIFE00@0Ogmo09RHV02HV9P0ZZZZ0P3Ph>00100l?3`0
Ti>C09>CT`3Shn<209JFUP0407inOP22PX80PX:2096AT@80W9bL00@0a/K60=[JfP3Jf]X0RHV90P1G
EeL0102DU9@0VIVI09VIV@24Q8@208j>SP0508B4Q02SXj<0Xj>S0;no_`2>SXh00P1oOgl01016ATH0
GUiN05iNGP21PH4204];B`0408V9R@1fMWH0MWIf07alO080RXZ:00@0QHF508Z:RP2:RXX0MgMg0P2d
];@0101SHf<0SHf=08f=S@2;Rh/20:j^[P0406e]K@2KVi/0Vi^K0:NWY`80LG5a00@0Lg=c0:b/[02/
[:`0RXZ:0P1lO7`0101QHF40De=C05=CD`1CDe<207]kN`0306a/K?oooooooooo00L0003o0`3oP005
0000o`030?n000000?l0003o00d0003o0`3oP0030000o`040?n000000?l0003o0000o`80oh001000
0?l20?n000030000o`3oP000oh0000@0003o0`3oP0020000o`030?n000000?l0003o00L0003o00@0
oh000000o`000?l0003o0P3oP0070000o`80oh0010000?l20?n000P0003o0P3oP00<0000o`<0oh00
00<0003o0?n0003oP0001`000?l30?n000030000o`3oP000oh0000T0003o00@0oh000000o`000?l0
003o0`3oP0020000o`030?n000000?l0003o00P0003o0P3oP0040000o`80oh003@000?l30?n000<0
003o2_ooool000Wooooo00@0RHV90:VYZ@2YZJT0P8200P1^KVh0101kNg/0[Zj^0:j^[P2o_kl20::R
XP040:2PX01mOGd0OGem06EUI@80UIFE00@0S8b<06MWI`1WIfL0NGUi0P1nOWh0102UYJD0RHV908V9
R@2:RXX207YjNP0406=SH`1:BTX0BTY:05IFEP80P82000@0HF5Q0;Vi^@2i^KT0/K6a0P2DU9@01039
bLT0Ti>C09>CT`2?Shl209>CT`0506i^KP21PH40c/k>0<k>cP2QXJ400P2YZJT0101kNg/0EEEE05EE
E@2b/[820:ZZZP040<K6aP2/[:`0[:b/0:b/[080Ogmo00@0Ng]k08N7Q`27QhL0QXJ60P1<C4`0101m
OGd0YZJV0:JVYP2d];@20;2`/0040820P02TY:@0Y:BT0:FUY@80/K6a00@0f][J0:>SX`2SXj<0X:2P
0P2LW9`00`34a<@0MgMg07MgM`0207]kN`80Ti>C00@0SXj>0:^[Z`2[Zj/0[Jf]0P2;Rh/0102YZJT0
/[:b0;:b/P2ATI4208J6QP0409VIV@2GUiL0UiNG0;6a/@80gMgM00@0>c/k09fMW@2MWId0hn?S0P2K
Vi/0101kNg/0Lg=c07=cL`26QXH209bLW0040<g=c@30`<00`<3009BDU080E5AD00@0WIfM08n?S`2?
Shl0NGUi0P2?Shl01@2:RXX0U9BD09BDU02a/K40RHV90080PH6100@0<30`05YJFP1JFUX0MWIf0P1:
BTX0101eMGD0O7al07alO01oOgl207UiN@0408b<S01cLg<0Lg=c08:2PP80_;bl00@0Lg=c096AT@2A
TI40UYJF0P2/[:`0101mOGd0ZJVY0:VYZ@2YZJT208N7Q`0407IfMP2LW9`0W9bL09^KV`80R8R800@0
GemO051@D01@D500D51@0P2@T9000`20P83oooooooooo`070000o`<0oh005@000?l30?n000<0003o
0`3oP0000`000?l0oh000?n000070000o`80oh0010000?l30?n00080003o00<0oh000000o`000?l0
1`000?l0103oP000003o0000o`000?l30?n000D0003o0`3oP0040000o`80oh0020000?l20?n000<0
003o00<0oh000000o`000?l010000?l50?n000030000o`3oP000oh0000L0003o0`3oP0000`000?l0
oh000?n000090000o`040?n000000?l0003o0000o`<0oh000P000?l00`3oP000003o0000o`080000
o`80oh004`000?l30?n000<0003o2_ooool000Wooooo00@0R8R80;>c/`2c/k<0QhN70P1jNWX01029
RHT0^;Rh0;Rh^035aLD209jNWP0409nOW`22PX80PX:206e]K@80QXJ600@0OGem06MWI`1WIfL0I6AT
0P1LG5`0102[Zj/0QXJ608J6QP2:RXX207emO@0406IVIP15ADD0ADE505EEE@80<C4a00@0FUYJ0;6a
/@2a/K40XJ6Q0P2FUYH0102o_kl0SHf=08f=S@29RHT208N7Q`05075aL@26QXH0`<300<30`02GUiL0
0P2MWId0101_Kfl0HF5Q065QH@34a<@20;Jf]P040<K6aP2/[:`0[:b/0;Fe]@80OGem00@0OWin092@
T02@T900TY:B0P19BDT0101bLW80ZJVY0:VYZ@2VYZH20;Bd]00407alO02a/K40/K6a0;Jf]P80^;Rh
00@0fMWI09^KV`2KVi/0UYJF0P2LW9`01@33`l<0Ng]k07]kN`1oOgl0Ng]k00<0SHf=0P2NWYh0102L
W9`0WYjN09jNWP2`/;020:^[Z`0309FEU@1eMGD0MGEe00<0YJFU00@0^KVi0=KFeP3Fe]H0@T920P2[
Zj/0103Vi^H0ZJVY0:VYZ@1iNGT206EUI@040861P@2LW9`0W9bL0;Jf]P80U9BD00@0Zj^[06ATI01T
I6@0/;2`0P2IVIT0102;Rh/0W9bL09bLW02<S8`208f=S@050:RXZ02=SHd0OGem07emO@0f=SH00P1^
KVh01023Ph<0AdM704M7A`1XJ6P207=cL`0406YZJP1^KVh0KVi^096AT@80PX:200@0S8b<0;fm_@2m
_Kd0MGEe0P2;Rh/01029RHT0W9bL09bLW021PH4209>CT`0409fMW@26QXH0QXJ60:JVYP80Z:RX00@0
ZJVY07UiN@1iNGT0Fe]K0P1=CDd0101LG5`0MWIf07IfMP1/K6`2ooooo`030000o`3oP000oh0000@0
003o0`3oP00<0000o`80oh001`000?l70?n000<0003o0P3oP0070000o`80oh001P000?l40?n00003
0000o`3oP000oh0000H0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`060?n000@0
003o0P3oP00;0000o`80oh001`000?l50?n000030000o`3oP000oh0000L0003o00<0oh000000o`00
0?l00`000?l00`3oP000003o0000o`0:0000o`80oh000`000?l00`3oP000003o0000o`080000o`80
oh004P000?l40?n000<0003o2_ooool000Wooooo00@0R8R80;>c/`2c/k<0QhN70P1jNWX01029RHT0
^;Rh0;Rh^035aLD209jNWP0409nOW`22PX80PX:206e]K@80QXJ600@0OGem06MWI`1WIfL0I6AT0P1L
G5`0102[Zj/0QXJ608J6QP2:RXX207emO@0406IVIP15ADD0ADE505EEE@80<C4a00@0FUYJ0;6a/@2a
/K40XJ6Q0P2FUYH0102o_kl0SHf=08f=S@29RHT208N7Q`05075aL@26QXH0`<300<30`02GUiL00P2M
WId0101_Kfl0HF5Q065QH@34a<@20;Jf]P040<K6aP2/[:`0[:b/0;Fe]@80OGem00@0OWin092@T02@
T900TY:B0P19BDT0101bLW80ZJVY0:VYZ@2VYZH20;Bd]00407alO02a/K40/K6a0;Jf]P80^;Rh00@0
fMWI09^KV`2KVi/0UYJF0P2LW9`01@33`l<0Ng]k07]kN`1oOgl0Ng]k00<0SHf=0P2NWYh0102LW9`0
WYjN09jNWP2`/;020:^[Z`0309FEU@1eMGD0MGEe00<0YJFU00@0^KVi0=KFeP3Fe]H0@T920P2[Zj/0
103Vi^H0ZJVY0:VYZ@1iNGT206EUI@040861P@2LW9`0W9bL0;Jf]P80U9BD00@0Zj^[06ATI01TI6@0
/;2`0P2IVIT0102;Rh/0W9bL09bLW02<S8`208f=S@050:RXZ02=SHd0OGem07emO@0f=SH00P1^KVh0
1023Ph<0AdM704M7A`1XJ6P207=cL`0406YZJP1^KVh0KVi^096AT@80PX:200@0S8b<0;fm_@2m_Kd0
MGEe0P2;Rh/01029RHT0W9bL09bLW021PH4209>CT`0409fMW@26QXH0QXJ60:JVYP80Z:RX00@0ZJVY
07UiN@1iNGT0Fe]K0P1=CDd0101LG5`0MWIf07IfMP1/K6`2ooooo`030000o`3oP000oh0000@0003o
0`3oP00<0000o`80oh001`000?l70?n000<0003o0P3oP0070000o`80oh001P000?l40?n000030000
o`3oP000oh0000H0003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`060?n000@0003o
0P3oP00;0000o`80oh001`000?l50?n000030000o`3oP000oh0000L0003o00<0oh000000o`000?l0
0`000?l00`3oP000003o0000o`0:0000o`80oh000`000?l00`3oP000003o0000o`080000o`80oh00
4P000?l40?n000<0003o2_ooool000Wooooo00@0RHV909fMW@2MWId0S8b<0P1]KFd0102?Shl0/;2`
0;2`/036a/H20::RXP040:RXZ02@T900T92@07EeM@80U9BD00@0N7Qh06YZJP1ZJVX0IFEU0P1OGel0
102UYJD0OWin07inOP1fMWH207]kN`0406=SH`1@D500D51@05IFEP80?Shn00@0Ng]k0:VYZ@2YZJT0
X:2P0P2BTY80102m_Kd0TY:B09:BTP2?Shl208Z:RP0507QhN02CTi<0^[Zj0;Zj^P2HV9P00P2PX:03
071`L0040<;2`P2j^[X0^[Zj0<C4a080/;2`00@0ZJVY08>3P`23Ph<0OGem0P2?Shl0102EUID0ATI6
04I6AP1dM7@20:NWY`040;Fe]@2i^KT0^KVi07=cL`80Zj^[00@0]kNg0<?3``33`l<0gmoO0P2IVIT3
09bLW0050;Zj^P25QHD0QHF508^;R`1cLg<00P2<S8`0101jNWX0WYjN09jNWP2BTY820:>SX`040;Bd
]02`/;00/;2`0861P@80LG5a00@0Z:RX0;2`/02`/;00`/;20P3EeMD0100i>CT0[Zj^0:j^[P3[jn/2
0;Jf]P0407UiN@1GEeL0EeMG0820P080TI6A0`2j^[X0102/[:`0JVYZ06YZJP2ZZZX208N7Q`0408Z:
RP2JVYX0VYZJ092@T080S8b<00D0]KFe08Z:RP29RHT0RHV903dm?@0207emO@0407inOP1@D500D51@
07QhN080K6a/0`1[Jf/30820P00408V9R@2TY:@0Y:BT06e]K@80OGem00@0QhN709RHV02HV9P0PX:2
0P2BTY80102;Rh/0PX:208:2PP2?Shl20:BTY0040;>c/`1jNWX0NWYj06YZJP80CTi>00@0JFUY07Qh
N01hN7P0I6AT0_ooool70000o`<0oh005@000?l40?n000H0003o0P3oP0070000o`80oh001P000?l5
0?n000P0003o00@0oh000000o`000?l0003o0`3oP0030000o`D0oh0010000?l20?n000/0003o0`3o
P0050000o`X0oh000P000?l0103oP000003o0000o`000?l30?n000`0003o00@0oh000000o`000?l0
003o0P3oP0030000o`030?n000000?l0003o01T0003o00@0oh000000o`000?l0003o0P3oP0040000
o`[ooooo0009ooooo`0407UiN@2CTi<0Ti>C08N7Q`80EEEE00@0V9RH0:FUY@2UYJD0_;bl0P2KVi/0
102/[:`0PX:208:2PP1iNGT209FEU@0408>3P`1dM7@0M7Ad075aL@80N7Qh00@0/K6a08V9R@29RHT0
O7al0P27QhL0101_Kfl0I6AT06ATI01HF5P206ATI00408:2PP2`/;00/;2`09^KV`80U9BD00@0[Zj^
08b<S02<S8`0SHf=0P26QXH01@27QhL0V9RH0<?3``33`l<0WIfM0080WinO00@0Jf][07=cL`1cLg<0
[:b/0P33`l<01032`/80ZZZZ0:ZZZP2JVYX20861P@0407QhN026QXH0QXJ609jNWP80CDe=00@0IfMW
0:JVYP2VYZH0[Jf]0P2^[Zh0101gMgL0YZJV0:JVYP2TY:@20<W9b@040=_Kf`2EUID0UIFE09fMW@80
Shn?00D0Zj^[0820P020P800RXZ:07YjNP0208b<S00408>3P`2IVIT0VIVI08F5Q@80XZ:R00@0/k>c
0:n_[`2_[jl0NWYj0P1TI6@0102PX:00/[:b0;:b/P37alL20=?Cd`04038b<P2_[jl0[jn_0>KViP80
_Kfm00@0O7al05eMG@1MGEd0OWin0P2HV9P0102g]kL0_;bl0;bl_02_[jl207=cL`0409ZJVP21PH40
PH6108n?S`80PH6100D0SHf=07emO@1mOGd0a<C40820P00207emO@0402d];@1XJ6P0J6QX05mOG`80
DE5A00@0Ph>306ATI01TI6@0Ng]k0P1mOGd0102:RXX0Ph>308>3P`1iNGT208V9R@0307UiN@23Ph<0
Ph>300<0UYJF00@0SHf=0:ZZZP2ZZZX0Ogmo0P2?Shl0102GUiL0ZJVY0:VYZ@2TY:@207MgM`040820
P01SHf<0Hf=S06][J`80OGem00<0LW9booooooooool010000?l20?n000<0003o00<0oh000000o`00
0?l030000?l00`3oP000003o0000o`050000o`80oh000`000?l0103oP000003o0000o`000?l20?n0
00L0003o0P3oP0070000o`<0oh002@000?l0103oP000003o0000o`000?l30?n000D0003o0`3oP00A
0000o`<0oh001@000?l:0?n00080003o00@0oh000000o`000?l0003o103oP00;0000o`040?n00000
0?l0003o0000o`80oh000`000?l00`3oP000003o0000o`0S0000o`[ooooo0009ooooo`0407UiN@2C
Ti<0Ti>C08N7Q`80EEEE00@0V9RH0:FUY@2UYJD0_;bl0P2KVi/0102/[:`0PX:208:2PP1iNGT209FE
U@0408>3P`1dM7@0M7Ad075aL@80N7Qh00@0/K6a08V9R@29RHT0O7al0P27QhL0101_Kfl0I6AT06AT
I01HF5P206ATI00408:2PP2`/;00/;2`09^KV`80U9BD00@0[Zj^08b<S02<S8`0SHf=0P26QXH01@27
QhL0V9RH0<?3``33`l<0WIfM0080WinO00@0Jf][07=cL`1cLg<0[:b/0P33`l<01032`/80ZZZZ0:ZZ
ZP2JVYX20861P@0407QhN026QXH0QXJ609jNWP80CDe=00@0IfMW0:JVYP2VYZH0[Jf]0P2^[Zh0101g
MgL0YZJV0:JVYP2TY:@20<W9b@040=_Kf`2EUID0UIFE09fMW@80Shn?00D0Zj^[0820P020P800RXZ:
07YjNP0208b<S00408>3P`2IVIT0VIVI08F5Q@80XZ:R00@0/k>c0:n_[`2_[jl0NWYj0P1TI6@0102P
X:00/[:b0;:b/P37alL20=?Cd`04038b<P2_[jl0[jn_0>KViP80_Kfm00@0O7al05eMG@1MGEd0OWin
0P2HV9P0102g]kL0_;bl0;bl_02_[jl207=cL`0409ZJVP21PH40PH6108n?S`80PH6100D0SHf=07em
O@1mOGd0a<C40820P00207emO@0402d];@1XJ6P0J6QX05mOG`80DE5A00@0Ph>306ATI01TI6@0Ng]k
0P1mOGd0102:RXX0Ph>308>3P`1iNGT208V9R@0307UiN@23Ph<0Ph>300<0UYJF00@0SHf=0:ZZZP2Z
ZZX0Ogmo0P2?Shl0102GUiL0ZJVY0:VYZ@2TY:@207MgM`040820P01SHf<0Hf=S06][J`80OGem00<0
LW9booooooooool010000?l20?n000<0003o00<0oh000000o`000?l030000?l00`3oP000003o0000
o`050000o`80oh000`000?l0103oP000003o0000o`000?l20?n000L0003o0P3oP0070000o`<0oh00
2@000?l0103oP000003o0000o`000?l30?n000D0003o0`3oP00A0000o`<0oh001@000?l:0?n00080
003o00@0oh000000o`000?l0003o103oP00;0000o`040?n000000?l0003o0000o`80oh000`000?l0
0`3oP000003o0000o`0S0000o`[ooooo0009ooooo`0407emO@2IVIT0VIVI08^;R`80Fe]K00@0X:2P
09VIV@2IVIT0YjNW0P2FUYH0102ZZZX0Q8B408B4Q01]KFd208J6QP0408F5Q@21PH40PH6107IfMP80
JFUY00@0[:b/09NGU`2GUiL0OWin0P2CTi<0101^KVh0GEeM05eMG@17AdL203hn?P0408B4Q02h^;P0
^;Rh09jNWP80X:2P00@0_Kfm08j>SP2>SXh0Ti>C0P29RHT01@1oOgl0Xj>S0<?3``33`l<0Vi^K0080
W9bL00@0M7Ad07YjNP1jNWX0YJFU0P3Hf=P0103AdM40^;Rh0;Rh^02GUiL208J6QP0407alO01mOGd0
OGem09^KV`80HV9R00@0J6QX0:2PX02PX:00/k>c0P2KVi/0101dM7@0Xj>S0:>SX`2SXj<20=GEe@04
0=?Cd`2QXJ40XJ6Q0:VYZ@80QhN700D0ZZZZ08n?S`2?Shl0QhN708J6QP0208F5Q@0407moO`2FUYH0
UYJF07moO`80Ti>C00@0];Bd0;>c/`2c/k<0Ph>30P1RHV800`2NWYh0ZZZZ0:ZZZP030<;2`P0402`/
;02e]KD0]KFe0>[ZjP80`<3000@0LW9b069RHP1RHV80EUIF0P2<S8`0102QXJ40^;Rh0;Rh^02a/K42
08N7Q`040:VYZ@2@T900T92@0:2PX080NGUi00D0UiNG06a/K01/K6`0]kNg08J6QP0207moO`0403Ti
>@1oOgl0Ogmo075aL@80HV9R00@0Ti>C05mOG`1OGel0NGUi0P1_Kfl0102=SHd0MgMg07MgM`1jNWX2
07moO`0408>3P`27QhL0QhN709jNWP80Shn?00@0T92@0:6QX@2QXJ40RXZ:0P2KVi/0102FUYH0VYZJ
09ZJVP2HV9P206a/K00407EeM@1LG5`0G5aL06e]K@80OGem00<0L71`ooooooooool010000?l20?n0
01T0003o103oP0020000o`040?n000000?l0003o0000o`80oh001`000?l20?n000L0003o103oP00<
0000o`80oh001P000?l30?n00140003o0`3oP0060000o`T0oh000`000?l20?n00080003o0`3oP00;
0000o`040?n000000?l0003o0000o`80oh008`000?l20?n000@0003o2_ooool000Wooooo00@0PH61
09RHV02HV9P0Rh^;0P1SHf<0102NWYh0V9RH09RHV02h^;P209ZJVP030:n_[`29RHT0RHV900<0TI6A
00@0MGEe06i^KP1^KVh0K6a/0P1HF5P0102NWYh0Q8B408B4Q01YJFT208n?S`0406m_K`1BDU80DU9B
06QXJ080A4A400@0QXJ60;Vi^@2i^KT0UYJF0P2?Shl0102RXZ80QXJ608J6QP1hN7P20861P@0508>3
P`2f][H0a<C40<C4a02PX:000P2DU9@0101/K6`0Ng]k07]kN`2SXj<20=3@d0040<;2`P2a/K40/K6a
08R8R080PH6100@0RHV90820P020P800V9RH0P1dM7@0101cLg<0TY:B09:BTP2/[:`209ZJVP0407Yj
NP2QXJ40XJ6Q09fMW@80hN7Q00@0d];B0:f][@2][Jd0X:2P0P29RHT01@2SXj<0UiNG09NGU`25QHD0
U9BD0080NGUi00@0M7Ad092@T02@T900R8R80P2LW9`0102a/K40Xj>S0:>SX`1]KFd206ATI00409RH
V02UYJD0YJFU0<C4a080alO700@09RHV0;jn_P2n_[h0inOW0P2l_;`0101bLW80MWIf07IfMP1PH602
09fMW@030:JVYP2m_Kd0_Kfm00<0UIFE00@0[:b/09:BTP2BTY80UiNG0P1VIVH01@2NWYh0LG5a075a
L@2RXZ80YJFU0080JFUY00@0?Cdm06i^KP1^KVh0F5QH0P1RHV80102FUYH0EeMG05MGE`1aLG42071`
L00408J6QP1`L700L71`0820P080K6a/00@0RHV908:2PP22PX80^KVi0P2GUiL0102FUYH0YjNW0:NW
Y`2@T90209^KV`0409BDU02JVYX0VYZJ09:BTP80M7Ad00@0LG5a06IVIP1VIVH0JFUY0P1hN7P00`1k
Ng_oooooooooo`090000o`040?n000000?l0003o0?n000T0003o0P3oP0070000o`040?n000000?l0
003o0?n00080003o00<0oh000000o`000?l02@000?l30?n000L0003o103oP00D0000o`@0oh004000
0?l20?n000L0003o2@3oP0070000o`80oh0040000?l20?n000030000o`3oP000oh0000<0003o00<0
oh000000o`000?l02P000?l00`3oP000003o0000o`0C0000o`[ooooo0009ooooo`040861P@2HV9P0
V9RH08^;R`80Hf=S00@0WYjN09RHV02HV9P0^;Rh0P2JVYX00`2_[jl0RHV908V9R@03096AT@0407Ee
M@1^KVh0KVi^06a/K080F5QH00@0WYjN08B4Q024Q8@0JFUY0P2?Shl0101_Kfl0DU9B059BDP1XJ6P2
04A4A00408J6QP2i^KT0^KVi09JFUP80Shn?00@0XZ:R08J6QP26QXH0N7Qh0P21PH401@23Ph<0][Jf
0<C4a034a<@0X:2P0080U9BD00@0K6a/07]kN`1kNg/0Xj>S0P3@d=001032`/80/K6a0;6a/@28R8P2
0861P@0408V9R@20P800P82009RHV080M7Ad00@0Lg=c09:BTP2BTY80[:b/0P2JVYX0101jNWX0XJ6Q
0:6QX@2MWId20>7Qh@040=;BdP2][Jd0[Jf]0:2PX080RHV900D0Xj>S09NGU`2GUiL0QHF509BDU002
07UiN@0407AdM02@T900T92@08R8R080W9bL00@0/K6a0:>SX`2SXj<0KFe]0P1TI6@0102HV9P0YJFU
0:FUY@34a<@20<O7a`0402HV9P2n_[h0_[jn0>OWi`80_;bl00@0LW9b07IfMP1fMWH0H61P0P2MWId0
0`2VYZH0_Kfm0;fm_@0309FEU@040:b/[02BTY80TY:B09NGU`80IVIV00D0WYjN075aL@1aLG40XZ:R
0:FUY@0206UYJ@0403dm?@1^KVh0KVi^05QHF080HV9R00@0UYJF05MGE`1GEeL0LG5a0P1`L7001026
QXH0L71`071`L020P80206a/K00408V9R@22PX80PX:20;Vi^@80UiNG00@0UYJF0:NWY`2WYjL0T92@
0P2KVi/0102DU9@0VYZJ09ZJVP2BTY8207AdM004075aL@1VIVH0IVIV06UYJ@80N7Qh00<0Ng]koooo
ooooool02@000?l0103oP000003o0000o`3oP0090000o`80oh001`000?l0103oP000003o0000o`3o
P0020000o`030?n000000?l0003o00T0003o0`3oP0070000o`@0oh0050000?l40?n00100003o0P3o
P0070000o`T0oh001`000?l20?n00100003o0P3oP0000`000?l0oh000?n000030000o`030?n00000
0?l0003o00X0003o00<0oh000000o`000?l04`000?l:ooooo`002Oooool01027QhL0UIFE09FEU@2@
T90205EEE@0409fMW@2JVYX0VYZJ0;Bd]080U9BD00@0]KFe09:BTP2BTY80Y:BT0P2@T900101gMgL0
O7al07alO01/K6`2079bLP040:JVYP22PX80PX:208F5Q@80X:2P00@0QHF5051@D01@D500K6a/0P14
A4@01028R8P0^[Zj0;Zj^P2<S8`209RHV0040:BTY01dM7@0M7Ad06EUI@80LW9b00D0Lg=c0;:b/P2o
_kl0_kno09>CT`0208n?S`04071`L01]KFd0KFe]0:6QX@80gMgM00@0alO70;:b/P2b/[80QHF50P2?
Shl0101^KVh0Q8B408B4Q02>SXh207UiN@0407AdM02ATI40TI6A0:b/[080R8R800@0Lg=c096AT@2A
TI40Ti>C0P3Shn<01035aLD0/[:b0;:b/P2YZJT2092@T0050:b/[02>SXh0SXj>08:2PP2^[Zh00P21
PH40101oOgl0Z:RX0:RXZ024Q8@209VIV@040;Fe]@2^[Zh0[Zj^08F5Q@80Ph>300@0U9BD0<O7a`37
alL0b/[:0P2YZJT0100d=3@0a<C40<C4a03WinL20:ZZZP0407]kN`24Q8@0Q8B404a<C080U9BD00@0
X:2P0=7Ad@3AdM40UIFE0P2SXj<0101oOgl0Y:BT0:BTY02GUiL206QXJ00508R8R023Ph<0Ph>308B4
Q02i^KT00P1CDe<0100h>3P0UYJF09JFUP1TI6@207=cL`04096AT@1KFe/0Fe]K075aL@80Fe]K00@0
LW9b06=SH`1SHf<0Kfm_0P1SHf<0102;Rh/0VIVI09VIV@2g]kL20:BTY00408n?S`2a/K40/K6a0:b/
[080Xj>S00@0][Jf09RHV02HV9P0MgMg0P20P800101^KVh0GEeM05eMG@1[Jf/20820P00306i^K_oo
oooooooo00@0003o0P3oP0030000o`040?n000000?l0003o0?n00180003o00@0oh000000o`000?l0
oh000P000?l00`3oP000003o0000o`090000o`<0oh001`000?l40?n001@0003o103oP0080000o`03
0?n000000?l0003o00D0003o0`3oP0050000o`<0oh0000<0003o0?n0003oP0000`3oP0040000o`80
oh000P000?l20?n000d0003o1@3oP0060000o`040?n000000?l0003o0?n000T0003o00@0oh000000
o`000?l0003o0P3oP0030000o`030?n000000?l0003o00@0003o0P3oP0040000o`[ooooo003ooooo
oi7ooooo003ooooooi7ooooo0009ooooo`0405YJFP23Ph<0Ph>309>CT`80XJ6Q00@0[jn_09jNWP2N
WYh0D51@0P0g=cL0102c/k<0^KVi0;Vi^@2l_;`20;Rh^0040;Jf]P1mOGd0OGem02l_;`80Ogmo00@0
MGEe07MgM`1gMgL0P8200P25QHD01021PH40AdM704M7A`2][Jd20;6a/@040:ZZZP2YZJT0ZJVY0:^[
Z`80UIFE00@07QhN07QhN01hN7P0Shn?0P2DU9@01@2IVIT0WYjN09>CT`2CTi<09RHV0080EEEE00@0
HV9R06UYJ@1YJFT0JFUY0P1^KVh0101cLg<0?Cdm03dm?@1nOWh209:BTP0409fMW@2TY:@0Y:BT0:ZZ
ZP80ZJVY00@0/;2`0;Bd]02d];@0EeMG0P2OWil30;:b/P<0/;2`00@0LG5a03Xj>P0j>SX0WIfM0P2[
Zj/01@2_[jl0Zj^[0:^[Z`2`/;00KVi^0080<c<c00@0Ph>30820P020P800TY:B0P2LW9`0102YZJT0
K6a/06a/K00U9BD204I6AP0404U9B@1EEED0EEEE06QXJ080MGEe00@0Cdm?06i^KP1^KVh0^KVi0P2b
/[80102_[jl0[Jf]0:f][@2^[Zh205=CD`0409ZJVP2h^;P0^;Rh0;Rh^080^[Zj00@0_;bl0;Jf]P2f
][H0I6AT0P2d];@01@2h^;P0_;bl0;bl_02i^KT0^;Rh0080Fe]K00@0Q8B40;:b/P2b/[80[Jf]0`2d
];@208J6QP0408V9R@2b/[80/[:b0:n_[`80[Jf]00@0[:b/0:VYZ@2YZJT0De=C0P28R8P0102UYJD0
[:b/0:b/[02a/K420:f][@0408J6QP23Ph<0Ph>30<?3``80alO700@0`<300;jn_P2n_[h0[Jf]0P1B
DU80102/[:`0/;2`0;2`/02^[Zh2ooooo`030?n000000?l0003o00<0003o00<0oh000000o`000?l0
2P3oP0020000o`030?n000000?l0003o00L0003o103oP0060000o`80oh002@000?l30?n000L0003o
00<0oh000000o`000?l01`000?l50?n000030000o`3oP000oh0000@0oh000P000?l0103oP000003o
0000o`000?l20?n000050000o`3oP000oh000000o`3oP0002@000?l60?n000<0003o0P3oP0000`00
0?l0oh000?n000070?n000030000o`3oP000oh0000H0oh0000<0003o0?n0003oP0001`3oP0020000
o`H0oh000`000?l40?n000<0003o00<0oh000000o`000?l00`000?l30?n000<0003o2@3oP0001000
0?l0oh000?n0003oP00:ooooo`002Oooool0101NGUh0TI6A096AT@2QXJ420;Fe]@040;Vi^@2c/k<0
/k>c079bLP80>CTi00<0[Zj^0;bl_02l_;`00`2l_;`0102i^KT0OWin07inOP0h>3P207EeM@0406e]
K@1^KVh0KVi^07QhN080Q8B400@0R8R803Xj>P0j>SX0Z:RX0P2`/;00102^[Zh0ZZZZ0:ZZZP2][Jd2
096AT@0402HV9P2<S8`0S8b<09^KV`80YJFU00D0Y:BT0:6QX@2EUID0UIFE028R8P0206ATI00407in
OP23Ph<0Ph>306e]K@80J6QX00@0FEUI034a<@0a<C40P8200P2FUYH0102OWil0Xj>S0:>SX`2ZZZX2
0:j^[P040;>c/`2e]KD0]KFe05EEE@80XJ6Q00@0Zj^[0:n_[`2_[jl0[Zj^0P2`/;00101fMWH0;2`/
02`/;027QhL30:2PX080ZZZZ00D0[Jf]06a/K00f=SH0=SHf09bLW00209NGU`0409bLW02SXj<0Xj>S
0:VYZ@80MgMg00@0?Cdm06EUI@1UIFD0@d=30P1>CTh0101WIfL0L71`071`L019BDT207=cL`040;>c
/`2[Zj/0Zj^[0:f][@80/;2`00@0[:b/055AD@1ADE40UYJF0P2c/k<0102_[jl0/;2`0;2`/02j^[X2
0:^[Z`0406][J`2g]kL0]kNg0;Vi^@80_kno0P2i^KT206YZJP0408n?S`2c/k<0/k>c0:^[Z`80/k>c
00@0]KFe0:JVYP2VYZH0XJ6Q0P2m_Kd0102f][H0^;Rh0;Rh^02f][H20;:b/P0405aLG026QXH0QXJ6
09jNWP80ZZZZ00@0Zj^[0;Fe]@2e]KD0Ti>C0P2=SHd40;^k^`80_kno00<0`l?306m_K`1_Kfl0102Z
ZZX2ooooo`040?n000000?l0003o0000o`D0oh0000<0003o0?n0003oP0001`3oP0020000o`030?n0
00000?l0003o00L0003o00<0oh000000o`000?l00`3oP00010000?l0oh000?n000000?l20?n000T0
003o00<0oh000000o`000?l01P000?l20?n000P0003o1P3oP0030000o`@0oh000P000?l00`3oP000
003o0000o`040000o`80oh0000<0003o0?n000000?l020000?l20?n000040000o`3oP000oh000?n0
00<0003o0P3oP00010000?l0oh000?n000000?l30?n00080003o00<0oh000000o`3oP0001@3oP003
0000o`P0oh000`000?l00`3oP000003o0000o`030?n000<0003o203oP0060000o`80oh000`000?l7
0?n000H0003o2_ooool000Wooooo00@0GUiN096AT@2ATI40XJ6Q0P2e]KD0102i^KT0/k>c0;>c/`1b
LW8203Ti>@030:j^[P2l_;`0_;bl00<0_;bl00@0^KVi07inOP1nOWh0>3Ph0P1eMGD0101]KFd0KVi^
06i^KP1hN7P208B4Q00408R8R00j>SX0>SXj0:RXZ080/;2`00@0[Zj^0:ZZZP2ZZZX0[Jf]0P2ATI40
100V9RH0S8b<08b<S02KVi/20:FUY@050:BTY02QXJ40UIFE09FEU@0R8R800P1TI6@0101nOWh0Ph>3
08>3P`1]KFd206QXJ00405UIF@0a<C40<C4a0820P080UYJF00@0WinO0:>SX`2SXj<0ZZZZ0P2^[Zh0
102c/k<0]KFe0;Fe]@1EEED20:6QX@040:^[Z`2_[jl0[jn_0:j^[P80/;2`00@0MWIf02`/;00/;2`0
QhN70`2PX:020:ZZZP050:f][@1/K6`0=SHf03Hf=P2LW9`00P2GUiL0102LW9`0Xj>S0:>SX`2YZJT2
07MgM`0403dm?@1UIFD0IFEU04=3@`80CTi>00@0IfMW071`L01`L700BDU90P1cLg<0102c/k<0Zj^[
0:^[Z`2][Jd20;2`/0040:b/[01ADE40DE5A09JFUP80/k>c00@0[jn_0;2`/02`/;00^[Zj0P2[Zj/0
101[Jf/0]kNg0;Ng]`2i^KT20;no_`80^KVi0P1ZJVX0102?Shl0/k>c0;>c/`2[Zj/20;>c/`040;Fe
]@2VYZH0YZJV0:6QX@80_Kfm00@0][Jf0;Rh^02h^;P0][Jf0P2b/[80101LG5`0QXJ608J6QP2NWYh2
0:ZZZP040:^[Z`2e]KD0]KFe09>CT`80SHf=102k^k/20;no_`030<?3``1_Kfl0Kfm_00@0ZZZZ0_oo
ool0103oP000003o0000o`000?l50?n000030000o`3oP000oh0000L0oh000P000?l00`3oP000003o
0000o`070000o`030?n000000?l0003o00<0oh0000@0003o0?n0003oP000003o0P3oP0090000o`03
0?n000000?l0003o00H0003o0P3oP0080000o`H0oh000`000?l40?n00080003o00<0oh000000o`00
0?l010000?l20?n000030000o`3oP000003o00P0003o0P3oP00010000?l0oh000?n0003oP0030000
o`80oh0000@0003o0?n0003oP000003o0`3oP0020000o`030?n000000?l0oh0000D0oh000`000?l8
0?n000<0003o00<0oh000000o`000?l00`3oP0030000o`P0oh001P000?l20?n000<0003o1`3oP006
0000o`[ooooo0009ooooo`0405iNGP2GUiL0UiNG0:ZZZP80[Jf]00@0Z:RX0:FUY@2UYJD0IVIV0P0]
;Bd0102NWYh0]KFe0;Fe]@2d];@20;Vi^@040;Rh^02MWId0WIfM05EEE@80LG5a00@0JFUY06YZJP1Z
JVX0MGEe0P25QHD0102ATI40>3Ph03Ph>023Ph<209fMW@<0Xj>S00@0UiNG069RHP1RHV80?clo0P23
Ph<01@2BTY80XJ6Q0:6QX@2NWYh0V9RH0080Q8B400@0;Rh^05MGE`1GEeL0NGUi0P1_Kfl0101^KVh0
H61P061PH01@D50202`/;00408Z:RP2SXj<0Xj>S0:^[Z`80XJ6Q00<0YjNW0:j^[P2^[Zh00`2`/;00
101CDe<0V9RH09RHV02[Zj/20:f][@040:n_[`2`/;00/;2`07AdM080:RXZ00@0ZZZZ09nOW`2OWil0
T92@0P2PX:001@2[Zj/0L71`03/k>`0k>c/0WinO0080WIfM00@0XZ:R0:JVYP2VYZH0[:b/0P1hN7P0
1017AdL0UIFE09FEU@1CDe<205iNGP0406m_K`1cLg<0Lg=c04E5A@80HF5Q00@0/k>c0:RXZ02XZ:P0
YZJV0P2^[Zh0102`/;00CTi>04i>CP2EUID20;Jf]P040;:b/P2a/K40/K6a0;6a/@80/;2`00@0I6AT
0;Jf]P2f][H0_kno0P2h^;P01@2l_;`0^KVi06][J`1[Jf/0SXj>0080];Bd00@0]KFe0;>c/`2c/k<0
][Jf0P2TY:@0102HV9P0]kNg0;Ng]`2h^;P20;Jf]P040;:b/P2a/K40/K6a05MGE`80W9bL00@0/;2`
0:j^[P2^[Zh0]KFe0P2h^;P00`2BTY80QXJ608J6QP030;2`/0040:j^[P2c/k<0/k>c0;bl_080LW9b
00@0[Jf]0:>SX`2SXj<0WYjN0_ooool0103oP000003o0000o`000?l20?n000@0003o0P3oP0000`00
0?l0oh000?n000040?n00080003o00<0oh000000o`000?l01`000?l00`3oP000003o0000o`070000
o`80oh002@000?l30?n000H0003o0P3oP0080000o`H0oh000`000?l40?n00080003o00<0oh000000
o`000?l01`000?l00`3oP000003o0000o`070000o`80oh0000@0003o0?n0003oP000oh000`000?l2
0?n000030000o`3oP000oh0000<0003o103oP0000`000?l0oh000?n000060?n000030000o`3oP000
oh0000H0oh000`000?l60?n000<0003o203oP0020000o`H0oh000`000?l70?n00080003o00@0oh00
0000o`000?l0003o2_ooool000Wooooo00@0?3`l0410@010@400ATI60P0m?Cd0100i>CT0>3Ph03Ph
>00Y:BT202@T90<0;bl_00@0820P02PX:00X:2P09RHV0P0R8R80100N7Qh0:2PX02PX:00S8b<202PX
:00402TY:@0];Bd0;Bd]038b<P80;Bd]00@0?Cdm04i>CP1>CTh0=3@d0P0Y:BT0100M7Ad05ADE01DE
5@0O7al203dm?@0503hn?P0j>SX0>SXj03De=@0g=cL00P19BDT0100b<S80>3Ph03Ph>00n?Sh203Ti
>@0403Lg=`0d=3@0=3@d02d];@808b<S00<0ATI604U9B@19BDT00`1>CTh0101GEeL0GEeM05eMG@1V
IVH2065QH@0402h^;P1>CTh0CTi>06QXJ080K6a/00@0KVi^075aL@1aLG40ADE50P0G5aL0101]KFd0
Hf=S06=SH`1GEeL205iNGP0507EeM@1JFUX08B4Q024Q8@1]KFd00P1^KVh0101[Jf/0NWYj07YjNP1k
Ng/2059BDP04030`<014A4@0A4A403Lg=`80;Rh^00@0;2`/03Hf=P0f=SH0>c/k0P1RHV80102NWYh0
V9RH09RHV02CTi<208F5Q@04092@T015ADD0ADE506YZJP80WYjN00@0Y:BT0;6a/@2a/K40]KFe0P2Z
ZZX0101QHF40/k>c0;>c/`2l_;`20;Jf]P050;bl_02^[Zh0CTi>04i>CP1UIFD00P2PX:00102SXj<0
XZ:R0::RXP2XZ:P208j>SP0408n?S`2n_[h0_[jn0;Zj^P80]KFe00@0^;Rh0;Ng]`2g]kL0G5aL0P2=
SHd0102^[Zh0[:b/0:b/[02^[Zh20;2`/00408J6QP1oOgl0Ogmo0:FUY@80YZJV00@0V9RH0:FUY@2U
YJD0]kNg0P1UIFD0102NWYh0YZJV0:JVYP2ZZZX2ooooodP0oh000`000?l30?n000H0003o0`3oP003
0000o`<0oh000P000?l20?n000P0003o303oP0090000o`030?n000000?l0003o0080003o0`3oP003
0000o`T0oh002`000?l80?n00080003o00<0oh000000o`000?l00`3oP0090000o`030?n000000?l0
003o00@0003o2_ooool000Wooooo00@0?3`l0410@010@400ATI60P0m?Cd0100i>CT0>3Ph03Ph>00Y
:BT202@T90<0;bl_00@0820P02PX:00X:2P09RHV0P0R8R80100N7Qh0:2PX02PX:00S8b<202PX:004
02TY:@0];Bd0;Bd]038b<P80;Bd]00@0?Cdm04i>CP1>CTh0=3@d0P0Y:BT0100M7Ad05ADE01DE5@0O
7al203dm?@0503hn?P0j>SX0>SXj03De=@0g=cL00P19BDT0100b<S80>3Ph03Ph>00n?Sh203Ti>@04
03Lg=`0d=3@0=3@d02d];@808b<S00<0ATI604U9B@19BDT00`1>CTh0101GEeL0GEeM05eMG@1VIVH2
065QH@0402h^;P1>CTh0CTi>06QXJ080K6a/00@0KVi^075aL@1aLG40ADE50P0G5aL0101]KFd0Hf=S
06=SH`1GEeL205iNGP0507EeM@1JFUX08B4Q024Q8@1]KFd00P1^KVh0101[Jf/0NWYj07YjNP1kNg/2
059BDP04030`<014A4@0A4A403Lg=`80;Rh^00@0;2`/03Hf=P0f=SH0>c/k0P1RHV80102NWYh0V9RH
09RHV02CTi<208F5Q@04092@T015ADD0ADE506YZJP80WYjN00@0Y:BT0;6a/@2a/K40]KFe0P2ZZZX0
101QHF40/k>c0;>c/`2l_;`20;Jf]P050;bl_02^[Zh0CTi>04i>CP1UIFD00P2PX:00102SXj<0XZ:R
0::RXP2XZ:P208j>SP0408n?S`2n_[h0_[jn0;Zj^P80]KFe00@0^;Rh0;Ng]`2g]kL0G5aL0P2=SHd0
102^[Zh0[:b/0:b/[02^[Zh20;2`/00408J6QP1oOgl0Ogmo0:FUY@80YZJV00@0V9RH0:FUY@2UYJD0
]kNg0P1UIFD0102NWYh0YZJV0:JVYP2ZZZX2ooooodP0oh000`000?l30?n000H0003o0`3oP0030000
o`<0oh000P000?l20?n000P0003o303oP0090000o`030?n000000?l0003o0080003o0`3oP0030000
o`T0oh002`000?l80?n00080003o00<0oh000000o`000?l00`3oP0090000o`030?n000000?l0003o
00@0003o2_ooool000Wooooo0`2UYJD0102[Zj/0Z:RX0:RXZ01OGel207moO`04092@T028R8P0R8R8
0:2PX080Y:BT00@0Z:RX0:b/[02/[:`0Xj>S0P2VYZH0102TY:@0W9bL09bLW02DU9@208Z:RP0406][
J`1VIVH0IVIV0:BTY080WinO00@0XZ:R09jNWP2NWYh0VYZJ0P2=SHd0102<S8`0Shn?08n?S`26QXH2
08n?S`0508b<S028R8P0R8R808:2PP1:BTX00P1[Jf/0101iNGT0Jf][06][J`1`L70207IfMP0407Qh
N01gMgL0MgMg07MgM`<0N7Qh0P1dM7@0101NGUh0AdM704M7A`0b<S82059BDP0406IVIP1UIFD0IFEU
06EUI@80GUiN00@0ATI605IFEP1FEUH0C4a<0P15ADD303Ti>@0402l_;`0R8R808R8R01LG5`808B4Q
00D0;bl_03@d=00h>3P0>3Ph02l_;`0203De=@0402/[:`0S8b<08b<S02XZ:P80:BTY00@0:RXZ02/[
:`0[:b/0;Bd]0P0O7al0100R8R80;bl_02l_;`0e=CD203Lg=`0303hn?P0l?3`0?3`l00<0?3`l00@0
;Bd]01lO7`0O7al05aLG0P0K6a/0100V9RH0<30`030`<00S8b<201lO7`04010@400T92@092@T02`/
;0808B4Q00D0:RXZ01PH60030`<00`<3014A4@0202LW9`0402@T900W9bL09bLW02h^;P808R8R00@0
71`L03Hf=P0f=SH0@d=30P15ADD01019BDT0CDe=04e=C@0I6AT202h^;P0404];B`19BDT0BDU904e=
C@80DE5A00@0;Bd]03<c<`0c<c<0DE5A0P1QHF40101SHf<0KFe]06e]K@1dM7@203/k>`040451@@1:
BTX0BTY:04a<C0;ooooo<@000?l00`3oP000003o0000o`0>0000o`H0oh001@000?mT0?n000H0003o
1P3oP00:ooooo`002Oooool30:j^[P040;>c/`2e]KD0]KFe05QHF080TY:B00@0R8R80820P020P800
Vi^K0P2][Jd0102_[jl0/[:b0;:b/P2e]KD20;6a/@030;>c/`2`/;00/;2`00<0/K6a00@0KFe]06YZ
JP1ZJVX0[jn_0P2[Zj/0102][Jd0[:b/0:b/[02XZ:P20:FUY@040:RXZ02[Zj/0Zj^[0:j^[P80/K6a
00D0]kNg0;>c/`2c/k<0]KFe05YJFP0207]kN`0408J6QP25QHD0QHF508Z:RP80Shn?00@0WYjN0:2P
X02PX:00W9bL0P2>SXh308F5Q@0408n?S`2OWil0WinO04];B`80Ng]k00@0[:b/0:ZZZP2ZZZX0ZJVY
0P2VYZH0102=SHd0UYJF09JFUP2OWil207moO`0407inOP1UIFD0IFEU06e]K@80HF5Q00D0AdM708R8
R028R8P0Ogmo079bLP030:ZZZP80[Jf]00@0TI6A071`L01`L700QHF50`2d];@20;:b/P040;Ng]`1W
IfL0IfMW07alO080[Jf]00@0/k>c0;:b/P2b/[80[Zj^0P2b/[80102a/K40/;2`0;2`/02^[Zh30:ZZ
ZP80Zj^[00@0Ti>C05MGE`1GEeL0QhN70P2KVi/0102OWil0X:2P0:2PX02JVYX209VIV@0509jNWP2J
VYX0Rh^;08^;R`27QhL00P2<S8`0102;Rh/0Ogmo07moO`1VIVH208j>SP0408^;R`27QhL0QhN707em
O@80MGEe00@0NWYj07MgM`1gMgL0JFUY0P1ZJVX0101_Kfl0LW9b079bLP1/K6`2061PH00404E5A@1[
Jf/0Jf][05eMG@80EEEE00@0DE5A05ADE01DE5@0EeMG0P1XJ6P0101/K6`0KFe]06e]K@1VIVH2oooo
o`L0oh001P000?l>0?n000<0003o00@0oh000000o`3oP000oh001`000?l90?n001<0003o0P3oP00C
0000o`80oh001`000?l00`3oP000003o0000o`030000o`H0oh000`000?l<0?n000D0003o0P3oP00X
0000o`030?n000000?l0003o00L0oh001P000?l:ooooo`002Oooool30:j^[P040;>c/`2e]KD0]KFe
05QHF080TY:B00@0R8R80820P020P800Vi^K0P2][Jd0102_[jl0/[:b0;:b/P2e]KD20;6a/@030;>c
/`2`/;00/;2`00<0/K6a00@0KFe]06YZJP1ZJVX0[jn_0P2[Zj/0102][Jd0[:b/0:b/[02XZ:P20:FU
Y@040:RXZ02[Zj/0Zj^[0:j^[P80/K6a00D0]kNg0;>c/`2c/k<0]KFe05YJFP0207]kN`0408J6QP25
QHD0QHF508Z:RP80Shn?00@0WYjN0:2PX02PX:00W9bL0P2>SXh308F5Q@0408n?S`2OWil0WinO04];
B`80Ng]k00@0[:b/0:ZZZP2ZZZX0ZJVY0P2VYZH0102=SHd0UYJF09JFUP2OWil207moO`0407inOP1U
IFD0IFEU06e]K@80HF5Q00D0AdM708R8R028R8P0Ogmo079bLP030:ZZZP80[Jf]00@0TI6A071`L01`
L700QHF50`2d];@20;:b/P040;Ng]`1WIfL0IfMW07alO080[Jf]00@0/k>c0;:b/P2b/[80[Zj^0P2b
/[80102a/K40/;2`0;2`/02^[Zh30:ZZZP80Zj^[00@0Ti>C05MGE`1GEeL0QhN70P2KVi/0102OWil0
X:2P0:2PX02JVYX209VIV@0509jNWP2JVYX0Rh^;08^;R`27QhL00P2<S8`0102;Rh/0Ogmo07moO`1V
IVH208j>SP0408^;R`27QhL0QhN707emO@80MGEe00@0NWYj07MgM`1gMgL0JFUY0P1ZJVX0101_Kfl0
LW9b079bLP1/K6`2061PH00404E5A@1[Jf/0Jf][05eMG@80EEEE00@0DE5A05ADE01DE5@0EeMG0P1X
J6P0101/K6`0KFe]06e]K@1VIVH2ooooo`L0oh001P000?l>0?n000<0003o00@0oh000000o`3oP000
oh001`000?l90?n001<0003o0P3oP00C0000o`80oh001`000?l00`3oP000003o0000o`030000o`H0
oh000`000?l<0?n000D0003o0P3oP00X0000o`030?n000000?l0003o00L0oh001P000?l:ooooo`00
2Oooool0102^[Zh0Z:RX0:RXZ02/[:`20;:b/P04059BDP2MWId0WIfM08b<S080T92@00@0XJ6Q0:BT
Y02TY:@0YJFU0P2PX:00102VYZH0YjNW0:NWY`2VYZH20:b/[0040:f][@2`/;00/;2`06m_K`80JVYZ
00<0ZZZZ0:^[Z`2[Zj/00`2/[:`0102ZZZX0Y:BT0:BTY02VYZH20:NWY`040:RXZ02/[:`0[:b/0:n_
[`80][Jf00D0/k>c04a<C02TY:@0Y:BT09bLW00209FEU@040:BTY02UYJD0YJFU0:JVYP80YjNW00@0
Y:BT09ZJVP2JVYX0RHV90P22PX80102HV9P0XZ:R0::RXP16ATH20861P@040:6QX@2_[jl0[jn_0;>c
/`80ZZZZ0`2FUYH0102HV9P0M7Ad07AdM01fMWH207QhN00408>3P`22PX80PX:205IFEP80RXZ:0P2<
S8`20:b/[0040:^[Z`2/[:`0[:b/09BDU080MgMg00@0Kfm_0;6a/@2a/K40^;Rh0P2f][H0102j^[X0
HF5Q065QH@1iNGT30:f][@80Z:RX00<0YZJV0:NWY`2WYjL00`2WYjL0102YZJT0YJFU0:FUY@2[Zj/2
0:b/[0040:NWY`1OGel0GemO08Z:RP80ZZZZ0`2][Jd01@2^[Zh0]KFe0;Fe]@2j^[X0/;2`0080YZJV
00@0Z:RX0:f][@2][Jd0Zj^[0P2_[jl0101WIfL0^[Zj0;Zj^P35aLD20<C4a0040<71`@2f][H0][Jf
0<;2`P80YjNW00@0QHF506QXJ01XJ6P0/[:b0P2n_[h0102i^KT0RXZ:08Z:RP2?Shl20;Rh^0040;>c
/`2ZZZX0ZZZZ0;>c/`80]kNg00@0_;bl0;fm_@2m_Kd0/k>c0P2l_;`0102k^k_oooooooooo`3oP003
0000o`<0oh004@000?l30?n00140003o1P3oP00C0000o`80oh000`000?l30?n000d0003o0P3oP00=
0000o`H0oh000`000?l30?n001<0003o2@3oP0030000o`040?n000000?l0003o0?n00080003o203o
P0050000o`@0oh000`000?l30?n00080003o2P3oP00:ooooo`002Oooool00`2a/K40[Zj^0:j^[P03
0;>c/`0405=CD`2XZ:P0Z:RX09NGU`80UIFE00@0YjNW0:>SX`2SXj<0YZJV0P2SXj<0102ZZZX0Xj>S
0:>SX`2UYJD20:BTY0030:f][@2a/K40/K6a00<0IfMW00@0ZZZZ0:^[Z`2[Zj/0[:b/0P2[Zj/0102X
Z:P0YZJV0:JVYP2YZJT20:JVYP040:FUY@2VYZH0YZJV0:JVYP80[Zj^00D0Zj^[04=3@`2XZ:P0Z:RX
0:6QX@0209RHV00409^KV`2SXj<0Xj>S0:NWY`80YZJV00@0X:2P09fMW@2MWId0U9BD0P2>SXh0102P
X:00Vi^K09^KV`1;Bd/20861P@040:6QX@2_[jl0[jn_0;6a/@80/;2`00@0[:b/09jNWP2NWYh0Vi^K
0P2OWil0102DU9@0X:2P0:2PX02TY:@208b<S00505=CD`2<S8`0S8b<096AT@2DU9@00P2YZJT0102X
Z:P0[jn_0:n_[`2?Shl207MgM`0408F5Q@2b/[80/[:b0;Fe]@80/k>c00@0^KVi05aLG01LG5`0MWIf
0P2YZJT0102XZ:P0YJFU0:FUY@2TY:@30:VYZ@80Z:RX00<0YjNW0:ZZZP2ZZZX00`2][Jd0102TY:@0
EeMG05MGE`2:RXX20:VYZ@040:^[Z`2YZJT0ZJVY0:ZZZP80/[:b00D0][Jf0;:b/P2UYJD0YJFU0;2`
/0020;Bd]0040;:b/P2c/k<0/k>c04Y:BP80YJFU00@0a<C40<G5a@35aLD0alO70P2i^KT0102k^k/0
P8200820P01CDe<20410@0040:NWY`2n_[h0_[jn0;fm_@80Rh^;00@0RXZ:0;Vi^@2i^KT0]kNg0P2/
[:`00`2f][H0^[Zj0;Zj^P030;bl_0040;fm_@31`L40`L710;jn_P;ooooo1`3oP00A0000o`<0oh00
4`000?l0103oP000003o0000o`3oP00C0000o`80oh000`000?l40?n000`0003o0P3oP0070000o`03
0?n000000?l0003o00<0003o1`3oP00?0000o`<0oh0000<0003o0?n0003oP0001`000?l50?n00003
0000o`3oP000oh0000H0oh0000<0003o0?n0003oP0001@3oP0020000o`<0oh0000@0003o0?n0003o
P000oh000`000?l30?n00080003o2P3oP00:ooooo`002Oooool00`2a/K40[Zj^0:j^[P030;>c/`04
05=CD`2XZ:P0Z:RX09NGU`80UIFE00@0YjNW0:>SX`2SXj<0YZJV0P2SXj<0102ZZZX0Xj>S0:>SX`2U
YJD20:BTY0030:f][@2a/K40/K6a00<0IfMW00@0ZZZZ0:^[Z`2[Zj/0[:b/0P2[Zj/0102XZ:P0YZJV
0:JVYP2YZJT20:JVYP040:FUY@2VYZH0YZJV0:JVYP80[Zj^00D0Zj^[04=3@`2XZ:P0Z:RX0:6QX@02
09RHV00409^KV`2SXj<0Xj>S0:NWY`80YZJV00@0X:2P09fMW@2MWId0U9BD0P2>SXh0102PX:00Vi^K
09^KV`1;Bd/20861P@040:6QX@2_[jl0[jn_0;6a/@80/;2`00@0[:b/09jNWP2NWYh0Vi^K0P2OWil0
102DU9@0X:2P0:2PX02TY:@208b<S00505=CD`2<S8`0S8b<096AT@2DU9@00P2YZJT0102XZ:P0[jn_
0:n_[`2?Shl207MgM`0408F5Q@2b/[80/[:b0;Fe]@80/k>c00@0^KVi05aLG01LG5`0MWIf0P2YZJT0
102XZ:P0YJFU0:FUY@2TY:@30:VYZ@80Z:RX00<0YjNW0:ZZZP2ZZZX00`2][Jd0102TY:@0EeMG05MG
E`2:RXX20:VYZ@040:^[Z`2YZJT0ZJVY0:ZZZP80/[:b00D0][Jf0;:b/P2UYJD0YJFU0;2`/0020;Bd
]0040;:b/P2c/k<0/k>c04Y:BP80YJFU00@0a<C40<G5a@35aLD0alO70P2i^KT0102k^k/0P8200820
P01CDe<20410@0040:NWY`2n_[h0_[jn0;fm_@80Rh^;00@0RXZ:0;Vi^@2i^KT0]kNg0P2/[:`00`2f
][H0^[Zj0;Zj^P030;bl_0040;fm_@31`L40`L710;jn_P;ooooo1`3oP00A0000o`<0oh004`000?l0
103oP000003o0000o`3oP00C0000o`80oh000`000?l40?n000`0003o0P3oP0070000o`030?n00000
0?l0003o00<0003o1`3oP00?0000o`<0oh0000<0003o0?n0003oP0001`000?l50?n000030000o`3o
P000oh0000H0oh0000<0003o0?n0003oP0001@3oP0020000o`<0oh0000@0003o0?n0003oP000oh00
0`000?l30?n00080003o2P3oP00:ooooo`002Oooool0102YZJT0[:b/0:b/[02TY:@209JFUP04059B
DP20P800P82008B4Q0<0QhN70P2<S8`0102@T900TI6A096AT@2HV9P209:BTP0408f=S@2JVYX0VYZJ
09nOW`80XJ6Q00@0JFUY05YJFP1JFUX0R8R80P2;Rh/0102JVYX0WYjN09jNWP2<S8`209>CT`0408f=
S@2DU9@0U9BD08f=S@80SXj>00D0Shn?09^KV`2KVi/0U9BD04I6AP020:RXZ0040:NWY`2IVIT0VIVI
0:2PX080WIfM0`2QXJ40102HV9P0VYZJ09ZJVP2BTY8208^;R`0409NGU`2KVi/0Vi^K04E5A@80NGUi
00@0YJFU09nOW`2OWil0WIfM0P2a/K40102c/k<0[Jf]0:f][@2[Zj/20:VYZ@040:b/[02ZZZX0ZZZZ
0:^[Z`80QhN700D0D51@08R8R028R8P0Vi^K09nOW`020:ZZZP040:^[Z`2c/k<0/k>c09ZJVP80OWin
00@0PH610;Jf]P2f][H0^KVi0P2j^[X0102i^KT0HF5Q065QH@1oOgl20:n_[`040:b/[02SXj<0Xj>S
0::RXP<0WinO0P2SXj<0102VYZH0YjNW0:NWY`2/[:`20:JVYP040::RXP1ZJVX0JVYZ09JFUP80Z:RX
00@0YZJV0:6QX@2QXJ40WinO0P2UYJD01@2^[Zh0/;2`09fMW@2MWId0X:2P0080[:b/00@0[Jf]0:^[
Z`2[Zj/0@4100P2HV9P0102o_kl0_[jn0;jn_P2b/[820:ZZZP040:BTY01QHF40HF5Q03Lg=`80A4A4
00@0WIfM0;:b/P2b/[80/;2`0P1aLG40102;Rh/0^[Zj0;Zj^P2e]KD20:f][@040;Jf]P2j^[X0^[Zj
0;no_`80_Kfm00@0^[Zj0;bl_02l_;`0_Kfm0_ooool60000o`030?n000000?l0003o01<0003o0P3o
P00C0000o`030?n000000?l0003o0140003o0P3oP0060000o`@0oh002@000?l20?n000L0003o00<0
oh000000o`000?l00`000?l60?n000<0003o00<0oh000000o`000?l06@000?l30?n000@0003o0P3o
P00010000?l0oh000?n000000?l40?n000D0003o0`3oP00010000?l0oh000?n0003oP0030000o`l0
oh002_ooool000Wooooo00@0VYZJ09NGU`2GUiL0Ti>C0P2?Shl0102=SHd0QhN708N7Q`1mOGd207Qh
N00407UiN@1XJ6P0J6QX03De=@80IVIV00@0J6QX07EeM@1eMGD0OWin0P1iNGT0101jNWX0MgMg07Mg
M`1lO7`206EUI@0407UiN@1nOWh0OWin075aL@80F5QH00@0?clo05ADE01DE5@0Lg=c0P1fMWH0101c
Lg<0MGEe07EeM@1hN7P306m_K`0406i^KP1_Kfl0Kfm_069RHP80EeMG00@0E5AD0410@010@400GUiN
0P1oOgl00`1lO7`0NGUi07UiN@030861P@0408N7Q`1mOGd0OGem07IfMP80Ng]k00@0O7al069RHP1R
HV80EeMG0P1CDe<0101>CTh0CDe=04e=C@1<C4`3055AD@80EEEE00@0Fe]K04e=C@1=CDd0A4A40P1<
C4`2061PH080JFUY00@0GUiN05QHF01HF5P0ATI60P19BDT0101EEED0J6QX06QXJ01hN7P207EeM@04
07QhN01@D500D51@04i>CP80N7Qh00@0NGUi06UYJ@1YJFT0IfMW0P1UIFD0101jNWX0O7al07alO022
PX8208R8R00406e]K@1cLg<0Lg=c08:2PP80BDU900@0NWYj08b<S02<S8`0QHF50P1eMGD01@24Q8@0
Shn?08n?S`2HV9P0WIfM0080W9bL00@0SHf=09NGU`2GUiL0WIfM0P2OWil0100h>3P0Q8B408B4Q02V
YZH209^KV`0407inOP20P800P82007UiN@80EEEE00@0BTY:06][J`1[Jf/0NGUi0P2<S8`0102FUYH0
Lg=c07=cL`2=SHd20:n_[`040;:b/P2/[:`0[:b/0;>c/`<0^k^k0P2i^KT0102h^;P0_Kfm0;fm_@2d
];@2ooooo`l0003o00<0oh000000o`000?l040000?l40?n000l0003o1P3oP00@0000oa80oh001000
0?l80?n000H0003o0`3oP00A0000o`80oh004`000?l20?n000P0003o0`3oP0090000o`<0oh000P00
0?l:0?n000[ooooo0009ooooo`0409ZJVP2GUiL0UiNG09>CT`80Shn?00@0SHf=08N7Q`27QhL0OGem
0P1hN7P0101iNGT0J6QX06QXJ00e=CD206IVIP0406QXJ01eMGD0MGEe07inOP80NGUi00@0NWYj07Mg
M`1gMgL0O7al0P1UIFD0101iNGT0OWin07inOP1aLG4205QHF00403lo?`1DE5@0E5AD07=cL`80MWIf
00@0Lg=c07EeM@1eMGD0N7Qh0`1_Kfl0101^KVh0Kfm_06m_K`1RHV8205MGE`0405ADE010@400@410
05iNGP80Ogmo00<0O7al07UiN@1iNGT00`21PH401027QhL0OGem07emO@1fMWH207]kN`0407alO01R
HV80HV9R05MGE`80De=C00@0CTi>04e=C@1=CDd0C4a<0`1ADE4205EEE@0405]KF`1=CDd0CDe=04A4
A080C4a<0P1PH60206UYJ@0405iNGP1HF5P0F5QH04I6AP80BDU900@0EEEE06QXJ01XJ6P0N7Qh0P1e
MGD0101hN7P0D51@051@D01>CTh207QhN00407UiN@1YJFT0JFUY06MWI`80IFEU00@0NWYj07alO01l
O7`0PX:20P28R8P0101]KFd0Lg=c07=cL`22PX8204U9B@0407YjNP2<S8`0S8b<08F5Q@80MGEe00D0
Q8B408n?S`2?Shl0V9RH09fMW@0209bLW00408f=S@2GUiL0UiNG09fMW@80WinO00@0>3Ph08B4Q024
Q8@0YZJV0P2KVi/0101nOWh0P8200820P01iNGT205EEE@0404Y:BP1[Jf/0Jf][07UiN@80S8b<00@0
UYJF07=cL`1cLg<0SHf=0P2_[jl0102b/[80[:b/0:b/[02c/k<30;^k^`80^KVi00@0^;Rh0;fm_@2m
_Kd0];Bd0_ooool?0000o`030?n000000?l0003o0100003o103oP00?0000o`H0oh0040000?lB0?n0
00@0003o203oP0060000o`<0oh004@000?l20?n001<0003o0P3oP0080000o`<0oh002@000?l30?n0
0080003o2P3oP00:ooooo`002Oooool00`2k^k/0]kNg0;Ng]`030;Zj^P040;Ng]`2e]KD0]KFe0;:b
/P80[jn_00@0ZJVY0:b/[02/[:`0CTi>0P2LW9`0102QXJ40WinO09nOW`2SXj<20:FUY@040:^[Z`2X
Z:P0Z:RX0:f][@80/K6a00@0];Bd0;>c/`2c/k<0[:b/0P2QXJ40101PH600XJ6Q0:6QX@2_[jl20:j^
[P030:f][@2e]KD0]KFe00<0];Bd00D0^k^k0;Vi^@2l_;`0_;bl0;no_`020<30`0040;Zj^P1UIFD0
IFEU0:f][@80[jn_00@0ZJVY0:JVYP2VYZH0YZJV0P2UYJD0102ZZZX0[Jf]0:f][@2][Jd20:j^[P04
0;6a/@2c/k<0/k>c0;>c/`80Jf][00@0SXj>0;:b/P2b/[80/;2`0P2WYjL0102TY:@0];Bd0;Bd]02g
]kL20;Bd]0050;Rh^02f][H0][Jf0;6a/@2_[jl00P2UYJD0101WIfL0RHV908V9R@2GUiL209bLW004
09ZJVP2GUiL0UiNG09JFUP80UIFE00@0UYJF09jNWP2NWYh0Z:RX0P2YZJT0102JVYX0Ph>308>3P`1J
FUX207]kN`0408>3P`1gMgL0MgMg07AdM080LG5a00@0NGUi07inOP1nOWh0OWin0P28R8P0101hN7P0
JFUY06UYJ@1UIFD203lo?`0304U9B@1UIFD0IFEU0080JVYZ0P1JFUX0101KFe/0HV9R069RHP1QHF42
05mOG`0406ATI01OGel0GemO06a/K080JVYZ00@0A4A4065QH@1QHF40J6QX0P1RHV80101TI6@0IFEU
06EUI@1LG5`205mOG`0405]KF`1GEeL0EeMG04];B`80>CTi0`0k>c/0100j>SX0?Shn03hn?P1<C4`2
04M7A`0404m?C`1:BTX0BTY:04];B`;ooooo303oP0030000o`030?n000000?l0003o00T0003o1@3o
P0060000oa80oh000P000?l30?n000L0003o2@3oP0030000o`<0oh000`000?l:0?n001H0003o0P3o
P00A0000o`<0oh001@000?l30?n000X0003o00<0oh000000o`000?l01P000?l00`3oP000003o0000
o`0C0?n000[ooooo0009ooooo`040;Ng]`2`/;00/;2`0;>c/`80/;2`00@0[jn_0:b/[02/[:`0ZJVY
0P2/[:`0102[Zj/0[:b/0:b/[01@D5020::RXP<0YJFU00@0WIfM09RHV02HV9P0T92@0P2MWId0102X
Z:P0ZZZZ0:ZZZP2_[jl20:j^[P040:VYZ@2WYjL0YjNW05aLG080Y:BT00@0Zj^[0:b/[02/[:`0ZJVY
0P2[Zj/30:VYZ@050:NWY`2YZJT0/K6a0;6a/@2g]kL00P2k^k/0102o_kl0MWIf07IfMP2WYjL20:f]
[@040:BTY02KVi/0Vi^K09fMW@80XZ:R00<0XJ6Q0:VYZ@2YZJT00`2^[Zh0102][Jd0/;2`0;2`/02^
[Zh207]kN`0408b<S02ZZZX0ZZZZ0:NWY`80YZJV00@0YJFU0:b/[02/[:`0[Zj^1@2`/;001@2/[:`0
ZZZZ0:ZZZP2ZZZX0R8R80080][Jf00@0^k^k0<;2`P32`/80_;bl0P2k^k/0102n_[h0`/;20<;2`P2o
_kl30<71`@80aLG500@0_[jn0;Fe]@2e]KD0RHV90P2h^;P0102j^[X0^;Rh0;Rh^02d];@20:n_[`03
0;Jf]P2g]kL0]kNg00<0/k>c00@0];Bd0;Jf]P2f][H0/k>c0P1OGel00`29RHT0^[Zj0;Zj^P020;bl
_080^[Zj00@0^;Rh0;:b/P2b/[80];Bd0P2h^;P0102d];@0^[Zj0;Zj^P30`<020;bl_00406UYJ@2_
[jl0[jn_0;Ng]`80/K6a00<0[:b/0:n_[`2_[jl00`2d];@0102g]kL0];Bd0;Bd]02XZ:P20:VYZ@04
0:f][@2FUYH0UYJF06ATI080X:2P00@0[Zj^0;>c/`2c/k<0[jn_0P2TY:@00`2PX:3oooooooooo`07
0?n000P0003o00<0oh000000o`000?l030000?l20?n000<0003o0P3oP00=0000o`H0oh000`000?l2
0?n000P0003o203oP00:0000o`H0oh001P000?lC0?n00080003o4@3oP0030000oa80oh0000<0003o
0?n0003oP0000`3oP0000`000?l0oh000?n000060?n000<0003o00<0oh000000o`000?l00`000?l4
0?n000<0003o2_ooool000Wooooo00@0]kNg0;2`/02`/;00/k>c0P2`/;00102_[jl0[:b/0:b/[02Y
ZJT20:b/[0040:^[Z`2/[:`0[:b/051@D080XZ:R0`2UYJD0102MWId0V9RH09RHV02@T90209fMW@04
0:RXZ02ZZZX0ZZZZ0:n_[`80[Zj^00@0ZJVY0:NWY`2WYjL0G5aL0P2TY:@0102[Zj/0[:b/0:b/[02Y
ZJT20:^[Z`<0ZJVY00D0YjNW0:VYZ@2a/K40/K6a0;Ng]`020;^k^`040;no_`1fMWH0MWIf0:NWY`80
[Jf]00@0Y:BT09^KV`2KVi/0WIfM0P2RXZ800`2QXJ40ZJVY0:VYZ@030:j^[P040:f][@2`/;00/;2`
0:j^[P80Ng]k00@0S8b<0:ZZZP2ZZZX0YjNW0P2VYZH0102UYJD0[:b/0:b/[02^[Zh50;2`/0050:b/
[02ZZZX0ZZZZ0:ZZZP28R8P00P2f][H0102k^k/0`/;20<;2`P2l_;`20;^k^`040;jn_P32`/80`/;2
0;no_`<0`L710P35aLD0102n_[h0]KFe0;Fe]@29RHT20;Rh^0040;Zj^P2h^;P0^;Rh0;Bd]080[jn_
00<0][Jf0;Ng]`2g]kL00`2c/k<0102d];@0][Jf0;Jf]P2c/k<205mOG`0308V9R@2j^[X0^[Zj0080
_;bl0P2j^[X0102h^;P0/[:b0;:b/P2d];@20;Rh^0040;Bd]02j^[X0^[Zj0<30`080_;bl00@0JFUY
0:n_[`2_[jl0]kNg0P2a/K400`2/[:`0[jn_0:n_[`030;Bd]0040;Ng]`2d];@0];Bd0:RXZ080ZJVY
00@0[Jf]09JFUP2FUYH0I6AT0P2PX:00102^[Zh0/k>c0;>c/`2_[jl20:BTY0030:2PX?oooooooooo
00L0oh0020000?l00`3oP000003o0000o`0<0000o`80oh000`000?l20?n000d0003o1P3oP0030000
o`80oh0020000?l80?n000X0003o1P3oP0060000oa<0oh000P000?lA0?n000<0003o4P3oP0000`00
0?l0oh000?n000030?n000030000o`3oP000oh0000H0oh000`000?l00`3oP000003o0000o`030000
o`@0oh000`000?l:ooooo`002Oooool0102a/K40[jn_0:n_[`2_[jl20:ZZZP<0ZJVY00@0YZJV0:^[
Z`2[Zj/0[Jf]0P2_[jl0101PH600SXj>08j>SP29RHT209ZJVP0309bLW02QXJ40XJ6Q00<0WinO00@0
[:b/0:f][@2][Jd0[:b/0P2[Zj/0102ZZZX0[:b/0:b/[01bLW820;>c/`040:ZZZP2XZ:P0Z:RX0:NW
Y`80Z:RX00D0ZZZZ0:RXZ02XZ:P0Zj^[0:VYZ@020:f][@040;Bd]02k^k/0^k^k0;Zj^P80N7Qh00@0
/k>c0:j^[P2^[Zh0WIfM0P2JVYX0102EUID0YZJV0:JVYP2PX:020:BTY0040::RXP2UYJD0YJFU0:^[
Z`80[jn_00@0[Jf]07=cL`1cLg<0PH610P2KVi/0102FUYH0UiNG09NGU`2OWil20:RXZ0040:NWY`2Z
ZZX0ZZZZ0:VYZ@80[Zj^00D0Zj^[0:NWY`2MWId0WIfM08^;R`020;Fe]@040;Rh^02l_;`0_;bl0;^k
^`80]kNg00@0]KFe0;no_`2o_kl0a/K60P2m_Kd0102o_kl0alO70<O7a`33`l<20;Fe]@0407YjNP2e
]KD0]KFe0;Ng]`80^;Rh00@0]KFe0;6a/@2a/K40^k^k0P2h^;P0102e]KD0/[:b0;:b/P2[Zj/20:b/
[0040:f][@1JFUX0FUYJ07emO@80^;Rh00<0_;bl0;Zj^P2i^KT00P2i^KT50;Bd]0040;Rh^02i^KT0
^KVi0;^k^`80^KVi00@0I6AT09^KV`2KVi/0/k>c0P2/[:`0102YZJT0[jn_0:n_[`2c/k<20;:b/P04
0;2`/02_[jl0[jn_0:ZZZP80[Jf]00@0[Zj^092@T02@T900I6AT0P2[Zj/0102d];@0/[:b0;:b/P2c
/k<20:^[Z`030;6a/Ooooooooooo00@0oh0020000?l30?n000d0003o0P3oP0070000o`030?n00000
0?l0003o00X0003o1P3oP0020000o`<0oh003@000?l30?n000l0003o00<0oh000000o`000?l01000
0?lC0?n00080003o3@3oP0030000o`<0oh0000<0003o0?n0003oP000403oP0030000o`040?n00000
0?l0003o0000o`P0oh0000@0003o0?n0003oP000oh001@000?l40?n00080003o00<0oh00oooooooo
ool02?ooool000Wooooo00@0/k>c0;6a/@2a/K40/K6a0P2f][H0102`/;00WinO09nOW`2QXJ420:>S
X`<0ZJVY00@0EeMG08J6QP26QXH0V9RH0P2XZ:P30;6a/@040:j^[P2XZ:P0Z:RX0:b/[080/K6a00@0
/k>c0;Vi^@2i^KT0][Jf0P2b/[800`1`L700XZ:R0::RXP030:RXZ0040:NWY`2ZZZX0ZZZZ0:f][@80
ZZZZ00D0/k>c0;2`/02e]KD0]KFe0;Ng]`020;bl_0040;^k^`1lO7`0O7al0;Vi^@80]KFe00@0/;2`
0:j^[P2^[Zh0ZJVY0P2RXZ80102FUYH0X:2P0:2PX02[Zj/20;2`/0040;Jf]P2e]KD0]KFe0;>c/`80
Hf=S00@0NWYj08j>SP2>SXh0Rh^;0P2?Shl0102DU9@0XJ6Q0:6QX@2IVIT209fMW@<0XZ:R00D0Z:RX
09jNWP1lO7`0O7al0861P@020;6a/@040;Bd]02f][H0][Jf0;Ng]`80^KVi00@0^[Zj0;fm_@2m_Kd0
_Kfm0P2g]kL0102h^;P0_[jn0;jn_P2k^k/20;6a/@0408>3P`2c/k<0/k>c0;6a/@80][Jf00@0^KVi
0;Ng]`2g]kL0/[:b0P2a/K40102][Jd0[:b/0:b/[02[Zj/20:JVYP040:>SX`1GEeL0EeMG08^;R`80
];Bd00D0]kNg0;Vi^@2h^;P0^;Rh0;Jf]P020;6a/@040;>c/`2b/[80/[:b0;6a/@80]kNg00@0^KVi
0;Bd]02d];@0EUIF0P2DU9@0102_[jl0Z:RX0:RXZ02WYjL20:f][@040;6a/@2`/;00/;2`0:j^[P80
[Jf]00@0ZZZZ0:b/[02/[:`0Zj^[0P2>SXh0101gMgL0ZZZZ0:ZZZP2g]kL20;Bd]0040;>c/`2YZJT0
ZJVY0:n_[`;ooooo1`3oP0080000o`030?n000000?l0003o00<0003o103oP0030000o`L0oh002@00
0?l20?n000030000o`3oP000oh0000L0oh000P000?l50?n000P0003o1P3oP00F0000oa<0oh000P00
0?l;0?n000H0003o0P3oP0000`000?l0oh000?n0000A0?n00080003o00@0oh000000o`000?l0003o
203oP0090000o`@0oh000P000?l00`3oP03oooooooooo`08ooooo`002Oooool0102c/k<0/K6a0;6a
/@2a/K420;Jf]P040;2`/02OWil0WinO0:6QX@80Xj>S0`2YZJT0101GEeL0QXJ608J6QP2HV9P20:RX
Z0<0/K6a00@0[Zj^0:RXZ02XZ:P0[:b/0P2a/K40102c/k<0^KVi0;Vi^@2f][H20;:b/P03071`L02R
XZ80XZ:R00<0Z:RX00@0YjNW0:ZZZP2ZZZX0[Jf]0P2ZZZX01@2c/k<0/;2`0;Fe]@2e]KD0]kNg0080
_;bl00@0^k^k07alO01lO7`0^KVi0P2e]KD0102`/;00[Zj^0:j^[P2YZJT20::RXP0409JFUP2PX:00
X:2P0:^[Z`80/;2`00@0][Jf0;Fe]@2e]KD0/k>c0P1SHf<0101jNWX0SXj>08j>SP2;Rh/208n?S`04
09BDU02QXJ40XJ6Q09VIV@80WIfM0`2RXZ801@2XZ:P0WYjN07alO01lO7`0PH610080/K6a00@0];Bd
0;Jf]P2f][H0]kNg0P2i^KT0102j^[X0_Kfm0;fm_@2m_Kd20;Ng]`040;Rh^02n_[h0_[jn0;^k^`80
/K6a00@0Ph>30;>c/`2c/k<0/K6a0P2f][H0102i^KT0]kNg0;Ng]`2b/[820;6a/@040:f][@2/[:`0
[:b/0:^[Z`80YZJV00@0Xj>S05MGE`1GEeL0Rh^;0P2d];@01@2g]kL0^KVi0;Rh^02h^;P0][Jf0080
/K6a00@0/k>c0;:b/P2b/[80/K6a0P2g]kL0102i^KT0];Bd0;Bd]01FEUH209BDU0040:n_[`2XZ:P0
Z:RX0:NWY`80[Jf]00@0/K6a0;2`/02`/;00[Zj^0P2][Jd0102ZZZX0[:b/0:b/[02[Zj/208j>SP04
07MgM`2ZZZX0ZZZZ0;Ng]`80];Bd00@0/k>c0:VYZ@2YZJT0[jn_0_ooool70?n000P0003o00<0oh00
0000o`000?l00`000?l40?n000<0003o1`3oP0090000o`80oh0000<0003o0?n0003oP0001`3oP002
0000o`D0oh0020000?l60?n001H0003o4`3oP0020000o`/0oh001P000?l20?n000030000o`3oP000
oh000140oh000P000?l0103oP000003o0000o`000?l80?n000T0003o103oP0020000o`030?n00?oo
oooooooo00Sooooo0009ooooo`0406IVIP1MGEd0GEeM04Q8B080>CTi00@0<C4a03Hf=P0f=SH0=3@d
0P0a<C401011@D40?3`l03`l?00d=3@2038b<P040410@00k>c/0>c/k03`l?080>CTi00@0@T9203dm
?@0m?Cd0<30`0P0f=SH0100l?3`0?Shn03hn?P0k>c/203Xj>P0402HV9P0n?Sh0?Shn04a<C080Bd];
00@0CDe=03dm?@0m?Cd0>c/k0P0d=3@01@0e=CD0:RXZ03Xj>P0j>SX0@d=30080ATI600@0>SXj03/k
>`0k>c/0FEUI0P1NGUh0101QHF40EUIF05IFEP1PH602065QH@04061PH01MGEd0GEeM065QH@80JVYZ
00@0MGEe07=cL`1cLg<0Jf][0P0d=3@0101>CTh0Fe]K05]KF`1LG5`206IVIP04069RHP1SHf<0Hf=S
06ATI080Jf][00D0K6a/06i^KP1^KVh0KVi^06MWI`0206EUI@0404Q8B01kNg/0Ng]k0820P080PH61
00@0O7al06a/K01/K6`0IVIV0P1`L7001021PH40QHF508F5Q@2:RXX2092@T00408n?S`1UIFD0IFEU
065QH@80SXj>00@0Ogmo0:>SX`2SXj<0XJ6Q0P2TY:@0102NWYh0X:2P0:2PX02LW9`209NGU`0409RH
V02KVi/0Vi^K09:BTP80CTi>00D0QHF50;6a/@2a/K40/k>c0;Rh^0020;Jf]P030;Bd]02_[jl0[jn_
00<0[Zj^00@0/k>c0;:b/P2b/[80/k>c0P2][Jd0101:BTX0WYjN09jNWP2`/;030:j^[P80/;2`00@0
/K6a0;:b/P2b/[80/[:b0P2[Zj/0102OWil0ZZZZ0:ZZZP2`/;0208b<S00407MgM`2RXZ80XZ:R0:BT
Y080/K6a0`2YZJT0102a/K7oooooooooo`000?ll0?n000030000o`3oP000003o00@0003o00<0oh00
0000o`000?l01P000?l60?n000h0003o0P3oP00V0000o`80oh0000<0003o0?n0003oP0004@3oP002
0000o`X0oh001@000?l00`3oP000003o0000o`040000o`80oh000`000?l00`3oP03oooooooooo`08
ooooo`002Oooool0102g]kL0][Jf0;Jf]P2[Zj/2079bLP0407UiN@2^[Zh0[Zj^0:n_[`D0/k>c00@0
];Bd0;bl_02l_;`0^;Rh0P2d];@0102][Jd0[:b/0:b/[02YZJT209>CT`04059BDP2c/k<0/k>c0;Jf
]P80]kNg00@0/k>c0;:b/P2b/[80ZZZZ0P2UYJD0102MWId0U9BD09BDU02<S8`208f=S@05096AT@27
QhL0QhN704U9B@2NWYh00P2/[:`0102][Jd0Y:BT0:BTY02TY:@30:NWY`80YZJV00@0X:2P09^KV`2K
Vi/0UiNG0P2ATI401023Ph<0Cdm?04m?C`1mOGd20861P@0408:2PP20P800P82007inOP80MgMg00@0
K6a/06QXJ01XJ6P0IFEU0`1YJFT207IfMP04071`L00f=SH0=SHf059BDP80GemO00D0FEUI05iNGP1U
IFD0IFEU06i^KP0206a/K00406MWI`1RHV80HV9R05]KF`80GEeM00@0EUIF03dm?@0m?Cd0;bl_0`1:
BTX204m?C`0404Y:BP19BDT0BDU903hn?P80;bl_00@0ATI603lo?`0o?cl0@4100P0k>c/0100e=CD0
C4a<04a<C01BDU82055AD@0405EEE@18B4P0B4Q804U9B@80De=C00D0E5AD04A4A014A4@0@D5104Q8
B00203/k>`0402`/;00^;Rh0;Rh^03Lg=`80>SXj00@0@d=304M7A`17AdL0CDe=0P0g=cL0100];Bd0
@D510451@@1>CTh204];B`04051@D01DE5@0E5AD05YJFP80GUiN00@0HV9R06IVIP1VIVH0K6a/0P1Z
JVX0101XJ6P0DU9B059BDP0e=CD205=CD`0405eMG@1ZJVX0JVYZ06EUI@80HV9R00<0MWIfoooooooo
ool00`3oP0040000o`l0oh001@000?l80?n000`0003o0P3oP0030000o`030?n000000?l0003o00d0
003o00<0oh000000o`000?l04P000?l30?n000040000o`3oP000oh000?n000L0003o@`3oP0070000
o`H0oh001P000?l:ooooo`002Oooool0102g]kL0][Jf0;Jf]P2[Zj/2079bLP0407UiN@2^[Zh0[Zj^
0:n_[`D0/k>c00@0];Bd0;bl_02l_;`0^;Rh0P2d];@0102][Jd0[:b/0:b/[02YZJT209>CT`04059B
DP2c/k<0/k>c0;Jf]P80]kNg00@0/k>c0;:b/P2b/[80ZZZZ0P2UYJD0102MWId0U9BD09BDU02<S8`2
08f=S@05096AT@27QhL0QhN704U9B@2NWYh00P2/[:`0102][Jd0Y:BT0:BTY02TY:@30:NWY`80YZJV
00@0X:2P09^KV`2KVi/0UiNG0P2ATI401023Ph<0Cdm?04m?C`1mOGd20861P@0408:2PP20P800P820
07inOP80MgMg00@0K6a/06QXJ01XJ6P0IFEU0`1YJFT207IfMP04071`L00f=SH0=SHf059BDP80GemO
00D0FEUI05iNGP1UIFD0IFEU06i^KP0206a/K00406MWI`1RHV80HV9R05]KF`80GEeM00@0EUIF03dm
?@0m?Cd0;bl_0`1:BTX204m?C`0404Y:BP19BDT0BDU903hn?P80;bl_00@0ATI603lo?`0o?cl0@410
0P0k>c/0100e=CD0C4a<04a<C01BDU82055AD@0405EEE@18B4P0B4Q804U9B@80De=C00D0E5AD04A4
A014A4@0@D5104Q8B00203/k>`0402`/;00^;Rh0;Rh^03Lg=`80>SXj00@0@d=304M7A`17AdL0CDe=
0P0g=cL0100];Bd0@D510451@@1>CTh204];B`04051@D01DE5@0E5AD05YJFP80GUiN00@0HV9R06IV
IP1VIVH0K6a/0P1ZJVX0101XJ6P0DU9B059BDP0e=CD205=CD`0405eMG@1ZJVX0JVYZ06EUI@80HV9R
00<0MWIfooooooooool00`3oP0040000o`l0oh001@000?l80?n000`0003o0P3oP0030000o`030?n0
00000?l0003o00d0003o00<0oh000000o`000?l04P000?l30?n000040000o`3oP000oh000?n000L0
003o@`3oP0070000o`H0oh001P000?l:ooooo`002Oooool0102a/K40/[:b0;:b/P2XZ:P207IfMP04
08V9R@2][Jd0[Jf]0;6a/@<0]KFe0P2i^KT0102j^[X0^k^k0;^k^`30`<020;^k^`040:j^[P2VYZH0
YZJV0:^[Z`80[:b/00@0FUYJ0:f][@2][Jd0[jn_0P2e]KD0102WYjL0[Zj^0:j^[P2][Jd20:VYZ@04
0::RXP2MWId0WIfM08b<S080T92@00D0UiNG09^KV`2KVi/0DE5A0:j^[P020;2`/0<0ZJVY00@0[Zj^
0:n_[`2_[jl0]KFe0P2d];@0102_[jl0ZZZZ0:ZZZP2TY:@20:>SX`040:6QX@1ZJVX0JVYZ0:VYZ@80
^;Rh00@0^k^k0;fm_@2m_Kd0_[jn0P2l_;`0102i^KT0^[Zj0;Zj^P2i^KT20;Fe]@040;Vi^@2l_;`0
_;bl0;bl_080JFUY0`2b/[800`2ZZZX0YjNW0;Bd]0040;Bd]0040;>c/`2h^;P0^;Rh0;Rh^080];Bd
00@0/[:b09FEU@2EUID0EeMG0P2`/;00102HV9P0/k>c0;>c/`2k^k/20;fm_@<0_[jn0`2o_kl0102k
^k/0Jf][06][J`1TI6@20;Bd]0040;Jf]P2h^;P0^;Rh0;Ng]`<0/k>c0P2g]kL30;^k^`050<71`@2o
_kl0^;Rh0;Rh^01]KFd00P1mOGd0102UYJD0ZJVY0:VYZ@2PX:020;2`/0040;bl_02k^k/0^k^k0;Zj
^P80[jn_00@0Zj^[09ZJVP2JVYX0UYJF0P2<S8`0101>CTh0LW9b079bLP25QHD207inOP040820P01o
Ogl0Ogmo079bLP80KFe]00@0M7Ad07]kN`1kNg/0L71`0P1hN7P01021PH40Q8B408B4Q01RHV82oooo
o`<0oh0010000?l?0?n000D0003o1@3oP0020000o`<0oh002P000?l50?n000<0003o1`3oP0090000
oa80oh0000@0003o0?n0003oP000oh000`000?l<0?n000040000o`3oP000oh000?n00080003o303o
P0020000oa80oh0020000?l70?n000H0003o00<0oh000000o`000?l04`000?l:ooooo`002Oooool3
0;2`/0040:f][@1gMgL0MgMg08Z:RP<0[Zj^0P2b/[80102h^;P0/k>c0;>c/`2d];@20;:b/P040;>c
/`2d];@0];Bd0:f][@80WYjN00@0[:b/09jNWP2NWYh0Fe]K0P2^[Zh30;>c/`040:BTY02XZ:P0Z:RX
0:RXZ080YJFU00@0YjNW09jNWP2NWYh0Vi^K0P2NWYh01@2LW9`0X:2P0:2PX019BDT0[:b/0080[Zj^
00@0Zj^[0:BTY02TY:@0X:2P0P2^[Zh0102g]kL0]KFe0;Fe]@2a/K420:j^[P040:VYZ@2OWil0WinO
09jNWP80IfMW00@0[jn_0;Jf]P2f][H0]kNg1P2k^k/20;bl_0040;Vi^@2g]kL0]kNg0;Vi^@80^k^k
00@0_[jn06EUI@1UIFD0/k>c0P2/[:`01@2YZJT0YjNW0:^[Z`2[Zj/0/[:b0080];Bd0`2b/[80102`
/;00[Jf]0:f][@2][Jd209bLW00407QhN02c/k<0/k>c09ZJVP80ZZZZ00@0_kno0;jn_P2n_[h0_Kfm
0P2l_;`01032`/80`l?30<?3``2m_Kd206QXJ00406UYJ@2g]kL0]kNg0;6a/@80][Jf00@0]KFe0;Bd
]02d];@0][Jf0P2i^KT00`2e]KD0_;bl0;bl_0020;jn_P80^;Rh00@0PX:208j>SP2>SXh0[jn_0P2/
[:`00`2XZ:P0/k>c0;>c/`030;Zj^P040;no_`2h^;P0^;Rh0;bl_080^KVi00@0]kNg0;2`/02`/;00
EUIF0P2SXj<30;jn_P040<30`02m_Kd0_Kfm0;^k^`80^;Rh00@0^k^k0;fm_@2m_Kd0`<300P32`/80
1031`L40_;bl0;bl_02DU9@2ooooo`@0oh000`000?l?0?n000D0003o1@3oP00?0000o`80oh0000<0
003o0?n0003oP00010000?l70?n000H0003o503oP0000`000?l0oh000?n000050000o`/0oh000`00
0?l0103oP000003o0000o`000?l;0?n00080003o4P3oP0030000o`80oh000`000?l>0?n00080003o
4P3oP0000`000?ooooooooooo`08ooooo`002Oooool30;2`/0040:f][@1gMgL0MgMg08Z:RP<0[Zj^
0P2b/[80102h^;P0/k>c0;>c/`2d];@20;:b/P040;>c/`2d];@0];Bd0:f][@80WYjN00@0[:b/09jN
WP2NWYh0Fe]K0P2^[Zh30;>c/`040:BTY02XZ:P0Z:RX0:RXZ080YJFU00@0YjNW09jNWP2NWYh0Vi^K
0P2NWYh01@2LW9`0X:2P0:2PX019BDT0[:b/0080[Zj^00@0Zj^[0:BTY02TY:@0X:2P0P2^[Zh0102g
]kL0]KFe0;Fe]@2a/K420:j^[P040:VYZ@2OWil0WinO09jNWP80IfMW00@0[jn_0;Jf]P2f][H0]kNg
1P2k^k/20;bl_0040;Vi^@2g]kL0]kNg0;Vi^@80^k^k00@0_[jn06EUI@1UIFD0/k>c0P2/[:`01@2Y
ZJT0YjNW0:^[Z`2[Zj/0/[:b0080];Bd0`2b/[80102`/;00[Jf]0:f][@2][Jd209bLW00407QhN02c
/k<0/k>c09ZJVP80ZZZZ00@0_kno0;jn_P2n_[h0_Kfm0P2l_;`01032`/80`l?30<?3``2m_Kd206QX
J00406UYJ@2g]kL0]kNg0;6a/@80][Jf00@0]KFe0;Bd]02d];@0][Jf0P2i^KT00`2e]KD0_;bl0;bl
_0020;jn_P80^;Rh00@0PX:208j>SP2>SXh0[jn_0P2/[:`00`2XZ:P0/k>c0;>c/`030;Zj^P040;no
_`2h^;P0^;Rh0;bl_080^KVi00@0]kNg0;2`/02`/;00EUIF0P2SXj<30;jn_P040<30`02m_Kd0_Kfm
0;^k^`80^;Rh00@0^k^k0;fm_@2m_Kd0`<300P32`/801031`L40_;bl0;bl_02DU9@2ooooo`@0oh00
0`000?l?0?n000D0003o1@3oP00?0000o`80oh0000<0003o0?n0003oP00010000?l70?n000H0003o
503oP0000`000?l0oh000?n000050000o`/0oh000`000?l0103oP000003o0000o`000?l;0?n00080
003o4P3oP0030000o`80oh000`000?l>0?n00080003o4P3oP0000`000?ooooooooooo`08ooooo`00
2Oooool0102^[Zh0[jn_0:n_[`2YZJT206UYJ@0408>3P`2`/;00/;2`0:VYZ@80[Jf]00@0]KFe0:RX
Z02XZ:P0ZZZZ0P2UYJD0102YZJT0[:b/0:b/[02/[:`209VIV@040:FUY@2QXJ40XJ6Q069RHP80]KFe
0`2d];@0102_[jl0[:b/0:b/[02WYjL20:RXZ0030:VYZ@2UYJD0YJFU00<0WinO00D0Vi^K0:>SX`2S
Xj<0@T920:2PX0020;:b/P040:BTY02VYZH0YZJV0:VYZ@80[:b/00@0]KFe0:j^[P2^[Zh0[Jf]0P2/
[:`0102YZJT0YZJV0:JVYP2NWYh205mOG`040:n_[`2d];@0];Bd0;>c/`80]KFe00@0]kNg0;Jf]P2f
][H0][Jf0`2k^k/20;Jf]P040;>c/`2b/[80/[:b0:FUY@80HV9R00D0/[:b0:ZZZP2ZZZX0V9RH0:6Q
X@020:j^[P040;Ng]`2l_;`0_;bl0;Ng]`80/k>c00@0/K6a0:j^[P2^[Zh0[Zj^0P2FUYH0101bLW80
[Zj^0:j^[P2XZ:P20:f][@040;6a/@2h^;P0^;Rh0;Jf]P80^k^k00@0_Kfm0;Zj^P2j^[X0]kNg0P1e
MGD0101UIFD0/k>c0;>c/`2b/[820;Jf]P<0/k>c00<0];Bd0;Ng]`2g]kL00`2h^;P01@2n_[h0_Kfm
0;Vi^@2i^KT0M7Ad0080Rh^;00@0[Jf]0:^[Z`2[Zj/0Vi^K0P2_[jl0102g]kL0^k^k0;^k^`2g]kL2
0;:b/P040;>c/`2d];@0];Bd0;Zj^P80/K6a00@0AdM70;2`/02`/;00`l?30P35aLD01033`l<0^k^k
0;^k^`2g]kL20;:b/P040;Ng]`2k^k/0^k^k0;jn_P80`l?300@0`<300;Vi^@2i^KT0Shn?0_ooool3
0?n000@0003o0P3oP00010000?l0oh000?n0003oP00?0000o`H0oh003@000?l20?n000030000o`3o
P000oh0000H0003o103oP0070000oa80oh000`000?l20?n000@0003o303oP0030000o`030?n00000
0?l0003o00`0oh000P000?lB0?n000<0003o0P3oP0030000ob80oh0000<0003oooooooooool02?oo
ool000Wooooo00@0R8R807inOP1nOWh0Jf][0P18B4P0101OGel0Ng]k07]kN`1iNGT20861P@0408J6
QP1nOWh0OWin07IfMP80N7Qh00@0Lg=c06i^KP1^KVh0LG5a0P1ZJVX0101VIVH0I6AT06ATI019BDT2
08R8R00408B4Q028R8P0R8R80820P080HV9R00@0IFEU06IVIP1VIVH0Jf][0P1]KFd0101KFe/0GemO
05mOG`1CDe<205MGE`0502<S8`10@400IFEU06EUI@1bLW800P1gMgL0101nOWh0TY:B09:BTP2ATI42
08V9R@0407IfMP21PH40PH6107emO@80Q8B400@0P82003/k>`0k>c/0T92@0P2NWYh30:^[Z`0408b<
S02FUYH0UYJF0:6QX@80][Jf00@0XZ:R09RHV02HV9P0];Bd0P2e]KD0102VYZH0Kfm_06m_K`2b/[82
0:JVYP0508V9R@2OWil0[:b/0:b/[02`/;000P2d];@0102b/[80]KFe0;Fe]@2`/;020;Fe]@040;:b
/P2=SHd0SHf=05UIF@80VIVI00@0[Jf]0;:b/P2b/[80/k>c0P2d];@0102f][H0/K6a0;6a/@2d];@2
0;:b/P040:^[Z`1aLG40LG5a07=cL`80];Bd00@0/;2`0:^[Z`2[Zj/0[Jf]0`2`/;020;>c/`050;Fe
]@2g]kL0]kNg0;Vi^@2f][H00P2d];@00`1[Jf/0SHf=08f=S@030:VYZ@040:2PX02][Jd0[Jf]0;Ng
]`80^;Rh00@0]kNg0:j^[P2^[Zh0/K6a0P2d];@0102h^;P0[jn_0:n_[`17AdL20:f][@040;no_`2n
_[h0_[jn0;bl_080]kNg00@0]KFe0:RXZ02XZ:P0/k>c0P2h^;P0102m_Kd0^k^k0;^k^`2l_;`20:RX
Z0030861POoooooooooo00@0003o0P3oP00E0000o`030?n000000?l0003o00/0003o0P3oP0000`00
0?l0oh000?n000040?n00180003o00<0oh000000o`000?l02@000?l0103oP000003o0000o`000?l3
0?n000<0003o0P3oP0050000o`/0oh0000@0003o0?n0003oP000003o303oP0040000o`<0oh000P00
0?l=0?n000P0003o5`3oP0020000o`L0oh000`000?l:ooooo`002Oooool01028R8P0OWin07inOP1[
Jf/204Q8B00405mOG`1kNg/0Ng]k07UiN@80PH6100@0QXJ607inOP1nOWh0MWIf0P1hN7P0101cLg<0
KVi^06i^KP1aLG4206YZJP0406IVIP1TI6@0I6AT04U9B@80R8R800@0Q8B408R8R028R8P0P8200P1R
HV80101UIFD0IVIV06IVIP1[Jf/206e]K@0405]KF`1OGel0GemO05=CD`80EeMG00D08b<S0410@01U
IFD0IFEU079bLP0207MgM`0407inOP2BTY80TY:B096AT@80RHV900@0MWIf0861P@21PH40OGem0P24
Q8@01020P800>c/k03/k>`2@T90209jNWP<0Zj^[00@0S8b<09JFUP2FUYH0XJ6Q0P2f][H0102RXZ80
V9RH09RHV02d];@20;Fe]@040:JVYP1_Kfl0Kfm_0;:b/P80YZJV00D0RHV909nOW`2/[:`0[:b/0;2`
/0020;Bd]0040;:b/P2e]KD0]KFe0;2`/080]KFe00@0/[:b08f=S@2=SHd0FEUI0P2IVIT0102][Jd0
/[:b0;:b/P2c/k<20;Bd]0040;Jf]P2a/K40/K6a0;Bd]080/[:b00@0Zj^[075aL@1aLG40Lg=c0P2d
];@0102`/;00Zj^[0:^[Z`2][Jd30;2`/080/k>c00D0]KFe0;Ng]`2g]kL0^KVi0;Jf]P020;Bd]003
06][J`2=SHd0SHf=00<0ZJVY00@0X:2P0:f][@2][Jd0]kNg0P2h^;P0102g]kL0[Zj^0:j^[P2a/K42
0;Bd]0040;Rh^02_[jl0[jn_04M7A`80[Jf]00@0_kno0;jn_P2n_[h0_;bl0P2g]kL0102e]KD0Z:RX
0:RXZ02c/k<20;Rh^0040;fm_@2k^k/0^k^k0;bl_080Z:RX00<0PH61ooooooooool010000?l20?n0
01D0003o00<0oh000000o`000?l02`000?l20?n000030000o`3oP000oh0000@0oh004P000?l00`3o
P000003o0000o`090000o`040?n000000?l0003o0000o`<0oh000`000?l20?n000D0003o2`3oP000
10000?l0oh000?n000000?l<0?n000@0003o0`3oP0020000o`d0oh0020000?lG0?n00080003o1`3o
P0030000o`[ooooo0009ooooo`040:BTY02IVIT0VIVI08f=S@<0T92@0P28R8P01025QHD0Q8B408B4
Q024Q8@205MGE`0406ATI01`L700L71`075aL@80Lg=c00@0N7Qh07UiN@1iNGT0KVi^0P1_Kfl0101m
OGd0MgMg07MgM`1kNg/20820P00407UiN@1EEED0EEEE0492@P80IFEU00@0KVi^06a/K01/K6`0LW9b
0P1aLG400`1cLg<0LG5a075aL@0206a/K080NWYj00@0MGEe06EUI@1UIFD0Fe]K0P0`<300101CDe<0
EEEE05EEE@1GEeL205QHF00405IFEP1LG5`0G5aL05YJFP80I6AT00@0E5AD05QHF01HF5P0Fe]K0P1G
EeL0100n?Sh092@T02@T9011@D4204Q8B0<0@T9200@0?3`l03lo?`0o?cl0CDe=0P16ATH01@18B4P0
>3Ph03Ph>012@T80Cdm?0080<c<c00@0?Cdm051@D01@D500ADE50`1GEeL204E5A@0404m?C`1@D500
D51@02l_;`80>c/k00@0ADE505=CD`1CDe<0EUIF0P1<C4`404i>CP80EeMG00@0Hf=S04=3@`13@d<0
=SHf0`19BDT2059BDP0405EEE@1KFe/0Fe]K05MGE`80FUYJ00D0GUiN06=SH`1SHf<0HV9R065QH@02
06IVIP<0<S8b00@0H61P06UYJ@1YJFT0LG5a0P1bLW80101hN7P0OGem07emO@1lO7`207MgM`0407em
O@1_Kfl0Kfm_07QhN080KVi^00@0;bl_06][J`1[Jf/0U9BD0P2GUiL0102DU9@0Vi^K09^KV`2HV9P2
09BDU0<0TI6A00@0Xj>S0:JVYP2VYZH0[Jf]0P1iNGT00`1RHV;oooooooooo`0=0000o`80oh004`00
0?l30?n00180003o3@3oP0000`000?l0oh000?n0000e0?n00080003o3P3oP0060000o`<0oh004P00
0?l00`3oP000003o0000o`0?0000o`040?n000000?l0003o0000o`[ooooo0009ooooo`040;Vi^@2g
]kL0]kNg0;Rh^0D0_;bl00@0^KVi0;Ng]`2g]kL0]KFe0P1^KVh0102BTY80/[:b0;:b/P2XZ:P20;Ng
]`040;Rh^02i^KT0^KVi0;Rh^080];Bd00@0^KVi0;Rh^02h^;P0]kNg0`2h^;P207YjNP0306][J`2]
[Jd0[Jf]00<0YjNW00@0[jn_0;6a/@2a/K40^;Rh0P2g]kL01@2h^;P0];Bd0;>c/`2c/k<0[Jf]0080
ZZZZ00@0Ti>C03dm?@0m?Cd0Xj>S0P2`/;00102TY:@0VYZJ09ZJVP2BTY8208b<S00408B4Q02DU9@0
U9BD09bLW080XZ:R00@0YZJV0:^[Z`2[Zj/0Zj^[0P1BDU80102JVYX0Y:BT0:BTY02SXj<20:NWY`<0
ZJVY00@0YZJV0;6a/@2a/K40/[:b0P2a/K401@2[Zj/0[:b/0:n_[`2_[jl0JFUY0080YZJV00@0Z:RX
0:BTY02TY:@0YZJV0P2ZZZX0102[Zj/0YjNW0:NWY`2/[:`20:NWY`040:ZZZP2YZJT0ZJVY0:NWY`80
QXJ600@0MgMg0:JVYP2VYZH0YZJV0P2WYjL0102/[:`0Zj^[0:^[Z`2RXZ820:>SX`040:6QX@2IVIT0
VIVI09RHV080Shn?00@0OGem03dm?@0m?Cd0EEEE0P1`L7001@1]KFd0JFUY06YZJP1ZJVX0MWIf0080
NGUi00@0MgMg07YjNP1jNWX0L71`0P1]KFd0101UIFD0I6AT06ATI010@40205mOG`0406=SH`1WIfL0
IfMW06IVIP80IFEU00@0Hf=S06ATI01TI6@0Hf=S0P1RHV80101TI6@0IfMW06MWI`1CDe<203lo?`04
03dm?@1PH600H61P06=SH`80IVIV00@0J6QX06IVIP1VIVH0GEeM0_ooool=0?n000<0003o0P3oP000
0`000?l0oh000?n0000=0?n000<0003o00@0oh000000o`000?l0003o303oP0030000o`80oh0000<0
003o0?n0003oP00040000?l00`3oP000003o0000o`090000o`@0oh000`000?l00`3oP000003o0000
o`0V0000o`<0oh004P000?l00`3oP000003o0000o`0?0000o`@0oh0020000?l00`3oP03ooooooooo
o`08ooooo`002Oooool0102i^KT0]kNg0;Ng]`2h^;P50;bl_0040;Vi^@2g]kL0]kNg0;Fe]@80KVi^
00@0TY:B0;:b/P2b/[80Z:RX0P2g]kL0102h^;P0^KVi0;Vi^@2h^;P20;Bd]0040;Vi^@2h^;P0^;Rh
0;Ng]`<0^;Rh0P1jNWX00`1[Jf/0[Jf]0:f][@030:NWY`040:n_[`2a/K40/K6a0;Rh^080]kNg00D0
^;Rh0;Bd]02c/k<0/k>c0:f][@020:ZZZP0409>CT`0m?Cd0?Cdm0:>SX`80/;2`00@0Y:BT09ZJVP2J
VYX0TY:B0P2<S8`01024Q8@0U9BD09BDU02LW9`20::RXP040:JVYP2[Zj/0Zj^[0:^[Z`80DU9B00@0
VYZJ0:BTY02TY:@0Xj>S0P2WYjL30:VYZ@040:JVYP2a/K40/K6a0;:b/P80/K6a00D0Zj^[0:b/[02_
[jl0[jn_06UYJ@020:JVYP040:RXZ02TY:@0Y:BT0:JVYP80ZZZZ00@0Zj^[0:NWY`2WYjL0[:b/0P2W
YjL0102ZZZX0ZJVY0:VYZ@2WYjL208J6QP0407MgM`2VYZH0YZJV0:JVYP80YjNW00@0[:b/0:^[Z`2[
Zj/0XZ:R0P2SXj<0102QXJ40VIVI09VIV@2HV9P208n?S`0407emO@0m?Cd0?Cdm05EEE@80L71`00D0
KFe]06UYJ@1ZJVX0JVYZ07IfMP0207UiN@0407MgM`1jNWX0NWYj071`L080KFe]00@0IFEU06ATI01T
I6@0@4100P1OGel0101SHf<0IfMW06MWI`1VIVH206EUI@0406=SH`1TI6@0I6AT06=SH`80HV9R00@0
I6AT06MWI`1WIfL0De=C0P0o?cl0100m?Cd0H61P061PH01SHf<206IVIP0406QXJ01VIVH0IVIV05eM
G@;ooooo3@3oP0030000o`80oh0000<0003o0?n0003oP0003@3oP0030000o`040?n000000?l0003o
0000o``0oh000`000?l20?n000030000o`3oP000oh000100003o00<0oh000000o`000?l02@000?l4
0?n000<0003o00<0oh000000o`000?l09P000?l30?n00180003o00<0oh000000o`000?l03`000?l4
0?n000P0003o00<0oh00ooooooooool02?ooool000Wooooo00@0^;Rh0;Ng]`2g]kL0_Kfm0P2n_[h0
0`2o_kl0_;bl0;bl_0030;Rh^0040;Fe]@1]KFd0KFe]096AT@80[Jf]00@0VYZJ0:VYZ@2YZJT0[Zj^
0P2/[:`0102[Zj/0[Jf]0:f][@2_[jl30;Ng]`80/K6a00@0ZZZZ08:2PP22PX80Jf][0P2TY:@0102U
YJD0XZ:R0::RXP2QXJ420:JVYP050:RXZ02YZJT0ZJVY0:n_[`2^[Zh00P2a/K40102_[jl0/[:b0;:b
/P2QXJ4204U9B@040:b/[02_[jl0[jn_0:NWY`80V9RH00@0UiNG09BDU02DU9@0SXj>0P2:RXX0102<
S8`0U9BD09BDU02SXj<20:j^[P040:NWY`11@D40@D5109>CT`D0WIfM00@0YJFU0:6QX@2QXJ40Y:BT
0P2^[Zh01@2a/K40Zj^[0:^[Z`2][Jd0]KFe0080/k>c00<0NGUi0:^[Z`2[Zj/01P2WYjL30:RXZ004
0:NWY`2ZZZX0ZZZZ0:ZZZP80ZJVY00@0ZZZZ08>3P`23Ph<0PH610`2`/;020:j^[P040;>c/`2d];@0
];Bd0;:b/P80/;2`00@0/[:b0;Bd]02d];@0ZZZZ0P2[Zj/0102YZJT0GemO05mOG`20P8020:2PX005
0:ZZZP2b/[80/;2`0;2`/02^[Zh00P2ZZZX0102][Jd0YjNW0:NWY`2TY:@20:RXZ0040:f][@2XZ:P0
Z:RX065QH@80YZJV00@0[Zj^0:n_[`2_[jl0/;2`0P2a/K40102d];@0/k>c0;>c/`2a/K420:j^[P04
0:VYZ@2ZZZX0ZZZZ09BDU080OGem00@0IFEU09FEU@2EUID0XJ6Q0P2/[:`30;Jf]P030;Bd]?oooooo
oooo00d0oh000`000?l20?n000<0003o00@0oh000000o`000?l0003o1`3oP00?0000o`P0oh0000@0
003o0?n0003oP000003o0P3oP00=0000o`040?n000000?l0003o0?n000/0003o0`3oP0000`000?l0
oh000?n000020?n001L0003o3@3oP00:0000o`D0oh0000<0003o0?n0003oP00010000?l20?n000@0
003o303oP00<0000o`@0oh002_ooool000Wooooo00@0]kNg0;Fe]@2e]KD0]kNg0P2h^;P30;Fe]@04
0;Bd]02g]kL0]kNg0;2`/080JFUY00@0RXZ:0:VYZ@2YZJT0V9RH0`2YZJT20:j^[P040:JVYP2YZJT0
ZJVY0:^[Z`<0[Zj^0P2_[jl0102[Zj/0OGem07emO@1UIFD209ZJVP0409:BTP2OWil0WinO0::RXP80
YJFU0`2WYjL01@2YZJT0YjNW0:j^[P2^[Zh0[Jf]0080/K6a00@0[Zj^04Q8B018B4P0YJFU0P2XZ:P0
102KVi/0TI6A096AT@2DU9@208>3P`0308B4Q022PX80PX:200<0QHF500@0V9RH0:RXZ02XZ:P0UYJF
0P0o?cl0102>SXh0UYJF09JFUP2GUiL209ZJVP<0W9bL00@0Vi^K0:f][@2][Jd0[:b/0`2ZZZX0102c
/k<0/K6a0;6a/@1_Kfl20:NWY`0409nOW`2PX:00X:2P09nOW`80YJFU00@0WinO0:6QX@2QXJ40Xj>S
0P2UYJD0102TY:@0YJFU0:FUY@2WYjL208:2PP0308^;R`2/[:`0[:b/00<0[Jf]00@0ZZZZ0:RXZ02X
Z:P0YZJV0P2/[:`0102[Zj/0/;2`0;2`/02[Zj/20:f][@040:NWY`1>CTh0CTi>07IfMP80WYjN00D0
[:b/0:VYZ@2[Zj/0Zj^[0:ZZZP020:NWY`<0Xj>S00@0W9bL0::RXP2RXZ80WinO0P2YZJT0101LG5`0
WYjN09jNWP2/[:`20:RXZ0040:ZZZP2YZJT0ZJVY0:b/[080[Zj^00@0/k>c0:n_[`2_[jl0Z:RX0`2W
YjL209^KV`0406MWI`2EUID0UIFE09FEU@80YjNW00@0ZZZZ0:n_[`2_[jl0[Zj^0_ooool=0?n000T0
003o0P3oP0040000o`@0oh004P000?l80?n001<0003o00<0oh000000o`000?l02@000?l00`3oP000
003o0000o`030000o`80oh0060000?l30?n000L0003o0P3oP00010000?l0oh000?n000000?l20?n0
01<0003o00<0oh000000o`000?l01`000?l50?n000d0003o0`3oP00:ooooo`002Oooool0102g]kL0
]KFe0;Fe]@2g]kL20;Rh^0<0]KFe00@0];Bd0;Ng]`2g]kL0/;2`0P1YJFT0102:RXX0ZJVY0:VYZ@2H
V9P30:VYZ@80[Zj^00@0YZJV0:VYZ@2YZJT0Zj^[0`2^[Zh20:n_[`040:^[Z`1mOGd0OGem06EUI@80
VYZJ00@0TY:B09nOW`2OWil0XZ:R0P2UYJD30:NWY`050:VYZ@2WYjL0[Zj^0:j^[P2][Jd00P2a/K40
102^[Zh0B4Q804Q8B02UYJD20:RXZ00409^KV`2ATI40TI6A09BDU080Ph>300<0Q8B408:2PP22PX80
0`25QHD0102HV9P0Z:RX0:RXZ02FUYH203lo?`0408j>SP2FUYH0UYJF09NGU`80VYZJ0`2LW9`0102K
Vi/0[Jf]0:f][@2/[:`30:ZZZP040;>c/`2a/K40/K6a06m_K`80YjNW00@0WinO0:2PX02PX:00WinO
0P2UYJD0102OWil0XJ6Q0:6QX@2SXj<20:FUY@040:BTY02UYJD0YJFU0:NWY`80PX:200<0Rh^;0:b/
[02/[:`00`2][Jd0102ZZZX0Z:RX0:RXZ02VYZH20:b/[0040:^[Z`2`/;00/;2`0:^[Z`80[Jf]00@0
YjNW04i>CP1>CTh0MWIf0P2NWYh01@2/[:`0ZJVY0:^[Z`2[Zj/0ZZZZ0080YjNW0`2SXj<0102LW9`0
XZ:R0::RXP2OWil20:VYZ@0405aLG02NWYh0WYjN0:b/[080Z:RX00@0ZZZZ0:VYZ@2YZJT0[:b/0P2^
[Zh0102c/k<0[jn_0:n_[`2XZ:P30:NWY`80Vi^K00@0IfMW09FEU@2EUID0UIFE0P2WYjL0102ZZZX0
[jn_0:n_[`2^[Zh2ooooo`d0oh002@000?l20?n000@0003o103oP00B0000o`P0oh004`000?l00`3o
P000003o0000o`090000o`030?n000000?l0003o00<0003o0P3oP00H0000o`<0oh001`000?l20?n0
00040000o`3oP000oh000000o`80oh004`000?l00`3oP000003o0000o`070000o`D0oh003@000?l3
0?n000[ooooo0009ooooo`0408N7Q`22PX80PX:207emO@80Ng]k00@0OGem08B4Q024Q8@0SHf=0P2:
RXX0102<S8`0FUYJ05YJFP1lO7`2092@T004079bLP2BTY80TY:B09BDU0<0W9bL0P2KVi/0102PX:00
XJ6Q0:6QX@2YZJT20:RXZ0040:JVYP1gMgL0MgMg04m?C`80S8b<00@0TY:B09RHV02HV9P0X:2P0P2Q
XJ401@2PX:00Y:BT0:BTY02JVYX0[:b/0080/[:b00@0[Zj^0:b/[02/[:`0/;2`0P1<C4`0102WYjL0
X:2P0:2PX02?Shl208b<S004096AT@23Ph<0Ph>308:2PP80Ng]k00@0P82007moO`1oOgl0Q8B40P2D
U9@0102>SXh0EeMG05MGE`2;Rh/208j>SP0408B4Q027QhL0QhN708j>SP80X:2P00<0WinO0:j^[P2^
[Zh00`2][Jd01@2[Zj/0[jn_0:ZZZP2ZZZX0IVIV0080VIVI00<0UiNG09>CT`2CTi<00`2ATI40102F
UYH0WYjN09jNWP2OWil20:RXZ00409jNWP2OWil0WinO0::RXP80NWYj00@0P8200:VYZ@2YZJT0Z:RX
0P2WYjL0102XZ:P0YZJV0:JVYP2UYJD20:BTY0040:JVYP2SXj<0Xj>S0:>SX`80YZJV00@0XJ6Q05aL
G01LG5`0NGUi0P2GUiL01@2ZZZX0Zj^[0:VYZ@2YZJT0Y:BT0080WIfM0`2NWYh0102CTi<0U9BD09BD
U02FUYH209fMW@0405UIF@2PX:00X:2P0:JVYP<0Zj^[0`2WYjL20:b/[0030:n_[`2^[Zh0[Zj^00<0
V9RH00@0YJFU09RHV02HV9P0Jf][0P2;Rh/0101hN7P0UYJF09JFUP2UYJD30:NWY`;ooooo3@000?l2
0?n001@0003o0P3oP00=0000o`<0oh000P000?l30?n001<0003o00<0oh000000o`000?l02@000?l4
0?n00080003o00<0oh000000o`000?l09`000?l20?n001<0003o00<0oh000000o`000?l02@000?l3
0?n00100003o2_ooool000Wooooo00@0JFUY05mOG`1OGel0DE5A0P0`<300101=CDd0D51@051@D019
BDT20492@P0403Ti>@1;Bd/0Bd];04m?C`80ATI600@0BDU904I6AP16ATH0AdM70P1?Cdl0100i>CT0
:BTY02TY:@0o?cl204I6AP0404];B`11@D40@D5103dm?@80>CTi00@0:b/[030`<00`<300:RXZ0P0S
8b<00`0_;bl09RHV02HV9P0302<S8`0502XZ:P1<C4`0FUYJ05YJFP1PH6000P1MGEd01019BDT0@D51
0451@@1YJFT2079bLP0406YZJP1EEED0EEEE04m?C`80Fe]K00@0GEeM05MGE`1GEeL0HV9R0P1[Jf/0
101EEED0F5QH05QHF01GEeL203Lg=`0403Ti>@14A4@0A4A40410@080@T9200@0CDe=055AD@1ADE40
DU9B0P1<C4`01@1HF5P0EUIF05IFEP1HF5P0DU9B0080CDe=00@0@T9206EUI@1UIFD0IfMW0`1]KFd2
06][J`0406IVIP1WIfL0IfMW06ATI080G5aL00@0Hf=S06EUI@1UIFD0HV9R0P1ADE40101GEeL0NWYj
07YjNP20P802079bLP0307EeM@1oOgl0Ogmo00<0PH6100@0Ogmo071`L01`L700NGUi0P1nOWh0101o
Ogl0BTY:04Y:BP1SHf<206MWI`0507IfMP1hN7P0OGem07emO@1aLG400P1RHV80101IFET0CTi>04i>
CP1MGEd205]KF`0405UIF@1SHf<0Hf=S04Q8B080NWYj00@0PX:208Z:RP2:RXX0L71`0P1eMGD00`2;
Rh/0TY:B09:BTP0308n?S`0408>3P`1hN7P0N7Qh08V9R@80J6QX00@0FEUI07=cL`1cLg<0KVi^0P2:
RXX0102PX:00WIfM09fMW@2LW9`2ooooo`<0003o<@3oP0000`000?l0oh000?n000030?n000@0003o
1`3oP0030000oa/0oh0030000?l00`3oP000003o0000o`030000o`<0oh004@000?l20?n000X0003o
203oP0000`000?l0oh000000o`0C0000o`030?n000000?l0003o00L0003o2_ooool000Wooooo00@0
JFUY05mOG`1OGel0DE5A0P0`<300101=CDd0D51@051@D019BDT20492@P0403Ti>@1;Bd/0Bd];04m?
C`80ATI600@0BDU904I6AP16ATH0AdM70P1?Cdl0100i>CT0:BTY02TY:@0o?cl204I6AP0404];B`11
@D40@D5103dm?@80>CTi00@0:b/[030`<00`<300:RXZ0P0S8b<00`0_;bl09RHV02HV9P0302<S8`05
02XZ:P1<C4`0FUYJ05YJFP1PH6000P1MGEd01019BDT0@D510451@@1YJFT2079bLP0406YZJP1EEED0
EEEE04m?C`80Fe]K00@0GEeM05MGE`1GEeL0HV9R0P1[Jf/0101EEED0F5QH05QHF01GEeL203Lg=`04
03Ti>@14A4@0A4A40410@080@T9200@0CDe=055AD@1ADE40DU9B0P1<C4`01@1HF5P0EUIF05IFEP1H
F5P0DU9B0080CDe=00@0@T9206EUI@1UIFD0IfMW0`1]KFd206][J`0406IVIP1WIfL0IfMW06ATI080
G5aL00@0Hf=S06EUI@1UIFD0HV9R0P1ADE40101GEeL0NWYj07YjNP20P802079bLP0307EeM@1oOgl0
Ogmo00<0PH6100@0Ogmo071`L01`L700NGUi0P1nOWh0101oOgl0BTY:04Y:BP1SHf<206MWI`0507If
MP1hN7P0OGem07emO@1aLG400P1RHV80101IFET0CTi>04i>CP1MGEd205]KF`0405UIF@1SHf<0Hf=S
04Q8B080NWYj00@0PX:208Z:RP2:RXX0L71`0P1eMGD00`2;Rh/0TY:B09:BTP0308n?S`0408>3P`1h
N7P0N7Qh08V9R@80J6QX00@0FEUI07=cL`1cLg<0KVi^0P2:RXX0102PX:00WIfM09fMW@2LW9`2oooo
o`<0003o<@3oP0000`000?l0oh000?n000030?n000@0003o1`3oP0030000oa/0oh0030000?l00`3o
P000003o0000o`030000o`<0oh004@000?l20?n000X0003o203oP0000`000?l0oh000000o`0C0000
o`030?n000000?l0003o00L0003o2_ooool000Wooooo00@0^[Zj0;Vi^@2i^KT0/K6a0P1_Kfl0102i
^KT0]KFe0;Fe]@2`/;020;Bd]0040:f][@2b/[80/[:b0;>c/`80]kNg00@0^[Zj0;jn_P2n_[h0_kno
0P2j^[X0102VYZH0FUYJ05YJFP1lO7`208R8R0040;>c/`2j^[X0^[Zj0;Vi^@80_[jn00@0]KFe0;:b
/P2b/[80[Zj^0P2UYJD30:b/[0050:NWY`1:BTX0BTY:0:ZZZP2d];@00P2c/k<0102`/;00[Jf]0:f]
[@2`/;020::RXP<0[jn_00@0[:b/0:6QX@2QXJ40Vi^K0P2=SHd0101@D500WYjN09jNWP2/[:`20:NW
Y`040:BTY02XZ:P0Z:RX0:RXZ080XZ:R0`2MWId0102EUID0WinO09nOW`2KVi/207alO00404E5A@1o
Ogl0Ogmo08Z:RP80QHF500D0QhN708b<S02?Shl0Shn?08B4Q00208^;R`<0SXj>00@0TI6A09FEU@2E
UID0S8b<0P1FEUH0101`L700NWYj07YjNP1iNGT207]kN`0407IfMP1cLg<0Lg=c06e]K@80J6QX00@0
I6AT05QHF01HF5P0FEUI0P1GEeL0100/;2`0=cLg03Lg=`1NGUh205YJFP0405EEE@1HF5P0F5QH05iN
GP80I6AT00D0G5aL05IFEP1FEUH0HF5Q05YJFP0204Q8B00303`l?01LG5`0G5aL00<0IFEU00@0FEUI
05EEE@1EEED0Fe]K0P1TI6@0101XJ6P0GemO05mOG`1DE5@204i>CP0404=3@`0V9RH09RHV03Ph>080
AdM700<0?Shn0451@@11@D400`0o?cl0100l?3`0ADE504E5A@12@T8204U9B@0404e=C@1HF5P0F5QH
05=CD`80?Shn00<0A4A4ooooooooool0103oP0020000oa80oh0000<0003o0?n0003oP0000`000?l:
0?n000H0003o00<0oh000000o`000?l01`3oP0020000o`<0oh001@000?l20?n001<0003o0P3oP00C
0000o`030?n000000?l0003o00`0003o3P3oP0020000o`<0oh0000<0003o0?n0003oP000103oP003
0000o`D0oh0010000?lL0?n000[ooooo0009ooooo`040;Fe]@2d];@0];Bd0:j^[P80LG5a00@0/k>c
0;Bd]02d];@0]kNg0P2b/[80102^[Zh0/K6a0;6a/@2][Jd20;Ng]`040;^k^`2j^[X0^[Zj0;Ng]`80
/K6a00@0[Zj^04i>CP1>CTh0SXj>0P2EUID0102[Zj/0[jn_0:n_[`2g]kL20;Bd]0040;6a/@2[Zj/0
Zj^[0:RXZ080YJFU00@0Z:RX0:BTY02TY:@0WYjN0P1CDe<01@2_[jl0[Zj^0;2`/02`/;00[Zj^0080
YjNW00@0/;2`0:j^[P2^[Zh0[Zj^0P2[Zj/0102UYJD0Zj^[0:^[Z`2[Zj/20:b/[004061PH02/[:`0
[:b/0;6a/@80/[:b00@0][Jf0;Fe]@2e]KD0];Bd0P2`/;00102[Zj/0Vi^K09^KV`2MWId20:b/[004
0;:b/P2TY:@0Y:BT05=CD`80WinO00D0YJFU09bLW02LW9`0Vi^K0:BTY0020:NWY`040:JVYP2UYJD0
YJFU0:>SX`80YZJV00@0[:b/0:j^[P2^[Zh0/[:b0P1fMWH00`2i^KT0_Kfm0;fm_@030;fm_@<0_kno
00@0`<300;no_`2o_kl0_;bl0P2f][H0102c/k<0^k^k0;^k^`0o?cl208b<S0030:NWY`2XZ:P0Z:RX
00<0ZZZZ00@0[jn_0;Bd]02d];@0^;Rh0`2k^k/0102h^;P0KFe]06e]K@1^KVh20:BTY0040:VYZ@2b
/[80/[:b0;Rh^080_Kfm00@0^k^k0;fm_@2m_Kd0^k^k0P2h^;P0102a/K40[jn_0:n_[`2NWYh2055A
D@0409BDU02^[Zh0[Zj^0:VYZ@80[:b/00@0];Bd0;>c/`2c/k<0/;2`0P2i^KT00`2g]kL0_[jn0;jn
_P030;fm_@040:b/[01ZJVX0JVYZ0:j^[P;ooooo103oP0020000oaD0oh0010000?l60?n000T0003o
1`3oP0020000o`@0oh002P000?l90?n000H0003o0P3oP0000`000?l0oh000?n0000@0000o`<0oh00
00<0003o0?n0003oP0004@3oP0080000o`T0oh001P000?l=0?n000040000o`3oP000oh000000o`80
oh000`000?l<0?n000<0003o00<0oh00ooooooooool02?ooool000Wooooo00@0]KFe0;Bd]02d];@0
[Zj^0P1aLG40102c/k<0];Bd0;Bd]02g]kL20;:b/P040:j^[P2a/K40/K6a0:f][@80]kNg00@0^k^k
0;Zj^P2j^[X0]kNg0P2a/K40102^[Zh0CTi>04i>CP2>SXh209FEU@040:^[Z`2_[jl0[jn_0;Ng]`80
];Bd00@0/K6a0:^[Z`2[Zj/0Z:RX0P2UYJD0102XZ:P0Y:BT0:BTY02NWYh205=CD`050:n_[`2^[Zh0
/;2`0;2`/02^[Zh00P2WYjL0102`/;00[Zj^0:j^[P2^[Zh20:^[Z`040:FUY@2[Zj/0Zj^[0:^[Z`80
[:b/00@0H61P0:b/[02/[:`0/K6a0P2b/[80102f][H0]KFe0;Fe]@2d];@20;2`/0040:^[Z`2KVi/0
Vi^K09fMW@80[:b/00@0/[:b0:BTY02TY:@0De=C0P2OWil01@2UYJD0W9bL09bLW02KVi/0Y:BT0080
YjNW00@0YZJV0:FUY@2UYJD0Xj>S0P2VYZH0102/[:`0[Zj^0:j^[P2b/[8207IfMP030;Vi^@2m_Kd0
_Kfm00<0_Kfm0`2o_kl01030`<00_kno0;no_`2l_;`20;Jf]P040;>c/`2k^k/0^k^k03lo?`80S8b<
00<0YjNW0:RXZ02XZ:P00`2ZZZX0102_[jl0];Bd0;Bd]02h^;P30;^k^`040;Rh^01]KFd0KFe]06i^
KP80Y:BT00@0ZJVY0;:b/P2b/[80^;Rh0P2m_Kd0102k^k/0_Kfm0;fm_@2k^k/20;Rh^0040;6a/@2_
[jl0[jn_09jNWP80DE5A00@0U9BD0:j^[P2^[Zh0ZJVY0P2/[:`0102d];@0/k>c0;>c/`2`/;020;Vi
^@030;Ng]`2n_[h0_[jn00<0_Kfm00@0[:b/06YZJP1ZJVX0[Zj^0_ooool40?n00080003o5@3oP004
0000o`H0oh002@000?l70?n00080003o103oP00:0000o`T0oh001P000?l20?n000030000o`3oP000
oh000100003o0`3oP0000`000?l0oh000?n0000A0?n000P0003o2@3oP0060000o`d0oh0000@0003o
0?n0003oP000003o0P3oP0030000o``0oh000`000?l00`3oP03oooooooooo`08ooooo`002Oooool0
102e]KD0/K6a0;6a/@2VYZH206i^KP040;>c/`2h^;P0^;Rh0;Vi^@80];Bd00@0/K6a0:j^[P2^[Zh0
Zj^[0P2b/[80102g]kL0]KFe0;Fe]@2b/[820:b/[0040:f][@1MGEd0GEeM0:VYZ@80Xj>S00@0[Jf]
0:VYZ@2YZJT0YZJV0P2YZJT0102WYjL0Xj>S0:>SX`2SXj<20:NWY`040:ZZZP2PX:00X:2P08Z:RP80
GemO00D0[Zj^0:b/[02ZZZX0ZZZZ0:VYZ@0209jNWP040:JVYP2ZZZX0ZZZZ0:BTY080YZJV00@0YjNW
0:JVYP2VYZH0ZZZZ0P2`/;00101aLG40/K6a0;6a/@2][Jd20;Bd]0040;6a/@2][Jd0[Jf]0:FUY@80
XZ:R00@0WIfM0::RXP2RXZ80Xj>S0P2ZZZX0102/[:`0YZJV0:JVYP1;Bd/309jNWP80Shn?00D0UiNG
09:BTP2NWYh0WYjN09bLW00209jNWP040:BTY02RXZ80XZ:R0:VYZ@80[Jf]00@0/;2`075aL@1aLG40
^KVi0P2n_[h0102o_kl0`L710<71`@32`/820;jn_P040:n_[`2b/[80/[:b0;Jf]P80]KFe00@0^;Rh
0;Vi^@2i^KT0CDe=0P2TY:@0102WYjL0Zj^[0:^[Z`2YZJT20:ZZZP040:n_[`2b/[80/[:b0;Fe]@80
];Bd00D0]kNg0;Jf]P1YJFT0JFUY071`L0020:NWY`040:j^[P2c/k<0/k>c0;Ng]`80^k^k00@0_Kfm
0;Zj^P2j^[X0^[Zj0P2e]KD0102b/[80[:b/0:b/[02<S8`204Y:BP0309^KV`2ZZZX0ZZZZ00<0[Zj^
00@0[jn_0;2`/02`/;00/[:b0P2j^[X0102h^;P0^k^k0;^k^`2j^[X20;Vi^@040:n_[`1dM7@0M7Ad
0;6a/@;ooooo0`3oP0030000o`T0oh0000<0003o0?n0003oP000103oP0020000o`<0oh000`000?l0
0`3oP000003o0000o`0>0000o`80oh0040000?l00`3oP000003o0000o`070?n000`0003o0P3oP00@
0000o`<0oh0000<0003o0?n0003oP0004@3oP0080000o`T0oh0010000?l=0?n000<0003o0P3oP003
0000oa00oh000P000?l00`3oP03oooooooooo`08ooooo`002Oooool0102_[jl0ZZZZ0:ZZZP2WYjL2
07MgM`040;Fe]@2g]kL0]kNg0;Rh^080[Jf]00@0XJ6Q0:BTY02TY:@0ZJVY0P2c/k<0102d];@0/[:b
0;:b/P2][Jd20:VYZ@040:NWY`1HF5P0F5QH0:f][@80ZZZZ00@0[:b/0:j^[P2^[Zh0Y:BT0P2RXZ80
102UYJD0VYZJ09ZJVP2PX:020:>SX`040:NWY`2ZZZX0ZZZZ08n?S`80FUYJ00D0[Zj^0:RXZ02YZJT0
ZJVY0:NWY`0209:BTP0409VIV@2HV9P0V9RH09FEU@80VIVI00@0Z:RX0:ZZZP2ZZZX0YjNW0P2_[jl0
101TI6@0[Zj^0:j^[P2^[Zh20:b/[0040:j^[P2TY:@0Y:BT0:FUY@80YZJV00@0YJFU0:JVYP2VYZH0
Xj>S0P2QXJ40102UYJD0[jn_0:n_[`1=CDd209fMW@0509^KV`23Ph<0Ph>307moO`1lO7`00P2:RXX0
102ATI40U9BD09BDU02SXj<20:2PX0@0ZZZZ0P1bLW80102m_Kd0`L710<71`@30`<030;fm_@80^k^k
00@0^KVi0;>c/`2c/k<0^k^k0P2g]kL0102l_;`0^[Zj0;Zj^P1HF5P309ZJVP80SXj>00@0U9BD0:2P
X02PX:00YjNW0P2`/;001@2e]KD0^KVi0;Vi^@2i^KT0[Zj^0080CTi>00@0KFe]0:^[Z`2[Zj/0Zj^[
0P2/[:`0102[Zj/0[Jf]0:f][@2g]kL20;Fe]@040:j^[P2ZZZX0ZZZZ0:>SX`80Z:RX00@0U9BD04];
B`1;Bd/0VIVI0P2QXJ440:JVYP80UiNG00@0YJFU0:2PX02PX:00XJ6Q0P2YZJT0102a/K40Z:RX0:RX
Z02SXj<207emO@040;Bd]?oooooooooo0?n000D0003o1P3oP0040000o`H0oh000`000?l30?n000<0
003o00<0oh000000o`000?l030000?l30?n00100003o00<0oh000000o`000?l00`3oP0000`000?l0
oh000?n0000<0000o`<0oh0050000?lC0?n000T0003o2@3oP0080000o`D0oh001P000?l20?n000l0
003o00<0oh000000o`000?l00`000?l00`3oP03oooooooooo`08ooooo`002Oooool0102_[jl0ZZZZ
0:ZZZP2WYjL207MgM`040;Fe]@2g]kL0]kNg0;Rh^080[Jf]00@0XJ6Q0:BTY02TY:@0ZJVY0P2c/k<0
102d];@0/[:b0;:b/P2][Jd20:VYZ@040:NWY`1HF5P0F5QH0:f][@80ZZZZ00@0[:b/0:j^[P2^[Zh0
Y:BT0P2RXZ80102UYJD0VYZJ09ZJVP2PX:020:>SX`040:NWY`2ZZZX0ZZZZ08n?S`80FUYJ00D0[Zj^
0:RXZ02YZJT0ZJVY0:NWY`0209:BTP0409VIV@2HV9P0V9RH09FEU@80VIVI00@0Z:RX0:ZZZP2ZZZX0
YjNW0P2_[jl0101TI6@0[Zj^0:j^[P2^[Zh20:b/[0040:j^[P2TY:@0Y:BT0:FUY@80YZJV00@0YJFU
0:JVYP2VYZH0Xj>S0P2QXJ40102UYJD0[jn_0:n_[`1=CDd209fMW@0509^KV`23Ph<0Ph>307moO`1l
O7`00P2:RXX0102ATI40U9BD09BDU02SXj<20:2PX0@0ZZZZ0P1bLW80102m_Kd0`L710<71`@30`<03
0;fm_@80^k^k00@0^KVi0;>c/`2c/k<0^k^k0P2g]kL0102l_;`0^[Zj0;Zj^P1HF5P309ZJVP80SXj>
00@0U9BD0:2PX02PX:00YjNW0P2`/;001@2e]KD0^KVi0;Vi^@2i^KT0[Zj^0080CTi>00@0KFe]0:^[
Z`2[Zj/0Zj^[0P2/[:`0102[Zj/0[Jf]0:f][@2g]kL20;Fe]@040:j^[P2ZZZX0ZZZZ0:>SX`80Z:RX
00@0U9BD04];B`1;Bd/0VIVI0P2QXJ440:JVYP80UiNG00@0YJFU0:2PX02PX:00XJ6Q0P2YZJT0102a
/K40Z:RX0:RXZ02SXj<207emO@040;Bd]?oooooooooo0?n000D0003o1P3oP0040000o`H0oh000`00
0?l30?n000<0003o00<0oh000000o`000?l030000?l30?n00100003o00<0oh000000o`000?l00`3o
P0000`000?l0oh000?n0000<0000o`<0oh0050000?lC0?n000T0003o2@3oP0080000o`D0oh001P00
0?l20?n000l0003o00<0oh000000o`000?l00`000?l00`3oP03oooooooooo`08ooooo`002Oooool0
101=CDd0A4A404A4A00`<30202LW9`040410@013@d<0@d=303Ph>080=SHf00@0<c<c020P800P8200
<30`0P0k>c/0100n?Sh0@D510451@@0m?Cd203hn?P04038b<P0/;2`0;2`/03Xj>P80B4Q800@0C4a<
04Q8B018B4P0B4Q80P11@D40100k>c/0B4Q804Q8B01>CTh2051@D00405EEE@16ATH0ATI60492@P80
7AdM00D0G5aL06ATI01VIVH0IVIV06MWI`0206][J`0406MWI`1`L700L71`06a/K080JVYZ00@0MWIf
06i^KP1^KVh0Jf][0P1_Kfl0100m?Cd0LW9b079bLP1gMgL207UiN@0307]kN`1cLg<0Lg=c00<0Lg=c
00@0LG5a06a/K01/K6`0MWIf0P1hN7P0101lO7`0NGUi07UiN@0j>SX207emO@0507MgM`1hN7P0N7Qh
075aL@1VIVH00P1hN7P0101nOWh0PH610861P@21PH4308^;R`80QhN700@0S8b<05IFEP1FEUH0SHf=
0P2:RXX0102@T900R8R808R8R027QhL2092@T004096AT@25QHD0QHF509FEU@80VIVI00@0XZ:R0;6a
/@2a/K40Bd];0P2IVIT0102XZ:P0V9RH09RHV02;Rh/209NGU`0409:BTP2HV9P0V9RH0:JVYP80[Jf]
00D0^;Rh0;2`/01>CTh0CTi>06e]K@0209fMW@0409bLW02NWYh0WYjN0::RXP80Zj^[00@0Z:RX0:VY
Z@2YZJT0Y:BT0P2PX:00102;Rh/0VYZJ09ZJVP2>SXh205UIF@0409nOW`2DU9@0U9BD09BDU080WYjN
00@0XJ6Q09JFUP2FUYH0TI6A0P29RHT0102;Rh/0VYZJ09ZJVP2TY:@20:j^[P040:>SX`1fMWH0MWIf
0;2`/0;ooooo<@3oP00A0000o`80oh004`000?l20?n001<0003o00<0oh000000o`000?l03`000?l2
0?n000`0003o1P3oP00C0000o`80oh0040000?l20?n000<0003o00<0oh00ooooooooool02?ooool0
00Wooooo00@0Jf][04A4A014A4@0Ph>30P2@T900102;Rh/0R8R808R8R01bLW8202`/;00406=SH`2:
RXX0RXZ:08^;R`80PH6100@0OWin06MWI`1WIfL0<30`0P1OGel01022PX80Ph>308>3P`23Ph<207Mg
M`0407AdM00f=SH0=SHf06UYJ@80KVi^00@0HV9R05MGE`1GEeL0GUiN0P1EEED0100X:2P0>SXj03Xj
>P14A4@204e=C@0506IVIP1RHV80>CTi03Ti>@0X:2P00P1NGUh0101gMgL0Kfm_06m_K`1VIVH206QX
J00406MWI`0[:b/0:b/[03hn?P80H61P00@0Hf=S05MGE`1GEeL0BDU90P1ADE40100g=cL0F5QH05QH
F01DE5@204Y:BP0403`l?010@400@41003Xj>P80:RXZ00@0G5aL05QHF01HF5P0F5QH0P18B4P01@0`
<300:BTY02TY:@0S8b<0:b/[0080;bl_00@0>3Ph03Hf=P0f=SH0:b/[0P0W9bL0100j>SX0ADE504E5
A@19BDT20492@P0403Xj>P0f=SH0=SHf03<c<`80@D5100@0?Cdm03Ph>00h>3P0=3@d0P0R8R80100I
6AT09RHV02HV9P0];Bd2034a<@0402XZ:P0];Bd0;Bd]03Xj>P80ADE500@0@D5104A4A014A4@0ADE5
0P11@D401@0m?Cd0>CTi03Ti>@12@T80EeMG0080Bd];0`1<C4`305=CD`0404e=C@19BDT0BDU904i>
CP80EeMG00<0FEUI05QHF01HF5P00`1BDU80101EEED0=SHf03Hf=P0Z:RX203/k>`040451@@15ADD0
ADE504E5A@80EEEE00@0EeMG04Q8B018B4P0AdM70`1<C4`205aLG00404i>CP0`<300<30`04E5A@;o
oooo00<0003o0?n0003oP0001`000?l20?n000T0003o00<0oh000000o`000?l01`000?l00`3oP000
003o0000o`030000o`X0oh000`000?l50?n000L0003o0`3oP0030000ogT0oh002_ooool000Wooooo
00@0WYjN03dm?@0m?Cd0_;bl0P38b<P01039bLT0b/[:0<[:bP2m_Kd202/[:`030861P@2d];@0];Bd
00<0]kNg00@0^;Rh09jNWP2NWYh0:2PX0P2<S8`40;Vi^@80[:b/00@0UiNG04e=C@1=CDd0TI6A0P2M
WId0102<S8`0RXZ:08Z:RP2>SXh20820P00404e=C@1FEUH0EUIF05EEE@80IFEU00D0Ph>308n?S`22
PX80PX:203<c<`0208f=S@040:j^[P2MWId0WIfM09NGU`80XJ6Q00@0W9bL04=3@`13@d<0MGEe0P2Y
ZJT0102a/K40/;2`0;2`/02c/k<20;Rh^00405EEE@2QXJ40XJ6Q08f=S@80I6AT00@0GEeM05IFEP1F
EUH0DE5A0P18B4P0102g]kL0^KVi0;Vi^@2h^;P20;Jf]P050;:b/P1YJFT0JFUY05]KF`2WYjL00P2f
][H0102g]kL0_;bl0;bl_02[Zj/20492@P0308V9R@2e]KD0]KFe00<0];Bd00@0^[Zj0:j^[P2^[Zh0
@d=30P2j^[X0102o_kl0a<C40<C4a035aLD208^;R`0408>3P`2j^[X0^[Zj0;:b/P80Z:RX00@0Y:BT
08b<S02<S8`0DU9B0P2QXJ40102ZZZX0YJFU0:FUY@2[Zj/20:ZZZP050:BTY01FEUH0EUIF0:n_[`2d
];@00P2l_;`0102i^KT0/k>c0;>c/`1<C4`206a/K0030:2PX02CTi<0Ti>C00<0T92@00@0UYJF05mO
G`1OGel0B4Q80P28R8P0102ATI40Xj>S0:>SX`2QXJ4208V9R@0403/k>`1^KVh0KVi^08f=S@80VIVI
00@0V9RH09VIV@2IVIT0Shn?0P0f=SH0101QHF40SXj>08j>SP2IVIT20::RXP0409bLW?oooooooooo
0000o`/0oh0000<0003o0?n0003oP000103oP0020000o`030?n000000?l0003o00@0oh000`000?l0
0`3oP000003o0000o`070000o`D0oh001P000?l0103oP000003o0000o`3oP0060000o`040?n00000
0?l0003o0000o`P0oh0010000?l>0?n000040000o`3oP000oh000000o`@0oh000P000?l00`3oP000
003o0000o`0?0?n000<0003o0`3oP0040000o`030?n000000?l0003o00L0003o2`3oP00:0000o`03
0?n000000?l0003o00H0003o00<0oh000000o`000?l01`000?l20?n000L0003o2_ooool000Wooooo
00@0WYjN03dm?@0m?Cd0_;bl0P38b<P01039bLT0b/[:0<[:bP2m_Kd202/[:`030861P@2d];@0];Bd
00<0]kNg00@0^;Rh09jNWP2NWYh0:2PX0P2<S8`40;Vi^@80[:b/00@0UiNG04e=C@1=CDd0TI6A0P2M
WId0102<S8`0RXZ:08Z:RP2>SXh20820P00404e=C@1FEUH0EUIF05EEE@80IFEU00D0Ph>308n?S`22
PX80PX:203<c<`0208f=S@040:j^[P2MWId0WIfM09NGU`80XJ6Q00@0W9bL04=3@`13@d<0MGEe0P2Y
ZJT0102a/K40/;2`0;2`/02c/k<20;Rh^00405EEE@2QXJ40XJ6Q08f=S@80I6AT00@0GEeM05IFEP1F
EUH0DE5A0P18B4P0102g]kL0^KVi0;Vi^@2h^;P20;Jf]P050;:b/P1YJFT0JFUY05]KF`2WYjL00P2f
][H0102g]kL0_;bl0;bl_02[Zj/20492@P0308V9R@2e]KD0]KFe00<0];Bd00@0^[Zj0:j^[P2^[Zh0
@d=30P2j^[X0102o_kl0a<C40<C4a035aLD208^;R`0408>3P`2j^[X0^[Zj0;:b/P80Z:RX00@0Y:BT
08b<S02<S8`0DU9B0P2QXJ40102ZZZX0YJFU0:FUY@2[Zj/20:ZZZP050:BTY01FEUH0EUIF0:n_[`2d
];@00P2l_;`0102i^KT0/k>c0;>c/`1<C4`206a/K0030:2PX02CTi<0Ti>C00<0T92@00@0UYJF05mO
G`1OGel0B4Q80P28R8P0102ATI40Xj>S0:>SX`2QXJ4208V9R@0403/k>`1^KVh0KVi^08f=S@80VIVI
00@0V9RH09VIV@2IVIT0Shn?0P0f=SH0101QHF40SXj>08j>SP2IVIT20::RXP0409bLW?oooooooooo
0000o`/0oh0000<0003o0?n0003oP000103oP0020000o`030?n000000?l0003o00@0oh000`000?l0
0`3oP000003o0000o`070000o`D0oh001P000?l0103oP000003o0000o`3oP0060000o`040?n00000
0?l0003o0000o`P0oh0010000?l>0?n000040000o`3oP000oh000000o`@0oh000P000?l00`3oP000
003o0000o`0?0?n000<0003o0`3oP0040000o`030?n000000?l0003o00L0003o2`3oP00:0000o`03
0?n000000?l0003o00H0003o00<0oh000000o`000?l01`000?l20?n000L0003o2_ooool000Wooooo
00@0[jn_04E5A@15ADD0_[jn0P35aLD01039bLT0b/[:0<[:bP2d];@202@T900408F5Q@2_[jl0[jn_
0:f][@80/[:b00@0];Bd0:NWY`2WYjL09RHV0P2BTY80102g]kL0/k>c0;>c/`2d];@20:FUY@0409>C
T`0j>SX0>SXj09>CT`80/k>c00<0/K6a0;>c/`2c/k<00`2YZJT0101EEED0?Cdm03dm?@0m?Cd204];
B`0506e]K@1kNg/0OWin07inOP12@T800P28R8P0102b/[80YJFU0:FUY@2GUiL20:>SX`040:2PX00k
>c/0>c/k08>3P`<0]kNg0P2j^[X30;no_`0406=SH`2VYZH0YZJV0:JVYP80T92@00@0L71`05mOG`1O
Gel0Bd];0P1FEUH0102e]KD0^;Rh0;Rh^02i^KT20;bl_0050;Rh^01XJ6P0J6QX07AdM02`/;000P2d
];@0102i^KT0`<300<30`02h^;P204];B`0409BDU02d];@0];Bd0:ZZZP80[Zj^00@0^;Rh0;bl_02l
_;`0J6QX0P2m_Kd01031`L40`/;20<;2`P38b<P20;>c/`0406m_K`2XZ:P0Z:RX0:RXZ080WIfM00@0
Xj>S0:NWY`2WYjL0H61P0P2WYjL0102[Zj/0YJFU0:FUY@2RXZ8209bLW00408f=S@1BDU80DU9B0;Ng
]`<0^k^k00@0]kNg0;Rh^02h^;P0KFe]0P1dM7@0102EUID0W9bL09bLW02@T90208N7Q`04092@T01I
FET0FEUI08F5Q@80[Zj^00@0][Jf0;Ng]`2g]kL0/k>c0P2^[Zh01011@D40WinO09nOW`2i^KT30;Rh
^080/k>c00@0[Jf]03hn?P0n?Sh0XJ6Q0P2XZ:P0102/[:`0/;2`0;2`/02`/;02ooooo``0oh0000<0
003o0?n0003oP000103oP0020000o`030?n000000?l0003o00@0oh000`000?l00`3oP000003o0000
o`040?n000<0003o1P3oP0050000o`040?n000000?l0003o0?n000H0003o00<0oh000000o`000?l0
1`3oP0090000o`/0oh000`000?l80?n00080003o00<0oh000000o`000?l0103oP0020000o`L0oh00
4`000?l90?n000X0003o0P3oP0000`000?l0oh000?n000070?n00080003o2@3oP0040000o`<0oh00
2_ooool000Wooooo00@0/[:b05EEE@1EEED0^;Rh0P31`L401030`<00a/K60<K6aP2XZ:P202d];@04
08n?S`2YZJT0ZJVY0:RXZ080Zj^[00@0Z:RX09>CT`2CTi<08B4Q0P2>SXh0102c/k<0/[:b0;:b/P2/
[:`209NGU`040820P00o?cl0?clo09RHV080];Bd00@0Zj^[0:b/[02/[:`0/;2`0P2^[Zh0101?Cdl0
=cLg03Lg=`0G5aL201TI6@0501hN7P11@D40ADE504E5A@0c<c<00P24Q8@0102OWil0Ogmo07moO`1j
NWX209>CT`0409ZJVP19BDT0BDU907moO`80ZJVY00@0[jn_0;2`/02`/;00^k^k0P2n_[h0101SHf<0
W9bL09bLW02[Zj/20:VYZ@0408>3P`1bLW80LW9b05mOG`80CTi>00@0/k>c0:j^[P2^[Zh0[:b/0P2b
/[801@2d];@0IFEU06EUI@1oOgl0[jn_0080];Bd00@0]KFe0;Ng]`2g]kL0ZZZZ0P0j>SX0102FUYH0
/K6a0;6a/@2/[:`20;:b/P040;Ng]`2e]KD0]KFe061PH080^[Zj0`2m_Kd01036a/H0[jn_0:n_[`1a
LG420:JVYP040:6QX@2WYjL0YjNW0:FUY@80UiNG00@0HV9R09VIV@2IVIT0YJFU0P2MWId0102EUID0
Q8B408B4Q026QXH204M7A`050;:b/P2e]KD0/k>c0;>c/`2^[Zh00P2`/;00101SHf<0I6AT06ATI02:
RXX208:2PP0407moO`1kNg/0Ng]k07EeM@80B4Q800@0R8R80;:b/P2b/[80][Jf0P2h^;P0102g]kL0
/;2`0;2`/00f=SH20:BTY0040;>c/`2h^;P0^;Rh0;Jf]P80/K6a00@0Z:RX03Lg=`0g=cL0V9RH0P2U
YJD0102][Jd0Zj^[0:^[Z`2WYjL2ooooo`T0oh0000<0003o0?n0003oP0002@000?l00`3oP000003o
0000o`030?n000@0003o00@0oh000000o`000?l0oh000`000?l?0?n000T0003o00@0oh000000o`00
0?l0003o1P3oP00;0000o`@0oh000P000?l30?n000<0003o1@3oP0020000o`040?n000000?l0003o
0?n00080003o103oP0020000o`L0oh004`000?l90?n000X0003o0P3oP0000`000?l0oh000?n00007
0?n00080003o1P3oP0000`000?l0oh000?n000030000o`040?n000000?l0003o0000o`[ooooo0009
ooooo`040;:b/P1EEED0EEEE0;Rh^080`L7100@0`<300<K6aP36a/H0Z:RX0P0];Bd0102?Shl0ZJVY
0:VYZ@2XZ:P20:^[Z`040:RXZ02CTi<0Ti>C024Q8@80SXj>00@0/k>c0;:b/P2b/[80[:b/0P2GUiL0
1020P800?clo03lo?`2HV9P20;Bd]0040:^[Z`2/[:`0[:b/0;2`/080[Zj^00@0Cdm?03Lg=`0g=cL0
5aLG0P0I6AT01@0N7Qh0@D5104E5A@15ADD0<c<c0080Q8B400@0WinO07moO`1oOgl0NWYj0P2CTi<0
102JVYX0BDU904U9B@1oOgl20:VYZ@040:n_[`2`/;00/;2`0;^k^`80_[jn00@0Hf=S09bLW02LW9`0
Zj^[0P2YZJT01023Ph<0LW9b079bLP1OGel204i>CP040;>c/`2^[Zh0[Zj^0:b/[080/[:b00D0];Bd
06EUI@1UIFD0Ogmo0:n_[`020;Bd]0040;Fe]@2g]kL0]kNg0:ZZZP80>SXj00@0UYJF0;6a/@2a/K40
[:b/0P2b/[80102g]kL0]KFe0;Fe]@1PH6020;Zj^P<0_Kfm00@0a/K60:n_[`2_[jl0LG5a0P2VYZH0
102QXJ40YjNW0:NWY`2UYJD209NGU`04069RHP2IVIT0VIVI0:FUY@80WIfM00@0UIFE08B4Q024Q8@0
QXJ60P17AdL01@2b/[80]KFe0;>c/`2c/k<0[Zj^0080/;2`00@0Hf=S06ATI01TI6@0RXZ:0P22PX80
101oOgl0Ng]k07]kN`1eMGD204Q8B00408R8R02b/[80/[:b0;Jf]P80^;Rh00@0]kNg0;2`/02`/;00
=SHf0P2TY:@0102c/k<0^;Rh0;Rh^02f][H20;6a/@040:RXZ00g=cL0=cLg09RHV080YJFU00@0[Jf]
0:^[Z`2[Zj/0YjNW0_ooool90?n000030000o`3oP000oh0000T0003o00<0oh000000o`000?l00`3o
P0040000o`040?n000000?l0003o0?n000<0003o3`3oP0090000o`040?n000000?l0003o0000o`H0
oh002`000?l40?n00080003o0`3oP0030000o`D0oh000P000?l0103oP000003o0000o`3oP0020000
o`@0oh000P000?l70?n001<0003o2@3oP00:0000o`80oh0000<0003o0?n0003oP0001`3oP0020000
o`H0oh0000<0003o0?n0003oP0000`000?l0103oP000003o0000o`000?l:ooooo`002Oooool01024
Q8@0<c<c03<c<`1lO7`208F5Q@0407inOP22PX80PX:207IfMP80?Cdm00@0G5aL07moO`1oOgl0NWYj
0P1fMWH01027QhL0Ng]k07]kN`0Z:RX205mOG`0406e]K@1aLG40LG5a05]KF`80De=C00@0GemO04E5
A@15ADD0HV9R0P1hN7P308:2PP0408J6QP2=SHd0SHf=04I6AP80?Shn00D0;2`/03/k>`0k>c/0?3`l
0451@@0205ADE0040410@01SHf<0Hf=S06ATI080Bd];00@0EEEE061PH01PH600JFUY0P17AdL0101Q
HF40O7al07alO01bLW82071`L0040820P027QhL0QhN704Q8B080VYZJ00@0UiNG07AdM01dM7@0I6AT
0P13@d<0101QHF40AdM704M7A`2CTi<208^;R`0407inOP1kNg/0Ng]k08R8R080EUIF00D0JFUY0820
P023Ph<0Ph>309>CT`020:2PX00408:2PP0g=cL0=cLg08R8R080U9BD00@0WinO0:2PX02PX:00Zj^[
0P2TY:@0101JFUX0UiNG09NGU`2IVIT20;Fe]@040;Jf]P2PX:00X:2P06a/K080Z:RX00@0YjNW0:BT
Y02TY:@0YjNW0P2LW9`0101JFUX0UYJF09JFUP2OWil209RHV00409>CT`25QHD0QHF507moO`80Cdm?
00D0ZZZZ0:n_[`2ZZZX0ZZZZ0:BTY0020:NWY`0405ADE01>CTh0CTi>08V9R@80R8R800@0O7al07Ui
N@1iNGT0KFe]0P1>CTh0102BTY80^;Rh0;Rh^034a<@20;bl_0040;Vi^@2c/k<0/k>c02/[:`80X:2P
00@0][Jf0;^k^`2k^k/0^[Zj0P2i^KT0102a/K40>CTi03Ti>@2TY:@20:JVYP040:RXZ02`/;00/;2`
0:j^[P;ooooo00<0003o0?n0003oP0001`000?l30?n000P0003o00<0oh000000o`000?l00`000?l3
0?n000030000o`3oP000003o00P0003o303oP0030000o`<0oh000`000?l00`3oP000003o0000o`07
0000o`80oh001P000?l0103oP000003o0000o`3oP0080000o`030?n000000?l0003o00L0003o00<0
oh000000o`000?l01`000?l20?n000<0003o0`3oP00:0000o`030?n000000?l0003o00L0003o0P3o
P0000`000?l0oh000?n000040000o`<0oh001`000?l20?n000030000o`3oP000oh0000L0oh000P00
0?l90?n000@0003o0`3oP00:ooooo`002Oooool01028R8P0Ng]k07]kN`1hN7P2079bLP040451@@1K
Fe/0Fe]K071`L080NGUi00@0OWin06m_K`1_Kfl0KFe]0P1`L700101iNGT0JVYZ06YZJP1XJ6P205QH
F00405EEE@1HF5P0F5QH03hn?P80AdM700@0J6QX06m_K`1_Kfl0J6QX0P1NGUh0101LG5`0Bd];04];
B`1EEED205]KF`0405YJFP1IFET0FEUI05iNGP80D51@00D0?3`l04U9B@1SHf<0Hf=S06YZJP0206][
J`04069RHP1LG5`0G5aL05aLG0<0GemO0P1RHV80101OGel0F5QH05QHF01NGUh204I6AP0403Xj>P1A
DE40DE5A05MGE`80EEEE0`1LG5`0101KFe/0GEeM05eMG@1RHV82061PH00405mOG`1YJFT0JFUY069R
HP80CTi>00D0EEEE05]KF`1KFe/0Fe]K05IFEP0204e=C@0404I6AP1<C4`0C4a<04I6AP80DU9B0`1R
HV80101VIVH0HF5Q065QH@1=CDd204Y:BP040492@P0k>c/0>c/k04A4A080C4a<00@0B4Q803hn?P0n
?Sh0Bd];0P1FEUH0101:BTX0Cdm?04m?C`1ADE4205]KF`0405=CD`1VIVH0IVIV06ATI080HF5Q00@0
FUYJ06ATI01TI6@0Fe]K0P1CDe<01@1lO7`0Lg=c06e]K@1]KFd0JVYZ0080IVIV00@0C4a<0410@010
@400GemO0P1VIVH0101LG5`0GEeM05eMG@1IFET204a<C00406YZJP1hN7P0N7Qh08F5Q@80Ph>300@0
MWIf07QhN01hN7P0@D510P1_Kfl0101kNg/0PH610861P@1eMGD207MgM`04075aL@0o?cl0?clo07Qh
N080O7al00@0NGUi08>3P`23Ph<0OWin0_ooool60000o`<0oh003@000?l80?n000@0003o403oP006
0000o`<0oh001P000?l@0?n000P0003o3P3oP0060000oaH0oh001@000?l00`3oP000003o0000o`03
0?n000L0003o0`3oP0030000o`H0oh002@000?l00`3oP000003o0000o`070000o`80oh001`000?l:
ooooo`002Oooool01028R8P0Ng]k07]kN`1hN7P2079bLP040451@@1KFe/0Fe]K071`L080NGUi00@0
OWin06m_K`1_Kfl0KFe]0P1`L700101iNGT0JVYZ06YZJP1XJ6P205QHF00405EEE@1HF5P0F5QH03hn
?P80AdM700@0J6QX06m_K`1_Kfl0J6QX0P1NGUh0101LG5`0Bd];04];B`1EEED205]KF`0405YJFP1I
FET0FEUI05iNGP80D51@00D0?3`l04U9B@1SHf<0Hf=S06YZJP0206][J`04069RHP1LG5`0G5aL05aL
G0<0GemO0P1RHV80101OGel0F5QH05QHF01NGUh204I6AP0403Xj>P1ADE40DE5A05MGE`80EEEE0`1L
G5`0101KFe/0GEeM05eMG@1RHV82061PH00405mOG`1YJFT0JFUY069RHP80CTi>00D0EEEE05]KF`1K
Fe/0Fe]K05IFEP0204e=C@0404I6AP1<C4`0C4a<04I6AP80DU9B0`1RHV80101VIVH0HF5Q065QH@1=
CDd204Y:BP040492@P0k>c/0>c/k04A4A080C4a<00@0B4Q803hn?P0n?Sh0Bd];0P1FEUH0101:BTX0
Cdm?04m?C`1ADE4205]KF`0405=CD`1VIVH0IVIV06ATI080HF5Q00@0FUYJ06ATI01TI6@0Fe]K0P1C
De<01@1lO7`0Lg=c06e]K@1]KFd0JVYZ0080IVIV00@0C4a<0410@010@400GemO0P1VIVH0101LG5`0
GEeM05eMG@1IFET204a<C00406YZJP1hN7P0N7Qh08F5Q@80Ph>300@0MWIf07QhN01hN7P0@D510P1_
Kfl0101kNg/0PH610861P@1eMGD207MgM`04075aL@0o?cl0?clo07QhN080O7al00@0NGUi08>3P`23
Ph<0OWin0_ooool60000o`<0oh003@000?l80?n000@0003o403oP0060000o`<0oh001P000?l@0?n0
00P0003o3P3oP0060000oaH0oh001@000?l00`3oP000003o0000o`030?n000L0003o0`3oP0030000
o`H0oh002@000?l00`3oP000003o0000o`070000o`80oh001`000?l:ooooo`002Oooool0102d];@0
/;2`0;2`/02WYjL209nOW`030492@P2DU9@0U9BD00<0Zj^[00@0[:b/0:FUY@2UYJD0/[:b0P2d];@0
102e]KD0/;2`0;2`/02ZZZX20:BTY00409FEU@2MWId0WIfM06YZJP80OWin00@0];Bd0:^[Z`2[Zj/0
YZJV0P2PX:030:f][@<0[:b/00@0Z:RX0:ZZZP2ZZZX0[Zj^0P2`/;000`1cLg<0Rh^;0;6a/@040;6a
/@030:^[Z`2^[Zh0[Zj^00<0YZJV00@0ZJVY0:JVYP2VYZH0[:b/0P2YZJT0102[Zj/0N7Qh07QhN01`
L7020;Vi^@040;fm_@2l_;`0_;bl0;Fe]@80^;Rh00@0]kNg0;Fe]@2e]KD0/K6a0P2d];@0102c/k<0
^KVi0;Vi^@2e]KD206UYJ@050:j^[P2f][H0][Jf0;Jf]P2g]kL00P2c/k<0102VYZH0ZZZZ0:ZZZP2`
/;020;jn_P040;Vi^@2f][H0][Jf0<;2`P80a<C40`1BDU800`2XZ:P0ZJVY0:VYZ@030;Bd]0040;6a
/@2ZZZX0ZZZZ0:FUY@80WYjN00@0Rh^;07]kN`1kNg/0@D510P2UYJD0102_[jl0XJ6Q0:6QX@22PX82
09>CT`0408b<S02FUYH0UYJF09^KV`80WYjN00D0WinO09VIV@29RHT0RHV9069RHP0205IFEP0409FE
U@2JVYX0VYZJ08j>SP80VYZJ00@0XZ:R0:2PX02PX:00PH610P2HV9P0102QXJ40UiNG09NGU`2FUYH2
09FEU@04059BDP20P800P82009bLW080T92@00@0Q8B406m_K`1_Kfl0DE5A0P1EEED0101^KVh0RHV9
08V9R@1ZJVX206=SH`04065QH@1?Cdl0Cdm?04m?C`;ooooo0`3oP0030000o`030?n000000?l0003o
00H0003o1P3oP0090000o`030?n000000?l0003o0080003o0`3oP0060000o`<0oh000`000?l50?n0
00030000o`3oP000oh0000d0003o4P3oP0000`000?l0oh000?n000050?n000<0003o303oP0030000
o`D0oh001`000?l0103oP000003o0000o`3oP00A0000o`030?n000000?l0003o0100003o00<0oh00
0000o`000?l01P000?l30?n000L0003o0`3oP00:ooooo`002Oooool0102d];@0[Zj^0:j^[P2[Zj/2
0:NWY`0403Ph>02GUiL0UiNG0:NWY`80YJFU00@0XZ:R09^KV`2KVi/0YZJV0P2/[:`0102XZ:P0YJFU
0:FUY@2UYJD20:>SX`040::RXP2LW9`0W9bL06QXJ080PH6100@0[jn_0;6a/@2a/K40YjNW0P29RHT0
102UYJD0XZ:R0::RXP2TY:@20:NWY`0409bLW02QXJ40XJ6Q0:f][@80/[:b00D0OGem08j>SP2f][H0
][Jf0;Bd]0020;:b/P040;Jf]P2`/;00/;2`0:NWY`80YZJV0`2WYjL0102[Zj/0YjNW0:NWY`2QXJ42
08b<S004096AT@2b/[80/[:b0;6a/@80/;2`00@0[Zj^0;>c/`2c/k<0]KFe0P2d];@0102b/[80/K6a
0;6a/@2f][H20;Ng]`040;Jf]P1GEeL0EeMG0:JVYP80];Bd00D0/;2`0;6a/@2`/;00/;2`0:6QX@02
0::RXP030:NWY`2o_kl0_kno00<0`<3000@0_Kfm0:j^[P2^[Zh0A4A40P1jNWX0102YZJT0[jn_0:n_
[`2f][H20;Rh^0040:f][@2XZ:P0Z:RX0:JVYP<0Xj>S0P21PH401015ADD0^;Rh0;Rh^02h^;P20;bl
_0<0^KVi00@0]kNg0;Jf]P2f][H0Zj^[0P2DU9@01@2YZJT0/k>c0;Fe]@2e]KD0TI6A0080MGEe00@0
/K6a0;:b/P2b/[80[Jf]0P2d];@0102k^k/0_[jn0;jn_P2j^[X20;bl_0040;^k^`2g]kL0]kNg0:b/
[080];Bd00@0Kfm_0:RXZ02XZ:P0/[:b0P2YZJT0102LW9`0WinO09nOW`2e]KD20;Rh^0040;>c/`2d
];@0];Bd0:f][@80/K6a00@0^;Rh07YjNP1jNWX0KFe]0_ooool30?n000<0003o00<0oh000000o`00
0?l05@000?l20?n000`0003o0`3oP0030000o`P0oh003@000?lC0?n00080003o1@3oP0050000o`T0
oh000`000?l60?n000L0003o303oP0040000o`<0oh000`000?l?0?n000030000o`3oP000oh0000<0
003o00<0oh000000o`000?l00`000?l:0?n000<0003o2_ooool000Wooooo00@0];Bd0:j^[P2^[Zh0
Zj^[0P2WYjL0100h>3P0UiNG09NGU`2WYjL20:FUY@040::RXP2KVi/0Vi^K0:JVYP80[:b/00@0Z:RX
0:FUY@2UYJD0YJFU0P2SXj<0102RXZ80W9bL09bLW01XJ6P20861P@040:n_[`2a/K40/K6a0:NWY`80
RHV900@0YJFU0::RXP2RXZ80Y:BT0P2WYjL0102LW9`0XJ6Q0:6QX@2][Jd20;:b/P0507emO@2>SXh0
][Jf0;Jf]P2d];@00P2b/[80102f][H0/;2`0;2`/02WYjL20:JVYP<0YjNW00@0Zj^[0:NWY`2WYjL0
XJ6Q0P2<S8`0102ATI40/[:b0;:b/P2a/K420;2`/0040:j^[P2c/k<0/k>c0;Fe]@80];Bd00@0/[:b
0;6a/@2a/K40][Jf0P2g]kL0102f][H0EeMG05MGE`2VYZH20;Bd]0050;2`/02a/K40/;2`0;2`/02Q
XJ400P2RXZ800`2WYjL0_kno0;no_`030<30`0040;fm_@2^[Zh0[Zj^04A4A080NWYj00@0ZJVY0:n_
[`2_[jl0][Jf0P2h^;P0102][Jd0Z:RX0:RXZ02VYZH30:>SX`80PH6100@0ADE50;Rh^02h^;P0^;Rh
0P2l_;`30;Vi^@040;Ng]`2f][H0][Jf0:^[Z`80U9BD00D0ZJVY0;>c/`2e]KD0]KFe096AT@0207Ee
M@040;6a/@2b/[80/[:b0:f][@80];Bd00@0^k^k0;jn_P2n_[h0^[Zj0P2l_;`0102k^k/0]kNg0;Ng
]`2/[:`20;Bd]00406m_K`2XZ:P0Z:RX0;:b/P80ZJVY00@0W9bL09nOW`2OWil0]KFe0P2h^;P0102c
/k<0];Bd0;Bd]02][Jd20;6a/@040;Rh^01jNWX0NWYj06e]K@;ooooo0`3oP0030000o`030?n00000
0?l0003o01D0003o0P3oP00<0000o`<0oh000`000?l80?n000d0003o4`3oP0020000o`D0oh001@00
0?l90?n000<0003o1P3oP0070000o``0oh0010000?l30?n000<0003o3`3oP0000`000?l0oh000?n0
00030000o`030?n000000?l0003o00<0003o2P3oP0030000o`[ooooo0009ooooo`040:RXZ02SXj<0
Xj>S0:JVYP80WinO00<0=cLg09ZJVP2JVYX00`2SXj<0102RXZ80WYjN09jNWP2OWil20:FUY@040:RX
Z02YZJT0ZJVY0:>SX`80WIfM00@0Xj>S0:2PX02PX:00KVi^0P26QXH0102`/;00^;Rh0;Rh^02c/k<2
09NGU`040:JVYP2MWId0WIfM0:2PX080ZJVY00<0Xj>S0:FUY@2UYJD00`2d];@01@2<S8`0Q8B40;Vi
^@2i^KT0][Jf0080];Bd00@0/k>c0:n_[`2_[jl0YZJV0P2UYJD40:ZZZP80Z:RX00@0[Jf]07IfMP1f
MWH0Kfm_0P2ZZZX0102^[Zh0/K6a0;6a/@2][Jd20;2`/0040:f][@2`/;00/;2`0:n_[`80/K6a00@0
/;2`0;Fe]@2e]KD0]kNg0P1QHF401@2TY:@0Zj^[0:^[Z`2^[Zh0ZZZZ0080[Jf]0`2UYJD0102VYZH0
];Bd0;Bd]02k^k/20;no_`040;jn_P2PX:00X:2P03Ti>@80Ogmo00@0ZZZZ0:f][@2][Jd0[:b/0P2^
[Zh0102ZZZX0XZ:R0::RXP2UYJD20:>SX`0409BDU024Q8@0Q8B404U9B@80]kNg00@0^k^k0<?3``33
`l<0_[jn0P32`/80102m_Kd0^[Zj0;Zj^P2UYJD209>CT`050:n_[`2l_;`0^k^k0;^k^`2CTi<00P20
P800102b/[80];Bd0;Bd]02e]KD50;Vi^@040;Bd]02l_;`0_;bl0;^k^`80^;Rh00@0/;2`0;:b/P2b
/[80IfMW0P2VYZH0102c/k<0ZZZZ0:ZZZP2@T90209BDU0040;Jf]P2j^[X0^[Zj0;Vi^@80]kNg00@0
]KFe0;Vi^@2i^KT0^k^k0P1lO7`00`1fMWKoooooooooo`060000o`030?n000000?l0003o01D0003o
103oP00:0000o`<0oh000`000?l80?n000P0003o0P3oP0040000oa40oh0010000?l20?n000030000
o`3oP000003o00@0003o1P3oP0000`000?l0oh000?n000030000o`040?n000000?l0003o0?n000T0
003o303oP0030000o`@0oh000`000?lB0?n000<0003o00<0oh000000o`000?l00`000?l:0?n000<0
003o2_ooool000Wooooo00@0/K6a0;>c/`2c/k<0/;2`0P2b/[80101GEeL0XZ:R0::RXP2RXZ820:>S
X`040::RXP2BTY80TY:B09ZJVP80VIVI00@0Z:RX0:b/[02/[:`0YjNW0P2QXJ40102SXj<0X:2P0:2P
X01RHV820820P0040:VYZ@2_[jl0[jn_0;2`/080Vi^K00@0[Jf]0:6QX@2QXJ40YZJV0P2YZJT0102R
XZ80W9bL09bLW02RXZ820:n_[`0507moO`1nOWh0[jn_0:n_[`2a/K400P2f][H0102d];@0/k>c0;>c
/`2/[:`20:FUY@040:f][@2[Zj/0Zj^[0:b/[080Z:RX00@0WinO05UIF@1IFET0Fe]K0P2RXZ830:ZZ
ZP040:RXZ02WYjL0YjNW0:RXZ080YJFU00@0ZJVY0:ZZZP2ZZZX0[Zj^0P2c/k<00`2f][H0KVi^06i^
KP030:>SX`050:JVYP2WYjL0Z:RX0:RXZ02YZJT00P2][Jd0102ZZZX0];Bd0;Bd]02i^KT20;Zj^P04
0;^k^`2_[jl0[jn_04e=C@80MWIf00@0Z:RX0:NWY`2WYjL0[Jf]0P2[Zj/0102][Jd0ZJVY0:VYZ@2U
YJD208n?S`0408R8R023Ph<0Ph>305eMG@80/K6a00@0][Jf0;Rh^02h^;P0][Jf0P2l_;`00`2g]kL0
_;bl0;bl_0030:RXZ0050;Rh^031`L40_Kfm0;fm_@2GUiL00P23Ph<0102b/[80/k>c0;>c/`2h^;P2
0;Vi^@040;Zj^P2i^KT0^KVi0;>c/`80]KFe00@0^KVi0;>c/`2c/k<0[Jf]0P2`/;00101MGEd0Xj>S
0:>SX`2c/k<20:VYZ@0408:2PP1eMGD0MGEe0:>SX`80[jn_00<0/[:b0:f][@2][Jd00`2d];@0102g
]kL0RXZ:08Z:RP20P802ooooo`L0oh0060000?l30?n000030000o`3oP000oh0000T0003o00@0oh00
0000o`000?l0003o203oP0030000o`030?n000000?l0003o00@0003o0`3oP00=0000o`D0oh002P00
0?l00`3oP000003o0000o`090?n000@0003o0P3oP0000`000?l0oh000?n000070000o``0oh000`00
0?l40?n000<0003o4`3oP0020000o`030?n000000?l0003o00@0003o2@3oP0030000o`[ooooo0009
ooooo`040;6a/@2c/k<0/k>c0;2`/080/[:b00@0EeMG0::RXP2RXZ80XZ:R0P2SXj<0102RXZ80TY:B
09:BTP2JVYX209VIV@040:RXZ02/[:`0[:b/0:NWY`80XJ6Q00@0Xj>S0:2PX02PX:00HV9R0P20P800
102YZJT0[jn_0:n_[`2`/;0209^KV`040:f][@2QXJ40XJ6Q0:JVYP80ZJVY00@0XZ:R09bLW02LW9`0
XZ:R0P2_[jl01@1oOgl0OWin0:n_[`2_[jl0/K6a0080][Jf00@0];Bd0;>c/`2c/k<0[:b/0P2UYJD0
102][Jd0Zj^[0:^[Z`2/[:`20:RXZ00409nOW`1IFET0FEUI05]KF`80XZ:R0`2ZZZX0102XZ:P0YjNW
0:NWY`2XZ:P20:FUY@040:VYZ@2ZZZX0ZZZZ0:j^[P80/k>c00<0][Jf06i^KP1^KVh00`2SXj<01@2V
YZH0YjNW0:RXZ02XZ:P0ZJVY0080[Jf]00@0ZZZZ0;Bd]02d];@0^KVi0P2j^[X0102k^k/0[jn_0:n_
[`1=CDd207IfMP040:RXZ02WYjL0YjNW0:f][@80Zj^[00@0[Jf]0:VYZ@2YZJT0YJFU0P2?Shl01028
R8P0Ph>308>3P`1MGEd20;6a/@040;Jf]P2h^;P0^;Rh0;Jf]P80_;bl00<0]kNg0;bl_02l_;`00`2X
Z:P01@2h^;P0`L710;fm_@2m_Kd0UiNG0080Ph>300@0/[:b0;>c/`2c/k<0^;Rh0P2i^KT0102j^[X0
^KVi0;Vi^@2c/k<20;Fe]@040;Vi^@2c/k<0/k>c0:f][@80/;2`00@0GEeM0:>SX`2SXj<0/k>c0P2Y
ZJT01022PX80MGEe07EeM@2SXj<20:n_[`030;:b/P2][Jd0[Jf]00<0];Bd00@0]kNg08Z:RP2:RXX0
P8200_ooool70?n001P0003o0`3oP0000`000?l0oh000?n000090000o`040?n000000?l0003o0000
o`P0oh000`000?l00`3oP000003o0000o`040000o`<0oh003@000?l50?n000X0003o00<0oh000000
o`000?l02@3oP0040000o`80oh0000<0003o0?n0003oP0001`000?l<0?n000<0003o103oP0030000
oa<0oh000P000?l00`3oP000003o0000o`040000o`T0oh000`000?l:ooooo`002Oooool00`1UIFD0
EeMG05MGE`0304Q8B004034a<@10@400@41004];B`80DE5A00@0DU9B04Y:BP1:BTX0?Shn0P0Y:BT0
101;Bd/0Hf=S06=SH`1KFe/204e=C@0404M7A`0o?cl0?clo03hn?P80Bd];00@0EEEE06YZJP1ZJVX0
H61P0P1DE5@01014A4@0>3Ph03Ph>00h>3P203Ti>@04034a<@0h>3P0>3Ph04E5A@80@41000D0>c/k
04Y:BP1IFET0FEUI05YJFP0206EUI@0406MWI`1GEeL0EeMG0492@P80?3`l00@0De=C055AD@1ADE40
CDe=0P11@D40100o?cl0=SHf03Hf=P0[:b/205ADE004055AD@1BDU80DU9B03hn?P80@d=300@0>CTi
03De=@0e=CD0BDU90P11@D40101BDU80CDe=04e=C@1=CDd203Lg=`05069RHP1WIfL0IfMW065QH@1S
Hf<00`1]KFd2075aL@0406YZJP1`L700L71`06IVIP80Jf][00@0J6QX05=CD`1CDe<0;2`/0P18B4P0
101VIVH0HF5Q065QH@1KFe/206IVIP0405eMG@1HF5P0F5QH04a<C080GEeM00@0IFEU065QH@1QHF40
>CTi0P1PH600101[Jf/0Lg=c07=cL`1aLG4207]kN`0407EeM@1lO7`0O7al06m_K`80MgMg00D0P820
08F5Q@23Ph<0Ph>306UYJ@0205EEE@0407YjNP1lO7`0O7al08>3P`80P82000@0PH6107emO@1mOGd0
PH610P1jNWX01022PX80OWin07inOP1hN7P207UiN@0404Y:BP1kNg/0Ng]k07UiN@80HV9R00@0De=C
05ADE01DE5@0HF5Q0P1aLG4307YjNP0408:2PP2=SHd0SHf=08R8R080IFEU00@0HV9Rooooooooool0
003o4P3oP0020000o`X0oh000`000?lC0?n000<0003o8P3oP00B0000o`@0oh000`000?l20?n00003
0000o`3oP000oh0000@0oh000`000?l00`3oP000003o0000o`0B0000o`030?n000000?l0003o0100
003o00<0oh000000o`000?l00`000?l30?n000d0003o2_ooool000Wooooo00@0/K6a08Z:RP2:RXX0
NGUi0P2JVYX0102RXZ80ZJVY0:VYZ@2/[:`209jNWP0409:BTP2=SHd0SHf=0861P@809RHV00@0YZJV
0:NWY`2WYjL0XJ6Q0P2PX:00102KVi/0VYZJ09ZJVP2JVYX209NGU`<0WYjN00@0Rh^;08n?S`2?Shl0
TY:B0P1DE5@0102ATI40W9bL09bLW02QXJ420:j^[P030;6a/@2c/k<0/k>c0080];Bd0P2f][H30:n_
[`040:VYZ@29RHT0RHV905UIF@80YZJV00@0XJ6Q0:NWY`2WYjL0Z:RX0P2QXJ40102SXj<0WinO09nO
W`2EUID209ZJVP040::RXP2XZ:P0Z:RX0:ZZZP80Hf=S00@0>SXj08j>SP2>SXh0V9RH0P2NWYh0102V
YZH0ZJVY0:VYZ@2YZJT20:2PX005092@T02DU9@0U9BD0:>SX`2][Jd00P2WYjL0101hN7P0IVIV06IV
IP2MWId20:JVYP040:BTY02_[jl0[jn_0;6a/@80[jn_00@0[Zj^0:JVYP2VYZH0VYZJ0P2/[:`0102f
][H0/[:b0;:b/P1XJ6P2071`L00409^KV`2MWId0WIfM09NGU`80UYJF00@0WIfM09jNWP2NWYh0WIfM
0P2IVIT309RHV00409^KV`25QHD0QHF504=3@`80Jf][00D0N7Qh07YjNP1dM7@0M7Ad07=cL`0207If
MP0407AdM01WIfL0IfMW05QHF080G5aL00@0DU9B03Lg=`0g=cL0HV9R0P1ZJVX306UYJ@0406IVIP1/
K6`0K6a/06m_K`80EeMG00@0GUiN06a/K01/K6`0Jf][0P1cLg<0101OGel0BTY:04Y:BP1/K6`206][
J`0406UYJ@1WIfL0IfMW06UYJ@80J6QX00@0I6ATooooooooool0oh003`000?l20?n001<0003o00<0
oh000000o`000?l00`000?l<0?n000<0003o00<0oh000000o`000?l04@000?l20?n000l0003o00<0
oh000000o`000?l01`000?l60?n000@0003o0`3oP00E0000o`030?n000000?l0003o00X0003o1P3o
P00:0000o`<0oh001P000?l20?n000X0003o2_ooool000Wooooo00@0/K6a08Z:RP2:RXX0NGUi0P2J
VYX0102RXZ80ZJVY0:VYZ@2/[:`209jNWP0409:BTP2=SHd0SHf=0861P@809RHV00@0YZJV0:NWY`2W
YjL0XJ6Q0P2PX:00102KVi/0VYZJ09ZJVP2JVYX209NGU`<0WYjN00@0Rh^;08n?S`2?Shl0TY:B0P1D
E5@0102ATI40W9bL09bLW02QXJ420:j^[P030;6a/@2c/k<0/k>c0080];Bd0P2f][H30:n_[`040:VY
Z@29RHT0RHV905UIF@80YZJV00@0XJ6Q0:NWY`2WYjL0Z:RX0P2QXJ40102SXj<0WinO09nOW`2EUID2
09ZJVP040::RXP2XZ:P0Z:RX0:ZZZP80Hf=S00@0>SXj08j>SP2>SXh0V9RH0P2NWYh0102VYZH0ZJVY
0:VYZ@2YZJT20:2PX005092@T02DU9@0U9BD0:>SX`2][Jd00P2WYjL0101hN7P0IVIV06IVIP2MWId2
0:JVYP040:BTY02_[jl0[jn_0;6a/@80[jn_00@0[Zj^0:JVYP2VYZH0VYZJ0P2/[:`0102f][H0/[:b
0;:b/P1XJ6P2071`L00409^KV`2MWId0WIfM09NGU`80UYJF00@0WIfM09jNWP2NWYh0WIfM0P2IVIT3
09RHV00409^KV`25QHD0QHF504=3@`80Jf][00D0N7Qh07YjNP1dM7@0M7Ad07=cL`0207IfMP0407Ad
M01WIfL0IfMW05QHF080G5aL00@0DU9B03Lg=`0g=cL0HV9R0P1ZJVX306UYJ@0406IVIP1/K6`0K6a/
06m_K`80EeMG00@0GUiN06a/K01/K6`0Jf][0P1cLg<0101OGel0BTY:04Y:BP1/K6`206][J`0406UY
J@1WIfL0IfMW06UYJ@80J6QX00@0I6ATooooooooool0oh003`000?l20?n001<0003o00<0oh000000
o`000?l00`000?l<0?n000<0003o00<0oh000000o`000?l04@000?l20?n000l0003o00<0oh000000
o`000?l01`000?l60?n000@0003o0`3oP00E0000o`030?n000000?l0003o00X0003o1P3oP00:0000
o`<0oh001P000?l20?n000X0003o2_ooool000Wooooo00@0];Bd0::RXP2RXZ80T92@0P2CTi<0102T
Y:@0Z:RX0:RXZ02a/K4209FEU@0408^;R`2RXZ80XZ:R09bLW080;2`/00@0Vi^K0::RXP2RXZ80Ti>C
0P2=SHd0102<S8`0QXJ608J6QP20P80208^;R`0408V9R@25QHD0QHF506UYJ@80T92@00@0UiNG03hn
?P0n?Sh0Q8B40P2<S8`0102=SHd0WYjN09jNWP2PX:0209fMW@050:JVYP2WYjL0Z:RX0:RXZ02WYjL0
0P2SXj<0102PX:00Ti>C09>CT`1]KFd20::RXP<0X:2P00@0Xj>S0:6QX@2QXJ40X:2P0P2KVi/0102;
Rh/0V9RH09RHV02OWil20:BTY0040:ZZZP1dM7@0M7Ad055AD@80YJFU00@0XJ6Q0:FUY@2UYJD0ZJVY
0P2ZZZX0102VYZH0Xj>S0:>SX`2HV9P20:2PX0050:FUY@2^[Zh0/;2`0;2`/01_Kfl00P1iNGT0102X
Z:P0ZJVY0:VYZ@2[Zj/20;Fe]@030;:b/P2_[jl0[jn_00<0^KVi00@0][Jf0;Bd]02d];@0][Jf0P2h
^;P00`1_Kfl0Ng]k07]kN`030;Ng]`030;6a/@2/[:`0[:b/00<0^KVi00@0/k>c0:j^[P2^[Zh0]kNg
0P2l_;`01030`<00/[:b0;:b/P0m?Cd207emO@050:NWY`2c/k<0[jn_0:n_[`2TY:@00P2LW9`0102J
VYX0S8b<08b<S02QXJ420;2`/0040;^k^`1XJ6P0J6QX09FEU@80^KVi00@0/K6a0;:b/P2b/[80/;2`
0P2c/k<0102UYJD0PH610861P@2RXZ820:f][@040:ZZZP2`/;00/;2`08F5Q@80PX:200@0^KVi0<30
`030`<00_[jn0P31`L40102h^;P0^KVi0;Vi^@2h^;P2ooooo`030?n000000?l0003o00H0003o00<0
oh000000o`000?l010000?l20?n001<0003o00<0oh000000o`000?l09P000?l20?n000l0003o0P3o
P0080000o`d0oh000`000?l50?n000030000o`3oP000oh0000/0oh000`000?l30?n000P0003o0`3o
P0020000o`P0oh0010000?l20?n000030000o`3oP000oh0000<0003o2P3oP00:ooooo`002Oooool0
102[Zj/0YJFU0:FUY@2DU9@208f=S@040:2PX02VYZH0YZJV0:NWY`80SXj>00@0RHV909nOW`2OWil0
Ti>C0P0/;2`0102NWYh0WinO09nOW`2HV9P208R8R00408B4Q01iNGT0NGUi08B4Q080RXZ:00@0QXJ6
08n?S`2?Shl0OWin0P2CTi<0102ATI40=cLg03Lg=`22PX8209:BTP0408J6QP2ATI40TI6A09nOW`80
X:2P00D0XJ6Q0:JVYP2YZJT0ZJVY0:BTY0030:2PX080Ogmo00@0Jf][096AT@2ATI40WIfM0P2GUiL0
102LW9`0WinO09nOW`2KVi/209bLW00409BDU02FUYH0UYJF0:2PX080Xj>S00@0YJFU075aL@1aLG40
EUIF0P2TY:@00`2VYZH0Y:BT0:BTY0030:FUY@040:NWY`2SXj<0Xj>S09ZJVP80WYjN00D0YJFU0:RX
Z02UYJD0YJFU06YZJP02061PH0040:6QX@2TY:@0Y:BT0:b/[080/k>c00@0];Bd0:j^[P2^[Zh0]KFe
0P2k^k/00`2g]kL0]KFe0;Fe]@030;Jf]P0406a/K023Ph<0Ph>30;Rh^080];Bd00@0Z:RX0:VYZ@2Y
ZJT0][Jf0P2g]kL0102c/k<0ZZZZ0:ZZZP2g]kL30;bl_080^[Zj00D0B4Q809>CT`2CTi<0]kNg0;>c
/`020:b/[00409^KV`2IVIT0VIVI0:JVYP80Zj^[00@0[:b/0:n_[`2_[jl0^;Rh0P1ZJVX0102GUiL0
]KFe0;Fe]@2d];@20;6a/@040;>c/`2b/[80/[:b0:f][@80XZ:R00@0ZZZZ0:^[Z`2[Zj/0YjNW0P2_
[jl0101hN7P0O7al07alO02f][H20;^k^`040<C4a02m_Kd0_Kfm0:f][@80]kNg00<0]KFeoooooooo
ool040000?l20?n001<0003o00<0oh000000o`000?l09P000?l20?n001T0003o3@3oP0030000o`<0
oh000`000?l40?n00080003o1`3oP0020000o`<0oh002@000?l30?n00080003o2@3oP0060000o`80
oh000`000?l:0?n000[ooooo0009ooooo`040:^[Z`2UYJD0YJFU09BDU080SHf=00@0X:2P0:JVYP2V
YZH0YjNW0P2>SXh01029RHT0WinO09nOW`2CTi<202`/;00409jNWP2OWil0WinO09RHV080R8R800@0
Q8B407UiN@1iNGT0Q8B40P2:RXX01026QXH0Shn?08n?S`1nOWh209>CT`04096AT@0g=cL0=cLg08:2
PP80TY:B00@0QXJ6096AT@2ATI40WinO0P2PX:001@2QXJ40YZJV0:VYZ@2YZJT0Y:BT00<0X:2P0P1o
Ogl0101[Jf/0TI6A096AT@2MWId209NGU`0409bLW02OWil0WinO09^KV`80W9bL00@0U9BD09JFUP2F
UYH0X:2P0P2SXj<0102UYJD0LG5a075aL@1FEUH20:BTY0030:JVYP2TY:@0Y:BT00<0YJFU00@0YjNW
0:>SX`2SXj<0VYZJ0P2NWYh01@2UYJD0Z:RX0:FUY@2UYJD0JVYZ0080H61P00@0XJ6Q0:BTY02TY:@0
[:b/0P2c/k<0102d];@0[Zj^0:j^[P2e]KD20;^k^`030;Ng]`2e]KD0]KFe00<0][Jf00@0K6a/08>3
P`23Ph<0^;Rh0P2d];@0102XZ:P0ZJVY0:VYZ@2f][H20;Ng]`040;>c/`2ZZZX0ZZZZ0;Ng]`<0_;bl
0P2j^[X01@18B4P0Ti>C09>CT`2g]kL0/k>c0080[:b/00@0Vi^K09VIV@2IVIT0YZJV0P2[Zj/0102/
[:`0[jn_0:n_[`2h^;P206YZJP0409NGU`2e]KD0]KFe0;Bd]080/K6a00@0/k>c0;:b/P2b/[80[Jf]
0P2RXZ80102ZZZX0Zj^[0:^[Z`2WYjL20:n_[`0407QhN01lO7`0O7al0;Jf]P80^k^k00@0a<C40;fm
_@2m_Kd0[Jf]0P2g]kL00`2e]KGoooooooooo`0@0000o`80oh004`000?l00`3oP000003o0000o`0V
0000o`80oh006@000?l=0?n000<0003o0`3oP0030000o`@0oh000P000?l70?n00080003o0`3oP009
0000o`<0oh000P000?l90?n000H0003o0P3oP0030000o`X0oh002_ooool000Wooooo00@0YJFU0:6Q
X@2QXJ40Xj>S0P2MWId0102PX:00WYjN09jNWP2LW9`308n?S`80QHF500@0OGem03Ti>@0i>CT0WYjN
0P2PX:00102VYZH0Y:BT0:BTY02KVi/208B4Q00408R8R021PH40PH6108V9R@80T92@00@0Vi^K09JF
UP2FUYH0V9RH0P0n?Sh01020P800Ph>308>3P`23Ph<209:BTP0509JFUP2@T900T92@08f=S@2ATI40
0P2QXJ40102SXj<0X:2P0:2PX02NWYh2075aL@0405MGE`1WIfL0IfMW08>3P`80TI6A00@0SHf=09bL
W02LW9`0VIVI0P2LW9`01026QXH0TY:B09:BTP2PX:020:6QX@0409nOW`25QHD0QHF506IVIP80WIfM
00@0Z:RX0:NWY`2WYjL0Xj>S0P2QXJ40102SXj<0Vi^K09^KV`2?Shl208b<S080Ti>C0P2ATI40101e
MGD0HF5Q065QH@2;Rh/209FEU@040:2PX02WYjL0YjNW0:>SX`80XJ6Q00@0ZZZZ0;6a/@2a/K40/;2`
0P2d];@0102g]kL0]KFe0;Fe]@1bLW8209FEU@040;Ng]`2b/[80/[:b09ZJVP80ZJVY00@0];Bd0;:b
/P2b/[80[Zj^0P2XZ:P0102f][H0^KVi0;Vi^@2i^KT20;Rh^0050451@@2KVi/0Vi^K0;Zj^P2i^KT0
0P2^[Zh00`2KVi/0YjNW0:NWY`040:j^[P80[jn_00@0^KVi06QXJ01XJ6P0VYZJ1@2a/K40102d];@0
[jn_0:n_[`2VYZH20:RXZ0040:FUY@2[Zj/0Zj^[0:RXZ080[Zj^00@0OGem08:2PP22PX80^KVi0P2k
^k/01031`L40^[Zj0;Zj^P2[Zj/20;2`/0030;Bd]?oooooooooo0100003o0P3oP00C0000o`030?n0
00000?l0003o0180003o00<0oh000000o`000?l0<P000?l70?n000<0003o0`3oP0030000o`@0oh00
0P000?l70?n00080003o103oP0030000o`P0oh000P000?l80?n000L0003o0P3oP0030000o`H0oh00
00@0003o0?n0003oP000oh002_ooool000Wooooo00@0Lg=c06IVIP1VIVH0IfMW0P1LG5`01010@400
ATI604I6AP12@T8203Xj>P0403Ti>@0V9RH09RHV02LW9`80:BTY00@0ADE505=CD`1CDe<0DU9B0P1C
De<01012@T80B4Q804Q8B00m?Cd204U9B@0404m?C`1LG5`0G5aL04a<C080@d=300@0=3@d03hn?P0n
?Sh0De=C0P19BDT0101>CTh0GEeM05eMG@1VIVH205=CD`0504Y:BP17AdL0Cdm?04m?C`1IFET00P1@
D500101QHF40CDe=04e=C@19BDT204E5A@04051@D015ADD0ADE504M7A`80Bd];00@0GUiN05MGE`1G
EeL0Cdm?0`1FEUH205YJFP0405EEE@1:BTX0BTY:04I6AP80LG5a00@0Jf][06i^KP1^KVh0JVYZ0P1X
J6P0101VIVH0I6AT06ATI01]KFd206=SH`05061PH01ZJVX0I6AT06ATI01FEUH00P1?Cdl0101>CTh0
Fe]K05]KF`1`L70207=cL`0407EeM@1cLg<0Lg=c06UYJ@80IFEU00@0LG5a06m_K`1_Kfl0L71`0P1^
KVh0100k>c/0Hf=S06=SH`20P80207]kN`0407EeM@21PH40PH6108B4Q080OGem00@0Ph>307YjNP1j
NWX0O7al0P1gMgL0101lO7`0MWIf07IfMP0e=CD2079bLP0508F5Q@24Q8@0OGem07emO@1LG5`00P1d
M7@0101nOWh0Q8B408B4Q02<S8`2092@T00409:BTP1OGel0GemO07EeM@80QhN700@0RXZ:08F5Q@25
QHD0OWin0P1hN7P0101`L700OWin07inOP20P80208R8R0040861P@22PX80PX:206EUI@80HF5Q00@0
VYZJ0::RXP2RXZ80X:2P0P2MWId0101kNg/0TI6A096AT@2GUiL2ooooo`@0003o:03oP0020000o`T0
oh0000<0003o0?n0003oP0005P3oP00A0000o`H0oh003`000?l20?n001<0003o00<0oh000000o`00
0?l010000?l20?n002T0003o2_ooool000Wooooo00@0Lg=c06IVIP1VIVH0IfMW0P1LG5`01010@400
ATI604I6AP12@T8203Xj>P0403Ti>@0V9RH09RHV02LW9`80:BTY00@0ADE505=CD`1CDe<0DU9B0P1C
De<01012@T80B4Q804Q8B00m?Cd204U9B@0404m?C`1LG5`0G5aL04a<C080@d=300@0=3@d03hn?P0n
?Sh0De=C0P19BDT0101>CTh0GEeM05eMG@1VIVH205=CD`0504Y:BP17AdL0Cdm?04m?C`1IFET00P1@
D500101QHF40CDe=04e=C@19BDT204E5A@04051@D015ADD0ADE504M7A`80Bd];00@0GUiN05MGE`1G
EeL0Cdm?0`1FEUH205YJFP0405EEE@1:BTX0BTY:04I6AP80LG5a00@0Jf][06i^KP1^KVh0JVYZ0P1X
J6P0101VIVH0I6AT06ATI01]KFd206=SH`05061PH01ZJVX0I6AT06ATI01FEUH00P1?Cdl0101>CTh0
Fe]K05]KF`1`L70207=cL`0407EeM@1cLg<0Lg=c06UYJ@80IFEU00@0LG5a06m_K`1_Kfl0L71`0P1^
KVh0100k>c/0Hf=S06=SH`20P80207]kN`0407EeM@21PH40PH6108B4Q080OGem00@0Ph>307YjNP1j
NWX0O7al0P1gMgL0101lO7`0MWIf07IfMP0e=CD2079bLP0508F5Q@24Q8@0OGem07emO@1LG5`00P1d
M7@0101nOWh0Q8B408B4Q02<S8`2092@T00409:BTP1OGel0GemO07EeM@80QhN700@0RXZ:08F5Q@25
QHD0OWin0P1hN7P0101`L700OWin07inOP20P80208R8R0040861P@22PX80PX:206EUI@80HF5Q00@0
VYZJ0::RXP2RXZ80X:2P0P2MWId0101kNg/0TI6A096AT@2GUiL2ooooo`@0003o:03oP0020000o`T0
oh0000<0003o0?n0003oP0005P3oP00A0000o`H0oh003`000?l20?n001<0003o00<0oh000000o`00
0?l010000?l20?n002T0003o2_ooool000Wooooo00@0[jn_0:BTY02TY:@0YJFU0P2GUiL0101<C4`0
P8200820P02BTY8209VIV@0409NGU`2;Rh/0Rh^;09:BTP80UIFE00@0XJ6Q0:>SX`2SXj<0Z:RX0P2W
YjL0102YZJT0UIFE09FEU@1=CDd205MGE`040:>SX`2IVIT0VIVI0820P080X:2P00@0XZ:R09nOW`2O
Wil0Vi^K0P2HV9P0102JVYX0WYjN09jNWP2PX:020:NWY`0507UiN@1XJ6P0VIVI09VIV@2JVYX00P2;
Rh/01024Q8@0TY:B09:BTP26QXH208j>SP0409BDU02EUID0UIFE092@T080V9RH00@0TI6A05eMG@1M
GEd0MWIf0P2LW9`0102XZ:P0YJFU0:FUY@2DU9@2096AT@04092@T02CTi<0Ti>C092@T0<0Rh^;0P2P
X:00102TY:@0GemO05mOG`1dM7@208R8R00508N7Q`1oOgl0Ph>308>3P`2=SHd00P26QXH0102=SHd0
RXZ:08Z:RP29RHT208>3P`0408J6QP1iNGT0NGUi04I6AP80QHF500@0P8200861P@21PH40R8R80P2<
S8`01029RHT0M7Ad07AdM01TI6@206=SH`0405mOG`1LG5`0G5aL02/[:`80HV9R00@0RXZ:08n?S`2?
Shl0S8b<0P2ATI40102>SXh0S8b<08b<S02<S8`208>3P`0507moO`22PX80Ogmo07moO`1eMGD00P0j
>SX0101VIVH0Ng]k07]kN`1kNg/207EeM@0407=cL`1gMgL0MgMg079bLP80L71`00@0JFUY06a/K01/
K6`0IVIV0P1WIfL0100g=cL0@4100410@01FEUH205YJFP0304m?C`1GEeL0EeMG00<0FUYJ0`1MGEd0
101NGUh0HV9R069RHP1MGEd205mOG`0403/k>ooooooooooo0?n000D0003o00<0oh000000o`000?l0
4P000?l30?n002H0003o00<0oh000000o`000?l09P000?l20?n000l0003o0P3oP00D0000o`030?n0
00000?l0003o0100003o403oP0020000o`040?n000000?l0003o0?n000[ooooo0009ooooo`040;Jf
]P2a/K40/K6a0:b/[080ZZZZ00@0C4a<08R8R028R8P0ZJVY0`2_[jl20;6a/@030;:b/P2f][H0][Jf
00<0];Bd00@0YZJV0:>SX`2SXj<0[:b/0P2IVIT0101GEeL0F5QH05QHF02LW9`209NGU`0408V9R@2I
VIT0VIVI092@T080RXZ:00@0Ph>308^;R`2;Rh/0Ti>C0P2KVi/01@2QXJ40YZJV0:JVYP22PX80KVi^
0080[:b/00@0YZJV0:2PX02PX:00Xj>S0P2KVi/309nOW`0409^KV`2QXJ40XJ6Q0:BTY080VYZJ00@0
S8b<05YJFP1JFUX0Ogmo0P2h^;P0102i^KT0^;Rh0;Rh^02QXJ430:n_[`80[Jf]00@0YZJV0:NWY`2W
YjL0YJFU0P2XZ:P0102[Zj/0M7Ad07AdM02WYjL20;2`/0050:n_[`2`/;00/;2`0;2`/02d];@00P2h
^;P0102f][H0^KVi0;Vi^@2j^[X30;jn_P80];Bd00@0GUiN0;Zj^P2j^[X0[jn_0P2ZZZX0102b/[80
/k>c0;>c/`2i^KT20;Bd]0040;6a/@2VYZH0YZJV09ZJVP80X:2P00@0<30`08Z:RP2:RXX0/;2`0P2/
[:`00`2YZJT0/;2`0;2`/0030;Fe]@050:f][@2/[:`0[:b/0;6a/@2f][H00P2l_;`0102UYJD0=cLg
03Lg=`2VYZH20;>c/`040;6a/@2b/[80/[:b0;Fe]@80][Jf00@0[:b/0:f][@2][Jd0[Zj^0P2b/[80
102^[Zh0ZZZZ0:ZZZP1TI6@207UiN@040;Jf]P2g]kL0]kNg0;Ng]`80^[Zj00@0];Bd0:RXZ02XZ:P0
Y:BT0P2`/;000`2^[Zh0/[:b0;:b/P030;6a/@03069RH_oooooooooo00<0oh000`000?l0103oP000
003o0000o`000?l;0?n000H0003o0`3oP00V0000o`030?n000000?l0003o00@0oh000P000?l40?n0
00/0003o5P3oP0000`000?l0oh000?n000060?n000@0003o00@0oh000000o`000?l0oh000`000?l6
0?n00080003o103oP0020000o`030?n000000?l0003o00L0oh0000<0003o0?n0003oP000103oP005
0000o`L0oh000`000?l80?n000030000oooooooooooo00Sooooo0009ooooo`040;Jf]P2a/K40/K6a
0:b/[080ZZZZ00@0C4a<08R8R028R8P0ZJVY0`2_[jl20;6a/@030;:b/P2f][H0][Jf00<0];Bd00@0
YZJV0:>SX`2SXj<0[:b/0P2IVIT0101GEeL0F5QH05QHF02LW9`209NGU`0408V9R@2IVIT0VIVI092@
T080RXZ:00@0Ph>308^;R`2;Rh/0Ti>C0P2KVi/01@2QXJ40YZJV0:JVYP22PX80KVi^0080[:b/00@0
YZJV0:2PX02PX:00Xj>S0P2KVi/309nOW`0409^KV`2QXJ40XJ6Q0:BTY080VYZJ00@0S8b<05YJFP1J
FUX0Ogmo0P2h^;P0102i^KT0^;Rh0;Rh^02QXJ430:n_[`80[Jf]00@0YZJV0:NWY`2WYjL0YJFU0P2X
Z:P0102[Zj/0M7Ad07AdM02WYjL20;2`/0050:n_[`2`/;00/;2`0;2`/02d];@00P2h^;P0102f][H0
^KVi0;Vi^@2j^[X30;jn_P80];Bd00@0GUiN0;Zj^P2j^[X0[jn_0P2ZZZX0102b/[80/k>c0;>c/`2i
^KT20;Bd]0040;6a/@2VYZH0YZJV09ZJVP80X:2P00@0<30`08Z:RP2:RXX0/;2`0P2/[:`00`2YZJT0
/;2`0;2`/0030;Fe]@050:f][@2/[:`0[:b/0;6a/@2f][H00P2l_;`0102UYJD0=cLg03Lg=`2VYZH2
0;>c/`040;6a/@2b/[80/[:b0;Fe]@80][Jf00@0[:b/0:f][@2][Jd0[Zj^0P2b/[80102^[Zh0ZZZZ
0:ZZZP1TI6@207UiN@040;Jf]P2g]kL0]kNg0;Ng]`80^[Zj00@0];Bd0:RXZ02XZ:P0Y:BT0P2`/;00
0`2^[Zh0/[:b0;:b/P030;6a/@03069RH_oooooooooo00<0oh000`000?l0103oP000003o0000o`00
0?l;0?n000H0003o0`3oP00V0000o`030?n000000?l0003o00@0oh000P000?l40?n000/0003o5P3o
P0000`000?l0oh000?n000060?n000@0003o00@0oh000000o`000?l0oh000`000?l60?n00080003o
103oP0020000o`030?n000000?l0003o00L0oh0000<0003o0?n0003oP000103oP0050000o`L0oh00
0`000?l80?n000030000oooooooooooo00Sooooo0009ooooo`040;>c/`2^[Zh0[Zj^0:b/[080ZJVY
00@0>c/k08N7Q`27QhL0[Zj^0P2_[jl0102ZZZX0[Jf]0:f][@2^[Zh50;Ng]`040:BTY02QXJ40XJ6Q
0:JVYP80YJFU00@0J6QX05ADE01DE5@0YJFU0P2QXJ4309NGU`0408b<S023Ph<0Ph>307]kN`80O7al
00@0Shn?09jNWP2NWYh0X:2P0P2OWil00`22PX80LG5a0:NWY`040:NWY`0409^KV`29RHT0RHV909bL
W080XJ6Q00@0UIFE0::RXP2RXZ80YJFU0P2DU9@01023Ph<0C4a<04a<C01lO7`50;Bd]00409fMW@2e
]KD0]KFe0:n_[`80ZZZZ00@0ZJVY0:NWY`2WYjL0[Zj^0P2][Jd0102[Zj/0LG5a075aL@2HV9P20:b/
[0050;6a/@2^[Zh0/;2`0;2`/02g]kL00P2h^;P0102i^KT0_;bl0;bl_031`L420<C4a0040;no_`2X
Z:P0Z:RX069RHP80]kNg00@0/;2`0:^[Z`2[Zj/0Zj^[0P2][Jd0102f][H0/[:b0;:b/P2[Zj/20:>S
X`0409nOW`2ATI40TI6A030`<080MWIf00@0[Jf]0:b/[02/[:`0[Zj^0P2_[jl0102c/k<0/[:b0;:b
/P2d];@20:n_[`050;Fe]@2k^k/0^k^k0;^k^`2NWYh00P0e=CD0102VYZH0Z:RX0:RXZ02][Jd20:RX
Z0040:f][@2UYJD0YJFU0:RXZ080[:b/0`2`/;00102XZ:P0Zj^[0:^[Z`1_Kfl207IfMP040;2`/02^
[Zh0[Zj^0;2`/080]KFe00@0Zj^[09VIV@2IVIT0WinO0P2[Zj/0102b/[80/K6a0;6a/@2d];@20;6a
/@0306YZJ_oooooooooo00<0oh000`000?l00`3oP000003o0000o`030?n000030000o`3oP000oh00
00H0oh001`000?l20?n002H0003o00<0oh000000o`000?l0103oP0020000o`<0oh0010000?l30?n0
00H0003o3`3oP0030000o`<0oh000`000?l40?n000H0003o00@0oh000000o`000?l0oh000P000?l=
0?n00080003o00@0oh000000o`000?l0003o0P3oP0000`000?l0oh000?n000040000o`<0oh001P00
0?l60?n000H0003o1P3oP0000`000?ooooooooooo`08ooooo`002Oooool0102`/;00ZZZZ0:ZZZP2X
Z:P20:ZZZP04055AD@1eMGD0MGEe0:JVYP80Z:RX00@0XZ:R0:6QX@2QXJ40YZJV0P2[Zj/0102`/;00
YjNW0:NWY`2RXZ820:2PX00409ZJVP2QXJ40XJ6Q06MWI`80DU9B00@0XZ:R09ZJVP2JVYX0UiNG0P2H
V9P01027QhL0OGem07emO@1mOGd207YjNP0407]kN`24Q8@0Q8B408Z:RP80U9BD00D0NGUi07IfMP2T
Y:@0Y:BT0:RXZ0020:JVYP0409^KV`2GUiL0UiNG0:BTY080ZJVY0`2PX:00102SXj<0UiNG09NGU`28
R8P2055AD@0408B4Q02^[Zh0[Zj^0:j^[P80[:b/00<0WinO0:n_[`2_[jl00`2/[:`0102RXZ80XJ6Q
0:6QX@2[Zj/20:JVYP040:FUY@1SHf<0Hf=S08V9R@<0[jn_00@0Zj^[0:b/[02/[:`0Z:RX0P2OWil0
102l_;`0_Kfm0;fm_@33`l<20<;2`P040<71`@2LW9`0W9bL05eMG@80]KFe00@0/k>c0;:b/P2b/[80
Xj>S0P2OWil0102ZZZX0Zj^[0:^[Z`2YZJT20:BTY00408N7Q`1lO7`0O7al03dm?@80J6QX00@0YjNW
0:ZZZP2ZZZX0[:b/0P2_[jl00`2d];@0/[:b0;:b/P030;Jf]P050;>c/`2`/;00[jn_0:n_[`2/[:`0
0P0o?cl30:f][@040:ZZZP2b/[80/[:b0;>c/`80[Jf]00@0/;2`0:j^[P2^[Zh0]kNg0P2k^k/0102h
^;P0^KVi0;Vi^@1lO7`207MgM`040:f][@2`/;00/;2`0;>c/`80];Bd00@0[jn_0:^[Z`2[Zj/0YjNW
0P2ZZZX0102d];@0]kNg0;Ng]`2j^[X20;:b/P0406MWIooooooooooo0?n000D0003o00<0oh000000
o`000?l02@000?l00`3oP000003o0000o`070000o`80oh009P000?l00`3oP000003o0000o`030?n0
00<0003o00<0oh000000o`000?l030000?l30?n000D0003o203oP0000`000?l0oh000?n000040?n0
00`0003o00<0oh000000o`000?l010000?l<0?n00080003o103oP0020000o`d0oh000`000?l70?n0
00D0003o1P3oP0000`000?ooooooooooo`08ooooo`002Oooool0102`/;00ZZZZ0:ZZZP2XZ:P20:ZZ
ZP04055AD@1eMGD0MGEe0:JVYP80Z:RX00@0XZ:R0:6QX@2QXJ40YZJV0P2[Zj/0102`/;00YjNW0:NW
Y`2RXZ820:2PX00409ZJVP2QXJ40XJ6Q06MWI`80DU9B00@0XZ:R09ZJVP2JVYX0UiNG0P2HV9P01027
QhL0OGem07emO@1mOGd207YjNP0407]kN`24Q8@0Q8B408Z:RP80U9BD00D0NGUi07IfMP2TY:@0Y:BT
0:RXZ0020:JVYP0409^KV`2GUiL0UiNG0:BTY080ZJVY0`2PX:00102SXj<0UiNG09NGU`28R8P2055A
D@0408B4Q02^[Zh0[Zj^0:j^[P80[:b/00<0WinO0:n_[`2_[jl00`2/[:`0102RXZ80XJ6Q0:6QX@2[
Zj/20:JVYP040:FUY@1SHf<0Hf=S08V9R@<0[jn_00@0Zj^[0:b/[02/[:`0Z:RX0P2OWil0102l_;`0
_Kfm0;fm_@33`l<20<;2`P040<71`@2LW9`0W9bL05eMG@80]KFe00@0/k>c0;:b/P2b/[80Xj>S0P2O
Wil0102ZZZX0Zj^[0:^[Z`2YZJT20:BTY00408N7Q`1lO7`0O7al03dm?@80J6QX00@0YjNW0:ZZZP2Z
ZZX0[:b/0P2_[jl00`2d];@0/[:b0;:b/P030;Jf]P050;>c/`2`/;00[jn_0:n_[`2/[:`00P0o?cl3
0:f][@040:ZZZP2b/[80/[:b0;>c/`80[Jf]00@0/;2`0:j^[P2^[Zh0]kNg0P2k^k/0102h^;P0^KVi
0;Vi^@1lO7`207MgM`040:f][@2`/;00/;2`0;>c/`80];Bd00@0[jn_0:^[Z`2[Zj/0YjNW0P2ZZZX0
102d];@0]kNg0;Ng]`2j^[X20;:b/P0406MWIooooooooooo0?n000D0003o00<0oh000000o`000?l0
2@000?l00`3oP000003o0000o`070000o`80oh009P000?l00`3oP000003o0000o`030?n000<0003o
00<0oh000000o`000?l030000?l30?n000D0003o203oP0000`000?l0oh000?n000040?n000`0003o
00<0oh000000o`000?l010000?l<0?n00080003o103oP0020000o`d0oh000`000?l70?n000D0003o
1P3oP0000`000?ooooooooooo`08ooooo`002Oooool0101eMGD0LG5a075aL@1YJFT206=SH`0403@d
=01LG5`0G5aL06i^KP80IfMW0`1ZJVX0101[Jf/0HF5Q065QH@1YJFT206MWI`0406=SH`1DE5@0E5AD
04i>CP80C4a<00@0<30`03@d=00d=3@0KFe]0P1eMGD3071`L00406ATI01JFUX0FUYJ05UIF@80Fe]K
00@0De=C05YJFP1JFUX0HF5Q0P1XJ6P01@0l?3`0CTi>07IfMP1fMWH0L71`0080Kfm_00@0I6AT065Q
H@1QHF40IVIV0P1`L700101OGel0GUiN05iNGP1QHF4205ADE00404a<C00b<S80<S8b055AD@80Lg=c
00@0MGEe079bLP1bLW80Kfm_0P1`L700101jNWX0MGEe07EeM@1ZJVX305mOG`80EUIF00@0Cdm?034a
<@0a<C40AdM70P1EEED00`1UIFD0KVi^06MWI`0206MWI`80GUiN00@0NGUi08>3P`23Ph<0RXZ:0P26
QXH01023Ph<0BTY:04Y:BP0o?cl208R8R00408:2PP2<S8`0S8b<07moO`80QhN700@0PX:20820P020
P800QhN70P1jNWX0101WIfL0KVi^06i^KP14A4@2065QH@0408n?S`2IVIT0VIVI09NGU`80XJ6Q00@0
WYjN092@T02@T900PX:20P2EUID01@2@T900VYZJ09>CT`2CTi<0P8200080=SHf00@0PH6109fMW@2M
WId0T92@0`2DU9@209NGU`0409bLW02PX:00X:2P0:BTY080Z:RX00@0Zj^[0:b/[02/[:`0P8200P1T
I6@0102EUID0Y:BT0:BTY02ZZZX20:JVYP040:ZZZP2UYJD0YJFU09fMW@80XJ6Q00@0XZ:R0:BTY02T
Y:@0ZZZZ0P2YZJT00`1TI6Coooooooooo`060000o`<0oh003@000?l80?n000L0003o1`3oP0030000
o`<0oh0030000?l00`3oP000003o0000o`060?n000l0003o1`3oP0060000o`030?n000000?l0003o
00H0003o0`3oP00@0000o`030?n000000?l0003o0180003o00<0oh000000o`000?l09P000?l:oooo
o`002Oooool0102GUiL0V9RH09RHV02EUID2092@T00309FEU@2@T900T92@00<0Q8B400@0U9BD09bL
W02LW9`0X:2P0P1HF5P0101XJ6P0Shn?08n?S`2=SHd20861P@0408:2PP29RHT0RHV9092@T080Ti>C
00@0T92@08V9R@29RHT0Ph>30P24Q8@0101oOgl0E5AD05ADE00i>CT205iNGP04061PH01TI6@0I6AT
06][J`80JFUY0P1PH60206a/K00406YZJP1^KVh0KVi^06e]K@80JVYZ00@0ATI605mOG`1OGel0IVIV
0P1/K6`0101VIVH0KVi^06i^KP1cLg<207inOP0407IfMP1jNWX0NWYj07IfMP80Jf][00@0LG5a069R
HP1RHV80ATI60`1_Kfl206UYJ@0406YZJP1WIfL0IfMW06][J`80M7Ad00D0MgMg06a/K01/K6`0MWIf
07QhN00207IfMP0404];B`0i>CT0>CTi06EUI@80L71`00@0Jf][06EUI@1UIFD0Jf][0P1_Kfl0101g
MgL0K6a/06a/K01^KVh2075aL@0406m_K`1WIfL0IfMW05ADE080K6a/00@0KFe]06YZJP1ZJVX0LW9b
0`1hN7P207AdM004071`L01/K6`0K6a/06QXJ080HV9R00@0GemO03Ti>@0i>CT092@T0P0a<C401@0l
?3`0?Cdm04Y:BP1:BTX0AdM70080DE5A00@0DU9B05MGE`1GEeL0Bd];0P1?Cdl01017AdL0?clo03lo
?`0j>SX205mOG`04065QH@1RHV80HV9R061PH080GUiN00@0I6AT06=SH`1SHf<0F5QH0P1OGel0101L
G5`0EUIF05IFEP1@D50203De=@0404=3@`1QHF40HF5Q05eMG@80HV9R00@0Fe]K061PH01PH600Fe]K
0_ooool@0000o`80oh004`000?l40?n00140003o00<0oh000000o`000?l04@000?l20?n00140003o
0`3oP00B0000o`80oh004@000?lF0?n000H0003o0P3oP0030000o`030?n000000?l0003o00L0oh00
0P000?l0103oP000003o0000o`3oP0020000o`030?n00?oooooooooo00Sooooo0009ooooo`0409NG
U`2HV9P0V9RH09FEU@80T92@00<0UIFE092@T02@T9000`24Q8@0102DU9@0W9bL09bLW02PX:0205QH
F00406QXJ02?Shl0Shn?08f=S@80PH6100@0PX:208V9R@29RHT0T92@0P2CTi<0102@T900RHV908V9
R@23Ph<208B4Q00407moO`1DE5@0E5AD03Ti>@80GUiN00@0H61P06ATI01TI6@0Jf][0P1YJFT2061P
H080K6a/00@0JVYZ06i^KP1^KVh0KFe]0P1ZJVX01016ATH0GemO05mOG`1VIVH206a/K00406IVIP1^
KVh0KVi^07=cL`80OWin00@0MWIf07YjNP1jNWX0MWIf0P1[Jf/0101aLG40HV9R069RHP16ATH306m_
K`80JFUY00@0JVYZ06MWI`1WIfL0Jf][0P1dM7@01@1gMgL0K6a/06a/K01fMWH0N7Qh0080MWIf00@0
Bd];03Ti>@0i>CT0IFEU0P1`L700101[Jf/0IFEU06EUI@1[Jf/206m_K`0407MgM`1/K6`0K6a/06i^
KP80LG5a00@0Kfm_06MWI`1WIfL0E5AD0P1/K6`0101]KFd0JVYZ06YZJP1bLW8307QhN080M7Ad00@0
L71`06a/K01/K6`0J6QX0P1RHV80101OGel0>CTi03Ti>@0T92@2034a<@0503`l?00m?Cd0BTY:04Y:
BP17AdL00P1ADE40101BDU80EeMG05MGE`1;Bd/204m?C`0404M7A`0o?cl0?clo03Xj>P80GemO00@0
HF5Q069RHP1RHV80H61P0P1NGUh0101TI6@0Hf=S06=SH`1HF5P205mOG`0405aLG01FEUH0EUIF051@
D080=CDe00@0@d=3065QH@1QHF40GEeM0P1RHV80101KFe/0H61P061PH01KFe/2oooooa00003o0P3o
P00C0000o`@0oh004@000?l00`3oP000003o0000o`0A0000o`80oh004@000?l30?n00180003o0P3o
P00A0000oaH0oh001P000?l20?n000<0003o00<0oh000000o`000?l01`3oP0020000o`040?n00000
0?l0003o0?n00080003o00<0oh00ooooooooool02?ooool000Wooooo00@0_[jn0;Vi^@2i^KT0]KFe
0P2f][H0102h^;P0/[:b0;:b/P2a/K420:f][@040:j^[P2`/;00/;2`0;Bd]080HF5Q00@0Ng]k0:VY
Z@2YZJT0Y:BT0P2NWYh0102FUYH0WYjN09jNWP2NWYh20:JVYP040::RXP2QXJ40XJ6Q0:BTY080YjNW
00@0Xj>S06=SH`1SHf<0DE5A0P2<S8`01029RHT0U9BD09BDU02GUiL209ZJVP80ZZZZ0P2][Jd0102Y
ZJT0ZZZZ0:ZZZP2YZJT20;6a/@04069RHP26QXH0QXJ60:j^[P80]kNg00@0^;Rh0:j^[P2^[Zh0[:b/
0P2][Jd30:j^[P040:b/[02`/;00/;2`0:b/[080Y:BT00@0JFUY0:ZZZP2ZZZX0Xj>S0P2HV9P0102C
Ti<0T92@092@T02OWil20:FUY@040:BTY02UYJD0YJFU0:VYZ@<0YZJV00@0LW9b061PH01PH600ZZZZ
0P2`/;030;>c/`040;6a/@2h^;P0^;Rh0;Ng]`80^KVi00@0][Jf0;Vi^@2i^KT0/k>c0P2[Zj/01023
Ph<0YjNW0:NWY`2a/K420;Ng]`040;Jf]P2c/k<0/k>c0;Bd]0<0[Zj^0P2g]kL0102i^KT0]kNg0;Ng
]`2h^;P2071`L00506IVIP1oOgl0Ogmo0820P02PX:000P2RXZ80102ATI40MgMg07MgM`1JFUX207Yj
NP0408B4Q025QHD0QHF508>3P`80GemO00@0CDe=0:FUY@2UYJD0[:b/0P2^[Zh0102d];@0^KVi0;Vi
^@2f][H20:ZZZP040;Ng]`2i^KT0^KVi0;no_`80^k^k00@0^KVi04=3@`13@d<0TY:B0P2ZZZX0102Y
ZJT0/[:b0;:b/P2g]kL20;Fe]@030;6a/Ooooooooooo0100oh005P000?l20?n000X0003o0P3oP004
0000o`80oh000`000?l50?n00080003o103oP0020000o`030?n000000?l0003o01T0003o3`3oP004
0000oa00oh0030000?l20?n000L0003o00@0oh000000o`000?l0003o1P3oP0020000o`T0oh001000
0?l60?n000[ooooo0009ooooo`030;jn_P2j^[X0^[Zj00<0/;2`00@0][Jf0:n_[`2_[jl0[jn_0P2/
[:`0102_[jl0[Jf]0:f][@2a/K4206e]K@0408F5Q@2/[:`0[:b/0:6QX@80Vi^K00@0UIFE09^KV`2K
Vi/0VIVI0P2MWId0102PX:00Xj>S0:>SX`2UYJD20:JVYP0409ZJVP1PH600H61P051@D080SHf=00@0
TY:B08n?S`2?Shl0VIVI0P2EUID01@2RXZ80Xj>S0:ZZZP2ZZZX0Z:RX0080Xj>S00@0WinO0:FUY@2U
YJD0K6a/0P23Ph<0102/[:`0[Jf]0:f][@2`/;020::RXP040:2PX02[Zj/0Zj^[0:f][@80[:b/00@0
ZJVY0:RXZ02XZ:P0ZJVY0P2MWId0101FEUH0YjNW0:NWY`2SXj<209RHV00408J6QP2>SXh0SXj>0:BT
Y080YZJV00D0Vi^K0:>SX`2SXj<0Z:RX0:ZZZP020:NWY`0406i^KP1YJFT0JFUY0:^[Z`80[jn_00@0
];Bd0:n_[`2_[jl0[Zj^0P2`/;00102c/k<0]KFe0;Fe]@2k^k/20;fm_@040;Rh^02TY:@0Y:BT08J6
QP80X:2P00@0[Zj^0;Bd]02d];@0/K6a0`2_[jl20:JVYP040:b/[02_[jl0[jn_0;Fe]@80^;Rh00@0
/k>c06MWI`1WIfL0U9BD0P2ZZZX01@2@T900XJ6Q09JFUP2FUYH0VIVI0080QXJ600@0EUIF09JFUP2F
UYH0YjNW0P2ZZZX0102/[:`0MgMg07MgM`1LG5`20:b/[0040:FUY@2WYjL0YjNW0:b/[080/[:b00@0
[Zj^08n?S`2?Shl0WYjN0P2h^;P0102k^k/0][Jf0;Jf]P2i^KT205aLG00409>CT`2][Jd0[Jf]0;2`
/080/K6a00@0]KFe0;6a/@2a/K40[Jf]0_ooool:0?n00080003o103oP00F0000o`80oh005P000?l3
0?n000@0003o0P3oP0070000o`80oh005P000?l?0?n000@0003o1`3oP0030000o`H0oh0030000?l2
0?n000L0003o00<0oh000000o`000?l010000?l30?n000<0003o203oP0000`000?l0oh000?n00007
0?n000[ooooo0009ooooo`030;jn_P2j^[X0^[Zj00<0/;2`00@0][Jf0:n_[`2_[jl0[jn_0P2/[:`0
102_[jl0[Jf]0:f][@2a/K4206e]K@0408F5Q@2/[:`0[:b/0:6QX@80Vi^K00@0UIFE09^KV`2KVi/0
VIVI0P2MWId0102PX:00Xj>S0:>SX`2UYJD20:JVYP0409ZJVP1PH600H61P051@D080SHf=00@0TY:B
08n?S`2?Shl0VIVI0P2EUID01@2RXZ80Xj>S0:ZZZP2ZZZX0Z:RX0080Xj>S00@0WinO0:FUY@2UYJD0
K6a/0P23Ph<0102/[:`0[Jf]0:f][@2`/;020::RXP040:2PX02[Zj/0Zj^[0:f][@80[:b/00@0ZJVY
0:RXZ02XZ:P0ZJVY0P2MWId0101FEUH0YjNW0:NWY`2SXj<209RHV00408J6QP2>SXh0SXj>0:BTY080
YZJV00D0Vi^K0:>SX`2SXj<0Z:RX0:ZZZP020:NWY`0406i^KP1YJFT0JFUY0:^[Z`80[jn_00@0];Bd
0:n_[`2_[jl0[Zj^0P2`/;00102c/k<0]KFe0;Fe]@2k^k/20;fm_@040;Rh^02TY:@0Y:BT08J6QP80
X:2P00@0[Zj^0;Bd]02d];@0/K6a0`2_[jl20:JVYP040:b/[02_[jl0[jn_0;Fe]@80^;Rh00@0/k>c
06MWI`1WIfL0U9BD0P2ZZZX01@2@T900XJ6Q09JFUP2FUYH0VIVI0080QXJ600@0EUIF09JFUP2FUYH0
YjNW0P2ZZZX0102/[:`0MgMg07MgM`1LG5`20:b/[0040:FUY@2WYjL0YjNW0:b/[080/[:b00@0[Zj^
08n?S`2?Shl0WYjN0P2h^;P0102k^k/0][Jf0;Jf]P2i^KT205aLG00409>CT`2][Jd0[Jf]0;2`/080
/K6a00@0]KFe0;6a/@2a/K40[Jf]0_ooool:0?n00080003o103oP00F0000o`80oh005P000?l30?n0
00@0003o0P3oP0070000o`80oh005P000?l?0?n000@0003o1`3oP0030000o`H0oh0030000?l20?n0
00L0003o00<0oh000000o`000?l010000?l30?n000<0003o203oP0000`000?l0oh000?n000070?n0
00[ooooo0009ooooo`040;>c/`2`/;00/;2`0:b/[080Z:RX00@0ZJVY0:b/[02/[:`0Zj^[0P2/[:`0
102][Jd0[Zj^0:j^[P2][Jd207QhN00408B4Q02RXZ80XZ:R09BDU080LW9b00@0L71`07moO`1oOgl0
UiNG0P2PX:00102CTi<0XJ6Q0:6QX@2SXj<209nOW`04092@T01EEED0EEEE04i>CP80Ogmo00@0PH61
08f=S@2=SHd0TI6A0P26QXH01@2:RXX0RHV909fMW@2MWId0X:2P0080Vi^K00@0WIfM0::RXP2RXZ80
IFEU0P1oOgl0102ATI40Y:BT0:BTY02/[:`20::RXP0409JFUP2HV9P0V9RH0:FUY@80Y:BT00@0YjNW
0:JVYP2VYZH0YJFU0P2HV9P0101NGUh0X:2P0:2PX02BTY8209>CT`0408R8R025QHD0QHF50:2PX080
Xj>S00@0XZ:R0:FUY@2UYJD0YZJV0`2[Zj/0101fMWH0PX:208:2PP2VYZH20:VYZ@040:b/[02VYZH0
YZJV0:RXZ080XZ:R0`2_[jl30;Fe]@040;6a/@2UYJD0YJFU08N7Q`80VIVI00<0/[:b0:n_[`2_[jl0
0`2^[Zh0102YZJT0X:2P0:2PX02WYjL20:RXZ0040:b/[02`/;00/;2`0:RXZ080H61P00D0Rh^;09jN
WP2NWYh0Shn?09fMW@0208^;R`0408f=S@2>SXh0SXj>05UIF@80U9BD00@0WIfM0:NWY`2WYjL0ZZZZ
0P1jNWX0101IFET0ZZZZ0:ZZZP2MWId20:^[Z`040:RXZ02_[jl0[jn_0:RXZ080Vi^K00@0/K6a0;Vi
^@2i^KT0^[Zj0P2h^;P0102i^KT0Kfm_06m_K`2KVi/20:RXZ0<0[jn_0`2^[Zh00`2[Zj_ooooooooo
o`030?n000T0003o103oP00E0000o`<0oh009P000?l20?n001d0003o203oP0040000o`H0oh001`00
0?l20?n000d0003o0P3oP0070000o`030?n000000?l0003o00@0003o0P3oP0030000o`L0oh001@00
0?l60?n000030000oooooooooooo00Sooooo0009ooooo`0408J6QP1gMgL0MgMg079bLP80MGEe0`1`
L700101]KFd0IfMW06MWI`1[Jf/206QXJ00406YZJP0h>3P0>3Ph061PH080OGem00@0PX:207YjNP1j
NWX0Bd];0P1MGEd0101NGUh0Kfm_06m_K`1eMGD206e]K@04075aL@21PH40PH6107QhN080?Shn00@0
EUIF079bLP1bLW80LW9b0P1eMGD01@1cLg<0IfMW06MWI`1JFUX0Cdm?0080HV9R00@0MWIf075aL@1a
LG40LG5a0P1[Jf/01016ATH0KFe]06e]K@1gMgL208V9R@040820P01aLG40LG5a05iNGP80E5AD00@0
Kfm_07UiN@1iNGT0MWIf0P1cLg<0101gMgL0NWYj07YjNP1=CDd206e]K@0406YZJP1dM7@0M7Ad06i^
KP80IFEU00@0JVYZ05mOG`1OGel0GemO0P1[Jf/01@1^KVh0Kfm_06ATI01TI6@0E5AD0080JFUY00@0
IfMW06YZJP1ZJVX0NWYj0P1mOGd0101cLg<0RXZ:08Z:RP2:RXX208V9R@0408n?S`22PX80PX:207mo
O`80Q8B400@0LW9b06IVIP1VIVH0S8b<0P2=SHd00`2?Shl0Ti>C09>CT`0309BDU00409bLW02@T900
T92@092@T080UYJF00@0QXJ605UIF@1IFET0QHF50P22PX801@20P800Ogmo06m_K`1_Kfl0NGUi0080
Jf][00<0Bd];07moO`1oOgl00`2ATI40102PX:00Jf][06][J`1VIVH207]kN`0307alO02MWId0WIfM
00<0W9bL00@0TY:B07alO01lO7`0Z:RX0P2TY:@0102EUID0QhN708N7Q`1aLG4205IFEP0406EUI@2H
V9P0V9RH0:^[Z`80YJFU00@0Xj>S0:ZZZP2ZZZX0/K6a0_ooool@0000o`80oh001P000?l40?n000T0
003o0`3oP0070000o`<0oh0020000?l00`3oP000003o0000o`050000o`<0oh002@000?l20?n00140
003o0P3oP00V0000o`80oh002P000?l20?n001X0003o0P3oP0090000o`030?n00?oooooooooo00So
oooo0009ooooo`0408J6QP1gMgL0MgMg079bLP80MGEe0`1`L700101]KFd0IfMW06MWI`1[Jf/206QX
J00406YZJP0h>3P0>3Ph061PH080OGem00@0PX:207YjNP1jNWX0Bd];0P1MGEd0101NGUh0Kfm_06m_
K`1eMGD206e]K@04075aL@21PH40PH6107QhN080?Shn00@0EUIF079bLP1bLW80LW9b0P1eMGD01@1c
Lg<0IfMW06MWI`1JFUX0Cdm?0080HV9R00@0MWIf075aL@1aLG40LG5a0P1[Jf/01016ATH0KFe]06e]
K@1gMgL208V9R@040820P01aLG40LG5a05iNGP80E5AD00@0Kfm_07UiN@1iNGT0MWIf0P1cLg<0101g
MgL0NWYj07YjNP1=CDd206e]K@0406YZJP1dM7@0M7Ad06i^KP80IFEU00@0JVYZ05mOG`1OGel0GemO
0P1[Jf/01@1^KVh0Kfm_06ATI01TI6@0E5AD0080JFUY00@0IfMW06YZJP1ZJVX0NWYj0P1mOGd0101c
Lg<0RXZ:08Z:RP2:RXX208V9R@0408n?S`22PX80PX:207moO`80Q8B400@0LW9b06IVIP1VIVH0S8b<
0P2=SHd00`2?Shl0Ti>C09>CT`0309BDU00409bLW02@T900T92@092@T080UYJF00@0QXJ605UIF@1I
FET0QHF50P22PX801@20P800Ogmo06m_K`1_Kfl0NGUi0080Jf][00<0Bd];07moO`1oOgl00`2ATI40
102PX:00Jf][06][J`1VIVH207]kN`0307alO02MWId0WIfM00<0W9bL00@0TY:B07alO01lO7`0Z:RX
0P2TY:@0102EUID0QhN708N7Q`1aLG4205IFEP0406EUI@2HV9P0V9RH0:^[Z`80YJFU00@0Xj>S0:ZZ
ZP2ZZZX0/K6a0_ooool@0000o`80oh001P000?l40?n000T0003o0`3oP0070000o`<0oh0020000?l0
0`3oP000003o0000o`050000o`<0oh002@000?l20?n00140003o0P3oP00V0000o`80oh002P000?l2
0?n001X0003o0P3oP0090000o`030?n00?oooooooooo00Sooooo0009ooooo`0407inOP1_Kfl0Kfm_
06=SH`80ATI600@0<30`075aL@1aLG40Lg=c0P1eMGD00`1iNGT0PX:208:2PP0308V9R@0408B4Q01h
N7P0N7Qh071`L080Ng]k00@0MgMg05EEE@1EEED0;Rh^0P1MGEd0101WIfL0IFEU06EUI@1OGel305QH
F080EUIF00@0EeMG05ADE01DE5@0Cdm?0`1@D50203<c<`0401hN7P1DE5@0KFe]06e]K@<0IFEU00@0
HF5Q069RHP1RHV80Hf=S0P1TI6@0101LG5`0I6AT06ATI01PH60205eMG@0404Q8B00b<S80<S8b05eM
G@80HV9R00@0GemO06EUI@1UIFD0HF5Q0P1PH600101NGUh0Fe]K05]KF`1PH60205iNGP0405IFEP1@
D500D51@03<c<`80:2PX00D0?Cdm04I6AP16ATH0@T9204A4A00205YJFP0405mOG`1LG5`0G5aL05aL
G080GemO0`1QHF40101IFET0>SXj03Xj>P17AdL206=SH`0406YZJP1VIVH0IVIV05mOG`80LW9b00@0
L71`06e]K@1]KFd0MGEe0P1cLg<0101eMGD0NWYj07YjNP1aLG4203@d=00404m?C`1NGUh0GUiN05aL
G080BTY:00@0FUYJ05MGE`1GEeL0EeMG0P1CDe<01@1EEED0ATI603Xj>P0j>SX08R8R00807AdM00@0
9bLW02HV9P0V9RH0>SXj0P16ATH0101HF5P0GEeM05eMG@1RHV8206IVIP0406e]K@1/K6`0K6a/065Q
H@80D51@00@0=cLg02DU9@0U9BD0BTY:0P0o?cl01011@D40?Shn03hn?P10@40204Q8B004059BDP1X
J6P0J6QX07=cL`80MGEe00@0Ogmo07IfMP1fMWH0Hf=S0_ooool40000o`<0oh004P000?l50?n000@0
003o403oP00;0000o`040?n000000?l0003o0000o`H0oh001`000?l30?n00080003o3P3oP0020000
o`<0oh0010000?l50?n00140003o7P3oP0070000o`l0oh002@000?l:ooooo`002Oooool0102TY:@0
QhN708N7Q`1cLg<207AdM00403hn?P2XZ:P0Z:RX0:VYZ@80[jn_00@0ZZZZ0:^[Z`2[Zj/0YZJV0P2]
[Jd0102XZ:P0ZZZZ0:ZZZP2OWil20:NWY`040:6QX@1oOgl0Ogmo05UIF@80[Jf]00@0Zj^[0:RXZ02X
Z:P0ZZZZ0P2WYjL0102[Zj/0Y:BT0:BTY02HV9P208n?S`0409jNWP2SXj<0Xj>S0:6QX@80K6a/00D0
?Cdm0:j^[P2[Zj/0Zj^[0:VYZ@020:>SX`0409nOW`2SXj<0Xj>S0:2PX080XZ:R00@0YZJV0::RXP2R
XZ80TY:B0P2=SHd0101nOWh0?3`l03`l?028R8P20:6QX@040:^[Z`2_[jl0[jn_0;Bd]0<0]KFe0P2c
/k<0102g]kL0/[:b0;:b/P2VYZH20:j^[P04065QH@15ADD0ADE507=cL`80Ng]k0P1iNGT209>CT`04
09RHV02?Shl0Shn?0861P@<0TY:B0P28R8P0102:RXX0FUYJ05YJFP2EUID20;2`/0040;>c/`2e]KD0
]KFe0;Bd]080/;2`0`2f][H0102i^KT0]KFe0;Fe]@2`/;030:j^[P80<C4a00@0Shn?0:n_[`2_[jl0
/k>c0P31`L40102f][H0_[jn0;jn_P2g]kL20;Rh^0050;jn_P31`L40^[Zj0;Zj^P2[Zj/00P0`<300
1013@d<0QXJ608J6QP2[Zj/20:n_[`040;Bd]02k^k/0^k^k0;bl_080^k^k00@0];Bd0;2`/02`/;00
/K6a0P2YZJT00`2MWId0M7Ad07AdM0030;:b/P<0Y:BT00@0][Jf0;Ng]`2g]kL0^;Rh0P2l_;`01030
`<00aLG50<G5a@3Bd]820=3@d00307IfM_oooooooooo00H0003o00@0oh000000o`000?l0003o0P3o
P0040000o`80oh002@000?l30?n00140003o0`3oP00B0000o`030?n000000?l0003o00<0003o2P3o
P0020000o`040?n000000?l0003o0?n00180003o00<0oh000000o`000?l04`3oP0000`000?l0oh00
0?n0000=0?n00080003o0`3oP0030000o`/0oh001@000?l30?n000<0003o303oP0000`000?oooooo
ooooo`08ooooo`002Oooool0102TY:@0QhN708N7Q`1cLg<207AdM00403hn?P2XZ:P0Z:RX0:VYZ@80
[jn_00@0ZZZZ0:^[Z`2[Zj/0YZJV0P2][Jd0102XZ:P0ZZZZ0:ZZZP2OWil20:NWY`040:6QX@1oOgl0
Ogmo05UIF@80[Jf]00@0Zj^[0:RXZ02XZ:P0ZZZZ0P2WYjL0102[Zj/0Y:BT0:BTY02HV9P208n?S`04
09jNWP2SXj<0Xj>S0:6QX@80K6a/00D0?Cdm0:j^[P2[Zj/0Zj^[0:VYZ@020:>SX`0409nOW`2SXj<0
Xj>S0:2PX080XZ:R00@0YZJV0::RXP2RXZ80TY:B0P2=SHd0101nOWh0?3`l03`l?028R8P20:6QX@04
0:^[Z`2_[jl0[jn_0;Bd]0<0]KFe0P2c/k<0102g]kL0/[:b0;:b/P2VYZH20:j^[P04065QH@15ADD0
ADE507=cL`80Ng]k0P1iNGT209>CT`0409RHV02?Shl0Shn?0861P@<0TY:B0P28R8P0102:RXX0FUYJ
05YJFP2EUID20;2`/0040;>c/`2e]KD0]KFe0;Bd]080/;2`0`2f][H0102i^KT0]KFe0;Fe]@2`/;03
0:j^[P80<C4a00@0Shn?0:n_[`2_[jl0/k>c0P31`L40102f][H0_[jn0;jn_P2g]kL20;Rh^0050;jn
_P31`L40^[Zj0;Zj^P2[Zj/00P0`<3001013@d<0QXJ608J6QP2[Zj/20:n_[`040;Bd]02k^k/0^k^k
0;bl_080^k^k00@0];Bd0;2`/02`/;00/K6a0P2YZJT00`2MWId0M7Ad07AdM0030;:b/P<0Y:BT00@0
][Jf0;Ng]`2g]kL0^;Rh0P2l_;`01030`<00aLG50<G5a@3Bd]820=3@d00307IfM_oooooooooo00H0
003o00@0oh000000o`000?l0003o0P3oP0040000o`80oh002@000?l30?n00140003o0`3oP00B0000
o`030?n000000?l0003o00<0003o2P3oP0020000o`040?n000000?l0003o0?n00180003o00<0oh00
0000o`000?l04`3oP0000`000?l0oh000?n0000=0?n00080003o0`3oP0030000o`/0oh001@000?l3
0?n000<0003o303oP0000`000?ooooooooooo`08ooooo`002Oooool0102^[Zh0UIFE09FEU@1XJ6P2
07=cL`0405MGE`2`/;00/;2`0:j^[P80[:b/00@0ZZZZ0:FUY@2UYJD0YZJV0P2TY:@0102YZJT0QHF5
08F5Q@1mOGd209VIV@0409ZJVP2@T900T92@05aLG080Zj^[0`2^[Zh30:ZZZP040:^[Z`2RXZ80XZ:R
0:6QX@80UYJF00@0W9bL0:6QX@2QXJ40WYjN0P1hN7P01@0m?Cd0ZZZZ0:f][@2][Jd0Z:RX0080XJ6Q
00@0WYjN09bLW02LW9`0WIfM0P2RXZ80102QXJ40XZ:R0::RXP2RXZ820:2PX00407inOP0o?cl0?clo
09fMW@80Y:BT00@0ZJVY0:^[Z`2[Zj/0[Jf]0P2YZJT0102_[jl0[Zj^0:j^[P2`/;020:b/[0040:NW
Y`2][Jd0[Jf]075aL@80EeMG00D0MGEe06i^KP1^KVh0KVi^06YZJP0207MgM`0406i^KP1YJFT0JFUY
06=SH`80MWIf00@0RHV908B4Q024Q8@0Q8B40P1EEED01027QhL0/[:b0;:b/P2e]KD20;>c/`0409nO
W`2FUYH0UYJF0:n_[`<0/k>c0P2_[jl0102`/;00[Zj^0:j^[P2XZ:P203Hf=P0409BDU02YZJT0ZJVY
0:RXZ080/K6a00@0[jn_0;Ng]`2g]kL0^;Rh0P2e]KD20;Rh^080^[Zj00@0]KFe04I6AP16ATH0MWIf
0P2][Jd0102SXj<0T92@092@T02IVIT20:^[Z`040;6a/@2b/[80/[:b0;>c/`80[Zj^00@0[Jf]0:ZZ
ZP2ZZZX0ZJVY0P1bLW80102g]kL0];Bd0;Bd]02a/K420;2`/0040;Jf]P2b/[80/[:b0;Bd]080^k^k
00@0]kNg0;^k^`2k^k/0`/;20P30`<00101aLG7oooooooooo`3oP0050000o`@0oh004@000?l00`3o
P000003o0000o`020?n000l0003o0P3oP0000`000?l0oh000?n0000@0000o`030?n000000?l0003o
00@0003o0P3oP0000`000?l0oh000?n000030?n000<0003o00@0oh000000o`000?l0oh004P000?l0
0`3oP000003o0000o`040?n000<0003o2@3oP0000`000?l0oh000?n000040000o`l0oh000P000?l0
0`3oP000003o0000o`040000o`L0oh001@000?lB0?n000030000oooooooooooo00Sooooo0009oooo
o`040:b/[02JVYX0VYZJ07=cL`80Fe]K00@0IfMW0;Fe]@2e]KD0]KFe0P2ZZZX0102][Jd0/;2`0;2`
/02c/k<20;2`/0040:^[Z`1ZJVX0JVYZ07alO080[Zj^00@0ZZZZ08n?S`2?Shl0HF5Q1@2/[:`0102Z
ZZX0Z:RX0:RXZ02/[:`609VIV@80Shn?00@0TI6A06a/K01/K6`0?clo0`2`/;00102TY:@0Z:RX0:RX
Z02PX:020:RXZ0040:NWY`2[Zj/0Zj^[0:NWY`80X:2P00@0Xj>S0:2PX02PX:00OWin0P0_;bl0102M
WId0UiNG09NGU`2LW9`20:FUY@040:ZZZP2WYjL0YjNW0:VYZ@80[:b/00@0[jn_0:ZZZP2ZZZX0ZJVY
0P2^[Zh0101aLG40@d=304=3@`1UIFD206IVIP0506YZJP1[Jf/0JVYZ06YZJP1XJ6P00P1HF5P00`1?
Cdl0GUiN05iNGP0307EeM@0407=cL`18B4P0B4Q808>3P`80[jn_00@0/K6a0:j^[P2^[Zh0Xj>S0P2L
W9`0102MWId0/k>c0;>c/`2d];@20:b/[0040:n_[`2c/k<0/k>c0:n_[`80=cLg00<0TY:B0:ZZZP2Z
ZZX00`2/[:`0102b/[80][Jf0;Jf]P2l_;`20;Vi^@050<30`02k^k/0`<300<30`02f][H00P1BDU80
101mOGd0Zj^[0:^[Z`2UYJD209VIV@040:FUY@2/[:`0[:b/0;Bd]080/K6a00@0/[:b0;2`/02`/;00
[Zj^0P2/[:`00`2ZZZX0KFe]06e]K@030;6a/@040:n_[`2][Jd0[Jf]0;:b/P<0/k>c0P2f][H00`2e
]KD0^;Rh0;Rh^0030;Rh^00307AdM?oooooooooo00@0003o0P3oP00010000?l0oh000?n0003oP002
0000o`H0oh0010000?l20?n001L0003o1@3oP00@0000o`030?n000000?l0003o00X0003o0P3oP003
0000o`040?n000000?l0003o0?n000T0003o103oP0050000o`030?n000000?l0003o00@0oh001@00
0?l30?n000030000o`3oP000oh0000@0oh001P000?l=0?n000T0003o1`3oP0050000oa80oh0000<0
003oooooooooool02?ooool000Wooooo00@0[:b/09ZJVP2JVYX0Lg=c0P1KFe/0101WIfL0]KFe0;Fe
]@2e]KD20:ZZZP040:f][@2`/;00/;2`0;>c/`80/;2`00@0Zj^[06YZJP1ZJVX0O7al0P2^[Zh0102Z
ZZX0Shn?08n?S`1QHF450:b/[0040:ZZZP2XZ:P0Z:RX0:b/[0H0VIVI0P2?Shl0102ATI40K6a/06a/
K00o?cl30;2`/0040:BTY02XZ:P0Z:RX0:2PX080Z:RX00@0YjNW0:^[Z`2[Zj/0YjNW0P2PX:00102S
Xj<0X:2P0:2PX01nOWh202l_;`0409fMW@2GUiL0UiNG09bLW080YJFU00@0ZZZZ0:NWY`2WYjL0ZJVY
0P2/[:`0102_[jl0ZZZZ0:ZZZP2YZJT20:j^[P04075aL@13@d<0@d=306EUI@80IVIV00D0JVYZ06][
J`1ZJVX0JVYZ06QXJ00205QHF00304m?C`1NGUh0GUiN00<0MGEe00@0Lg=c04Q8B018B4P0Ph>30P2_
[jl0102a/K40[Zj^0:j^[P2SXj<209bLW00409fMW@2c/k<0/k>c0;Bd]080[:b/00@0[jn_0;>c/`2c
/k<0[jn_0P0g=cL00`2BTY80ZZZZ0:ZZZP030:b/[0040;:b/P2f][H0][Jf0;bl_080^KVi00D0`<30
0;^k^`30`<00`<300;Jf]P02059BDP0407emO@2[Zj/0Zj^[0:FUY@80VIVI00@0YJFU0:b/[02/[:`0
];Bd0P2a/K40102b/[80/;2`0;2`/02^[Zh20:b/[0030:ZZZP1]KFd0KFe]00<0/K6a00@0[jn_0:f]
[@2][Jd0/[:b0`2c/k<20;Jf]P030;Fe]@2h^;P0^;Rh00<0^;Rh00<0M7Adooooooooool010000?l2
0?n000040000o`3oP000oh000?n00080003o1P3oP0040000o`80oh005`000?l50?n00100003o00<0
oh000000o`000?l02P000?l20?n000<0003o00@0oh000000o`000?l0oh002@000?l40?n000D0003o
00<0oh000000o`000?l0103oP0050000o`<0oh0000<0003o0?n0003oP000103oP0060000o`d0oh00
2@000?l70?n000D0003o4P3oP0000`000?ooooooooooo`08ooooo`002Oooool0102ATI40R8R808R8
R01/K6`204i>CP0404m?C`2;Rh/0Rh^;08F5Q@80Lg=c00@0MgMg08:2PP22PX80MGEe0P1gMgL0101o
Ogl0G5aL05aLG01WIfL20861P@0408J6QP1UIFD0IFEU04a<C080PH6100@0MGEe07MgM`1gMgL0OWin
0P26QXH01028R8P0Ph>308>3P`25QHD206QXJ004079bLP1QHF40HF5Q069RHP80B4Q800D0@41008^;
R`2ATI40TI6A092@T00208^;R`0408B4Q01mOGd0OGem07UiN@80LW9b00@0R8R807AdM01dM7@0LG5a
0P1/K6`0101NGUh0;bl_02l_;`1mOGd207]kN`04075aL@21PH40PH6108>3P`80R8R800@0QXJ607em
O@1mOGd0N7Qh0P1bLW80101aLG40L71`071`L01=CDd2034a<@05030`<00];Bd0;Bd]03Hf=P0g=cL0
0P14A4@0100n?Sh0@4100410@010@40204a<C00404E5A@1DE5@0E5AD04i>CP80B4Q800@0OWin096A
T@2ATI40Shn?0P2EUID01025QHD0QhN708N7Q`1nOWh208f=S@0408Z:RP2;Rh/0Rh^;08b<S080Ti>C
00@0QHF503Ph>00h>3P0F5QH0P22PX801026QXH0RHV908V9R@1nOWh207emO@040861P@20P800P820
07moO`<0LG5a00@0MgMg03Ti>@0i>CT0H61P0P2JVYX0102VYZH0Y:BT0:BTY02SXj<20:RXZ0040:j^
[P2][Jd0[Jf]0:VYZ@80Xj>S00@0[:b/09jNWP2NWYh0Ng]k0P1SHf<0102ATI40UYJF09JFUP2DU9@2
092@T00409>CT`2IVIT0VIVI09^KV`80WIfM00@0Y:BT0:VYZ@2YZJT0YJFU0P2HV9P00`1DE5Cooooo
ooooo`040000o`<0oh0030000?l20?n000H0003o00<0oh000000o`000?l040000?l30?n00140003o
0`3oP00B0000oaH0oh004`000?l30?n00140003o00<0oh000000o`000?l01`000?l30?n001/0003o
00<0oh00ooooooooool02?ooool000Wooooo00@0@D510492@P12@T80GUiN0P1VIVH0101]KFd0IVIV
06IVIP1MGEd203Hf=P0404U9B@1IFET0FEUI051@D080EEEE00@0FEUI055AD@1ADE4092@T0P0g=cL0
101GEeL0DE5A055AD@1PH602069RHP04065QH@16ATH0ATI60410@080=cLg00@0AdM705=CD`1CDe<0
E5AD0P1?Cdl0100[:b/08b<S02<S8`0h>3P204I6AP05051@D01=CDd0<C4a034a<@0Q8B400P0h>3P0
1015ADD0C4a<04a<C01ADE4205MGE`0404A4A00a<C40<C4a03hn?P80Hf=S00@0JFUY06YZJP1ZJVX0
Fe]K0P1NGUh0100V9RH07AdM01dM7@1=CDd2059BDP04055AD@1>CTh0CTi>059BDP80;2`/00@0?Shn
04i>CP1>CTh0FUYJ0P1RHV801@1LG5`0DE5A055AD@0Y:BT0?Shn0080F5QH00@0D51@05QHF01HF5P0
HV9R0P0o?cl0100W9bL0De=C05=CD`1WIfL206QXJ004065QH@1OGel0GemO05mOG`80=SHf00@0G5aL
06IVIP1VIVH0EeMG0P1LG5`0101NGUh0E5AD05ADE00V9RH204U9B@<0HV9R00@0IFEU05iNGP1NGUh0
AdM70P15ADD0101RHV80I6AT06ATI01RHV8205=CD`0505iNGP0i>CT0EEEE05EEE@1MGEd00P1IFET0
1016ATH0B4Q804Q8B00g=cL202TY:@04034a<@0j>SX0>SXj030`<080>3Ph00@0=SHf02XZ:P0Z:RX0
:b/[0P0g=cL01011@D40>CTi03Ti>@11@D4203Xj>P0402@T900_;bl0;bl_03dm?@80@T9200@0CTi>
04U9B@19BDT0@D510P0c<c<0101=CDd0C4a<04a<C018B4P2ooooo`@0oh001@000?lB0?n000@0003o
8P3oP0040000oa@0oh0000<0003o0?n0003oP000203oP0020000o`@0oh0020000?l30?n000030000
o`3oP000oh0000L0oh0010000?l50?n000@0003o<@3oP00:ooooo`002Oooool01011@D40@T920492
@P1NGUh206IVIP0406e]K@1VIVH0IVIV05eMG@80=SHf00@0BDU905UIF@1IFET0D51@0P1EEED0101I
FET0DE5A055AD@0T92@203Lg=`0405MGE`1ADE40DE5A061PH080HV9R00@0HF5Q04I6AP16ATH0@410
0P0g=cL01017AdL0De=C05=CD`1DE5@204m?C`0402/[:`0S8b<08b<S03Ph>080ATI600D0D51@04e=
C@0a<C40<C4a024Q8@0203Ph>00404E5A@1<C4`0C4a<055AD@80EeMG00@0A4A4034a<@0a<C40?Shn
0P1SHf<0101YJFT0JVYZ06YZJP1KFe/205iNGP0402HV9P0M7Ad07AdM04e=C@80DU9B00@0DE5A04i>
CP1>CTh0DU9B0P0/;2`0100n?Sh0CTi>04i>CP1JFUX2069RHP0505aLG01ADE40DE5A02TY:@0n?Sh0
0P1HF5P0101@D500F5QH05QHF01RHV8203lo?`0402LW9`1CDe<0De=C06MWI`80J6QX00@0HF5Q05mO
G`1OGel0GemO0P0f=SH0101LG5`0IVIV06IVIP1GEeL205aLG00405iNGP1DE5@0E5AD02HV9P80BDU9
0`1RHV80101UIFD0GUiN05iNGP17AdL204E5A@04069RHP1TI6@0I6AT069RHP80De=C00D0GUiN03Ti
>@1EEED0EEEE05eMG@0205UIF@0404I6AP18B4P0B4Q803Lg=`80:BTY00@0<C4a03Xj>P0j>SX0<30`
0P0h>3P0100f=SH0:RXZ02XZ:P0[:b/203Lg=`040451@@0i>CT0>CTi0451@@80>SXj00@092@T02l_
;`0_;bl0?Cdm0P12@T80101>CTh0BDU904U9B@11@D4203<c<`0404e=C@1<C4`0C4a<04Q8B0;ooooo
103oP0050000oa80oh0010000?lR0?n000@0003o503oP0000`000?l0oh000?n000080?n00080003o
103oP0080000o`<0oh0000<0003o0?n0003oP0001`3oP0040000o`D0oh0010000?la0?n000[ooooo
0009ooooo`0407YjNP1KFe/0Fe]K0:BTY080YJFU00@0ZZZZ0;6a/@2a/K40]kNg0P1NGUh0101kNg/0
TI6A096AT@28R8P209RHV0040:6QX@2GUiL0UiNG02XZ:P80CDe=00@0U9BD09VIV@2IVIT0Ti>C0P2L
W9`0102YZJT0Cdm?04m?C`1SHf<209JFUP0409ZJVP2DU9@0U9BD08f=S@80O7al0`0k>c/01@1QHF40
Lg=c07=cL`1GEeL0N7Qh0080TY:B00@0?Cdm07]kN`1kNg/0Xj>S0P2PX:00102SXj<0[Zj^0:j^[P2=
SHd20410@00406UYJ@2?Shl0Shn?09^KV`80WYjN00@0TI6A09:BTP2BTY80>CTi0P1ZJVX0102/[:`0
Xj>S0:>SX`28R8P208F5Q@0409jNWP1:BTX0BTY:06i^KP80Zj^[00@0XZ:R0:JVYP2VYZH0WIfM0P2R
XZ801@19BDT0SXj>0:n_[`2_[jl0/K6a0080]KFe00@0_Kfm0:NWY`2WYjL09RHV0P2@T900102a/K40
];Bd0;Bd]02f][H20;Rh^0040;jn_P0j>SX0>SXj0:>SX`80`L7100@0^KVi0;6a/@2a/K40[Zj^0P2O
Wil0100_;bl0PX:208:2PP28R8P209:BTP0409RHV02@T900T92@07EeM@80N7Qh00@0[jn_0:j^[P2^
[Zh0[:b/0P2_[jl01@2g]kL0GEeM09JFUP2FUYH0X:2P0080YJFU00@0ZZZZ0:VYZ@2YZJT0M7Ad0P0V
9RH0102JVYX0aLG50<G5a@31`L420;bl_0040:n_[`1KFe/0Fe]K03lo?`<0Z:RX0P2WYjL0102SXj<0
V9RH09RHV01<C4`206QXJ00408j>SP2^[Zh0[Zj^0:j^[P80][Jf00@0X:2P0451@@11@D40/;2`0`2h
^;P2ooooo`030000o`3oP000oh0000@0003o1@3oP0090000o`<0oh001`000?l00`3oP000003o0000
o`070000o`<0oh000`000?l20?n000<0003o00<0oh000000o`000?l010000?l20?n000030000o`3o
P000003o00P0003o0P3oP0090000o`030?n000000?l0003o00L0003o0P3oP0000`000?l0oh000?n0
00040?n000040000o`3oP000oh000000o`T0oh000P000?l60?n000030000o`3oP000oh0000X0003o
0`3oP0000`000?l0oh000?n000030?n000T0003o00<0oh000000o`000?l0203oP0080000o`040?n0
00000?l0003o0000o`D0oh0000<0003o0?n0003oP000103oP00:ooooo`002Oooool0102;Rh/0KVi^
06i^KP2PX:020:FUY@040:RXZ02e]KD0]KFe0;^k^`80Hf=S00@0FUYJ0:>SX`2SXj<0Shn?0P2OWil0
102XZ:P0/;2`0;2`/019BDT205=CD`0408j>SP2EUID0UIFE092@T080SHf=00@0V9RH05YJFP1JFUX0
HF5Q0P2KVi/0102JVYX0SXj>08j>SP1mOGd207=cL`0403Xj>P0i>CT0>CTi05eMG@80OWin00D0I6AT
07MgM`26QXH0QXJ604a<C00207QhN00409FEU@2IVIT0VIVI09FEU@80Z:RX00@0T92@04a<C01<C4`0
Kfm_0P2KVi/0102XZ:P0X:2P0:2PX02JVYX209bLW00404i>CP1bLW80LW9b0:n_[`80ZZZZ00@0X:2P
09jNWP2NWYh0Vi^K0P1;Bd/0101^KVh0ZZZZ0:ZZZP2XZ:P20:JVYP0509^KV`2MWId0WIfM04U9B@2F
UYH00P2h^;P0102f][H0^KVi0;Vi^@2n_[h20;Jf]P0405=CD`2NWYh0WYjN0;6a/@80[:b/00@0/;2`
0;Zj^P2j^[X0^k^k0P0m?Cd0102YZJT0_kno0;no_`2l_;`20;Fe]@040;:b/P2IVIT0VIVI038b<P80
OGem00@0SHf=08n?S`2?Shl0TI6A0P21PH40101RHV80JVYZ06YZJP2^[Zh20;>c/`050;Ng]`31`L40
`L710<30`01EEED00P26QXH0102OWil0XZ:R0::RXP2UYJD20:2PX004079bLP0h>3P0>3Ph0;Fe]@80
][Jf00@0]kNg0;Fe]@2e]KD0]kNg0P1TI6@0101eMGD0[jn_0:n_[`2WYjL20:VYZ@040:f][@2WYjL0
YjNW04M7A`80NWYj00@0VIVI0::RXP2RXZ80YZJV0P2_[jl0102b/[80Cdm?04m?C`2c/k<30;Rh^0;o
oooo1`000?l30?n00080003o00<0oh000000o`000?l010000?l50?n000L0003o00<0oh000000o`00
0?l01`000?l50?n000H0003o00<0oh000000o`000?l01`000?l00`3oP000003o0000o`070000o`80
oh0000<0003o0?n0003oP0001P000?l00`3oP000003o0000o`070000o`80oh0000<0003o0?n0003o
P0001`3oP00010000?l0oh000?n000000?l60?n00080003o1P3oP0000`000?l0oh000?n0000:0000
o`T0oh002@000?l80?n000<0003o0P3oP0030000o`040?n000000?l0003o0?n000H0003o2@3oP00:
ooooo`002Oooool0102?Shl0MgMg07MgM`2ZZZX20:JVYP040;6a/@2n_[h0_[jn0;no_`80FUYJ00@0
Lg=c0:RXZ02XZ:P0SXj>0P2WYjL0102d];@0[Jf]0:f][@14A4@206UYJ@0409bLW02@T900T92@08f=
S@80SXj>00@0XJ6Q059BDP1BDU80IVIV0P2?Shl0101oOgl0Kfm_06m_K`1]KFd2065QH@0403@d=00i
>CT0>CTi055AD@80FEUI00D0Fe]K065QH@1eMGD0MGEe03hn?P0207]kN`0409^KV`2QXJ40XJ6Q0:NW
Y`80Z:RX00@0UiNG04M7A`17AdL0NWYj0P2OWil0102GUiL0U9BD09BDU027QhL209>CT`04059BDP1j
NWX0NWYj0:f][@80Z:RX00@0W9bL09:BTP2BTY80WIfM0P1:BTX0101bLW80XZ:R0::RXP2UYJD20:BT
Y0050:NWY`2GUiL0UiNG03lo?`2HV9P00P2h^;P30;Ng]`040;Rh^02b/[80/[:b04e=C@80VIVI00@0
ZJVY0:NWY`2WYjL0ZZZZ0P2c/k<0102i^KT0>c/k03/k>`2XZ:P20;fm_@040;Zj^P2h^;P0^;Rh0;Vi
^@80Y:BT00@0=cLg0820P020P800R8R80P1oOgl0101kNg/0QXJ608J6QP1XJ6P2079bLP040;:b/P2h
^;P0^;Rh0;Vi^@80`<3000D0^k^k05QHF02NWYh0WYjN0:VYZ@020:NWY`040:JVYP2QXJ40XJ6Q06][
J`80Bd];00@0]KFe0;:b/P2b/[80[jn_0P2d];@0102c/k<0L71`071`L01fMWH20;2`/0<0ZZZZ00@0
/K6a0:f][@2][Jd0?3`l0P1lO7`0102FUYH0YJFU0:FUY@2UYJD209^KV`0406IVIP19BDT0BDU90;:b
/P80^[Zj00<0]kNgooooooooool01P000?l60?n000H0003o103oP0090000o`030?n000000?l0003o
00L0003o203oP0030000o`030?n000000?l0003o00L0003o00<0oh000000o`000?l01`000?l20?n0
00030000o`3oP000oh0000H0003o00<0oh000000o`000?l01`000?l20?n000030000o`3oP000oh00
00L0oh001P000?l40?n00080003o1P3oP0000`000?l0oh000?n0000:0000o`T0oh002@000?l80?n0
00<0003o0P3oP0030000o`@0oh002@000?l60?n000[ooooo0009ooooo`0408n?S`1gMgL0MgMg0:ZZ
ZP80YZJV00@0/K6a0;jn_P2n_[h0_kno0P1JFUX0101cLg<0Z:RX0:RXZ02>SXh20:NWY`040;Bd]02]
[Jd0[Jf]04A4A080JFUY00@0W9bL092@T02@T900SHf=0P2>SXh0102QXJ40DU9B059BDP1VIVH208n?
S`0407moO`1_Kfl0Kfm_06e]K@80HF5Q00@0=3@d03Ti>@0i>CT0DE5A0P1IFET01@1KFe/0HF5Q07Ee
M@1eMGD0?Shn0080Ng]k00@0Vi^K0:6QX@2QXJ40YjNW0P2XZ:P0102GUiL0AdM704M7A`1jNWX209nO
W`0409NGU`2DU9@0U9BD08N7Q`80Ti>C00@0DU9B07YjNP1jNWX0[Jf]0P2XZ:P0102LW9`0TY:B09:B
TP2MWId204Y:BP04079bLP2RXZ80XZ:R0:FUY@80Y:BT00D0YjNW09NGU`2GUiL0?clo09RHV0020;Rh
^0<0]kNg00@0^;Rh0;:b/P2b/[80CDe=0P2IVIT0102YZJT0YjNW0:NWY`2ZZZX20;>c/`040;Vi^@0k
>c/0>c/k0:RXZ080_Kfm00@0^[Zj0;Rh^02h^;P0^KVi0P2TY:@0100g=cL0P8200820P028R8P207mo
O`0407]kN`26QXH0QXJ606QXJ080LW9b00@0/[:b0;Rh^02h^;P0^KVi0P30`<001@2k^k/0F5QH09jN
WP2NWYh0ZJVY0080YjNW00@0YZJV0:6QX@2QXJ40Jf][0P1;Bd/0102e]KD0/[:b0;:b/P2_[jl20;Bd
]0040;>c/`1`L700L71`07IfMP80/;2`0`2ZZZX0102a/K40[Jf]0:f][@0l?3`207alO00409JFUP2U
YJD0YJFU0:FUY@80Vi^K00@0IVIV04U9B@19BDT0/[:b0P2j^[X00`2g]kOoooooooooo`060000o`H0
oh001P000?l40?n000T0003o00<0oh000000o`000?l01`000?l80?n000<0003o00<0oh000000o`00
0?l01`000?l00`3oP000003o0000o`070000o`80oh0000<0003o0?n0003oP0001P000?l00`3oP000
003o0000o`070000o`80oh0000<0003o0?n0003oP0001`3oP0060000o`@0oh000P000?l60?n00003
0000o`3oP000oh0000X0003o2@3oP0090000o`P0oh000`000?l20?n000<0003o103oP0090000o`H0
oh002_ooool000Wooooo00@0SHf=069RHP1RHV80W9bL0`2PX:020:FUY@0409bLW01?Cdl0Cdm?04A4
A080QXJ600@0V9RH0:j^[P2^[Zh0/K6a0P2QXJ40100d=3@0G5aL05aLG02QXJ4209:BTP04092@T02=
SHd0SHf=09VIV@80AdM700@0;2`/08R8R028R8P0RXZ:0P1eMGD0101lO7`0OGem07emO@1>CTh205UI
F@0507MgM`1eMGD0MGEe06EUI@1LG5`00P20P800101;Bd/0QHF508F5Q@2JVYX20:^[Z`040;:b/P2Y
ZJT0ZJVY0:2PX080@d=300@0H61P0:NWY`2WYjL0WinO0P2@T9001022PX80R8R808R8R01DE5@2071`
L00409VIV@2MWId0WIfM09:BTP80QXJ600@0MgMg04=3@`13@d<0M7Ad0P2MWId01027QhL0PX:208:2
PP2HV9P209^KV`0306IVIP2KVi/0/[:b0080/[:b0P2e]KD0102[Zj/0SHf=08f=S@12@T8209VIV@04
0:>SX`2ZZZX0ZZZZ0;6a/@<0^;Rh0P1<C4`0102SXj<0]KFe0;Fe]@2`/;020:RXZ0040:BTY02@T900
T92@038b<P80Bd];00<0GUiN06a/K01/K6`00`23Ph<0101LG5`0EUIF05IFEP2<S8`209NGU`0509JF
UP2HV9P0V9RH0::RXP2ATI400P2][Jd0102b/[80/K6a0;6a/@2[Zj/20:JVYP04079bLP1TI6@0I6AT
0;Jf]P<0];Bd0P2i^KT0102k^k/0LW9b079bLP23Ph<20;2`/0040:^[Z`2/[:`0[:b/0;2`/080[Zj^
00@0ATI607]kN`1kNg/0[Zj^0P2XZ:P0102PX:00TY:B09:BTP1mOGd2059BDP040;:b/P2c/k<0/k>c
0;Bd]0;ooooo2P000?l30?n000<0003o0`3oP0020000o`<0oh001`000?l30?n000L0003o0`3oP005
0000o`040?n000000?l0003o0?n000D0003o00D0oh000000o`000?l0003o0?n000090000o`80oh00
2@000?l00`3oP000003o0000o`0:0000o`@0oh000`000?l20?n000@0003o1P3oP0020000o`<0oh00
10000?l40?n000D0003o0`3oP0090000o`@0oh001P000?l70?n000<0003o0P3oP0030000o`@0oh00
0P000?l00`3oP000003o0000o`040000o`H0oh002_ooool000Wooooo00@0JFUY05QHF01HF5P0D51@
0P0o?cl0100b<S80=3@d03@d=00e=CD203<c<`0403/k>`19BDT0BDU904m?C`80CTi>00@0De=C051@
D01@D500Bd];0P1EEED0101FEUH0?clo03lo?`0i>CT204Q8B00404e=C@1ADE40DE5A04];B`80D51@
00@0De=C05YJFP1JFUX0DE5A0P16ATH0100j>SX0<S8b038b<P0n?Sh202@T900502XZ:P1<C4`0A4A4
04A4A00j>SX00P1;Bd/0101>CTh0JFUY06UYJ@1[Jf/206m_K`04069RHP1CDe<0De=C05mOG`80F5QH
00@0;Bd]05=CD`1CDe<0FUYJ0P15ADD01018B4P0AdM704M7A`1XJ6P2079bLP0407QhN01@D500D51@
05QHF080EeMG00@0BTY:03Ph>00h>3P092@T0P1<C4`01@1IFET0GUiN05iNGP1HF5P0Fe]K0080IVIV
0`1WIfL0101JFUX0De=C05=CD`19BDT204];B`0404M7A`0_;bl0;bl_04];B`80FUYJ00@0HV9R05UI
F@1IFET0KFe]0P1aLG40101XJ6P0IVIV06IVIP1TI6@205YJFP0405UIF@1DE5@0E5AD0451@@80=cLg
00@0Bd];05MGE`1GEeL0@T920P15ADD0101FEUH0FUYJ05YJFP1@D50205QHF00506i^KP1oOgl0NGUi
07UiN@1^KVh00P12@T80101GEeL0IFEU06EUI@1QHF4206IVIP0408>3P`24Q8@0Q8B407inOP<0O7al
0P1HF5P0101NGUh0G5aL05aLG01BDU8205MGE`04069RHP1MGEd0GEeM04];B`80GEeM00@0HV9R05eM
G@1MGEd0EUIF0P1DE5@01012@T80>c/k03/k>`1=CDd205=CD`0405IFE_oooooooooo0000ocL0oh00
1P000?l00`3oP000003o0000o`0:0?n000D0003o403oP0040000o``0oh000P000?l00`3oP000003o
0000o`060000oa<0oh001P000?l30?n000/0003o203oP0000`000?l0oh000?n000030?n000030000
o`3oP000oh0000X0oh002_ooool000Wooooo00@0JFUY05QHF01HF5P0D51@0P0o?cl0100b<S80=3@d
03@d=00e=CD203<c<`0403/k>`19BDT0BDU904m?C`80CTi>00@0De=C051@D01@D500Bd];0P1EEED0
101FEUH0?clo03lo?`0i>CT204Q8B00404e=C@1ADE40DE5A04];B`80D51@00@0De=C05YJFP1JFUX0
DE5A0P16ATH0100j>SX0<S8b038b<P0n?Sh202@T900502XZ:P1<C4`0A4A404A4A00j>SX00P1;Bd/0
101>CTh0JFUY06UYJ@1[Jf/206m_K`04069RHP1CDe<0De=C05mOG`80F5QH00@0;Bd]05=CD`1CDe<0
FUYJ0P15ADD01018B4P0AdM704M7A`1XJ6P2079bLP0407QhN01@D500D51@05QHF080EeMG00@0BTY:
03Ph>00h>3P092@T0P1<C4`01@1IFET0GUiN05iNGP1HF5P0Fe]K0080IVIV0`1WIfL0101JFUX0De=C
05=CD`19BDT204];B`0404M7A`0_;bl0;bl_04];B`80FUYJ00@0HV9R05UIF@1IFET0KFe]0P1aLG40
101XJ6P0IVIV06IVIP1TI6@205YJFP0405UIF@1DE5@0E5AD0451@@80=cLg00@0Bd];05MGE`1GEeL0
@T920P15ADD0101FEUH0FUYJ05YJFP1@D50205QHF00506i^KP1oOgl0NGUi07UiN@1^KVh00P12@T80
101GEeL0IFEU06EUI@1QHF4206IVIP0408>3P`24Q8@0Q8B407inOP<0O7al0P1HF5P0101NGUh0G5aL
05aLG01BDU8205MGE`04069RHP1MGEd0GEeM04];B`80GEeM00@0HV9R05eMG@1MGEd0EUIF0P1DE5@0
1012@T80>c/k03/k>`1=CDd205=CD`0405IFE_oooooooooo0000ocL0oh001P000?l00`3oP000003o
0000o`0:0?n000D0003o403oP0040000o``0oh000P000?l00`3oP000003o0000o`060000oa<0oh00
1P000?l30?n000/0003o203oP0000`000?l0oh000?n000030?n000030000o`3oP000oh0000X0oh00
2_ooool000Wooooo00@0ZZZZ0:NWY`2WYjL0WIfM0P1^KVh0100g=cL0Rh^;08^;R`2LW9`20:2PX0@0
YjNW0P2/[:`30:j^[P040:ZZZP2/[:`0[:b/0:RXZ080MWIf00@0Hf=S092@T02@T900S8b<0P2LW9`0
1023Ph<0Q8B408B4Q02JVYX209fMW@0409FEU@2=SHd0SHf=07QhN080Rh^;00D0SHf=065QH@1QHF40
HV9R0:6QX@020:JVYP040:NWY`2UYJD0YJFU0::RXP80YZJV00<0Zj^[0:j^[P2^[Zh0102a/K420;:b
/P0404a<C02CTi<0Ti>C0:RXZ0<0WinO0P2IVIT0102[Zj/0[Zj^0:j^[P2/[:`20:JVYP040::RXP2Z
ZZX0ZZZZ0:2PX080Y:BT00@0?3`l0:JVYP2VYZH0ZZZZ0P2_[jl01@2XZ:P0YJFU0:FUY@2UYJD0[:b/
0080Zj^[00@0[Zj^0;2`/02`/;00/K6a0`2b/[820492@P0409nOW`2XZ:P0Z:RX0;:b/P80[jn_00@0
/K6a0;Rh^02h^;P0/K6a0P2b/[80102/[:`0YJFU0:FUY@2XZ:P20:b/[00409bLW025QHD0QHF50;Bd
]080^;Rh00@0ZZZZ0:FUY@2UYJD0/K6a0P2^[Zh01@2f][H0/k>c0;>c/`2l_;`0^[Zj0080/K6a00@0
[Zj^05IFEP1FEUH0Zj^[0P2c/k<0102i^KT0]kNg0;Ng]`2j^[X20;^k^`040;Zj^P2h^;P0^;Rh0;6a
/@80YjNW00@0Y:BT0:j^[P2^[Zh0L71`0P1TI6@0102=SHd0UiNG09NGU`2RXZ820:b/[0040;2`/02^
[Zh0[Zj^0:j^[P80/[:b00@0/K6a0;>c/`2c/k<0]kNg0P2^[Zh00`1QHF7oooooooooo`060000o`03
0?n000000?l0003o00T0003o0`3oP00V0000o`T0oh002@000?l00`3oP000003o0000o`070000o`80
oh000`000?l00`3oP000003o0000o`050000o`T0oh000`000?l90?n000T0003o0`3oP0030000o`d0
oh000P000?l;0?n000<0003o0P3oP0090000o``0oh0000<0003oooooooooool02?ooool000Wooooo
00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH0101QHF40Z:RX0:RXZ02NWYh208Z:RP0409RHV02PX:00X:2P
09fMW@80WYjN00@0XJ6Q0:BTY02TY:@0WinO0P2TY:@0102SXj<0R8R808R8R01XJ6P209VIV@0409ZJ
VP2RXZ80XZ:R08b<S080RHV900@0Shn?09ZJVP2JVYX0Shn?0P2>SXh0102=SHd0UiNG09NGU`2ATI42
06QXJ00508B4Q02TY:@0ZJVY0:VYZ@2UYJD00P2QXJ40102NWYh0W9bL09bLW02MWId209nOW`040:>S
X`2VYZH0YZJV0:ZZZP80/[:b00@0J6QX09VIV@2IVIT0ZJVY0P2NWYh0102GUiL0SHf=08f=S@2VYZH2
0:ZZZP040:NWY`2YZJT0ZJVY09VIV@80YZJV00@0XJ6Q0:BTY02TY:@0GemO0P2PX:001@2TY:@0YZJV
0:JVYP2TY:@0T92@0080VYZJ00@0Y:BT0::RXP2RXZ80YJFU0P2VYZH0102ZZZX0[Jf]0:f][@2][Jd2
03lo?`040:BTY02XZ:P0Z:RX0:j^[P80/[:b00@0/K6a0:f][@2][Jd0Y:BT0P2OWil0102ZZZX0[Jf]
0:f][@2b/[820;6a/@030:2PX026QXH0QXJ600<0^;Rh00@0[Jf]0:^[Z`2[Zj/0^[Zj0P2e]KD01@2l
_;`0]kNg0;Ng]`31`L40_kno0080^KVi00@0/k>c05iNGP1NGUh0[Zj^0P2d];@0102f][H0_[jn0;jn
_P2m_Kd30<30`080_[jn00@0/[:b0:JVYP2VYZH0YjNW0P2e]KD0101fMWH0N7Qh07QhN02XZ:P20:^[
Z`040:RXZ02[Zj/0Zj^[0:f][@80YjNW00@0ZJVY0:NWY`2WYjL0YjNW0P2ZZZX0102[Zj/0[Jf]0:f]
[@1VIVH2oooood40003o00<0oh000000o`000?l09@000?l40?n000<0003o1P3oP0050000o`@0oh00
0`000?l40?n00080003o6P3oP0030000o`80oh002@000?l00`3oP000003o0000o`070000o`80oh00
00<0003oooooooooool02?ooool000Wooooo00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH0101QHF40Z:RX
0:RXZ02NWYh208Z:RP0409RHV02PX:00X:2P09fMW@80WYjN00@0XJ6Q0:BTY02TY:@0WinO0P2TY:@0
102SXj<0R8R808R8R01XJ6P209VIV@0409ZJVP2RXZ80XZ:R08b<S080RHV900@0Shn?09ZJVP2JVYX0
Shn?0P2>SXh0102=SHd0UiNG09NGU`2ATI4206QXJ00508B4Q02TY:@0ZJVY0:VYZ@2UYJD00P2QXJ40
102NWYh0W9bL09bLW02MWId209nOW`040:>SX`2VYZH0YZJV0:ZZZP80/[:b00@0J6QX09VIV@2IVIT0
ZJVY0P2NWYh0102GUiL0SHf=08f=S@2VYZH20:ZZZP040:NWY`2YZJT0ZJVY09VIV@80YZJV00@0XJ6Q
0:BTY02TY:@0GemO0P2PX:001@2TY:@0YZJV0:JVYP2TY:@0T92@0080VYZJ00@0Y:BT0::RXP2RXZ80
YJFU0P2VYZH0102ZZZX0[Jf]0:f][@2][Jd203lo?`040:BTY02XZ:P0Z:RX0:j^[P80/[:b00@0/K6a
0:f][@2][Jd0Y:BT0P2OWil0102ZZZX0[Jf]0:f][@2b/[820;6a/@030:2PX026QXH0QXJ600<0^;Rh
00@0[Jf]0:^[Z`2[Zj/0^[Zj0P2e]KD01@2l_;`0]kNg0;Ng]`31`L40_kno0080^KVi00@0/k>c05iN
GP1NGUh0[Zj^0P2d];@0102f][H0_[jn0;jn_P2m_Kd30<30`080_[jn00@0/[:b0:JVYP2VYZH0YjNW
0P2e]KD0101fMWH0N7Qh07QhN02XZ:P20:^[Z`040:RXZ02[Zj/0Zj^[0:f][@80YjNW00@0ZJVY0:NW
Y`2WYjL0YjNW0P2ZZZX0102[Zj/0[Jf]0:f][@1VIVH2oooood40003o00<0oh000000o`000?l09@00
0?l40?n000<0003o1P3oP0050000o`@0oh000`000?l40?n00080003o6P3oP0030000o`80oh002@00
0?l00`3oP000003o0000o`070000o`80oh0000<0003oooooooooool02?ooool000Wooooo00@0[jn_
0:VYZ@2YZJT0[:b/0P1MGEd01017AdL0YJFU0:FUY@2OWil208f=S@04096AT@2RXZ80XZ:R0:JVYP80
YjNW00@0Y:BT0:2PX02PX:00WYjN0P2WYjL0102TY:@0S8b<08b<S01UIFD20:6QX@040::RXP2UYJD0
YJFU09nOW`80VYZJ0`2<S8`0102IVIT0PX:208:2PP1hN7P208N7Q`0508f=S@1YJFT0JFUY08B4Q02S
Xj<00P2KVi/0102QXJ40WYjN09jNWP2IVIT208J6QP0408V9R@2KVi/0Vi^K09nOW`80Vi^K00@0YZJV
0:b/[02/[:`0JVYZ0P2LW9`0102XZ:P0Xj>S0:>SX`2SXj<2096AT@040::RXP2QXJ40XJ6Q0:FUY@80
Zj^[00@0XZ:R0:FUY@2UYJD0Xj>S0P2MWId0101MGEd0XZ:R0::RXP2MWId309ZJVP0409BDU02JVYX0
VYZJ09NGU`80SHf=00@0X:2P0:BTY02TY:@0YZJV0P2XZ:P0102][Jd0CTi>04i>CP2TY:@20::RXP04
0:BTY02][Jd0[Jf]0:b/[080[Zj^00@0YJFU0::RXP2RXZ80[jn_0P2`/;030:f][@040:2PX024Q8@0
Q8B40;Rh^080_;bl00<0/[:b0:j^[P2^[Zh00`2f][H01@2n_[h0^k^k0;^k^`32`/80_Kfm0080_;bl
00<0]kNg06m_K`1_Kfl00`2b/[80102k^k/0`/;20<;2`P2l_;`20;jn_P040;fm_@2k^k/0^k^k0:^[
Z`80XJ6Q00@0ZJVY0;>c/`2c/k<0J6QX0P1aLG40102PX:00YZJV0:JVYP2ZZZX20:VYZ@040:JVYP2N
WYh0WYjN09fMW@80X:2P00@0XJ6Q0:RXZ02XZ:P0Xj>S0P2XZ:P0101gMgOoooooooooo`3oP0030000
o`<0oh00D0000?l20?n00140003o0`3oP0050000o`040?n000000?l0003o0?n000<0003o1P3oP003
0000oa80oh0000<0003o0?n0003oP0002P3oP0040000o`80oh005P000?l:ooooo`002Oooool30;Rh
^0040;Jf]P1bLW80LW9b0451@@80WIfM00@0Xj>S0:2PX02PX:00Xj>S0P2MWId0102OWil0YJFU0:FU
Y@2XZ:P20:j^[P040:b/[02WYjL0YjNW0:6QX@80Q8B400@0Hf=S09>CT`2CTi<0XJ6Q0P2VYZH0102T
Y:@0XJ6Q0:6QX@2OWil209fMW@0409ZJVP29RHT0RHV907EeM@80Ng]k00D0VIVI06EUI@1UIFD0Q8B4
0::RXP0209bLW00409nOW`2MWId0WIfM0:6QX@80S8b<00@0Q8B407inOP1nOWh0R8R80P2:RXX0102R
XZ80UIFE09FEU@15ADD209JFUP0409RHV024Q8@0Q8B409RHV080Vi^K00@0ZZZZ0:RXZ02XZ:P0YjNW
0P2VYZH0102MWId0WinO09nOW`2NWYh209ZJVP0404M7A`21PH40PH6108F5Q@<0O7al00@0NGUi08B4
Q024Q8@0QXJ60P2CTi<0102JVYX0WinO09nOW`2WYjL20:RXZ0030:ZZZP1>CTh0CTi>00<0WinO00@0
YZJV0:b/[02/[:`0ZZZZ0P2UYJD0102JVYX0UIFE09FEU@2HV9P209jNWP040:6QX@2LW9`0W9bL07in
OP80N7Qh00@0/;2`0;:b/P2b/[80Y:BT0P2QXJ40102d];@0^KVi0;Vi^@2k^k/20;Ng]`050;Vi^@2m
_Kd0^KVi0;Vi^@2e]KD00P1aLG40102PX:00Xj>S0:>SX`2c/k<20;Ng]`<0^;Rh00@0/k>c0;:b/P2b
/[80Xj>S0P2GUiL0102SXj<0[jn_0:n_[`1KFe/206ATI0040:^[Z`2UYJD0YJFU0:FUY@80YZJV00<0
Xj>S09bLW02LW9`00`2OWil0102IVIT0WYjN09jNWP2VYZH20:2PX00308>3Pooooooooooo00@0oh00
0P000?l00`3oP000003o0000o`0:0000o`80oh00;@000?l20?n001<0003o0P3oP00C0000o`030?n0
00000?l0003o01<0003o0`3oP0030000o``0oh0010000?l90?n000@0003o0`3oP00E0000o`[ooooo
0009ooooo`<0^;Rh00@0][Jf079bLP1bLW80@D510P2MWId0102SXj<0X:2P0:2PX02SXj<209fMW@04
09nOW`2UYJD0YJFU0:RXZ080[Zj^00@0[:b/0:NWY`2WYjL0XJ6Q0P24Q8@0101SHf<0Ti>C09>CT`2Q
XJ420:JVYP040:BTY02QXJ40XJ6Q09nOW`80WIfM00@0VYZJ08V9R@29RHT0MGEe0P1kNg/01@2IVIT0
IFEU06EUI@24Q8@0XZ:R0080W9bL00@0WinO09fMW@2MWId0XJ6Q0P2<S8`01024Q8@0OWin07inOP28
R8P208Z:RP040::RXP2EUID0UIFE04E5A@80UYJF00@0V9RH08B4Q024Q8@0V9RH0P2KVi/0102ZZZX0
Z:RX0:RXZ02WYjL20:JVYP0409fMW@2OWil0WinO09jNWP80VYZJ00@0AdM70861P@21PH40QHF50`1l
O7`0101iNGT0Q8B408B4Q026QXH209>CT`0409ZJVP2OWil0WinO0:NWY`80Z:RX00<0ZZZZ04i>CP1>
CTh00`2OWil0102VYZH0[:b/0:b/[02ZZZX20:FUY@0409ZJVP2EUID0UIFE09RHV080WYjN00@0XJ6Q
09bLW02LW9`0OWin0P1hN7P0102`/;00/[:b0;:b/P2TY:@20:6QX@040;Bd]02i^KT0^KVi0;^k^`80
]kNg00D0^KVi0;fm_@2i^KT0^KVi0;Fe]@02075aL@040:2PX02SXj<0Xj>S0;>c/`80]kNg0`2h^;P0
102c/k<0/[:b0;:b/P2SXj<209NGU`040:>SX`2_[jl0[jn_05]KF`80I6AT00@0Zj^[0:FUY@2UYJD0
YJFU0P2VYZH00`2SXj<0W9bL09bLW00309nOW`0409VIV@2NWYh0WYjN0:JVYP80X:2P00<0Ph>3oooo
ooooool0103oP0020000o`030?n000000?l0003o00X0003o0P3oP00]0000o`80oh004`000?l20?n0
01<0003o00<0oh000000o`000?l04`000?l30?n000<0003o303oP0040000o`T0oh0010000?l30?n0
01D0003o2_ooool000Wooooo00@0IVIV06UYJ@1YJFT0I6AT0P1DE5@0100o?cl0D51@051@D01NGUh2
05]KF`0406MWI`1NGUh0GUiN04A4A080@D5100@0BTY:04];B`1;Bd/0Bd];0P0/;2`0100[:b/0;Rh^
02h^;P0_;bl203<c<`040451@@1;Bd/0Bd];05YJFP80Cdm?00@0?Cdm03@d=00d=3@0>SXj0P0i>CT0
101IFET0D51@051@D01RHV8204A4A00505]KF`1YJFT0IfMW06MWI`1KFe/00P1=CDd01010@400=cLg
03Lg=`0l?3`204U9B@0404m?C`1ADE40DE5A055AD@80=CDe00@0:2PX03`l?00l?3`0@4100P0n?Sh0
100m?Cd0@4100410@01=CDd203Ti>@04034a<@0n?Sh0?Shn03lo?`80@41000@0@T9203`l?00l?3`0
=3@d0P0`<3001@0k>c/0<30`030`<00f=SH0;bl_0080;Rh^00@092@T038b<P0b<S80>c/k0P1CDe<0
1018B4P0Cdm?04m?C`19BDT202h^;P0404Q8B01=CDd0CDe=05EEE@80FEUI00@0C4a<055AD@1ADE40
<S8b0P14A4@01016ATH0FEUI05UIF@1KFe/205mOG`0406a/K01VIVH0IVIV061PH080I6AT00@0Fe]K
04I6AP16ATH0?clo0P0d=3@01@0b<S80CDe=04e=C@1:BTX0DU9B0080D51@00@0De=C04Y:BP1:BTX0
BDU90P1BDU80101MGEd0F5QH05QHF01KFe/205EEE@0406IVIP1OGel0GemO065QH@80F5QH00@0JVYZ
06][J`1[Jf/0BTY:0P0c<c<0101<C4`0Bd];04];B`13@d<20492@P040451@@1>CTh0CTi>05MGE`80
Cdm?00@0GemO05=CD`1CDe<0CTi>0P18B4P00`0i>CWoooooooooo`040000o`P0oh0000<0003o0?n0
003oP0007@3oP0020000o`<0oh000`000?m:0?n000L0003o6@3oP0040000o`80oh000`000?l?0?n0
00030000o`3oP000oh0000@0oh002_ooool000Wooooo00@0Z:RX0:>SX`2SXj<0Xj>S0P2QXJ40102P
X:00Xj>S0:>SX`2UYJD209jNWP0409bLW02EUID0UIFE05IFEP80HV9R00@0/;2`0:^[Z`2[Zj/0XZ:R
0P2ZZZX0102UYJD0YjNW0:NWY`2XZ:P20:VYZ@040;2`/02c/k<0/k>c0;>c/`80/;2`00@0DU9B05EE
E@1EEED0T92@0P2DU9@0102EUID0X:2P0:2PX02VYZH20:n_[`050;2`/02RXZ80WIfM09fMW@2JVYX0
0P2VYZH0102MWId0G5aL05aLG018B4P20:RXZ0040:>SX`2PX:00X:2P0:RXZ080ZZZZ0`2TY:@0102Q
XJ40Y:BT0:BTY02/[:`20:n_[`040;6a/@1mOGd0OGem02`/;080P82000@0RHV909>CT`2CTi<0UIFE
0P2MWId0102FUYH0V9RH09RHV02CTi<209^KV`0509FEU@2TY:@0UIFE09FEU@0m?Cd00P1OGel0101U
IFD0K6a/06a/K01]KFd207IfMP0408F5Q@2CTi<0Ti>C09VIV@80TY:B00@0RHV908F5Q@25QHD0Vi^K
0P1TI6@0101<C4`0/[:b0;:b/P2e]KD20;>c/`040:^[Z`2c/k<0/k>c0;^k^`<0_Kfm0P32`/80102f
][H0UiNG09NGU`1lO7`205YJFP0508:2PP3;bl/0bl_;0<?3``2m_Kd00P2g]kL0102e]KD0]kNg0;Ng
]`2c/k<20;:b/P<0][Jf00@0V9RH071`L01`L700][Jf0`2j^[X20;6a/@040;2`/02e]KD0]KFe0;Rh
^080/k>c00@0[Zj^0;2`/02`/;00[jn_0P24Q8@0100l?3`0YJFU0:FUY@2NWYh20::RXP040;:b/P2e
]KD0]KFe0;>c/`<0[Zj^0_ooool?0000o`040?n000000?l0003o0?n000/0003o203oP0080000o`<0
oh001`000?l30?n000l0003o0`3oP0000`000?l0oh000?n0000A0000o`80oh004`000?l60?n00080
003o203oP0030000o`80oh0000<0003o0?n0003oP0003@3oP0030000oa00oh000P000?l00`3oP000
003o0000o`030000o`L0oh002_ooool000Wooooo00@0Z:RX0:>SX`2SXj<0Xj>S0P2QXJ40102PX:00
Xj>S0:>SX`2UYJD209jNWP0409bLW02EUID0UIFE05IFEP80HV9R00@0/;2`0:^[Z`2[Zj/0XZ:R0P2Z
ZZX0102UYJD0YjNW0:NWY`2XZ:P20:VYZ@040;2`/02c/k<0/k>c0;>c/`80/;2`00@0DU9B05EEE@1E
EED0T92@0P2DU9@0102EUID0X:2P0:2PX02VYZH20:n_[`050;2`/02RXZ80WIfM09fMW@2JVYX00P2V
YZH0102MWId0G5aL05aLG018B4P20:RXZ0040:>SX`2PX:00X:2P0:RXZ080ZZZZ0`2TY:@0102QXJ40
Y:BT0:BTY02/[:`20:n_[`040;6a/@1mOGd0OGem02`/;080P82000@0RHV909>CT`2CTi<0UIFE0P2M
WId0102FUYH0V9RH09RHV02CTi<209^KV`0509FEU@2TY:@0UIFE09FEU@0m?Cd00P1OGel0101UIFD0
K6a/06a/K01]KFd207IfMP0408F5Q@2CTi<0Ti>C09VIV@80TY:B00@0RHV908F5Q@25QHD0Vi^K0P1T
I6@0101<C4`0/[:b0;:b/P2e]KD20;>c/`040:^[Z`2c/k<0/k>c0;^k^`<0_Kfm0P32`/80102f][H0
UiNG09NGU`1lO7`205YJFP0508:2PP3;bl/0bl_;0<?3``2m_Kd00P2g]kL0102e]KD0]kNg0;Ng]`2c
/k<20;:b/P<0][Jf00@0V9RH071`L01`L700][Jf0`2j^[X20;6a/@040;2`/02e]KD0]KFe0;Rh^080
/k>c00@0[Zj^0;2`/02`/;00[jn_0P24Q8@0100l?3`0YJFU0:FUY@2NWYh20::RXP040;:b/P2e]KD0
]KFe0;>c/`<0[Zj^0_ooool?0000o`040?n000000?l0003o0?n000/0003o203oP0080000o`<0oh00
1`000?l30?n000l0003o0`3oP0000`000?l0oh000?n0000A0000o`80oh004`000?l60?n00080003o
203oP0030000o`80oh0000<0003o0?n0003oP0003@3oP0030000oa00oh000P000?l00`3oP000003o
0000o`030000o`L0oh002_ooool000Wooooo00@0YZJV09fMW@2MWId0VYZJ0P2@T90308b<S00409fM
W@2FUYH0UYJF08j>SP80Shn?00@0GEeM06][J`1[Jf/0[Jf]0P2^[Zh0102RXZ80Xj>S0:>SX`2QXJ43
0::RXP80YjNW00@0ZJVY0;>c/`2c/k<0];Bd0P2_[jl0101oOgl0IfMW06MWI`2GUiL207]kN`0407Ui
N@2LW9`0W9bL0:2PX080WinO0P2IVIT208b<S00408n?S`2:RXX0RXZ:08R8R080HF5Q00@0=SHf09JF
UP2FUYH0X:2P0P2IVIT0102MWId0XJ6Q0:6QX@2MWId209jNWP0408R8R02SXj<0Xj>S0:ZZZP<0[Zj^
0P21PH401015ADD0YjNW0:NWY`2SXj<20:JVYP040:BTY02VYZH0YZJV0:JVYP80Z:RX00D0YZJV0:NW
Y`2WYjL0Rh^;0::RXP020:VYZ@0405YJFP1UIFD0IFEU079bLP80MWIf00@0Ph>307]kN`1kNg/0LG5a
0P1lO7`01025QHD0Q8B408B4Q01kNg/20861P@0407YjNP1QHF40HF5Q03lo?`80WYjN0`2^[Zh0102S
Xj<0[Jf]0:f][@2a/K420;:b/P030;Bd]02f][H0][Jf00<0];Bd00@0]KFe06e]K@1]KFd0TY:B0P2k
^k/20;Rh^080];Bd0`2a/K40102][Jd0/K6a0;6a/@2`/;020:VYZ@<0Kfm_00@0]kNg0;Jf]P2f][H0
]KFe0P2d];@0102g]kL0]KFe0;Fe]@2g]kL20;Bd]0040:n_[`2][Jd0[Jf]0:j^[P80WIfM00@0DU9B
0::RXP2RXZ80Xj>S0P2VYZH0102c/k<0/K6a0;6a/@2^[Zh20:f][@030;:b/_oooooooooo00l0003o
00<0oh000000o`000?l00`3oP00:0000o`@0oh005`000?l00`3oP000003o0000o`0=0000o`<0oh00
00<0003o0?n0003oP0004@000?l20?n001<0003o0P3oP00010000?l0oh000?n0003oP0020000o`/0
oh000`000?l>0?n000@0003o403oP0020000o`030?n000000?l0003o00<0003o1`3oP00:ooooo`00
2Oooool0102XZ:P0Xj>S0:>SX`2PX:0309:BTP80PX:200@0U9BD09FEU@2EUID0Rh^;0P24Q8@0101Q
HF40IVIV06IVIP2[Zj/20:b/[0040::RXP2MWId0WIfM09fMW@80VYZJ00@0Y:BT0:2PX02PX:00YZJV
0P2ZZZX0102a/K40Zj^[0:^[Z`20P80206QXJ00409>CT`21PH40PH6108J6QP80RXZ:00D0SHf=0:b/
[02/[:`0ZJVY0:j^[P020:^[Z`040:b/[02WYjL0YjNW09RHV080JVYZ00@0;Bd]09ZJVP2JVYX0YjNW
0P2TY:@0102ZZZX0YZJV0:JVYP2SXj<209nOW`04092@T02TY:@0Y:BT0:f][@80/k>c00@0[Zj^08R8
R028R8P0B4Q80P2YZJT30;Bd]0040:ZZZP2SXj<0Xj>S0:NWY`80Y:BT00D0YZJV0:2PX02PX:00OWin
0:2PX0020:^[Z`0405eMG@1VIVH0IVIV07moO`80Rh^;00<0RHV907moO`1oOgl00`1mOGd0101oOgl0
QhN708N7Q`25QHD208R8R00407UiN@1XJ6P0J6QX0492@P80PX:200@0O7al06UYJ@1YJFT0KFe]0P2O
Wil0102ZZZX0[Zj^0:j^[P2[Zj/30:n_[`<0[Jf]0P1OGel01@2BTY80/k>c0;>c/`2a/K40/[:b0080
ZZZZ00@0Zj^[0:ZZZP2ZZZX0ZJVY0P2UYJD0102TY:@0YJFU0:FUY@1IFET207inOP040<[:bP34a<@0
a<C40;fm_@80];Bd00@0][Jf0;Bd]02d];@0][Jf0P2h^;P40;>c/`80Z:RX00@0GUiN09jNWP2NWYh0
XJ6Q0P2WYjL0102][Jd0[jn_0:n_[`2XZ:P20:b/[0030:j^[_oooooooooo0200003o0P3oP00?0000
o`030?n000000?l0003o00H0003o00<0oh000000o`000?l02`000?l50?n000040000o`3oP000oh00
0000o`<0oh003@000?l20?n001<0003o0P3oP0080000o`80oh0000<0003o0?n0003oP000103oP003
0000o`D0oh002P000?l20?n000030000o`3oP000oh0000h0oh000P000?l00`3oP000003o0000o`03
0000o`<0oh000`000?l00`3oP03oooooooooo`08ooooo`002Oooool0102XZ:P0Xj>S0:>SX`2PX:03
09:BTP80PX:200@0U9BD09FEU@2EUID0Rh^;0P24Q8@0101QHF40IVIV06IVIP2[Zj/20:b/[0040::R
XP2MWId0WIfM09fMW@80VYZJ00@0Y:BT0:2PX02PX:00YZJV0P2ZZZX0102a/K40Zj^[0:^[Z`20P802
06QXJ00409>CT`21PH40PH6108J6QP80RXZ:00D0SHf=0:b/[02/[:`0ZJVY0:j^[P020:^[Z`040:b/
[02WYjL0YjNW09RHV080JVYZ00@0;Bd]09ZJVP2JVYX0YjNW0P2TY:@0102ZZZX0YZJV0:JVYP2SXj<2
09nOW`04092@T02TY:@0Y:BT0:f][@80/k>c00@0[Zj^08R8R028R8P0B4Q80P2YZJT30;Bd]0040:ZZ
ZP2SXj<0Xj>S0:NWY`80Y:BT00D0YZJV0:2PX02PX:00OWin0:2PX0020:^[Z`0405eMG@1VIVH0IVIV
07moO`80Rh^;00<0RHV907moO`1oOgl00`1mOGd0101oOgl0QhN708N7Q`25QHD208R8R00407UiN@1X
J6P0J6QX0492@P80PX:200@0O7al06UYJ@1YJFT0KFe]0P2OWil0102ZZZX0[Zj^0:j^[P2[Zj/30:n_
[`<0[Jf]0P1OGel01@2BTY80/k>c0;>c/`2a/K40/[:b0080ZZZZ00@0Zj^[0:ZZZP2ZZZX0ZJVY0P2U
YJD0102TY:@0YJFU0:FUY@1IFET207inOP040<[:bP34a<@0a<C40;fm_@80];Bd00@0][Jf0;Bd]02d
];@0][Jf0P2h^;P40;>c/`80Z:RX00@0GUiN09jNWP2NWYh0XJ6Q0P2WYjL0102][Jd0[jn_0:n_[`2X
Z:P20:b/[0030:j^[_oooooooooo0200003o0P3oP00?0000o`030?n000000?l0003o00H0003o00<0
oh000000o`000?l02`000?l50?n000040000o`3oP000oh000000o`<0oh003@000?l20?n001<0003o
0P3oP0080000o`80oh0000<0003o0?n0003oP000103oP0030000o`D0oh002P000?l20?n000030000
o`3oP000oh0000h0oh000P000?l00`3oP000003o0000o`030000o`<0oh000`000?l00`3oP03ooooo
ooooo`08ooooo`002Oooool0102UYJD0Xj>S0:>SX`2IVIT209^KV`0408n?S`2=SHd0SHf=096AT@80
R8R800@0Shn?09>CT`2CTi<0JVYZ0P1LG5`0102ZZZX0YjNW0:NWY`2SXj<20:BTY00409fMW@2JVYX0
VYZJ09nOW`80X:2P00@0ZJVY0:ZZZP2ZZZX0[Zj^0P2UYJD0101ZJVX0LG5a075aL@2<S8`208Z:RP04
07QhN021PH40PH6108>3P`80WYjN00@0YjNW0:^[Z`2][Jd0[Jf]0`2YZJT0102RXZ80JVYZ06YZJP0b
<S8209RHV0040:j^[P2][Jd0[Jf]0;6a/@<0[:b/0P2UYJD0102QXJ40ZJVY0:VYZ@2/[:`20;2`/004
0:NWY`2HV9P0V9RH0410@080YJFU00@0XZ:R0:NWY`2WYjL0YjNW0P2QXJ40102BTY80VIVI09VIV@2R
XZ820:2PX00508Z:RP2=SHd0YJFU0:FUY@1ZJVX00P1gMgL309nOW`0409RHV01jNWX0NWYj06i^KP80
MWIf00@0O7al08n?S`2?Shl0TY:B0P25QHD01026QXH0Lg=c07=cL`1YJFT20:2PX0<0WYjN00@0K6a/
0820P020P800RXZ:0P2QXJ40102SXj<0Vi^K09^KV`2MWId209>CT`0408^;R`0n?Sh0?Shn0820P080
WinO00D0VIVI09RHV02FUYH0UYJF0:6QX@0209bLW0030:2PX02KVi/0Vi^K00<0VIVI00<0H61P079b
LP1bLW80102l_;`20;Fe]@040:n_[`2YZJT0ZJVY0:6QX@80Z:RX00@0/;2`0:2PX02PX:00WYjN0P2J
VYX0101EEED0W9bL09bLW02NWYh20:FUY@040:ZZZP2][Jd0[Jf]0:FUY@80Xj>S00<0Z:RXoooooooo
ool040000?l20?n000h0003o0P3oP00@0000o`80oh001P000?l00`3oP000003o0000o`040?n000T0
003o00@0oh000000o`000?l0003o0P3oP00i0000o`80oh004`000?l70?n000D0003o00<0oh000000
o`000?l00`000?l00`3oP000003o0000o`040000o`80oh0010000?l:ooooo`002Oooool0101UIFD0
F5QH05QHF017AdL203Ti>@0303/k>`12@T80@T9200<0B4Q800@0BDU903lo?`0o?cl09RHV0P0/;2`0
101PH600LG5a075aL@1hN7P207AdM00406UYJ@17AdL0AdM704U9B@80CDe=00@0BDU904m?C`1?Cdl0
BTY:0P0n?Sh0100/;2`0?3`l03`l?013@d<204];B`<0@d=300D0ATI604a<C01<C4`0DU9B04i>CP02
05=CD`04065QH@1NGUh0GUiN03hn?P8092@T00@0:b/[04U9B@19BDT0E5AD0P1LG5`304m?C`040492
@P16ATH0ATI604M7A`80@d=300@0B4Q804A4A014A4@0;bl_0P0i>CT0100g=cL0CDe=04e=C@1@D502
04a<C00403lo?`11@D40@D51034a<@80<30`00<0<c<c0451@@11@D400P12@T8204=3@`<0@41000@0
ATI604a<C01<C4`0BDU90P0o?cl0100`<300>3Ph03Ph>00d=3@203/k>`0403Lg=`0i>CT0>CTi03lo
?`80<S8b00@0>c/k03lo?`0o?cl0=CDe0P10@4001017AdL0@d=304=3@`0];Bd2024Q8@0403Ph>00k
>c/0>c/k0451@@80?Cdm00@0>c/k03Ti>@0i>CT0@4100P1;Bd/01@13@d<0?clo04A4A014A4@0?3`l
00808b<S00@0<c<c03Hf=P0f=SH0=CDe0P0l?3`01014A4@0?Cdm03dm?@14A4@204Q8B00404U9B@18
B4P0B4Q803<c<`80<S8b00@071`L02h^;P0^;Rh0?3`l0P0g=cL0100f=SH0A4A404A4A01:BTX205AD
E00405UIF@1SHf<0Hf=S05eMG@<0CTi>0P16ATH0101KFe_oooooooooo`000?lA0?n000L0003o6`3o
P0000`000?l0oh000?n0001m0?n00080003o1`3oP00:ooooo`002Oooool0101UIFD0F5QH05QHF017
AdL203Ti>@0303/k>`12@T80@T9200<0B4Q800@0BDU903lo?`0o?cl09RHV0P0/;2`0101PH600LG5a
075aL@1hN7P207AdM00406UYJ@17AdL0AdM704U9B@80CDe=00@0BDU904m?C`1?Cdl0BTY:0P0n?Sh0
100/;2`0?3`l03`l?013@d<204];B`<0@d=300D0ATI604a<C01<C4`0DU9B04i>CP0205=CD`04065Q
H@1NGUh0GUiN03hn?P8092@T00@0:b/[04U9B@19BDT0E5AD0P1LG5`304m?C`040492@P16ATH0ATI6
04M7A`80@d=300@0B4Q804A4A014A4@0;bl_0P0i>CT0100g=cL0CDe=04e=C@1@D50204a<C00403lo
?`11@D40@D51034a<@80<30`00<0<c<c0451@@11@D400P12@T8204=3@`<0@41000@0ATI604a<C01<
C4`0BDU90P0o?cl0100`<300>3Ph03Ph>00d=3@203/k>`0403Lg=`0i>CT0>CTi03lo?`80<S8b00@0
>c/k03lo?`0o?cl0=CDe0P10@4001017AdL0@d=304=3@`0];Bd2024Q8@0403Ph>00k>c/0>c/k0451
@@80?Cdm00@0>c/k03Ti>@0i>CT0@4100P1;Bd/01@13@d<0?clo04A4A014A4@0?3`l00808b<S00@0
<c<c03Hf=P0f=SH0=CDe0P0l?3`01014A4@0?Cdm03dm?@14A4@204Q8B00404U9B@18B4P0B4Q803<c
<`80<S8b00@071`L02h^;P0^;Rh0?3`l0P0g=cL0100f=SH0A4A404A4A01:BTX205ADE00405UIF@1S
Hf<0Hf=S05eMG@<0CTi>0P16ATH0101KFe_oooooooooo`000?lA0?n000L0003o6`3oP0000`000?l0
oh000?n0001m0?n00080003o1`3oP00:ooooo`002Oooool0102b/[80Z:RX0:RXZ02SXj<205YJFP04
07alO02BTY80TY:B07AdM080OGem00@0UiNG09BDU02DU9@0Y:BT0P2ZZZX0102?Shl0[:b/0:b/[02Z
ZZX20:NWY`040:FUY@0i>CT0>CTi06QXJ080R8R800@0XZ:R0:f][@2][Jd0[jn_0P2^[Zh0102/[:`0
ZZZZ0:ZZZP2RXZ820:6QX@040::RXP2PX:00X:2P0:VYZ@80F5QH00D0NWYj0:JVYP2XZ:P0Z:RX0:^[
Z`020:>SX`040:NWY`2PX:00X:2P0:FUY@80ZZZZ00@0XJ6Q0:RXZ02XZ:P0[jn_0P2NWYh01016ATH0
L71`071`L021PH4208f=S@0409ZJVP2KVi/0Vi^K0:2PX080W9bL102QXJ4309ZJVP80UiNG00@0BDU9
09nOW`2OWil0[Jf]0P2_[jl01@2d];@0`<300;Ng]`2g]kL0/;2`0080[Jf]00@0/;2`0:j^[P2^[Zh0
/k>c0P2d];@0102EUID0JFUY06UYJ@2TY:@20:j^[P040:^[Z`2^[Zh0[Zj^0;Ng]`80^[Zj00@0^k^k
0;Ng]`2g]kL0][Jf0P2d];@0102`/;00/k>c0;>c/`17AdL2065QH@040;Vi^@2l_;`0_;bl0;Zj^P80
[jn_00@0];Bd0;^k^`2k^k/0_Kfm0P2j^[X01@2m_Kd0_;bl0;Zj^P2j^[X0YjNW0080?Cdm00<0^k^k
0;Ng]`2g]kL0102j^[X20;Jf]P040;Bd]02a/K40/K6a0;6a/@80/[:b00@0[Jf]0:FUY@2UYJD0J6QX
0P2RXZ80102d];@0/;2`0;2`/02d];@20;6a/@<0/;2`00@0ZZZZ0:BTY02TY:@0YZJV0P2TY:@0102Z
ZZX0LG5a075aL@2PX:02ooooo`040?n000000?l0003o0000o`80oh004`000?l20?n000@0003o103o
P00;0000o`030?n000000?l0003o00h0003o0P3oP0000`000?l0oh000?n0000C0000o`80oh0000<0
003o0?n0003oP0003P3oP0050000o`030?n000000?l0003o00h0oh000P000?l@0?n00080003o4@3o
P0050000o`T0oh002P000?l:ooooo`002Oooool0102ZZZX0YjNW0:NWY`2UYJD206ATI00407QhN02D
U9@0U9BD05aLG080NWYj00@0RHV907]kN`1kNg/0TY:B0P2EUID00`1UIFD0WYjN09jNWP0309jNWP04
09fMW@0];Bd0;Bd]06EUI@80NWYj00@0P82009fMW@2MWId0VYZJ0P2FUYH0102HV9P0UiNG09NGU`2A
TI4209BDU00409:BTP2GUiL0UiNG0:RXZ080IVIV00D0R8R80:ZZZP2ZZZX0ZZZZ0:JVYP020:FUY@04
0:BTY02LW9`0W9bL0:6QX@80X:2P00@0WYjN0:JVYP2VYZH0ZZZZ0P2[Zj/0101JFUX0NGUi07UiN@2I
VIT209RHV00409nOW`2SXj<0Xj>S0:FUY@80X:2P00@0VYZJ092@T02@T900SXj>0P2=SHd0102?Shl0
RXZ:08Z:RP0o?cl20:>SX`050;:b/P2h^;P0^;Rh0;Fe]@2k^k/00P2d];@0102`/;00[jn_0:n_[`2/
[:`20:j^[P040:^[Z`2`/;00/;2`09NGU`80JFUY00@0WIfM0:>SX`2SXj<0[:b/0P2c/k<0102_[jl0
/k>c0;>c/`2h^;P20;Jf]P040;:b/P2[Zj/0Zj^[0:b/[080[Zj^00@0CDe=08:2PP22PX80_Kfm0P35
aLD0102o_kl0];Bd0;Bd]02g]kL20<30`0050;no_`34a<@0a<C40<G5a@36a/H00P2n_[h0102][Jd0
ADE504E5A@2d];@20;6a/@040;Bd]02c/k<0/k>c0;Bd]080YjNW0`2VYZH0102^[Zh0[jn_0:n_[`2_
[jl20:VYZ@04061PH02][Jd0[Jf]0;Fe]@80[Jf]00@0/;2`0;6a/@2a/K40/;2`0P2f][H0102/[:`0
Z:RX0:RXZ02`/;020;6a/@040;:b/P1iNGT0NGUi0:b/[0;ooooo2@000?l00`3oP000003o0000o`0=
0000o`80oh009`000?l20?n001<0003o0P3oP0000`000?l0oh000?n000080?n00080003o00@0oh00
0000o`000?l0oh0020000?l90?n000<0003o0P3oP0020000oa/0oh0010000?l40?n000<0003o2`3o
P0030000o`@0oh000`000?l:ooooo`002Oooool0102ZZZX0YjNW0:NWY`2UYJD206ATI00407QhN02D
U9@0U9BD05aLG080NWYj00@0RHV907]kN`1kNg/0TY:B0P2EUID00`1UIFD0WYjN09jNWP0309jNWP04
09fMW@0];Bd0;Bd]06EUI@80NWYj00@0P82009fMW@2MWId0VYZJ0P2FUYH0102HV9P0UiNG09NGU`2A
TI4209BDU00409:BTP2GUiL0UiNG0:RXZ080IVIV00D0R8R80:ZZZP2ZZZX0ZZZZ0:JVYP020:FUY@04
0:BTY02LW9`0W9bL0:6QX@80X:2P00@0WYjN0:JVYP2VYZH0ZZZZ0P2[Zj/0101JFUX0NGUi07UiN@2I
VIT209RHV00409nOW`2SXj<0Xj>S0:FUY@80X:2P00@0VYZJ092@T02@T900SXj>0P2=SHd0102?Shl0
RXZ:08Z:RP0o?cl20:>SX`050;:b/P2h^;P0^;Rh0;Fe]@2k^k/00P2d];@0102`/;00[jn_0:n_[`2/
[:`20:j^[P040:^[Z`2`/;00/;2`09NGU`80JFUY00@0WIfM0:>SX`2SXj<0[:b/0P2c/k<0102_[jl0
/k>c0;>c/`2h^;P20;Jf]P040;:b/P2[Zj/0Zj^[0:b/[080[Zj^00@0CDe=08:2PP22PX80_Kfm0P35
aLD0102o_kl0];Bd0;Bd]02g]kL20<30`0050;no_`34a<@0a<C40<G5a@36a/H00P2n_[h0102][Jd0
ADE504E5A@2d];@20;6a/@040;Bd]02c/k<0/k>c0;Bd]080YjNW0`2VYZH0102^[Zh0[jn_0:n_[`2_
[jl20:VYZ@04061PH02][Jd0[Jf]0;Fe]@80[Jf]00@0/;2`0;6a/@2a/K40/;2`0P2f][H0102/[:`0
Z:RX0:RXZ02`/;020;6a/@040;:b/P1iNGT0NGUi0:b/[0;ooooo2@000?l00`3oP000003o0000o`0=
0000o`80oh009`000?l20?n001<0003o0P3oP0000`000?l0oh000?n000080?n00080003o00@0oh00
0000o`000?l0oh0020000?l90?n000<0003o0P3oP0020000oa/0oh0010000?l40?n000<0003o2`3o
P0030000o`@0oh000`000?l:ooooo`002Oooool0102QXJ40WIfM09fMW@2OWil205eMG@0407=cL`2:
RXX0RXZ:05ADE080RHV900@0TI6A07moO`1oOgl0Ti>C0P21PH400`1VIVH0VYZJ09ZJVP0309RHV004
09nOW`0g=cL0=cLg05iNGP<0NGUi0P2NWYh0102LW9`0UiNG09NGU`2ATI420861P@0308R8R02@T900
T92@00<0TY:B00D0U9BD059BDP1BDU80Lg=c0:6QX@020:>SX`<0XJ6Q00@0X:2P09>CT`2CTi<0UYJF
0P2BTY80102CTi<0X:2P0:2PX02TY:@20:6QX@0404Y:BP1YJFT0JFUY09VIV@80VYZJ00@0XJ6Q09fM
W@2MWId0SXj>0P2:RXX01029RHT0QHF508F5Q@24Q8@208j>SP0408b<S029RHT0RHV90451@@80Vi^K
0`2][Jd01@2^[Zh0];Bd0;2`/02`/;00ZJVY0080YjNW00@0Y:BT0:>SX`2SXj<0YJFU0P2YZJT0102S
Xj<0IFEU06EUI@2BTY8209JFUP040:2PX02XZ:P0Z:RX0:6QX@80[:b/00@0[Zj^0:b/[02/[:`0Z:RX
0P2TY:@0102WYjL0ZZZZ0:ZZZP1<C4`208f=S@040;no_`32`/80`/;20;no_`80^k^k00@0^[Zj0;jn
_P2n_[h0`l?30P39bLT01@35aLD0_Kfm0;^k^`2k^k/0/[:b0080BTY:00@0/k>c0;6a/@2a/K40]KFe
0P2f][H0102a/K40YjNW0:NWY`2OWil209VIV@0409RHV02OWil0WinO0:VYZ@80Xj>S00@0EUIF0:f]
[@2][Jd0/[:b0P2][Jd0102/[:`0[Zj^0:j^[P2_[jl20;6a/@<0[Jf]00@0];Bd0;Jf]P2f][H0[jn_
0P1fMWH00`2YZJWoooooooooo`040000o`80oh000`000?l00`3oP000003o0000o`0=0000o`<0oh00
4P000?l00`3oP000003o0000o`0A0000o`80oh004`000?l20?n000030000o`3oP000oh0000D0oh00
5@000?l20?n000L0003o00<0oh000000o`000?l06`3oP00:0000o`H0oh0000<0003o0?n0003oP000
2P3oP0030000o`[ooooo0009ooooo`040:6QX@2LW9`0W9bL09^KV`80IFEU00@0LG5a08n?S`2?Shl0
Kfm_0P2OWil0102KVi/0VYZJ09ZJVP2TY:@20820P00407emO@2QXJ40XJ6Q0:2PX080WIfM00@0Ti>C
04=3@`13@d<0GUiN0P23Ph<0102<S8`0W9bL09bLW02SXj<209nOW`0409ZJVP2ATI40TI6A092@T080
SXj>00@0SHf=09>CT`2CTi<0PX:20P0d=3@01@1eMGD0WYjN09jNWP2NWYh0WIfM0080UiNG00@0X:2P
09RHV02HV9P0SHf=0P28R8P00`2CTi<0UiNG09NGU`0309VIV@0404m?C`1SHf<0Hf=S08R8R080UIFE
00@0VYZJ09VIV@2IVIT0Shn?0P23Ph<0101oOgl0OWin07inOP20P80208F5Q@0408R8R01gMgL0MgMg
0492@P80RXZ:00D0WYjN0:BTY02TY:@0WIfM0:BTY0020:JVYP0409nOW`2GUiL0UiNG09BDU080TI6A
00@0WIfM09ZJVP2JVYX0UiNG0P1KFe/0102GUiL0QXJ608J6QP29RHT209fMW@<0VIVI00@0WYjN09VI
V@2IVIT0UYJF0P2GUiL0102NWYh0VYZJ09ZJVP0i>CT20820P0040:NWY`2TY:@0Y:BT0;2`/080[Zj^
00@0[jn_0:b/[02/[:`0Xj>S0P2d];@01@2VYZH0YjNW0:n_[`2_[jl0VIVI0080DE5A00@0S8b<08f=
S@2=SHd0VIVI0P2ZZZX0102WYjL0TY:B09:BTP26QXH208N7Q`0408R8R024Q8@0Q8B409BDU080V9RH
00@0Fe]K0:>SX`2SXj<0Xj>S0`2TY:@20:VYZ@0409ZJVP2OWil0WinO09JFUP80Xj>S00@0Y:BT0:2P
X02PX:00VYZJ0P1MGEd00`2EUIGoooooooooo`0I0000o`<0oh004P000?l00`3oP000003o0000o`0A
0000o`80oh004`000?l20?n001<0003o00<0oh000000o`000?l040000?l00`3oP000003o0000o`03
0000o`@0oh000`000?l20?n000<0003o00@0oh000000o`000?l0oh004P000?l00`3oP000003o0000
o`0@0000o`80oh0000<0003oooooooooool02?ooool000Wooooo00@0XJ6Q09bLW02LW9`0Vi^K0P1U
IFD0101aLG40Shn?08n?S`1_Kfl209nOW`0409^KV`2JVYX0VYZJ0:BTY080P82000@0OGem0:6QX@2Q
XJ40X:2P0P2MWId0102CTi<0@d=304=3@`1NGUh208>3P`0408b<S02LW9`0W9bL0:>SX`80WinO00@0
VYZJ096AT@2ATI40T92@0P2>SXh0102=SHd0Ti>C09>CT`22PX8203@d=00507EeM@2NWYh0WYjN09jN
WP2MWId00P2GUiL0102PX:00V9RH09RHV02=SHd208R8R00309>CT`2GUiL0UiNG00<0VIVI00@0Cdm?
06=SH`1SHf<0R8R80P2EUID0102JVYX0VIVI09VIV@2?Shl208>3P`0407moO`1nOWh0OWin0820P080
QHF500@0R8R807MgM`1gMgL0@T920P2:RXX01@2NWYh0Y:BT0:BTY02MWId0Y:BT0080YZJV00@0WinO
09NGU`2GUiL0U9BD0P2ATI40102MWId0VYZJ09ZJVP2GUiL205]KF`0409NGU`26QXH0QXJ608V9R@80
WIfM0`2IVIT0102NWYh0VIVI09VIV@2FUYH209NGU`0409jNWP2JVYX0VYZJ03Ti>@80P82000@0YjNW
0:BTY02TY:@0/;2`0P2^[Zh0102_[jl0[:b/0:b/[02SXj<20;Bd]0050:JVYP2WYjL0[jn_0:n_[`2I
VIT00P1ADE40102<S8`0SHf=08f=S@2IVIT20:ZZZP040:NWY`2BTY80TY:B08J6QP80QhN700@0R8R8
08B4Q024Q8@0U9BD0P2HV9P0101KFe/0Xj>S0:>SX`2SXj<30:BTY080ZJVY00@0VYZJ09nOW`2OWil0
UYJF0P2SXj<0102TY:@0X:2P0:2PX02JVYX205eMG@0309FEUOoooooooooo01T0003o0`3oP00B0000
o`030?n000000?l0003o0140003o0P3oP00C0000o`80oh004`000?l00`3oP000003o0000o`0@0000
o`030?n000000?l0003o00<0003o103oP0030000o`80oh000`000?l0103oP000003o0000o`3oP00B
0000o`030?n000000?l0003o0100003o0P3oP0000`000?ooooooooooo`08ooooo`002Oooool0101I
FET0Bd];04];B`1:BTX203Ti>@0403/k>`1;Bd/0Bd];03lo?`80A4A400@0B4Q804m?C`1?Cdl0CTi>
0P0k>c/0101:BTX0D51@051@D017AdL204A4A00403Xj>P0K6a/06a/K02@T90<0?3`l0`0h>3P20492
@P0403Ph>00];Bd0;Bd]03Xj>P80C4a<00@0Cdm?05=CD`1CDe<0?3`l0P0O7al01@16ATH0GUiN05UI
F@1IFET0GemO00<0EEEE0P1>CTh0101:BTX0AdM704M7A`16ATH2051@D00404e=C@18B4P0B4Q8024Q
8@80=cLg00@0Bd];059BDP1BDU80De=C0P1BDU80101=CDd0DE5A055AD@15ADD204Q8B00404=3@`12
@T80@T9203Xj>P80=cLg00@0820P02`/;00/;2`0;bl_0P0^;Rh01@0V9RH0?Cdm0492@P12@T80>3Ph
0080=cLg00@0;bl_02TY:@0Y:BT0<30`0P0c<c<0100Y:BT09RHV02HV9P1>CTh20451@@0403`l?00k
>c/0>c/k03Xj>P80@D5100@0ATI603Hf=P0f=SH0<30`0P0a<C40100];Bd08b<S02<S8`0O7al201hN
7P0402@T900U9BD09BDU02XZ:P80;2`/00@09RHV02PX:00X:2P0>SXj0P10@4001@11@D40BDU904a<
C01<C4`0CDe=0080@T9200@0?Shn03Xj>P0j>SX08b<S0P0W9bL0100X:2P04Q8B018B4P0P820202LW
9`0302HV9P0O7al07alO00<09RHV00@05QHF01TI6@0I6AT0820P0P0K6a/0100R8R806QXJ01XJ6P0=
3@d201HF5P0402LW9`0a<C40<C4a034a<@80;bl_00@0:BTY028R8P0R8R808R8R0_oooold0?n00003
0000o`3oP000oh0008H0oh002_ooool000Wooooo00@0Ti>C08R8R028R8P0QhN70P21PH400`1mOGd0
NGUi07UiN@0307AdM00407UiN@1mOGd0OGem08B4Q080<30`00@0B4Q806][J`1[Jf/0NWYj0P1eMGD0
101kNg/0P8200820P01fMWH307inOP80O7al00@0LW9b06i^KP1^KVh0J6QX0P0T92@0101lO7`0RXZ:
08Z:RP26QXH208n?S`0509fMW@2VYZH0YZJV09ZJVP2HV9P00P2KVi/0102EUID0R8R808R8R02=SHd2
08>3P`0402l_;`1MGEd0GEeM07emO@80RHV900@0Ph>307UiN@1iNGT0MgMg0P1dM7@0101TI6@0JVYZ
06YZJP1^KVh206][J`0406a/K01eMGD0MGEe03<c<`80Kfm_00@0L71`06MWI`1WIfL0M7Ad0P1hN7P0
1020P800Q8B408B4Q02:RXX208j>SP80UYJF0P2@T900101dM7@0KVi^06i^KP2HV9P208b<S00409BD
U02MWId0WIfM09VIV@80W9bL0`2GUiL0102XZ:P0ZJVY0:VYZ@2[Zj/206EUI@0408>3P`2JVYX0VYZJ
09>CT`<0SXj>0P2CTi<0102JVYX0VIVI09VIV@2OWil20::RXP0409nOW`2QXJ40XJ6Q07YjNP80J6QX
00D0V9RH09jNWP2NWYh0/;2`0;Fe]@020:RXZ0040:j^[P2MWId0WIfM09^KV`80X:2P00@0VYZJ08V9
R@29RHT0Y:BT0P1DE5@0102:RXX0GUiN05iNGP1lO7`209NGU`040::RXP2LW9`0W9bL07=cL`80Ng]k
00@0OGem08^;R`2;Rh/0XZ:R0P2PX:00101PH600PH610861P@2QXJ420:BTY0040:FUY@2WYjL0YjNW
0:NWY`80W9bL00<0QXJ6ooooooooool040000?l30?n00180003o00<0oh000000o`000?l04P000?l3
0?n00140003o0P3oP00n0000o`<0oh0000<0003o0?n0003oP0002@000?l0103oP000003o0?n0003o
P00L0000o`[ooooo0009ooooo`0409>CT`28R8P0R8R808N7Q`80PH6100<0OGem07UiN@1iNGT00`1d
M7@0101iNGT0OGem07emO@24Q8@2030`<00404Q8B01[Jf/0Jf][07YjNP80MGEe00@0Ng]k0820P020
P800MWIf0`1nOWh207alO004079bLP1^KVh0KVi^06QXJ08092@T00@0O7al08Z:RP2:RXX0QXJ60P2?
Shl01@2MWId0YZJV0:JVYP2JVYX0V9RH0080Vi^K00@0UIFE08R8R028R8P0SHf=0P23Ph<0100_;bl0
GEeM05eMG@1mOGd208V9R@0408>3P`1iNGT0NGUi07MgM`80M7Ad00@0I6AT06YZJP1ZJVX0KVi^0P1[
Jf/0101/K6`0MGEe07EeM@0c<c<206m_K`04071`L01WIfL0IfMW07AdM080N7Qh00@0P82008B4Q024
Q8@0RXZ:0P2>SXh209JFUP80T92@00@0M7Ad06i^KP1^KVh0V9RH0P2<S8`0102DU9@0WIfM09fMW@2I
VIT209bLW0<0UiNG00@0Z:RX0:VYZ@2YZJT0Zj^[0P1UIFD01023Ph<0VYZJ09ZJVP2CTi<308j>SP80
Ti>C00@0VYZJ09VIV@2IVIT0WinO0P2RXZ80102OWil0XJ6Q0:6QX@1jNWX206QXJ00509RHV02NWYh0
WYjN0;2`/02e]KD00P2XZ:P0102^[Zh0WIfM09fMW@2KVi/20:2PX00409ZJVP29RHT0RHV90:BTY080
E5AD00@0RXZ:05iNGP1NGUh0O7al0P2GUiL0102RXZ80W9bL09bLW01cLg<207]kN`0407emO@2;Rh/0
Rh^;0::RXP80X:2P00@0H61P0861P@21PH40XJ6Q0P2TY:@0102UYJD0YjNW0:NWY`2WYjL209bLW003
08J6Q_oooooooooo0100003o0`3oP00B0000o`030?n000000?l0003o0180003o0`3oP00A0000o`80
oh00?P000?l30?n000030000o`3oP000oh0000T0003o00@0oh000000o`3oP000oh0070000?l:oooo
o`002Oooool00`2_[jl0XJ6Q0:6QX@030:6QX@0409fMW@2UYJD0YJFU0:JVYP80Xj>S00@0XZ:R09^K
V`2KVi/0XJ6Q0P0l?3`0102:RXX0UiNG09NGU`2PX:020:BTY00409fMW@2FUYH0UYJF08f=S@80WinO
00@0Y:BT0:>SX`2SXj<0Ti>C0P2=SHd01022PX80;Bd]02d];@2:RXX209^KV`0409RHV02MWId0WIfM
09bLW0<0Y:BT00@0Xj>S0:BTY02TY:@0VIVI0P2<S8`0102;Rh/0RHV908V9R@1;Bd/209^KV`0409>C
T`2MWId0WIfM0:6QX@80YZJV00@0Xj>S09ZJVP2JVYX0Ti>C0P23Ph<01026QXH0MWIf07IfMP20P802
09JFUP0403@d=029RHT0RHV908V9R@80RXZ:00@0QhN709NGU`2GUiL0WIfM0P2BTY801@2@T900Shn?
08n?S`2QXJ40XZ:R0080TY:B00@0MgMg05=CD`1CDe<0RXZ:0P2=SHd0102CTi<0VIVI09VIV@2KVi/2
09nOW`<0X:2P00@0ZJVY0:ZZZP2ZZZX0ZZZZ0P1=CDd0102KVi/0YZJV0:JVYP2NWYh20:2PX00409jN
WP2XZ:P0Z:RX0:ZZZP80YJFU00@0ZZZZ0:b/[02/[:`0Zj^[0P2SXj<01022PX80FUYJ05YJFP2SXj<2
0::RXP80Zj^[0P2BTY80102SXj<0PX:208:2PP2>SXh209JFUP0408n?S`26QXH0QXJ609ZJVP80FUYJ
00@0Q8B404M7A`17AdL0T92@0P2JVYX0102OWil0VIVI09VIV@1`L70206e]K@0406QXJ01`L700L71`
09>CT`80YZJV00@0K6a/07]kN`1kNg/0Ti>C0P2NWYh0102PX:00Y:BT0:BTY02WYjL20:>SX`040:JV
Y_oooooooooo0?n000l0003o0P3oP00C0000o`030?n000000?l0003o0180003o00<0oh000000o`00
0?l04@000?l20?n001<0003o00<0oh000000o`000?l03`000?l00`3oP000003o0000o`0A0000o`80
oh004P000?l0103oP000003o0?n0003oP00L0000o`[ooooo0009ooooo`040;6a/@2TY:@0Y:BT0:6Q
X@80WYjN00@0UYJF096AT@2ATI40W9bL0P2QXJ40102DU9@0Ph>308>3P`25QHD203Xj>P0406UYJ@23
Ph<0Ph>308n?S`80VYZJ00@0T92@08R8R028R8P0Ph>30P2@T900102NWYh0TY:B09:BTP25QHD307Mg
M`80;Rh^00@0PH6108n?S`2?Shl0T92@0P2?Shl01@1nOWh0NGUi07UiN@1oOgl0Rh^;0080WYjN00@0
OWin06e]K@1]KFd0MWIf0P1`L700100m?Cd0SXj>08j>SP2OWil20::RXP040:FUY@2TY:@0Y:BT0:6Q
X@80UYJF00@0Rh^;079bLP1bLW80Ph>30P1mOGd0102?Shl0WIfM09fMW@0`<30209ZJVP0409bLW02N
WYh0WYjN096AT@80UIFE00@0Ti>C08>3P`23Ph<0R8R80P21PH401@2JVYX0XJ6Q09BDU02DU9@0Kfm_
0080GemO00@0UYJF096AT@2ATI40W9bL0P2MWId0102@T900U9BD09BDU02?Shl209jNWP040:NWY`2]
[Jd0[Jf]0:^[Z`80I6AT00<0X:2P0:FUY@2UYJD0102WYjL20:JVYP040:VYZ@2UYJD0YJFU0:NWY`80
ZJVY00@0YZJV0:BTY02TY:@0SHf=0P1PH6001@2OWil0Xj>S0:>SX`2_[jl0UYJF0080[:b/00@0WIfM
08:2PP22PX80U9BD0P2JVYX0102IVIT0TY:B09:BTP2LW9`203lo?`0304a<C01ADE40DE5A00<0QXJ6
00@0R8R808V9R@29RHT0Fe]K0P1XJ6P0101CDe<0M7Ad07AdM02IVIT20:6QX@0405]KF`1lO7`0O7al
0861P@80UiNG00@0W9bL0:FUY@2UYJD0X:2P0P2OWil0102SXj?oooooooooo`3oP00?0000o`80oh00
4`000?l00`3oP000003o0000o`0B0000o`030?n000000?l0003o0140003o0P3oP00R0000o`030?n0
00000?l0003o01T0003o00<0oh000000o`000?l030000?l40?n000H0003o00@0oh000000o`000?l0
oh001@000?l00`3oP000003o0000o`0:0000o`[ooooo0009ooooo`040;6a/@2TY:@0Y:BT0:6QX@80
WYjN00@0UYJF096AT@2ATI40W9bL0P2QXJ40102DU9@0Ph>308>3P`25QHD203Xj>P0406UYJ@23Ph<0
Ph>308n?S`80VYZJ00@0T92@08R8R028R8P0Ph>30P2@T900102NWYh0TY:B09:BTP25QHD307MgM`80
;Rh^00@0PH6108n?S`2?Shl0T92@0P2?Shl01@1nOWh0NGUi07UiN@1oOgl0Rh^;0080WYjN00@0OWin
06e]K@1]KFd0MWIf0P1`L700100m?Cd0SXj>08j>SP2OWil20::RXP040:FUY@2TY:@0Y:BT0:6QX@80
UYJF00@0Rh^;079bLP1bLW80Ph>30P1mOGd0102?Shl0WIfM09fMW@0`<30209ZJVP0409bLW02NWYh0
WYjN096AT@80UIFE00@0Ti>C08>3P`23Ph<0R8R80P21PH401@2JVYX0XJ6Q09BDU02DU9@0Kfm_0080
GemO00@0UYJF096AT@2ATI40W9bL0P2MWId0102@T900U9BD09BDU02?Shl209jNWP040:NWY`2][Jd0
[Jf]0:^[Z`80I6AT00<0X:2P0:FUY@2UYJD0102WYjL20:JVYP040:VYZ@2UYJD0YJFU0:NWY`80ZJVY
00@0YZJV0:BTY02TY:@0SHf=0P1PH6001@2OWil0Xj>S0:>SX`2_[jl0UYJF0080[:b/00@0WIfM08:2
PP22PX80U9BD0P2JVYX0102IVIT0TY:B09:BTP2LW9`203lo?`0304a<C01ADE40DE5A00<0QXJ600@0
R8R808V9R@29RHT0Fe]K0P1XJ6P0101CDe<0M7Ad07AdM02IVIT20:6QX@0405]KF`1lO7`0O7al0861
P@80UiNG00@0W9bL0:FUY@2UYJD0X:2P0P2OWil0102SXj?oooooooooo`3oP00?0000o`80oh004`00
0?l00`3oP000003o0000o`0B0000o`030?n000000?l0003o0140003o0P3oP00R0000o`030?n00000
0?l0003o01T0003o00<0oh000000o`000?l030000?l40?n000H0003o00@0oh000000o`000?l0oh00
1@000?l00`3oP000003o0000o`0:0000o`[ooooo0009ooooo`040:^[Z`2UYJD0YJFU0:FUY@80WinO
00@0VYZJ096AT@2ATI40Vi^K0P2MWId0102=SHd0Q8B408B4Q029RHT20451@@0407QhN02<S8`0S8b<
08F5Q@80Rh^;00@0RXZ:08N7Q`27QhL0R8R80P23Ph<0102GUiL0RXZ:08Z:RP1ZJVX2065QH@04075a
L@0_;bl0;bl_08J6QP80Ti>C00@0VIVI08R8R028R8P0NGUi0P1jNWX01@1iNGT0QhN70:BTY02TY:@0
Rh^;0080JFUY00@0IFEU05IFEP1FEUH0<30`0P21PH401029RHT0U9BD09BDU02GUiL209>CT`0408b<
S029RHT0RHV907UiN@80MWIf00@0P82009>CT`2CTi<0UYJF0P2<S8`01010@400Ti>C09>CT`2GUiL2
08j>SP0408>3P`29RHT0RHV908N7Q`80RHV900@0VYZJ08n?S`2?Shl0Ti>C0`2?Shl0101YJFT0DU9B
059BDP1UIFD2069RHP0406QXJ01^KVh0KVi^06m_K`80M7Ad00@0LG5a07UiN@1iNGT0SHf=0P2EUID0
101hN7P0Cdm?04m?C`1nOWh209NGU`0309FEU@2QXJ40XJ6Q00<0YJFU00@0YjNW0:>SX`2SXj<0UiNG
0P2VYZH0102IVIT0Vi^K09^KV`25QHD206QXJ0<0UYJF00D0/;2`0;Fe]@2ZZZX0ZZZZ09FEU@0209bL
W00408^;R`2GUiL0UiNG09ZJVP80UiNG00@0WYjN03Ti>@0i>CT0D51@0P1TI6@0102BTY80RHV908V9
R@2;Rh/206=SH`0404Q8B01JFUX0FUYJ051@D080NGUi0`23Ph<0100n?Sh0JFUY06UYJ@2GUiL20::R
XP0409VIV@2ATI40TI6A09jNWP80XJ6Q00<0X:2Pooooooooool040000?l20?n001<0003o00<0oh00
0000o`000?l040000?l30?n001<0003o0P3oP00C0000o`030?n000000?l0003o00l0003o00<0oh00
0000o`000?l05P000?l30?n000`0003o0P3oP0080000o`@0oh001@000?l00`3oP000003o0000o`0:
0000o`[ooooo0009ooooo`04071`L01WIfL0IfMW06][J`80J6QX00@0HV9R06=SH`1SHf<0I6AT0P1V
IVH0101CDe<0F5QH05QHF01QHF4203Hf=P0304I6AP1FEUH0EUIF00<0E5AD00@0DU9B05=CD`1CDe<0
CDe=0P17AdL0101<C4`0CTi>04i>CP0g=cL203Xj>P040410@00N7Qh07QhN055AD@80Fe]K00@0I6AT
065QH@1QHF40I6AT0P1RHV801@1MGEd0Hf=S06ATI01TI6@0H61P0080Cdm?00@0ADE503Lg=`0g=cL0
;2`/0P1FEUH0101IFET0FUYJ05YJFP1OGel205]KF`0404Y:BP14A4@0A4A4055AD@80ATI600@0B4Q8
04];B`1;Bd/0Bd];0P13@d<0100L71`0HV9R069RHP1NGUh206ATI00405iNGP1HF5P0F5QH059BDP80
FEUI00D0IVIV059BDP1BDU80GemO05eMG@0204E5A@0403Ph>00_;bl0;bl_04A4A080@d=300@0>SXj
038b<P0b<S80=CDe0P12@T80101@D500De=C05=CD`1CDe<205EEE@0402XZ:P0U9BD09BDU01hN7P80
BDU900@0EUIF05QHF01HF5P0B4Q80P19BDT0101;Bd/0?Cdm03dm?@10@40205ADE00404Q8B00k>c/0
>c/k024Q8@809BDU00D0;Bd]01HF5P0F5QH09BDU030`<00202TY:@0403De=@0Q8B408B4Q020P8080
9RHV00@09BDU02TY:@0Y:BT07alO0P0<30`00`0A4A407QhN01hN7P0302DU9@0401/K6`0L71`071`L
01PH60806ATI00@07AdM02LW9`0W9bL09bLW0P0];Bd0100T92@09RHV02HV9P0Z:RX2038b<P<092@T
00@0@4100451@@11@D40A4A40_ooool<0000o`<0oh0000<0003o0?n0003oP0005`3oP0060000o`80
oh0010000?l:0?n00080003o3`3oP00010000?l0oh000?n000000?l60?n00080003o00<0oh000000
o`000?l0GP3oP00:ooooo`002Oooool0101`L700IfMW06MWI`1[Jf/206QXJ004069RHP1SHf<0Hf=S
06ATI080IVIV00@0De=C05QHF01HF5P0HF5Q0P0f=SH00`16ATH0EUIF05IFEP0305ADE004059BDP1C
De<0De=C04e=C@80AdM700@0C4a<04i>CP1>CTh0=cLg0P0j>SX01010@4007QhN01hN7P1ADE4205]K
F`0406ATI01QHF40HF5Q06ATI080HV9R00D0GEeM06=SH`1TI6@0I6AT061PH00204m?C`0404E5A@0g
=cL0=cLg02`/;080EUIF00@0FEUI05YJFP1JFUX0GemO0P1KFe/0101:BTX0A4A404A4A01ADE4204I6
AP0404Q8B01;Bd/0Bd];04];B`80@d=300@071`L069RHP1RHV80GUiN0P1TI6@0101NGUh0F5QH05QH
F01BDU8205UIF@0506IVIP1BDU80DU9B05mOG`1MGEd00P15ADD0100h>3P0;bl_02l_;`14A4@204=3
@`0403Xj>P0b<S80<S8b03De=@80@T9200@0D51@05=CD`1CDe<0De=C0P1EEED0100Z:RX09BDU02DU
9@0N7Qh204U9B@0405IFEP1HF5P0F5QH04Q8B080BDU900@0Bd];03dm?@0m?Cd0@4100P1DE5@01018
B4P0>c/k03/k>`0Q8B4202DU9@0502d];@0F5QH05QHF02DU9@0`<3000P0Y:BT0100e=CD08B4Q024Q
8@0P820202HV9P0402DU9@0Y:BT0:BTY01lO7`8030`<00<04A4A01hN7P0N7Qh00`0U9BD0100K6a/0
71`L01`L700H61P201TI6@0401dM7@0W9bL09bLW02LW9`80;Bd]00@092@T02HV9P0V9RH0:RXZ0P0b
<S8302@T90040410@011@D40@D5104A4A0;ooooo30000?l30?n000030000o`3oP000oh0001L0oh00
1P000?l20?n000@0003o2P3oP0020000o`l0oh0000@0003o0?n0003oP000003o1P3oP0020000o`03
0?n000000?l0003o05h0oh002_ooool000Wooooo00@0IfMW05EEE@1EEED0@d=30P0i>CT0100H61P0
<C4a034a<@1LG5`20410@00404m?C`1CDe<0De=C04e=C@80G5aL00<0IFEU05iNGP1NGUh00`1MGEd0
101JFUX0EUIF05IFEP19BDT204i>CP0407]kN`1bLW80LW9b06YZJP80IfMW00@0J6QX06e]K@1]KFd0
Jf][0P1^KVh0101hN7P0KFe]06e]K@1cLg<206a/K0050410@01PH600JFUY06UYJ@1QHF400P1OGel0
0`1IFET0GUiN05iNGP03061PH004065QH@1RHV80HV9R05]KF`80I6AT00@0GUiN0492@P12@T80IFEU
0P1VIVH0101SHf<0Bd];04];B`1=CDd2065QH@0406i^KP1NGUh0GUiN05IFEP80FEUI00@0GUiN06EU
I@1UIFD0>c/k0P12@T801@1/K6`0Ng]k07]kN`1hN7P0Ng]k0080N7Qh00@0LW9b07EeM@1eMGD0LG5a
0P1SHf<0101WIfL0Jf][06][J`1ZJVX202TY:@0404Y:BP1VIVH0IVIV07EeM@80LG5a00@0OWin08R8
R028R8P0QXJ60P24Q8@0102:RXX0NGUi07UiN@1hN7P208:2PP04079bLP0[:b/0:b/[07]kN`80QHF5
00@0U9BD08R8R028R8P0SXj>0P2VYZH01@2NWYh0XZ:R0::RXP2PX:00XZ:R0080WinO00@0W9bL03hn
?P0n?Sh0NWYj0P25QHD0102?Shl0UiNG09NGU`2GUiL209ZJVP030::RXP2SXj<0Xj>S00<0WinO00@0
V9RH09>CT`2CTi<0IfMW0P1dM7@0102BTY80SXj>08j>SP26QXH20861P@04065QH@1ZJVX0JVYZ08Z:
RP80U9BD0`2=SHd0102EUID0Rh^;08^;R`1TI6@2ooooo`030000o`3oP000oh0000l0oh0000<0003o
0?n0003oP0002@3oP00A0000o`80oh001P000?l30?n000D0003o0P3oP00010000?l0oh000?n0003o
P0050000o`<0oh000`000?l60?n000040000o`3oP000oh000?n00180003o0`3oP00A0000o`80oh00
4P000?l00`3oP000003o0000o`0V0000o`[ooooo0009ooooo`040:n_[`2a/K40/K6a0;Bd]080ZZZZ
00@0?Shn05eMG@1MGEd0Ti>C0P1CDe<0101EEED0Ogmo07moO`25QHD208n?S`0408R8R02<S8`0S8b<
08F5Q@80Q8B400@0OWin07MgM`1gMgL0EEEE0P25QHD30;bl_0030;^k^`2e]KD0]KFe00<0][Jf00@0
];Bd0;2`/02`/;00/k>c0P2`/;001@2b/[80[jn_0:n_[`1LG5`0OGem0080QXJ600@0NGUi075aL@1a
LG40JFUY0P1WIfL0101UIFD0HF5Q065QH@1TI6@206][J`0406a/K01gMgL0MgMg07emO@80G5aL00@0
VYZJ09BDU02DU9@0UiNG0P2SXj<0102YZJT0Z:RX0:RXZ02ZZZX20:BTY0040:6QX@2RXZ80XZ:R0:BT
Y080ZJVY00@0M7Ad06YZJP1ZJVX0YJFU0P2XZ:P01@2[Zj/0ZZZZ0:>SX`2SXj<0YJFU0080Y:BT00@0
Xj>S0:BTY02TY:@0Xj>S0P2OWil0102PX:00=cLg03Lg=`1cLg<20:2PX0040:>SX`2VYZH0YZJV0:NW
Y`80YZJV00@0Y:BT0::RXP2RXZ80YJFU0P2?Shl0102CTi<0VYZJ09ZJVP1oOgl205=CD`0409FEU@2R
XZ80XZ:R09^KV`80V9RH00@0X:2P0::RXP2RXZ80YjNW0P2VYZH01@2UYJD0YjNW0:VYZ@2YZJT0VYZJ
0080=SHf00@0W9bL0:2PX02PX:00Z:RX0P2_[jl0102XZ:P0XZ:R0::RXP2UYJD20:JVYP040:FUY@2L
W9`0W9bL09JFUP80V9RH00@0G5aL0820P020P800WYjN0P2JVYX01028R8P0T92@092@T02HV9P209VI
V@0408N7Q`2:RXX0RXZ:08b<S080SHf=00@0X:2P08^;R`2;Rh/0MGEe0_ooool40?n00080003o0`3o
P00010000?l0oh000?n0003oP00>0000o`030?n000000?l0003o01<0oh004`000?l00`3oP000003o
0000o`0U0000o`030?n000000?l0003o0140003o0P3oP00B0000o`030?n000000?l0003o00<0003o
00<0oh000000o`000?l02P000?l00`3oP000003o0000o`0C0000o`[ooooo0009ooooo`040:n_[`2a
/K40/K6a0;Bd]080ZZZZ00@0?Shn05eMG@1MGEd0Ti>C0P1CDe<0101EEED0Ogmo07moO`25QHD208n?
S`0408R8R02<S8`0S8b<08F5Q@80Q8B400@0OWin07MgM`1gMgL0EEEE0P25QHD30;bl_0030;^k^`2e
]KD0]KFe00<0][Jf00@0];Bd0;2`/02`/;00/k>c0P2`/;001@2b/[80[jn_0:n_[`1LG5`0OGem0080
QXJ600@0NGUi075aL@1aLG40JFUY0P1WIfL0101UIFD0HF5Q065QH@1TI6@206][J`0406a/K01gMgL0
MgMg07emO@80G5aL00@0VYZJ09BDU02DU9@0UiNG0P2SXj<0102YZJT0Z:RX0:RXZ02ZZZX20:BTY004
0:6QX@2RXZ80XZ:R0:BTY080ZJVY00@0M7Ad06YZJP1ZJVX0YJFU0P2XZ:P01@2[Zj/0ZZZZ0:>SX`2S
Xj<0YJFU0080Y:BT00@0Xj>S0:BTY02TY:@0Xj>S0P2OWil0102PX:00=cLg03Lg=`1cLg<20:2PX004
0:>SX`2VYZH0YZJV0:NWY`80YZJV00@0Y:BT0::RXP2RXZ80YJFU0P2?Shl0102CTi<0VYZJ09ZJVP1o
Ogl205=CD`0409FEU@2RXZ80XZ:R09^KV`80V9RH00@0X:2P0::RXP2RXZ80YjNW0P2VYZH01@2UYJD0
YjNW0:VYZ@2YZJT0VYZJ0080=SHf00@0W9bL0:2PX02PX:00Z:RX0P2_[jl0102XZ:P0XZ:R0::RXP2U
YJD20:JVYP040:FUY@2LW9`0W9bL09JFUP80V9RH00@0G5aL0820P020P800WYjN0P2JVYX01028R8P0
T92@092@T02HV9P209VIV@0408N7Q`2:RXX0RXZ:08b<S080SHf=00@0X:2P08^;R`2;Rh/0MGEe0_oo
ool40?n00080003o0`3oP00010000?l0oh000?n0003oP00>0000o`030?n000000?l0003o01<0oh00
4`000?l00`3oP000003o0000o`0U0000o`030?n000000?l0003o0140003o0P3oP00B0000o`030?n0
00000?l0003o00<0003o00<0oh000000o`000?l02P000?l00`3oP000003o0000o`0C0000o`[ooooo
0009ooooo`040;>c/`2`/;00/;2`0:n_[`80Z:RX00@0@D5105UIF@1IFET0R8R80P19BDT0101DE5@0
NGUi07UiN@1gMgL207moO`0407YjNP1lO7`0O7al0820P080MgMg00@0O7al07=cL`1cLg<0Cdm?0P28
R8P0102f][H0^;Rh0;Rh^02c/k<20:^[Z`040:f][@2YZJT0ZJVY0:2PX080Xj>S00@0YJFU09ZJVP2J
VYX0YjNW0P2UYJD01@1RHV80MWIf08N7Q`27QhL0QHF50080Hf=S00@0Lg=c06QXJ01XJ6P0HF5Q0P1K
Fe/0101CDe<0EUIF05IFEP1QHF42069RHP0406QXJ01EEED0EEEE09FEU@80XJ6Q00@0WIfM0:6QX@2Q
XJ40YJFU0P2VYZH0102^[Zh0YZJV0:JVYP2KVi/30:2PX080YJFU00<0IVIV06YZJP1ZJVX00`2WYjL0
1@2/[:`0Y:BT0:6QX@2QXJ40Y:BT0080XZ:R00@0XJ6Q0::RXP2RXZ80Y:BT0P2RXZ80102LW9`0?3`l
03`l?01aLG4208n?S`040:>SX`2TY:@0Y:BT0:BTY080VIVI00@0X:2P0:>SX`2SXj<0X:2P0P1nOWh0
102DU9@0VIVI09VIV@1]KFd2059BDP0409RHV02JVYX0VYZJ09^KV`80WinO00@0YJFU0:2PX02PX:00
Xj>S0P2@T9001@2OWil0ZZZZ0:6QX@2QXJ40L71`00809BDU00@0Ti>C0:2PX02PX:00ZZZZ0P2`/;00
102][Jd0[Zj^0:j^[P2[Zj/20:6QX@<0WYjN00@0V9RH08^;R`2;Rh/0E5AD0P1fMWH0102EUID0VYZJ
09ZJVP2OWil208^;R`0408R8R02OWil0WinO08Z:RP80NWYj00@0SXj>0:BTY02TY:@0ZZZZ0P2<S8`0
0`1aLG7oooooooooo`040?n00080003o0`3oP00010000?l0oh000?n0003oP00>0000o`030?n00000
0?l0003o00@0oh0000<0003o0?n0003oP0005P000?l40?n000D0003o00<0oh000000o`000?l01`00
0?l20?n001`0003o00<0oh000000o`000?l04@000?l20?n00180003o00<0oh000000o`000?l00`00
0?l40?n000T0003o00<0oh000000o`000?l04`000?l:ooooo`002Oooool0102][Jd0Z:RX0:RXZ02T
Y:@209:BTP040410@018B4P0B4Q807inOP80ADE500@0EeMG08:2PP22PX80NWYj0P1kNg/0101nOWh0
L71`071`L01jNWX207UiN@0407YjNP1hN7P0N7Qh04I6AP80OWin00<0/;2`0:ZZZP2ZZZX00`2NWYh0
102OWil0X:2P0:2PX02JVYX208b<S004092@T023Ph<0Ph>309>CT`80TY:B00D0J6QX06m_K`26QXH0
QXJ608>3P`0206][J`04079bLP1hN7P0N7Qh08F5Q@80S8b<00@0TI6A09:BTP2BTY80QXJ60P1eMGD0
101cLg<0F5QH05QHF02?Shl209JFUP0409>CT`2MWId0WIfM09jNWP80XJ6Q00@0XZ:R09RHV02HV9P0
SXj>0P29RHT0102;Rh/0UYJF09JFUP1JFUX206YZJP050:>SX`2QXJ40XJ6Q0:6QX@2IVIT00P2HV9P0
102MWId0VIVI09VIV@2@T9020:>SX`040:FUY@2RXZ80XZ:R09nOW`80=CDe00@0E5AD07emO@1mOGd0
VIVI0P2RXZ80102GUiL0U9BD09BDU02LW9`20:>SX`0409fMW@1WIfL0IfMW07YjNP80L71`00@0IVIV
06=SH`1SHf<0Xj>S0P2QXJ40102RXZ80YJFU0:FUY@2VYZH20:2PX00509NGU`1gMgL0MgMg0820P02@
T9000P1lO7`0101aLG40?Shn03hn?P2BTY8209jNWP040:^[Z`2YZJT0ZJVY0:JVYP80Z:RX00@0Y:BT
09nOW`2OWil0WYjN0P2GUiL0102NWYh0Q8B408B4Q00o?cl207EeM@<0Rh^;00@0UIFE08B4Q024Q8@0
O7al0P2ATI400`1gMgL0NWYj07YjNP0309nOW`040:RXZ023Ph<0Ph>306][J`;ooooo00<0oh000000
o`000?l00`000?l30?n000040000o`3oP000oh000?n000h0003o00@0oh000000o`000?l0oh009@00
0?l00`3oP000003o0000o`0@0000o`80oh004`000?l30?n002D0003o00<0oh000000o`000?l04000
0?l00`3oP000003o0000o`0C0000o`[ooooo0009ooooo`040:f][@2XZ:P0Z:RX0:BTY080TY:B00@0
@41004Q8B018B4P0OWin0P15ADD0101GEeL0PX:208:2PP1jNWX207]kN`0407inOP1`L700L71`07Yj
NP80NGUi00@0NWYj07QhN01hN7P0ATI60P1nOWh00`2`/;00ZZZZ0:ZZZP0309jNWP0409nOW`2PX:00
X:2P09ZJVP80S8b<00@0T92@08>3P`23Ph<0Ti>C0P2BTY801@1XJ6P0Kfm_08J6QP26QXH0Ph>30080
Jf][00@0LW9b07QhN01hN7P0QHF50P2<S8`0102ATI40TY:B09:BTP26QXH207EeM@0407=cL`1HF5P0
F5QH08n?S`80UYJF00@0Ti>C09fMW@2MWId0WYjN0P2QXJ40102RXZ80V9RH09RHV02>SXh208V9R@04
08^;R`2FUYH0UYJF05YJFP80JVYZ00D0Xj>S0:6QX@2QXJ40XJ6Q09VIV@0209RHV00409fMW@2IVIT0
VIVI092@T080Xj>S00@0YJFU0::RXP2RXZ80WinO0P0e=CD0101DE5@0OGem07emO@2IVIT20::RXP04
09NGU`2DU9@0U9BD09bLW080Xj>S00@0WIfM06MWI`1WIfL0NWYj0P1`L700101VIVH0Hf=S06=SH`2S
Xj<20:6QX@040::RXP2UYJD0YJFU0:JVYP80X:2P00D0UiNG07MgM`1gMgL0P820092@T00207alO004
075aL@0n?Sh0?Shn09:BTP80WYjN00@0Zj^[0:VYZ@2YZJT0YZJV0P2XZ:P0102TY:@0WinO09nOW`2N
WYh209NGU`0409jNWP24Q8@0Q8B403lo?`80MGEe0`2;Rh/0102EUID0Q8B408B4Q01lO7`2096AT@03
07MgM`1jNWX0NWYj00<0WinO00@0Z:RX08>3P`23Ph<0Jf][0_ooool00`3oP000003o0000o`030000
o`<0oh0000@0003o0?n0003oP000oh003P000?l0103oP000003o0000o`3oP00U0000o`030?n00000
0?l0003o0100003o0P3oP00C0000o`<0oh009@000?l00`3oP000003o0000o`0@0000o`030?n00000
0?l0003o01<0003o2_ooool000Wooooo00@0P82006YZJP1ZJVX0B4Q80P1EEED0100m?Cd0EEEE05EE
E@1[Jf/204e=C@04069RHP1MGEd0GEeM06IVIP80MgMg00@0IfMW05UIF@1IFET0K6a/0P1_Kfl0101U
IFD0E5AD05ADE00g=cL205IFEP0409NGU`2DU9@0U9BD092@T080RHV900@0PH6107IfMP1fMWH0MGEe
0P1cLg<0101ZJVX0I6AT06ATI01@D50204A4A00503<c<`0V9RH0EEEE05EEE@1?Cdl00P1:BTX0101A
DE40Cdm?04m?C`1UIFD305YJFP80IfMW00@0EUIF055AD@1ADE40Cdm?0P0U9BD0101@D500FUYJ05YJ
FP1FEUH206QXJ00406a/K01PH600H61P06IVIP80L71`00@0IfMW05YJFP1JFUX0DU9B0P1NGUh01011
@D40CDe=04e=C@1hN7P2075aL@0506ATI01XJ6P0HV9R069RHP1VIVH00P1GEeL0101ADE40Hf=S06=S
H`1]KFd206a/K00406IVIP0_;bl0;bl_03dm?@80EeMG00@0G5aL06e]K@1]KFd0LW9b0P1_Kfl3079b
LP0406IVIP1;Bd/0Bd];055AD@80>CTi00@0:2PX0410@010@400EUIF0P1IFET0101EEED0GUiN05iN
GP1NGUh205mOG`0505YJFP1NGUh0GUiN05]KF`1WIfL00P1GEeL0101=CDd08B4Q024Q8@16ATH205EE
E@04061PH01HF5P0F5QH05MGE`80GemO00<0GUiN05]KF`1KFe/00`1DE5@0101:BTX0?Shn03hn?P0Z
:RX204=3@`04051@D015ADD0ADE505=CD`80EeMG00@0De=C05ADE01DE5@0B4Q80P14A4@304Q8B004
04a<C00b<S80<S8b03Ph>0;ooooo0`000?l60?n000040000o`3oP000oh000000o`80oh0010000?l2
0?n000@0003o1@3oP00>0000o`h0oh0000D0003o0?n0003oP000oh000000o`0;0?n000T0003o1`3o
P0090000o`<0oh001P000?l60?n000T0003o3P3oP0020000o`@0oh000P000?l70?n00080003o0`3o
P0000`000?l0oh000?n0000M0?n000[ooooo0009ooooo`04061PH00`<300<30`02PX:080E5AD00@0
Fe]K055AD@1ADE40A4A40P0n?Sh00`0L71`08R8R028R8P0305=CD`0404];B`19BDT0BDU903Hf=P80
71`L00@02PX:055AD@1ADE40G5aL0P1]KFd0101XJ6P0JVYZ06YZJP12@T82024Q8@0403/k>`18B4P0
B4Q804a<C080DE5A00@0Fe]K04A4A014A4@0:BTY0`1KFe/305iNGP04065QH@18B4P0B4Q802HV9P80
EeMG00@0JVYZ075aL@1aLG40Lg=c0P1jNWX00`0o?cl09BDU02DU9@0305YJFP0405mOG`1SHf<0Hf=S
05aLG080:2PX00@0=cLg06EUI@1UIFD0LG5a0P21PH400`1gMgL0LW9b079bLP0302/[:`<0ADE500D0
Cdm?05=CD`1CDe<0820P02XZ:P0206EUI@0406a/K01MGEd0GEeM069RHP80GemO00<0@41004U9B@19
BDT00`1XJ6P0101TI6@0HF5Q065QH@0o?cl201hN7P0404I6AP1SHf<0Hf=S069RHP80Jf][00@0Lg=c
02XZ:P0Z:RX0AdM70P1hN7P01025QHD0R8R808R8R01kNg/206IVIP0402/[:`1ZJVX0JVYZ0861P@80
QhN700D0RHV908R8R028R8P0BTY:0492@P0206][J`0408B4Q02>SXh0SXj>08^;R`80FUYJ00@01`L7
03<c<`0c<c<0E5AD0P14A4@0100h>3P0HV9R069RHP1CDe<201TI6@0406ATI01kNg/0Ng]k08R8R080
RXZ:00@0OGem04Y:BP1:BTX0=SHf0`1]KFd2071`L00407alO01nOWh0OWin03hn?P80I6AT00@0PX:2
08j>SP2>SXh0U9BD0_ooool00`000?l0oh000?n0000I0?n000@0003o503oP0000`000?l0oh000?n0
00030?n000D0003o1P3oP0030000o`D0oh001`000?l<0?n000<0003o00@0oh000000o`000?l0003o
0`3oP0060000o`D0oh001P000?l30?n000L0003o00<0oh000000o`000?l01P000?l30?n000H0003o
203oP0020000o`<0oh001`000?l30?n000P0003o00<0oh000000o`000?l010000?l:ooooo`002Ooo
ool0101PH600<30`030`<00X:2P205ADE00405]KF`1ADE40DE5A04A4A080?Shn00<071`L028R8P0R
8R800`1CDe<0101;Bd/0BDU904U9B@0f=SH201`L700400X:2P1ADE40DE5A05aLG080KFe]00@0J6QX
06YZJP1ZJVX0@T920P0Q8B40100k>c/0B4Q804Q8B01<C4`2055AD@0405]KF`14A4@0A4A402TY:@<0
Fe]K0`1NGUh0101QHF40B4Q804Q8B00V9RH205MGE`0406YZJP1aLG40LG5a07=cL`80NWYj00<0?clo
02DU9@0U9BD00`1JFUX0101OGel0Hf=S06=SH`1LG5`202PX:00403Lg=`1UIFD0IFEU075aL@80PH61
00<0MgMg079bLP1bLW800`0[:b/304E5A@0504m?C`1CDe<0De=C020P800Z:RX00P1UIFD0101/K6`0
GEeM05eMG@1RHV8205mOG`030410@019BDT0BDU900<0J6QX00@0I6AT065QH@1QHF40?clo0P0N7Qh0
1016ATH0Hf=S06=SH`1RHV8206][J`0407=cL`0Z:RX0:RXZ04M7A`80N7Qh00@0QHF508R8R028R8P0
Ng]k0P1VIVH0100[:b/0JVYZ06YZJP21PH4208N7Q`0508V9R@28R8P0R8R804Y:BP12@T800P1[Jf/0
1024Q8@0SXj>08j>SP2;Rh/205YJFP0400L71`0c<c<0<c<c05ADE080A4A400@0>3Ph069RHP1RHV80
De=C0P0I6AT0101TI6@0Ng]k07]kN`28R8P208Z:RP0407emO@1:BTX0BTY:03Hf=P<0KFe]0P1`L700
101lO7`0OWin07inOP0n?Sh206ATI00408:2PP2>SXh0SXj>09BDU0;ooooo00<0003o0?n0003oP000
6@3oP0040000oa@0oh0000<0003o0?n0003oP0000`3oP0050000o`H0oh000`000?l50?n000L0003o
303oP0030000o`040?n000000?l0003o0000o`<0oh001P000?l50?n000H0003o0`3oP0070000o`03
0?n000000?l0003o00H0003o0`3oP0060000o`P0oh000P000?l30?n000L0003o0`3oP0080000o`03
0?n000000?l0003o00@0003o2_ooool000Wooooo00@0_;bl06UYJ@1YJFT0E5AD0P2ZZZX0102DU9@0
QhN708N7Q`29RHT2092@T00403Ph>019BDT0BDU909NGU`80Y:BT00@0/;2`0;>c/`2c/k<0Xj>S0P1@
D500100Z:RX0/[:b0;:b/P2c/k<20;Rh^0040;^k^`2l_;`0_;bl07emO@806QXJ00@0UYJF0:FUY@2U
YJD0Vi^K0`2JVYX207QhN00503@d=026QXH0QXJ608B4Q01eMGD00P21PH40101kNg/0De=C05=CD`14
A4@208>3P`0408f=S@2DU9@0U9BD08b<S080T92@00@0EeMG03De=@0e=CD0XZ:R0P2KVi/0102FUYH0
X:2P0:2PX02RXZ8205EEE@04065QH@2UYJD0YJFU0:JVYP<0ZJVY0P2ATI40100n?Sh0O7al07alO02;
Rh/208R8R00508b<S01nOWh0OWin07UiN@1ADE400`2RXZ820:VYZ@040:^[Z`28R8P0R8R806=SH`80
M7Ad00@0X:2P09JFUP2FUYH0QhN70P2HV9P0102NWYh0@T920492@P2MWId209^KV`0409FEU@2PX:00
X:2P09jNWP80EUIF00@0NGUi0:2PX02PX:00YZJV0P2WYjL0102VYZH0V9RH09RHV00i>CT208b<S004
0:RXZ02ZZZX0ZZZZ0:FUY@80Y:BT00D0EeMG07=cL`2^[Zh0[Zj^0;Bd]0020;>c/`040;Bd]025QHD0
QHF501DE5@80Ng]k00@0YZJV0::RXP2RXZ80YJFU0P2[Zj/0102BTY807QhN01hN7P2;Rh/208n?S`04
096AT@2LW9`0W9bL0:BTY080F5QH00@0=CDe09NGU`2GUiL0X:2P0P2][Jd30;Bd]00404I6AP2@T900
T92@0:ZZZP80/[:b00@0^;Rhooooooooool0oh000P000?l00`3oP000003o0000o`060000o`<0oh00
0`000?l30?n000030000o`3oP000oh0000P0oh000P000?l00`3oP000003o0000o`070000o`80oh00
1`000?l30?n000L0003o0`3oP0080000o`030?n000000?l0003o00L0003o0P3oP0090000o`030?n0
00000?l0003o0100003o00<0oh000000o`000?l01P000?l00`3oP000003o0000o`070000o`030?n0
00000?l0003o00H0003o00<0oh000000o`000?l01P3oP0000`000?l0oh000?n000080000o`80oh00
1`000?l30?n000<0003o1P3oP0030000o`<0oh002_ooool000Wooooo00@0^k^k069RHP1RHV80CDe=
0P2SXj<0102VYZH0X:2P0:2PX02CTi<207moO`04034a<@19BDT0BDU90:BTY080WinO00@0WYjN0:^[
Z`2[Zj/0Z:RX0P1FEUH0100Y:BT0[Zj^0:j^[P2i^KT20;bl_0040;Ng]`2i^KT0^KVi07AdM0807alO
00@0XZ:R0:FUY@2UYJD0T92@0P2=SHd0102?Shl0LW9b079bLP0];Bd208R8R005092@T02HV9P0T92@
092@T01kNg/00P17AdL0100c<c<0MgMg07MgM`2ATI4209VIV@04096AT@2JVYX0VYZJ05ADE080;2`/
00<0WIfM0::RXP2RXZ800`2LW9`0102OWil0De=C05=CD`1XJ6P20:FUY@040:VYZ@2XZ:P0Z:RX0:2P
X080U9BD00@0@d=307QhN01hN7P0Ng]k0P2@T9001@2DU9@0KFe]06e]K@1<C4`0EUIF0080TY:B00@0
VYZJ0:JVYP2VYZH0[Zj^0P2ZZZX0101HF5P0MgMg07MgM`2EUID208>3P`0408B4Q02<S8`0S8b<08:2
PP80CDe=00@0XJ6Q0:2PX02PX:00SXj>0P26QXH0102FUYH0FUYJ05YJFP1nOWh20:b/[0040:ZZZP2Y
ZJT0ZJVY09ZJVP80T92@00@0A4A40:2PX02PX:00/;2`0P2c/k<01@2a/K40[Zj^0:j^[P1XJ6P0NGUi
0080[Jf]00@0][Jf0;Rh^02h^;P0][Jf0P29RHT0100?3`l0Kfm_06m_K`2QXJ420:NWY`040:ZZZP2]
[Jd0[Jf]0:JVYP807AdM00@0PH6109FEU@2EUID0WIfM0P2PX:00102KVi/0C4a<04a<C011@D420:NW
Y`040:VYZ@2[Zj/0Zj^[0:b/[080YJFU00@0@d=308^;R`2;Rh/0Zj^[0P2][Jd0102d];Cooooooooo
o`3oP0020000o`030?n000000?l0003o00H0003o0`3oP0070000o`X0oh000P000?l00`3oP000003o
0000o`070000o`80oh001`000?l30?n000L0003o0`3oP0080000o`030?n000000?l0003o00L0003o
0P3oP0070000o`<0oh0010000?l20?n000030000o`3oP000oh0000T0003o00<0oh000000o`000?l0
1P000?l00`3oP000003o0000o`070000o`030?n000000?l0003o00H0oh000`000?l60?n000030000
o`3oP000oh0000D0003o0P3oP0000`000?l0oh000?n000070000o`<0oh0020000?l0103oP000003o
0000o`000?l30?n000[ooooo0009ooooo`040;Ng]`1WIfL0IfMW05EEE@80Y:BT00@0YJFU0:>SX`2S
Xj<0WIfM0P22PX80100l?3`0C4a<04a<C02OWil209jNWP0409ZJVP2TY:@0Y:BT0:BTY080F5QH00@0
:2PX0:f][@2][Jd0^;Rh0P2b/[80102_[jl0];Bd0;Bd]01eMGD2028R8P0409jNWP2RXZ80XZ:R09bL
W080V9RH00@0U9BD06e]K@1]KFd0=cLg0P2=SHd01@2IVIT0QHF508^;R`2;Rh/0T92@0080GemO00@0
?Cdm08j>SP2>SXh0Y:BT0P2ZZZX30:BTY00407MgM`16ATH0ATI60:6QX@<0XZ:R0P2ATI40102MWId0
GUiN05iNGP1WIfL20:NWY`040:j^[P2_[jl0[jn_0::RXP80Ti>C00@0>c/k08j>SP2>SXh0WinO0P2A
TI401@26QXH0HV9R069RHP0j>SX0@D510080MWIf00@0Ogmo08Z:RP2:RXX0Ti>C0P28R8P0101ADE40
NGUi07UiN@2<S8`207moO`0408>3P`2:RXX0RXZ:08f=S@80AdM700@0Shn?09nOW`2OWil0V9RH0P2;
Rh/0102JVYX0H61P061PH01aLG430:RXZ080YjNW00@0W9bL09>CT`2CTi<0>SXj0P2][Jd0102h^;P0
];Bd0;Bd]02c/k<20;:b/P0505aLG02;Rh/0]kNg0;Ng]`2i^KT00P2f][H0102ZZZX0QXJ608J6QP14
A4@20861P@040:FUY@2[Zj/0Zj^[0;6a/@80/;2`00@0WinO028R8P0R8R80RXZ:0P2EUID0102PX:00
Xj>S0:>SX`2WYjL205mOG`0405aLG02[Zj/0Zj^[0:BTY080TI6A00@0OGem07alO01lO7`0=cLg0P2;
Rh/0102VYZH0ZZZZ0:ZZZP2[Zj/2ooooo`040?n000000?l0003o0?n000P0003o0`3oP0070000o`X0
oh000P000?l00`3oP000003o0000o`070000o`80oh002@000?l00`3oP000003o0000o`070000o`03
0?n000000?l0003o00H0003o00@0oh000000o`000?l0003o0`3oP0030000o`80oh001`000?l30?n0
00L0003o0P3oP0090000o`030?n000000?l0003o0100003o2P3oP0020000o`@0oh000`000?l20?n0
00@0003o0`3oP0000`000?l0oh000?n000090000o`030?n000000?l0003o00H0003o00<0oh000000
o`000?l010000?l:ooooo`002Oooool0102g]kL0IfMW06MWI`1EEED20:BTY0040:FUY@2SXj<0Xj>S
09fMW@80PX:200@0?3`l04a<C01<C4`0WinO0P2NWYh0102JVYX0Y:BT0:BTY02TY:@205QHF00402PX
:02][Jd0[Jf]0;Rh^080/[:b00@0[jn_0;Bd]02d];@0MGEe0P0R8R80102NWYh0XZ:R0::RXP2LW9`2
09RHV00409BDU01]KFd0KFe]03Lg=`80SHf=00D0VIVI08F5Q@2;Rh/0Rh^;092@T00205mOG`0403dm
?@2>SXh0SXj>0:BTY080ZZZZ0`2TY:@0101gMgL0ATI604I6AP2QXJ430::RXP80TI6A00@0WIfM05iN
GP1NGUh0IfMW0P2WYjL0102^[Zh0[jn_0:n_[`2RXZ8209>CT`0403/k>`2>SXh0SXj>09nOW`80TI6A
00D0QXJ6069RHP1RHV80>SXj0451@@0207IfMP0407moO`2:RXX0RXZ:09>CT`80R8R800@0DE5A07Ui
N@1iNGT0S8b<0P1oOgl01023Ph<0RXZ:08Z:RP2=SHd204M7A`0408n?S`2OWil0WinO09RHV080Rh^;
00@0VYZJ061PH01PH600LG5a0`2XZ:P20:NWY`0409bLW02CTi<0Ti>C03Xj>P80[Jf]00@0^;Rh0;Bd
]02d];@0/k>c0P2b/[801@1LG5`0Rh^;0;Ng]`2g]kL0^KVi0080][Jf00@0ZZZZ08J6QP26QXH0A4A4
0P21PH40102UYJD0Zj^[0:^[Z`2a/K420;2`/00409nOW`0R8R808R8R08Z:RP80UIFE00@0X:2P0:>S
X`2SXj<0YjNW0P1OGel0101LG5`0Zj^[0:^[Z`2TY:@2096AT@0407emO@1lO7`0O7al03Lg=`80Rh^;
00@0YZJV0:ZZZP2ZZZX0Zj^[0_ooool0103oP000003o0000o`3oP0080000o`<0oh001`000?l:0?n0
0080003o00<0oh000000o`000?l01`000?l20?n000T0003o00<0oh000000o`000?l01`000?l00`3o
P000003o0000o`060000o`040?n000000?l0003o0000o`<0oh000`000?l20?n000L0003o0`3oP007
0000o`80oh002@000?l00`3oP000003o0000o`0@0000o`X0oh000P000?l40?n000<0003o0P3oP004
0000o`<0oh0000<0003o0?n0003oP0002@000?l00`3oP000003o0000o`060000o`030?n000000?l0
003o00@0003o2_ooool000Wooooo00@0RHV9059BDP1BDU80FEUI0P2KVi/0102:RXX0VYZJ09ZJVP2K
Vi/208b<S00404M7A`0T92@092@T04M7A`80RXZ:00@0SXj>08^;R`2;Rh/0QHF50P19BDT0100L71`0
@d=304=3@`1fMWH209JFUP0409^KV`1RHV80HV9R05aLG0808B4Q1027QhL20861P@0407QhN00k>c/0
>c/k02LW9`80BTY:00D0FEUI06IVIP1fMWH0MWIf08F5Q@0205=CD`0404M7A`1hN7P0N7Qh08b<S080
TY:B00@0Ti>C092@T02@T900BDU90P0Y:BT0101^KVh0NWYj07YjNP1kNg/207UiN@0408b<S01BDU80
DU9B055AD@80Kfm_00@0O7al07UiN@1iNGT0Ng]k0P1]KFd0100^;Rh0MGEe07EeM@25QHD206QXJ005
05=CD`14A4@0A4A404Q8B00c<c<00P1XJ6P0101]KFd0Hf=S06=SH`1YJFT206IVIP0402l_;`1<C4`0
C4a<065QH@80IVIV00@0Hf=S06][J`1[Jf/0HV9R0P0F5QH010000000@4100410@01CDe<205UIF@04
06a/K014A4@0A4A4028R8P80?Cdm00@0KVi^06a/K01/K6`0JFUY0P1JFUX0100`<300EEEE05EEE@1H
F5P205EEE@0504Q8B014A4@0A4A402DU9@1EEED00P1KFe/0101VIVH0IFEU06EUI@1NGUh2038b<P04
01DE5@1JFUX0FUYJ07AdM0<0MgMg0P1/K6`0101QHF40:2PX02PX:01;Bd/205eMG@<0JFUY00@0Kfm_
0410@010@40071`L0P1WIfL0101YJFT0GEeM05eMG@1;Bd/204Y:BP0403<c<`1RHV80HV9R06UYJ@80
I6AT00@0H61Pooooooooool0003o0`3oP0080000o`@0oh001P000?l50?n000D0003o0`3oP0080000
o`H0oh0010000?l30?n000L0003o0`3oP0080000o`<0oh001`000?l20?n000@0003o1P3oP0070000
o`<0oh0020000?l70?n00080003o103oP0040000o`l0oh000`000?l60?n000L0003o1@3oP0040000
o`<0oh000`000?l60?n000H0003o2_ooool000Wooooo00@0GemO05YJFP1JFUX0CTi>0P0P8200100C
4a<09BDU02DU9@0R8R8203dm?@<0?clo00@0;2`/02<S8`0S8b<0;2`/0P0a<C40100j>SX0@T920492
@P19BDT201HF5P0400P8200E5AD05ADE024Q8@808b<S00@0:RXZ02d];@0];Bd0<S8b0P0c<c<0100a
<C40?3`l03`l?00m?Cd30410@0808R8R00D02PX:0492@P19BDT0BDU90492@P0203Ti>@0402/[:`0m
?Cd0?Cdm04E5A@80C4a<00@0CDe=04m?C`1?Cdl0EUIF0P1GEeL0100m?Cd05aLG01LG5`0^;Rh203dm
?@0403Xj>P10@400@41004Y:BP80EUIF00@0CDe=0410@010@400=SHf0P0k>c/0101ADE40DU9B059B
DP0];Bd2024Q8@0504A4A012@T80@T9204a<C011@D400P13@d<01018B4P0CTi>04i>CP1>CTh2059B
DP04069RHP1SHf<0Hf=S05iNGP808R8R00@0?3`l05EEE@1EEED0IVIV0P1eMGD01023Ph<0QXJ608J6
QP24Q8@207QhN004079bLP23Ph<0Ph>308J6QP80SHf=00@0JVYZ03Lg=`0g=cL0IFEU0P1ADE40101T
I6@0J6QX06QXJ01/K6`206i^KP0506MWI`1EEED0EEEE06][J`1nOWh00P21PH40101RHV80;2`/02`/
;01@D50207inOP0408R8R026QXH0QXJ607=cL`80LW9b00@0MWIf079bLP1bLW80I6AT0`1iNGT206YZ
JP040451@@1=CDd0CDe=06YZJP80KVi^00@0PH6108F5Q@25QHD0P8200P1cLg<0101IFET0BDU904U9
B@1YJFT208b<S00408R8R00j>SX0>SXj055AD@;ooooo00<0003o0?n0003oP000I03oP0030000o`H0
oh0040000?l20?n000030000o`3oP000oh0000L0003o0P3oP0060000o`<0oh0040000?l30?n000T0
003o0`3oP0040000o`<0oh002_ooool000Wooooo00@0GemO05YJFP1JFUX0CTi>0P0P8200100C4a<0
9BDU02DU9@0R8R8203dm?@<0?clo00@0;2`/02<S8`0S8b<0;2`/0P0a<C40100j>SX0@T920492@P19
BDT201HF5P0400P8200E5AD05ADE024Q8@808b<S00@0:RXZ02d];@0];Bd0<S8b0P0c<c<0100a<C40
?3`l03`l?00m?Cd30410@0808R8R00D02PX:0492@P19BDT0BDU90492@P0203Ti>@0402/[:`0m?Cd0
?Cdm04E5A@80C4a<00@0CDe=04m?C`1?Cdl0EUIF0P1GEeL0100m?Cd05aLG01LG5`0^;Rh203dm?@04
03Xj>P10@400@41004Y:BP80EUIF00@0CDe=0410@010@400=SHf0P0k>c/0101ADE40DU9B059BDP0]
;Bd2024Q8@0504A4A012@T80@T9204a<C011@D400P13@d<01018B4P0CTi>04i>CP1>CTh2059BDP04
069RHP1SHf<0Hf=S05iNGP808R8R00@0?3`l05EEE@1EEED0IVIV0P1eMGD01023Ph<0QXJ608J6QP24
Q8@207QhN004079bLP23Ph<0Ph>308J6QP80SHf=00@0JVYZ03Lg=`0g=cL0IFEU0P1ADE40101TI6@0
J6QX06QXJ01/K6`206i^KP0506MWI`1EEED0EEEE06][J`1nOWh00P21PH40101RHV80;2`/02`/;01@
D50207inOP0408R8R026QXH0QXJ607=cL`80LW9b00@0MWIf079bLP1bLW80I6AT0`1iNGT206YZJP04
0451@@1=CDd0CDe=06YZJP80KVi^00@0PH6108F5Q@25QHD0P8200P1cLg<0101IFET0BDU904U9B@1Y
JFT208b<S00408R8R00j>SX0>SXj055AD@;ooooo00<0003o0?n0003oP000I03oP0030000o`H0oh00
40000?l20?n000030000o`3oP000oh0000L0003o0P3oP0060000o`<0oh0040000?l30?n000T0003o
0`3oP0040000o`<0oh002_ooool000Wooooo00@0Y:BT09fMW@2MWId0X:2P0P1DE5@0101:BTX0L71`
071`L01ZJVX209ZJVP040:6QX@2PX:00X:2P08:2PP80KFe]00@0PH6108^;R`2;Rh/0Zj^[0P2_[jl0
102VYZH0@4100410@00<30`209ZJVP040:RXZ02WYjL0YjNW0:RXZ080XZ:R00@0YJFU09nOW`2OWil0
T92@0P28R8P0102KVi/0V9RH09RHV02LW9`206=SH`0501HF5P2XZ:P0YJFU0:FUY@2NWYh00P2DU9@0
0`1oOgl0TY:B09:BTP030:j^[P040;2`/02][Jd0[Jf]0:n_[`80];Bd00@0Vi^K024Q8@0Q8B40V9RH
0P2OWil0102CTi<0RXZ:08Z:RP23Ph<2096AT@0409:BTP2>SXh0SXj>07AdM080PX:200@0Xj>S0:^[
Z`2[Zj/0P8200P1=CDd01@2ZZZX0Vi^K09^KV`2HV9P0P8200080QXJ600@0Ti>C09FEU@2EUID0WIfM
0P2NWYh30:NWY`040:>SX`0o?cl0?clo05eMG@80QHF500@0Ph>309FEU@2EUID0UIFE0P2CTi<0102F
UYH0V9RH09RHV02CTi<209jNWP0409nOW`2RXZ80XZ:R0::RXP80KFe]00@0WYjN08N7Q`27QhL0RHV9
0P2RXZ80102PX:00Xj>S0:>SX`2BTY8308n?S`040:j^[P2d];@0];Bd0;2`/080AdM700@0Zj^[0:RX
Z02XZ:P0XZ:R0P2WYjL0102VYZH0Y:BT0:BTY02WYjL30::RXP80W9bL00@0UYJF0:>SX`2SXj<0J6QX
0P2:RXX0102QXJ40VYZJ09ZJVP2ATI4209nOW`040:6QX@2IVIT0VIVI07]kN`80DU9B00@0Q8B409jN
WP2NWYh0ZJVY0P0l?3`00`1XJ6Soooooooooo`040000o`<0oh003`000?l20?n000040000o`3oP000
oh000?n001<0003o0P3oP0090000o`P0oh000P000?l00`3oP000003o0000o`0B0000o`030?n00000
0?l0003o0100003o0`3oP00P0000o`H0oh007`000?l20?n000@0003o0P3oP0000`000?oooooooooo
o`08ooooo`002Oooool0102MWId0U9BD09BDU02HV9P2059BDP04061PH02@T900T92@07AdM080U9BD
00@0T92@09BDU02DU9@0QXJ60P1YJFT00`1nOWh0Shn?08n?S`030:JVYP040:ZZZP1;Bd/0Bd];03Hf
=P80XZ:R00<0YZJV0:NWY`2WYjL00`2ZZZX0102VYZH0WinO09nOW`2@T9020861P@<0Ti>C00D0UYJF
06=SH`1SHf<061PH0:2PX0020:>SX`0409bLW02FUYH0UYJF07emO@80QHF50`2VYZH0102/[:`0[jn_
0:n_[`2_[jl20;6a/@040:6QX@0X:2P0:2PX09VIV@80V9RH00@0VIVI08Z:RP2:RXX0MgMg0P29RHT0
102@T900Shn?08n?S`25QHD208B4Q00409ZJVP2TY:@0Y:BT07inOP80AdM700D0YZJV0:FUY@2UYJD0
RHV907]kN`0207QhN00408:2PP2>SXh0SXj>09RHV080VYZJ00@0YZJV0:RXZ02XZ:P0YJFU0P17AdL0
101WIfL0P8200820P02;Rh/208b<S00408N7Q`24Q8@0Q8B408V9R@80QhN700@0QHF5092@T02@T900
U9BD0P2<S8`0102GUiL0LG5a075aL@2][Jd20:2PX00409:BTP2LW9`0W9bL09JFUP80WIfM00D0W9bL
096AT@2ATI40UIFE0:FUY@020:ZZZP040:n_[`1<C4`0C4a<09BDU080X:2P0`2ZZZX0102WYjL0WYjN
09jNWP2SXj<20:BTY00409nOW`2MWId0WIfM0:6QX@80Xj>S00@0Cdm?08Z:RP2:RXX0WYjN0P2BTY80
1023Ph<0UYJF09JFUP2KVi/209RHV00408>3P`1ADE40DE5A08B4Q080X:2P00@0Y:BT04I6AP16ATH0
Lg=c0_ooool40000o`80oh004`000?l30?n001<0003o0P3oP00=0000o`@0oh000P000?l00`3oP000
003o0000o`0B0000o`030?n000000?l0003o0100003o00<0oh000000o`000?l04`000?l00`3oP000
003o0000o`0=0000o`<0oh004P000?l00`3oP000003o0000o`0:0000o`80oh0010000?l20?n00003
0000oooooooooooo00Sooooo0009ooooo`0409fMW@2DU9@0U9BD09RHV080DU9B00@0H61P092@T02@
T900M7Ad0P2DU9@0102@T900U9BD09BDU026QXH206UYJ@0307inOP2?Shl0Shn?00<0YZJV00@0ZZZZ
04];B`1;Bd/0=SHf0P2RXZ800`2VYZH0YjNW0:NWY`030:ZZZP040:JVYP2OWil0WinO092@T080PH61
0`2CTi<01@2FUYH0Hf=S06=SH`0H61P0X:2P0080Xj>S00@0W9bL09JFUP2FUYH0OGem0P25QHD30:JV
YP040:b/[02_[jl0[jn_0:n_[`80/K6a00@0XJ6Q02PX:00X:2P0VIVI0P2HV9P0102IVIT0RXZ:08Z:
RP1gMgL208V9R@04092@T02?Shl0Shn?08F5Q@80Q8B400@0VYZJ0:BTY02TY:@0OWin0P17AdL01@2V
YZH0YJFU0:FUY@29RHT0Ng]k0080N7Qh00@0PX:208j>SP2>SXh0V9RH0P2JVYX0102VYZH0Z:RX0:RX
Z02UYJD204M7A`0406MWI`20P800P82008^;R`80S8b<00@0QhN708B4Q024Q8@0RHV90P27QhL01025
QHD0T92@092@T02DU9@208b<S00409NGU`1aLG40LG5a0:f][@80X:2P00@0TY:B09bLW02LW9`0UYJF
0P2MWId01@2LW9`0TI6A096AT@2EUID0YJFU0080ZZZZ00@0[jn_04a<C01<C4`0U9BD0P2PX:030:ZZ
ZP040:NWY`2NWYh0WYjN0:>SX`80Y:BT00@0WinO09fMW@2MWId0XJ6Q0P2SXj<0101?Cdl0RXZ:08Z:
RP2NWYh209:BTP0408>3P`2FUYH0UYJF09^KV`80V9RH00@0Ph>3055AD@1ADE40Q8B40P2PX:00102T
Y:@0ATI604I6AP1cLg<2ooooo`@0003o0P3oP00C0000o`<0oh004`000?l20?n000d0003o103oP002
0000o`030?n000000?l0003o0180003o00<0oh000000o`000?l040000?l00`3oP000003o0000o`0C
0000o`030?n000000?l0003o00d0003o0`3oP00B0000o`030?n000000?l0003o00X0003o0P3oP004
0000o`80oh0000<0003oooooooooool02?ooool000Wooooo00@0ZJVY0:>SX`2SXj<0WYjN0P1JFUX0
101LG5`0WinO09nOW`1iNGT209bLW00409fMW@2KVi/0Vi^K09RHV080M7Ad00@0V9RH09NGU`2GUiL0
YJFU0P2/[:`0102XZ:P0EeMG05MGE`0a<C420:>SX`040:f][@2_[jl0[jn_0:j^[P80Zj^[00@0YjNW
0::RXP2RXZ80Ti>C0P1mOGd308f=S@0508j>SP1eMGD0MGEe01PH602LW9`00P2IVIT0102LW9`0XJ6Q
0:6QX@26QXH207alO0040::RXP2[Zj/0Zj^[0:j^[P80[jn_00@0/;2`0:b/[02/[:`0XJ6Q0P0g=cL0
102KVi/0WIfM09fMW@2RXZ8209nOW`0408F5Q@2FUYH0UYJF09ZJVP80W9bL00@0QhN708B4Q024Q8@0
WIfM0P2HV9P0101mOGd0D51@051@D02FUYH20:FUY@0508^;R`1nOWh0O7al07alO02:RXX00P2JVYX0
102LW9`0Xj>S0:>SX`2UYJD20:RXZ0040:BTY019BDT0BDU905QHF080N7Qh00@0SXj>09RHV02HV9P0
QHF50P1lO7`0101hN7P0MGEe07EeM@22PX8208R8R00408V9R@2DU9@0U9BD08f=S@80KVi^00@0Z:RX
0:BTY02TY:@0Rh^;0`2OWil20:BTY00509NGU`2=SHd0SHf=09ZJVP2YZJT00`2[Zj/20451@@0409ZJ
VP2WYjL0YjNW0:b/[080[Zj^00@0[jn_0:f][@2][Jd0ZZZZ0P2[Zj/0102YZJT0VIVI09VIV@2EUID2
09BDU00405=CD`2ATI40TI6A09^KV`<0WIfM0`2LW9`20:>SX`0408>3P`1LG5`0G5aL08V9R@80XJ6Q
00@0Xj>S05EEE@1EEED0P8200_ooool40000o`<0oh004P000?l30?n00080003o103oP00=0000o`80
oh0030000?l40?n000<0003o00<0oh000000o`000?l04P000?l00`3oP000003o0000o`0@0000o`<0
oh009@000?l00`3oP000003o0000o`030000o`@0oh002@000?l00`3oP000003o0000o`0:0000o`80
oh0010000?l20?n000030000oooooooooooo00Sooooo0009ooooo`0409jNWP2CTi<0Ti>C08J6QP80
;Bd]00@0DE5A09RHV02HV9P0MWIf0P2>SXh0102@T900UYJF09JFUP2DU9@206IVIP040861P@1lO7`0
O7al096AT@80T92@00@0W9bL04i>CP1>CTh051@D0P2;Rh/0102BTY80Rh^;08^;R`29RHT208N7Q`04
0820P01mOGd0OGem07IfMP80J6QX00@0Fe]K06ATI01TI6@0FUYJ0P18B4P01@0>3Ph0KFe]075aL@1a
LG40N7Qh0080MGEe00@0M7Ad05mOG`1OGel0PH610`1mOGd207AdM00407=cL`1]KFd0KFe]05QHF080
:RXZ00@0H61P071`L01`L700OGem0P1TI6@0101QHF40M7Ad07AdM01bLW8206i^KP04069RHP1EEED0
EEEE061PH080IFEU00@0>SXj03dm?@0m?Cd0Lg=c0P1gMgL01@1hN7P0L71`06][J`1[Jf/0H61P0080
IfMW00@0J6QX061PH01PH600F5QH0`1QHF4203Xj>P0403/k>`1?Cdl0Cdm?05IFEP<0LW9b0P1NGUh0
101VIVH0G5aL05aLG01=CDd204A4A00403Lg=`0U9BD09BDU04e=C@806a/K00@0EUIF05]KF`1KFe/0
Cdm?0P1SHf<0101OGel0IVIV06IVIP1DE5@204Y:BP0505iNGP1MGEd0Hf=S06=SH`1YJFT00P0R8R80
101OGel0L71`071`L01]KFd2071`L00405QHF01YJFT0JFUY071`L080J6QX00@0JFUY05ADE01DE5@0
>3Ph0P0m?Cd0101<C4`0D51@051@D01JFUX2065QH@0406=SH`1PH600H61P05iNGP80Fe]K00@0ATI6
03Xj>P0j>SX0@D510P1@D5001019BDT0;2`/02`/;00d=3@2ooooo`@0003o0`3oP00B0000o`<0oh00
3@000?l20?n000030000o`3oP000oh0000<0oh004@000?l30?n000h0003o00@0oh000000o`000?l0
003o0`3oP00=0000o`80oh000`000?l60?n000<0003o00<0oh000000o`000?l03P3oP0050000o`H0
oh000`000?l00`3oP000003o0000o`040000o`80oh001@000?l90?n000D0003o3@3oP00:ooooo`00
2Oooool0102NWYh0Ti>C09>CT`26QXH202d];@04055AD@2HV9P0V9RH07IfMP80SXj>00@0T92@09JF
UP2FUYH0U9BD0P1VIVH01021PH40O7al07alO02ATI42092@T00409bLW01>CTh0CTi>01@D5080Rh^;
00@0TY:B08^;R`2;Rh/0RHV90P27QhL01020P800OGem07emO@1fMWH206QXJ00405]KF`1TI6@0I6AT
05YJFP80B4Q800D03Ph>06e]K@1aLG40LG5a07QhN00207EeM@0407AdM01OGel0GemO0861P@<0OGem
0P1dM7@0101cLg<0KFe]06e]K@1HF5P202XZ:P04061PH01`L700L71`07emO@80I6AT00@0HF5Q07Ad
M01dM7@0LW9b0P1^KVh0101RHV80EEEE05EEE@1PH60206EUI@0403Xj>P0m?Cd0?Cdm07=cL`80MgMg
00D0N7Qh071`L01[Jf/0Jf][061PH00206MWI`0406QXJ01PH600H61P05QHF0<0HF5Q0P0j>SX0100k
>c/0Cdm?04m?C`1FEUH3079bLP80GUiN00@0IVIV05aLG01LG5`0CDe=0P14A4@0100g=cL09BDU02DU
9@1=CDd201/K6`0405IFEP1KFe/0Fe]K04m?C`80Hf=S00@0GemO06IVIP1VIVH0E5AD0P1:BTX01@1N
GUh0GEeM06=SH`1SHf<0JFUY00808R8R00@0GemO071`L01`L700KFe]0P1`L700101HF5P0JFUY06UY
J@1`L70206QXJ00406UYJ@1DE5@0E5AD03Ph>080?Cdm00@0C4a<051@D01@D500FUYJ0P1QHF40101S
Hf<0H61P061PH01NGUh205]KF`0404I6AP0j>SX0>SXj0451@@80D51@00@0BDU902`/;00/;2`0=3@d
0_ooool40000o`<0oh004P000?l30?n000d0003o0P3oP0000`000?l0oh000?n000030?n00140003o
0`3oP00>0000o`040?n000000?l0003o0000o`<0oh003@000?l20?n000<0003o1P3oP0030000o`03
0?n000000?l0003o00h0oh001@000?l60?n000<0003o00<0oh000000o`000?l010000?l20?n000D0
003o2@3oP0050000o`d0oh002_ooool000Wooooo00@0?Cdm03<c<`0c<c<0<C4a0P0];Bd0100d=3@0
>3Ph03Ph>00n?Sh203Ph>00403`l?00P8200820P00l?3`804Q8B0`0C4a<0100@410061PH01PH600U
9BD203De=@04038b<P0Z:RX0:RXZ02d];@80=CDe00@0<C4a03<c<`0c<c<04A4A0P0a<C40100^;Rh0
:BTY02TY:@0U9BD2028R8P0501/K6`0R8R808R8R02<S8`0O7al00P0S8b<0100W9bL092@T02@T900M
7Ad201<C4`0402TY:@0];Bd0;Bd]028R8P<0<C4a0P0[:b/0100a<C40?clo03lo?`0o?cl203@d=003
02XZ:P0`<300<30`00<07AdM00@0=CDe02PX:00X:2P08B4Q0P0U9BD0100_;bl0=SHf03Hf=P0i>CT2
03hn?P0503<c<`0T92@092@T02HV9P0I6AT00P0A4A40100N7Qh0;Bd]02d];@0_;bl203lo?`0404M7
A`0n?Sh0?Shn03Ti>@80;Bd]00@0>SXj03Hf=P0f=SH0BDU90P0m?Cd0100];Bd08b<S02<S8`1?Cdl2
04e=C@0404m?C`1@D500D51@05eMG@<0IVIV0P1MGEd01017AdL0>c/k03/k>`1:BTX204U9B@0402@T
9017AdL0AdM705]KF`80GEeM00D0GUiN05QHF01QHF40HF5Q05YJFP02061PH00405]KF`1HF5P0F5QH
05ADE080EeMG00@09RHV04E5A@15ADD0H61P0P1]KFd0101`L700MgMg07MgM`1hN7P208R8R0040820
P01dM7@0M7Ad06YZJP80Jf][00@0P82005EEE@1EEED0<30`0P1TI6@0101dM7@0N7Qh07QhN023Ph<2
09BDU00409VIV@2NWYh0WYjN09^KV`;oooooOP3oP0020000oa40oh0000@0003o0?n0003oP000003o
2@3oP00@0000o`<0oh0030000?l:ooooo`002Oooool00`2DU9@0VIVI09VIV@030:NWY`040:^[Z`2Z
ZZX0ZZZZ0:n_[`80Zj^[00@0YJFU05]KF`1KFe/0410@0P1gMgL307emO@0407]kN`2:RXX0RXZ:096A
T@80RHV900@0Rh^;09>CT`2CTi<0W9bL0P2JVYX0102QXJ40VIVI09VIV@0_;bl209fMW@0409BDU02E
UID0UIFE08J6QP80O7al00D0Ogmo08N7Q`27QhL0U9BD08N7Q`0208n?S`0409FEU@2DU9@0U9BD07Ee
M@80:b/[00@0V9RH09ZJVP2JVYX0YJFU0P2WYjL0102TY:@0QhN708N7Q`2RXZ820:JVYP040:VYZ@2Z
ZZX0ZZZZ09jNWP80YJFU00<0LW9b06IVIP1VIVH00`2VYZH0102TY:@0W9bL09bLW02SXj<20::RXP04
0:NWY`2TY:@0Y:BT0:>SX`80Y:BT00D0ZJVY096AT@17AdL0AdM7079bLP0209ZJVP<0Vi^K00@0Ti>C
09bLW02LW9`0UYJF0P28R8P0102FUYH0Ti>C09>CT`2QXJ420:b/[00409NGU`1IFET0FEUI0:f][@80
ZZZZ00@0Xj>S0:RXZ02XZ:P0[Jf]0P2/[:`0102a/K40[jn_0:n_[`2WYjL20:j^[P040:f][@2WYjL0
YjNW059BDP80V9RH00D0/;2`0:NWY`2WYjL0YJFU0:>SX`020:NWY`040::RXP2SXj<0Xj>S08f=S@80
O7al00@0Ph>30:VYZ@2YZJT0EEEE0P20P8030:n_[`040:f][@2VYZH0YZJV09RHV080YZJV00@0WIfM
0:6QX@2QXJ40X:2P0P26QXH0102WYjL0MWIf07IfMP1=CDd209VIV@0408Z:RP2JVYX0VYZJ0:FUY@80
[jn_00@0/k>c0;Fe]@2e]KD0/[:b0_ooool90000o`040?n000000?l0003o0000o`<0oh004`000?l2
0?n001<0003o0P3oP00V0000o`030?n000000?l0003o0180003o0`3oP0040000o`80oh0000D0003o
0?n0003oP000oh000000o`030?n00080003o00@0oh000000o`000?l0oh003`000?l20?n000030000
o`3oP000oh000080oh003P000?l00`3oP000003o0000o`040000o`H0oh002_ooool000Wooooo00<0
U9BD09VIV@2IVIT00`2WYjL0102[Zj/0ZZZZ0:ZZZP2_[jl20:^[Z`040:FUY@1KFe/0Fe]K010@4080
MgMg0`1mOGd0101kNg/0RXZ:08Z:RP2ATI4208V9R@0408^;R`2CTi<0Ti>C09bLW080VYZJ00@0XJ6Q
09VIV@2IVIT0;bl_0P2MWId0102DU9@0UIFE09FEU@26QXH207alO00507moO`27QhL0QhN709BDU027
QhL00P2?Shl0102EUID0U9BD09BDU01eMGD202/[:`0409RHV02JVYX0VYZJ0:FUY@80YjNW00@0Y:BT
08N7Q`27QhL0XZ:R0P2VYZH0102YZJT0ZZZZ0:ZZZP2NWYh20:FUY@03079bLP1VIVH0IVIV00<0YZJV
00@0Y:BT09bLW02LW9`0Xj>S0P2RXZ80102WYjL0Y:BT0:BTY02SXj<20:BTY0050:VYZ@2ATI40AdM7
04M7A`1bLW800P2JVYX309^KV`0409>CT`2LW9`0W9bL09JFUP80R8R800@0UYJF09>CT`2CTi<0XJ6Q
0P2/[:`0102GUiL0FEUI05UIF@2][Jd20:ZZZP040:>SX`2XZ:P0Z:RX0:f][@80[:b/00@0/K6a0:n_
[`2_[jl0YjNW0P2^[Zh0102][Jd0YjNW0:NWY`1BDU8209RHV0050;2`/02WYjL0YjNW0:FUY@2SXj<0
0P2WYjL0102RXZ80Xj>S0:>SX`2=SHd207alO00408>3P`2YZJT0ZJVY05EEE@80P8200`2_[jl0102]
[Jd0YZJV0:JVYP2HV9P20:JVYP0409fMW@2QXJ40XJ6Q0:2PX080QXJ600@0YjNW07IfMP1fMWH0CDe=
0P2IVIT0102:RXX0VYZJ09ZJVP2UYJD20:n_[`040;>c/`2e]KD0]KFe0;:b/P;ooooo2@000?l0103o
P000003o0000o`000?l30?n001<0003o0P3oP00C0000o`80oh009P000?l00`3oP000003o0000o`0B
0000o`<0oh0010000?l20?n000050000o`3oP000oh000?n000000?l00`3oP0020000o`040?n00000
0?l0003o0?n000l0003o0P3oP0000`000?l0oh000?n000020?n000h0003o00<0oh000000o`000?l0
10000?l60?n000[ooooo0009ooooo`040:2PX025QHD0QHF5092@T0<0W9bL0P2QXJ430:FUY@0409fM
W@2;Rh/0Rh^;028R8P80Ph>300@0T92@09fMW@2MWId0UYJF0P26QXH01027QhL0Ogmo07moO`24Q8@2
092@T00409:BTP2LW9`0W9bL09ZJVP80V9RH00@0?3`l09:BTP2BTY80YZJV0P2SXj<0102QXJ40R8R8
08R8R020P80208^;R`80U9BD0P2EUID0102>SXh0WIfM09fMW@2;Rh/203De=@0406a/K01bLW80LW9b
07alO080MWIf00@0RHV908Z:RP2:RXX0VYZJ0P2GUiL0102TY:@0X:2P0:2PX02RXZ820:>SX`0407mo
O`1>CTh0CTi>0861P@80R8R800@0OWin08B4Q024Q8@0Ph>30P2;Rh/0102DU9@0T92@092@T02>SXh2
092@T005096AT@2BTY80Fe]K05]KF`1OGel00P2;Rh/0102?Shl0W9bL09bLW02CTi<2092@T00408N7
Q`24Q8@0Q8B408n?S`80UiNG00@0VYZJ0:RXZ02XZ:P0T92@0P1XJ6P0102[Zj/0[Jf]0:f][@2WYjL2
0:RXZ0040:ZZZP2[Zj/0Zj^[0:RXZ080[:b/00@0[Jf]0;Fe]@2e]KD0/;2`0P2XZ:P0101KFe/0ZZZZ
0:ZZZP2^[Zh20:BTY00509^KV`2RXZ80ZZZZ0:ZZZP2[Zj/00P2/[:`0102KVi/0VIVI09VIV@2SXj<2
0:VYZ@03061PH027QhL0QhN700@0[Jf]0P2WYjL0102MWId0Y:BT0:BTY02RXZ8209jNWP040:2PX02C
Ti<0Ti>C0:RXZ080Lg=c00@0GemO09FEU@2EUID0R8R80P2DU9@0102EUID0VYZJ09ZJVP2UYJD20:j^
[P030;6a/Ooooooooooo00l0003o00<0oh000000o`000?l04@000?l20?n001<0003o0P3oP00C0000
o`030?n000000?l0003o0100003o00<0oh000000o`000?l05@000?l00`3oP000003o0000o`070000
o`@0oh000P000?l0103oP000003o0000o`3oP00B0000o`@0oh0060000?l30?n000[ooooo0009oooo
o`040:2PX027QhL0QhN708Z:RP80UIFE00@0Ti>C09jNWP2NWYh0VIVI0P2FUYH0102;Rh/0O7al07al
O00e=CD208J6QP0409FEU@2NWYh0WYjN09jNWP80S8b<00@0SXj>07alO01lO7`0KFe]0P2>SXh0102L
W9`0Y:BT0:BTY02NWYh208N7Q`040492@P2HV9P0V9RH0:>SX`<0ZZZZ0P2HV9P01@29RHT0XJ6Q0:6Q
X@2SXj<0Y:BT0080YZJV00@0XZ:R0:JVYP2VYZH0QHF50P0f=SH0102IVIT0WinO09nOW`2VYZH209fM
W@040820P02ATI40TI6A09RHV080Q8B400@0RHV908b<S02<S8`0Vi^K0P2RXZ801023Ph<0CDe=04e=
C@23Ph<208N7Q`0408B4Q01iNGT0NGUi07alO080Ogmo00@0QXJ608j>SP2>SXh0QHF50P2=SHd01@20
P800OWin04m?C`1?Cdl0KVi^0080TY:B00@0T92@09RHV02HV9P0YZJV0P2OWil0102;Rh/0Shn?08n?
S`2LW9`209fMW@0409RHV02SXj<0Xj>S08b<S080F5QH00@0/K6a0;>c/`2c/k<0[Jf]0P2`/;00102]
[Jd0[:b/0:b/[02^[Zh20;:b/P040;Bd]02g]kL0]kNg0;Fe]@80[Jf]00@0B4Q809jNWP2NWYh0/;2`
0P2ZZZX01@2][Jd0[jn_0;Fe]@2e]KD0[Zj^0080]KFe00@0[:b/0:6QX@2QXJ40ZJVY0P2/[:`0101I
FET0QHF508F5Q@2^[Zh30:b/[080YjNW00<0XZ:R0:RXZ02XZ:P00`2XZ:P0102WYjL0XJ6Q0:6QX@2f
][H208F5Q@0406QXJ028R8P0R8R807]kN`80R8R800@0PH6108J6QP26QXH0XJ6Q0`2XZ:P2ooooo`l0
003o00<0oh000000o`000?l04@000?l20?n001<0003o0P3oP00C0000o`030?n000000?l0003o0100
003o00<0oh000000o`000?l04P000?l90?n000030000o`3oP000oh0000P0oh000P000?l00`3oP000
003o0000o`070?n000H0003o0P3oP0000`000?l0oh000000o`0=0000o`030?n000000?l0003o00d0
003o2_ooool000Wooooo00@0X:2P08N7Q`27QhL0RXZ:0P2EUID0102CTi<0WYjN09jNWP2IVIT209JF
UP0408^;R`1lO7`0O7al03De=@80QXJ600@0UIFE09jNWP2NWYh0WYjN0P2<S8`0102>SXh0O7al07al
O01]KFd208j>SP0409bLW02TY:@0Y:BT09jNWP80QhN700@0@T9209RHV02HV9P0Xj>S0`2ZZZX209RH
V00508V9R@2QXJ40XJ6Q0:>SX`2TY:@00P2VYZH0102RXZ80YZJV0:JVYP25QHD203Hf=P0409VIV@2O
Wil0WinO0:JVYP80WIfM00@0P820096AT@2ATI40V9RH0P24Q8@01029RHT0S8b<08b<S02KVi/20::R
XP0408>3P`1=CDd0CDe=08>3P`80QhN700@0Q8B407UiN@1iNGT0O7al0P1oOgl01026QXH0SXj>08j>
SP25QHD208f=S@050820P01nOWh0Cdm?04m?C`1^KVh00P2BTY80102@T900V9RH09RHV02VYZH209nO
W`0408^;R`2?Shl0Shn?09bLW080WIfM00@0V9RH0:>SX`2SXj<0S8b<0P1HF5P0102a/K40/k>c0;>c
/`2][Jd20;2`/0040:f][@2/[:`0[:b/0:j^[P80/[:b00@0];Bd0;Ng]`2g]kL0]KFe0P2][Jd01018
B4P0WYjN09jNWP2`/;020:ZZZP050:f][@2_[jl0]KFe0;Fe]@2^[Zh00P2e]KD0102/[:`0XJ6Q0:6Q
X@2YZJT20:b/[00405UIF@25QHD0QHF50:j^[P<0[:b/0P2WYjL00`2RXZ80Z:RX0:RXZ0030:RXZ004
0:NWY`2QXJ40XJ6Q0;Jf]P80QHF500@0J6QX08R8R028R8P0Ng]k0P28R8P01021PH40QXJ608J6QP2Q
XJ430:RXZ0;ooooo3`000?l00`3oP000003o0000o`0A0000o`80oh004`000?l20?n001<0003o00<0
oh000000o`000?l040000?l00`3oP000003o0000o`0B0000o`T0oh0000<0003o0?n0003oP000203o
P0020000o`030?n000000?l0003o00L0oh001P000?l20?n000030000o`3oP000003o00d0003o00<0
oh000000o`000?l03@000?l:ooooo`002Oooool0102RXZ80TY:B09:BTP2JVYX209jNWP0408Z:RP2=
SHd0SHf=096AT@80RHV900@0Ng]k07IfMP1fMWH09bLW0P20P800102HV9P0WIfM09fMW@2VYZH209bL
W00409fMW@2IVIT0VIVI08f=S@80P82000@0U9BD09ZJVP2JVYX0Ph>30P1UIFD01017AdL0WYjN09jN
WP2RXZ820:JVYP040:^[Z`2OWil0WinO09NGU`80WIfM00D0X:2P0:BTY02NWYh0WYjN09JFUP0209:B
TP0407]kN`0`<300<30`08Z:RP80VIVI00@0WIfM0::RXP2RXZ80Ph>30P1kNg/0101oOgl0KFe]06e]
K@1/K6`206e]K@0408V9R@21PH40PH6105EEE@80ADE500@0LW9b07MgM`1gMgL0Ng]k0P1iNGT306UY
J@0407=cL`1/K6`0K6a/06i^KP80O7al00D0MWIf0820P01<C4`0C4a<05iNGP0207UiN@0408:2PP25
QHD0QHF508R8R0<0SHf=0P1kNg/0102;Rh/0QHF508F5Q@25QHD20861P@0405YJFP0Y:BT0:BTY08J6
QP80Ti>C00@0SXj>08n?S`2?Shl0Ph>30P21PH401022PX80QHF508F5Q@27QhL208Z:RP0408J6QP1o
Ogl0Ogmo02d];@80J6QX00D0PX:207moO`1oOgl0SXj>08V9R@0208Z:RP04071`L01fMWH0MWIf07in
OP80Lg=c00@0KVi^06UYJ@1YJFT0<C4a0P19BDT0101`L700LG5a075aL@1_Kfl206][J`0406EUI@1E
EED0EEEE05EEE@80FUYJ00@0EUIF05=CD`1CDe<0A4A40P0S8b<0100Y:BT0?3`l03`l?00g=cL203`l
?00404A4A01FEUH0EUIF069RHP80GemO00<0Fe]Kooooooooool03`000?l00`3oP000003o0000o`0A
0000o`80oh004`000?l20?n00140003o0`3oP00B0000o`<0oh0040000?l30?n00180003o00<0oh00
0000o`000?l040000?l30?n000L0003o503oP0030000o`030?n00?oooooooooo00Sooooo0009oooo
o`0402`/;00U9BD09BDU01XJ6P807QhN00@04Q8B014A4@0A4A404a<C0P0;2`/0100=3@d02@T900T9
2@0:2PX201HF5P0401XJ6P0H61P061PH01lO7`80820P0`0M7Ad0100I6AT04a<C01<C4`0E5AD201TI
6@0401@D500N7Qh07QhN03Ph>080;bl_00<0:BTY02HV9P0V9RH00`0U9BD01@0Q8B406a/K01/K6`0J
6QX09bLW0080:2PX00@092@T01hN7P0N7Qh07QhN0P0G5aL0100L71`0410@010@400E5AD201XJ6P04
020P800?3`l03`l?01dM7@8092@T00@05QHF024Q8@0Q8B4092@T0P0];Bd0100`<300=3@d03@d=00c
<c<202@T900402<S8`0O7al07alO01XJ6P804a<C00@0:b/[03@d=00d=3@0<c<c0P0i>CT01@0e=CD0
;Rh^03Ph>00h>3P0@4100080ADE500@0@D5103dm?@0m?Cd0>SXj0P0R8R80100P82009RHV02HV9P0c
<c<203Ti>@0404I6AP1;Bd/0Bd];04M7A`80CDe=00@0A4A403Hf=P0f=SH0=3@d0P0_;bl0100a<C40
7alO01lO7`0X:2P203<c<`0402HV9P0g=cL0=cLg02h^;P80?3`l00@0ATI604M7A`17AdL0CDe=0P1:
BTX01@1=CDd0Cdm?02<S8`0S8b<0=cLg0080G5aL00@0HV9R05iNGP1NGUh0HF5Q0P1SHf<0101ZJVX0
KFe]06e]K@1WIfL206QXJ00406MWI`1^KVh0KVi^069RHP80>SXj00@0KFe]07=cL`1cLg<0NWYj0P1o
Ogl0101jNWX0M7Ad07AdM01aLG4206][J`04071`L01dM7@0M7Ad07YjNP80OGem00@09bLW06IVIP1V
IVH0SHf=0_oooonE0?n00080003o00<0oh000000o`000?l02`000?l20?n00180003o00@0oh000000
o`000?l0003o2_ooool000Wooooo00@0;2`/02DU9@0U9BD06QXJ0P0N7Qh0100B4Q804A4A014A4@0C
4a<200/;2`0400d=3@092@T02@T900X:2P805QHF00@06QXJ01PH600H61P07alO0P0P820301dM7@04
01TI6@0C4a<04a<C01DE5@806ATI00@051@D01hN7P0N7Qh0>3Ph0P0_;bl00`0Y:BT09RHV02HV9P03
02DU9@05024Q8@0K6a/06a/K01XJ6P0W9bL00P0X:2P0100T92@07QhN01hN7P0N7Qh201LG5`0401`L
700@4100410@01DE5@806QXJ00@0820P00l?3`0?3`l07AdM0P0T92@0100F5QH08B4Q024Q8@0T92@2
02d];@04030`<00d=3@0=3@d03<c<`8092@T00@08b<S01lO7`0O7al06QXJ0P0C4a<0100[:b/0=3@d
03@d=00c<c<203Ti>@0503De=@0^;Rh0>3Ph03Ph>010@4000P15ADD01011@D40?Cdm03dm?@0j>SX2
028R8P04020P800V9RH09RHV03<c<`80>CTi00@0ATI604];B`1;Bd/0AdM70P1=CDd01014A4@0=SHf
03Hf=P0d=3@202l_;`04034a<@0O7al07alO02PX:080<c<c00@09RHV03Lg=`0g=cL0;Rh^0P0l?3`0
1016ATH0AdM704M7A`1=CDd204Y:BP0504e=C@1?Cdl08b<S02<S8`0g=cL00P1LG5`0101RHV80GUiN
05iNGP1QHF4206=SH`0406YZJP1]KFd0KFe]06MWI`80J6QX00@0IfMW06i^KP1^KVh0HV9R0P0j>SX0
101]KFd0Lg=c07=cL`1jNWX207moO`0407YjNP1dM7@0M7Ad075aL@80Jf][00@0L71`07AdM01dM7@0
NWYj0P1mOGd0100W9bL0IVIV06IVIP2=SHd2oooooiD0oh000P000?l00`3oP000003o0000o`0;0000
o`80oh004P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0102KVi/0UIFE09FEU@2:RXX2
05=CD`030:n_[`2WYjL0YjNW00<0Q8B400@0TI6A09fMW@2MWId0WIfM0P2SXj<0102][Jd0Z:RX0:RX
Z02e]KD20;:b/P0407IfMP0l?3`0?3`l092@T080XJ6Q00@0YZJV0:b/[02/[:`0Y:BT0P2RXZ80102N
WYh0UYJF09JFUP29RHT208J6QP0408^;R`2MWId0WIfM03Ti>@80G5aL00D0UYJF09fMW@2YZJT0ZJVY
09NGU`02092@T00408n?S`28R8P0R8R808R8R080QhN700@0W9bL09nOW`2OWil0VYZJ0P0Z:RX01022
PX80Ti>C09>CT`2<S8`3092@T080V9RH00@0X:2P09nOW`2OWil0X:2P0P2RXZ8309jNWP0406m_K`0j
>SX0>SXj0:NWY`80YJFU00D0YjNW0:6QX@2QXJ40UIFE09NGU`020:6QX@040::RXP2UYJD0YJFU0:JV
YP80YJFU00@0XJ6Q04i>CP1>CTh0Jf][0`2HV9P209BDU0040::RXP2WYjL0YjNW0:b/[0<0[Zj^0P2Z
ZZX0102SXj<0Ng]k07]kN`2ATI4204A4A0040:2PX02k^k/0^k^k0;jn_P80_;bl00@0^[Zj0;Vi^@2i
^KT0^KVi0P2o_kl01@34a<@0`l?30<?3``35aLD0alO70080Cdm?00@0NWYj0;>c/`2c/k<0^;Rh0P2b
/[800`2_[jl0/;2`0;2`/0030:b/[0040:FUY@2>SXh0SXj>09:BTP80V9RH00<0Q8B404e=C@1=CDd0
0`28R8P0102;Rh/0TY:B09:BTP2?Shl208V9R@0408^;R`28R8P0R8R809>CT`80UiNG00@0X:2P09fM
W@2MWId0>c/k0P2PX:000`2d];Coooooooooo`040000o`<0oh002`000?l00`3oP000003o0000o`03
0?n000030000o`3oP000oh000140003o0`3oP00B0000o`030?n000000?l0003o0180003o00<0oh00
0000o`000?l040000?l00`3oP000003o0000o`090000o`<0oh001P000?l00`3oP000003o0?n0000A
0?n00080003o1`3oP00:0000o`80oh004P000?l0103oP000003o0000o`3oP00:ooooo`002Oooool0
102[Zj/0YjNW0:NWY`2YZJT204a<C0<0ZZZZ00@0WinO09RHV02HV9P0VIVI0P2QXJ430:FUY@040:NW
Y`2][Jd0[Jf]0:b/[080[Zj^00@0TI6A03hn?P0n?Sh0SHf=0P2IVIT00`2HV9P0VYZJ09ZJVP03096A
T@0409:BTP2?Shl0Shn?09>CT`80Q8B400@0P82009RHV02HV9P0BDU90P1_Kfl01@2NWYh0YZJV0:JV
YP2VYZH0U9BD0080R8R800@0QhN708B4Q024Q8@0OWin0P23Ph<0102GUiL0VYZJ09ZJVP2ATI4202@T
9004075aL@1eMGD0MGEe07UiN@80PH6100@0SXj>09ZJVP2JVYX0SXj>0P2EUID0102CTi<0Y:BT0:BT
Y02XZ:P20:JVYP0406EUI@0l?3`0?3`l0:BTY080XZ:R0`2NWYh01@2QXJ40VYZJ09FEU@2EUID0U9BD
0080UIFE00@0SXj>09BDU02DU9@0XJ6Q0P1LG5`0101SHf<0SXj>08j>SP2BTY8209RHV00408N7Q`2=
SHd0SHf=09jNWP80UiNG00@0TI6A08f=S@2=SHd0RHV90P2;Rh/0101oOgl0@d=304=3@`2`/;020;fm
_@040;Zj^P2g]kL0]kNg0;>c/`80^[Zj00@0/k>c0;Bd]02d];@0^k^k0P2j^[X01@2o_kl0`L7106=S
H`1SHf<0PX:200<0[:b/0P2QXJ40102SXj<0XJ6Q0:6QX@2LW9`209ZJVP0409VIV@1dM7@0M7Ad071`
L080MgMg00<0KFe]04U9B@19BDT00`20P8001027QhL0PX:208:2PP24Q8@207moO`0407emO@1oOgl0
Ogmo07]kN`80QHF500@0Ti>C09RHV02HV9P0=cLg0P2LW9`00`2YZJWoooooooooo`040000o`80oh00
3@000?l20?n000040000o`3oP000oh000000o`80oh004@000?l20?n001<0003o00<0oh000000o`00
0?l04P000?l00`3oP000003o0000o`0@0000o`030?n000000?l0003o0180003o4`3oP00D0000o`80
oh004P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0102[Zj/0YjNW0:NWY`2YZJT204a<
C0<0ZZZZ00@0WinO09RHV02HV9P0VIVI0P2QXJ430:FUY@040:NWY`2][Jd0[Jf]0:b/[080[Zj^00@0
TI6A03hn?P0n?Sh0SHf=0P2IVIT00`2HV9P0VYZJ09ZJVP03096AT@0409:BTP2?Shl0Shn?09>CT`80
Q8B400@0P82009RHV02HV9P0BDU90P1_Kfl01@2NWYh0YZJV0:JVYP2VYZH0U9BD0080R8R800@0QhN7
08B4Q024Q8@0OWin0P23Ph<0102GUiL0VYZJ09ZJVP2ATI4202@T9004075aL@1eMGD0MGEe07UiN@80
PH6100@0SXj>09ZJVP2JVYX0SXj>0P2EUID0102CTi<0Y:BT0:BTY02XZ:P20:JVYP0406EUI@0l?3`0
?3`l0:BTY080XZ:R0`2NWYh01@2QXJ40VYZJ09FEU@2EUID0U9BD0080UIFE00@0SXj>09BDU02DU9@0
XJ6Q0P1LG5`0101SHf<0SXj>08j>SP2BTY8209RHV00408N7Q`2=SHd0SHf=09jNWP80UiNG00@0TI6A
08f=S@2=SHd0RHV90P2;Rh/0101oOgl0@d=304=3@`2`/;020;fm_@040;Zj^P2g]kL0]kNg0;>c/`80
^[Zj00@0/k>c0;Bd]02d];@0^k^k0P2j^[X01@2o_kl0`L7106=SH`1SHf<0PX:200<0[:b/0P2QXJ40
102SXj<0XJ6Q0:6QX@2LW9`209ZJVP0409VIV@1dM7@0M7Ad071`L080MgMg00<0KFe]04U9B@19BDT0
0`20P8001027QhL0PX:208:2PP24Q8@207moO`0407emO@1oOgl0Ogmo07]kN`80QHF500@0Ti>C09RH
V02HV9P0=cLg0P2LW9`00`2YZJWoooooooooo`040000o`80oh003@000?l20?n000040000o`3oP000
oh000000o`80oh004@000?l20?n001<0003o00<0oh000000o`000?l04P000?l00`3oP000003o0000
o`0@0000o`030?n000000?l0003o0180003o4`3oP00D0000o`80oh004P000?l0103oP000003o0000
o`000?l:ooooo`002Oooool0102VYZH0WinO09nOW`2YZJT204e=C@<0YjNW00@0YJFU0::RXP2RXZ80
V9RH0P2OWil0102NWYh0UiNG09NGU`2HV9P20:NWY`040:n_[`2/[:`0[:b/08f=S@80?clo00@0S8b<
09^KV`2KVi/0YJFU0P2WYjL0102TY:@0WIfM09fMW@2QXJ420:NWY`0409nOW`26QXH0QXJ608j>SP80
UIFE00D0ATI606IVIP1VIVH0Xj>S0:RXZ0020:BTY00409RHV02?Shl0Shn?08N7Q`80Ng]k00@0N7Qh
079bLP1bLW80Q8B40P2IVIT0102ATI40<S8b038b<P1dM7@207alO00408f=S@2;Rh/0Rh^;08Z:RP<0
XJ6Q0P2OWil0102HV9P0Vi^K09^KV`2SXj<209^KV`0402<S8`10@400@4100:NWY`80Z:RX00D0XZ:R
0:>SX`2SXj<0WIfM09>CT`0209FEU@0309>CT`2NWYh0WYjN00<0WYjN00@0YZJV06=SH`1SHf<0EUIF
0P1nOWh0102:RXX0VIVI09VIV@2IVIT209jNWP040:BTY02MWId0WIfM0:2PX080Y:BT00@0U9BD08Z:
RP2:RXX0VIVI0P19BDT0102`/;00`<300<30`02h^;P20;Ng]`<0];Bd00@0[Jf]0:RXZ02XZ:P0Z:RX
0P2][Jd01@2m_Kd0b/[:06EUI@1UIFD0Q8B40080ZJVY00<0Xj>S09bLW02LW9`00`2HV9P0102DU9@0
TY:B09:BTP2ATI4207alO00407EeM@1aLG40LG5a06MWI`80DE5A00@0UIFE09RHV02HV9P0TY:B0P28
R8P01024Q8@0N7Qh07QhN022PX820820P00407moO`29RHT0RHV909JFUP80VIVI00@0:BTY08Z:RP2:
RXX0UYJF0_ooool40000o`80oh003`000?l0103oP000003o0000o`000?l20?n00140003o0P3oP00C
0000o`030?n000000?l0003o0100003o0`3oP00C0000o`80oh004P000?l;0?n000<0003o1@3oP00D
0000o`80oh004P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0102/[:`0YZJV0:JVYP2H
V9P204];B`040:^[Z`2WYjL0YjNW09nOW`80X:2P00@0V9RH09NGU`2GUiL0Q8B40P2@T9001021PH40
UiNG09NGU`2KVi/208n?S`0407UiN@10@400@41008J6QP80W9bL00@0Z:RX0:VYZ@2YZJT0[:b/0P2^
[Zh0102YZJT0YJFU0:FUY@2KVi/209ZJVP0409bLW02;Rh/0Rh^;02DU9@80KFe]00D0XJ6Q09>CT`2Q
XJ40XJ6Q09>CT`0207EeM@0407AdM01eMGD0MGEe06i^KP80L71`00@0Ogmo09VIV@2IVIT0U9BD0P0i
>CT0101oOgl0PX:208:2PP2:RXX209BDU00308R8R02FUYH0UYJF00<0Vi^K00@0TI6A08f=S@2=SHd0
WIfM0P2DU9@0101EEED0@T920492@P2TY:@20:VYZ@<0ZZZZ00D0Xj>S09FEU@26QXH0QXJ607UiN@02
09JFUP<0V9RH00@0VYZJ06QXJ01XJ6P0CDe=0P1hN7P0102;Rh/0XJ6Q0:6QX@2UYJD20:JVYP0409BD
U02MWId0WIfM09NGU`80T92@00@0Rh^;07alO01lO7`0V9RH0P1CDe<0102LW9`0VYZJ09ZJVP2/[:`2
0;jn_P040;2`/02TY:@0Y:BT09RHV080X:2P00D0UIFE096AT@2ATI40SHf=09jNWP0204e=C@04079b
LP1nOWh0OWin07IfMP80OWin00@0MGEe079bLP1bLW80MgMg0P1cLg<0101bLW80GEeM05eMG@1GEeL2
04U9B@0403Ph>00c<c<0<c<c05aLG080Hf=S00@0IFEU05]KF`1KFe/0BDU90P13@d<01019BDT0De=C
05=CD`1=CDd305=CD`80ATI600@071`L05iNGP1NGUh0JVYZ0_ooool40000o`80oh004`000?l20?n0
00L0003o00<0oh000000o`000?l01`000?l20?n001<0003o00<0oh000000o`000?l040000?l30?n0
01<0003o0P3oP00B0000o`030?n000000?l0003o0080003o0`3oP00;0000o`030?n000000?l0003o
00/0003o2@3oP0030000oa40oh0000<0003oooooooooool02?ooool000Wooooo00@0[:b/0:JVYP2V
YZH0V9RH0P1;Bd/0102[Zj/0YjNW0:NWY`2OWil20:2PX00409RHV02GUiL0UiNG08B4Q080T92@00@0
PH6109NGU`2GUiL0Vi^K0P2?Shl0101iNGT0@4100410@026QXH209bLW0040:RXZ02YZJT0ZJVY0:b/
[080[Zj^00@0ZJVY0:FUY@2UYJD0Vi^K0P2JVYX0102LW9`0Rh^;08^;R`0U9BD206e]K@050:6QX@2C
Ti<0XJ6Q0:6QX@2CTi<00P1eMGD0101dM7@0MGEe07EeM@1^KVh2071`L00407moO`2IVIT0VIVI09BD
U080>CTi00@0Ogmo08:2PP22PX80RXZ:0P2DU9@00`28R8P0UYJF09JFUP0309^KV`04096AT@2=SHd0
SHf=09fMW@80U9BD00@0EEEE0492@P12@T80Y:BT0P2YZJT30:ZZZP050:>SX`2EUID0QXJ608J6QP1i
NGT00P2FUYH309RHV00409ZJVP1XJ6P0J6QX04e=C@80N7Qh00@0Rh^;0:6QX@2QXJ40YJFU0P2VYZH0
102DU9@0WIfM09fMW@2GUiL2092@T00408^;R`1lO7`0O7al09RHV080De=C00@0W9bL09ZJVP2JVYX0
[:b/0P2n_[h0102`/;00Y:BT0:BTY02HV9P20:2PX00509FEU@2ATI40TI6A08f=S@2NWYh00P1=CDd0
101bLW80OWin07inOP1fMWH207inOP0407EeM@1bLW80LW9b07MgM`80Lg=c00@0LW9b05eMG@1MGEd0
EeMG0P19BDT0100h>3P0<c<c03<c<`1LG5`206=SH`0406EUI@1KFe/0Fe]K04U9B@80@d=300@0BDU9
05=CD`1CDe<0CDe=0`1CDe<204I6AP0401`L701NGUh0GUiN06YZJP;ooooo10000?l20?n001<0003o
0P3oP0070000o`030?n000000?l0003o00L0003o0P3oP00C0000o`030?n000000?l0003o0100003o
0`3oP00C0000o`80oh004P000?l00`3oP000003o0000o`020000o`<0oh002`000?l00`3oP000003o
0000o`0;0000o`T0oh000`000?lA0?n000030000oooooooooooo00Sooooo0009ooooo`0405eMG@17
AdL0AdM703Ph>0809RHV00@0=cLg03`l?00l?3`0>3Ph0P0j>SX0100g=cL0<c<c03<c<`0/;2`201`L
7004024Q8@0V9RH09RHV02@T9080:RXZ00@08R8R010@400@4100?clo0P17AdL01011@D40ATI604I6
AP18B4P204];B`0405UIF@16ATH0ATI603Hf=P80<c<c00@0>CTi01XJ6P0J6QX01PH60P0=3@d201<C
4`806a/K00@06ATI01`L700L71`07AdM0P0N7Qh0100I6AT07QhN01hN7P0P820201dM7@0401lO7`0M
7Ad07AdM01LG5`806a/K00@07alO020P800P82006QXJ0P0P8200100S8b<06ATI01TI6@0W9bL202<S
8`0402DU9@0P8200820P020P80808B4Q00@0:b/[03hn?P0n?Sh0?clo0P0i>CT01@0d=3@0;2`/02<S
8`0S8b<020P800805aLG00@0:b/[038b<P0b<S80<C4a0P0`<300100/;2`0>SXj03Xj>P0h>3P20410
@00405=CD`1ADE40DE5A03Lg=`8092@T00@07alO02HV9P0V9RH0:BTY0P0g=cL0100n?Sh0>c/k03/k
>`0j>SX203Lg=`0404A4A01;Bd/0Bd];04i>CP80C4a<00@0=CDe01hN7P0N7Qh0>c/k0P0m?Cd01@12
@T80@d=304e=C@1=CDd0ATI600<0A4A40P0m?Cd01017AdL0BDU904U9B@19BDT201`L700403/k>`1P
H600H61P05mOG`80HF5Q00@0Jf][06YZJP1ZJVX0HV9R0P1`L7001021PH40OGem07emO@1lO7`206IV
IP0403Ti>@1oOgl0Ogmo07UiN@80Ng]k00@0P82008B4Q024Q8@0S8b<0P1jNWX00`1_Kfoooooooooo
o`2O0?n00140003o00<0oh000000o`000?l02P000?l:ooooo`002Oooool0102HV9P0U9BD09BDU02F
UYH209VIV@0409ZJVP2HV9P0V9RH08f=S@80V9RH0`2PX:00102CTi<08R8R028R8P1YJFT208V9R@04
08F5Q@2FUYH0UYJF09>CT`80S8b<00@0OWin07alO01lO7`0P8200P2ATI40102JVYX0XJ6Q0:6QX@2N
WYh2038b<P0406ATI025QHD0QHF508J6QP80R8R800D0Y:BT0:>SX`2SXj<0V9RH0:>SX`020:2PX0<0
W9bL00@0V9RH07inOP1nOWh0=SHf0P27QhL0102LW9`0VYZJ09ZJVP2KVi/20:2PX00409fMW@2RXZ80
XZ:R09nOW`80X:2P00@0XZ:R0:>SX`2SXj<0YJFU0P0e=CD01021PH40OWin07inOP20P80207MgM`04
06i^KP1eMGD0MGEe096AT@80UYJF00D0Ti>C096AT@2ATI40Ph>308:2PP02075aL@04038b<P1kNg/0
Ng]k08J6QP80Ti>C00@0V9RH09bLW02LW9`0VYZJ0P2EUID0102DU9@0XJ6Q0:6QX@2PX:020:NWY`04
0:BTY01FEUH0EUIF07alO080ZZZZ00@0YJFU0:BTY02TY:@0YZJV0P2TY:@0102UYJD0Xj>S0:>SX`2X
Z:P209ZJVP0407=cL`1bLW80LW9b06m_K`80D51@00D0][Jf0:^[Z`2[Zj/0WYjN0:>SX`030;>c/`80
ZZZZ00@0WYjN08n?S`2?Shl0YJFU0P2ZZZX0102TY:@0DU9B059BDP2QXJ4209^KV`0408^;R`1lO7`0
O7al07AdM080Q8B400@0MWIf07alO01lO7`0U9BD0P2IVIT0102DU9@0LW9b079bLP0e=CD309ZJVP80
V9RH00@0Vi^K0:2PX02PX:00RXZ:0P24Q8@00`1iNGWoooooooooo`0@0000o`80oh004`000?l00`3o
P000003o0000o`0B0000o`030?n000000?l0003o0100003o00<0oh000000o`000?l04@000?l20?n0
0180003o00<0oh000000o`000?l04@000?l30?n000D0003o0`3oP0090000o`030?n000000?l0003o
0100003o00<0oh000000o`000?l02P000?l:ooooo`002Oooool0102HV9P0U9BD09BDU02FUYH209VI
V@0409ZJVP2HV9P0V9RH08f=S@80V9RH0`2PX:00102CTi<08R8R028R8P1YJFT208V9R@0408F5Q@2F
UYH0UYJF09>CT`80S8b<00@0OWin07alO01lO7`0P8200P2ATI40102JVYX0XJ6Q0:6QX@2NWYh2038b
<P0406ATI025QHD0QHF508J6QP80R8R800D0Y:BT0:>SX`2SXj<0V9RH0:>SX`020:2PX0<0W9bL00@0
V9RH07inOP1nOWh0=SHf0P27QhL0102LW9`0VYZJ09ZJVP2KVi/20:2PX00409fMW@2RXZ80XZ:R09nO
W`80X:2P00@0XZ:R0:>SX`2SXj<0YJFU0P0e=CD01021PH40OWin07inOP20P80207MgM`0406i^KP1e
MGD0MGEe096AT@80UYJF00D0Ti>C096AT@2ATI40Ph>308:2PP02075aL@04038b<P1kNg/0Ng]k08J6
QP80Ti>C00@0V9RH09bLW02LW9`0VYZJ0P2EUID0102DU9@0XJ6Q0:6QX@2PX:020:NWY`040:BTY01F
EUH0EUIF07alO080ZZZZ00@0YJFU0:BTY02TY:@0YZJV0P2TY:@0102UYJD0Xj>S0:>SX`2XZ:P209ZJ
VP0407=cL`1bLW80LW9b06m_K`80D51@00D0][Jf0:^[Z`2[Zj/0WYjN0:>SX`030;>c/`80ZZZZ00@0
WYjN08n?S`2?Shl0YJFU0P2ZZZX0102TY:@0DU9B059BDP2QXJ4209^KV`0408^;R`1lO7`0O7al07Ad
M080Q8B400@0MWIf07alO01lO7`0U9BD0P2IVIT0102DU9@0LW9b079bLP0e=CD309ZJVP80V9RH00@0
Vi^K0:2PX02PX:00RXZ:0P24Q8@00`1iNGWoooooooooo`0@0000o`80oh004`000?l00`3oP000003o
0000o`0B0000o`030?n000000?l0003o0100003o00<0oh000000o`000?l04@000?l20?n00180003o
00<0oh000000o`000?l04@000?l30?n000D0003o0`3oP0090000o`030?n000000?l0003o0100003o
00<0oh000000o`000?l02P000?l:ooooo`002Oooool00`2g]kL0/;2`0;2`/0030:j^[P040;2`/02^
[Zh0[Zj^0:NWY`80YJFU00@0Y:BT0:ZZZP2ZZZX0Zj^[0P0f=SH0102?Shl0ZJVY0:VYZ@2YZJT20:BT
Y00408Z:RP1gMgL0MgMg08J6QP80Vi^K00@0QXJ608^;R`2;Rh/0XJ6Q0P2TY:@0102OWil0>CTi03Ti
>@2BTY820:2PX00409>CT`2VYZH0YZJV0:JVYP80XZ:R00D0TY:B08f=S@24Q8@0Q8B409NGU`020:2P
X00408j>SP1iNGT0NGUi0451@@80R8R800@0XJ6Q09fMW@2MWId0XZ:R0P2IVIT0102MWId0VIVI09VI
V@29RHT208b<S00409RHV02UYJD0YJFU0:VYZ@80>CTi00@0IVIV07inOP1nOWh0OWin0P1iNGT0101/
K6`0LG5a075aL@1gMgL507emO@0507alO01kNg/0P8200820P013@d<00P21PH40101oOgl0NWYj07Yj
NP25QHD208J6QP0408>3P`2@T900T92@08Z:RP80Ti>C00@0VYZJ0:2PX02PX:00[:b/0P1PH600101o
Ogl0Z:RX0:RXZ02RXZ8208^;R`0408J6QP22PX80PX:208B4Q080SHf=00@0Vi^K09JFUP2FUYH0OWin
0P1hN7P0101SHf<0A4A404A4A02][Jd20:RXZ0050:NWY`2RXZ80YJFU0:FUY@2[Zj/00P2VYZH0102T
Y:@0XJ6Q0:6QX@2TY:@20:>SX`0409^KV`16ATH0ATI609fMW@80SHf=00@0QHF507MgM`1gMgL0KVi^
0P1jNWX0101eMGD0LW9b079bLP29RHT209>CT`040:6QX@1hN7P0N7Qh034a<@80S8b<00@0SHf=08V9
R@29RHT0Shn?0P2PX:001026QXH0NWYj07YjNP23Ph<2ooooo`T0oh001`000?l20?n001<0003o00<0
oh000000o`000?l04P000?l00`3oP000003o0000o`0@0000o`030?n000000?l0003o0140003o0P3o
P00V0000o`<0oh004@000?l00`3oP000003o0000o`0@0000o`030?n000000?l0003o00X0003o2_oo
ool000Wooooo00@0]kNg0:j^[P2^[Zh0/K6a0P2][Jd0102d];@0[jn_0:n_[`2ZZZX20:NWY`040:ZZ
ZP2b/[80/[:b09VIV@80:RXZ00@0Rh^;0:BTY02TY:@0YjNW0P2RXZ800`22PX80N7Qh07QhN0030861
P@0407inOP2<S8`0S8b<09RHV080Y:BT00@0X:2P03Lg=`0g=cL0Vi^K0P2HV9P0102?Shl0WIfM09fM
W@2FUYH209fMW@0509JFUP2@T900Q8B408B4Q02<S8`00P2GUiL0102;Rh/0OWin07inOP0m?Cd2096A
T@<0XJ6Q00@0WinO09FEU@2EUID0Vi^K0P2EUID0102GUiL0T92@092@T02BTY820:>SX`040:FUY@0c
<c<0<c<c069RHP80Lg=c00@0Ogmo08J6QP26QXH0J6QX0P1WIfL0101bLW80N7Qh07QhN020P80208:2
PP0508R8R026QXH0Ogmo07moO`18B4P00P1oOgl0101fMWH0KVi^06i^KP1hN7P20861P@0407alO01h
N7P0N7Qh07moO`80O7al00@0TY:B09>CT`2CTi<0Zj^[0P1/K6`0101kNg/0YZJV0:JVYP2RXZ8209ZJ
VP04096AT@2CTi<0Ti>C092@T080Ti>C00@0XZ:R08b<S02<S8`0Ph>30P24Q8@0101XJ6P0EEEE05EE
E@2ZZZX20:RXZ0050;2`/02/[:`0[jn_0:n_[`2YZJT00P2XZ:P0102WYjL0X:2P0:2PX02RXZ8209fM
W@0408b<S00T92@092@T09bLW080YJFU00@0QXJ606m_K`1_Kfl0JFUY0P1NGUh0101YJFT0IVIV06IV
IP2@T90209^KV`0409jNWP1mOGd0OGem04Q8B080XZ:R00@0WinO0:JVYP2VYZH0YZJV0P2_[jl0102V
YZH0X:2P0:2PX02SXj<2ooooo`T0oh0010000?l20?n000030000o`3oP000oh0001<0003o00<0oh00
0000o`000?l04P000?l00`3oP000003o0000o`0@0000o`030?n000000?l0003o0140003o0P3oP00V
0000o`80oh000`000?l0103oP000003o0000o`3oP00;0000o`030?n000000?l0003o00D0003o0P3o
P0090000o`030?n000000?l0003o00@0003o0P3oP0040000o`[ooooo0009ooooo`040;Ng]`2^[Zh0
[Zj^0;6a/@80[Jf]00@0];Bd0:n_[`2_[jl0ZZZZ0P2WYjL0102ZZZX0/[:b0;:b/P2IVIT202XZ:P04
08^;R`2TY:@0Y:BT0:NWY`80XZ:R00<0PX:207QhN01hN7P00`21PH40101nOWh0S8b<08b<S02HV9P2
0:BTY0040:2PX00g=cL0=cLg09^KV`80V9RH00@0Shn?09fMW@2MWId0UYJF0P2MWId01@2FUYH0T92@
08B4Q024Q8@0S8b<0080UiNG00@0Rh^;07inOP1nOWh0?Cdm0P2ATI430:6QX@0409nOW`2EUID0UIFE
09^KV`80UIFE00@0UiNG092@T02@T900TY:B0P2SXj<0102UYJD0<c<c03<c<`1RHV8207=cL`0407mo
O`26QXH0QXJ606QXJ080IfMW00@0LW9b07QhN01hN7P0P8200P22PX801@28R8P0QXJ607moO`1oOgl0
B4Q80080Ogmo00@0MWIf06i^KP1^KVh0N7Qh0P21PH40101lO7`0N7Qh07QhN01oOgl207alO00409:B
TP2CTi<0Ti>C0:^[Z`80K6a/00@0Ng]k0:JVYP2VYZH0XZ:R0P2JVYX0102ATI40Ti>C09>CT`2@T902
09>CT`040::RXP2<S8`0S8b<08>3P`80Q8B400@0J6QX05EEE@1EEED0ZZZZ0P2XZ:P01@2`/;00[:b/
0:n_[`2_[jl0ZJVY0080Z:RX00@0YjNW0:2PX02PX:00XZ:R0P2MWId0102<S8`092@T02@T902LW9`2
0:FUY@0408J6QP1_Kfl0Kfm_06UYJ@80GUiN00@0JFUY06IVIP1VIVH0T92@0P2KVi/0102NWYh0OGem
07emO@18B4P20::RXP0409nOW`2VYZH0YZJV0:JVYP80[jn_00@0YZJV0:2PX02PX:00Xj>S0_ooool9
0?n000@0003o0P3oP0000`000?l0oh000?n0000C0000o`030?n000000?l0003o0180003o00<0oh00
0000o`000?l040000?l00`3oP000003o0000o`0A0000o`80oh009P000?l20?n000<0003o00@0oh00
0000o`000?l0oh002`000?l00`3oP000003o0000o`050000o`80oh002@000?l00`3oP000003o0000
o`040000o`80oh0010000?l:ooooo`002Oooool0102h^;P0/k>c0;>c/`2d];@20:ZZZP040:VYZ@2^
[Zh0[Zj^0:VYZ@80ZZZZ00@0Xj>S0:2PX02PX:00WinO0P19BDT0102OWil0X:2P0:2PX02QXJ4209NG
U`0408V9R@1lO7`0O7al07emO@80N7Qh00@0TI6A09ZJVP2JVYX0Vi^K0P2SXj<0102GUiL0?Cdm03dm
?@2KVi/209VIV@0409:BTP2TY:@0Y:BT0:2PX080YJFU00D0S8b<092@T01fMWH0MWIf08N7Q`0208F5
Q@0408>3P`1eMGD0MGEe04E5A@80Ti>C00@0W9bL09>CT`2CTi<0TI6A0`2NWYh209VIV@0409NGU`2?
Shl0Shn?09BDU080WYjN00@0WIfM04E5A@15ADD0JVYZ0P1]KFd01021PH40Ng]k07]kN`20P80206IV
IP0407AdM01eMGD0MGEe075aL@80Jf][00D0O7al07IfMP1gMgL0MgMg04];B`02065QH@04061PH01S
Hf<0Hf=S06][J`80LG5a00@0JVYZ07=cL`1cLg<0Ng]k0P28R8P0102?Shl0UYJF09JFUP2JVYX206UY
J@0407moO`26QXH0QXJ607IfMP80Ph>300@0S8b<08R8R028R8P0TI6A0P2FUYH0102;Rh/0OGem07em
O@1ZJVX206IVIP<0Bd];00D0Shn?08b<S02<S8`0Shn?08Z:RP0208b<S00408V9R@1mOGd0OGem07mo
O`<0NWYj0P1kNg/0101NGUh05aLG01LG5`1ZJVX207AdM00406IVIP1>CTh0CTi>03`l?080=SHf00@0
?Shn03Hf=P0f=SH0C4a<0`1LG5`204I6AP0402h^;P14A4@0A4A404e=C@80Cdm?00@0@D5104M7A`17
AdL0FUYJ0P1VIVH00`1TI6Coooooooooo`040?n000<0003o0P3oP0070000o`80oh004`000?l00`3o
P000003o0000o`0B0000o`030?n000000?l0003o0100003o00<0oh000000o`000?l04@000?l20?n0
02D0003o0`3oP00@0000o`<0oh0010000?lH0?n000<0003o2_ooool000Wooooo00@0HF5Q05MGE`1G
EeL0HF5Q0P1<C4`01015ADD0>3Ph03Ph>00n?Sh20410@00403dm?@0d=3@0=3@d02TY:@805ADE00@0
DE5A051@D01@D500Cdm?0P13@d<01017AdL0BDU904U9B@1ADE4204U9B@0403`l?014A4@0A4A404M7
A`80ADE500@0?clo01XJ6P0J6QX0@4100P19BDT0100o?cl0>SXj03Xj>P0c<c<303Hf=P0402XZ:P0O
7al07alO01LG5`8061PH00@05QHF00l?3`0?3`l04Q8B0P0Z:RX0100c<c<0=CDe03De=@0d=3@203Xj
>P0403@d=00`<300<30`02`/;0807AdM00@0;bl_034a<@0a<C4071`L0P0Z:RX0100T92@07AdM01dM
7@0N7Qh2024Q8@<06a/K00@08b<S02l_;`0_;bl0:BTY0P0R8R801@0^;Rh0:b/[02`/;00/;2`0;Rh^
0080=3@d0`0b<S80100[:b/0:2PX02PX:00T92@202TY:@0405ADE01HF5P0F5QH059BDP80?Shn00@0
;Rh^03Ti>@0i>CT0?3`l0P0k>c/0100l?3`0>SXj03Xj>P0d=3@203<c<`0401TI6@0`<300<30`04U9
B@80D51@00@0EeMG04i>CP1>CTh0F5QH1@1MGEd01@1NGUh0CTi>04m?C`1?Cdl0;Rh^0080:RXZ0`10
@4001019BDT0B4Q804Q8B01=CDd205=CD`04059BDP1;Bd/0Bd];04m?C`80B4Q800@0CTi>02h^;P0^
;Rh0IVIV0P1`L700102:RXX0V9RH09RHV02FUYH20::RXP0409ZJVP2CTi<0Ti>C08^;R`80UiNG00@0
UYJF08F5Q@25QHD0@D510P25QHD0102@T93oooooooooo`000?l20?n000030000o`3oP000oh000:40
oh004P000?l0103oP000003o0000o`000?l:ooooo`002Oooool0101QHF40EeMG05MGE`1QHF4204a<
C00404E5A@0h>3P0>3Ph03hn?P80@41000@0?Cdm03@d=00d=3@0:BTY0P0E5AD0101ADE40D51@051@
D01?Cdl204=3@`0404M7A`19BDT0BDU9055AD@80BDU900@0?3`l04A4A014A4@0AdM70P15ADD0100o
?cl06QXJ01XJ6P10@40204U9B@0403lo?`0j>SX0>SXj03<c<`<0=SHf00@0:RXZ01lO7`0O7al05aLG
0P0H61P0100F5QH03`l?00l?3`0B4Q8202XZ:P0403<c<`0e=CD0=CDe03@d=080>SXj00@0=3@d030`
<00`<300;2`/0P0M7Ad0100_;bl0<C4a034a<@0L71`202XZ:P0402@T900M7Ad07AdM01hN7P808B4Q
0`0K6a/0100S8b<0;bl_02l_;`0Y:BT2028R8P0502h^;P0[:b/0;2`/02`/;00^;Rh00P0d=3@3038b
<P0402/[:`0X:2P0:2PX02@T9080:BTY00@0E5AD05QHF01HF5P0DU9B0P0n?Sh0100^;Rh0>CTi03Ti
>@0l?3`203/k>`0403`l?00j>SX0>SXj03@d=080<c<c00@06ATI030`<00`<300BDU90P1@D500101G
EeL0CTi>04i>CP1HF5P505eMG@0505iNGP1>CTh0Cdm?04m?C`0^;Rh00P0Z:RX30410@00404U9B@18
B4P0B4Q804e=C@80De=C00@0DU9B04];B`1;Bd/0Cdm?0P18B4P0101>CTh0;Rh^02h^;P1VIVH2071`
L00408Z:RP2HV9P0V9RH09JFUP80XZ:R00@0VYZJ09>CT`2CTi<0Rh^;0P2GUiL0102FUYH0QHF508F5
Q@11@D4208F5Q@04092@T?oooooooooo0000o`80oh0000<0003o0?n0003oP000X@3oP00B0000o`04
0?n000000?l0003o0000o`[ooooo0009ooooo`0408F5Q@1kNg/0Ng]k08J6QP80?Cdm00@0EUIF09VI
V@2IVIT0S8b<0P2?Shl0101mOGd0Q8B408B4Q027QhL209JFUP040:RXZ02SXj<0Xj>S09jNWP<0ZJVY
0P0d=3@0100l?3`0Ogmo07moO`1lO7`508>3P`0408F5Q@26QXH0QXJ608j>SP80QXJ600@0Shn?09NG
U`2GUiL0U9BD0`1CDe<0101WIfL0Vi^K09^KV`2QXJ420:BTY0040:RXZ02LW9`0W9bL0:FUY@80Z:RX
00@0ZJVY0:BTY02TY:@0SXj>0P2ZZZX0100l?3`0Jf][06][J`2JVYX208>3P`0407]kN`27QhL0QhN7
08n?S`80TI6A00@0PX:207inOP1nOWh0MWIf0P22PX801023Ph<0Ng]k07]kN`0F5QH207inOP050:>S
X`2LW9`0W9bL0:NWY`2CTi<00P2PX:00102RXZ80YjNW0:NWY`27QhL2092@T00409:BTP2[Zj/0Zj^[
07moO`80Fe]K00@0YjNW08J6QP26QXH0Xj>S0P2][Jd0102b/[80[Zj^0:j^[P2WYjL20:FUY@0409bL
W02EUID0UIFE09VIV@80Vi^K00@0@410096AT@2ATI40][Jf0P2d];@0102a/K40[:b/0:b/[02_[jl2
0;Fe]@050;bl_02n_[h0_[jn0<G5a@32`/800P35aLD0101cLg<0UiNG09NGU`2i^KT20;Fe]@040;Rh
^02j^[X0^[Zj0;^k^`80_Kfm00@0`/;20<71`@31`L40`L710P2l_;`0102d];@0E5AD05ADE02FUYH2
0;:b/P040;>c/`2a/K40/K6a0:RXZ080YZJV00<0Zj^[0:b/[02/[:`00`2[Zj/0102^[Zh0Xj>S0:>S
X`1GEeL209bLW0030:BTY?oooooooooo00@0003o0`3oP00B0000o`<0oh004P000?l30?n00140003o
0P3oP00C0000o`80oh004`000?l00`3oP000003o0000o`030000o`@0oh002@000?l00`3oP000003o
0000o`040?n00080003o2P3oP0030000oa80oh0000<0003o0?n0003oP0000`3oP0090000o`040?n0
00000?l0003o0?n000<0003o2_ooool000Wooooo00@0Zj^[0;:b/P2b/[80/;2`0P1:BTX0101[Jf/0
WinO09nOW`2KVi/2092@T0<0QHF500@0RXZ:09NGU`2GUiL0XZ:R0P2NWYh30:RXZ0040;2`/01OGel0
GemO05]KF`80UiNG00@0PH6108:2PP22PX80Ogmo0P1kNg/0101gMgL0Lg=c07=cL`1nOWh20861P@04
07UiN@26QXH0QXJ609RHV080DE5A00D0HV9R06ATI02ATI40TI6A0:NWY`020:JVYP040:6QX@23Ph<0
Ph>309ZJVP80WIfM0`2TY:@0102>SXh0[:b/0:b/[013@d<2075aL@0408j>SP1kNg/0Ng]k07UiN@80
NWYj00@0OGem07inOP1nOWh0OWin0P1lO7`307inOP0408F5Q@1oOgl0Ogmo020P8080Rh^;00D0X:2P
0:6QX@2QXJ40Xj>S09NGU`0209fMW@040:JVYP2TY:@0Y:BT07UiN@80NWYj00@0QXJ60:b/[02/[:`0
UiNG0P1NGUh309JFUP0409fMW@2NWYh0WYjN0::RXP80Xj>S00@0VYZJ09nOW`2OWil0Vi^K0P2ATI40
102JVYX0Ti>C09>CT`0o?cl20;:b/P030;fm_@2h^;P0^;Rh00<0^;Rh00<0_;bl0;jn_P2n_[h00`31
`L401@2k^k/0`<300;jn_P2n_[h0JFUY0080QXJ600@0ZZZZ0:n_[`2_[jl0YZJV0P2QXJ40102HV9P0
XZ:R0::RXP2XZ:P20;Ng]`<0[Zj^00@0Z:RX05MGE`1GEeL0Xj>S0P2VYZH00`2SXj<0YJFU0:FUY@04
0:BTY080XZ:R00@0YJFU0:NWY`2WYjL0Zj^[0P2HV9P0101?Cdl0Rh^;08^;R`2MWId2ooooo`030000
o`3oP000oh0000<0oh004P000?l0103oP000003o0000o`3oP00B0000o`030?n000000?l0003o0140
003o0P3oP00C0000o`80oh004`000?l00`3oP000003o0000o`0@0000oa<0oh001@000?l00`3oP000
003o0000o`050000o`D0oh0000<0003o0?n0003oP0004P000?l0103oP000003o0000o`000?l:oooo
o`002Oooool0102[Zj/0/[:b0;:b/P2`/;0204Y:BP0406][J`2OWil0WinO09^KV`80T92@0`25QHD0
102:RXX0UiNG09NGU`2RXZ8209jNWP<0Z:RX00@0/;2`05mOG`1OGel0Fe]K0P2GUiL01021PH40PX:2
08:2PP1oOgl207]kN`0407MgM`1cLg<0Lg=c07inOP80PH6100@0NGUi08J6QP26QXH0V9RH0P1ADE40
1@1RHV80I6AT096AT@2ATI40YjNW0080YZJV00@0XJ6Q08>3P`23Ph<0VYZJ0P2MWId30:BTY00408j>
SP2/[:`0[:b/04=3@`80LG5a00@0SXj>07]kN`1kNg/0NGUi0P1jNWX0101mOGd0OWin07inOP1nOWh2
07alO0<0OWin00@0QHF507moO`1oOgl0820P0P2;Rh/01@2PX:00XJ6Q0:6QX@2SXj<0UiNG0080WIfM
00@0YZJV0:BTY02TY:@0NGUi0P1jNWX01026QXH0[:b/0:b/[02GUiL205iNGP<0UYJF00@0WIfM09jN
WP2NWYh0XZ:R0P2SXj<0102JVYX0WinO09nOW`2KVi/2096AT@0409ZJVP2CTi<0Ti>C03lo?`80/[:b
00<0_Kfm0;Rh^02h^;P00`2h^;P00`2l_;`0_[jn0;jn_P030<71`@050;^k^`30`<00_[jn0;jn_P1Y
JFT00P26QXH0102ZZZX0[jn_0:n_[`2VYZH20:6QX@0409RHV02RXZ80XZ:R0:RXZ080]kNg0`2^[Zh0
102XZ:P0EeMG05MGE`2SXj<20:JVYP030:>SX`2UYJD0YJFU00@0Y:BT0P2RXZ80102UYJD0YjNW0:NW
Y`2[Zj/209RHV00404m?C`2;Rh/0Rh^;09fMW@;ooooo00<0003o0?n0003oP0000`3oP00B0000o`04
0?n000000?l0003o0?n00180003o00<0oh000000o`000?l04@000?l20?n001<0003o0P3oP00C0000
o`030?n000000?l0003o0100003o4`3oP0050000o`030?n000000?l0003o00D0003o1@3oP0000`00
0?l0oh000?n0000B0000o`040?n000000?l0003o0000o`[ooooo0009ooooo`040:ZZZP2/[:`0[:b/
0:ZZZP80ATI600@0I6AT09RHV02HV9P0W9bL0P2FUYH0102;Rh/0R8R808R8R02;Rh/208N7Q`0408n?
S`2=SHd0SHf=09RHV080WinO00@0YjNW05QHF01HF5P0AdM70P1mOGd308Z:RP0408B4Q01jNWX0NWYj
07QhN080MGEe0`26QXH307QhN00508^;R`1HF5P0F5QH069RHP1JFUX00P23Ph<0102UYJD0WinO09nO
W`2KVi/207MgM`0409JFUP2KVi/0Vi^K09jNWP80WinO00@0O7al0:6QX@2QXJ40?Shn0P1TI6@0101n
OWh0M7Ad07AdM01dM7@306m_K`80MGEe0`1hN7P0101mOGd0N7Qh07QhN01iNGT207IfMP0402h^;P2<
S8`0S8b<08Z:RP80UiNG00D0TI6A09JFUP2NWYh0WYjN0:BTY0020:JVYP0408N7Q`23Ph<0Ph>308^;
R`80Y:BT00@0Shn?04a<C01<C4`0Vi^K0P2IVIT0102OWil0XZ:R0::RXP2OWil20:>SX`<0WinO00@0
SXj>09>CT`2CTi<0TY:B0P2CTi<0100n?Sh0/;2`0;2`/02n_[h50;fm_@040;Vi^@2j^[X0^[Zj0;Vi
^@80]kNg00D0/k>c0;6a/@2/[:`0[:b/05ADE00207UiN@0409ZJVP2ATI40TI6A07IfMP80MGEe00@0
RHV909NGU`2GUiL0I6AT0P2WYjL0102BTY80U9BD09BDU02?Shl205IFEP0409BDU02QXJ40XJ6Q09nO
W`80W9bL00<0VIVI09RHV02HV9P00`2HV9P30::RXP040:BTY024Q8@0Q8B403Hf=P80Rh^;00<0VIVI
ooooooooool010000?l20?n001<0003o0`3oP00B0000o`040?n000000?l0003o0?n00100003o0P3o
P00C0000o`80oh004`000?l00`3oP000003o0000o`0@0000oa80oh0000<0003o0?n0003oP0004@00
0?l20?n00180003o00@0oh000000o`000?l0003o2_ooool000Wooooo00@0[Zj^0:f][@2][Jd0Xj>S
0P11@D400`1GEeL0Vi^K09^KV`0309nOW`0409ZJVP2IVIT0VIVI0::RXP80WinO00@0UIFE07alO01l
O7`0S8b<0P2EUID0102UYJD0CTi>04i>CP0^;Rh2075aL@0407MgM`24Q8@0Q8B408:2PP80OGem00<0
RXZ:08f=S@2=SHd00`2;Rh/308J6QP0508n?S`1JFUX0FUYJ04e=C@1TI6@00P2<S8`0102FUYH0SXj>
08j>SP2BTY8206][J`0407EeM@22PX80PX:2096AT@80Rh^;00@0JVYZ06UYJ@1YJFT0;2`/0P13@d<0
101kNg/0NWYj07YjNP1hN7P206e]K@04075aL@1kNg/0Ng]k0820P080PH6100@0N7Qh06e]K@1]KFd0
IfMW0P1RHV80100n?Sh0QXJ608J6QP2;Rh/408J6QP80TY:B00@0VYZJ0:NWY`2WYjL0Vi^K0P2DU9@0
1029RHT0Rh^;08^;R`1CDe<201LG5`0408F5Q@2?Shl0Shn?08F5Q@80Ph>300@0Rh^;08b<S02<S8`0
QhN70P24Q8@01023Ph<0SHf=08f=S@1oOgl207UiN@0403Ph>027QhL0QhN709bLW080TY:B00@0Shn?
09>CT`2CTi<0QhN70P22PX801@2ATI40Shn?08n?S`2>SXh0S8b<0080NGUi00@0@41006e]K@1]KFd0
F5QH0P19BDT0100k>c/0ADE504E5A@19BDT20451@@0404E5A@18B4P0B4Q803Hf=P80?clo00@0=cLg
034a<@0a<C40ATI60P1<C4`0101EEED0Bd];04];B`1=CDd204Q8B00404];B`1>CTh0CTi>04U9B@80
@D5100@0>SXj028R8P0R8R804a<C0P0S8b<00`0g=cOoooooooooo`030?n000040000o`3oP000oh00
0?n00180003o0`3oP00B0000o`<0oh004@000?l30?n00180003o0P3oP00A0000o`<0oh004P000?l0
0`3oP000003o0000o`0@0000o`80oh0000<0003o0?n0003oP0009P3oP00:ooooo`002Oooool0102^
[Zh0[Jf]0:f][@2SXj<20451@@0305MGE`2KVi/0Vi^K00<0WinO00@0VYZJ09VIV@2IVIT0XZ:R0P2O
Wil0102EUID0O7al07alO02<S8`209FEU@040:FUY@1>CTh0CTi>02h^;P80LG5a00@0MgMg08B4Q024
Q8@0PX:20P1mOGd00`2:RXX0SHf=08f=S@0308^;R`<0QXJ600D0Shn?05YJFP1JFUX0CDe=06ATI002
08b<S00409JFUP2>SXh0SXj>09:BTP80Jf][00@0MGEe08:2PP22PX80TI6A0P2;Rh/0101ZJVX0JFUY
06UYJ@0/;2`204=3@`0407]kN`1jNWX0NWYj07QhN080KFe]00@0LG5a07]kN`1kNg/0P8200P21PH40
101hN7P0KFe]06e]K@1WIfL2069RHP0403hn?P26QXH0QXJ608^;R`@0QXJ60P2BTY80102JVYX0YjNW
0:NWY`2KVi/209BDU00408V9R@2;Rh/0Rh^;05=CD`805aLG00@0QHF508n?S`2?Shl0QHF50P23Ph<0
102;Rh/0S8b<08b<S027QhL208B4Q00408>3P`2=SHd0SHf=07moO`80NGUi00@0>3Ph08N7Q`27QhL0
W9bL0P2BTY80102?Shl0Ti>C09>CT`27QhL208:2PP05096AT@2?Shl0Shn?08j>SP2<S8`00P1iNGT0
1010@400KFe]06e]K@1HF5P204U9B@0403/k>`15ADD0ADE504U9B@80@D5100@0ADE504Q8B018B4P0
=SHf0P0o?cl0100g=cL0<C4a034a<@16ATH204a<C00405EEE@1;Bd/0Bd];04e=C@80B4Q800@0Bd];
04i>CP1>CTh0BDU90P11@D40100j>SX08R8R028R8P0C4a<202<S8`0303Lg=ooooooooooo00<0oh00
00@0003o0?n0003oP000oh004P000?l30?n00180003o0`3oP00A0000o`<0oh004P000?l20?n00140
003o0`3oP00B0000o`030?n000000?l0003o0100003o0P3oP0000`000?l0oh000?n0000V0?n000[o
oooo0009ooooo`0406IVIP1/K6`0K6a/065QH@80<c<c00@0<S8b061PH01PH600IVIV0P1QHF40101K
Fe/0G5aL05aLG01LG5`205YJFP04061PH01KFe/0Fe]K06ATI080FUYJ00@0HV9R03De=@0e=CD0<C4a
0`13@d<203/k>`0404A4A00g=cL0=cLg03De=@80;2`/00@0=cLg030`<00`<300=cLg0P0];Bd01@0[
:b/08b<S02<S8`0R8R80:2PX0080;bl_00@0<C4a028R8P0R8R805ADE0P0F5QH0100B4Q805ADE01DE
5@0^;Rh202LW9`0401hN7P0G5aL05aLG014A4@805ADE0`0[:b/0100a<C40BDU904U9B@0n?Sh204=3
@`0304I6AP18B4P0B4Q800<0<S8b00@0@d=303/k>`0k>c/04Q8B0P0K6a/01@0S8b<0<30`030`<00o
?cl0?3`l0080;2`/00@0<S8b0410@010@400>c/k0P0b<S80100/;2`06ATI01TI6@0N7Qh202l_;`04
03Lg=`0Z:RX0:RXZ01@D50809BDU00@0=CDe03/k>`0k>c/0@D510P12@T80100F5QH08B4Q024Q8@0b
<S82034a<@0402d];@0c<c<0<c<c03Lg=`806a/K00<0;bl_04U9B@19BDT0101>CTh203Hf=P0504];
B`1@D500IFEU06EUI@1kNg/00P2:RXX0101VIVH0DE5A055AD@1aLG42071`L00406m_K`1[Jf/0Jf][
06ATI0808b<S00@0KVi^07AdM01dM7@0JVYZ0P1XJ6P0101SHf<0:BTY02TY:@0[:b/2061PH00406UY
J@1fMWH0MWIf07inOP80MWIf00@071`L07=cL`1cLg<0Lg=c0P1jNWX0102?Shl0QhN708N7Q`1:BTX2
ooooo`@0003o0`3oP0050000o`H0oh0000@0003o0?n0003oP000003o0P3oP0000`000?l0oh000?n0
001f0?n000H0003o00<0oh000000o`000?l01@000?l20?n000L0003o0`3oP0080000o`030?n00000
0?l0003o00H0003o00<0oh00ooooooooool02?ooool000Wooooo00@0MWIf051@D01@D500O7al0P1j
NWX0101fMWH0OWin07inOP22PX8203De=@0403Hf=P1cLg<0Lg=c07]kN`80NWYj00@0S8b<08^;R`2;
Rh/0:2PX0P1ADE40102LW9`0Vi^K09^KV`2XZ:P20:b/[00409BDU00n?Sh0?Shn06m_K`80VIVI0`2L
W9`0102ATI40MgMg07MgM`0X:2P209FEU@050:ZZZP2][Jd0[Jf]0:RXZ02^[Zh00P1LG5`0100[:b/0
SHf=08f=S@2DU9@208n?S`<0RXZ:00@0ATI6028R8P0R8R80@d=30P1JFUX0101MGEd0Lg=c07=cL`23
Ph<203dm?@0403De=@1ZJVX0JVYZ06EUI@80LG5a00@0L71`06m_K`1_Kfl0<30`0P0^;Rh0101ZJVX0
NGUi07UiN@1gMgL206m_K`0506ATI00_;bl0;bl_06e]K@22PX800P1eMGD01021PH40U9BD09BDU01H
F5P200`<300407YjNP2EUID0UIFE09:BTP80S8b<00@0WYjN07EeM@1eMGD0=CDe0P2ZZZX0102_[jl0
[Jf]0:f][@2TY:@209jNWP0402LW9`1fMWH0MWIf0:f][@80[jn_00@0/k>c0;fm_@2m_Kd0][Jf0P0^
;Rh0102UYJD0^k^k0;^k^`2i^KT20;^k^`050;Ng]`1FEUH0EUIF09fMW@2h^;P00P2i^KT0102f][H0
/[:b0;:b/P24Q8@2075aL@040:VYZ@2e]KD0]KFe0;Jf]P80];Bd00@0Z:RX03De=@0e=CD0ZJVY0P2_
[jl0102XZ:P0YjNW0:NWY`2WYjL20451@@0306a/K02YZJT0ZJVY00<0/K6a00@0];Bd0:6QX@2QXJ40
7alO0P20P800101gMgL0HF5Q065QH@1[Jf/206a/K0040410@?oooooooooo0000o`80oh001`000?l3
0?n000P0003o0`3oP0070000o`030?n000000?l0003o00L0003o0P3oP0030000o`030?n000000?l0
003o00@0oh0020000?l70?n000<0003o0`3oP0070000o`<0oh0020000?l00`3oP000003o0000o`05
0000o`<0oh002@000?l20?n000040000o`3oP000oh000?n000<0003o0P3oP0000`000?l0oh000?n0
00070?n000030000o`3oP000oh0000H0oh0000<0003o0?n0003oP000103oP0050000o`@0oh0000@0
003o0?n0003oP000003o0P3oP0040000o`80oh000`000?l40?n00080003o00<0oh000000o`000?l0
1P000?l00`3oP03oooooooooo`08ooooo`002Oooool0101fMWH0D51@051@D01lO7`207YjNP0407If
MP1nOWh0OWin08:2PP80=CDe00@0=SHf07=cL`1cLg<0Ng]k0P1jNWX0102<S8`0Rh^;08^;R`0X:2P2
055AD@0409bLW02KVi/0Vi^K0:RXZ080[:b/00@0U9BD03hn?P0n?Sh0Kfm_0P2IVIT309bLW004096A
T@1gMgL0MgMg02PX:080UIFE00D0ZZZZ0:f][@2][Jd0Z:RX0:j^[P0205aLG00402/[:`2=SHd0SHf=
09BDU080Shn?0`2:RXX01016ATH08R8R028R8P13@d<205YJFP0405eMG@1cLg<0Lg=c08>3P`80?Cdm
00@0=CDe06YZJP1ZJVX0IFEU0P1aLG40101`L700Kfm_06m_K`0`<30202h^;P0406YZJP1iNGT0NGUi
07MgM`80Kfm_00D0I6AT02l_;`0_;bl0KFe]08:2PP0207EeM@040861P@2DU9@0U9BD05QHF08030`<
00@0NWYj09FEU@2EUID0TY:B0P2<S8`0102NWYh0MGEe07EeM@0e=CD20:ZZZP040:n_[`2][Jd0[Jf]
0:BTY080WYjN00@09bLW07IfMP1fMWH0[Jf]0P2_[jl0102c/k<0_Kfm0;fm_@2f][H202h^;P040:FU
Y@2k^k/0^k^k0;Vi^@80^k^k00D0]kNg05IFEP1FEUH0WIfM0;Rh^0020;Vi^@040;Jf]P2b/[80/[:b
08B4Q080LG5a00@0ZJVY0;Fe]@2e]KD0][Jf0P2d];@0102XZ:P0=CDe03De=@2YZJT20:n_[`040:RX
Z02WYjL0YjNW0:NWY`80@D5100<0K6a/0:VYZ@2YZJT00`2a/K40102d];@0XJ6Q0:6QX@0O7al20820
P00407MgM`1QHF40HF5Q06][J`80K6a/00@0@410ooooooooool0003o0P3oP0070000o`<0oh002000
0?l30?n000L0003o00<0oh000000o`000?l01`000?l20?n000<0003o00<0oh000000o`000?l0103o
P0080000o`L0oh000`000?l30?n000L0003o0`3oP0080000o`030?n000000?l0003o00D0003o0`3o
P0090000o`80oh0000@0003o0?n0003oP000oh000`000?l20?n000030000o`3oP000oh0000L0oh00
00<0003o0?n0003oP0001P3oP0000`000?l0oh000?n000040?n000D0003o103oP00010000?l0oh00
0?n000000?l20?n000@0003o0P3oP0030000o`@0oh000P000?l00`3oP000003o0000o`060000o`03
0?n00?oooooooooo00Sooooo0009ooooo`0409>CT`1DE5@0E5AD0:^[Z`80/;2`00@0Zj^[0;2`/02`
/;00/K6a0P1MGEd0101`L700]KFe0;Fe]@2g]kL20;Rh^0040;bl_02m_Kd0_Kfm03Hf=P80HV9R00@0
[Zj^0;>c/`2c/k<0^KVi0`2g]kL204M7A`0408>3P`2e]KD0]KFe0;>c/`80[jn_00@0/;2`08>3P`23
Ph<0820P0P2IVIT01@2QXJ40YjNW0:NWY`2VYZH0Z:RX0080IFEU00@0@T920:BTY02TY:@0Zj^[0P2Y
ZJT0102^[Zh0[:b/0:b/[01IFET203Hf=P0405YJFP1WIfL0IfMW06][J`80KVi^00@0K6a/03De=@0e
=CD0=CDe0`1eMGD207MgM`0406UYJ@1SHf<0Hf=S02PX:080;Rh^00@0GUiN06YZJP1ZJVX0KVi^0P1X
J6P01@1UIFD08R8R028R8P1VIVH0NWYj0080LW9b00@0LG5a08b<S02<S8`0G5aL0P0=3@d0101jNWX0
W9bL09bLW02LW9`209ZJVP0409BDU01RHV80HV9R05IFEP80[jn_00@0/K6a0:BTY02TY:@0UIFE0P2=
SHd0100V9RH0MGEe07EeM@2YZJT20:RXZ0040;>c/`2k^k/0^k^k0;6a/@80;Bd]00@0/;2`0;bl_02l
_;`0^KVi0P2k^k/01@2i^KT0E5AD05ADE02IVIT0]kNg0080^[Zj00@0^k^k0;Vi^@2i^KT0QHF50P1a
LG40102`/;00/K6a0;6a/@2/[:`20:RXZ0040::RXP0l?3`0?3`l0:RXZ080[jn_00@0ZZZZ0:BTY02T
Y:@0Y:BT0P12@T800`23Ph<0];Bd0;Bd]0030;2`/0040;>c/`2LW9`0W9bL028R8P80QhN700@0NWYj
06MWI`1WIfL0O7al0P26QXH0101=CDgoooooooooo`000?l20?n000040000o`3oP000oh000000o`D0
oh0000<0003o0?n0003oP0001`3oP0020000o`P0oh000P000?l60?n000030000o`3oP000oh0000T0
003o00<0oh000000o`000?l00`000?l00`3oP000003o0000o`040?n000H0003o0`3oP0070000o`D0
oh001P000?l00`3oP000003o0000o`050000o`<0oh002@000?l50?n000@0003o0P3oP0040000o`l0
oh0000<0003o0?n0003oP000103oP0030000o`<0oh0010000?l20?n000030000o`3oP000oh0000@0
003o0P3oP0000`000?l0oh000?n000040?n00080003o00<0oh000000o`000?l01P000?l00`3oP03o
ooooooooo`08ooooo`002Oooool0102DU9@0EUIF05IFEP2TY:@20:^[Z`040:ZZZP2TY:@0Y:BT09nO
W`80Cdm?00@0NGUi0;Vi^@2i^KT0_;bl0P2i^KT30;Zj^P0404];B`1XJ6P0J6QX0:BTY080];Bd00@0
^;Rh0;Vi^@2i^KT0]kNg0P0o?cl01026QXH0[jn_0:n_[`2`/;020:b/[0040:n_[`2HV9P0V9RH03Lg
=`80Zj^[0`2a/K401@2`/;00Zj^[065QH@1QHF40=SHf0080VIVI00@0ZZZZ0:f][@2][Jd0[jn_0P2^
[Zh0101EEED0<C4a034a<@1IFET205iNGP0405]KF`1;Bd/0Bd];06MWI`80?clo00@0ATI608b<S02<
S8`0QhN70P20P800101bLW80IfMW06MWI`0X:2P202l_;`0405MGE`1HF5P0F5QH065QH@80Hf=S00D0
HF5Q02DU9@0U9BD0M7Ad08^;R`0208B4Q00407inOP2BTY80TY:B05mOG`803@d=00@0Ti>C0;Fe]@2e
]KD0[Zj^0P2TY:@0102QXJ40IfMW06MWI`1SHf<20;6a/@040;:b/P2a/K40/K6a0;6a/@80[Jf]00@0
<c<c07moO`1oOgl0ZJVY0P2_[jl0102d];@0^[Zj0;Zj^P2e]KD203@d=0<0]kNg0`2o_kl01@2j^[X0
E5AD05ADE02KVi/0_Kfm0080^[Zj00@0][Jf0;Fe]@2e]KD0RHV90P1cLg<0102PX:00WIfM09fMW@2L
W9`209:BTP0407moO`0f=SH0=SHf0:JVYP80[:b/00@0Zj^[0:RXZ02XZ:P0Xj>S0P0o?cl01020P800
[Zj^0:j^[P2^[Zh20;2`/0040:b/[02VYZH0YZJV03Lg=`80Zj^[00@0Rh^;08N7Q`27QhL0TI6A0P27
QhL0101:BT[oooooooooo`000?l20?n000L0003o0P3oP0000`000?l0oh000?n000070?n000<0003o
1`3oP0020000o`<0oh0000@0003o0?n0003oP000003o0P3oP0000`000?l0oh000?n000030?n000<0
003o00@0oh000000o`000?l0003o3@3oP0020000o`<0oh001`000?l60?n000D0003o00<0oh000000
o`000?l01`000?l00`3oP000003o0000o`030?n000H0003o2@3oP0030000oa00oh0000<0003o0?n0
003oP000103oP00:0000o`80oh001`000?l20?n000030000o`3oP000oh0000<0oh000`000?l00`3o
P000003o0000o`060000o`030?n00?oooooooooo00Sooooo0009ooooo`0409BDU01FEUH0EUIF0:BT
Y080Zj^[00@0ZZZZ0:BTY02TY:@0WinO0P1?Cdl0101iNGT0^KVi0;Vi^@2l_;`20;Vi^@<0^[Zj00@0
Bd];06QXJ01XJ6P0Y:BT0P2d];@0102h^;P0^KVi0;Vi^@2g]kL203lo?`0408J6QP2_[jl0[jn_0;2`
/080[:b/00@0[jn_09RHV02HV9P0=cLg0P2[Zj/30;6a/@050;2`/02[Zj/0HF5Q065QH@0f=SH00P2I
VIT0102ZZZX0[Jf]0:f][@2_[jl20:j^[P0405EEE@0a<C40<C4a05UIF@80GUiN00@0Fe]K04];B`1;
Bd/0IfMW0P0o?cl01016ATH0S8b<08b<S027QhL20820P004079bLP1WIfL0IfMW02PX:080;bl_00@0
EeMG05QHF01HF5P0HF5Q0P1SHf<01@1QHF409BDU02DU9@1dM7@0Rh^;0080Q8B400@0OWin09:BTP2B
TY80GemO0P0=3@d0102CTi<0]KFe0;Fe]@2^[Zh20:BTY0040:6QX@1WIfL0IfMW06=SH`80/K6a00@0
/[:b0;6a/@2a/K40/K6a0P2][Jd0100c<c<0Ogmo07moO`2YZJT20:n_[`040;Bd]02j^[X0^[Zj0;Fe
]@80=3@d0`2g]kL30;no_`050;Zj^P1DE5@0E5AD09^KV`2m_Kd00P2j^[X0102f][H0]KFe0;Fe]@29
RHT207=cL`040:2PX02MWId0WIfM09bLW080TY:B00@0Ogmo03Hf=P0f=SH0YZJV0P2/[:`0102[Zj/0
Z:RX0:RXZ02SXj<203lo?`040820P02^[Zh0[Zj^0:j^[P80/;2`00@0[:b/0:JVYP2VYZH0=cLg0P2[
Zj/0102;Rh/0QhN708N7Q`2ATI4208N7Q`0404Y:B_oooooooooo0000o`80oh001`000?l20?n00003
0000o`3oP000oh0000L0oh000`000?l70?n00080003o0`3oP00010000?l0oh000?n000000?l20?n0
00030000o`3oP000oh0000<0oh000`000?l0103oP000003o0000o`000?l=0?n00080003o0`3oP007
0000o`H0oh001@000?l00`3oP000003o0000o`070000o`030?n000000?l0003o00<0oh001P000?l9
0?n000<0003o403oP0000`000?l0oh000?n000040?n000X0003o0P3oP0070000o`80oh0000<0003o
0?n0003oP0000`3oP0030000o`030?n000000?l0003o00H0003o00<0oh00ooooooooool02?ooool0
00Wooooo00@0U9BD05YJFP1JFUX0Y:BT0P2[Zj/30:NWY`040::RXP1BDU80DU9B07MgM`80[jn_0`2`
/;00102b/[80^;Rh0;Rh^01CDe<206ATI0040861P@2<S8`0S8b<09nOW`80X:2P00@0VYZJ034a<@0a
<C40R8R80P2][Jd0102ZZZX0YZJV0:JVYP2[Zj/208J6QP0403/k>`2UYJD0YJFU0:NWY`<0[Jf]00@0
Vi^K05YJFP1JFUX0F5QH0P2SXj<30:^[Z`<0/;2`00@0GUiN071`L01`L700IFEU0P1cLg<0101DE5@0
H61P061PH01cLg<205UIF@0406m_K`2TY:@0Y:BT09VIV@80QhN700@0OGem06m_K`1_Kfl0;2`/0P0^
;Rh01013@d<0BTY:04Y:BP1:BTX203hn?P050451@@0L71`071`L08^;R`2IVIT00P2@T900102=SHd0
UIFE09FEU@1EEED201`L700409JFUP2ZZZX0ZZZZ0:^[Z`80Xj>S00@0UiNG06m_K`1_Kfl0De=C0P2O
Wil30:VYZ@040:FUY@2SXj<0Xj>S03Ph>080J6QX00@0M7Ad07=cL`1cLg<0Z:RX0P2c/k<0102b/[80
=SHf03Hf=P25QHD208:2PP0408R8R021PH40PH6107EeM@80<S8b00<0MWIf08>3P`1oOgl00P1oOgl2
06e]K@040451@@1ADE40DE5A06e]K@80JFUY00@0IVIV05aLG01LG5`0EUIF0P0X:2P0101JFUX0HV9R
069RHP1RHV8205]KF`0404I6AP0S8b<08b<S04=3@`80DE5A00@0DU9B04U9B@19BDT0@d=30P0b<S80
100N7Qh0?clo03lo?`0b<S8203De=@04034a<@0`<300<30`01/K6`;ooooo00<0003o0?n0003oP000
1`000?l20?n000030000o`3oP000oh0000L0oh002@000?l0103oP000003o0000o`3oP0060000o`80
oh000`000?l30?n000040000o`3oP000oh000?n000D0003o103oP0040000o`80oh000`000?l00`3o
P000003o0000o`070000o``0oh001`000?l30?n000T0003o0P3oP0070000o`80oh001@000?l50?n0
00L0003o0P3oP0070000o`<0oh001@000?l50?n000<0003o603oP00:ooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 197.562}, {389.5, 201.375}} -> {-6.41612, \
-5.43722, 0.675314, 0.675314}, {{201.375, 389.438}, {389.5, 201.375}} -> \
{-135.992, -5.43722, 0.675314, 0.675314}, {{9.5, 197.562}, {197.562, 9.5}} -> \
{-6.41612, -135.034, 0.675314, 0.675314}, {{201.375, 389.438}, {197.562, \
9.5}} -> {-135.992, -135.034, 0.675314, 0.675314}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute classification error", "Subsection"],

Cell[BoxData[{
    \(\(brickStats\  = \ 
        First\  /@ \ 
          Frequencies[
            Partition[Flatten[c1[\([1, 1]\)]], 
              3]];\)\), "\[IndentingNewLine]", 
    \(\(woodStats\  = \ 
        First\  /@ \ \ Frequencies[
            Partition[Flatten[c2[\([1, 1]\)]], 
              3]];\)\), "\[IndentingNewLine]", 
    \(\(bar1\  = \ {brickStats/\((Plus\  @@ \ brickStats)\), 
            woodStats/\((Plus\  @@ \ woodStats)\)}\  // \ 
          Transpose;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification error", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[bar1[\([1]\)], \ bar1[\([2]\)], \ 
        BarStyle \[Rule] {Blue, Orange}, \ \[IndentingNewLine]Frame \[Rule] 
          True, BarLabels \[Rule] {"\<Brick\>", "\<Wood\>"}, \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.810734 [
[.27273 -0.0125 -17 -12 ]
[.27273 -0.0125 17 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09579 -18 -4.5 ]
[-0.0125 .09579 0 4.5 ]
[-0.0125 .17686 -18 -4.5 ]
[-0.0125 .17686 0 4.5 ]
[-0.0125 .25794 -18 -4.5 ]
[-0.0125 .25794 0 4.5 ]
[-0.0125 .33901 -18 -4.5 ]
[-0.0125 .33901 0 4.5 ]
[-0.0125 .42008 -18 -4.5 ]
[-0.0125 .42008 0 4.5 ]
[-0.0125 .50116 -18 -4.5 ]
[-0.0125 .50116 0 4.5 ]
[-0.0125 .58223 -18 -4.5 ]
[-0.0125 .58223 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -17 0 ]
[.27273 .63053 17 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -78 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Brick) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wood) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09579 m
.00625 .09579 L
s
[(0.1)] -0.0125 .09579 1 0 Mshowa
0 .17686 m
.00625 .17686 L
s
[(0.2)] -0.0125 .17686 1 0 Mshowa
0 .25794 m
.00625 .25794 L
s
[(0.3)] -0.0125 .25794 1 0 Mshowa
0 .33901 m
.00625 .33901 L
s
[(0.4)] -0.0125 .33901 1 0 Mshowa
0 .42008 m
.00625 .42008 L
s
[(0.5)] -0.0125 .42008 1 0 Mshowa
0 .50116 m
.00625 .50116 L
s
[(0.6)] -0.0125 .50116 1 0 Mshowa
0 .58223 m
.00625 .58223 L
s
[(0.7)] -0.0125 .58223 1 0 Mshowa
.125 Mabswid
0 .03093 m
.00375 .03093 L
s
0 .04714 m
.00375 .04714 L
s
0 .06336 m
.00375 .06336 L
s
0 .07957 m
.00375 .07957 L
s
0 .112 m
.00375 .112 L
s
0 .12822 m
.00375 .12822 L
s
0 .14443 m
.00375 .14443 L
s
0 .16065 m
.00375 .16065 L
s
0 .19308 m
.00375 .19308 L
s
0 .20929 m
.00375 .20929 L
s
0 .22551 m
.00375 .22551 L
s
0 .24172 m
.00375 .24172 L
s
0 .27415 m
.00375 .27415 L
s
0 .29036 m
.00375 .29036 L
s
0 .30658 m
.00375 .30658 L
s
0 .32279 m
.00375 .32279 L
s
0 .35522 m
.00375 .35522 L
s
0 .37144 m
.00375 .37144 L
s
0 .38765 m
.00375 .38765 L
s
0 .40387 m
.00375 .40387 L
s
0 .4363 m
.00375 .4363 L
s
0 .45251 m
.00375 .45251 L
s
0 .46873 m
.00375 .46873 L
s
0 .48494 m
.00375 .48494 L
s
0 .51737 m
.00375 .51737 L
s
0 .53359 m
.00375 .53359 L
s
0 .5498 m
.00375 .5498 L
s
0 .56601 m
.00375 .56601 L
s
0 .59844 m
.00375 .59844 L
s
0 .61466 m
.00375 .61466 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Brick) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wood) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09579 m
1 .09579 L
s
.99375 .17686 m
1 .17686 L
s
.99375 .25794 m
1 .25794 L
s
.99375 .33901 m
1 .33901 L
s
.99375 .42008 m
1 .42008 L
s
.99375 .50116 m
1 .50116 L
s
.99375 .58223 m
1 .58223 L
s
.125 Mabswid
.99625 .03093 m
1 .03093 L
s
.99625 .04714 m
1 .04714 L
s
.99625 .06336 m
1 .06336 L
s
.99625 .07957 m
1 .07957 L
s
.99625 .112 m
1 .112 L
s
.99625 .12822 m
1 .12822 L
s
.99625 .14443 m
1 .14443 L
s
.99625 .16065 m
1 .16065 L
s
.99625 .19308 m
1 .19308 L
s
.99625 .20929 m
1 .20929 L
s
.99625 .22551 m
1 .22551 L
s
.99625 .24172 m
1 .24172 L
s
.99625 .27415 m
1 .27415 L
s
.99625 .29036 m
1 .29036 L
s
.99625 .30658 m
1 .30658 L
s
.99625 .32279 m
1 .32279 L
s
.99625 .35522 m
1 .35522 L
s
.99625 .37144 m
1 .37144 L
s
.99625 .38765 m
1 .38765 L
s
.99625 .40387 m
1 .40387 L
s
.99625 .4363 m
1 .4363 L
s
.99625 .45251 m
1 .45251 L
s
.99625 .46873 m
1 .46873 L
s
.99625 .48494 m
1 .48494 L
s
.99625 .51737 m
1 .51737 L
s
.99625 .53359 m
1 .53359 L
s
.99625 .5498 m
1 .5498 L
s
.99625 .56601 m
1 .56601 L
s
.99625 .59844 m
1 .59844 L
s
.99625 .61466 m
1 .61466 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.09091 .01472 m
.09091 .4949 L
.27273 .4949 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .4949 L
.27273 .4949 L
.27273 .01472 L
.09091 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .60332 L
.72727 .60332 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .60332 L
.72727 .60332 L
.72727 .01472 L
.54545 .01472 L
s
1 .5 0 r
.27273 .01472 m
.27273 .34526 L
.45455 .34526 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .34526 L
.45455 .34526 L
.45455 .01472 L
.27273 .01472 L
s
1 .5 0 r
.72727 .01472 m
.72727 .23685 L
.90909 .23685 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .23685 L
.90909 .23685 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00MOooool4o`0000;ooooo0ol0
0003ooooo`Go00000_ooool3o`0000;ooooo0_l000000ooooooo0000o`000024ooooo`03o`000?oo
oooo000000?ooooo0ol00003ooooo`?o00000oooool4o`0006Cooooo001fooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Ko0000oooooooooooo0000ooooool00025ooooo`03o`000?oooooo000000;ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`1Sooooo`00M_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`;o0000Q_ooool00ol0003oooooo`000002ooooo`07o`00
0?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool0Hoooool007Kooooo0ol00003ooooo`;o00001Oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Ko0000oooooooooooo0000ooooool00024ooooo`07o`000?oooooo0000ooooool0003o
ooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`1Sooooo`00M_ooool01Ol0003oooooooooool0003ooooo00;o000000Coooooo`000?l0
003ooooo0ol00004ooooo`?o00000oooool01?l0003oooooo`000?l00023ooooo`05o`000?oooooo
0000ooooool000000_ooool3o`0000?ooooo0ol00003ooooo`?o0000IOooool007Kooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`24ooooo`05o`000?oooooo0000ooooool00000
4?ooool00ol0003oooooooooo`1Sooooo`00MOooool4o`0000[ooooo00?o0000ooooooooool01ooo
ool2o`0008Kooooo1_l0000>ooooo`;o0000IOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool002Goooooo`00001L0000
013ooooo000Uooooo`0300000?oooooooooo05cooooo00?o0000ooooooooool0V_ooool00`00003o
ooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Mooooo`;o00001_ooool00`00003ooooo
ooooo`1Looooo`03o`000?oooooooooo09[ooooo00<00000ooooooooool0Foooool00`00003ooooo
ooooo`0>ooooo`007?ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo0?oooooo
F?ooool00`00003oooooooooo`0>ooooo`007?ooool01?l0003oooooooooool00005ooooo`030000
0?oooooooooo0?ooooooF?ooool00`00003oooooooooo`0>ooooo`007?ooool01?l0003ooooooooo
ool00005ooooool00000G000000@ooooo`007?ooool01?l0003oooooooooool00005ooooo`030000
0?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
0?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
0?oooooooooo01gooooo00<00000ooooooooool03_ooool001cooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Mooooo`;o00001_oo
ool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01gooooo00<00000ooooooooool03_ooool002Gooooo0`00000Mooooo`0300000?l00?oo003o
03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o
03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Looooo`03o`000000003ooooo
00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool002Gooooo
00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl0
00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl0
00<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003ooooooooo
o`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003ooooooooo
o`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000
o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000
o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000
ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>oooo
o`009Oooool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo0003
00000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo0003
00000?oooooooooo01cooooo00?o000000000?ooool03oooool002Gooooo00<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l0
0?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l0
0?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool0
02Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl0
03_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl0
03_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`<000007Oooool00`00003o003o
o`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003o
o`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07?ooool00ol000000000
ooooo`0?ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000U
ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000k
oomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000k
oomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool002Gooooo00<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooo
ooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`03
00000?oooooooooo00kooooo000Uooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<00000ooooooooool07?ooool00ol000000000ooooo`0?ooooo`009Ooo
ool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01gooooo00<00000ooooooooool03_ooool0017ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00006ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool0013o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo
01gooooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`05ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool0013o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`<000007Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool06oooool30000
013ooooo000@ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool00`00
003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00
003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00
003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00007ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool0017o
oooo0_l0000:ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool07Oooool00`00003o
003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o
003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o
ooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o
00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o
00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo
000Uooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
0000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
0000ooooooooool07?ooool00ol000000000ooooo`0?ooooo`009Oooool00`00003oooooooooo`0M
ooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0M
ooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0M
ooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00
ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00
ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000oooo
ooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`00
9Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oo
oooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oo
oooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oo
oooooooo01gooooo00<00000ooooooooool03_ooool002Gooooo0`00000Mooooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Looooo`03o`000000003o
oooo00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool002Go
oooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003ooooo
ooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003ooooo
ooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<0
0000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<0
0000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<0
0000ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0l
o`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0l
o`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>
ooooo`009Oooool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo
000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo
000300000?oooooooooo01cooooo00?o000000000?ooool03oooool002Gooooo00<00000oooooooo
ool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooooooo
ool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooooooo
ool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`030000
0?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`030000
0?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`030000
0?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l0
0?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l0
0?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_oo
ool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3o
ogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3o
ogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool30000
01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo
01cooooo00?o000000000?ooool03oooool002Gooooo00<00000ooooooooool07Oooool00`00003o
003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o
003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o
ooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o
00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o
00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo
000Aooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Gooooo00<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`00
4?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00<00000oooooooo
ool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooooooo
ool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooooooo
ool07Oooool00`00003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00Cooooo0`00000Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`00003oooooooooo`0Kooooo`<000004?ooool0013ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Gooooo00<00000ooooooooool07Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00
003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Aoooo
o`;o00002Oooool3o`0000Kooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>oooo
o`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`<00000
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7?ooool00ol000000000ooooo`0?ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l0
0?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l0
0?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool0
02Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl0
03_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl0
03_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo
00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo
00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo
00<00000ooooooooool03_ooool002Gooooo0`00000Mooooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`00003oooooooooo`0Looooo`03o`000000003ooooo00oooooo000U
ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000k
oomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000k
oomo000300000?oooooooooo01gooooo00<00000ooooooooool03_ooool002Gooooo00<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooo
ooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`03
00000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0
??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0
??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000ooooooooool0
3_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<00000ooooooooool07Oooool00`00003oooooooooo`0>ooooo`009Oooool3
000001gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooo
oooo01cooooo00?o000000000?ooool03oooool002Gooooo00<00000ooooooooool07Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00
003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?oooooooooo00ko
oooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0
oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?lo000001oooooo
00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00
o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00
o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo0`00000M
ooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0M
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0F_ooool00ol000000000ooooo`0?
ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo
0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oooo
ooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`00
4Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Kooooo00<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool0
3_ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Go
oooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_o
oooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ooooooooo`1Kooooo`0300000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00006ooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05Wo
oooo0`00000@ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?o
oooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_o
oooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool0017ooooo0_l00009ooooo`?o
00001_ooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oooooooo
ool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`030000
0?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`030000
0?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Ooo
ool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oo
oooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Jooooo`03o`000000
003ooooo00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l0
0`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo
00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003o
ooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo
00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo
00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo
000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo
000koomo000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003ooooooooo
o`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`<000007Oooool00`00003o003oo`00o`0l
o`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0l
o`00o`0300000?oooooooooo05[ooooo00?o000000000?ooool03oooool002Gooooo00<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000oooo
ooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000oooo
ooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool0
7Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool0
3_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
oooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool0
0`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000ooooooooool07Oooool0
0`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool0
02Gooooo0`00000Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00
003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0F_ooool00ol0
00000000ooooo`0?ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co
003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003ooooo
ooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003ooooo
ooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooo
ooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<0
0000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0M
ooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00003oooooooooo`0M
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>
ooooo`009Oooool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo
000300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Joooo
o`03o`000000003ooooo00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool0
0?l0??l00?l00`00003oogl0oomo000koomo000300000?oooooooooo01gooooo00<00000o`00ool0
0?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`030000
0?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
0?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`030000
0?oooooooooo00kooooo000Aooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001Ooo
ool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Fooo
ool00`00003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00Cooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
oooooooo05_ooooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00001ooo
ool5o`0000Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oo
oooooooo05_ooooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00006ooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`030000
0?oooooooooo05Wooooo0`00000@ooooo`004?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Kooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`030000
0?oooooooooo05_ooooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooooooo0000
2Oooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00ocl00000
7oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool0
3_ooool0017ooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool07Ooo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo
003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool30000
01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o
03co003o00<00000ooooooooool0F_ooool00ol000000000ooooo`0?ooooo`009Oooool00`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o
003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo
00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo
00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo
000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003ooooooooo
o`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooooooo
o`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000
ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Koooo
o`0300000?oooooooooo00kooooo000Uooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Jooooo`03
o`000000003ooooo00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0
??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0
Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l0
0?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oo
oooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool0
0`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l0
0`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o
03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o
003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo
0`00000Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003o
o`00o`0lo`00o`0300000?oooooooooo05[ooooo00?o000000000?ooool03oooool002Gooooo00<0
0000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<0
0000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000U
ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1K
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>
ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oooo
ooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000oooo
ooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`03
00000?oooooooooo00kooooo000Uooooo`<000007Oooool00`00003o003oo`00o`0lo`00o`030000
0?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Jooooo`03o`00
0000003ooooo00oooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Fooo
ool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo
003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooo
oooo05_ooooo00<00000ooooooooool03_ooool0017ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00006ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00
003oooooooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00
003oooooooooo`0>ooooo`004?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000
ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`03
ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1K
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>
ooooo`004?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo0`00000M
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0l
o`00o`0300000?oooooooooo05Wooooo0`00000@ooooo`004?ooool01?l0003oooooooooool00007
ooooo`Co00001_ooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000
ooooooooool03_ooool0013ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`07
ooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1K
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>
ooooo`004Oooool2o`0000Sooooo1Ol00005ooooo`0300000?oooooooooo01gooooo00<00000o`00
ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000oooo
ooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`03
00000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo0`00000Mooooo`030000
0?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`030000
0?oooooooooo05[ooooo00?o000000000?ooool03oooool002Gooooo00<00000ooooooooool07Ooo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooo
oooo01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo
003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00
003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00
003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Go
oooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_o
oooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00ko
oooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003ooooo
ooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooo
ooooo`0>ooooo`009Oooool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003ooooooooo
o`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0F_ooool00ol000000000oooo
o`0?ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000
ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000
ooooooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00
o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Koooo
o`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool0
0?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o03co003o00<00000oooooooo
ool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`0Mooooo`030000
0?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o003oo`00o`0lo`00o`030000
0?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool07Ooo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`<000007Oooool0
0`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l0
0`00003oooooooooo`1Jooooo`03o`000000003ooooo00oooooo000Uooooo`0300000?oooooooooo
01gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?l00?oo003o
03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003o
ooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003o
003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo
00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo
00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo
000Uooooo`0300000?oooooooooo01gooooo00<00000o`00ool00?l0??l00?l00`00003ooooooooo
o`1Kooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooooooo
o`0>ooooo`009Oooool3000001gooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1K
ooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0F_ooool00ol000000000ooooo`0?
ooooo`009Oooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000oooo
ooooool0Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000oooo
ooooool03_ooool002Gooooo00<00000ooooooooool07Oooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`03
00000?oooooooooo00kooooo000Aooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1_ooool00`00003oooooooooo`0Mooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0
Foooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool0
3_ooool0013ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Go
oooo00<00000ooooooooool07Ooooom0000005gooooo00<00000o`00ool00?l0??l00?l00`00003o
ooooooooo`1Kooooo`0300000?oooooooooo00kooooo000@ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000005ooooo`0300000?oooooooooo0;[ooooo00<00000o`00
ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000@ooooo`04
o`000?ooooooooooo`0000Oooooo1?l00006ooooo`<00000^_ooool00`00003o003oo`00o`0lo`00
o`0300000?oooooooooo05Wooooo0`00000@ooooo`004?ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Oooooo00<00000ooooooooool0^_ooool00`00003o003oo`00o`0lo`00
o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool0013ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo0;[ooooo00<00000o`00
ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Aooooo`;o
00002_ooool2o`0000Kooooo00<00000ooooooooool0^_ooool00`00003o003oo`00o`0lo`00o`03
00000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool0
^_ooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool0
3_ooool002Gooooo0`00002jooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0F_oo
ool00ol000000000ooooo`0?ooooo`009Oooool00`00003oooooooooo`2jooooo`0300000?l00?oo
003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00
003oooooooooo`2jooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00
003oooooooooo`0>ooooo`009Oooool00`00003oooooooooo`2jooooo`0300000?l00?oo003o03co
003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool00`00003ooooo
ooooo`2jooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooo
ooooo`0>ooooo`009Oooool00`00003oooooooooo`2jooooo`0300000?l00?oo003o03co003o00<0
0000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool300000;[ooooo00<00000
o`00ool00?l0??l00?l00`00003oooooooooo`1Jooooo`03o`000000003ooooo00oooooo000Uoooo
o`0300000?oooooooooo0;[ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Koooo
o`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo0;[ooooo00<00000o`00ool0
0?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`030000
0?oooooooooo0;[ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`030000
0?oooooooooo00kooooo000Uooooo`0300000?oooooooooo0;[ooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000Uooooo`0300000?oooooo
oooo0;[ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`0300000?oooooo
oooo00kooooo000Uooooo`<00000^_ooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo
05[ooooo00?o000000000?ooool03oooool002Gooooo00<00000ooooooooool0^_ooool00`00003o
003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo
00<00000ooooooooool0^_ooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo
00<00000ooooooooool03_ooool002Gooooo00<00000ooooooooool0^_ooool00`00003o003oo`00
o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_ooool002Gooooo00<00000
ooooooooool0^_ooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000
ooooooooool03_ooool002Gooooo0`00002jooooo`0300000?l00?oo003o03co003o00<00000oooo
ooooool0F_ooool00ol000000000ooooo`0?ooooo`009Oooool00`00003oooooooooo`2jooooo`03
00000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`00
9Oooool00`00003oooooooooo`2jooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0
Foooool00`00003oooooooooo`0>ooooo`004Oooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`0300000?oooooooooo0;[ooooo00<00000o`00ool00?l0??l0
0?l00`00003oooooooooo`1Kooooo`0300000?oooooooooo00kooooo000@ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`2jooooo`0300000?l0
0?oo003o03co003o00<00000ooooooooool0Foooool00`00003oooooooooo`0>ooooo`004?ooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0^_oo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_oo
ool0013ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`04ooooo`<00000^_oo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05Wooooo0`00000@ooooo`004?ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool0^_oo
ool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo00<00000ooooooooool03_oo
ool0013ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Gooooo
00<00000ooooooooool0^_ooool00`00003o003oo`00o`0lo`00o`0300000?oooooooooo05_ooooo
00<00000ooooooooool03_ooool0017ooooo0_l00008ooooo`Go00001Oooool00`00003ooooooooo
o`2jooooo`0300000?l00?oo003o03co003o00<00000ooooooooool0Foooool00`00003ooooooooo
o`0>ooooo`009Oooool00`00003oooooooooo`2jooooo`0300000?l00?oo003o03co003o00<00000
ooooooooool0Foooool00`00003oooooooooo`0>ooooo`009Oooool300000;[ooooo00<00000o`00
ool00?l0??l00?l00`00003oooooooooo`1Jooooo`03o`000000003ooooo00oooooo000Uooooo`03
00000?oooooooooo0;[ooooo00<00000o`00ool00?l0??l00?l00`00003oooooooooo`1Kooooo`03
00000?oooooooooo00kooooo000Uooooo`0300000?oooooooooo0;[ooooo@000001Mooooo`030000
0?oooooooooo00kooooo000Uooooo`0300000?oooooooooo0?ooooooF?ooool00`00003ooooooooo
o`0>ooooo`009Oooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool03_ooool0
02Gooooo00<00000ooooooooool0G?ooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo
05_ooooo00<00000ooooooooool03_ooool002Gooooo0`00001Looooo`0300000?oooooooooo09[o
oooo00<00000ooooooooool0F_ooool00ol000000000ooooo`0?ooooo`009Ooooooo000005`00000
4?ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool007Gooooo1?l00002ooooo`?o00000oooool5o`00
00;ooooo0ol00002ooooo`;o000000?oooooo`000?l00000Q?ooool00ol0003oooooo`000003oooo
o`?o00000oooool3o`0000?ooooo1?l0001Tooooo`00M_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooo
ooooo`000?oooooo0000QOooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0
003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0Hoooool007Ko
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool2o`0008Kooooo00?o0000ooooool000000_ooool01ol0003ooooooooooooo
oooo0000ooooool000000oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo06?ooooo
001fooooo`?o00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`06o`00
0?ooooooooooo`000?oooooo0000Q?ooool01ol0003oooooo`000?oooooo0000ooooool000000ooo
ool00ol0003oooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0Hooo
ool007Kooooo00Go0000oooooooooooo0000ooooo`02o`000004ooooool0003o0000ooooo`?o0000
1?ooool3o`0000?ooooo00Co0000ooooool0003o0000Poooool01Ol0003oooooo`000?oooooo0000
00;ooooo0ol00003ooooo`?o00000oooool3o`0006Gooooo001fooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool0Q?ooool01Ol0003oooooo`000?oooooo0000013ooooo00?o0000
ooooooooool0Hoooool007Gooooo1?l0000:ooooo`03o`000?oooooooooo00Oooooo0_l00026oooo
o`Ko00003_ooool2o`0006Gooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.359117, -0.0764094, \
0.00636706, 0.00356975}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency-based classification (2D)", "Section"],

Cell[CellGroupData[{

Cell["Read in image files", "Subsection"],

Cell[BoxData[{
    \(\(brick = ReadWholeImage[BrickFile];\)\ \), "\[IndentingNewLine]", 
    \(\(brickIm = brick;\)\), "\[IndentingNewLine]", 
    \(wood = ReadWholeImage[WoodFile]; woodIm = wood;\)}], "Input"],

Cell[BoxData[
    \(\(size = \(brick[\([1, 1]\)]\  // \ Dimensions\)\  // \ 
          First;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show image files", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{brick, wood}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A8393A1AF9E5037B3B9BCB8B67D2F7F757780858147ADB1AAA9AB951E788F94999E9326
556269696E733D7E929DA4AAA9B0B4579FB2B2B0B0713A9DABAFABB06E338380929CA96C
2546495568754F6EB9B2AFADAE539AB8B8BABCB664B4B8BCB9B85B84B2ADB4B48689B2AF
ADACA95388A5ACB1AD8683C3C7C0BEAD52ACB0AE
5E91A1B5B9B37239AEBCBCBCB97E38756D6E7884883AA8B0AEAAAD91268C9BA5A4A19522
647E836D68593180969FA3AAAEB3B555A1ABAFAEB0762C87A0A0AAAD6C369C979CA3A977
3D65434E67704973B3ABADB0AC5196B3AFB0BAAB6BB7B9BFB9B96A8FB3ABB3B5A6A1BDB6
B8B6B25C869EAAABB5938DBBBBBBBFC36FAAAAAA
5E97AAADA8A5662D9EB5B4B9B89D5571696A75859138839DA3A397623F8392A19E98842E
57796F6E60502C8AA3ABA1A7AEB0B05398ABADAFB0742AAA9F90A0AB703B9F9DA2A6AC78
4795535E6F734561B3A8A6AEB04E95B6B2B1B1B064B6BFB8BCB96B8EB4B5B3B6A498B7B8
B6B2B1579CB0AEB5B89286B0B0AEB3BC72ADA39E
3C40463D393829242F2F202826221E282328292D322D3D4E34291D151F3D3E3A35374932
383E3937342D2346494E4E575D66612E4E686C6E7145176D63575E755A216D6E6B7A7B52
3044372E2C363B629E98938590456A9EA4B1B5AA61B3BCB6BCAE4E65A0A3A2A88E8FBEBA
B5B8B75C8DAEACAEB0867FA5A698A5B7659EA6AA
A5A5ABA85F7F9088A0A4A8ACA3A6A49C948A6B66A49FA29E9A8D8C8F868F8C88824A6B79
6B70767877777878745E4732526665655E46564C4539392F2217212F34382F352B232A29
2A2B2D1F222F35373E3C3C3C2D1F171B2630231F10242C212A1803112724272E221C3643
45494D192E4B494D512D335161636D743B414A4C
AEAEB3B5589288809BADAFB2B5B1B3B0B1B16D6AAFABADACA8A5A8ABAEB1B7B3B55A7B86
858A8F9EA09C8E85858F9F4B7BACAAA9A68D969F7F7E656D6147887F72AAAAAD917085B4
B4B2B7677CADB3B2AEB2B1B0AEAAAAAB9357879B9FA09A999E9A8B878C8B7F668E8B877D
757A77696A6F726C60456B5D55515457686C6D66
AEA8ACB2529D8C90A1A4A5A0A6A7A6ACADB06F6AAAABACACAAA4A6A7A8ACAFB6B34CA49C
95A4A5A6A7A49A898298A24681A1AFB3AA9696987476788382568A8C8CACABAC94776FB1
B8B6BA6179ADADA8A6A7A7A7A9A5ABACA75F8AAAADADAEB5BAB0A6A8ADABAF67BAC5C4C1
B6C2A78568B2BEB98A8FB8B3AAB3B7BCBDB3BCBB
B1AEB3B353A89795A7A3A6A3AAA3A5A4ADB16767AAABACABA8A6A9A6A5A6A6AEAB43A8A1
989BA3A7A6A09D948EA09B4B81A1AFB1B0AC9E9B9F94A0A48C538C9194A9A8AF8F7785B2
B5B3B95C76A9A8A5A4A9A9A8A7AAADADA4578AA9ABA9AAB2B6B2A5B0B4B2B34AA5C4C5C7
B9BB805340A7BEBD8B8AB9B7ACB6BABCBCBDC1BE
A9ACA49652808487878C909198928D9A9FA1695A888B9A9E8C938D948D8E8F9B9446A8A7
99A09DA1A1989A928B979B4579A59F9DB1B3ADABA9ACAAAB8750889B9FAAABB39A7E81B6
B9BAB9617FAFACA3A29F9FA3A6A7ACA6A26A96A8A6A19FA5AEB09DA0ACADAB4098BFBEB2
AAA46137449DB2B0718BBAB5ADB6BABFBDBABCBD
9A97938F8D877D787968356668757E797A777C65797E71583F5473767375786F6F6E6F62
5754405E7F7C798181877D767B7C6257534E4D4C5151555B4D444C6060695E5846495568
787578504E78796967657A7C82886D7382497A8C8575848F989D9C8D979D9F3884A69B7E
8079554A6B798C96738DAFB2ACB3BBBBB9B8BDB4
BBB7BABAB7B5B2AFA9AC4E9CA19FA3A5ABA8ADB1B4B3ACA160A1AFAEADB5B4B4BBB9BCBF
C0BA65ADAFA9A6A6A5AAADADAEB1B3B36B8EB2B0A7A4B4B7B4B8B6B1AFA56789979C9A97
9695969EA8A99A835A7B83777471797E7E887869653F49656A6A5A5B62615F645F6C6A44
61686264655C5F5B574B393B3B3A3E4C474F4A4B
B7B0B3B0AFACA9ACABAC50A2A5A59D98909DA8AAAFAEA9A75CA4ABACA9ABA9A9A7A9B1B7
BBBF76A7ADA49B9DA2A1A9AEAEADB0AE7B8CAAA7A6A5ACAEB0B0B0ACAAAA88B6BBC2BCBB
BEC2BFC1C1C5BEB589B8BAB8B4AFB6B7B3B3B4B6B35F89BABCBCBAB8B2B4B8B4BAC0BC69
AFB7B1ACAFB4B4B7B4A8A9AD9664A0AEB3AFA4A0
B1AFAFAAA9A9A6ABADAF608E899A9CA19F9FACADACABAAAC72B3AAA8A7A8AAA8ABA9ADB4
BBBA78B3AE9D9A95A6A0A4A2A5ABAFAD73819B96979FA8A7AAA9AEABA79D8BB5B8BCBBB7
B5BFC6BDBFC7C3B57AB5B7B8B5B1BBB8B5B2ABACAD5A7DB8BCBAB9B9B4B4B4B8B9BBB964
9BB3ACA9AFB3B2B0AFAAADAE9064ABB4B2B3ABB1
B3B1B1B6B09FA1A3A9A9578698A8B1B1AEA8ACB1B3B9B6B270A2A8A8A7AAADAAB3B0B5B7
BCBB7CB9B5B0AEA9A296A0ABB0B6B5B3637A8E8B8F94A1999DA2A2A89E7C81B1B4B6B7B9
BABDBDB7B8BEBBB183B3B1B6B9B7B2B1ADACABA6A3578BB4B7B9B8B6B1B3B2B1B7B9B456
94AFA8A7ADB1B0AEADAAACAB8E77AAB7B4B3A9AF
665D483931363431413C3432403B3C39423D30363C3E3B3A263E4C4B4D3D3B34352A3A43
463A3B595E61566061605D616A75736B344E5B5C666263646B6C6E6E6765487B80817C6C
667081858A908F65618E7FA3A1A49EA09C97989B924E85B1B3B8B6B4AFAEAEB3B2B3AD4A
9EB0AEAEB0B1B2B2AB9FAAB08C77A2A4B1A9A9B1
B7B6AB7279AEAFB3B3B3B4BCB8B4ADACA99352B3B6B7B3B2AAA59D948C8D9187499EACAD
A4A4A7A7A6A09B9791834F7D8182807E776C68656969767036525F595E656E6C67625B5D
563D2F4A4A4F4A493E2F463F403B354C525155484953544441483B2C2E373A43474D372D
414E4B50545A5E62666C6A685235535D6A656276
B1B2A87689ADB1B5B5B9BABBC0BBAEA6ABAC5AADAFB5A7AEADA9A29D8C90979B51AEB0A9
A9AEAFB5B4AFAAA4A3A16AA9B8BBBDBEBCB9BAB9B5B9BCBC69B2B2AAA7B4B4B4B3B8B8B4
B29557B098B3BBBDBEBEBFBFBB6B64B4B6B8B7B3B3B7BBBBC1BFB86D7DA5A9A0B0BCBBBA
AFAB9A968C4E72857E807F726D747B7078818462
B0B0AD778AAEAEB2B8B3B4B2B3B4AD9EAC9E5BAEB3B3A4A8A8A5A79E9B9E9CA049ACAEAB
A4A0AEB7B5B1AEA99F9E67AFB6B7BBBBBBBBBCB9B7B9BBBE65B3ACA9A7ABB2B4B2B2B0AD
AD9C78B39AAABFBEBDBCC2C3BD6869B7B1B6B5B4B6B9B5BCBEBEB8828EAFACA8B3BABABF
B8BCB9B7B056A3BEBEC0BDBBB8BBBDC0C2C1BC94
AEAFA96983B0A9ADB5A8AAA5A9ACAC99A5A162B5B4B4AFACA7A8A9A59F9F9BA342A0B2A4
A6A9ACB5AEADACA9A69E5FAFB4B3B5B7B6B6BBBBB6B3B2A562B2AA98A1AEB7BCB7B3B1AE
AE9672AEA8ADB1B8B6BBBDBAB77565B3B2B6B3B3B4B7B8B8BEBDB9748BADAB9BAFB7BBB7
B2B3B4BAB147B0C3C5C3BBB7B2B7BBBEC3C0B98F
887E6B485F7B7981867E7678736E716A666449888488806265666B6D5B5F535723406572
777E92918976817D84803B909EABAB8C96A1B6A298B4B5A66FB2A6899FACB0B4B2B5B0B5
B28D5999ADB2B3B4B6B1B4B2AB7173B4B0ABADB0B0B3B5B7B9B6B46B8DA9A9A0ADB7B8B7
AEB1B4B8AF47ADBFBEBCB7B5A8B3B8BDBBBCA881
A4998D909088858484576470717378796E6F7D777B80795542656E6C727173716C6C7A75
655B3053555758565C5A6454585B573E24414842423C3F4D464838424F333D5045575745
4F502F3B4553564C4E4E4E57634336494952555B575A5E63626166323260697172787D7C
777D6F786E2F6B9497949B98949191A3A6AD7962
B9B7B8BCBCBCB9B7B56E92B2A8B7B8B9B8B4B9B8B7B8B87A6BADA7A7AFB1B8B7B8B4B3AD
AA933DA3B0A49A928C84949CA2A6ABAB529AA4A3A7A9A9A6B1B2B1ABACAF69A6A8A4A6AA
ABA7ACA7AAA9A78677A6A6A7ACABA2A3A199988F7D3D55706D696A7679777A706D656440
5F63676665636463626467533F3D60636668665D
B8B7BDBEBFBCB8B8B56D91AD9AA9AEACABADAFB7B7B1AA826BA4A5A2A1A6A8A9AFAEB1AF
B2A149ACAFA79897948E8A8C94A3AEA741939D9D9DA5A1A4AEB1ABADB5B379ABA7A7A7A7
A8A8A7AAAAA9AA8381B0B0AEB3B4B2B0B2B4AAABA95F80A0AAB2B0AEAAADA7A4A8ADA861
A6AEAFB0B1B4B3B1AEA9AA947D6595A1ACB6B6B4
B7B5B7B8B5B5B4B7B0698AA998A9A9AEA6A9ABAEAEAFAB7D659A929FA2A5A7A7A9A7AEAD
B1AE48A5A89B9194838482858598A8963F8E96979A9C9C9BADACAAAAB3B16FA79FA09FA5
9FA1A3A5A4A5A7828BACADADAAA8A6ACABB0ABADA74E769EACA9ABAAA7A3A39CA29FA95C
9EACA8AAA9ACAEB3AFA8A7A79B679595A7AAAFAE
87827D7B7D848D8A8C5A7C907292949C9C9BA0A1A9A8A6774F8C9298A0A1A0A49AACB2AE
ACB04CA7A08F8C9183827B807F84948E578B8E84878EA09FAEADADABAFAA669997939191
969E9FA89E9FA27A80A9A8A7A8A6A5A4A6A3A3A6A15C7997AAABA9A49D9E9E9394969D59
A0A6ABABA7A7ACAFAE9898A5986B8B7896A5A7A7
695F51304D504942394B4F464946474F39293F464B413D392B302A232F2623232A4C5A60
5D494169726A554F5B5D57626B55585737394440424D51524C585658524D4265676D6D6B
6667645C63656251577A8072757F81817F70797E7F4A636776787D7162594E5D5B596348
7A828A70758B928F8F8378896859736E8AA09D9C
BAB9B16FB9B5B0B4ADB2B3B7BABEBFBAA65A7C88B3BAB9BEB5B2AEA5ACACA74AAAB4B3B0
ADB0A2AFAFACA19B8D509EACA7A4A8A8A29D9D959F9B7C457F8A85878C8F848B8E8E9195
8C56707A797B76736D68645859572C375E5A55585E645C56615A483C5C656559555B6468
5F544E432638473E413F3F3C4542494D58533E44
B5B4AE71B3B4B7B2AEB1ADB7BBBAB7B1AE4E8E95ABAFB7B4B1ABA8A5A8A49E53AFAEB0AE
A7B0AEAEABA5ABABAC60ACB1B2B6B5B4B0AB9B9DACB2A4539FA59C9BA4A7A6A5A3A6ACAE
B276B9BDBDBDBFBFC0BFBCB6B3BB3F8CA7A8AAAAAFB4B8BBBBB86D6EA4A9B2B8BDBBBDBB
B8B1AF9E5194AEA9ACB4B3B0B9B7BEBDBDAC6AAE
B5B1A66EB3B8B9B4B1AEABB2B7B5B2ACAD5DA9A3ADA9A6A9A7A3A3A7AAA08A5FAEACAAA9
9EA6AAA4A6A7A6AAB071B1ADB4B1ADA5A29DA2A3AAACA64B9E9E8F97929E9C9EA4A2A9AD
B071B9BEBFC1C2BEAFB2B6B5B8B94DA4A7ABA9AAAFB2B5B4B7B66970A7AEB3B7BBBDBABA
B5B2AC8C4A9BAAAEAEAFB0B2BAB8BBBAB9AF74B1
AFAAA777B5B7B8ADA1A4A9B3B4B2ADA9A758ADAAACAEA4A2A59AA0A3A7AA8F5AAEA8A9A7
9299989599A8AAA7AF64AEAEACAEA4A5A6A5A6A3A1A5AF4D9D9B837F7C8A9194A3A0AAAA
AA72BDC1C0BDBDBBB9B3BBB7BCBA589A9A8E94A0A7B0B5B9B9AE4E6DABABACABADB7B5AE
AAA3A8944B99A1A6A6A697A5A0A1A9B1A8A37DB4
4D443027404338363320303B3E413D3E322C3A484C4848413B484E505546421D5C646667
6B67706C6A766E6B6F3D7277797B737373716C76787C793A7D77787166787E81818B8B87
8C568D8A9088879091859599A2B14B99A8988B979298A6ADB8B04E6D9D9C9EA2ABA8A9A4
A08B9A8E599F94949EA19691898B9AA4AEA376B0
6B4483908B88722C638A8B817E67305F828383777436696E62575E55283A444D66623928
5E776F6668672B3E60635749513758544A3C403A2A5C5858483029232B2F38362B273A45
49423A3633413D38342219262D312A2D3A45414445413D3942574B4C4C53534D494E5759
58525255362A3B414545555748474C4C5C4E3045
9E3DBCC8C9CABD2B81B4B7B7B89E288CB9B9B9AC974D919D8C8A8E804D565565838F8233
8DAE9D97A19C4375A9B1B0B3B855A18D645D565148B7B9B8B6B2695BA7B6B7BCAB4289B5
B4B4BAAE43BABFC4C58B83BAB2A8A48C52A1AAA5ABAAA456AFB4BCB9B34C6CA093909096
5F488891A3A1893B6E8D9998998F36618E99A29C
AF45BEC5C9CAB42485AFADB2B4A72692B7B3B4A5933A93B3B1B3A9A9553D3D4B6D7B7E42
88B2A597A3A03B83B7B7BABFBF63A6A690705F4B56B5B8B9BCB86874B0B4B9C0B84B94B4
AAAEB8BC68BDC1C2C8B36FA8A89DA3A760A7ABA5A29C8D52B7BBBBB7B86D74959C908790
5985AEB6B7B3AE419FB9B8B8B3AD3EA1A8ACB0B0
B255B8C1C0C6A82D8FA9A8ABA893218EB3B2AC97803F98B4ABACB0AE4F3717191E414533
849F7F7A939A497FA9AFB0BBBE639CABA983725F4EB3AEACB2B4657FAFB4B5B7AA3A96B1
ACB2B7B560BABDBDC6AF71A6A1A7A5976299A59D95848647B2B5B3AEB063648A827F7B75
4888B2B6B8B7B036A4B3B8B6B1A83798A5ADABA7
84337C857E82763D5C7F7A76877B2A5F6D715B535F4562788282868D463E2C3B3C415440
63644B55606947617C72708087489A977464436147938B7E7B885669808393A082378894
9FA0ABA45A9799B5B6A06CA8A7A4A79C5A969F9893857F4FAAAFAAA4A7544E89887C796D
4E92B8C4BCB9B32BA0B6BBBAB9B139A4A6A8B0AE
887B7872415B70797E6F6D70796A685855583E47686F685E5C4B555B5A595E503C49636A
6B625C5C5F5F625F585E463A5157555C5C5B5D62605F69624E555B5B564D464C46526262
66614D4A423B444C483E4B564A4F515B536664615A645B537C736D6A664C405F665C5D59
4C6A7885837678416F7B817577713F787C79837E
B4B0A79F4294ABABACA5B2B4B5B0AAA4959D6A7EB4ABA6A0ADADACACA8AAAEB0738BB1B1
B1ABAEA6A6A9A6ACA9AB7870B9BDBCB5B8B7B5B1B4B3B9B569AEB6B6B7B3A6AAB0BEB9B6
C2C45252A8A9B4B4B1AAA59E8B7B41A5AFA182938C969B9E9F99896256959A8E9AA2A081
98A197969552809C90846F51556E896A63614F4F
B4AEABA73897A7A5A29BA6ACA8A5A5A3A29C6881AFB1A789A5A2A4A79CA1ADB27D8EB6B4
B2B6B0A7A6A7A7ABA7A18C91B2B1B0AEB3B5B4B2B1B6B7B657A6B4B0B1B0A1A2A7BFC0C0
BDAE447AA9AFB6B8ADA8A6A3A38145B8B8BCB9B9B7B6AB94A9B3B59175B1B2ADB4BBBEBA
BCBBB7ACB46FA8B2A99C9FB5B8B3B4ADB1B87A6D
A8A3A69F379AA3A3A29E9FA5A8A9A39DA3A06E86B0B8B397A69DA0A9A3A5B4B48C84B9B6
B4B3AFA6A5AAAAAAA8AD766FAAAEB1ADB0ADB0AFB1B0B5B761A4ABAEAAADA5A5A6B4BBBF
BEA0397FAAADACAEAAA2A5A3948449B7BBC3BEC2BDBAA593AFBCBB9380B2B4B5B9B9B9B4
BCBBB8B0B267A6B3AA9094B6BAB9B7B5B9BB7C76
B1B3B0B257A2A2A3A2929A99A8ACA7A1A3A06280A9AFB09BADA1A6A9A29CA2AF7F7EAFB1
B6B4B3ACA5ADABACA89F595BA2AAAAA8A7A8A5A9AAAEB3B66EA3A3A6A7A8A9ADAAB4B9BA
BBAF4D76A8A7ADABADA9A58F88835DB1B6B8B6BCB7BCA8A8B8C1BD9783B2B3B8B9BAB9B3
B5B9B3ADB05DA3B3A98275A3AFB2ADB4B4B78A80
6557484831404B51524A3E294B635B4D473F3E4B556A605444383839313845403B4A595A
656757423C53514D413F362B5451523E4339354941524D4D37626761636D6D716A70666B
68532C4866615B665D584C5D656139606B73717B757C6F7780858369557A7C8380817D81
7A827E78794A7B7962535461717A7A828D886562
B18A799AA2A9AC9E928D8126A6A7A1A09B9A9A979E9E8B8F9254919CA1AEB1B3B4B4B6AF
AFA98959A6A1A7A8A1A39F959AA2A8AA633A8E989EA6A9A9A09094A3ADA778669DA6A4AF
B1AFAEA69AACB6B268709B9D97969D9E9D9998989B85436B787A7473767467585C523762
6A6969666C6F575E6C6B735F4A6C6B6967696864
B4A29093A4A8B1958BA29C2C9BA2938D8C86808B89856990973E848C8D9EA09DA6A7A8A7
A3A0936DA2A0A0A3A1A09B8B989FA4AA7451A5A1A5A9AAA6A398A0A5AEB06F79A8A9ABB5
B2AFB9B9B6B4B6B86F7BB7B7B1ACB9B9B3AEB7BCC0B23D7DA7B3AFA49C9A8CA1B0BB6895
B9B1B2B0B3A581A2ADAAB08582B9C0BEC1B8B9B8
ABA5948DA0A6A78E899F932C9E9F98888479848A868F7E939137829286919FA0A1A6A9A4
A0A07F6B919D979C9F9B9C9496A0A3A57156A4A6A4A5A5A7A39A9EA5A8A56A60A1A4ACB3
B4AEB5BBB7B5B6B66C83B8B4A8A9B6B7B3AAB7BCBCBA4893B7B3AC9B99A6ABACAFB86A97
B5B4B1B3B2ADA2AAABA7AF787CB6BBC4BDADB7B5
A5A1A39DA09E9C8F8F857D399EA0A6A49B84888189909B96983E8083839296908D91A1A3
A09E71576783918D9C999C8692A0A19F85669DA8A7A3A1A39B8F8C93939175618B95A0A7
A3A1AAB1B0B4B7B57295B7B29AA9B4B2AEA8B6B9B9B8419BBAB9AE9BA7AEAEAEAFB9689A
B1B1B1B4AFA6A8A5ABA8AE7D82B9BBC1BAABB0B4
7366675C4046423A392627294553525342483D494F5C4C43343E53494E5D66534A474F59
50614D49455045474B5E574F56565A554A46716B6E6A6866646D63606A64564F4E5B7073
75736965716F706E3B63807B7581847D837A7C777C76357285847D5C747E848C90925F75
878A857E78707E8088818265619AA2A09D7B9197
AFA4A5974C809299978B9295A1A3A8A7A9954D57A39980A0A29F9B989A9EA0A77968999A
8B8492868E94959098915D769CA8A594919093908B8BA0A45F7488877F838D868D8A8983
867946858081888C897464635F5C2B628A8F8C918E8C8C837F827F753A667B7B75737772
70696C66673740565A4F575A5A5D5D5E625D5F3B
B6B1ACAA4C88A9AFAFB1B2B6B4B4A6A3AC9957589C978999908A838B939BA1A6826EACA6
A0A39B9F9F9BA1A49A8C5A7FB8B9B8A1AFAFADA6A7A5A8AB74A7B0AFB0B0B4B8B6B9BABE
BEB45EBAAFAAB2B3B9B4B1A69AA0308AB0ACA9B0B5B5ADACB1B6BCA537A6B3B1B2B5B6AC
ADAEB2AEAA6479B6B7B7BAB4A8A4B0AEB2B1B162
B3AEACA93B87AEAFAAADAEB7B7B7A4A1A6A56854A5A197978C837B7C8F9EA09F8271A7A7
A79B899CA195A2A594834C7CB4B4B49DB5AFAAA9A7AEADAB7198ACB1AEB0B7B8B9BCC1C4
BFA862B7B0ABABADB6B2ABA39F913076ADACAEAFB3B2B4AFB5BBBB9E35A6A8ADA8ADA5A8
ACB0B0A8AB6F76B0AEB0B5AB999FABB2B1B4B16A
B0AAA8AA5175A6A8A2A1A6ABB0A7A2A09AA16752A29A9798877D7D7A7B848A947976A4A8
A69B97A4A9A0A0A397885184AEAEAC9FAFACACA2A1ABA6A56389AFAFABACA89FBCBDC3C2
C19C5DB5B3B2A39FAAABA9A4877C3D68A7AAACAFB4B2B6B6B3B0AFAC3FADADAAB2B3ADB0
AEB7BBB8B97C77ADB0B3B4AFABA7AAB4B7BAB267
75716963345C6E676A6A6B61696763544E4C30346D757070645A595B535A61683C4E7670
6F646166705F5E61544C32517375726F707A756A5F5F564F314755656E67675E79838A86
834A3F88828C7F878280877A676E44618F9997A19E908295909A938036819D909494979C
A0A4A8ABAC806495A4AAA6AAA59DA1A2A4AAA964
9798959095908484949CA058688F8D8182899093908983847F54395E60646B6960606C6A
6E6D6A465F666C666E737E767A766B7162466F6F696A676B74776C7678764B3965706B65
6B6F776C6E716F67546C6D6A72787874706C68625F3924313C3D4A475152574B4F473F3A
5F6162605E6463585F5C56503543615D625B605B
BEB9B5B6B8B2B1ADAEB0B4617BA9A49E969E9EA6A2A1A4A7A363518C8994979AAAAAADA9
AAA9B16286AEB7B8AEACADAEAEACB0ACA469AAA39893909FA5A4A5A9A6A67260AAB0B3B3
B1B8B7B9B6B9B3AB83A7B1B7B6B3B4AEAEB7B9B7B870667F80A0A291775A7A8485835F4D
A5ACAEB4B9B6AAB7B9BFBBB94392AAA9B2B7B5B1
BEBAB0B0B6AFAFACAFADB16D85ACA19B959B999DA0A3A5A69A60508D928F9995A2A3AAA8
A39FA56C83ACADB0A2A0ABADACA9A8A99D56A7A398868EA4A69BA3A8AAA76E69ABAFB4AF
AEB0B3B5BBBDB8A486A0AEB4B1AFAFA6ACAFB5B8B36794AA90A19699865696A7AAAC775C
ACA5A7ACB2AE8F9EB8BBB6B95C93ADB0B1B5B1AD
B3B0ACA8A9ACABACADAEAD7884A29472707F97A093A1A39F90554E7F818D91868A899DA0
9B9DA2657F91A4ACA29698A5A4A7A6A5985EA092938885A0A3A2A5A6ABAB7682A6A9ACA6
A8A2AFAFB5B5B1A58799B2AFAEAEA9A0A7A8ACB0A8608B9E8F9D8B8D8E59949DA7AA7A59
AA9DABA8AFA89BB1B9BAB8B96F9BA8AFAFAEAEAB
8677727570706D676B686A38607D827A4B5D5E6F756D7181783E5672727573675A4F6276
71716B466D778980715E546F797673777A4D6D6A746E656A5F5F6B6E6F645469676A7A7D
738A8A898F827F8472668C8D8F9394949C90909686598582807F6F796B4B7F9191A06B66
7B7C9D9C9C927CA8A4958771566598ABA5A3AAB1
7E6F634630717375798289898478707B77552E5D67655F58585657544F5050331E546D65
65616263645C64605D48325D625F6561605E5B605E565033283D4642445A5F5C5C5F6161
593A47636A665F72706D7573757A71344F5E5C4A5A57575355463A221D27263A46585D62
666D6C615037254A3F413E4048526873757F7663
A48773743EA8A9AFAAABA6ADA8AA9FA7A17F59ADABA8AAA7ABA4988F9EA3A16C3DAEABA9
A39FA3A0A2A6A2928D7E3C88A1ABAFB4B5B5B3B7B2A6AE6145737B797993988F81929288
8A5A95B0B3B5B4B0B6B6B9B5B0AEAE318FAFB3C1B6BEB7B8BEC1BAAB304386ABAFB4BBBC
BBB4B0B1A99D74B2B2A4A4B6B7B8BCC0C5D2D076
AE95687357B0AEACAAA5A6A4A9857D999A905CABAEAEAAAAABA2A1969CA19E783DAAADA8
A19E9C9DA2A1A2A2A07E3F9DA4A9ABADA9AFAEB0ACA7AD7157756E6E6A776E6963768984
845587B2B5B39F96AFB3B3AFB0AEA83694A9A8B1AFB7B8B5B8B8BAB54676ADA39099ABB1
B2B3AEADAAA972B7B4B1B0B6B2B4BBB7BBC2C071
AC9A735B67B5B5AAADB0B3B0AB6A7CAEAA8F61ACACACAAA8AC999999998F916C3FB0B0A4
A8A0A8A7ABA7A0A3A07E2F9D979CA5AAA7A9ACAFAAA9AE714365666A6B6A68584F5E7575
734883AFB1AEA39C9DB3B4ACAFB3AF3792AAACACB2B6BCB9C0BBC0B6527DABA599A5ACB4
B1B2B0AEACAA6DB1B1AFADB2B3B3B6B5B8B8B874
91886C4E4F8B8573778275777F5C678186654C8175777E868883856872616248408B9190
8B847D79728874716C5E2F7D7B71818388867D787271704D31302D3637443E40404C4554
4E487E918F9585877E8D8A8B8C938538588286897E7D81807F71717739609AA6A4A3A8AE
ADA9A3AC9E7B639196949093999B9DA4A9A59854
41425E666D665D36495950555951243757516062614640374753544F2B233846504D3121
38454C515744313E63696A5B5E261D4D52514E522C3E4E5A625C51293E585058623F2753
6768615F5F365C66575C5E5426496262655E4745626462535E39555D5946483729313A30
38362A2B374139413A242F3D424E4941334D4C48
7A5BA4A5AAB1B75E7B918898A1972A4D9499939CA94F63969A948D7C3B3B61735778923D
7BA3A0A3AE8D40698F9B9E9192396AACA388859E4A6EABA2A69DA2498EAFB1B5BDA72690
B1B4B6B8BE3AA3C1B9B1AE9F2F82889298907578AFAEACAFB75D96A0A5AAA974269AC5C1
BCAF5B3FA8A8A7A3984C688EAEAEB6A041B0B8B8
8B6EA0A5A8B5BB635AA38F9FA8B049538E95908D985A619B9A8E7D733A395D7E6477864C
78959995A8904C6F9BA8A09A9C4E72AFAAA09E9B4B6EAAA8A69B9D4996B8B6B9BEB6539E
B1ACB0BABB3DA9BFBCB5B299327D8D8F9181626AAEB3B7C1C055869FA2A5A07238B5B6B7
B5B76475AFA7A9ADA7477A99A2A6AFB24FB3B8B8
8F77AAA6B1BEBF5A73A88EA7B4AD44699C908D8EA152668F7F6F6D61343951595B61753E
7B9BA1A7A897477A9F97948793527AADA89C929D4A72A2A5A4A7973F98B8B7B7B8B24D99
A9A7AAB3B93BA8BDBAB8B9A43780887F7B866872B2B8B9C0BB589EA9A7A6A16B4BB5B2AF
B4B37076B0AAAAB1AD3C7C96A5A59B6649B2BAB7
8D629CA0A0A59C4F448698AEB1A1345CA192908D99472C888A757C7D4E597775655C804B
859AABB2A9A04360A79F9082885470999D92867743749D8782989B669BB2B2B5AB8D4299
A3AAB1B8B84CA3B5B0A8A490324B5E6C83835C568C979698A291ADB2B1ABA67264B6B4B4
B9BB7283B0ABACB0AE467BAEA8A0927D52B2B3B4
6958503F323435333B494F4E53504B55563F39484D514B50535A51463A323E242A4C443A
4B4E696B6F62535F582D535A4548476872785058574A38244C595E585B6667675A53494B
472F4B5A62596D716866645A595441374B574245565A50586E7F796E425765616683847E
7C7C585E5C5257625D4B5D625D5654423B4D5356
AAA79D6E378B9CA0A7A7A7ACAEAEAAACA87663908C9C83849A9D958D788B8D6162A1A6A7
A5A2A6ABAEB1B1B1B24C93A89F9F99ABAEACA6A2AAA0A43CA6AAAFA8A5A5ACABAEB0B1B2
B2429FA8B2AFB1B8B1B2ACA5A8AC9C85B4B8AAA5B1AEB6B3BCBAB1AE56ABB3B9B7BABBBA
B8B1A7A4AE70648D97A2ACB0AEAEB2B1B3B7AE61
ABA4AA6661A89E8A98A09D9EA1A49FA4A38868999AA28C898F9A8F8E8D97916884A4A9A5
A19E9C9D9FA3A6AAB26899A99E978DA6AAA7A999A6A1A45FA0A4A6A4909AA4A2A5A6AAAD
AD3FA4A8AEB2B1ADA49FAAADB2B1A086B8B8ADABBAB5BCB7C1BFB9B35EAEB4B6BEBDC0C0
BEB2A6A7B57678A8ABA8ABADA7A9A7A7AAABAD66
AFA9AC5D47A59F8D91A2A6A7A4A09EA7A48C65A1A2A59F9A8C8C998278878D6984A39BA1
9E9986899B9F9BA6AC6A9CA8A3A391A2A1A5ABA2A5A39D5DA29D9A9A949A978DA0A4A6A8
AD4EA4A2A4ADACAEA5A2AFB0ADADA084B8BCB2AEB6B6BEBBC2BDBCB76FB2B2BBC2BCBEBD
BBABA1A9B36871A0A6AAA9A69E9DA0A1A8A3A877
B8B8B672419DA3A0A39D9FA5A8AEACA7A1846393A1A6A4A19F9D9A89757B996584A29C9F
9DA18C847E888AA29545969884989BAAA8A7A69D9F9E9A4781857C7C798486939A9FA7A8
AA4E9F9FA6ACAAA59A95989EA19C7E78B0B2A4A1B4B9BBB7B9BDB9B571A0A3B3B7B8B8B3
B2A397A3AF5B64ABA5A5A6A39C9F9F999EA6A083
666964543F505E5B675E44414A4B4B2C2B2E2F33414B5A4F3D343A39595062445B69675B
4D40373C494F515135283C403E3D404D39313E3F40423C34303B30362F2E24323B53484F
492E484D55594C51324446595B5F6C6660645B463F34324D4A5250534A49525D585B5566
5F61586A6B4A334C4B4342414E574F5F534E4839
A8A3A3A1A0A3A59E9C955662B0ABA2AAA5A7A8A9B0B3B3B05255909495A0A6AFB0A29D9A
A69D5C48A8A3A0A8AAA4A4A1A4ACAFB17D2C808993959D9698939B95A4953D5F656C6D76
8593999289859B644CB2B5B3ABB3BBBDBDC2B6977C5A82CBC3BDB7B5B7B3B2B6B69870B6
BABAB1B0B5B8B3AEB0AF843CA59EA2B2B5B3AEAE
A69D9A908C8C9D968E8F5D6BADAEA2A3A1A2A2A7A9B3B4AF7F67977B799CA09F99998C8F
8A88613696A0999DA19D9E88A3AAAEAE8145A7A3A6A4A6A6A8A6A78BA2A95A657276837B
717C85847B817A613F9EAEAEA3ADB1B2B4B6B4B4B56D92BBB8B8B4B1B1ADB1B0A96F6FB7
B6B5B4B7B5B7B4AFADAE9D52A2A3A6B3B1AEADB2
A8A3A092928294958B846166ABACA29D9D9AA4A0A6AAB1AB80689381868A8DACA9AEABAC
A7986A2D9AA7A4AAA6A39F90A4ADB3AE8848A9B4B4AAA3A7A4A6A07EA0AB5D667F8B897F
7D7D7F878588796842827C696D9FAAAEABAFAFADAD5F92B3B1B2AAABAAA9A5A4A5597ECA
C4BDB4B6B4B6B8B3B3B3A85E9EA1A7ADAFA8ACAE
A5A3999B8F8D91888F936A5CAAA7A3A49D9A9FA0A9AAAEA56A718C8A7881839EA7ABADA9
A9A26A3298AEADB1ACACA5A1A9ACB0A79840A5A2A7A7A19299A2A08A8DA56A779F9F987A
6E767C8F9285867369A09E9E6C808AA1A39B9D938B3E809F999896A19CA09B99996072BC
BCBCB5AFA9A1A8B0A09E9A559C9EA5AAADA5A3A8
655847393B424848493F262C607178746947494D494F4A3E2C3C434B4343464C524E5361
5E3E242B49545C4F4F4246474348442F39374D504C3F41313033414242434040464C493F
3038343B37393F323B3F354047432D21383B413D3B39404B433F443C233336353C443D44
48494833321C2E3C3736444A5459635D4E4E465B
B2A8A35A7C92747D9794A4AA8FACAAA7A5396888A2ADAFAEACAAA2A1A2A0A9587AA6A8AB
A3A7A0A5AAA1A8AF9E4670818D9A9BA09CA1A1A19A9A97499FADAFB4C0B7B0ADB0AEB3B4
9569A4AEABAEB7BABBB7B6B4B0B34761B9BCBAAFB4BBBDBABDBCBAA73DBBB7BABABAB6B4
B1B1B2ADA568A2B4B0B4B1B0B0AAA4A6A4AA71A0
AAA7A56478945C7A897B9295659E9E9E9D2D657A809D9A96989791949297A86688AAAAA6
A5A49CA1A09EA6AAAB5A7999989FA3A5A09A908E8D8F8A3FA3B2B8B5BBB4B0AFACAEABB0
97699DA3ACB3AFB3B8B6B2ABACAE4D82BDC5BFB4B7C0BFC4C5C6BEAD45B4B1B4B3B4A7A6
A6AEAFAFA960ADB5ADB0B1B0B6ACA8B0B1B279AC
A19D9F5D738A5489917F9381669A98989F375E79799E9C97918188909292945273A1A3A1
A1A093969293A0A4A14A69999AA19D8E8A8985848E8C89419BADADAEB4B0A9A7A4A3A5A9
A3659296A0A8A1ACAEACA8A4A7AA4C8DBFC2BFBBBABEC3C9C5BDBBB24AB3B1B5B6B1A79F
99989FA9A356ADB2ADACAEAFB1ADADB4B6AF76A9
A19C9B65718F6F9F9B9AA4807DA1A09D93435E838C9CA39F9A91908E8D938234759E9E9D
97A0988D88939799994F6388959A998F837F7E80858877428A9EA49DA4A69F9794919D9A
975B9786899D99999E9996979E9A3980A7A4B0AEAFACA3B4A6A7AF99518C8D99AAA79286
87888494985BA3A3A4A4A99A9F96A3A4A09A5D95
594B4A393B4B3F44484F4E3B4A5047443A1B243C3C383842382D3A4C4F533C1F465E595F
55554E4A4746504D4821374B5253524D51454843423A37202C2F2E263D4238372F293033
29264E413C3B3A41463630312D231F1E24252A2C26283A4041494C4D423E3A2327281220
27261F26261619201B221A0D162731312F292222
938887817D797474797D8430486B7A757B80767E7E7C726E68247C8A868F9DA69A989B95
888D832F5D7D8983797774646A6E6B6C75336F7067747880848A8E969690746E988C949D
999C9797A8A9AB65839A938E8E939A999FA29FA17A68989EB0B5A8AE9D9BA09A89A4548A
5E7C97A29C737B7D8BA2A06081A1A4A5A7A79C86
AFA1A1A19DA5A6A3A29BA13C8A97A0A49D968D9FA4A3938D822D8A9B989D9CA4A4A3A499
8C8B894B9B939DA1A6A39A9383867680963489898A87979D92908FA1A29277538A8D9399
9B9FA0A0A9AAAA4D9BA69EA09EA8AAA5AAACABA3825AA3A2ABAB92A3828E968F869A5A84
47909A9F99706D687093A66C7B939EA0A4A7A3A6
B1A4A19E96919CA19483853A69838F9A908883909E928577772E818F908F7E797F8B9E7E
6D76703D8E9FA2A5A4A1968B72837D8F9D309A9C9E9195938388819AA1946F5F96919C9D
90948F9EA7ADAB64A0A5A7A7A7A6A9A5A7A9A6A48D609FA3AF96AC9D82949A99929C3F4C
51868688895B68537499A15B7C81979CA5A09FA3
ABA5A59F9A919B9D8D848941788C858B8A878883978A6A61712F86939988797A7987A48B
6965563081899497938C8979768093968C4093978E838987899A8F938F8F69526562686E
6F7471798D95784F7E9795A1A5A5A7A397A6999B85689696B0B5AA959C8B979A979E3950
6492898B63485A507983833E6997A299919EA1A0
70676B6862636466535861364656545452534D474C4E373A401E515B646164625D636460
4F45372C56595A5F5B4A445146484B4B431C625E645E58525966525F5D45382F44433A32
3542505353552A251E49565848494B3D4054483B21252D162530293521202625291F0C11
1E25251B1C18191D27272D24262A322424404144
6755433918315C404F534D5C655E5D5D5A56494E7B726A67686D6B6E786D736C40606961
5F595E606061625B645E426566634B4D616E5E56595E653B426C7B787B7872757163676B
6A294A6675717E8886848A797882722B7B8594888EA69EA2A0A29F9C3E7A858F97979AA2
A39F9F98936774928E8681616A8A948D8D958B64
AFB1B4AA3E5D9353557F858F888C85847E775585BCBCBBB5B6B6B4B0B3B0B2AF5C7D8679
7169676561646B6C777D5C9A9497A3A9A8AAA4A1A2A4A9746AA5A8ABAAA3A5A4A3A4A39F
A03773A0A3A6A7A6A4A2A58F939A7F5395A29B98A0A2A7A6A5A7A99A369CA0A8AFA8A2A5
A6A59C96985C809E9A88909899878A8C8DA08B75
B3B0AFA8415988495479777F7A7C80777C734F88B6B8B3ABADA9A0A3A59AA7A562768785
637368615B53566162685595A19DA1A5A6AEA69BA0A0A5666AA7A7ACA4A1A4A2A1A2A4A2
9C3C718FA3A4A499A0A3A07E94996D52989A9B9FA5A0A3909FAAA1702593A0AAB0ADAEAB
A19E9E988B5476959A9F8B889F8A7A8EA4AA8C71
ADA8A49240487E4557827A7B7E707A797A78467EB0AA9E9E9FA09A8C90839392686F8683
6B7278858C9192867573588F96939D9EA1A2988E898B965A6AA3A1A199989D9990A3A5A2
9F35547D99A297949CA39D677A706663A3A1A2A5A6A0977780907C713E929EABA9A6A8A4
9F9E979E843F758B8B95847C91777A9F9FA8836B
806A48553D556B4D625D667767596C6F6554375697949089817675736A6450443326554F
4A514F655A5A6756514F25505A56686C606670675A525E414D7871646862665751636D6C
662F3D575C6D726F7272664B513928405659555E5E5F5A5E5B67574D2146556058575F5E
5B54544A3E2A43504553575354484448484C3238
603028545B51443E1C2253534B49361C0A515C6D686A42213B484C515B44295B5B5E5E61
4826576A71737A3F255A5A5F635C283765718177722B2B45454F53202A656C5D625F4049
686864613F1E4663626B732A477885887B662B6A818789884A426B848E8B5A0733544438
625319647B888A7D4A366D6D707C7E3E64828E94
BC6954AA94878990384997A4B0B3A3502AB2B3B8BBBC7D1A96A59B9A9A7834868475817B
5344838D948C905735A29B96A0A25561A5A6A9A9913E7C8B888C7E7951A2A2A9AB886374
A09687989E429D9B95A09E5679A0A6A7A698398CA8AAA5A45773AEB4B3B485157BA6A2A5
AB921E8B8F919CA4583597A0ADB4B44690AAB2B8
BB624DA3A6A0937F3149A49F9EABA85629AEB9BCB7B9741FA2A5908D8F722D889098907B
4733779199919A542C9DA29C9C9F5368A5A9A8A09443787B90946D4C56929AA6AEAA5877
9583848C824DA1A08E86965A7EACAAA99A9044A0B0B3B1AE6879ADB6B8B6890F6FA1A7AA
ADA61D81959DA09B4C41A7A9ABACA5438BABADB4
B76755A4A5A39D823C4C9F9E9AA4A45828ADB8B2AFB475229EA29C98946D378D99858B90
5F3D8EA4AAA4A47746A1A2A2919D5E67A7AEAFA2933B8E9F9186623A41767F8A93885179
8C7F838A8D478F9F988B9A6071A8A8A79C933AADB8B4B3B25C8BB7B9B6AA864481A5ABB1
B09F228A95A0A3A75F5CABA4917D7C378BA6AAAB
8952599B8A9A9B8C4724478A8E8B85491C4376969B625C2187878781783B274A59667685
5347788C92939049296E7A7B798C52516F7C797B6D2E75856853444833686D6369662F4C
6166636B6216004053596C44223D6E6C695A30555855484425555B66655E32155A747777
6C61284B5D69696F401C67695D4B4A3362696460
5F5A4E201325223D3F3F2C232C313A424916081521232A2D3233313C3D4040220A424942
392B3D454C4D4F56573D172E3D3A404A564D40363B51522D2144424C4143484E4E526263
5E223C556675838684787283868D6A37655164686C6E67556B7E81622C507E8886737276
726479796A414D6A6E818580735949698C883A51
A49DA0544A706A9AA1A0826D818BABAFA6400C9AA8A7A8A2A59F90889B989C6316A8A59E
947F92AEAEB0ADAFB49B21989F938A8391928E7482A3AB804DAA9B98808693959D9EA7A7
A33F5D85839595939698939E9FA2A26D9E8789A2A0A3928F8FAEB4B047ABA8A2A7A6A4A7
A2A29C96A3688AA19A919FA1997B52849EA93C68
9D94985260907494909486697E8FA6A6AA4B36A2A6A7AAAAA69F90819393966318A0A39C
967D85A6A6ACAFAFB1A1289998998A7789908F85849AA47E47A6A5897B78828E989AA6A8
A54767808B8C878489878590948C9771ADA0929C969D9C9195A5AAAF4C94A0AAAAA79EA3
A49F9DA1A34F8A9E9283969B98835184A0A44673
A9A39E5A5C9F799C9D9B98749897A5ACA85731A3ADAFAEABA7A2937D8D8D8E75189C999C
A1867CA2ABAEAFB0ACA1379B9DA29F85969A9C87849D987D5096A58B7E7C8A9A9CA3A5A8
A44958788E98857C7875828889948D6EA8A48B9F9FA4978D9AA9ABAB419AA7ACAEAFADAA
ABA999959453919B9D9D9C9CA3835C89A1A35580
9E93862D5198768E90969466817C91909C4E148B928B8987807D76685B645A480E6D7178
75745F817D7D74736D582A60707D646174726E625560653A3D737778706B606768605861
613A3B4F5672725E665C4D4437254D1B565B4F635F66544A5E5D6369225F706D70586970
686954383D4C505A6163605E5B463A4150492C34
3D33312D34383E383C200F12131310182535322A2D35313311312E2925221B22231F2327
241D13292D2231312B313F3F342A301D1D352821252F36393E33242619111E2D2F3F473E
392D3A36493D2D234F4D4F505D66665D473B4A4924475B5D5E58615A605B585457264560
6D7077788880746A6B8055306474788394999E9B
9499A7A7ABAAAFABA55B10777D7D7B8A91898B939C9AA1992F9D9495867C7F8794878F95
94752B989AA5A7A487A2A6A9AA9EA57266A6A6A49CA3A2A7A4A3A4A99147729A9B9B939C
96889693A1AC9759ADAAA3A8ADACB1AFA7AEADA75298B0A7A5A3A7A2A38D7C83A95580AF
AFADA698A69DA1A086A7764D998A9AA5AFB3B5B2
A085909C9CA1A5A59D8B2283909D9686877F8490929C9A983C92A6A3A188808B9494958E
9D8B356C727C76898A9A97A4A0A2A37F4E81887E84838B94908E9091925B5F8B8F9C9390
87848F979AA89068ABADA7A8AAABA8ACADB5B0A85BAAAEA49BA2AAABAC9B99A3A96087AD
ADADA79DA4A29EA093A8735F958894959AA5AEB1
A0878A95939E99968B7C3586959E9E8C8E7C6D8E9CA49E874298A3AAAA9889A1A3A4A6A2
A68536999FA69D80919884898C9BA2834D838784797C7F868E858D807E4F6E929098A69F
8B8F9C9D98A38C58B1B3ADB0ADACAEB2B4B7B5AD489EB0AAADAFB5AEB5ACA1A9AC5985AE
ACACA7A2A8A8A8A7A1B68568887B888186A1A8A8
A2929A9E8A8D91897B762780989DA69C9D998D80949A8365479EA2A6AB9F979DA0A49E96
927B308A999DA2837B7F6D6C6D8981554572777B796969736C6E7C76804C5E798285888D
8D7B8B8585815A2986938E8F83818285878A867F2D68827F8E898A70767E736E69314970
716F6B6555555A56534423293C373C4456625F5B
2C251A1E1211130B0D090A161A181F201D1D19131519141E382F29262525211B1A272824
1E1E171C10151A200F1D241621242D30343324231F1A132B343339352E384045413D3A22
20263339464B474D4436342F311F283326372E3C46474D4A4D4F23375C625E61636A6D67
68676E623A6D737A7F7A74716B70747A7D27668D
9B958A53AFA78484919D9DA3ADA8B5B2763C90A1A6ACA4A29E9689868B9D395C969DA997
908F8888879C9F9A2A82938C909098A09FA0A29E9E6F3AA7A5A7A19597A1A2A5A6A5A14E
6B989894A2A7ACAEAEAAA37B9144A0BBBEBCBAB9B9BFC4C3C5C74F7AB3B8B2AFB0ACACA5
8E9298844D88888B928F898B889397A09D3BA0B4
ABA7A94CAAAA9F9899A1A5A5A7ADACAE913E8D99989A9191928F93848098496F9EA6A694
8887847E83979A9124717579818E9A8E9593A4A8A6653CA4A29E9EA19A9594958E94A15C
638E9298878D9E97918D898B7F43B0BDBAB7B3BAB3B4BBBABFC16382ACACA1A3A19C9A99
7470776D4980808782847F7D7F7B859398379CA9
A69FA94DA7A7A5A2989F9E9798A7AFAC8D3F8C9BA5A7A49DA1A79F868E954666A3A8A498
8F877B787284999132747C8D8B8AA1A19F989BA39B2340A7A8A2A39D9395939E9E9EA663
567E8A99999EA49DA0A4948A9949B0C0B8B7B4B4ADA8A8ADBDCA6584A9A39C9898949291
7C7571675195989288847882807F899699298A96
ACA6984BABA79FA09897849081979B8F7940869CA8A9ACAEA9A59B9A9C8B256DA193A193
7574756E707F9994397F828A9488969B9B918D9D945542A4A9AAAAA39586799698989A68
4D788BA1A5A6949D97908B7C98539C9AACBEB0A498A095918D9E4D727E767E7572777372
5D574938335C63655B494349534D5353461C5E6A
5D473826373C383A37332C1C2126242A22103F474146484B59463633391A060D13131B19
1C1D1E191E201D1F1D171B1F201A2023192723252020212B3E3F39342C2308172B323130
2C3A3840535137241F2629373E3B3A37444B4E4C351E3B3D42434D4644443D4749491C3B
605F616B6A6270817D7C66397F797B80848C7A6F
989496999A988D98A0A0932269898596938C7E7C80919AA19E3264858688A4A398A3A09C
9C987E36879C9A9BA09DA29FA0A2A3A535817E80776E7591969391838271327B8693989C
9A9594A1A0A7A4567CAAA5A4A6A4A5A3A89A73726F50B6AB9EA3B3B3AA9E8FA5AAA452A1
9B8B7C7484767C94999472359A9A989BA08A8479
B7B0AEAEB0AEA7A5A4AAAB368FA9A9A48A77869B868BA1A49F3992A093A6A6A2928D8497
A08E794188A19DA2999D99898C98A5A939667E7E796C71777D7D7D7C7B8043817F7A8586
83908A939AA0AC607FA8A28B8682848D9B967E786344ADA8A7A2A5ABA6A4A1A4A39B469D
8D85776E7A75728993A178318C8D898FA0867A83
B7AEB1ADB4AFAAA7AAB2992A8BA4A7A2827881817E8C98A4A0379B988F9D969D9690848C
978B7E3D91A1A19F959B95979092A3A53362737F8668677278808288867F487F766E7881
7C787F7C9293AB6C7BA6A29A91939093A28C83846855AAA8B0ACAFA9A8A7A0A29D8C249C
A5866F695E6966909B9E7D48A29FA6A6AFA6A0A3
B8B3B4AAA9AEA9AAA3A09F499FA0A197897C7D78919A9BA3973D9B9992A4A0A58C907687
85837545939C93919E9E99978F949E9D456A6D817B80667475716B7C76774B6160636B71
6A737B888F969A697F8676838C8891968B7D6A664B4B8F8C8F8A8C897D7F7A7A7B5E176A
74664E3C363E364C5C5C462E444D4F41475A6664
6157614C45383E403D34291551504F43474951493C4447453F1A40493F3A3336362A1F17
18160F122A3335343A34302C1D2F311C2A241D1E211B1B232F29222E2B2C2E3432322B28
24295458523E2E393C3B3C3A343319304950574E585D5D5D5E4E4F2E2A404049484D5352
4B4F484E2E66708A9896A29A938B979685418590
857B863D56998C8F7D848796A8A39EA9A9343C7F7C83838385868E868F97945353679BA1
A4A89CA5A8A9A48EAA3C6B9A837B878F91827E7682837B167EA39CA793A0A2A7879092AB
7F5BA786A3ADB2AEA7A59C95999B4091B6B4B1ACAFB5BCBEC5C2C57397B9B5B8BABBBDC2
C1C1BCB45496B2B3B1A8A6ABACABABAEA3579CA4
ABB2B04A6B9F9B9085858A97A29EA8A8B05F5B9781827F7B77737E8179869851626491A7
A6A1839A9DA4A48EAC43718E7B797A7D7E7E7C7E7E857F208BA0A1A3979DA6A4797A86AC
975E96969D9EA2A39A9F9B919A933FB2BDB8B8B8BCBEC1C1BBC0BE6986AAAFA6A198A2A8
B7AEAEA857A3A6A3A5A4A4A4A2A5A7AB984F8B9D
AAACAA4664989C968B888B878F8D989FA758477D8A8A847A7875868678788B58625A83A5
9F9B77969B9E9F7CA13E647E74746F6F7578787D7879762E8C8A9791969EA4A687838BA4
8F4C9B999FA29FA39F9F8E9392933EB0BEBDBDBDB9BAB9B7B3B1AC54799A917675899764
A792948F5694A19F9C99989898A2A2A484368B99
AEADA341579B9F9F9A99A29F957C8C95A54E2E717784827D8A8D8B8B86868F5A4D648C96
8E926B7582918B6A692C437B7A786D717B8081786D67623E868B868686929AA79B94898B
5317858F85838B8C8784838D7F7938879C928F938782918F8E8C79406D58493B45494145
48363F3731464C554B4D484B4E49413A22132337
666C6133326066615B5C5C5A605B645A62353143433B4437352C3730372D2B2322282F31
22151612152E271E1711152B2B31493E4346483232433B121B23303F3C2C32403B322C19
1E2F372A1425353B4142162132312D33371B2F494E4E4E364B50657B8A665171706F6B64
236E746A6863292B6069767E761C73737A8F874A
76507C7A767E823536737B7A8C8B28519C9BA8AC943E6F999C9C91772895AAADA8AE5C2B
8D948F8A8A4622435A5D73833D356A6571706F302E6A79776F642F6D82758194580C7A95
928C9E7535AAAFADA49E2776ADAFB3BDB62EA5BBB9BBB7569DB8B9B6B28471A9B5B6B4A8
35A9AFA8A7A7416CA9B1B1B4A11F8077616B6C40
9354ABB0ABB0B15D70B5B7B8BCBD3662AEB3B9B7B74783B5B3AFB0832099A1A7A6A86542
A4ABA9AEAC59365A676B6E6C35357575776963282E5E6A6E686522667A72718C5C0D7A9C
9C9A946256AFB1A4958D2675A9A8B3BBB12DB0BCB9BBB95499B7BABBB98571B0B1ACA8A2
3CA8AFAAA4A44283B4B0B0B39C22877A677C864D
9456A4ABAAA49F4F79B9BCB9BABA4B68A4B4B8B9B73F86AFB0ACAF9837ABB1B1B0AB6136
99AAADAFAE5531595E5B4B673F468C87807267282F575861636125748B847E925F0D93B5
AEA4A16763B1B2B1B1AD337FA9AFB4BAB534B7B7BFBFBA549BBDBAB6B58973A09D9C927F
36A6ACABA8A33F80AEAEB0ACA637AB8B8791874A
945AA4ABA7A7A25277AFB0B0B2B85364818C9FA09A3188ADAAA6AB863BA5A7ADAD9B5A58
A3ABABB0B05E706573546073596FA499877D6F2C2E434A4A3E411C8B99908D95551C96AA
ABA3976F539FA9A9A5A338687473A8B3B23685828881753276837F7F6D41516D69665C56
285A62625B46234351524943321E3F323531301B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
78668C7A9191A8888F6B458C5E8B6D57667A7A4D647256946997954C904D717172D7845F
4675ACCAA4B2A5A9A49B7D656B7CA6BF719B95A5CD8FB1BFAAC34C89638B837574A0A97A
7654ABC2ACA47851E1A07C756360A9B799518A938E8992C4774B423E7583575B777E7082
5C675F7B938D8E9A9BBC7B9CA66D465C5F8D8275
71547B77868EAF7A887653885B7964536C868C505A65518069948D488D58818678D08D68
4B77AAC0A6AEA0A5A0987B687176A2C277959FA9BF78B9B3A2C35582618F87726EB0B17A
8A6998BFB6A5755BDC9C6A76746EB8B9A3618A9D939094D47F4943386A745C585E61658F
6B695B829594A29C9CB191A4AF7A50665F74817A
7F6081708579875D74663D745D8860564D63985D565D487E739B8E4B955C77767ED18369
5371A1B39CA59AAD98998E7D8585B1CA71AB95A2BB7CBDAEA5CF5C805F7E7B686CA4A276
7E7187C6BEAC735FD1945D837977A2B9AD6A7FA18B8494D783444431648D65655D677076
53675E788E7F9696A5BDA2BEA96B4F7A6F6E7E72
6B567D707E75A469856143815E75515958727B5D49573D7A72998C4A8A5C787677C08B6B
4A7CA7ACABB89E9D91997D6E6A6F98BD71A08F9DB976B9A19ABF5D8267867D5F5CA2BB71
868581C3B5AE6976BC8C5E78766D95C8A963819368707FBD783B3E3058806D7079856B7E
5A5F4C6F7F77A8657E756A7F996E575A73827A7F
7767878194889D5F88764F8B62966475647C8367505F427E6B908B4B825F777177D09A68
477AB4BFBFB79C9D9798867C767098AC6C9995A8B47EC4ACA3C55A80637F7C6C6F9FBD93
88848DBCB2A76671BB8A5B85897AA0C6A1706C9461827DAE713634314E70736C89817997
6A755B786E79A27AA4A280A7B47B5C526B7B8976
80608A748F81B26B8D7955886591515D6484926E5D59547D6A9C9A4A8356716781CC7D5D
417CAEBCBCBA9A959AA2847C6F789AB8799E74BEB983B9ACA8C05682607D8C545D95C27E
807484C3BBC8797EC583578B867AA7C9B76F8A9A71968DB97D423C3C53797C6E8B8B8295
6969787B9795B287AC90889DAF7C505F64798368
866E8B6C7F7BAC5E706A43806A803E5E54778F6A6159477965949E4A885B8D7C7FD2845A
376494A69BAC9FA09DA6837571719AA66AA277B1C57FB7AB9FB54E755D74786F659DB27B
7F8599BDA9B37577BA92638C8175A2C79F53B6A96D8F92CA7F45373D4A737A7088907C97
69776B737F7A96729A89879FB18651676981667C
7F5C80677E8DC169936641855D8E4A5F686A837E5E5845676F9E99498360867580D48C64
4186C1CAAFB69A989F93777464749AB05E8E91A9C97FAEB09BB24B76607C7F5D6B92BF7C
838397C1B1C0777EB887608E6A759CC7A86380A063828BC27C443E42426E7C6F6C856F8D
656763797483BB86BF818BA5AE7E516970868E7D
8976986D827FB064736C4A8D6295505D788C936D544E5265739E9F50825F7C6F7CC67E5B
3E77B6C6B5B7A4989B8474747591AEC6779A99A8CA82B7BEA1B14E84678283636392BF86
7E7680AEC1B17A7BA9885D84717091BCB0738095667A8AC4814A3A3F3F697276868A708C
675C5F839891C57CBB7380928F6751526D959479
7B5E8053878CBA7782724F935F9C4D5A7B7E92755C4C47636F949C457F4D718183D6875F
426B97A8A3A28B9191808167698398A5789898AABF7AABB49EBF37716383856963A8C49A
79807FB0B6B590849B8B7A89787196CAAD647B975F5A77C57E4638393D5A4F5B5E7C6091
646965768069966DB773929D92774B4C657A8783
7D648F5F866F7A757265437F609A4C568E858E644B464A5F78999D4989596D736DBB7B54
3D6B9CACA3B09B9D978E8A6B707B99C2809B90A9C083A69C98BA39654E67655E6594AA8D
5C6F7EA7C2B4847D9A9E8D7B7B638DB6A4588F84755B70B5934C3A384F636C6A76726072
5D4E5C7C8886AB92CF6D878C7C67505D5F657070
82718F5276738E68716745785B8E49529682997060575D64718C9B3F854F67747ACB8B6B
467DB8BBADAA8B9796868562717A9BCB779987A6BB9BABB39EC341807189835D5BB7B589
5D6188ACD3AF87778C9BA370605A73B19D639BA0795876C3A9554939577B70796F746E70
7963776E7F9A9B90AB487895968166596A698B84
8472955F7D778A5266624774679048488B7A926855484B4F7D968C437B5162687DC6915D
3E72B8B6A4B39B90988D7B5466758BA6638789B4C1A0AAC0AEB03F725C64736D4E9BB8A8
745F8CB7C8B18C7291B19B6A6F6398C7A07894968D6773C6B05B463C4D776C7A5A685F67
8A6368738B98878CAC508EA0977E7C6C646B7B72
766A835884819261715B436B697D484890718A716349615E829A954C7F546B6387BB8758
3467A6A6A3ADA1969A8B6B536D7994BB648F88B3C7A69BB8B9C44F917B7479736C8BAF9F
7E588DAEDABC70659BBE996B7173A8C2AB79A8A69A6978B2B6523E4A4681736F67736562
796A5563727E8D9EA94A888D8477625A7567877A
647E8446887E9158705A4F73707A464D877881714F47474B7A8F915682506E5E8BCB9E4D
2D64A2A7AEB39592A1957970717B95AB559587BACAAD93B1B6BA468A8488828D6D8ECC8C
6F4D7F84DAAD735D9FC581696170A1A8A185A19E855B6AA3B2603E4C415F747F70695D77
5F67636E899088939D5299A4A18C7A5F5E686765
6A747746937D815D726D5C9072794541907978855949455C73949C557E48606193CBA55C
3B739DB5AEAE939BA6A47E5C7C7D97AD609480B7C8B296B2B5B749807B7B7E8B6D7AC58A
7A589596BAA07A658FC77A6E6D6F9DADA9858E8D7F7690A5AE5F3E5444606C76727A6677
726E5C75859E8C819B5486B29D8D8B6A757A6E68
7A8A894B7F7A7C547B716A877D7758465A6570794246525A658F92558F5D786089CDA765
4B7EAEB1BBB18F7F8C7F644F78849EB76EB07BB8D0B398AFD0C15E86877E78946D74D886
715494AECDB8898E97CA6471776795B5A28286A383618BA3A1654D454164736F6F787880
77605B626A9A867C904971909880745A7C78626A
7C8E87458185764C6C687276837E6D4D7371866A48413D616D927C427753735D88CBA16E
5185A0BAB4A68D989A7F70586F7C9AA561A080B6C4BD9BB1D5C15F8B8E797F997862D396
7A53819CBAB4807E95D86B847C74939ABE9488897B7391A697714F3C4F69616B6D7B7876
6F7A646A5C938492B25B8CA69F756C5A74687169
7FA386467F8B7456816B78797E7A644B88828E6F4B4E566D6E978D3F894B73538DCBA356
416AA6B0AEA1848593826A546C7291AC5C9885BFC9D0A1A5C3BB6584917874967D56E38B
77556C93C5AF948CA0D6666D736E809DC0908BA982607FA19B744A334B635B7D6686787D
6B71677778AD949DAE5E7EA0A2897057645C7266
7AA97D5077816E54735A6B6C776E57467B8594715B4B546B769682557D426E4986BE8060
3C74B6B7A7AE9983998D755F6F7AA0B564A087BBC7CC9697B9B97C7994757B95714FD08D
7A6A7F9BBCB58B8A89D95F757F7275A7BF8D759C755B699BA2724533395E64785B786C7F
64745E6D729B90A1AE5E97A8AC84746B626B7972
74A17643788C73618668787378694D457F8196736A5550606C9F956E90577E5187CD915B
3A67A6A897AB9B759589735969778BB9649E90BEC8C5888BBBB07771906F70926C5FD075
7E6F728CB5C4878A79D36C9C7B78759CC8956F877C5A63A6A765433836617D696A6B787F
6469597476939193A5559CAEAF8A705870686A5C
6B936C406C6C685471697A6B716A47437180976756564C5F6C9A8661935F825F7FC39B5D
4069959DB1C0A29BA088775A6C7A92C468A992B8C7CC898AB6AE7A798E767A975F60D27D
8872719EB0C5999276CA5897777374A6CA95699C775F78B1B5724A434167755B6368778E
786A52787398AE8FAC68829B99735E67696C806F
71A7774A7C856D58805C76737E63545E7376896D5C44475E74A08B558C567E668CC78A59
2B5EB8B7B2BA9B97A588795A747E9DC964AA96BFCDD48F8FC4B581938A7A7D9D666BCF82
8887719A9FB8927C69D969886A808FBBD6996AA87A6F7EA2B56D3E393F5D705A5B626E85
87594D6D7999A38EAF84829AAC7C654D59597356
6298643B6E78695D84597B6C7B604653758C8F7066584E6174998A59995481707ABF854A
5259A9B3BEB98A9E998B7558677C8FAF549484AEC7D99393C5AF868973726D92606ED790
8F946EB6A3C9AC8170DF6F927B787CA7D09E67A589767A97BC74414040608A5E4E5D6766
754F547E7995B695B08085A0AC85625A626B8471
62A9754C7A85765C887C97787064435F697F857358463C5D728F92809E5A7F8282D18763
7464B4B8C0B8A6889F8B7559708793C45E9785ABBBC98484BBBD82867C7B7D9B5768CBA8
899067B8ACC69A6C52D97F90879395BFDCA175B48D8A739ACA6C45433C5684535D686D5B
7F4455706E8AAA80B78D8898AE7D545C6A577A62
679D7244707B654D6B68796C735B3C5C7C877E6D5058567C6F988B7A944E706676B16C5D
5960A09B9B9696879189755A818097C761A085B7BFD38C91BEB784786F7B798C5C6EC39F
768F5EB5AABC996050D67387838690ACD3A26DB39C987894CF68403A384C7D546859695D
6E4F616A79A9AC9BC09791B1AF7E5F606954765A
6AA96C426D7565597F69808C8A5A395E63818D795E584979609FA483AA5D776E6EBE8D5B
5973BAC4B6AEB29CA48B745670839EC35EAC8DBAC0D69389B1B38D767077768C6373C099
6F8760BEACAEAF714BD67393757B719DCE8862BDA496798CC76C413737536F65686F6875
7951685C889BAB94B79F5B7C987B6B5E625B9160
6EA47146768373667F759284805B426D5B727A6D4C434D5E5082897D95566F7980D59064
5C70A8B5BBAFAA9B938777637A7581AF57A69AB8C2CA9185B6B3986F736E848A7475C5A3
627152BBAEC6B37A47E08190828C8BB4DD936BB8A993717DC4764839394062785F83777C
6A5E6A6380AAAB85B7BC748FA3845B6B6A678A77
5F967B4C7376735E7F768B65664E387169878B745A55407255928E7E9C6476757BCC8B60
516EA9B2B2A2A690917E6E596C7993BD5D8C8FB5BDC58C79ABA197786D7793847788B89F
577250C3BAB6A96A40D07A9E81776897C79073BEB7826E8ACA8F4F3E2E4471956880767D
765978607FAAA691BEB67096A69168765F748D79
678C7B467581745777697F787B434560537E816853504477609A8E879D7678767DCD9762
6272A3B9B8B3B09AA58C7E617E8390BC619587B6BCC28F92AFB89071727892817D91BCA6
627A59C2B3A9AC7C4BDB768F758482ADC67F679EB2746986CC955A4716378A8E5E7D7E8C
806264508EB3A29FA09F6486888A5B7B74819976
5D8B7A517785805E807C7971764F4D5955799061535A447B639EA7849570737673C47F5A
737395B8C1B69D798E807556727C9CB76D9481B2BDC3907DAFAF8E757081927E7B8EB794
59775AC6C29AAD8148DE88897B8389AED5977DACB8677C71B3995C4133246F69536C7385
7956684260949B8881B8738C9B895170697B9D84
65A3744A7D9E875E7C7D94827C5C4765677B704B5D4E426F5896A78C9E7673796ABD7956
605A7AA0A7A6957A8C7D7257787F9ABA73988BA2BAC59578B8BA9D7E647793848592BAA0
5C745EBEC7B7AB8444D7958C847B7EABD59084A1BE67745BC0994C433534686152587F73
725A67516A89969594AD69A098985759485D8A78
5E936B4876896F56817D94817B6258686889A5525055497A52979D94A373757C72CC845E
71697FA9ACB18A8192838153739699BF8E9E95A2C4C29C74A9AEAD797194A67E8886BDAB
636A78A2B0A4967642C986907E706E9DC58487ACAE6E825DA19C51434A51636C64475C56
73506C4C5F7BA18599AB648E7F9C59725D7D8E6F
649E6A446C9E8F759A8BA28E79535B67688F9D5F5D5A467D55A09587AC7776816FD39C64
796B9DC5C0C78F8C8E77785B86919FB29CA58E99D5B4A98EAEA38F7D7B94AA869891BFBB
79597CABC4AB9A6F3ECA858981706EA5C787819B8B744C569A894B33344B63616A4A685D
6C57664E59959C928B9A63A690A55B66677E8574
659172466C7E88859B808F826D5B4F694F758C595951436353968B83A3715F736DCA836A
865D88BDB7C1929B908181558081AB9A98938E81DAB5BA8FC2C29E7F737991819A8EB7B6
725694AABDBFA07943D68D8D7D6E6C9EB88C8B9E87936A5D9297543E3B5B5A59664C675C
84455D604578A08F859C6FA985AA555F74878D8D
69AE7C558AA593779C7E917F80513F5C5E7378545D4F417F629F8D90A36B65605DC58D66
7B5A73ADB5B1848E8A7E8B708F88B0A396909979DFA9AC85C1BE977773849681AE87AFBD
765891ACB9A37A6B3FCF978A89787EB8CD9596A485A4628DA29E4E37354F564A6B596253
8943505E4F768C998A887CB79992625C798A8473
549365447AA0A084958D7D7E6F57465C5E8084486559478276A28D95AD7A6F6A5DBC8575
7B618EB9C5BB899D908390787A77A799996C915ED8A5A696BBBD816C617B8575A06D99A0
72518CADBBA68F6B43D2967F806F72AEC39F9AB28FB574929E8C463533434C466E6A544F
83484A74567A928A8A8B88AA9D9E5E557C6A696B
66A079517FA39F806C7E66736D5F3A555E6D6A466B5944685A9393A0A37C6F6C5AB3897C
775A7BAEC6B5898D908291857B80B29699839B6CC6A59FA4ADC19179768780738661A1A9
6B5080ADB79A956A4FDD7E7B6D656DB5B89A80A792AA5C8F9E894D3929414A3E7D6C5B6C
75674F78797B99998E84919A9A9F585D6453746F
67917266819B9C897B956D7D77664D5A837A622F52464987548994A3A47B6E7065C08782
6F5B84B8D6AE6D80897894806D65A273AB99A75FD49E94A19AB692777E8D8E828C739EA7
766D779DA696936151DA9073796678C0B5A587A380AB63838F9060342B3F413459665A67
6A60516270789D95887B8BA5A689706A7B5C7365
749A7C5D7A909EA16B7F667673604E648F97833970725F7D558F8D9BA27A6B725AC28881
7F5D93BBDAAB534D806D8476666EB183AD96A159DFA29BB897C98D7C81938B9FA280A7BB
79817F9EA9AF8B5850D288636E5671CBBEA9839B8DB5637E9FA476433E5352427B4C4F6B
66564544507FA19789918E7F957E6E7286637177
658D764A83A09D80787A5674735B333B687F74335A6352765A9194ABB491746C4DBA8B80
845A8FB4D19E7A5C7D7185935F6CB18BA695AB5CCB9492A689BC8773667973889777A5A9
72817C90A0B9967162E1936487677FD5C0B57D9E81B7727D9DA7773B3A464E407A5D5057
505B635B506BA2899DA59298BC897D6C77517F71
678574468EA19B8F967D66857F61454F6B916B315F6A658A619799A6B08B6B6C57C3887C
8C4F90BCD69F7261847A878A5B6AA283A1939967DFA39CB39BCE8E847B8679A3875EA3B4
7D7E7789A0AC806E62DC986F7B6A77C5BBB9819F7FA97F83A2B17E4440606A5A8A746364
5A625E4741809BA28FA37E84B1809669775C7A7B
688D7E4D9499968A948077858262535F6E937735596E65755C8D95A6B19674705DCA8986
8F4999C3D3A16D668D85868855689B8C8F84A06ED9B297BE96BE777471816DA07F5BA4AD
7987757FA5AD7C7355E08C6C746986C3BAB76FA9809A857B98B976403C576E5F6E6D685E
576B62594663919E96B6778FAC80825D74728875
7A8D84529C9C8E8C8F706D686A5D4E5C6A906D3254595476569695A5A69370755CC69C7D
764694B5D49374689F927C9C666FB1ADB0A2AF76D8AAA0C0ABC77976736F4E7C7265A6B6
90867486A7BD6F8058DE9977826E8FCDC3B36DA1899A787D87BC67382E455C605B6A5A59
585F6E72567998A58DBF6F87AA7E6F544C5A5C5B
71887C528E9B74828E6C70795B594A557698853C6659537B589E9DACAB976E725BCFA98B
7B60788DC39A775E8D95779F5E66CBBAAB9CB17DE0B1AAACABBF7C856E7B4F987872B7C3
A4967E8BA9BA607D5CDD996F756573B9B3AF7E838096838C87C159372B475B59514E5455
4A766980646990AE9BD65F8CA5946C47516F5F54
7D9B8D4F929E808A9F797B7E5C5D395983926A31453B566D4D998FB2A38F595B56C99685
736F87AAD3908F709CA185A2635DB6A7988B9B7BD0B1949694AF8478757C519C7584B6C1
8D9A6B7F98D6648263E193697B6B6BB0BDA95E8C919A7C8B85BF4D3A2A485D6E4E5A5052
5A726C92546991A172C1569FA18E7E5A60857468
6D877F4787997B88937165735561665E667954214455556B608E88AAA69B6A625ABA977D
85587EA9D3839075A4A28A8D6052A8A69B90A189D7CB989998B28C886574527B6A8FA4CE
8380638294CF537B66DC8F6B715C6CB5BBB4689A9E98818E8FCA54412A4C75645B69665A
4C7B5877485277868DCB609B999D5E5764846A5B
7F91804B8A997D7B896168775A605B6770746132545B577C448C88ABA89B68655FC09A8A
6D438CA9CC8A966FA6A28B8B6D6AA7AB9A92A897C9CA8E9396AC958C6E745699788FA3C4
7580597B9DDC587F70E299717A5B67A5A9AE658E92958E9899CC57432C3B655757716659
596960882E5D858D6EA6698EA0A15B5D6D7C5462
7394864C91A38683947264705E5C6163849A7F3C6E705C894BA094ABA89E5E6462BB9787
67437CABCA90966CA1B08484656BAFBCA3A4AA96C7D9978FA6A8A78F73765E9B7C978FB1
6F875E6F91D24E675BB67D65746076C7CFBC71868891827C85C15440273A5A5357736369
5C5F51833A3A627E81B67D8398AB4F5C6A6B5363
6388774F929B84898D64686E565162607A8D713A6761537F5C8295B4A99D65696EC6B598
735B7D90C2A48E6B969F7B6D6864A9BEA5A2AF94C6D08E8FAEA1A5826B6E5899729289C9
6A7C5571BCBA58766FE2956A6B5F6EB4CCAE64999C8C857B74A94A3C2635494C48716861
5F6B6675416BAA9CA8C59D98AAC07E7B7B6F677E
5E897A518FA28D898D7069747B4D4E56707069416263648A9DA392B49F95746067C1AB89
5D607699B3928B709491715372749FAF9395B097BFC1838AA998AF7D867B609C719686CB
867E557998DD6C6E69E3937273637BC6CDAF747B928C928186BD5E3B332D4E5F59738C81
70695C68374CA18884B99E658A926A80A76A6378
5C927A487B8F7789805E4968665A5B6E91967D42616C5F96A7B399B9AC935E526CBDB191
6963778CAB998E6F9F867C54876F99A293A1BA869EBF9894B1B5C0808D81699E89AD81D4
87825878A3E1736464DF91776D6871BCCBAE768A917A736C82A16439323050594E6A8478
7A6E7060523F919F8CB0A061889A825D5D37546C
609973447C81757D7E7955706049546689887A41675B628A97AC99BAA598745474C0C196
686D8598CEAD9B81B9897D6192809AB1B0B5CB8EA6B69483ABACC2768884779483986EDC
7E6D63899FDA655168E098767A7D7ACCD7BB909CA58F9A829EC97B3A342F4C5957767579
67656E4B5B568B9788BBA5658798886A634C6B86
5D7D6F45869C8588907A557C7353466A8767583A5E6D61828AA182B2A19B73497ACDC48A
616C8299C3AC9A71B686876E9579A0B2C4B7C48EA9CCA593B4AAC5607D8587A68F906CD9
8464617AA1D45D5358C7926D787C76C3CBA27CA8A8919788A4C574393C3151545A756573
6758504B5E4C5F987995867479849870705D718A
6D907C4B8D8E85899B6A486B7A6244708A827341536B7186A49E87B09C926D4B77C6B982
62657F9EC5AD9E6CAC7B81729E728AA5BCA1A7819CBEB1ACB8BCCA5787968A8C828672DD
7B637387ACDC614864D7865D746F79BDC7A16C89A07E8D8798C2793B3D364A6165806C77
70755A616A5B669C7A987363718F926668706C8A
708D7D4991B29D9597684C72675D4A6C7A8571475D6F5E7490A991B7A18C6D577BCEBF85
61799CB0D8C0AB75B072837A9B6C7DA0B58B8F8686ABA3A4A8B0B7568E8B878479826BDB
7B5D7994ABDC80576DE69A68816E83C5D0BA7A8EA88D8E8CA3C38043473F55687E887983
718260647662537D91AA846F908091716D728188
72917F52849F8B9191774E7D7B52405D6F6D5F5163695D687F8E85A4936F5C4863B3A46D
566F94ADD7BEA574B1778A818E5F8DAAB783A19697BFA7B1A5BBB55F8E849B819E7B6DDB
8C5B7B929CDF8C566CE4A26C866A80C0C2A16F85A28C8E97AAC3855246464F618C857A77
6C8C66657C676E828A97837C96967F676C928CA6
78A67E5E81A6939682644A6D6F5D435D817173585D6962788DA293ADA482623E60BEBA72
5B72829CC2AC8E629B647B7A7A5A82A4BA8C9999A1B1AABE92BFB267A58AA27B9E886DDB
9B5F8EA68ED47F4F5ADB99657D6A7BBEC8AB6C8AA5898C98A4C38644414D4A527E8E706C
6A8A676B61519B9F9B91716C9B936D56587E83A1
6D907662819B8F8D7B6B557A7057536C93807250516A677984B19FA39178674B65ABA466
52638A93C9CA966CAD6E908571657EA2C183998B9DBAA7CE88ADB463996B7576946A65D6
AD5E928C8BDE955957E3AA66886E86C4CEAC6A87A184889194AB77453E4B44486E7B5A52
617E767364576C7B9C968C82A5A67E706F80807C
6A8573508A9D8C90756C4D827857505E71706D4257796A7788B8A6A39E745F576BB5B872
5D5C7687BDB88C539368818660627A9FB47B90889DA995AF73A197547463837989695FD1
9E538E7B87CC955150E1BC738C6578B3C1B372949E878191B1C8764142464957737B685E
65786B777463A392AAA08184A0A6615E72847E91
748184487A7C6F757F62426C7256437C876B62425275595C81AE998C8671605571B0B779
68758A8BD5D3973E997F8D8F5B6A7DA5A984A390A0AFA1C57AB2AE6C91758495A57A78D2
C159898BA1D998444FD5A86F8463729DB19E6381957B788AB7C57E4646424D5F828B7A61
627C7160616B9795B1A48291AAB2806C65675B76
7C85955EA3AA88919A8256888B553D6394755B5A505E616485C0A29DA778665C639E9462
6373858DCCC99140A88F9A8F586E79ABAE99ABA8A2B6A39C72BBBC758D7579899A7875CB
B65B778D8FD4AD3A54DE9277896982BCC5AA61868C897A84BCC987494E48505B8072795C
63876F70664D70829EA68687AAB6868C7D655E63
6F6F7F4CA9B0968E977253686C593E71988A6F594C52656176C3A089AF7D6D7171A1A887
6F7B8487C6C08947A590A28B54727EA9B39AA99AA1C0978666A2A759746E7E83897578CC
B77B8A90A5D1BF645DE1B37B866B88CAC2B56E909D9B8E91BD9DA4545252555D85876E63
5B88717D64406C777E8A8480909D87A167696A6F
7077954EA1A1938FA3676781644A32576E755E4E4F51775986C8A688AB7974718EABB585
7E8491AECEC39448AC969F944A7D90B2BDA5B98994C1AF9F79BFC07B9A718298AD6F7CBC
B69B74829BC4BA5A60DF9E8089647DC4BCBA76989CA58992B7949B5D52494B566674616B
4F7F755F744D6D7BAE98807DA2967BA568586758
7C8698519AA997929B6C5F807B5B44667F8273706E5A906886BB9D84B578787D8EB4C990
8D8089A1CCBC934499898F89497C8BB8CEA4BD9390CAAB9F72A8BD7C916D7D7D9C828AC1
AD9B6D7FA6BA9B415BC39882766179BEB6BC729B90A86A98A4A08A6959514B5174847B78
568A87697850868A8B959474757A8395525B665A
6E7385448A908087906C57727057497281856F7B6D55835A84B79888AE7B7B817BB2BC83
837D9099D4BB934093889282467B82A3B9A9B09589C9B5A176BFC47F866F78869B7889BB
A38A6979A4B8B9516AE28586756671B8ABB2768C74AB5F97AC9C91564E4E4955667A706A
568B91686652728A999AA77C757E928045646965
7680864A8E988A969879557C674A416C9188716F504F5D5468A28F82A4737F7B67ACA76E
7F72809EDAC5925DA9989D87487A8AABC3B7AD9180C4B3A286C2C489897C8088988377AE
B491777CBBB8B05263DD928A7D797EBBB4A56E7D7491598C936797574B41445B707C6E5A
577F85595D4F6D8060709C647D768D7741647273
7183864F899588949673538B74514166777B6D7249505F607DB8A783BA80878F70AAB076
9361719AD3B69A62A19A96874B7C91ADACAFA3888AC8AE9A8BC7CC8F88766F91A59289C2
B0918073B8B4AE3B65DC9995906F7CC0BFA577888382779BA66E924E523D46607987745C
69878E595C4A56758685A96F767D946341635564
627C7D4A859A9199947A517C6E604C708D8F7A7949576B6885B39D7FBF8B8F82709FA47E
86636CA2D5A9A1679AA780834E8195A5A6BCA2926CBAA78E83BFBF8178746A83928E88BD
A9827B66BAAEA9266DDE84A2826970ACA69A857F8C796C83A071995E6C404F6186947561
628CA1545D56687E7D83AF757A838975566E655E
5D817F53728C8E8E7E6A527D5F66577B889776805C5F76678AB1A18ABB828181709CB589
9C4E6198C8A9987097B182705272978FA4BAAA967DBC928F8DB7C78C747D6E929B9C86BE
AC82745FB7A3A82E6DD47B97816D73BEBFA7B9758E8A8180838B986C5E3D505A688B8667
5D877E5855475C6F798BAE7C7F797979485F5F6D
658C84527CA09D938879617C6A665A6B73834F805A4D6F638AAD9A86B083907F658FAC96
9F566DAFCDB7B57798C07F775084A39BB3C4B0AC82C99E8D92AABC886073697D91998FC2
A67D7A58BAA7B03E6DDC85A1777171BCB9A7B28B9E84677E7496946A4935485A56797E6A
5D8B8D6568706F7C9493B387838386694D61576B
708D7C5170929299927D5F786565505443826B7842386A5D73A69D7BAD8382816D94B18B
96515490A696956E7EA27879538BB695AFC5A49C87D8AD8F90B9D0A37B7F768C7A8F83A8
9673654DAAB6AE436FDA7997756C6BB3BFA493928A956F966FA6977A593B514F616D6C6F
648A84716D6284818C87B6808386946B42576054
708893597F9696978D7D5B6E706F768369806C69453672738CA78C70B4948888638FB391
985F63ACB5B3A58486B1807A50849F8DBEC5A29781D8AD989BBACFAA7677669381998EAE
A6906E56C6BAAF4C6BDE76AB896C68A9C6AB7C908D92729368A9A3734A374C4B7965686B
66827A696C72838DA3A8BA8C8578937E565A5B59
7793985A889EA19C8E75596B686269756C826673584A66788EAA897DA37B67775A87B897
946462BFB5C4A7937FA7857E558DA99AC3C9A49980E0AFA1A0BFD29A758565A5839B8DB0
A98E674EB7ABA5535AD06EA4806E61B2CDB2838A8C86799C629FA2734838474880527F78
68886E6E637598968B96C0938C8FA3946B6A6565
7287804D889A978F92775E6B706B63795C807D512D51647786B28C86AF957C6F4A6FA28E
825D50ADAEBA9BA2789B84745B80AC97BDC1A99B7DDDAB989EB7D09F6D6B569782998BB1
AD9C654BBEB7C1535CD46AA27C656399AF9E8782809579A460A99B6C4035484E765B7175
79967579626980717B799A747F79968D71777A79
6B917D4E839A9A9A917760746E52706D5D807545564F547B89AD8F72ACA0866D5795BA92
836746A7A0BDA5A37A968A79728BA1A5B4B8A9927CD4ABA3A6C8D59C78805C9287A188B7
A4935F50BDB7CF556FDD75B07C616FABC29D78859A9875A05DAA9F623C385953575B666D
5C8E6D51737D99958B88B6838586887E565E5D73
77A07D4F919CA0958D7F5F6B763D6B7B69A185777C5D518387B28F6CAEA289725486B59F
757549C1B9C6ACA47D9897767589A5ACBCCEB0937CD7B09F9DB8D6917280619987987CB2
9A8D5B55C5A7A63E60D774B97F7876B3D7A57391A4977A995CAF996E3A4467745B6A747A
749575787A709F85A69EB0747586787374784B71
66997B4B939C9EA18C7B5B7679847977629D7B6770574E7C86B38F7AA9A58B736CA5CCA7
7E7B4BBCAEC7A7948580736A7582929C9FBEA28B7EDAB4989EB0DA9477856692859C7FA4
A2A9645FC9B7C64670D776A67C8071AFD0A67CB0AF9F86AD5CB4A1833940636D4B6D6773
829873757D81A1A59E88AE6D70837F8C746D5E82
6DA27B4B95999EA48B79577F7C777066589578566B5B557A7AB28D87A8A58C645899CEA2
7A7946BCA4BEA67F7B7E8078888D8C92B6CCB59978DBB697A0B8D4A2768C679687A18BAF
A791595EABAEBB3A7AD479B577847EADDBA57A92A89984935ABE957E353D5C5B4C53505A
5D77566B626C899E9F88B4888787728F70736A7D
6A967C458A9496A6837459847775636D588C7E4A5C574C7571AB868FA2A083665789C79D
6A6242B49BB9A6867C7E735F807C9489B5BDB1947FD2B8AAA1BACCA1797E619590A091AB
A68A536197A9D13F91E47EAC7A837AADDAA49A8BAE8F979073C4A27F3D4063625F676875
6D7E60656B5C79968B8AB5847E9280857477778F
7E9C804D8E9699B1937E598B7B7F7887619270626E524A7986AE8A88A099735B578EB597
667547A79BC2AC89778586758F739B93B3C1B39B81E0B2A19DBACEA8758E68998CA191AA
AE975C77A6AECF2F8DDD7EB2887F76B4D59E9696B0939E8B7ABFA0744B436062546E7575
717671726C8597A3898AB196869E7988756B6B8A
769781559EA3A2B797775A93797272775C8F845A7769608F90B1989BB8AC846A5FA6D0B1
6E7853A093C4B1806B7888769B658B91A3A4A78E78D5B3A5ABBAD8AD7B86609686A48B9C
9974526F8FA6C0329CD87CA0837A73B9D19A7AB1ADA2A98F81BE8963513D615F4B617D6B
69736E6B737F8AA1969BB28E7E825E656C5A5C7F
7296825798969FAD756F59826B77797376A08253636D5C7178A68991ABA1766B5FABDDBB
687F509F9AC0BC826E81917E9A678B9BB5C2B39E73B8A59BAAA7CA80727C69A68EA78CAA
A38B597BA6B1C43BA7E082977D7262A2BC8B68AF9D8F8E8CA0C88A5B5A4368645971847B
74666C6B7F869EA87993B38F7F8B8B594C64666A
5A83794A979B9D969C7654797C66554753896D425A4C56737E9C8997ABA873715C94D199
637D579598C4B07A6D718B7398739099B5C3B49D77D5C0B2B9A9DA8E7F886A9B86A87EA6
8F825C7E9BAEC73FA3E08D9B7F7F6FB2CB9E625C87A18E8D8FAA8453473C525856687975
6A765D6A6C6B828C567B9B74708983626F727A9C
6C957E528E90978D8C6F4A6C73686A67538C72416547496A79A27E9BA194646C608EC096
5E80589CA7C6A977716D8271916E8794B4A2A39165D2BB92AFB0E0948982609D85A87DAC
A48C5E7F9A9ED246A3E3818E7E8573AFCFA5555D869989969CBB794044365C5A626C7970
696D685C6C77928B627C98837E766F636E6F6C78
67A67954919CA0A28277577A7558726470886D3E6A565478729B7F99ACA36566618BC390
557A537D93C8AF7D6F637F728870878CB5AB98956DDAC59C7A8CA67C77725B9082A67DB2
AD866485ADAECA40A5E48493838674B8D0A75F919092839B8BB86C4D4437575A62677C69
6D755162575B779A6A8B91615E67675260636E80
6DAD7D67879FA7B48E7C60898F5B77667D906F485740476570B48894A6985C64779BD09D
5C80588795CBB582795F7C7484647E8AAA98868F71D6BFB365C797667678639280A386AA
AE8B6287A7AFBD40A2E28F997D7F7BB0D0A664B092A48FA890A86B593A4B8265707B8273
846D707376779ABF7EAEB18C75857E745166727A
7ABE866584A0A6AE8E7F5C839366635B727A41447D5C586767AB8790B4A4626971A8CCA3
6A8D5C81A2CAB27C785F83728564788EB3A38CA375C4B7B58BBCB388827952807D9986A5
AD825E889AB1C142A1D8858E767F74AFD19F69B68C9780A882AF71503C5C846293707579
7E8372766D7E99B16193A9908E967F847D6F7A84
80B6886B8C9EB2AD8C836686927169486F893A567D676D7470AF938F9D9B685A6398C395
5E7F6488B2D2B28A83638E7D916F607EA197788577D1C3B8959DB28C867D5E8B7C9378A4
B1865A87A1AFCA4AA7DB7584808573B1CA946BBE8E9684AC80BA6E4F3C5E83688A667069
7D796B6F5E73829A5B949E79677C697C69637882
6EAA846381A8C0A48C896C839E8272547F9D605A8B7C707D78B5979DB2BB71616EA4D2A4
65817D95B4DDB58F87618E75846C76A6B4A7939782C8B9B69597AD837C785C9692986FA1
AD785D868EB3C84BA7E37396858F83B8D99A69B6978C81A766BB693E2C517B58916E6E68
64716B5157688BAB688F876A5D646D69665D8A8B
6E836E5D8099A6867D7A6A8E9878484D6C8169558E69677671B8909DB1B2675F71A4C8AB
5F826F88BCDCB181815D8C8284655F8CA29B848F7FC6B6BA99A69A847172559998987EA4
AA715B869EAEC449ADDF649478757FAEC38566AC9587848E5BC16E442D5379538A716969
74746D65708C9CA27995917861706A557151728C
82B0847E9AB2A58A7789735C7B7E6E85838758498A67597767A38095AEA05E597599D8B6
5B858B88C0D7B686895D8A817D7663A2A0B097948ECDC0C2A4B0A08A7276509D90A584A0
A66E627B98ADD74898E27CA0888881B2D5A4689E86908D8C53B1815E3E54895C8F756159
6D7E7E54648691A383938C776F896B585C516F6E
86B389929BABA9968D8C7C7B8787635E749F654F8367516F6FA594A2A89B614D719ECA95
5580878BBAD4A6828E638189868A6EC4A4B49E9687C1C5B99BB1A68D858058A0909D849F
A57263829D98D04689DA8F9784767BA7D1A399A8A29DA29D558F8F5538507850856F6C52
647E7469537C779D809F936E749D73615B56686F
7DA9829D94A6AB9385787C7783837B7B7793604D865B59676DAB97A4AA9E655C7FA6D2A3
608D967DA6CA886C866582806F775EC0A2A594917BC9C4BCA8BEA88B7E7E5D968BA98BA3
B77D6C8DB5AFD5469FD4AC99897087A4CC8C86A1A6879C9E62AA8C57395D7E5481666054
66846F5E537C81B880A591768AA076656A667484
87AC838B81A8A2998C82776B8590888184966F557971617C6DAD9CA1B0A3666989AFD69E
5D838784AAD7B3879D5A847B7D8570C2B0B198A088CAC3A399BE9E8E807E679296A189A8
AA6F677EA5B4CE44A4E3AF928C86A2BCD39781ADAC7F9A9F62AA944830608A5F78665951
6A86848B568095AD759A797C8CBC905C4E60717D
7AA585868AAFAE958D8D72637A84737E87A9775289796A867FB8998AAAA0666468A2D099
5E898D89B1D3A7777547737A7864587DA09B9A9E88C6BCB089BE98888B7977909EA18CAE
B070687497B1CB4399E3B595898BA8BED59C83B2AD87A29E5BAB94603872A1878472704E
647370814B7283AD8DAD8F7F94AD955E665B6976
8AA68B829DACAF9E828A73617D8B70857A9B7B567F61607B6DB49485B1A86C68619AD7A7
6984848FB6D5AF7D845F9279956579B1B7B2959E87D0C4AB88B58B7C81757E8BA3A182BC
A4806A679DB7CA4B9EE4B1867080A7B2CE9D7EB0A67F94946FC2914F2C739C7B72757868
6F72778A4E7B9FA49EB98C92A6B498595F5D5F80
839379769AA6B39F8293826C7C89738C709970547A584D7378A68676A19A6E69659FDDB3
718985A0C1D7BB8F866392858B677CBCB4B4979D8FD5C6A88FC8988D9173828CA69980C4
B192656C9EABD34697E0A7776577A6B0D19369A9998C89958CC3853F297989736A685861
7385879459739E9F8AB08A95A6B1936272616070
7891836FA4A3A29A8C9C7B7F7E8D7876599268556F4D577E78AD9079ABA068665F97CFA5
60816497A5CBAA8082618D80875E6E999F9F909575D9D2A284C3A08580698074948780D1
A39D6F68A7A2CB4B91DC8D79697BB5BACF975DAF8F936681A4BF78383184905173776071
5A7C7885567AA59783AD7C8DB5B08A5E756A6167
66807C937197A08B8D9373858180849E699D69637E54618179A38675A4977D6F5FA8D8AD
5E825AB0A7D5BA83826B957D8A68709F9E99889264C8B28D7FC4AE80896E897F95757BD4
9CA27363B2ADBF449ADEB26F6A7DB9C7D0BA61AC88886188B7927D4434757C3C7C7C7A74
628483935970A09985C78A91A7AA7B667C706674
84938CB78DA5B891899269838266848D65A3706F856C697B6CA29376A88E7875559BD49B
707A4CAAA6D4C4807D6F957C974D66959B98908F6BDABD9B7AC09C769275918099746ED4
97906C58B6A7CC469CDFBF806B75B3CDD0B76F9B8B62757CAF768C5B3A857C6267727580
6285758F5E8BAC9077C58597AFA9825C6C564E6C
7D8F80B082A9BA918395728582558BA262A16F73816A5B7A7BBC8B77A59B796F508AC9A3
707B48B9ABDAD38C8B7D917F9D6777AEB49D9E9375E0C4A07DBB946E9A7BA38CA57B6BD2
9E977658B8A9C0399BE2B8716B75ACC7BBAB798E9A618A839694656C3F8C708E726B748C
5D7A72987087A88C79CC92A1B29E8967685E6EA5
7F92819A79A1B7928B967B818D5B85A26FA46F69755A5A7F79B89382AD9D7C7C5992CFAA
797D48BC99D3C985746D8877946D6EA2B2A09D987AD9B99888AF97689D8B9F8CA67864D3
A0837F58C0ABC534A1E3BC6A6874A7BBC6967C899976788068BD66532C6A65888A726E7E
5D735D8373819F836DC5908FB09BA27162697DA3
848D798A86B6B292849B75758D5A869976886A62825B5B737FB0847CA3A3847E5EA0CCA8
7D8444B89DDAD29187648C7E967F76A9B3A2A08F79D4B18F7EA98760968DA68BA4755ECD
9A888658C2ABC628B0E4B06F75729EC3CDA1928FA67A8F807CA46D4932716671907A7973
6F6B6E77717AA27467C49687AD876C7A726B796E
8296839288B5A99586A77F6C89538591759D806B7352507A78B3877EA79E8486658AC7A9
828948B7A5DDD492835F8D6D8C8368A4A59DA18D81D3A4917DAC886694838B7D947661CD
98707D57CAAAC21AB7E2937E7975A3BEBC8BA28EAA7B9A6CA9916C472F7C6259986C675F
926F7168837F998365C19F7DA18D845E66598164
8B896C787CAFAD9880A6867A8C57877D6EA171606F4B4C7075AA8176A79C7B85699ACAA4
7A824AB8A5DBCA8D7B61876E906A629B6685978F7FD9AE8B6DA68E6F99999A90A07B62CC
996D7E51BBA2C33EA5E39085857B98CCC87AA789A67F946C9D96665240715C6092947C6F
9D6967508183938468BA9E748D977D5B59749486
7D8574948FB0B991809E7B80955D8D956D9C6E5F624B4A77669C7A81AAA5867B598EC4AB
787C4DAE8FD3CB8B7F6C8E6D8F676AAE8E979D8B77D4A38D85AE99798E9E918DA4825ED4
9E728C5BBBA1BE559FE28E7F8B8A9BC1BD83A98E9C8A9474A4966E554C7A64697587767B
916F58486779939064A3977C8B9A718258648E79
897B849287A8A8908D987A8B8E649098779D7E6F7249527A7CB1868BA69F8583599CCAAF
7B8355C3A8DED0908B748D7A9F6270BC8DAFA08B83D5A18D80B1A8798A9E8D95A08267DD
9D6C8F60C3A9B62FA5E48881767A99CFC6909E9F9E889477B98F6F43316C5E7C6379607B
837F647582868C9864BDA67F8B8F62834F4E736F
937A7F8E89B5B19894A37C7C8D708088638676696F4752767EAB8482B1A0878B578DC4A2
797F52BE9BD9C993896B7770946666AA83BAA69B7FE4AF9376A29C7181888889A28559D0
8C759C79BDA29C25E0E69085887B91C2BB8DAB9EAD949984A98267383F8D508358845F74
8E7D6F8B7E8B98A073C8BC72929D5F743F3F615E
8B727D877B9BAEA09798808F855B7790536B49495C55627B88B48D80AF9D81935E8DC6A7
7C824DBE91D6C39A817281789B716FA997C5A3A57CD7A69B87ABA57A7B8D8491BC9186A0
A672A080BFB3A92ADCE3857D7B7994CDBC7EA18F958B7C91C08B68483E804D8A64837970
8871776176857E8C72BAC0668FBD6385594E715F
8F788A9D8CADC0AC8F9B6987946286986B9B7C6C664D5A7E89AF8E80B09D857F4F8FBBA5
768B4BC69EE0BEA7846F8680A17E7B9AB2BB959F92D4A8B489A49F807C7F6A75A79A7ACE
97629681A2AF993AE1E5787B888CA8C5B972A89483768288B77677433E7B587962778085
976D7E666C7E8CA979B9C0618EC55B6C60676D6D
8E7889AD93ADC0AD989C7A8D8E62819685AC76747F5862867BB59C7CB4A3858F6490C0A6
7A8A4BC596D2BCAD826D887B95797D889BBB7E8BADC5A5BA85ACA18D8087687F889F81CD
96668882AEB2843BDDE1657874749DC4B86DA0887E766987AE676E463C735865858D7274
815D766C6984818C6FB1A36D8AA751566B566E72
8D7C94AB8DAFC0A3979C788694597C987EA66A627B4F647D92B39E7DBEA4888C6893C7AA
7D894AC799C9B9AB88818B7D9686949CB0BE8F9FABD3A1C681AEA37E7B8562958CA3A7DD
8D6E899297BB7F31D6DD62738482B1C5B86AA28F8B79726BB869644138786A6780876E8F
80746D63616B7F9576AD88738DAC5A4F59566760
917B95AC90A8BEA6869274869150839E8AA460647C5478808EC09780BEA086906E90BBAD
869651BA96D3B9AA85668D808E8C9F94A4B19293B6D09FB8798E8D758181518F7198A8D6
898283B39FCF774DE2DC6A81746BBDC1BB7F9D92956C8D5EA87161503D76695C787E6584
707777676C76869474C37D7F91A96257594D6B63
917C8E9B8FA8B8AC869B688E95607D9C87986B64714D767087B79875BD9B89956995C0AB
8E944AC2A4CEB4A28B668073797E97B0A8A89296999EA6B77FA89B838C82509C7F92B1D5
91876DABA1DA6A4ADEDE79697759C9A8B088968D947591687F935D4C3D7F60576D7B5C7A
73707A6D727F968D7DD572929AA26D636352746B
90838F998EAFA8B5868F5B918866928D889A6F5E705C6E7487B59288CAA090936691C0A8
89854ABBADCBB0997F6D8D6C73878B9599AA8E88B7ABAAB48FB68987927D568D8780AFD2
8A8F60ABA1DC624DD8D17B697751CEBAB894756C896A7F7A769754405085796260828587
6B656979838BB18479D774959E9559685D4E6B6C
887E888685B3A1BE8F8B5B948A6985958195765F705866758AC49386BF8E857D6290B197
8C804EBC9BBCB29F7D6E88756F8D8FB3AAA6A490AAC6A29F85BB7F8B8F8B719A8873B0C7
809E5EA097DF575DE1C199787D5BC2CBAB9B9C89A6778093939A784154807D7F708A6273
6B6A65818E8EBA7A89DC579C958983756A547279
988A87807EAFB3B483865A9F92606D98879288676E505E7A88AE927DC083818D6895B498
998057B6A2C8ADA978718779528091BCA4949D7FADD4A3A689C27B768592808E9D65A6BA
84A7589195DF5073E4BD977A776BABD79F819B8E9B7B89A0A89D7D405A9156A072786872
716E6D7D9791B36E94D2538A908B924E6C4E716A
8D8D867E7FB5C9C596895F997E5E749789898465674C527E80AC947ABF8B84856E88C1A0
A98459BEB1CFB1B57B7D8E895F8FA6ACA193A28BA6CCA4A48EB77673818E929AB86EA9B5
91A6688AAAE54F77E3AE9985707BBDDE9865A097807A6B91B98F7149638A49A2766A786B
7E6A6E758A91A06F8DD0567B8C8491695A5B7B79
8CA87F7980B8C8C299865FA0905D6A868A8E836F684B5A8281AC988AC38D8A8F6786C09D
A97B58AEA7CEABAC797B84885085AAC09A96A7A1A5CFAC9D94C27174818A9991B673A2A4
879F7286A6DD4C88E59C8F8F8685B2DB91629F9A8D9F7F87B27D875A617B429A78627973
90669969A098A0658AC0657A9F83787C5B5A8475
8BA67D737EAEC3A7937C5D9C8D63727F9886867469424E7E76B99C86B88D8A8B5D79B297
A0835BBAABCBA6A47A8385884D80A3B3A397A19AA0C8A3998DBE7672828F969CC07CA4A8
8E957F98AAE03C93E3967E82919CC6DA89579499848E84A3BF8E7F465E814B89767C8A85
8A77B4638D8BAE6D9BA77173AC8A7C6153537B6C
89A9806E7BAEBFA2A07D65958C67797EA5898A7A634A568061B9B194C9938F936E81CEA1
A97B55B2AAC6ACAC7F7B87864C7DA6B4B080A4A5B1DAA3A09CC4777B7B938EABAD8BA9B2
91869997B1DD3B9DE39B7B73869CCDC094549D8F798F8A94B18981305A764A757C7F798C
7382BC739196AC7DA9A987769C9B885F50509080
88B3877A89B8C59E9F826D867D67645CAB868A7D664555315AB1A196BF8D89877186C097
9D6F61C4B6C6ACB57D7E90924972A9A6B47CB1B6B8D99B969CC37B7F7B8D8D9E9C9EB0AB
9575A5A5B9D642ABE6A97965819CB694AB64B0998B9C8C8DA88D7D366E834768736A6E91
828CBD758B899C81939D86A6A8A9795B4D5C766C
899D8C6D8FB0C6A2A8907594786A655FA57E767B6350563E7BA9A092BD928F8A7893BA98
A07070C2BAC4B0A9837D8F954674A7B5B973ABB7C3DF999C9CBA858B738C7A9E92A3B4B0
8171A8B0C2D539AEEBB679578091BABAAC6AAA878A9A908CB58A893D7D7E50786C6B6B80
8089A46D7D879882928B828FA4B37A6A4E697864
7993875598A5BC9BAC82799583747178B1897C876F64586482B09B94AE8C8D868798C39D
9F6B73ACC3C2AA9A8178869E4D67A6ADAE77A6A4C9DB959D8FAB808A7A8C839985A2B3AF
7A64A0B2C7D332AFE6BD7C5D7E98B7BCAF739A818F818D7DC4807D2D685F5183647B7D8A
837989798396968DAA7F8F97A9A47780636B7D72
7D998B5BA099A796AA846D8685817669AC977E936E5D473E84B89EA0BD8E93897FA3C39B
9C747AA5D8D1B897867C7D9B6268A0B39B74A3A3D5D3A1A987AA8F8786857F967F93B4B3
83629EAAC2C22CB5EAC07262568CA1B8B187A990A079976CB7867F397F7162935F796F8D
777A7F83879E8F90A18A9B969A986C755C6D7D70
81988B639E98B89AAF899191756E6C589E84698F6F52684486B9968FA286788183B6C4A0
946C7BA3D0C2B18881898098747392AC9A7AA19DE1D2ADA089A3978594797490889CB1A3
6D6498A5C4C726BEE7BC7276609DA6BD9595AC9297669E71A2A5693D6E58629657717086
70806C8982B99796A7909B949A9274716669787B
879590559D9AB494B592A490777C6C72A68285A085506C4488BA8C98A474657273B2BF93
8F706DA1DDC7B2858F6E848E797491AC88739193E3C5B2A990AC8E82AE817FA88499B5AE
858394C7CAA934C4E7AA7B844C94A0D195A37FA49768888384B95338966473915B715B72
636F638B99B7A48FB1ACA3B69877806E5D6B806E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_ooool0101JFUX0Ph>308>3
P`2CTi<20:6QX@050:n_[`2NWYh0D51@051@D00g=cL00P2c/k<01@2i^KT0_;bl0;bl_02h^;P0][Jf
0080OGem00D0;bl_07moO`1oOgl0MGEe07MgM`020820P00408F5Q@21PH40PH6104M7A`80[Jf]00D0
/K6a0:ZZZP2YZJT0ZJVY0:^[Z`0209FEU@0501hN7P1hN7P0Shn?08n?S`2DU9@00P2IVIT01@2NWYh0
Ti>C02HV9P0V9RH0EEEE0080HV9R0`1YJFT01@1^KVh0Lg=c03dm?@0m?Cd0OWin0080TY:B00D0WIfM
0:BTY02ZZZX0ZZZZ0:VYZ@020;2`/0040;Bd]01GEeL0EeMG09nOW`<0/[:b0`2`/;001@1aLG40>SXj
09fMW@2MWId0Zj^[0080[jn_00D0Zj^[0;2`/02`/;00KVi^03<c<`0208>3P`050820P02BTY80TY:B
09bLW02YZJT00P1/K6`01@0U9BD0ATI604I6AP19BDT0EEEE0080J6QX00@0MGEe04m?C`1?Cdl0KVi^
0P2i^KT01@2b/[80[jn_0:f][@2][Jd0[Zj^0080De=C00D0VYZJ0;Rh^02h^;P0^;Rh0;Zj^P020;bl
_0050;Jf]P1TI6@0I6AT0;Bd]02h^;P00P2l_;`01@2i^KT0^;Rh0;Rh^01KFe/0Q8B40080/[:b00D0
[Jf]0;Bd]02d];@0];Bd08J6QP0208V9R@040;:b/P2_[jl0[jn_0:f][@80[:b/00D0ZJVY05=CD`28
R8P0R8R80:FUY@020:b/[0050;6a/@2][Jd0QXJ608J6QP23Ph<00P33`l<01@37alL0`<300<30`02n
_[h0[Jf]0080DU9B00@0[:b/0;2`/02`/;00[Zj^4Oooool0101hN7P0IVIV06IVIP2<S8`207YjNP<0
TI6A00D0Z:RX08R8R02?Shl0Shn?06][J`0204E5A@0508b<S01NGUh0Rh^;08^;R`1]KFd00P1GEeL0
1@1VIVH0NWYj07YjNP1jNWX0CDe=0080I6AT00@0LW9b05IFEP1FEUH0U9BD0P1YJFT01@2GUiL0UIFE
04a<C01<C4`0T92@0080CDe=0`1aLG401@1bLW80emOG08B4Q024Q8@0GemO0080ATI600D0MGEe0:b/
[03:b/X0b/[:0:BTY0020;:b/P050:FUY@2YZJT0ZJVY0:BTY02KVi/00P1mOGd0101UIFD0Jf][06][
J`1lO7`20:JVYP050;no_`1aLG40Vi^K09^KV`2EUID00P2UYJD01@3=cLd0Shn?0;6a/@2a/K40_kno
0080ZZZZ00D0`l?304a<C01<C4`0RHV906=SH`0208^;R`0408>3P`1eMGD0MGEe07AdM080X:2P00D0
ZJVY07YjNP1fMWH0MWIf05ADE0020:^[Z`050<;2`P2/[:`0Y:BT0:BTY01hN7P00P1ADE401@3QhN40
X:2P0:2PX01lO7`0MGEe0080Hf=S00@0H61P0:VYZ@2YZJT0]kNg0P2IVIT01@1ADE40RXZ:09>CT`2C
Ti<0SXj>0080RHV900D0TY:B0<C4a034a<@0MgMg04];B`020492@P0503hn?P1eMGD0MGEe08>3P`1G
EeL00P1KFe/0101gMgL0OWin07inOP1`L70208:2PP0505aLG01WIfL0GemO05mOG`1kNg/00P2CTi<0
1@2=SHd0SXj>08j>SP2JVYX0Vi^K0080_;bl00D0Ng]k09bLW02LW9`0YZJV06e]K@0204I6AP0405aL
G01OGel0GemO08f=S@80PX:200<0MGEeooooooooool02?ooool000[ooooo00@0GUiN096AT@2ATI40
XJ6Q0P2e]KD01@2i^KT0/k>c079bLP1bLW80>CTi0080[Zj^102l_;`0102i^KT0OWin07inOP0h>3P2
07EeM@0506e]K@1^KVh0N7Qh07QhN024Q8@00P28R8P01@0j>SX0Z:RX0:RXZ02`/;00[Zj^0080ZZZZ
00D0[Jf]096AT@2ATI409RHV08b<S00209^KV`050:FUY@2TY:@0Y:BT0:6QX@2EUID00P0R8R80101T
I6@0OWin07inOP23Ph<206e]K@0506QXJ01IFET0<C4a034a<@20P8000P2FUYH01@2OWil0Xj>S0:ZZ
ZP2ZZZX0[Zj^0080/k>c00D0]KFe05EEE@1EEED0XJ6Q0:^[Z`020:n_[`050:j^[P2`/;00/;2`07If
MP0/;2`00P27QhL30:2PX0050:ZZZP2][Jd0[Jf]06a/K00f=SH00P2LW9`01@2GUiL0W9bL09bLW02S
Xj<0ZJVY0080MgMg00D0?Cdm06EUI@1UIFD0@d=304i>CP0206MWI`04071`L019BDT0BDU907=cL`80
/k>c00D0Zj^[0:f][@2`/;00/;2`0:b/[002055AD@0509JFUP2c/k<0[jn_0:n_[`2`/;000P2j^[X0
1@2[Zj/0Jf][06][J`2g]kL0^KVi0080_kno0`2i^KT01@1ZJVX0Shn?0;>c/`2c/k<0Zj^[0080/k>c
00D0]KFe0:JVYP2QXJ40XJ6Q0;fm_@020;Jf]P050;Rh^02f][H0][Jf0;:b/P1LG5`00P26QXH01@2N
WYh0ZZZZ0:ZZZP2[Zj/0]KFe0080Ti>C00<0SHf=0;^k^`2k^k/00`2k^k/0102o_kl0`l?306m_K`1_
Kfl40:ZZZQ7ooooo00@0LG5a05ADE01DE5@0Ng]k0P1gMgL01@26QXH0SXj>08j>SP2_[jl0NWYj0080
R8R800D0MWIf05=CD`1CDe<0R8R805]KF`0207UiN@0406ATI01CDe<0De=C06a/K080QXJ600D0S8b<
051@D01JFUX0FUYJ06EUI@02055AD@050820P01YJFT0JFUY09BDU02=SHd00P18B4P0102=SHd0F5QH
05QHF021PH4208J6QP0507QhN03@d=00SHf=08f=S@1XJ6P00P1;Bd/01@1gMgL0ZZZZ0<30`030`<00
YZJV0080[Zj^00D0X:2P0:FUY@2UYJD0X:2P09RHV00207]kN`0406QXJ01aLG40LG5a07IfMP80XZ:R
00D0`/;207MgM`2EUID0UIFE09nOW`020:VYZ@050;no_`1hN7P0^KVi0;Vi^@2c/k<00P2RXZ801@33
`l<0EEEE05EEE@22PX80HF5Q0080Shn?00@0QhN7079bLP1bLW80KVi^0P2`/;001@2a/K40NWYj08Z:
RP2:RXX0JFUY0080V9RH00D0_kno0;Jf]P2UYJD0YJFU07EeM@0205]KF`050=cLg02LW9`0W9bL06YZ
JP1fMWH00P1dM7@0101^KVh0^;Rh0;Rh^02i^KT20:>SX`05065QH@2:RXX0WIfM09fMW@2CTi<00P2@
T9001@2DU9@0e=CD0=CDe01oOgl0BDU90080@d=300D0>3Ph06YZJP1ZJVX0M7Ad05aLG00205QHF004
05iNGP1QHF40HF5Q06EUI@80Shn?00D0Jf][06UYJ@1KFe/0Fe]K08:2PP0209FEU@0309BDU02RXZ80
XZ:R0080W9bL0P2a/K401@2ATI40Y:BT0:BTY02_[jl0NWYj0080D51@00@0IVIV05mOG`1OGel0M7Ad
0P21PH400`1jNW[oooooooooo`08ooooo`002_ooool0101NGUh0TI6A096AT@2QXJ420;Fe]@050;Vi
^@2c/k<0LW9b079bLP0i>CT00P2^[Zh40;bl_0040;Vi^@1nOWh0OWin03Ph>080MGEe00D0KFe]06i^
KP1hN7P0N7Qh08B4Q00208R8R00503Xj>P2XZ:P0Z:RX0;2`/02^[Zh00P2ZZZX01@2][Jd0TI6A096A
T@0V9RH0S8b<0080Vi^K00D0YJFU0:BTY02TY:@0XJ6Q09FEU@02028R8P0406ATI01nOWh0OWin08>3
P`80KFe]00D0J6QX05UIF@0a<C40<C4a0820P00209JFUP0509nOW`2SXj<0ZZZZ0:ZZZP2^[Zh00P2c
/k<01@2e]KD0EEEE05EEE@2QXJ40Zj^[0080[jn_00D0[Zj^0;2`/02`/;00MWIf02`/;00208N7Q`<0
X:2P00D0ZZZZ0:f][@2][Jd0K6a/03Hf=P0209bLW00509NGU`2LW9`0W9bL0:>SX`2YZJT00P1gMgL0
1@0m?Cd0IFEU06EUI@13@d<0CTi>0080IfMW00@0L71`04U9B@19BDT0Lg=c0P2c/k<01@2[Zj/0[Jf]
0;2`/02`/;00[:b/0080DE5A00D0UYJF0;>c/`2_[jl0[jn_0;2`/0020;Zj^P050:^[Z`1[Jf/0Jf][
0;Ng]`2i^KT00P2o_kl30;Vi^@0506YZJP2?Shl0/k>c0;>c/`2[Zj/00P2c/k<01@2e]KD0YZJV0:6Q
X@2QXJ40_Kfm0080][Jf00D0^;Rh0;Jf]P2f][H0/[:b05aLG00208J6QP0509jNWP2ZZZX0ZZZZ0:^[
Z`2e]KD00P2CTi<00`2=SHd0^k^k0;^k^`030;^k^`040;no_`33`l<0Kfm_06m_K`@0ZZZZ4Oooool0
101aLG40E5AD05ADE01kNg/207MgM`0508J6QP2>SXh0SXj>0:n_[`1jNWX00P28R8P01@1fMWH0De=C
05=CD`28R8P0Fe]K0080NGUi00@0I6AT05=CD`1CDe<0K6a/0P26QXH01@2<S8`0D51@05YJFP1JFUX0
IFEU0080DE5A00D0P82006UYJ@1YJFT0U9BD08f=S@0204Q8B00408f=S@1HF5P0F5QH0861P@80QXJ6
00D0N7Qh0=3@d02=SHd0SHf=06QXJ00204];B`0507MgM`2ZZZX0`<300<30`02VYZH00P2^[Zh01@2P
X:00YJFU0:FUY@2PX:00V9RH0080Ng]k00@0J6QX075aL@1aLG40MWIf0P2RXZ801@32`/80MgMg09FE
U@2EUID0WinO0080ZJVY00D0_kno07QhN02i^KT0^KVi0;>c/`020::RXP050<?3``1EEED0EEEE08:2
PP1QHF400P2?Shl01027QhL0LW9b079bLP1^KVh20;2`/0050;6a/@1jNWX0RXZ:08Z:RP1YJFT00P2H
V9P01@2o_kl0][Jf0:FUY@2UYJD0MGEe0080Fe]K00D0g=cL09bLW02LW9`0JVYZ07IfMP0207AdM004
06i^KP2h^;P0^;Rh0;Vi^@80Xj>S00D0HF5Q08Z:RP2MWId0WIfM09>CT`02092@T00509BDU03De=@0
e=CD07moO`19BDT00P13@d<01@0h>3P0JVYZ06YZJP1dM7@0G5aL0080F5QH00@0GUiN065QH@1QHF40
IFEU0P2?Shl01@1[Jf/0JFUY05]KF`1KFe/0PX:20080UIFE00<0U9BD0::RXP2RXZ800P2LW9`20;6a
/@05096AT@2TY:@0Y:BT0:n_[`1jNWX00P1@D500101VIVH0GemO05mOG`1dM7@20861P@0307YjN_oo
oooooooo00Sooooo000:ooooo`0405iNGP2GUiL0UiNG0:ZZZP80[Jf]00D0Z:RX0:FUY@1VIVH0IVIV
02d];@0209jNWP050;Fe]@2d];@0];Bd0;Vi^@2h^;P00P2MWId01@1EEED0LG5a075aL@1YJFT0JVYZ
0080MGEe00@0QHF5096AT@2ATI40>3Ph0P23Ph<01@2MWId0Xj>S0:>SX`2SXj<0UiNG0080HV9R00D0
?clo08>3P`2BTY80TY:B0:6QX@0209jNWP0509RHV024Q8@0;Rh^02h^;P1GEeL00P1iNGT01@1_Kfl0
KVi^06i^KP1PH600D51@0080;2`/00D0RXZ:0:>SX`2SXj<0Zj^[0:6QX@020:NWY`040:j^[P2`/;00
/;2`0;2`/080De=C00D0V9RH0:^[Z`2][Jd0[Jf]0:n_[`020;2`/00507AdM00Z:RX0ZZZZ0:ZZZP2O
Wil00P2@T9001@2PX:00Zj^[0:^[Z`1`L700>c/k0080WinO00D0WIfM0::RXP2RXZ80YZJV0:b/[002
07QhN00504M7A`2EUID0UIFE05=CD`1NGUh00P1_Kfl0101cLg<0ADE504E5A@1QHF420;>c/`050:RX
Z02VYZH0[Zj^0:j^[P2`/;000P1>CTh0102EUID0][Jf0;:b/P2b/[830;6a/@050;2`/01TI6@0I6AT
0;Jf]P2o_kl00P2h^;P01@2l_;`0^KVi0;Vi^@1[Jf/0SXj>0080];Bd00D0]KFe0;>c/`2c/k<0][Jf
0:BTY00209RHV0040;Ng]`2h^;P0^;Rh0;Jf]P80/[:b00D0/K6a05MGE`2LW9`0W9bL0;2`/0020:j^
[P050;Fe]@2h^;P0TY:B09:BTP26QXH00`2`/;020:j^[P050;>c/`2l_;`0LW9b079bLP2][Jd00P2S
Xj<00`2NWYkoooooooooo`0?ooooo`0407moO`1PH600H61P0861P@80L71`00D0QHF507UiN@1iNGT0
QhN705eMG@0207AdM00506IVIP0m?Cd0?Cdm07AdM01MGEd00P28R8P0101PH600EUIF05IFEP1=CDd2
06=SH`0509RHV01MGEd0EUIF05IFEP1MGEd00P18B4P01@1nOWh0Lg=c07=cL`2KVi/0SXj>0080Bd];
00@0UIFE05aLG01LG5`0MgMg0P1fMWH01@1nOWh0dM7A08>3P`23Ph<0JFUY0080De=C00D0LG5a0:6Q
X@2c/k<0/k>c09bLW0020:FUY@0509ZJVP2][Jd0[Jf]09RHV02IVIT00P2>SXh0101mOGd0QHF508F5
Q@25QHD20;6a/@050<[:bP1aLG40Zj^[0:^[Z`2EUID00P2RXZ801@2k^k/0O7al0;fm_@2m_Kd0[Zj^
0080YJFU00D0clo?05aLG01LG5`0P82005mOG`0207inOP0407]kN`1XJ6P0J6QX06a/K080Y:BT00D0
XZ:R07IfMP1nOWh0OWin075aL@0208N7Q`050<K6aP2n_[h0[:b/0:b/[01cLg<00P1OGel01@3AdM40
U9BD09BDU01MGEd0Ph>30080NGUi00@0MgMg0::RXP2RXZ80^KVi0P2][Jd01@1ZJVX0Ogmo0:6QX@2Q
XJ40Rh^;0080Q8B400@0U9BD0=OGe`3GemL0Ph>30`14A4@0100a<C40I6AT06ATI02=SHd306EUI@04
05eMG@1WIfL0IfMW071`L080MWIf00D0De=C06MWI`1NGUh0GUiN07QhN00208j>SP0507moO`2FUYH0
UYJF09JFUP2UYJD00P2m_Kd01@2RXZ80_[jn0;jn_P2YZJT0Jf][0080Cdm?00@0NWYj06m_K`1_Kfl0
KVi^0P1nOWh00`1bLW;oooooooooo`08ooooo`002_ooool0100l?3`0@4100410@016ATH203dm?@05
03Ti>@0h>3P0:BTY02TY:@0T92@00`0_;bl2020P800502PX:00V9RH08R8R028R8P0N7Qh00P0X:2P0
1@0S8b<0:2PX02TY:@0Y:BT0;Bd]0080<S8b00D0;Bd]03dm?@0m?Cd0CTi>03@d=00202TY:@0501dM
7@0E5AD05ADE01lO7`0m?Cd00P0n?Sh01@0j>SX0=CDe03De=@0g=cL0BDU90080<S8b00@0>3Ph03hn
?P0n?Sh0>CTi0P0g=cL01@0d=3@0;Bd]02<S8`0S8b<0ATI60080BDU90P1>CTh205MGE`0405eMG@1V
IVH0IVIV065QH@80;Rh^00D0CTi>06QXJ01/K6`0K6a/06i^KP02075aL@0504E5A@0G5aL0KFe]06e]
K@1SHf<00P1GEeL01@1NGUh0MGEe07EeM@1JFUX08B4Q0080KFe]00D0KVi^06][J`1[Jf/0NWYj07]k
N`02059BDP05030`<014A4@0A4A403Lg=`0^;Rh00P0/;2`0100f=SH0>c/k03/k>`1RHV8209jNWP05
09RHV02CTi<0QHF508F5Q@2@T9000P15ADD01@1ZJVX0WYjN0:BTY02TY:@0/K6a0080]KFe00D0ZZZZ
065QH@1QHF40/k>c0;bl_0020;Jf]P050;bl_02^[Zh0[Zj^04i>CP1UIFD00P2PX:001@2SXj<0XZ:R
0::RXP2XZ:P0SXj>0080Shn?00@0_[jn0;Zj^P2j^[X0]KFe0P2h^;P01@2g]kL0G5aL08f=S@2=SHd0
[Zj^0080[:b/00D0[Zj^0;2`/026QXH0QXJ607moO`020:FUY@050:JVYP2HV9P0V9RH0:FUY@2g]kL0
0P1UIFD0102NWYh0YZJV0:JVYP2ZZZXAooooo`0406][J`1FEUH0EUIF07emO@80L71`00D0OWin07Ee
M@1eMGD0Y:BT06UYJ@0208F5Q@05065QH@13@d<0@d=30861P@1NGUh00P1eMGD0101ADE40FEUI05UI
F@1HF5P2079bLP0507]kN`1MGEd0BDU904U9B@1GEeL00P0m?Cd01@1jNWX0LW9b079bLP2IVIT0S8b<
0080BTY:00@0RXZ:05aLG01LG5`0N7Qh0P1fMWH01@1gMgL0`<3008^;R`2;Rh/0Jf][0080BTY:00D0
O7al0:NWY`2/[:`0[:b/0:^[Z`020;Rh^00509jNWP2MWId0WIfM096AT@2IVIT00P1mOGd0101^KVh0
JVYZ06YZJP1_Kfl209RHV0050;fm_@1aLG40X:2P0:2PX02?Shl00P2MWId01@2i^KT0MWIf0;Vi^@2i
^KT0XJ6Q0080VYZJ00D0_kno05eMG@1MGEd0PX:206MWI`0208J6QP0407emO@1OGel0GemO05aLG080
XZ:R00D0^k^k075aL@26QXH0QXJ608F5Q@020861P@050<?3``2e]KD0[Zj^0:j^[P1YJFT00P1fMWH0
1@2l_;`0S8b<08b<S01NGUh0N7Qh0080MWIf00@0KFe]09FEU@2EUID0b<S80P2YZJT01@1SHf<0PH61
09>CT`2CTi<0J6QX0080L71`00D0Ogmo0;fm_@2m_Kd0N7Qh03/k>`0203hn?P05030`<01HF5P0F5QH
0820P01]KFd00P1`L700101iNGT0QHF508F5Q@1[Jf/207inOP0505YJFP1OGel0C4a<04a<C01_Kfl0
0P1oOgl01@1gMgL0Z:RX0:RXZ01UIFD0OWin0080MGEe00D0JVYZ07moO`1oOgl0VIVI06i^KP0205MG
E`0405YJFP1cLg<0Lg=c08:2PP80NWYj00<0Ogmoooooooooool02?ooool000[ooooo00@0?3`l0410
@010@400ATI60P0m?Cd01@0i>CT0>3Ph02TY:@0Y:BT092@T00<0;bl_0P0P82001@0X:2P09RHV028R
8P0R8R807QhN0080:2PX00D08b<S02PX:00Y:BT0:BTY02d];@02038b<P0502d];@0m?Cd0?Cdm04i>
CP0d=3@00P0Y:BT01@0M7Ad05ADE01DE5@0O7al0?Cdm0080?Shn00D0>SXj03De=@0e=CD0=cLg04U9
B@02038b<P0403Ph>00n?Sh0?Shn03Ti>@80=cLg00D0=3@d02d];@0S8b<08b<S04I6AP0204U9B@80
CTi>0P1GEeL0101MGEd0IVIV06IVIP1QHF4202h^;P0504i>CP1XJ6P0K6a/06a/K01^KVh00P1aLG40
1@15ADD05aLG06e]K@1]KFd0Hf=S0080EeMG00D0GUiN07EeM@1eMGD0FUYJ024Q8@0206e]K@0506i^
KP1[Jf/0Jf][07YjNP1kNg/00P1BDU801@0`<300A4A404A4A00g=cL0;Rh^0080;2`/00@0=SHf03/k
>`0k>c/0HV9R0P2NWYh01@2HV9P0Ti>C08F5Q@25QHD0T92@0080ADE500D0JVYZ09jNWP2TY:@0Y:BT
0;6a/@020;Fe]@050:ZZZP1QHF40HF5Q0;>c/`2l_;`00P2f][H01@2l_;`0[Zj^0:j^[P1>CTh0IFEU
0080X:2P00D0Xj>S0::RXP2RXZ80Z:RX08j>SP0208n?S`040;jn_P2j^[X0^[Zj0;Fe]@80^;Rh00D0
]kNg05aLG02=SHd0SHf=0:j^[P020:b/[0050:j^[P2`/;00QXJ608J6QP1oOgl00P2UYJD01@2VYZH0
V9RH09RHV02UYJD0]kNg0080IFEU00@0WYjN0:JVYP2VYZH0ZZZZ4Oooool0101[Jf/0EUIF05IFEP1m
OGd2071`L00507inOP1eMGD0MGEe0:BTY01YJFT00P25QHD01@1QHF40@d=304=3@`21PH40GUiN0080
MGEe00@0DE5A05UIF@1IFET0F5QH0P1bLW801@1kNg/0GEeM04U9B@19BDT0EeMG0080?Cdm00D0NWYj
079bLP1bLW80VIVI08b<S00204Y:BP0408Z:RP1LG5`0G5aL07QhN080MWIf00D0MgMg0<30`02;Rh/0
Rh^;06][J`0204Y:BP0507alO02WYjL0[:b/0:b/[02[Zj/00P2h^;P01@2NWYh0WIfM09fMW@2ATI40
VIVI0080OGem00@0KVi^06YZJP1ZJVX0Kfm_0P2HV9P01@2m_Kd0LG5a0:2PX02PX:00Shn?0080WIfM
00D0^KVi07IfMP2i^KT0^KVi0:6QX@0209ZJVP050;no_`1MGEd0GEeM08:2PP1WIfL00P26QXH0101m
OGd0GemO05mOG`1LG5`20::RXP050;^k^`1aLG40QXJ608J6QP25QHD00P21PH401@33`l<0]KFe0:j^
[P2^[Zh0JFUY0080MWIf00D0_;bl08b<S02<S8`0GUiN07QhN00207IfMP0406e]K@2EUID0UIFE0<S8
b080ZJVY00D0Hf=S0861P@2CTi<0Ti>C06QXJ002071`L00507moO`2m_Kd0_Kfm07QhN00k>c/00P0n
?Sh01@0`<300F5QH05QHF020P800KFe]0080L71`00@0NGUi08F5Q@25QHD0Jf][0P1nOWh01@1JFUX0
GemO04a<C01<C4`0Kfm_0080Ogmo00D0MgMg0:RXZ02XZ:P0IFEU07inOP0207EeM@0506YZJP1oOgl0
Ogmo09VIV@1^KVh00P1GEeL0101JFUX0Lg=c07=cL`22PX8207YjNP0307moOooooooooooo00Sooooo
000:ooooo`<0YJFU00D0Zj^[0:RXZ02XZ:P0GemO07moO`02092@T00408R8R02PX:00X:2P0:BTY080
Z:RX00D0[:b/0:>SX`2VYZH0YZJV0:BTY00209bLW00509BDU02:RXX0Jf][06][J`1VIVH00P2TY:@0
1@2OWil0XZ:R0::RXP2NWYh0VYZJ0080SHf=00D0S8b<08n?S`2?Shl0QXJ608n?S`0208b<S00508R8
R022PX80PX:204Y:BP1[Jf/00P1iNGT0101[Jf/0L71`071`L01fMWH207QhN080MgMg0`1hN7P207Ad
M00505iNGP17AdL0<S8b038b<P1BDU800P1VIVH306EUI@0505iNGP16ATH0EUIF05IFEP1<C4`00P15
ADD203Ti>@80;bl_00@08R8R01LG5`0G5aL08B4Q0P0_;bl01@0d=3@0>3Ph02l_;`0_;bl0=CDe0080
:b/[00D08b<S02XZ:P0Y:BT0:BTY02XZ:P0202/[:`0502d];@0O7al08R8R028R8P0_;bl00P0e=CD0
0`0g=cL0?Shn03hn?P0403`l?00502d];@0O7al07alO01LG5`0K6a/00P0V9RH0100`<3008b<S02<S
8`0O7al2010@400502@T900/;2`08B4Q024Q8@0Z:RX00P0H61P01@030`<04A4A02LW9`0W9bL092@T
00809bLW00D0;Rh^028R8P0L71`071`L03Hf=P0204=3@`0504E5A@19BDT0BDU904e=C@0I6AT00P0^
;Rh01@1;Bd/0BDU904U9B@1=CDd0DE5A0080;Bd]00@0<c<c055AD@1ADE40HF5Q0P1SHf<01@1]KFd0
M7Ad03/k>`0k>c/0@D510080BTY:00<0C4a<ooooooooool03oooool0101gMgL0IfMW06MWI`27QhL2
0861P@0509BDU028R8P0R8R809fMW@1OGel00P28R8P01@1fMWH0Cdm?04m?C`2;Rh/0HV9R0080UYJF
00@0I6AT07EeM@1eMGD0I6AT0P1lO7`01@23Ph<0IfMW051@D01@D500GemO0080@T9200D0OWin06][
J`1[Jf/0T92@08^;R`0204];B`0408:2PP1OGel0GemO07MgM`80LG5a00D0MgMg0=3@d02JVYX0VYZJ
06QXJ00204M7A`0307YjNP2d];@0_kno0080_kno0P2g]kL01@2LW9`0WIfM09fMW@2GUiL0V9RH0080
QXJ600@0O7al07IfMP1fMWH0L71`0P2HV9P01@2/[:`0K6a/09VIV@2IVIT0UIFE0080Z:RX00D0];Bd
07inOP34a<@0a<C40:b/[0020:>SX`050<G5a@1JFUX0FUYJ0820P01SHf<00P1oOgl0101lO7`0K6a/
06a/K01_Kfl209nOW`050;fm_@2CTi<0R8R808R8R024Q8@00P2=SHd01@2l_;`0/[:b0:NWY`2WYjL0
IVIV0080LG5a00D0^k^k08Z:RP2:RXX0Fe]K08F5Q@0208V9R@0407YjNP2PX:00X:2P0<K6aP80XJ6Q
00D0L71`06a/K02DU9@0U9BD065QH@0208:2PP0507emO@2^[Zh0[Zj^075aL@0f=SH00P0d=3@01@0a
<C40CTi>04i>CP1`L700Lg=c0080K6a/00@0RHV90861P@21PH40NGUi0P2GUiL01@1ZJVX0MGEe05]K
F`1KFe/0N7Qh0080KVi^00D0NGUi0::RXP2RXZ80NWYj0:BTY0020::RXP050820P02WYjL0YjNW0;Bd
]01kNg/00P1LG5`0101BDU80Jf][06][J`1kNg/208V9R@0307IfM_oooooooooo00Sooooo000:oooo
o`<0[Zj^00D0/k>c0;Fe]@2e]KD0F5QH09:BTP0208R8R0040820P02KVi/0Vi^K0:f][@80[jn_00D0
/[:b0;Fe]@2a/K40/K6a0;>c/`020;2`/080/K6a0P1]KFd0101ZJVX0[jn_0:n_[`2[Zj/20:f][@05
0:b/[02XZ:P0YJFU0:FUY@2XZ:P00P2[Zj/01@2^[Zh0/K6a0;Ng]`2g]kL0/k>c0080]KFe00D0FUYJ
07]kN`26QXH0QXJ608F5Q@0208Z:RP0508n?S`2NWYh0WYjN0:2PX02LW9`00P2>SXh308F5Q@0508n?
S`2OWil0Bd];04];B`1kNg/00P2/[:`01@2ZZZX0ZJVY0:VYZ@2VYZH0SHf=0080UYJF00D0WinO07mo
O`1oOgl0OWin06EUI@0206e]K@04065QH@17AdL0AdM708R8R080Ogmo00D0LW9b0:ZZZP2ZZZX0ZZZZ
0:f][@02096AT@03071`L025QHD0];Bd0080];Bd0P2b/[801@2g]kL0IfMW07alO01lO7`0[Jf]0080
/k>c00D0/[:b0:j^[P2^[Zh0/[:b0;6a/@020;2`/0050:j^[P2ZZZX0ZZZZ0:ZZZP2[Zj/00P2CTi<0
101GEeL0QhN708N7Q`2KVi/209nOW`050:2PX02JVYX0VIVI09VIV@2NWYh00P2JVYX01@2;Rh/0QhN7
08b<S02<S8`0Rh^;0080Ogmo00D0IVIV08j>SP2;Rh/0Rh^;08N7Q`0207emO@0507EeM@1jNWX0NWYj
07MgM`1YJFT00P1ZJVX01@1_Kfl0LW9b079bLP1/K6`0H61P0080ADE500@0Jf][05eMG@1MGEd0EEEE
0P1ADE401@1DE5@0EeMG06QXJ01XJ6P0K6a/0080KFe]00<0IVIVooooooooool03oooool01020P800
H61P061PH02:RXX207AdM00508n?S`21PH40PH610;:b/P1[Jf/00P2=SHd01@1iNGT0EEEE05EEE@28
R8P0IFEU0080TI6A00@0DE5A05eMG@1MGEd0I6AT0P24Q8@01@2BTY80KVi^05eMG@1MGEd0FEUI0080
E5AD00D0OGem06YZJP1ZJVX0W9bL09ZJVP0204Y:BP0408>3P`1FEUH0EUIF075aL@80IfMW00D0PH61
0<c<c01mOGd0OGem05eMG@020451@@0307alO02^[Zh0_;bl0080_;bl0P2j^[X01@2JVYX0UIFE09FE
U@2JVYX0XZ:R0080Q8B400@0O7al06m_K`1_Kfl0N7Qh0P2JVYX01@2h^;P0NGUi09jNWP2NWYh0M7Ad
0080_[jn00D0^KVi08>3P`2i^KT0^KVi0:b/[0020:RXZ0050<30`01FEUH0EUIF08:2PP1PH6000P1m
OGd0102<S8`0E5AD05ADE01MGEd209FEU@050<;2`P1nOWh0P8200820P01dM7@00P24Q8@01@33`l<0
^k^k0<S8b038b<P0NGUi0080OWin00D0aLG508>3P`23Ph<0EeMG08^;R`0208J6QP0407YjNP2WYjL0
YjNW0<W9b@80]kNg00D0Kfm_08Z:RP2JVYX0VYZJ075aL@0209JFUP0508f=S@2i^KT0^KVi07emO@12
@T800`0l?3`205=CD`0407UiN@1lO7`0KVi^06i^KP<0Rh^;00<0PX:209FEU@2EUID00P1YJFT207Qh
N00407]kN`2GUiL0UiNG09FEU@80/[:b00D0QhN70:b/[02@T900T92@08R8R00209fMW@050:n_[`1l
O7`0D51@051@D01OGel00P1TI6@0101iNGT0Ph>308>3P`1XJ6P:ooooo`002_ooool30:j^[P050;>c
/`2e]KD0]KFe05QHF02BTY800P28R8P01020P800Vi^K09^KV`2][Jd20:n_[`050;:b/P2e]KD0/K6a
0;6a/@2c/k<00P2`/;020;6a/@80KFe]00@0JVYZ0:n_[`2_[jl0Zj^[0P2][Jd01@2/[:`0Z:RX0:FU
Y@2UYJD0Z:RX0080Zj^[00D0[Zj^0;6a/@2g]kL0]kNg0;>c/`020;Fe]@0505YJFP1kNg/0QXJ608J6
QP25QHD00P2:RXX01@2?Shl0WYjN09jNWP2PX:00W9bL0080SXj>0`25QHD01@2?Shl0WinO04];B`1;
Bd/0Ng]k0080[:b/00D0ZZZZ0:VYZ@2YZJT0YZJV08f=S@0209JFUP0509nOW`1oOgl0Ogmo07inOP1U
IFD00P1]KFd0101QHF40AdM704M7A`28R8P207moO`05079bLP2ZZZX0ZZZZ0:ZZZP2][Jd00P2ATI40
0`1`L700QHF50;Bd]0020;Bd]080/[:b00D0]kNg06MWI`1lO7`0O7al0:f][@020;>c/`050;:b/P2^
[Zh0[Zj^0;:b/P2a/K400P2`/;001@2^[Zh0ZZZZ0:ZZZP2ZZZX0Zj^[0080Ti>C00@0EeMG08N7Q`27
QhL0Vi^K0P2OWil01@2PX:00VYZJ09VIV@2IVIT0WYjN0080VYZJ00D0Rh^;08N7Q`2<S8`0S8b<08^;
R`0207moO`0506IVIP2>SXh0Rh^;08^;R`27QhL00P1mOGd01@1eMGD0NWYj07YjNP1gMgL0JFUY0080
JVYZ00D0Kfm_079bLP1bLW80K6a/061PH00204E5A@0406][J`1MGEd0GEeM05EEE@80DE5A00D0E5AD
05MGE`1XJ6P0J6QX06a/K00206e]K@0306IVI_oooooooooo00oooooo00@0P820061PH01PH600RXZ:
0P1dM7@01@2?Shl0PH610861P@2b/[80Jf][0080SHf=00D0NGUi05EEE@1EEED0R8R806EUI@02096A
T@04055AD@1MGEd0GEeM06ATI080Q8B400D0TY:B06i^KP1MGEd0GEeM05UIF@0205ADE00507emO@1Z
JVX0JVYZ09bLW02JVYX00P1:BTX01023Ph<0EUIF05IFEP1aLG4206MWI`050861P@3<c<`0OGem07em
O@1MGEd00P11@D400`1lO7`0[Zj^0;bl_0020;bl_080^[Zj00D0VYZJ09FEU@2EUID0VYZJ0::RXP02
08B4Q00407alO01_Kfl0Kfm_07QhN080VYZJ00D0^;Rh07UiN@2NWYh0WYjN07AdM0020;jn_P050;Vi
^@23Ph<0^KVi0;Vi^@2/[:`00P2XZ:P01@30`<00EUIF05IFEP22PX80H61P0080OGem00@0S8b<05AD
E01DE5@0GEeM0P2EUID01@32`/80OWin0820P020P800M7Ad0080Q8B400D0`l?30;^k^`38b<P0b<S8
07UiN@0207inOP050<G5a@23Ph<0Ph>305MGE`2;Rh/00P26QXH0101jNWX0YjNW0:NWY`39bLT20;Ng
]`0506m_K`2:RXX0VYZJ09ZJVP1aLG400P2FUYH01@2=SHd0^KVi0;Vi^@1mOGd0@T9200<0?3`l0P1C
De<0101iNGT0O7al06i^KP1^KVh308^;R`0308:2PP2EUID0UIFE0080JFUY0P1hN7P0101kNg/0UiNG
09NGU`2EUID20;:b/P0508N7Q`2/[:`0T92@092@T028R8P00P2MWId01@2_[jl0O7al051@D01@D500
GemO0080I6AT00@0NGUi08>3P`23Ph<0J6QX2_ooool000[ooooo00@0[Zj^0:RXZ02XZ:P0[:b/0P2b
/[801@1BDU80WIfM08b<S02<S8`0T92@0080XJ6Q00D0Y:BT0:FUY@2UYJD0X:2P0:JVYP020:NWY`05
0:JVYP2/[:`0[:b/0:f][@2`/;000P1_Kfl0101ZJVX0ZZZZ0:ZZZP2[Zj/30:b/[0040:ZZZP2TY:@0
Y:BT0:JVYP80YjNW00D0Z:RX0:b/[02_[jl0[jn_0;Jf]P020;>c/`0504a<C02TY:@0W9bL09bLW02E
UID00P2TY:@01@2UYJD0YZJV0:JVYP2WYjL0Y:BT0080VYZJ00D0RHV908:2PP22PX80V9RH0::RXP02
04I6AP040861P@2QXJ40XJ6Q0:n_[`80/k>c00D0ZZZZ09JFUP2FUYH0UYJF09RHV00207AdM00507If
MP1hN7P0Ph>308>3P`22PX800P1FEUH01@2:RXX0S8b<08b<S02<S8`0[:b/0080Zj^[00D0[:b/09BD
U02DU9@0MgMg06m_K`020;6a/@050;Rh^02f][H0][Jf0;Zj^P1QHF400P1iNGT30:f][@030:RXZ02V
YZH0YZJV00@0YjNW00D0ZJVY0:FUY@2UYJD0Zj^[0:b/[0020:NWY`0405mOG`2:RXX0RXZ:0:ZZZP<0
[Jf]00@0[Zj^0;Fe]@2e]KD0^[Zj0P2`/;001@2VYZH0Z:RX0:f][@2][Jd0Zj^[0080[jn_00D0IfMW
0;Zj^P35aLD0aLG50<C4a0020<71`@050;Jf]P32`/80`/;20:NWY`25QHD00P1XJ6P01@2b/[80_[jn
0;jn_P2i^KT0RXZ:0080Shn?00@0^;Rh0;>c/`2c/k<0ZZZZ0P2c/k<01@2g]kL0_;bl0;fm_@2m_Kd0
/k>c0080_;bl00<0^k^kooooooooool03oooool01026QXH0KVi^06i^KP2;Rh/206a/K00507moO`1k
Ng/0Ng]k0:b/[01NGUh00P1`L7001@1ZJVX0@d=304=3@`20P800JVYZ0080P82000@0?Shn05iNGP1N
GUh0E5AD0P1gMgL01@2?Shl0JVYZ065QH@1QHF40FEUI0080AdM700D0NGUi06EUI@1UIFD0U9BD09jN
WP0204Y:BP0408R8R01KFe/0Fe]K08f=S@80O7al00D0Ogmo0=;BdP24Q8@0Q8B405YJFP0203Lg=`05
06ATI02DU9@0YZJV0:JVYP2KVi/00P2/[:`01@2OWil0X:2P0:2PX02MWId0YZJV0080Ph>300@0MGEe
075aL@1aLG40LG5a0P2JVYX01@2VYZH0JVYZ0::RXP2RXZ80MgMg0080/K6a00D0aLG507moO`2g]kL0
]kNg0:^[Z`0209nOW`050;Fe]@1>CTh0CTi>07EeM@1MGEd00P1dM7@0101hN7P0Kfm_06m_K`1UIFD2
09fMW@050;:b/P1kNg/0Ogmo07moO`25QHD00P2IVIT01@2m_Kd0ZJVY0;>c/`2c/k<0MGEe0080MgMg
00D0^[Zj09:BTP2BTY80Hf=S08b<S0020861P@0407EeM@2RXZ80XZ:R0<O7a`80WinO00D0De=C0;Jf
]P2YZJT0ZJVY06e]K@0208n?S`0509:BTP3:b/X0b/[:07moO`15ADD00P0g=cL01@0m?Cd0BTY:04Y:
BP1cLg<0NWYj0080L71`00@0R8R8092@T02@T900O7al0P2GUiL01@1YJFT0MgMg06][J`1[Jf/0Lg=c
0080Ogmo00D0NWYj09JFUP2FUYH0LW9b09ZJVP0208V9R@0508N7Q`2OWil0WinO0;6a/@26QXH00P1A
DE40101WIfL0JFUY06UYJ@21PH4206IVIP0307alO?oooooooooo00Sooooo000:ooooo`030;6a/@2^
[Zh0[Zj^00<0/k>c00D0De=C0:RXZ02GUiL0UiNG09FEU@020:NWY`050:>SX`2VYZH0YZJV0:>SX`2Z
ZZX00P2SXj<01@2UYJD0Y:BT0:BTY02][Jd0/K6a00<0IfMW0P2ZZZX01@2[Zj/0[:b/0:b/[02[Zj/0
Z:RX0080YZJV00@0ZJVY0:JVYP2VYZH0YJFU0`2VYZH01@2^[Zh0Zj^[0:^[Z`13@d<0Z:RX0080XJ6Q
00@0V9RH09^KV`2KVi/0Xj>S0P2WYjL01@2VYZH0X:2P09fMW@2MWId0U9BD0080SXj>00D0X:2P09^K
V`1;Bd/0Bd];0861P@020:6QX@050:n_[`2a/K40/K6a0;2`/02/[:`00P2NWYh01@2KVi/0WinO09nO
W`2DU9@0X:2P0080Y:BT00@0S8b<05=CD`1CDe<0S8b<0P2ATI401@2DU9@0ZJVY0:RXZ02XZ:P0[jn_
0080Shn?00D0MgMg08F5Q@2b/[80/[:b0;Fe]@020;>c/`050;Vi^@1LG5`0MWIf07IfMP2YZJT00P2X
Z:P00`2UYJD0Y:BT0:BTY0020:VYZ@80Z:RX00<0YjNW0:ZZZP2ZZZX00P2][Jd20:BTY00405MGE`2:
RXX0RXZ:0:VYZ@80Zj^[00D0ZJVY0:ZZZP2b/[80/[:b0;Jf]P020;:b/P050:FUY@2`/;00];Bd0;Bd
]02b/[800P2c/k<01@1:BTX0YJFU0<C4a034a<@0aLG50080alO700D0^KVi0;^k^`2k^k/0P82005=C
D`020410@0050:NWY`2n_[h0_[jn0;fm_@2;Rh/00P2:RXX0102i^KT0]kNg0;Ng]`2/[:`20;Jf]P05
0;Zj^P2l_;`0_;bl0;bl_02m_Kd00P31`L400`2n_[koooooooooo`0?ooooo`0407moO`1LG5`0G5aL
0820P080IfMW00D0OWin08f=S@2=SHd0`L7106UYJ@0209>CT`0506IVIP11@D40@D5108F5Q@1MGEd0
0P2>SXh0101:BTX0GemO05mOG`1XJ6P206YZJP0508>3P`1nOWh0GUiN05iNGP1HF5P00P15ADD01@1W
IfL0Kfm_06m_K`2NWYh0VIVI0080BDU900@0Ph>3061PH01PH600QXJ60P1eMGD01@20P800e=CD08b<
S02<S8`0I6AT0080@D5100D0QXJ60<71`@3:b/X0b/[:0:n_[`020;Jf]P0509ZJVP2HV9P0V9RH09nO
W`2CTi<00P1gMgL0101dM7@0I6AT06ATI01dM7@209ZJVP050;2`/01NGUh0SXj>08j>SP2ATI400P2Y
ZJT01@39bLT0Ogmo0:j^[P2^[Zh0/;2`0080Vi^K00D0/[:b04];B`1;Bd/0MWIf061PH00207alO004
07moO`1MGEd0GEeM06][J`80TY:B00<0_kno07alO023Ph<00P23Ph<209NGU`050<71`@2a/K40`<30
0<30`01gMgL00P1nOWh01@2h^;P0QhN708N7Q`1PH600SXj>0080JVYZ00@0MGEe09bLW02LW9`0alO7
0P2XZ:P01@1SHf<0P8200:2PX02PX:00Hf=S0080PX:200D0Rh^;0<;2`P32`/80O7al04A4A00203hn
?P<0@T9200D0KVi^07alO01_Kfl0Kfm_06a/K00208F5Q@0506m_K`2=SHd0SHf=06EUI@1WIfL00P1S
Hf<0101iNGT0M7Ad07AdM023Ph<20;^k^`0508J6QP2o_kl0PH610861P@2;Rh/00P2UYJD01@2^[Zh0
OWin055AD@1ADE40JFUY0080L71`00@0QXJ608j>SP2>SXh0OGem2_ooool000[ooooo00@0ZJVY0:b/
[02/[:`0Y:BT0P2FUYH0101BDU80P82008B4Q024Q8@308N7Q`0508b<S02@T900T92@096AT@2HV9P0
0P2BTY801@2=SHd0VYZJ09ZJVP2OWil0XJ6Q0080JFUY00@0FUYJ08R8R028R8P0Rh^;0P2JVYX01@2N
WYh0S8b<09>CT`2CTi<0SHf=0080U9BD00D0SHf=08j>SP2?Shl0Shn?09^KV`0209BDU00504I6AP2X
Z:P0YjNW0:NWY`2IVIT00P2PX:001@2MWId0XJ6Q0:6QX@2QXJ40V9RH0080VYZJ00D0TY:B08^;R`2;
Rh/0UiNG09^KV`0204E5A@0407UiN@2UYJD0YJFU09nOW`80WIfM00D0/K6a0;>c/`2][Jd0[Jf]0:^[
Z`020:VYZ@050:b/[02ZZZX0Zj^[0:^[Z`27QhL00P1@D5001@28R8P0Vi^K09^KV`2OWil0ZZZZ0080
Zj^[00D0/k>c09ZJVP2JVYX0OWin0861P@020;Jf]P050;Vi^@2j^[X0^[Zj0;Vi^@1QHF400P1oOgl0
102_[jl0[:b/0:b/[02SXj<20::RXP80WinO0P2SXj<01@2VYZH0YjNW0:NWY`2/[:`0YZJV0080XZ:R
00@0JVYZ09JFUP2FUYH0Z:RX0P2VYZH01@2QXJ40WinO0:FUY@2UYJD0[Zj^0080/;2`00D0WIfM0:2P
X02/[:`0[:b/0:f][@020:^[Z`050410@02HV9P0_kno0;no_`2n_[h00P2b/[801@2ZZZX0Y:BT0:BT
Y01QHF40=cLg0080A4A400D0WIfM0;:b/P2b/[80/;2`075aL@0208^;R`040;Zj^P2e]KD0]KFe0:f]
[@80][Jf00D0^[Zj0;no_`2m_Kd0_Kfm0;Zj^P020;bl_0030;fm_Ooooooooooo00oooooo00@0RHV9
07IfMP1fMWH0V9RH0P1]KFd01@22PX80Ogmo07moO`2`/;00I6AT0080Lg=c00D0K6a/04Y:BP1:BTX0
SHf=069RHP0209FEU@04051@D01MGEd0GEeM07QhN080S8b<00D0Ti>C06e]K@1DE5@0E5AD04i>CP02
059BDP0506EUI@1cLg<0Lg=c09jNWP2OWil00P1@D5001022PX80GemO05mOG`1lO7`206m_K`0507al
O036a/H0OWin07inOP1KFe/00P0n?Sh01@1gMgL0][Jf0<K6aP36a/H0]KFe0080]kNg00D0Y:BT09RH
V02HV9P0Vi^K08B4Q00307AdM080MGEe00D0TI6A0:j^[P2^[Zh0a/K607MgM`0209ZJVP0509VIV@2X
Z:P0Z:RX0<[:bP22PX800P2g]kL0102n_[h0XJ6Q0:6QX@2a/K4204i>CP0508B4Q01WIfL0PX:208:2
PP23Ph<00`1SHf<209:BTP050;no_`26QXH0OWin07inOP1fMWH00P20P8001@2^[Zh0`L710;6a/@2a
/K40NWYj0080Ng]k00D0ZJVY08R8R028R8P0GEeM08B4Q002075aL@04071`L02ATI40TI6A0;bl_080
/;2`00D0Lg=c0820P02EUID0UIFE06IVIP0207YjNP0508Z:RP34a<@0a<C40861P@1:BTX00P0j>SX3
03lo?`0506UYJ@1bLW80MWIf07IfMP26QXH00P2:RXX01@1`L700S8b<08b<S01WIfL0G5aL0080GemO
00@0Ph>309RHV02HV9P0TI6A0P35aLD01@1lO7`0^k^k07=cL`1cLg<0P8200080TY:B00D0Shn?06MW
I`1ADE40DE5A059BDP0206e]K@0409FEU@2DU9@0U9BD07UiN@[ooooo000:ooooo`040:VYZ@2/[:`0
[:b/0:BTY080UYJF00@0DU9B0820P024Q8@0Q8B40`27QhL01@2<S8`0T92@092@T02ATI40V9RH0080
TY:B00D0SHf=09ZJVP2JVYX0WinO0:6QX@0206UYJ@0405YJFP28R8P0R8R808^;R`80VYZJ00D0WYjN
08b<S02CTi<0Ti>C08f=S@0209BDU00508f=S@2>SXh0Shn?08n?S`2KVi/00P2DU9@01@16ATH0Z:RX
0:NWY`2WYjL0VIVI0080X:2P00D0WIfM0:6QX@2QXJ40XJ6Q09RHV00209ZJVP0509:BTP2;Rh/0Rh^;
09NGU`2KVi/00P15ADD0101iNGT0YJFU0:FUY@2OWil209fMW@050;6a/@2c/k<0[Jf]0:f][@2[Zj/0
0P2YZJT01@2/[:`0ZZZZ0:^[Z`2[Zj/0QhN70080D51@00D0R8R809^KV`2KVi/0WinO0:ZZZP020:^[
Z`050;>c/`2JVYX0VYZJ07inOP21PH400P2f][H01@2i^KT0^[Zj0;Zj^P2i^KT0HF5Q0080Ogmo00@0
[jn_0:b/[02/[:`0Xj>S0P2RXZ8209nOW`80Xj>S00D0YZJV0:NWY`2WYjL0[:b/0:JVYP020::RXP04
06YZJP2FUYH0UYJF0:RXZ080YZJV00D0XJ6Q09nOW`2UYJD0YJFU0:j^[P020;2`/00509fMW@2PX:00
[:b/0:b/[02][Jd00P2[Zj/01@10@400V9RH0;no_`2o_kl0_[jn0080/[:b00D0ZZZZ0:BTY02TY:@0
HF5Q03Lg=`0204A4A00509fMW@2b/[80/[:b0;2`/01aLG400P2;Rh/0102j^[X0]KFe0;Fe]@2][Jd2
0;Jf]P050;Zj^P2o_kl0_Kfm0;fm_@2j^[X00P2l_;`00`2m_Kgoooooooooo`0?ooooo`0408V9R@1f
MWH0MWIf09RHV080KFe]00D0PX:207moO`1oOgl0/;2`06ATI00207=cL`0506a/K01:BTX0BTY:08f=
S@1RHV800P2EUID0101@D500GEeM05eMG@1hN7P208b<S00509>CT`1]KFd0E5AD05ADE01>CTh00P1B
DU801@1UIFD0Lg=c07=cL`2NWYh0WinO0080D51@00@0PX:205mOG`1OGel0O7al0P1_Kfl01@1lO7`0
a/K607inOP1nOWh0Fe]K0080?Shn00D0MgMg0;Jf]P36a/H0a/K60;Fe]@020;Ng]`050:BTY02HV9P0
V9RH09^KV`24Q8@00`1dM7@207EeM@05096AT@2^[Zh0[Zj^0<K6aP1gMgL00P2JVYX01@2IVIT0Z:RX
0:RXZ03:b/X0PX:20080]kNg00@0_[jn0:6QX@2QXJ40/K6a0P1>CTh01@24Q8@0IfMW08:2PP22PX80
Ph>300<0Hf=S0P2BTY801@2o_kl0QXJ607inOP1nOWh0MWIf0080P82000D0[Zj^0<71`@2a/K40/K6a
07YjNP0207]kN`050:VYZ@28R8P0R8R805eMG@24Q8@00P1aLG40101`L700TI6A096AT@2l_;`20;2`
/00507=cL`20P800UIFE09FEU@1VIVH00P1jNWX01@2:RXX0a<C40<C4a021PH40BTY:0080>SXj0`0o
?cl01@1YJFT0LW9b07IfMP1fMWH0QXJ60080RXZ:00D0L71`08b<S02<S8`0IfMW05aLG00205mOG`04
08>3P`2HV9P0V9RH096AT@80aLG500D0O7al0;^k^`1cLg<0Lg=c0820P00209:BTP0508n?S`1WIfL0
DE5A055AD@1BDU800P1]KFd0102EUID0U9BD09BDU01iNGT:ooooo`002_ooool0102JVYX0UiNG09NG
U`2CTi<208n?S`0508f=S@27QhL0OGem07emO@1hN7P00P1iNGT01@1XJ6P0=CDe03De=@1VIVH0J6QX
0080MGEe00D0OWin07UiN@1iNGT0NWYj07MgM`0207alO00406EUI@1iNGT0NGUi07inOP80LG5a00D0
F5QH03lo?`1DE5@0E5AD07=cL`0207IfMP0407=cL`1eMGD0N7Qh07QhN0<0Kfm_00D0KVi^06m_K`1R
HV80HV9R05MGE`0205ADE0050410@01NGUh0GUiN07moO`1lO7`00P1iNGT30861P@0508N7Q`1mOGd0
MWIf07IfMP1kNg/00P1lO7`01@1RHV80EeMG05MGE`1CDe<0CTi>0080CDe=00D0C4a<055AD@1ADE40
DE5A05EEE@0205]KF`0404e=C@14A4@0A4A404a<C0<0H61P00@0JFUY05iNGP1NGUh0F5QH0P16ATH0
1@19BDT0EEEE06QXJ01XJ6P0N7Qh0080MGEe00D0N7Qh051@D01>CTh0CTi>07QhN00207UiN@0506UY
J@1WIfL0IfMW06EUI@1jNWX00P1lO7`01@22PX80R8R808R8R01]KFd0Lg=c0080PX:200@0BDU907Yj
NP1jNWX0S8b<0P25QHD01@1eMGD0Q8B408n?S`2?Shl0V9RH0080WIfM00D0W9bL08f=S@2GUiL0UiNG
09fMW@0209nOW`0503Ph>024Q8@0YZJV0:JVYP2KVi/00P1nOWh01@20P800NGUi07UiN@1EEED0BTY:
0080Jf][00D0NGUi08b<S02<S8`0UYJF07=cL`0208f=S@040:n_[`2b/[80/[:b0:b/[080/k>c0P2k
^k/20;Vi^@040;Rh^02m_Kd0_Kfm0;Bd]17ooooo00@0Ng]k05iNGP1NGUh0P8200P1CDe<01@27QhL0
S8b<08b<S02j^[X0MgMg0080PX:200D0LW9b04m?C`1?Cdl0Ti>C05mOG`0209bLW00404e=C@1JFUX0
FUYJ07]kN`80OWin00D0TY:B07EeM@1LG5`0G5aL04a<C00204M7A`0506=SH`1_Kfl0Kfm_09BDU02L
W9`00P15ADD0101oOgl0CDe=04e=C@1aLG420861P@0508>3P`3Fe]H0QhN708N7Q`1OGel00P12@T80
1@1[Jf/0UiNG0:RXZ02XZ:P0Xj>S0080XZ:R00D0Rh^;096AT@2ATI40TI6A0820P0020861P@0406MW
I`1YJFT0JFUY08>3P`80V9RH00<0YJFU07QhN02HV9P00P2HV9P20:ZZZP050;no_`1jNWX0Zj^[0:^[
Z`2d];@00P2NWYh01@2o_kl0=cLg03Lg=`1aLG40Hf=S0080Ph>300@0QHF506UYJ@1YJFT0Hf=S0P2X
Z:P01@34a<@0VYZJ07UiN@1iNGT0P8200080Ogmo00D0/;2`0;Jf]P2e]KD0]KFe092@T00208B4Q005
09^KV`2;Rh/0Rh^;07YjNP29RHT00P1hN7P0101aLG40UYJF09JFUP3:b/X20:f][@0506ATI01kNg/0
UiNG09NGU`1OGel00P1JFUX01@1gMgL0aLG50<G5a@1nOWh0ATI60080>3Ph00D0>CTi03dm?@0m?Cd0
FUYJ04m?C`0205]KF`0405iNGP1lO7`0O7al061PH080TI6A00D0I6AT06UYJ@1UIFD0IFEU07IfMP02
0820P00506UYJ@2FUYH0UYJF06e]K@2g]kL00P1cLg<01@2BTY80WIfM09fMW@2BTY80MgMg0080Bd];
00@0C4a<06EUI@1UIFD0NWYj0P27QhL00`23Ph?oooooooooo`08ooooo`002_ooool00`2k^k/0]kNg
0;Ng]`030;Zj^P050;Ng]`2e]KD0/[:b0;:b/P2_[jl00P2YZJT01@2/[:`0CTi>04i>CP2LW9`0XJ6Q
0080WinO00D0Xj>S0:FUY@2UYJD0Zj^[0:RXZ0020:f][@040;6a/@2d];@0];Bd0;>c/`80[:b/00D0
XJ6Q061PH02QXJ40XJ6Q0:n_[`020:j^[P030:f][@2e]KD0];Bd0080];Bd0P2k^k/01@2i^KT0_;bl
0;no_`2o_kl0`<300080^[Zj00D0IFEU0:f][@2][Jd0[jn_0:VYZ@030:JVYP80YJFU00D0ZZZZ0:f]
[@2][Jd0[Jf]0:j^[P020;6a/@<0/k>c00D0Jf][08j>SP2b/[80/[:b0;2`/0020:NWY`050:BTY02d
];@0]kNg0;Ng]`2d];@00P2h^;P01@2f][H0/K6a0;6a/@2_[jl0YJFU0080IfMW00D0RHV909NGU`2G
UiL0W9bL09ZJVP0209NGU`0509JFUP2EUID0UIFE09JFUP2NWYh00P2XZ:P0102YZJT0VYZJ09ZJVP23
Ph<205YJFP0507]kN`23Ph<0MgMg07MgM`1dM7@00P1aLG401@1iNGT0OWin07inOP1nOWh0R8R80080
N7Qh00D0JFUY06EUI@1UIFD0?clo04U9B@0206EUI@<0JVYZ00D0FUYJ05]KF`1RHV80HV9R065QH@02
05mOG`0506ATI01OGel0K6a/06a/K01ZJVX00P14A4@01@1QHF40J6QX06QXJ01RHV80I6AT0080IFEU
00D0G5aL05mOG`1OGel0Fe]K05MGE`0204];B`0403Ti>@0k>c/0>c/k03/k>`80>SXj00D0?Shn04a<
C017AdL0AdM704m?C`0204Y:BP0304];Booooooooooo00oooooo00@0OGem06ATI01TI6@0Shn?0P1O
Gel01@26QXH0Kfm_06m_K`1jNWX0MGEe0080LW9b00D0IFEU04=3@`13@d<0Ogmo061PH00209ZJVP04
04a<C01FEUH0EUIF08j>SP80QHF500D0SXj>06ATI01;Bd/0Bd];04I6AP0204Y:BP0505mOG`1hN7P0
N7Qh09VIV@2MWId00P19BDT01029RHT0FEUI05UIF@1]KFd207=cL`0506e]K@2k^k/0Ng]k07]kN`1D
E5@00P0m?Cd01@1[Jf/0W9bL0:b/[02/[:`0Xj>S0080/;2`00D0Vi^K09fMW@2MWId0UiNG08j>SP02
08Z:RP0406][J`1`L700L71`07]kN`80VIVI00D0`/;20820P02KVi/0Vi^K092@T0020:VYZ@050<30
`023Ph<0YZJV0:JVYP2LW9`00P2HV9P01@2j^[X0>CTi03Ti>@1UIFD0CTi>0080IfMW00@0IFEU05iN
GP1NGUh0IFEU0P2DU9@01@2ZZZX0SHf=05aLG01LG5`0Kfm_0080OWin00D0YjNW0<;2`P2d];@0];Bd
08B4Q00207emO@0409ZJVP2NWYh0WYjN08f=S@<0Ng]k00@0Hf=S08f=S@2=SHd0][Jf0P2TY:@01@1H
F5P0Shn?08B4Q024Q8@0MGEe0080Fe]K00D0L71`0;Fe]@2e]KD0Ti>C04a<C00203Xj>P0503Ph>01?
Cdl0Cdm?06=SH`1/K6`00P1ZJVX0101fMWH0LW9b079bLP1PH602079bLP0505eMG@1>CTh0G5aL05aL
G01lO7`00P28R8P01@26QXH0Zj^[0:^[Z`2BTY80clo?0080KFe]00D0QhN708b<S02<S8`0O7al06MW
I`02051@D00405eMG@1OGel0GemO06EUI@<0L71`2_ooool000[ooooo00<0^k^k0;Ng]`2g]kL00`2j
^[X01@2g]kL0]KFe0;:b/P2b/[80[jn_0080ZJVY00D0[:b/04i>CP1>CTh0W9bL0:6QX@0209nOW`05
0:>SX`2UYJD0YJFU0:^[Z`2XZ:P00P2][Jd0102a/K40];Bd0;Bd]02c/k<20:b/[0050:6QX@1PH600
XJ6Q0:6QX@2_[jl00P2^[Zh00`2][Jd0]KFe0;Bd]0020;Bd]080^k^k00D0^KVi0;bl_02o_kl0_kno
0<30`0020;Zj^P0506EUI@2][Jd0[Jf]0:n_[`2YZJT00`2VYZH20:FUY@050:ZZZP2][Jd0[Jf]0:f]
[@2^[Zh00P2a/K430;>c/`0506][J`2>SXh0/[:b0;:b/P2`/;000P2WYjL01@2TY:@0];Bd0;Ng]`2g
]kL0];Bd0080^;Rh00D0][Jf0;6a/@2a/K40[jn_0:FUY@0206MWI`0508V9R@2GUiL0UiNG09bLW02J
VYX00P2GUiL01@2FUYH0UIFE09FEU@2FUYH0WYjN0080Z:RX00@0ZJVY09ZJVP2JVYX0Ph>30P1JFUX0
1@1kNg/0Ph>307MgM`1gMgL0M7Ad0080LG5a00D0NGUi07inOP1nOWh0OWin08R8R00207QhN00506UY
J@1UIFD0IFEU03lo?`19BDT00P1UIFD306YZJP0505YJFP1KFe/0HV9R069RHP1QHF400P1OGel01@1T
I6@0GemO06a/K01/K6`0JVYZ0080A4A400D0HF5Q06QXJ01XJ6P0HV9R06ATI00206EUI@0505aLG01O
Gel0GemO05]KF`1GEeL00P1;Bd/0100i>CT0>c/k03/k>`0k>c/203Xj>P0503hn?P1<C4`0AdM704M7
A`1?Cdl00P1:BTX00`1;Bd_oooooooooo`0?ooooo`0407emO@1TI6@0I6AT08n?S`80GemO00D0QXJ6
06m_K`1_Kfl0NWYj07EeM@02079bLP0506EUI@13@d<0@d=307moO`1PH6000P2JVYX0101<C4`0EUIF
05IFEP2>SXh208F5Q@0508j>SP1TI6@0Bd];04];B`16ATH00P1:BTX01@1OGel0N7Qh07QhN02IVIT0
WIfM0080BDU900@0RHV905UIF@1IFET0KFe]0P1cLg<01@1]KFd0^k^k07]kN`1kNg/0E5AD0080?Cdm
00D0Jf][09bLW02/[:`0[:b/0:>SX`020;2`/00509^KV`2MWId0WIfM09NGU`2>SXh00P2:RXX0101[
Jf/0L71`071`L01kNg/209VIV@050<;2`P20P800Vi^K09^KV`2@T9000P2YZJT01@30`<00Ph>30:JV
YP2VYZH0W9bL0080V9RH00D0^[Zj03Ti>@0i>CT0IFEU04i>CP0206MWI`0406EUI@1NGUh0GUiN06EU
I@80U9BD00D0ZZZZ08f=S@1LG5`0G5aL06m_K`0207inOP050:NWY`32`/80];Bd0;Bd]024Q8@00P1m
OGd0102JVYX0WYjN09jNWP2=SHd307]kN`0406=SH`2=SHd0SHf=0;Jf]P80Y:BT00D0F5QH08n?S`24
Q8@0Q8B407EeM@0205]KF`05071`L02e]KD0]KFe09>CT`1<C4`00P0j>SX01@0h>3P0Cdm?04m?C`1S
Hf<0K6a/0080JVYZ00@0MWIf079bLP1bLW80H61P0P1bLW801@1MGEd0CTi>05aLG01LG5`0O7al0080
R8R800D0QXJ60:^[Z`2[Zj/0TY:B0<o?c`0206e]K@0508N7Q`2<S8`0S8b<07alO01WIfL00P1@D500
101MGEd0GemO05mOG`1UIFD3071`L0[ooooo000:ooooo`040;Ng]`2`/;00/;2`0;>c/`80/;2`00D0
[jn_0:b/[02YZJT0ZJVY0:b/[0020:^[Z`040:b/[01@D500D51@0::RXP<0YJFU00D0WIfM09RHV02H
V9P0T92@09fMW@020:RXZ0040:ZZZP2_[jl0[jn_0:j^[P80ZJVY00D0YjNW05aLG02TY:@0Y:BT0:^[
Z`020:b/[0030:VYZ@2[Zj/0ZJVY0080ZJVY0P2WYjL01@2YZJT0/K6a0;Ng]`2g]kL0^k^k0080_kno
00D0MWIf0:NWY`2WYjL0[Jf]0:BTY00209^KV`0509fMW@2RXZ80XZ:R0:6QX@2YZJT00`2^[Zh20:f]
[@050;2`/02^[Zh0[Zj^07]kN`2<S8`00P2ZZZX01@2WYjL0YZJV0:JVYP2UYJD0[:b/0080[Zj^102`
/;020:b/[080ZZZZ0P28R8P01@2f][H0^k^k0;^k^`32`/80_;bl0080^k^k00@0_[jn0<;2`P32`/80
_kno0`31`L401035aLD0_[jn0;jn_P2e]KD208V9R@050;Rh^02j^[X0^;Rh0;Rh^02d];@00P2_[jl0
0`2f][H0]kNg0;>c/`020;>c/`80];Bd00D0][Jf0;>c/`2c/k<0GemO08V9R@020;Zj^P<0_;bl00D0
^[Zj0;Rh^02b/[80/[:b0;Bd]0020;Rh^0050;Bd]02j^[X0`<300<30`02l_;`00P1YJFT01@2_[jl0
]kNg0;Ng]`2a/K40[:b/0080[jn_0`2d];@01@2g]kL0];Bd0:RXZ02XZ:P0ZJVY0080[Jf]00D0UYJF
06ATI01TI6@0X:2P0:j^[P020;>c/`040:n_[`2TY:@0Y:BT0:2PX17ooooo00@0PX:2075aL@1aLG40
Shn?0P1BDU801@1fMWH0Lg=c07=cL`2>SXh0J6QX0080LG5a00D0IfMW04E5A@15ADD0N7Qh05]KF`02
08j>SP0404U9B@1BDU80DU9B09JFUP80PX:200D0VIVI071`L01PH600H61P05MGE`0205eMG@0506AT
I01aLG40LG5a08b<S02KVi/00P0o?cl01025QHD0Cdm?04m?C`1WIfL207AdM00507YjNP3;bl/0Rh^;
08^;R`1[Jf/00P16ATH01@1mOGd0^;Rh0;^k^`2k^k/0[Jf]0080ZZZZ00D0Rh^;09NGU`2GUiL0UYJF
08J6QP0208F5Q@04069RHP1aLG40LG5a07YjNP80Vi^K00D0bl_;07MgM`2IVIT0VIVI08N7Q`020:JV
YP050;^k^`2KVi/0Zj^[0:^[Z`2c/k<00P2NWYh01@33`l<0@D510451@@20P800LG5a0080RHV900@0
Ph>305eMG@1MGEd0Fe]K0P2g]kL01@2e]KD0RHV905eMG@1MGEd0HF5Q0080R8R800D0[:b/0=?Cd`2_
[jl0[jn_08N7Q`0207MgM`0508b<S02KVi/0Vi^K0:>SX`1`L7000P1PH600101JFUX0Lg=c07=cL`2a
/K4209fMW@0506=SH`2KVi/0X:2P0:2PX01iNGT00P1HF5P01@1fMWH0`l?30<?3``2YZJT0EEEE0080
BDU900D0>CTi05MGE`1GEeL0Ng]k071`L00207UiN@0406m_K`1dM7@0M7Ad06i^KP80L71`00D0NGUi
06=SH`1gMgL0MgMg06i^KP0207moO`0509ZJVP2KVi/0Vi^K092@T02[Zj/00P18B4P01@1hN7P0UIFE
09FEU@2FUYH0PH610080IVIV00@0FEUI06YZJP1ZJVX0JFUY0P2;Rh/00`24Q8Coooooooooo`08oooo
o`002_ooool0102a/K40[jn_0:n_[`2_[jl20:ZZZP80ZJVY0P2VYZH0102[Zj/0[Jf]0:f][@2_[jl2
061PH00508j>SP29RHT0VYZJ09ZJVP2LW9`00P2QXJ4209nOW`80[:b/00@0[Jf]0:b/[02/[:`0Zj^[
0P2ZZZX01@2/[:`0LW9b0;>c/`2c/k<0ZZZZ0080Z:RX00D0YjNW0:RXZ02ZZZX0ZZZZ0:RXZ0020:^[
Z`050:VYZ@2][Jd0];Bd0;Bd]02k^k/00P2j^[X01@1hN7P0/k>c0;>c/`2^[Zh0WIfM0080VYZJ00D0
UIFE0:JVYP2VYZH0X:2P0:BTY0020::RXP040:FUY@2[Zj/0Zj^[0:n_[`80[Jf]00D0Lg=c0861P@2K
Vi/0Vi^K09JFUP0209NGU`0509nOW`2XZ:P0YjNW0:NWY`2ZZZX00P2YZJT01@2^[Zh0Zj^[0:^[Z`2W
YjL0WIfM0080Rh^;00D0]KFe0;Rh^02h^;P0_;bl0;^k^`020;Ng]`050;Fe]@2o_kl0_kno0<K6aP2m
_Kd00P2o_kl01037alL0`l?30<?3``2e]KD207YjNP050;Fe]@2g]kL0^;Rh0;Rh^02e]KD00P2a/K40
1@2k^k/0^;Rh0;Fe]@2e]KD0/[:b0080Zj^[00D0[:b/0:f][@2][Jd0FUYJ07emO@020;Rh^0030;bl
_02j^[X0^[Zj0080^KVi1@2d];@01@2h^;P0^KVi0;^k^`2k^k/0^KVi0080I6AT00D0Vi^K0;>c/`2c
/k<0[:b/0:VYZ@020:n_[`050;>c/`2b/[80/[:b0;2`/02_[jl00P2ZZZX0102][Jd0[Zj^0:j^[P2@
T90206ATI0050:^[Z`2d];@0/[:b0;:b/P2c/k<00P2[Zj/00`2a/K7oooooooooo`0?ooooo`0408B4
Q01bLW80LW9b09FEU@80GemO00D0OGem07MgM`1gMgL0RXZ:059BDP0206IVIP05069RHP17AdL0AdM7
07AdM01WIfL00P2@T90304Q8B00508^;R`1jNWX0NWYj09:BTP1XJ6P00P1EEED01018B4P0Bd];04];
B`1?Cdl207emO@0509JFUP2<S8`0@d=304=3@`1kNg/00P1ADE401@1RHV80J6QX06QXJ01mOGd0a/K6
0080TI6A00D0GEeM03hn?P0n?Sh0LW9b0;Rh^0020;Jf]P040:BTY02c/k<0/k>c09^KV`80T92@00D0
V9RH08f=S@1kNg/0Ng]k05ADE00206IVIP0507EeM@2;Rh/0Rh^;0:JVYP1SHf<00P27QhL01@29RHT0
];Bd0;Bd]031`L40X:2P0080ZZZZ00@0`<300:j^[P2^[Zh0/;2`0P0o?cl01@1bLW80G5aL06ATI01T
I6@0Lg=c0080KFe]00D0CTi>09^KV`2KVi/0^;Rh0:RXZ00207AdM00505mOG`2<S8`0S8b<0;Ng]`38
b<P00P2a/K40102<S8`0LW9b079bLP2ATI420;6a/@0509^KV`1ZJVX0Kfm_06m_K`1SHf<00P2HV9P0
1@37alL0X:2P0:2PX01hN7P0U9BD0080UYJF00@0SHf=06MWI`1WIfL0Lg=c0P36a/H01@2`/;00Fe]K
04I6AP16ATH0?3`l0080CDe=00D0MgMg06a/K01jNWX0NWYj05YJFP0206QXJ00505mOG`1WIfL0IfMW
08Z:RP1SHf<00P1XJ6P0101cLg<0Rh^;08^;R`2HV9P208N7Q`0508b<S02/[:`0D51@051@D02>SXh0
0P2PX:001@2GUiL0OWin07alO01lO7`0K6a/0080I6AT00@0Jf][07]kN`1kNg/0LW9b2_ooool000[o
oooo00@0/k>c0;6a/@2a/K40/K6a0P2f][H01@2`/;00WinO0:6QX@2QXJ40Xj>S00<0ZJVY0P1GEeL0
1026QXH0V9RH0:RXZ02XZ:P30;6a/@050:j^[P2XZ:P0[:b/0:b/[02a/K400P2c/k<01@2i^KT0][Jf
0;Jf]P2b/[80L71`0080XZ:R0`2XZ:P01@2WYjL0ZZZZ0:f][@2][Jd0ZZZZ0080/k>c00D0/;2`0;Fe
]@2g]kL0]kNg0;bl_0020;^k^`0507alO02i^KT0^KVi0;Fe]@2`/;000P2^[Zh01@2YZJT0XZ:R0::R
XP2FUYH0X:2P0080Zj^[00@0/;2`0;Jf]P2f][H0]KFe0P2c/k<01@1SHf<0NWYj08j>SP2>SXh0Rh^;
0080Shn?00D0U9BD0:6QX@2IVIT0VIVI09fMW@030::RXP80Z:RX00D0WYjN07alO021PH40PH610;6a
/@020;Bd]0050;Jf]P2g]kL0^KVi0;Vi^@2j^[X00`2m_Kd0102g]kL0^;Rh0;Rh^02n_[h20;^k^`05
0;6a/@23Ph<0Ph>30;>c/`2a/K400P2f][H01@2i^KT0]kNg0;Ng]`2b/[80/K6a0080[Jf]00@0[:b/
0:^[Z`2[Zj/0YZJV0P2SXj<01@1GEeL0Rh^;0;Bd]02d];@0]kNg0080^KVi00D0^;Rh0;Jf]P2a/K40
/K6a0;>c/`020;:b/P050;6a/@2g]kL0^KVi0;Vi^@2d];@00P1FEUH01@2DU9@0[jn_0:n_[`2XZ:P0
YjNW0080[Jf]00D0/K6a0;2`/02`/;00[Zj^0:f][@020:ZZZP040:b/[02[Zj/0Zj^[08j>SP80MgMg
00D0ZZZZ0;Ng]`2d];@0];Bd0;>c/`020:VYZ@030:n_[ooooooooooo00oooooo00@0MWIf06YZJP1Z
JVX0Ph>30P1HF5P01@24Q8@0PH610861P@2BTY80HF5Q0080LG5a00D0Fe]K04=3@`13@d<0Jf][06UY
J@0207emO@<0B4Q800D0T92@075aL@1aLG40RXZ:075aL@0206=SH`0404U9B@1QHF40HF5Q05iNGP80
PX:200D0VYZJ09FEU@1<C4`0C4a<07moO`0205ADE00506][J`1SHf<0Hf=S08N7Q`2k^k/00P27QhL0
101HF5P0=3@d03@d=01WIfL30:JVYP040:>SX`2][Jd0[Jf]0:6QX@80UYJF00D0VYZJ08^;R`1[Jf/0
Jf][05=CD`0206e]K@0507UiN@2DU9@0U9BD0;^k^`1TI6@00P2?Shl01@28R8P0/k>c0;>c/`37alL0
YZJV0080Vi^K00@0^;Rh0;Vi^@2i^KT0a<C40P1?Cdl01@2ATI40Ng]k07AdM01dM7@0NGUi0080Lg=c
00D0K6a/08^;R`2;Rh/0[jn_09nOW`0207inOP0505QHF02=SHd0SHf=0:j^[P3Jf]X00P2l_;`0101`
L700IFEU06EUI@2KVi/20;jn_P0509VIV@1[Jf/0LG5a075aL@1cLg<00P2XZ:P01@32`/80Zj^[0:^[
Z`1iNGT0Z:RX0080YZJV00@0VYZJ06UYJ@1YJFT0N7Qh0P2b/[801@2f][H0DU9B03hn?P0n?Sh0BTY:
0080ATI600D0PH6107=cL`1_Kfl0Kfm_06MWI`0207=cL`0506EUI@1RHV80HV9R07UiN@1ZJVX00P1E
EED0101SHf<0LW9b079bLP1nOWh208f=S@0509jNWP2YZJT0BTY:04Y:BP28R8P00P2=SHd01@24Q8@0
MgMg069RHP1RHV80FUYJ0080MGEe00@0IfMW08N7Q`27QhL0NWYj2_ooool000[ooooo00@0/k>c0;6a
/@2a/K40/K6a0P2f][H01@2`/;00WinO0:6QX@2QXJ40Xj>S00<0ZJVY0P1GEeL01026QXH0V9RH0:RX
Z02XZ:P30;6a/@050:j^[P2XZ:P0[:b/0:b/[02a/K400P2c/k<01@2i^KT0][Jf0;Jf]P2b/[80L71`
0080XZ:R0`2XZ:P01@2WYjL0ZZZZ0:f][@2][Jd0ZZZZ0080/k>c00D0/;2`0;Fe]@2g]kL0]kNg0;bl
_0020;^k^`0507alO02i^KT0^KVi0;Fe]@2`/;000P2^[Zh01@2YZJT0XZ:R0::RXP2FUYH0X:2P0080
Zj^[00@0/;2`0;Jf]P2f][H0]KFe0P2c/k<01@1SHf<0NWYj08j>SP2>SXh0Rh^;0080Shn?00D0U9BD
0:6QX@2IVIT0VIVI09fMW@030::RXP80Z:RX00D0WYjN07alO021PH40PH610;6a/@020;Bd]0050;Jf
]P2g]kL0^KVi0;Vi^@2j^[X00`2m_Kd0102g]kL0^;Rh0;Rh^02n_[h20;^k^`050;6a/@23Ph<0Ph>3
0;>c/`2a/K400P2f][H01@2i^KT0]kNg0;Ng]`2b/[80/K6a0080[Jf]00@0[:b/0:^[Z`2[Zj/0YZJV
0P2SXj<01@1GEeL0Rh^;0;Bd]02d];@0]kNg0080^KVi00D0^;Rh0;Jf]P2a/K40/K6a0;>c/`020;:b
/P050;6a/@2g]kL0^KVi0;Vi^@2d];@00P1FEUH01@2DU9@0[jn_0:n_[`2XZ:P0YjNW0080[Jf]00D0
/K6a0;2`/02`/;00[Zj^0:f][@020:ZZZP040:b/[02[Zj/0Zj^[08j>SP80MgMg00D0ZZZZ0;Ng]`2d
];@0];Bd0;>c/`020:VYZ@030:n_[ooooooooooo00oooooo00@0MWIf06YZJP1ZJVX0Ph>30P1HF5P0
1@24Q8@0PH610861P@2BTY80HF5Q0080LG5a00D0Fe]K04=3@`13@d<0Jf][06UYJ@0207emO@<0B4Q8
00D0T92@075aL@1aLG40RXZ:075aL@0206=SH`0404U9B@1QHF40HF5Q05iNGP80PX:200D0VYZJ09FE
U@1<C4`0C4a<07moO`0205ADE00506][J`1SHf<0Hf=S08N7Q`2k^k/00P27QhL0101HF5P0=3@d03@d
=01WIfL30:JVYP040:>SX`2][Jd0[Jf]0:6QX@80UYJF00D0VYZJ08^;R`1[Jf/0Jf][05=CD`0206e]
K@0507UiN@2DU9@0U9BD0;^k^`1TI6@00P2?Shl01@28R8P0/k>c0;>c/`37alL0YZJV0080Vi^K00@0
^;Rh0;Vi^@2i^KT0a<C40P1?Cdl01@2ATI40Ng]k07AdM01dM7@0NGUi0080Lg=c00D0K6a/08^;R`2;
Rh/0[jn_09nOW`0207inOP0505QHF02=SHd0SHf=0:j^[P3Jf]X00P2l_;`0101`L700IFEU06EUI@2K
Vi/20;jn_P0509VIV@1[Jf/0LG5a075aL@1cLg<00P2XZ:P01@32`/80Zj^[0:^[Z`1iNGT0Z:RX0080
YZJV00@0VYZJ06UYJ@1YJFT0N7Qh0P2b/[801@2f][H0DU9B03hn?P0n?Sh0BTY:0080ATI600D0PH61
07=cL`1_Kfl0Kfm_06MWI`0207=cL`0506EUI@1RHV80HV9R07UiN@1ZJVX00P1EEED0101SHf<0LW9b
079bLP1nOWh208f=S@0509jNWP2YZJT0BTY:04Y:BP28R8P00P2=SHd01@24Q8@0MgMg069RHP1RHV80
FUYJ0080MGEe00@0IfMW08N7Q`27QhL0NWYj2_ooool000[ooooo00@0IVIV05eMG@1MGEd0B4Q80P0i
>CT01@0a<C40=SHf03@d=00d=3@0<C4a0080@D5100D0?3`l03@d=00d=3@0<S8b0410@00203/k>`05
03`l?00i>CT0>CTi0492@P0m?Cd00P0`<300100f=SH0?3`l03`l?00n?Sh203/k>`0503Xj>P0V9RH0
?Shn03hn?P1<C4`00P1;Bd/01@1=CDd0?Cdm03/k>`0k>c/0=3@d0080=CDe00D0:RXZ03Xj>P13@d<0
@d=304I6AP0203Xj>P0503/k>`1IFET0FEUI05iNGP1QHF400P1FEUH01@1PH600HF5Q065QH@1PH600
GEeM0080HF5Q00@0JVYZ07EeM@1eMGD0Lg=c0P1[Jf/01@0d=3@0CTi>05]KF`1KFe/0G5aL0080IVIV
00D0HV9R06=SH`1TI6@0I6AT06][J`0206a/K0<0KVi^00D0IfMW06EUI@18B4P0B4Q807]kN`020820
P0050861P@1lO7`0K6a/06a/K01VIVH00P1`L7001@21PH40QHF508Z:RP2:RXX0T92@0080Shn?00D0
IFEU065QH@1QHF40SXj>07moO`020:>SX`050:6QX@2TY:@0Y:BT09jNWP2PX:000P2LW9`0102GUiL0
V9RH09RHV02KVi/209:BTP0504i>CP25QHD0/K6a0;6a/@2c/k<00P2h^;P0102f][H0];Bd0:n_[`2_
[jl30:j^[P050;>c/`2b/[80/k>c0;>c/`2][Jd00P1:BTX00`2NWYh0/;2`0;2`/0020:j^[P80/;2`
00D0/K6a0;:b/P2b/[80/[:b0:^[Z`0209nOW`040:ZZZP2`/;00/;2`08b<S080MgMg00@0XZ:R0:BT
Y02a/K40/K6a0`2YZJT00`2a/K7oooooooooo`0?ooooo`0406ATI01nOWh0OWin08B4Q080ATI600D0
R8R807inOP1nOWh0TI6A05QHF002071`L00505YJFP1?Cdl0Cdm?07=cL`1`L7000P1jNWX01016ATH0
CDe=04e=C@27QhL207QhN0040861P@1aLG40Cdm?04m?C`<0AdM700D0Bd];07YjNP1jNWX0Shn?096A
T@0205IFEP0408:2PP1@D500D51@06i^KP80GUiN00D0Rh^;0<_;b`2NWYh0WYjN04e=C@0202d];@05
06ATI02RXZ80YjNW0:NWY`2^[Zh00P2c/k<01@2EUID0TY:B09:BTP2QXJ40UIFE0080NGUi00@0L71`
075aL@1aLG40Ng]k0P2EUID01@2[Zj/0EEEE09FEU@2EUID0QhN70080^[Zj00D0b/[:0:f][@2CTi<0
Ti>C0;6a/@020;Jf]P050;Zj^P16ATH0ATI608Z:RP24Q8@00P28R8P01022PX80SHf=08f=S@1]KFd2
08j>SP050<c<c02<S8`0Kfm_06m_K`1=CDd00P1oOgl01@24Q8@0f][J0:f][@2][Jd0Lg=c0080GEeM
00D0WinO0<G5a@35aLD0PH6106UYJ@02065QH@04071`L02QXJ40XJ6Q0:RXZ080XJ6Q00D0QHF50:6Q
X@2NWYh0WYjN08F5Q@0205]KF`0506YZJP2SXj<0Xj>S0;:b/P1PH6000P0n?Sh01@1<C4`0@D510451
@@1OGel0M7Ad0080Ogmo00@0L71`06UYJ@1YJFT0GEeM0P1gMgL01@1OGel0IfMW06=SH`1SHf<0KVi^
0080RHV900D0T92@08R8R028R8P0Ti>C09fMW@02059BDP0509VIV@2TY:@0Y:BT0:6QX@2<S8`00P1j
NWX0101OGel0GUiN05iNGP1XJ6P206MWI`0306EUIOoooooooooo00Sooooo000:ooooo`040;Ng]`2f
][H0][Jf0:^[Z`80LW9b00@0NGUi0:j^[P2_[jl0[jn_102c/k<20;Bd]0050;bl_02h^;P0];Bd0;Bd
]02][Jd00P2/[:`01@2YZJT0Ti>C059BDP1BDU80/k>c0080][Jf00D0]kNg0;>c/`2c/k<0/[:b0:ZZ
ZP020:FUY@0509fMW@2DU9@0U9BD08b<S02=SHd00P2ATI401@27QhL0BDU904U9B@2NWYh0[:b/0080
[Jf]0`2TY:@30:NWY`050:JVYP2PX:00Vi^K09^KV`2GUiL00P2ATI401@23Ph<0Cdm?07emO@1mOGd0
PH610080PX:200D0P82007inOP1nOWh0MgMg06a/K00206QXJ00506EUI@1YJFT0JFUY06UYJ@1fMWH0
0P1`L700100f=SH0DU9B059BDP1OGel205UIF@0505iNGP1UIFD0KVi^06i^KP1/K6`00P1WIfL01@1R
HV80Fe]K05eMG@1MGEd0EUIF0080?Cdm00D0;bl_04Y:BP1:BTX0BTY:04m?C`0204Y:BP0504U9B@0n
?Sh0?Shn02l_;`16ATH00P0o?cl01@10@400>c/k03/k>`0e=CD0C4a<0080DU9B00@0DE5A05EEE@1E
EED0B4Q80P19BDT01@1CDe<0E5AD04A4A014A4@0@D510080B4Q800D0>c/k02`/;00^;Rh0;Rh^03Lg
=`0203Xj>P0504=3@`17AdL0CDe=04e=C@0g=cL00P0];Bd01@11@D40CTi>04i>CP1;Bd/0D51@0080
E5AD00D0FUYJ05iNGP1NGUh0HV9R06IVIP0206a/K00406YZJP1XJ6P0J6QX059BDP80=CDe00D0De=C
05eMG@1ZJVX0JVYZ06EUI@02069RHP0307IfM_oooooooooo00oooooo00@0JVYZ07AdM01dM7@0MgMg
0P16ATH01@2CTi<0OGem07emO@21PH40GEeM0080LW9b00D0KFe]05aLG01LG5`0T92@079bLP0207Ui
N@0404E5A@11@D40@D51092@T080NGUi00D0N7Qh08F5Q@1IFET0FEUI04U9B@0204E5A@0505aLG01c
Lg<0Lg=c09BDU02LW9`00P1EEED0101nOWh0B4Q804Q8B01PH602065QH@0509>CT`3;bl/0YJFU0:FU
Y@1LG5`00P0k>c/0101cLg<0WIfM0;Fe]@2e]KD30:j^[P0509>CT`2KVi/0Vi^K0:JVYP2TY:@00P1n
OWh0101LG5`0O7al07alO01mOGd209NGU`050:f][@1PH600U9BD09BDU020P8000P2g]kL01@38b<P0
/[:b09JFUP2FUYH0/[:b0080]KFe00@0]kNg04U9B@19BDT0P8200`1kNg/0101nOWh0Rh^;08^;R`1]
KFd207YjNP050<G5a@2:RXX0NWYj07YjNP1HF5P00P2EUID01@2FUYH0^[Zj0:2PX02PX:00NWYj0080
IFEU00D0Shn?0<O7a`37alL0NWYj06i^KP0206e]K@0406m_K`2MWId0WIfM0:f][@80ZJVY00D0QHF5
08j>SP2=SHd0SHf=07moO`0207IfMP05092@T02UYJD0YJFU0:j^[P1OGel00P0n?Sh01@1DE5@0A4A4
04A4A01PH600K6a/0080MWIf00@0LW9b07YjNP1jNWX0IVIV0P1gMgL01@1bLW80KVi^05aLG01LG5`0
MGEe0080QHF500D0WYjN08b<S02<S8`0PH6109^KV`0205ADE00508J6QP2b/[80/[:b09fMW@2=SHd0
0P2;Rh/0101ZJVX0MGEe07EeM@1jNWX206i^KP0306QXJ?oooooooooo00Sooooo000:ooooo`040;Ng
]`2f][H0][Jf0:^[Z`80LW9b00@0NGUi0:j^[P2_[jl0[jn_102c/k<20;Bd]0050;bl_02h^;P0];Bd
0;Bd]02][Jd00P2/[:`01@2YZJT0Ti>C059BDP1BDU80/k>c0080][Jf00D0]kNg0;>c/`2c/k<0/[:b
0:ZZZP020:FUY@0509fMW@2DU9@0U9BD08b<S02=SHd00P2ATI401@27QhL0BDU904U9B@2NWYh0[:b/
0080[Jf]0`2TY:@30:NWY`050:JVYP2PX:00Vi^K09^KV`2GUiL00P2ATI401@23Ph<0Cdm?07emO@1m
OGd0PH610080PX:200D0P82007inOP1nOWh0MgMg06a/K00206QXJ00506EUI@1YJFT0JFUY06UYJ@1f
MWH00P1`L700100f=SH0DU9B059BDP1OGel205UIF@0505iNGP1UIFD0KVi^06i^KP1/K6`00P1WIfL0
1@1RHV80Fe]K05eMG@1MGEd0EUIF0080?Cdm00D0;bl_04Y:BP1:BTX0BTY:04m?C`0204Y:BP0504U9
B@0n?Sh0?Shn02l_;`16ATH00P0o?cl01@10@400>c/k03/k>`0e=CD0C4a<0080DU9B00@0DE5A05EE
E@1EEED0B4Q80P19BDT01@1CDe<0E5AD04A4A014A4@0@D510080B4Q800D0>c/k02`/;00^;Rh0;Rh^
03Lg=`0203Xj>P0504=3@`17AdL0CDe=04e=C@0g=cL00P0];Bd01@11@D40CTi>04i>CP1;Bd/0D51@
0080E5AD00D0FUYJ05iNGP1NGUh0HV9R06IVIP0206a/K00406YZJP1XJ6P0J6QX059BDP80=CDe00D0
De=C05eMG@1ZJVX0JVYZ06EUI@02069RHP0307IfM_oooooooooo00oooooo00@0JVYZ07AdM01dM7@0
MgMg0P16ATH01@2CTi<0OGem07emO@21PH40GEeM0080LW9b00D0KFe]05aLG01LG5`0T92@079bLP02
07UiN@0404E5A@11@D40@D51092@T080NGUi00D0N7Qh08F5Q@1IFET0FEUI04U9B@0204E5A@0505aL
G01cLg<0Lg=c09BDU02LW9`00P1EEED0101nOWh0B4Q804Q8B01PH602065QH@0509>CT`3;bl/0YJFU
0:FUY@1LG5`00P0k>c/0101cLg<0WIfM0;Fe]@2e]KD30:j^[P0509>CT`2KVi/0Vi^K0:JVYP2TY:@0
0P1nOWh0101LG5`0O7al07alO01mOGd209NGU`050:f][@1PH600U9BD09BDU020P8000P2g]kL01@38
b<P0/[:b09JFUP2FUYH0/[:b0080]KFe00@0]kNg04U9B@19BDT0P8200`1kNg/0101nOWh0Rh^;08^;
R`1]KFd207YjNP050<G5a@2:RXX0NWYj07YjNP1HF5P00P2EUID01@2FUYH0^[Zj0:2PX02PX:00NWYj
0080IFEU00D0Shn?0<O7a`37alL0NWYj06i^KP0206e]K@0406m_K`2MWId0WIfM0:f][@80ZJVY00D0
QHF508j>SP2=SHd0SHf=07moO`0207IfMP05092@T02UYJD0YJFU0:j^[P1OGel00P0n?Sh01@1DE5@0
A4A404A4A01PH600K6a/0080MWIf00@0LW9b07YjNP1jNWX0IVIV0P1gMgL01@1bLW80KVi^05aLG01L
G5`0MGEe0080QHF500D0WYjN08b<S02<S8`0PH6109^KV`0205ADE00508J6QP2b/[80/[:b09fMW@2=
SHd00P2;Rh/0101ZJVX0MGEe07EeM@1jNWX206i^KP0306QXJ?oooooooooo00Sooooo000:ooooo`04
0;6a/@2b/[80/[:b0:RXZ080MWIf00@0RHV90:f][@2a/K40/K6a0`2e]KD01@2i^KT0^[Zj0;Zj^P2k
^k/0`<300080^k^k00D0[Zj^0:JVYP2VYZH0Zj^[0:b/[00205YJFP040:f][@2_[jl0[jn_0;Fe]@80
YjNW00D0[Zj^0:f][@2YZJT0ZJVY0::RXP0209fMW@0508b<S02@T900UiNG09NGU`2KVi/00P1ADE40
0`2^[Zh0/;2`0:VYZ@020:VYZ@80[Zj^00D0[jn_0;Fe]@2e]KD0];Bd0:n_[`020:ZZZP050:BTY02S
Xj<0Xj>S0:6QX@1ZJVX00P2YZJT0102h^;P0^k^k0;^k^`2m_Kd20;jn_P050;bl_02i^KT0^[Zj0;Zj
^P2i^KT00P2e]KD01@2i^KT0_;bl0;bl_02l_;`0JFUY00<0/[:b0P2ZZZX00`2WYjL0];Bd0;Bd]002
0;Bd]080/k>c0P2h^;P20;Bd]0050;:b/P2EUID0UIFE05MGE`2`/;000P2HV9P0102c/k<0^k^k0;^k
^`2m_Kd30;jn_P<0_kno00D0^k^k06][J`1[Jf/0I6AT0;Bd]0020;Jf]P030;Rh^02g]kL0]kNg00<0
/k>c00D0]kNg0;^k^`2k^k/0^k^k0<71`@020;no_`050;Rh^01]KFd0OGem07emO@2UYJD00P2YZJT0
1@2PX:00/;2`0;bl_02l_;`0^k^k0080^[Zj00D0[jn_0:^[Z`2[Zj/0VYZJ09JFUP0208b<S00504i>
CP1bLW80LW9b08F5Q@1nOWh00P20P800101oOgl0LW9b079bLP1]KFd207AdM00507]kN`1`L700N7Qh
07QhN021PH400P24Q8@00`1RHV;oooooooooo`0?ooooo`0407YjNP2:RXX0RXZ:08V9R@80Bd];00D0
Ogmo07YjNP1jNWX0O7al05ADE00207]kN`05075aL@1ZJVX0JVYZ08N7Q`1mOGd00P1gMgL0101HF5P0
ATI604I6AP1JFUX206EUI@05071`L01iNGT0@T920492@P16ATH00P1BDU801@1JFUX0IFEU06EUI@2?
Shl0TY:B0080EEEE00@0Shn?05eMG@1MGEd0N7Qh0P1PH6001@29RHT0cLg=0:NWY`2WYjL0IFEU0080
Bd];00D0OWin0:j^[P2a/K40/K6a0;^k^`020;6a/@0508n?S`1oOgl0Ogmo08b<S01oOgl00P1TI6@0
101?Cdl0N7Qh07QhN024Q8@209jNWP050;Ng]`1^KVh0/;2`0;2`/01kNg/00P2h^;P01@3@d=00/k>c
09RHV02HV9P0[jn_0080d=3@00D0`L7105iNGP1NGUh0QXJ608N7Q`0207inOP0407QhN02DU9@0U9BD
06e]K@80M7Ad00D0f=SH08J6QP1aLG40LG5a05ADE00209BDU0050:j^[P3=cLd0^;Rh0;Rh^029RHT0
0P2>SXh01@2GUiL0b/[:0<[:bP1TI6@0LG5a0080MgMg00@0IfMW09FEU@2EUID0]KFe0P2RXZ801@22
PX80QXJ60:>SX`2SXj<0Ph>30080HF5Q00D0Rh^;0:>SX`2SXj<0XJ6Q06EUI@0204e=C@0504E5A@11
@D40@D5106ATI01cLg<00`1_Kfl307QhN080P82000D0MgMg061PH01KFe/0Fe]K069RHP0206YZJP05
09ZJVP26QXH0QXJ607alO02@T9000P19BDT01@1aLG40T92@092@T02HV9P0P8200080M7Ad00@0FUYJ
07alO01lO7`0N7Qh0P1RHV800`1ZJV[oooooooooo`08ooooo`002_ooool30;2`/0040:f][@1gMgL0
MgMg08Z:RP<0[Zj^00@0/[:b0;Rh^02h^;P0/k>c0P2d];@01@2b/[80/k>c0;Bd]02d];@0[Jf]0080
WYjN00D0[:b/09jNWP1KFe/0Fe]K0:j^[P030;>c/`80Y:BT0P2XZ:P20:FUY@050:NWY`2NWYh0WYjN
09^KV`2NWYh00P2LW9`01@2PX:00BDU904U9B@2/[:`0[Zj^0080Zj^[00@0Y:BT0:2PX02PX:00[Zj^
0P2g]kL01@2e]KD0/K6a0:j^[P2^[Zh0ZJVY0080WinO00D0WYjN06MWI`2_[jl0[jn_0;Jf]P020;Ng
]`D0^k^k0P2l_;`01@2i^KT0]kNg0;Ng]`2i^KT0^k^k0080_[jn00@0IFEU0;>c/`2c/k<0[:b/0P2Y
ZJT01@2WYjL0Zj^[0;:b/P2b/[80];Bd00<0/[:b00@0/;2`0:f][@2][Jd0[Jf]0P2LW9`01@1hN7P0
/k>c09ZJVP2JVYX0ZZZZ0080_kno00D0_[jn0;fm_@2m_Kd0_;bl0<;2`P020<?3``050;fm_@1XJ6P0
J6QX06UYJ@2g]kL00P2a/K40102f][H0]KFe0;Fe]@2d];@20;Jf]P040;Vi^@2e]KD0_;bl0;bl_0<0
_[jn00D0^;Rh08:2PP2>SXh0SXj>0:n_[`020:b/[0030:RXZ02c/k<0^[Zj0080^[Zj0P2o_kl01@2h
^;P0_;bl0;bl_02i^KT0]kNg0080/;2`00<0EUIF0:>SX`2SXj<00P2n_[h20<30`0040;fm_@2k^k/0
^k^k0;Rh^080^k^k00D0_Kfm0<30`032`/80`/;20<71`@020;bl_00309BDU?oooooooooo00oooooo
00@0O7al08j>SP2>SXh0QhN70P15ADD01@21PH40QHF508F5Q@1fMWH0C4a<0080K6a/00D0J6QX079b
LP1bLW80MWIf08>3P`0207inOP0406e]K@1=CDd0CDe=07=cL`80LG5a00D0QXJ606YZJP18B4P0B4Q8
0451@@0203dm?@05065QH@1]KFd0KFe]09:BTP1lO7`00P12@T80101gMgL0De=C05=CD`1cLg<205eM
G@0508R8R03;bl/0XJ6Q0:6QX@1^KVh00P1ADE401@25QHD0X:2P0;Zj^P2j^[X0];Bd0080YZJV00D0
SHf=09RHV02HV9P0VYZJ07moO`02071`L00405QHF01_Kfl0Kfm_07alO080VYZJ00D0YJFU065QH@2P
X:00X:2P0820P0020;Jf]P050<C4a02m_Kd0Vi^K09^KV`2a/K400P3EeMD01@31`L40GemO05mOG`2;
Rh/0SXj>0080NGUi00@0Ogmo09VIV@2IVIT0N7Qh0P1RHV801@3Cdm<0UYJF07YjNP1jNWX0De=C0080
PH6100D0W9bL0;Zj^P2d];@0];Bd0820P00207inOP0509FEU@3Hf=P0f=SH06][J`24Q8@00P1lO7`0
101dM7@0Ti>C09>CT`2JVYX20;jn_P0509BDU028R8P0RHV908V9R@1kNg/00P1cLg<01@2ATI40YZJV
0:JVYP2GUiL0LG5a0080Cdm?00D0?3`l04m?C`1?Cdl0JFUY065QH@0206][J`0406e]K@1kNg/0Ng]k
07QhN080MWIf00D0Kfm_07YjNP1TI6@0I6AT06YZJP0205aLG00509>CT`24Q8@0Q8B409:BTP2b/[80
0P1KFe/01@2<S8`0YZJV0:JVYP2OWil0MGEe0080K6a/00@0FUYJ07AdM01dM7@0J6QX0P1aLG400`1Y
JFWoooooooooo`08ooooo`002_ooool30;2`/0040:f][@1gMgL0MgMg08Z:RP<0[Zj^00@0/[:b0;Rh
^02h^;P0/k>c0P2d];@01@2b/[80/k>c0;Bd]02d];@0[Jf]0080WYjN00D0[:b/09jNWP1KFe/0Fe]K
0:j^[P030;>c/`80Y:BT0P2XZ:P20:FUY@050:NWY`2NWYh0WYjN09^KV`2NWYh00P2LW9`01@2PX:00
BDU904U9B@2/[:`0[Zj^0080Zj^[00@0Y:BT0:2PX02PX:00[Zj^0P2g]kL01@2e]KD0/K6a0:j^[P2^
[Zh0ZJVY0080WinO00D0WYjN06MWI`2_[jl0[jn_0;Jf]P020;Ng]`D0^k^k0P2l_;`01@2i^KT0]kNg
0;Ng]`2i^KT0^k^k0080_[jn00@0IFEU0;>c/`2c/k<0[:b/0P2YZJT01@2WYjL0Zj^[0;:b/P2b/[80
];Bd00<0/[:b00@0/;2`0:f][@2][Jd0[Jf]0P2LW9`01@1hN7P0/k>c09ZJVP2JVYX0ZZZZ0080_kno
00D0_[jn0;fm_@2m_Kd0_;bl0<;2`P020<?3``050;fm_@1XJ6P0J6QX06UYJ@2g]kL00P2a/K40102f
][H0]KFe0;Fe]@2d];@20;Jf]P040;Vi^@2e]KD0_;bl0;bl_0<0_[jn00D0^;Rh08:2PP2>SXh0SXj>
0:n_[`020:b/[0030:RXZ02c/k<0^[Zj0080^[Zj0P2o_kl01@2h^;P0_;bl0;bl_02i^KT0]kNg0080
/;2`00<0EUIF0:>SX`2SXj<00P2n_[h20<30`0040;fm_@2k^k/0^k^k0;Rh^080^k^k00D0_Kfm0<30
`032`/80`/;20<71`@020;bl_00309BDU?oooooooooo00oooooo00@0O7al08j>SP2>SXh0QhN70P15
ADD01@21PH40QHF508F5Q@1fMWH0C4a<0080K6a/00D0J6QX079bLP1bLW80MWIf08>3P`0207inOP04
06e]K@1=CDd0CDe=07=cL`80LG5a00D0QXJ606YZJP18B4P0B4Q80451@@0203dm?@05065QH@1]KFd0
KFe]09:BTP1lO7`00P12@T80101gMgL0De=C05=CD`1cLg<205eMG@0508R8R03;bl/0XJ6Q0:6QX@1^
KVh00P1ADE401@25QHD0X:2P0;Zj^P2j^[X0];Bd0080YZJV00D0SHf=09RHV02HV9P0VYZJ07moO`02
071`L00405QHF01_Kfl0Kfm_07alO080VYZJ00D0YJFU065QH@2PX:00X:2P0820P0020;Jf]P050<C4
a02m_Kd0Vi^K09^KV`2a/K400P3EeMD01@31`L40GemO05mOG`2;Rh/0SXj>0080NGUi00@0Ogmo09VI
V@2IVIT0N7Qh0P1RHV801@3Cdm<0UYJF07YjNP1jNWX0De=C0080PH6100D0W9bL0;Zj^P2d];@0];Bd
0820P00207inOP0509FEU@3Hf=P0f=SH06][J`24Q8@00P1lO7`0101dM7@0Ti>C09>CT`2JVYX20;jn
_P0509BDU028R8P0RHV908V9R@1kNg/00P1cLg<01@2ATI40YZJV0:JVYP2GUiL0LG5a0080Cdm?00D0
?3`l04m?C`1?Cdl0JFUY065QH@0206][J`0406e]K@1kNg/0Ng]k07QhN080MWIf00D0Kfm_07YjNP1T
I6@0I6AT06YZJP0205aLG00509>CT`24Q8@0Q8B409:BTP2b/[800P1KFe/01@2<S8`0YZJV0:JVYP2O
Wil0MGEe0080K6a/00@0FUYJ07AdM01dM7@0J6QX0P1aLG400`1YJFWoooooooooo`08ooooo`002_oo
ool0102^[Zh0[jn_0:n_[`2YZJT206UYJ@0508>3P`2`/;00ZJVY0:VYZ@2][Jd00P2e]KD01@2XZ:P0
ZZZZ0:ZZZP2UYJD0ZJVY00<0[:b/0P2IVIT01@2UYJD0XJ6Q069RHP1RHV80]KFe00<0];Bd0P2_[jl0
1@2/[:`0YjNW0:RXZ02XZ:P0ZJVY0080YJFU0P2OWil209^KV`050:>SX`12@T80@T920:2PX02b/[80
0P2TY:@0102VYZH0ZJVY0:VYZ@2/[:`20;Fe]@050:j^[P2][Jd0[:b/0:b/[02YZJT00P2VYZH01@2N
WYh0GemO0:n_[`2_[jl0];Bd0080/k>c00<0]KFe0;Ng]`2g]kL00P2f][H30;^k^`80][Jf00D0/k>c
0;:b/P2UYJD0YJFU069RHP020;:b/P050:ZZZP2HV9P0V9RH0:6QX@2^[Zh00P2g]kL01@2l_;`0]kNg
0;Ng]`2c/k<0/K6a00<0[Zj^0P2FUYH01@1bLW80[Zj^0:RXZ02XZ:P0[Jf]0080/K6a00D0^;Rh0;Jf
]P2f][H0^k^k0;fm_@020;Zj^P050;Ng]`1eMGD0MGEe06EUI@2c/k<00P2b/[80102f][H0/k>c0;>c
/`2c/k<20;Bd]0050;Ng]`2h^;P0^;Rh0;Rh^02n_[h00P2m_Kd01@2i^KT0M7Ad08^;R`2;Rh/0[Jf]
0080Zj^[00D0Vi^K0:n_[`2g]kL0]kNg0;^k^`020;Ng]`050;:b/P2c/k<0/k>c0;Bd]02j^[X00P2a
/K401@17AdL0/;2`0;2`/033`l<0aLG50080`l?300@0^k^k0;Ng]`2g]kL0/[:b0P2g]kL01@2k^k/0
_[jn0<?3``33`l<0`<300080^KVi00<0Shn?ooooooooool03oooool0101oOgl0Xj>S0:>SX`26QXH2
04I6AP0507moO`2;Rh/0Rh^;07AdM01FEUH00P21PH401@1[Jf/0N7Qh07QhN01iNGT0OWin0080NWYj
00@0I6AT04];B`1;Bd/0R8R80P22PX801@2>SXh0Kfm_04];B`1;Bd/0CTi>0080EUIF00D0KFe]06i^
KP1^KVh0UiNG08f=S@0203lo?`0408V9R@1;Bd/0Bd];07=cL`80De=C00D0SHf=0<_;b`2SXj<0Xj>S
05IFEP020451@@0506YZJP2VYZH0/;2`0;2`/02^[Zh00P2QXJ401@24Q8@0QHF508F5Q@2CTi<0PX:2
0080JVYZ00@0E5AD06a/K01/K6`0LW9b0P2ATI401@2/[:`0G5aL09RHV02HV9P0QHF50080_kno00D0
bLW90=3@d02QXJ40XJ6Q0:FUY@020<?3``050;^k^`1UIFD0IFEU08B4Q02ATI400P1hN7P0101dM7@0
UYJF09JFUP1mOGd205IFEP050>?Sh`2;Rh/0MgMg07MgM`1EEED00P1/K6`01@2CTi<0aLG50:n_[`2_
[jl0U9BD0080S8b<00D0X:2P0=KFeP3Fe]H0IVIV06e]K@0207=cL`0406i^KP20P800P82009fMW@80
`<3000D0T92@08^;R`2YZJT0ZJVY08:2PP02061PH00507moO`2QXJ40XJ6Q09^KV`1dM7@00P1:BTX0
1@0c<c<0Bd];04];B`1SHf<0Fe]K0080OGem00@0IVIV08J6QP26QXH0N7Qh0P1mOGd01@1[Jf/0LG5a
06MWI`1WIfL0MgMg0080N7Qh00D0[Jf]09BDU02DU9@0WIfM0:j^[P0205iNGP0507inOP2PX:00X:2P
0::RXP29RHT00P1`L700101GEeL0I6AT06ATI01LG5`2079bLP0306IVI_oooooooooo00Sooooo000:
ooooo`0408R8R01nOWh0OWin06][J`80B4Q800D0GemO07]kN`1iNGT0NGUi0861P@0208J6QP0507in
OP1fMWH0MWIf07QhN01cLg<00P1^KVh01@1aLG40JVYZ06YZJP1VIVH0I6AT0080BDU900@0R8R808B4
Q024Q8@0R8R80P20P8001@1RHV80IFEU06IVIP1VIVH0Jf][0080KFe]00D0Fe]K05mOG`1CDe<0De=C
05MGE`0202<S8`050410@01UIFD0LW9b079bLP1gMgL00P1nOWh01@2BTY80TI6A096AT@29RHT0MWIf
0080PH6100D0OGem08B4Q024Q8@0P82003/k>`02092@T00409jNWP2[Zj/0Zj^[0:^[Z`80S8b<00D0
UYJF0:6QX@2f][H0][Jf0::RXP0209RHV0050;Bd]02e]KD0YZJV0:JVYP1_Kfl00P2b/[801@2VYZH0
RHV908V9R@2OWil0[:b/0080/;2`00D0];Bd0;:b/P2b/[80]KFe0;2`/0020;Fe]@050;:b/P2=SHd0
SHf=05UIF@2IVIT00P2][Jd0102b/[80/k>c0;>c/`2d];@20;Jf]P050;6a/@2d];@0/[:b0;:b/P2[
Zj/00P1aLG401@1cLg<0];Bd0;2`/02`/;00Zj^[0080[Jf]0`2`/;001@2c/k<0]KFe0;Ng]`2g]kL0
^KVi0080][Jf00@0];Bd06][J`2=SHd0SHf=0`2YZJT01@2PX:00[Jf]0;Ng]`2g]kL0^;Rh0080]kNg
00D0[Zj^0;6a/@2a/K40];Bd0;Rh^0020:n_[`0504M7A`2][Jd0[Jf]0;no_`2n_[h00P2l_;`0102g
]kL0]KFe0;Fe]@2XZ:P20;>c/`050;Rh^02m_Kd0^k^k0;^k^`2l_;`00P2XZ:P00`21PH7ooooooooo
o`0?ooooo`0407YjNP2YZJT0ZJVY07emO@80D51@00D0MgMg0861P@21PH40KVi^05ADE00207=cL`05
05YJFP1[Jf/0Jf][06a/K01gMgL00P1^KVh0101GEeL0ATI604I6AP1kNg/208F5Q@0509BDU01aLG40
Fe]K05]KF`1;Bd/00P1DE5@01@1[Jf/0MWIf07IfMP2FUYH0PX:20080EEEE00@0OGem0492@P12@T80
KVi^0P19BDT01@26QXH0_[jn0820P020P800H61P0080?3`l00D0M7Ad0;Jf]P2g]kL0]kNg0:NWY`02
0:j^[P0509VIV@23Ph<0Ph>309VIV@2=SHd00P1eMGD0101OGel0Kfm_06m_K`1jNWX20:2PX0050;Fe
]@1TI6@0X:2P0:2PX027QhL00P2k^k/01@37alL0c<c<09JFUP2FUYH0UiNG00<0^KVi0P1lO7`01@1i
NGT0U9BD07EeM@1eMGD0Ng]k0080UIFE00D0LG5a04m?C`1?Cdl0d=3@08f=S@0207YjNP0506YZJP1o
Ogl0Ogmo09^KV`2l_;`00P2e]KD0102;Rh/0RXZ:08Z:RP29RHT20=WIf@0505mOG`1eMGD0Ogmo07mo
O`1bLW800P1eMGD01@2WYjL0_kno0;no_`2=SHd0MGEe0080W9bL00@0MGEe05]KF`1KFe/0JFUY0P2K
Vi/01@2RXZ80LW9b04E5A@15ADD0<c<c0080>CTi00D0GUiN06ATI01hN7P0N7Qh05]KF`0207QhN005
06a/K01oOgl0Ogmo06ATI01dM7@00P1NGUh0101]KFd0LW9b079bLP2KVi/2092@T0050:6QX@2^[Zh0
GUiN05iNGP2GUiL00P2XZ:P01@2/[:`0Q8B407AdM01dM7@0Jf][0080HV9R00@0Jf][07UiN@1iNGT0
LW9b2_ooool000[ooooo00@0Y:BT09VIV@2IVIT0SHf=0`2@T9000`28R8P0QHF508F5Q@0308B4Q005
05MGE`1TI6@0I6AT071`L01aLG400P1cLg<01@1hN7P0NGUi07UiN@1^KVh0Kfm_0080OGem00@0MgMg
07]kN`1kNg/0P8200P1iNGT01@1EEED0@T9206EUI@1UIFD0KVi^0080K6a/00D0LW9b075aL@1cLg<0
Lg=c075aL@0306a/K00407YjNP1eMGD0MGEe06EUI@80Fe]K00D0<30`05=CD`1CDe<0EEEE05MGE`02
05QHF00505IFEP1LG5`0G5aL05YJFP1TI6@00P1DE5@0101HF5P0Fe]K05]KF`1GEeL203hn?P0402@T
9011@D40B4Q804Q8B0<0@T9200D0?3`l03lo?`1=CDd0CDe=04I6AP0204Q8B00503Ph>012@T80@T92
04m?C`0c<c<00P0m?Cd00`1@D500ADE504E5A@0205MGE`80ADE500D0Cdm?051@D01@D500;bl_03/k
>`0204E5A@0405=CD`1FEUH0EUIF04a<C0@0CTi>0P1GEeL0101SHf<0@d=304=3@`0f=SH304U9B@04
059BDP1EEED0EEEE05]KF`80EeMG00D0FUYJ05iNGP1SHf<0Hf=S069RHP02065QH@0506IVIP0b<S80
<S8b038b<P1PH6000P1YJFT01@1aLG40LW9b07QhN01hN7P0OGem0080O7al00D0MgMg07emO@1mOGd0
Kfm_07QhN00206i^KP0502l_;`1[Jf/0Jf][09BDU02GUiL00P2DU9@0102KVi/0V9RH09RHV02DU9@3
096AT@040:>SX`2VYZH0YZJV0:f][@80NGUi00<0HV9Rooooooooool03oooool0101dM7@0XJ6Q0:6Q
X@1fMWH204=3@`0507QhN02<S8`0S8b<07=cL`1QHF400P26QXH01@1XJ6P0N7Qh07QhN01cLg<0N7Qh
0080JFUY00@0CDe=04E5A@15ADD0Ogmo0P21PH401@2FUYH0Lg=c06YZJP1ZJVX0EEEE0080D51@00D0
H61P06a/K01/K6`0WinO09FEU@0206i^KP04092@T01GEeL0EeMG07inOP80DE5A00D0QhN70<g=c@2A
TI40TI6A05]KF`0203Xj>P0506MWI`2VYZH0Z:RX0:RXZ02GUiL00P2[Zj/01@2KVi/0MGEe07EeM@2E
UID0RHV90080Lg=c00@0FEUI06UYJ@1YJFT0MgMg0P2;Rh/01@2i^KT0I6AT09jNWP2NWYh0T92@0080
_[jn00D0b<S80<G5a@28R8P0R8R808^;R`020;^k^`050;2`/01gMgL0MgMg075aL@2@T9000P1_Kfl0
101`L700TY:B09:BTP1/K6`205mOG`050=3@d01eMGD0OWin07inOP1_Kfl00P1bLW801@2<S8`0]KFe
0<C4a034a<@0QhN70080RXZ:00D0NGUi0=?Cd`3Cdm<0K6a/09bLW00207]kN`0407QhN01eMGD0MGEe
09bLW080b<S800D0UIFE06m_K`27QhL0QhN707alO00205YJFP0506=SH`2VYZH0YZJV0:NWY`1UIFD0
0P13@d<01@0h>3P0=SHf03Hf=P1QHF40OGem0080JFUY00@0JVYZ06][J`1[Jf/0N7Qh0P1oOgl01@1T
I6@0JFUY05UIF@1IFET0M7Ad0080MWIf00D0Ti>C096AT@2ATI40Ti>C0:FUY@0205EEE@0509bLW02^
[Zh0[Zj^0:n_[`2:RXX00P1`L700101HF5P0L71`071`L01XJ6P206YZJP0305aLG?oooooooooo00So
oooo000:ooooo`040:BTY02IVIT0VIVI08f=S@<0T92@00<0R8R808F5Q@25QHD00`24Q8@01@1GEeL0
I6AT06ATI01`L700LG5a0080Lg=c00D0N7Qh07UiN@1iNGT0KVi^06m_K`0207emO@0407MgM`1kNg/0
Ng]k0820P080NGUi00D0EEEE0492@P1UIFD0IFEU06i^KP0206a/K005079bLP1aLG40Lg=c07=cL`1a
LG400`1/K6`0101jNWX0MGEe07EeM@1UIFD205]KF`05030`<01CDe<0De=C05EEE@1GEeL00P1HF5P0
1@1FEUH0G5aL05aLG01JFUX0I6AT0080E5AD00@0F5QH05]KF`1KFe/0EeMG0P0n?Sh0100T92@0@D51
04Q8B018B4P30492@P0503`l?00o?cl0CDe=04e=C@16ATH00P18B4P01@0h>3P0@T920492@P1?Cdl0
<c<c0080?Cdm00<0D51@04E5A@15ADD00P1GEeL204E5A@0504m?C`1@D500D51@02l_;`0k>c/00P15
ADD0101CDe<0EUIF05IFEP1<C4`404i>CP80EeMG00@0Hf=S04=3@`13@d<0=SHf0`19BDT0101BDU80
EEEE05EEE@1KFe/205MGE`0505YJFP1NGUh0Hf=S06=SH`1RHV800P1QHF401@1VIVH0<S8b038b<P0b
<S80H61P0080JFUY00D0LG5a079bLP1hN7P0N7Qh07emO@0207alO00507MgM`1mOGd0OGem06m_K`1h
N7P00P1^KVh01@0_;bl0Jf][06][J`2DU9@0UiNG0080U9BD00@0Vi^K09RHV02HV9P0U9BD0`2ATI40
102SXj<0YZJV0:JVYP2][Jd207UiN@03069RH_oooooooooo00oooooo00@0M7Ad0:6QX@2QXJ40MWIf
0P13@d<01@1hN7P0S8b<08b<S01cLg<0HF5Q0080QXJ600D0J6QX07QhN01hN7P0Lg=c07QhN00206UY
J@0404e=C@15ADD0ADE507moO`80PH6100D0UYJF07=cL`1ZJVX0JVYZ05EEE@02051@D005061PH01/
K6`0K6a/09nOW`2EUID00P1^KVh0102@T900EeMG05MGE`1nOWh2055AD@0508N7Q`3=cLd0TI6A096A
T@1KFe/00P0j>SX01@1WIfL0YZJV0:RXZ02XZ:P0UiNG0080Zj^[00D0Vi^K07EeM@1eMGD0UIFE08V9
R@0207=cL`0405UIF@1YJFT0JFUY07MgM`80Rh^;00D0^KVi06ATI02NWYh0WYjN092@T0020;jn_P05
0<S8b035aLD0R8R808R8R02;Rh/00P2k^k/01@2`/;00MgMg07MgM`1aLG40T92@0080Kfm_00@0L71`
09:BTP2BTY80K6a/0P1OGel01@3@d=00MGEe07inOP1nOWh0Kfm_0080LW9b00D0S8b<0;Fe]@34a<@0
a<C408N7Q`0208Z:RP0507UiN@3Cdm<0dm?C06a/K02LW9`00P1kNg/0101hN7P0MGEe07EeM@2LW9`2
0<S8b00509FEU@1_Kfl0QhN708N7Q`1lO7`00P1JFUX01@1SHf<0YZJV0:JVYP2WYjL0IFEU0080@d=3
00D0>3Ph03Hf=P0f=SH0HF5Q07emO@0206UYJ@0406YZJP1[Jf/0Jf][07QhN080Ogmo00D0I6AT06UY
J@1IFET0FEUI07AdM00207IfMP0509>CT`2ATI40TI6A09>CT`2UYJD00P1EEED01@2LW9`0[Zj^0:j^
[P2_[jl0RXZ:0080L71`00@0F5QH071`L01`L700J6QX0P1ZJVX00`1LG5coooooooooo`08ooooo`00
2_ooool0102i^KT0]kNg0;Ng]`2h^;P40;bl_080^KVi00@0]kNg0;Fe]@2e]KD0KVi^0P2BTY801@2b
/[80Z:RX0;Ng]`2g]kL0^;Rh0080^KVi00D0^;Rh0;Bd]02i^KT0^KVi0;Rh^0020;Ng]`<0^;Rh00@0
NWYj06][J`2][Jd0[Jf]0`2WYjL01@2_[jl0/K6a0;Rh^02h^;P0]kNg0080^;Rh00D0];Bd0;>c/`2]
[Jd0[Jf]0:ZZZP0209>CT`0503dm?@2SXj<0Xj>S0;2`/02TY:@00P2JVYX01@2BTY80S8b<08b<S024
Q8@0U9BD0080W9bL00<0XZ:R0:JVYP2VYZH00`2[Zj/01@1BDU80VYZJ0:BTY02TY:@0Xj>S0080YjNW
0P2YZJT20:JVYP040;6a/@2b/[80/[:b0;6a/@80Zj^[00D0[:b/0:n_[`1YJFT0JFUY0:JVYP020:RX
Z0050:BTY02VYZH0ZZZZ0:ZZZP2[Zj/00P2WYjL01@2/[:`0YjNW0:ZZZP2ZZZX0ZJVY0080YjNW00<0
QXJ607MgM`1gMgL00P2VYZH20:NWY`050:b/[02[Zj/0Zj^[0::RXP2SXj<00P2QXJ40102IVIT0V9RH
09RHV02?Shl207emO@0503dm?@1EEED0L71`071`L01]KFd00P1YJFT01@1ZJVX0MWIf07UiN@1iNGT0
MgMg0080NWYj00D0L71`06e]K@1UIFD0IFEU06ATI0020410@00505mOG`1SHf<0Hf=S06MWI`1VIVH0
0P1UIFD01@1SHf<0I6AT06ATI01SHf<0HV9R0080I6AT00@0IfMW05=CD`1CDe<0?clo0P0m?Cd01@1P
H600Hf=S06IVIP1VIVH0J6QX0080IVIV00<0GEeMooooooooool03oooool0101[Jf/0Ti>C09>CT`1/
K6`20410@0<0K6a/00D0J6QX05ADE01aLG40LG5a06UYJ@0207YjNP0506][J`1aLG40JVYZ06YZJP17
AdL00P13@d<01@1aLG40P8200820P02GUiL0IfMW00<0EUIF0P1<C4`01@1OGel0K6a/06a/K02JVYX0
QXJ60080HF5Q00@0Ti>C05mOG`1OGel0PX:20P1OGel01@1oOgl0`l?309^KV`2KVi/0GEeM0080@410
00D0JFUY09FEU@2MWId0WIfM0;6a/@020<30`0050::RXP2KVi/0Vi^K0:2PX028R8P00P1gMgL0101J
FUX0K6a/06a/K01jNWX209:BTP050<C4a01XJ6P0ZJVY0:VYZ@2BTY800P2h^;P01@37alL0c<c<08V9
R@29RHT0RXZ:0080][Jf00D0[Zj^07YjNP1jNWX0NGUi08j>SP0207IfMP0407YjNP2GUiL0UiNG05mO
G`80H61P00D0d];B07emO@28R8P0R8R8079bLP02075aL@0509jNWP2`/;00aLG50<G5a@2IVIT00P2B
TY801@1fMWH0b/[:0<[:bP1HF5P0UiNG0080MgMg00@0Lg=c07AdM01dM7@0YZJV0P3:b/X01@2EUID0
JFUY09bLW02LW9`0MgMg0080GemO00D0N7Qh0;6a/@2a/K40]KFe079bLP0204Y:BP0504=3@`11@D40
@D5106MWI`1eMGD00P1KFe/0101SHf<0J6QX06QXJ01gMgL208j>SP0507QhN01ZJVX0DU9B059BDP1h
N7P00P1cLg<01@2HV9P0[Zj^0:j^[P2?Shl0[:b/0080J6QX00D0PX:209^KV`2KVi/0VIVI07=cL`02
05iNGP0406MWI`1YJFT0JFUY06a/K080P82000<0Kfm_ooooooooool02?ooool000[ooooo00@0^;Rh
0;Ng]`2g]kL0_Kfm0P2n_[h00`2o_kl0_;bl0;Rh^0020;Rh^080]KFe00D0KFe]096AT@2ATI40[Jf]
09ZJVP020:VYZ@050:j^[P2/[:`0[:b/0:^[Z`2][Jd00P2_[jl30;Ng]`050;6a/@2ZZZX0ZZZZ08:2
PP1[Jf/00P2TY:@01@2UYJD0XZ:R0::RXP2QXJ40YZJV0080Z:RX00D0ZJVY0:n_[`2_[jl0[Zj^0;6a
/@020:n_[`040;:b/P2QXJ40XJ6Q04U9B@80[:b/00D0[jn_0:NWY`2HV9P0V9RH09NGU`0209BDU005
08j>SP2:RXX0S8b<08b<S02DU9@00P2SXj<01@2^[Zh0YjNW0:NWY`11@D40Ti>C00D0WIfM00D0YJFU
0:6QX@2TY:@0Y:BT0:j^[P020;6a/@050:^[Z`2][Jd0[Jf]0;Fe]@2c/k<00P1iNGT00`2[Zj/0YjNW
0:NWY`040:NWY`<0Z:RX00D0YjNW0:ZZZP2ZZZX0ZZZZ0:VYZ@020:ZZZP0308>3P`21PH40PH610080
/;2`0P2^[Zh01@2c/k<0];Bd0;Bd]02b/[80/;2`0080/[:b00@0];Bd0:ZZZP2ZZZX0Zj^[0P2YZJT0
1@1OGel0P8200:2PX02PX:00ZZZZ0080/[:b00D0/;2`0:j^[P2ZZZX0ZZZZ0:f][@020:NWY`050:BT
Y02XZ:P0[Jf]0:f][@2XZ:P00P1QHF401@2VYZH0[Zj^0:j^[P2_[jl0/;2`0080/K6a00D0];Bd0;>c
/`2c/k<0/K6a0:j^[P020:VYZ@040:ZZZP2DU9@0U9BD07emO@80IFEU00@0UIFE0:6QX@2/[:`0[:b/
0`2f][H00`2d];Coooooooooo`0?ooooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25
QHD0KFe]05QHF0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1c
Lg<207IfMP0508V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080
EEEE00@0S8b<05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN
0;Rh^02g]kL0]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad
07AdM01nOWh209fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?
S`80a<C400D0]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0
clo?08:2PP28R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0
fMWI0=WIf@1YJFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02X
Z:P0NWYj0080Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`
L7000P1JFUX0101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT0
1@2IVIT0Xj>S0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=
C@1IFET0FEUI05UIF@80Lg=c00<0EUIFooooooooool02?ooool000[ooooo00@0^;Rh0;Ng]`2g]kL0
_Kfm0P2n_[h00`2o_kl0_;bl0;Rh^0020;Rh^080]KFe00D0KFe]096AT@2ATI40[Jf]09ZJVP020:VY
Z@050:j^[P2/[:`0[:b/0:^[Z`2][Jd00P2_[jl30;Ng]`050;6a/@2ZZZX0ZZZZ08:2PP1[Jf/00P2T
Y:@01@2UYJD0XZ:R0::RXP2QXJ40YZJV0080Z:RX00D0ZJVY0:n_[`2_[jl0[Zj^0;6a/@020:n_[`04
0;:b/P2QXJ40XJ6Q04U9B@80[:b/00D0[jn_0:NWY`2HV9P0V9RH09NGU`0209BDU00508j>SP2:RXX0
S8b<08b<S02DU9@00P2SXj<01@2^[Zh0YjNW0:NWY`11@D40Ti>C00D0WIfM00D0YJFU0:6QX@2TY:@0
Y:BT0:j^[P020;6a/@050:^[Z`2][Jd0[Jf]0;Fe]@2c/k<00P1iNGT00`2[Zj/0YjNW0:NWY`040:NW
Y`<0Z:RX00D0YjNW0:ZZZP2ZZZX0ZZZZ0:VYZ@020:ZZZP0308>3P`21PH40PH610080/;2`0P2^[Zh0
1@2c/k<0];Bd0;Bd]02b/[80/;2`0080/[:b00@0];Bd0:ZZZP2ZZZX0Zj^[0P2YZJT01@1OGel0P820
0:2PX02PX:00ZZZZ0080/[:b00D0/;2`0:j^[P2ZZZX0ZZZZ0:f][@020:NWY`050:BTY02XZ:P0[Jf]
0:f][@2XZ:P00P1QHF401@2VYZH0[Zj^0:j^[P2_[jl0/;2`0080/K6a00D0];Bd0;>c/`2c/k<0/K6a
0:j^[P020:VYZ@040:ZZZP2DU9@0U9BD07emO@80IFEU00@0UIFE0:6QX@2/[:`0[:b/0`2f][H00`2d
];Coooooooooo`0?ooooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25QHD0KFe]05QH
F0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1cLg<207IfMP05
08V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080EEEE00@0S8b<
05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN0;Rh^02g]kL0
]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad07AdM01nOWh2
09fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?S`80a<C400D0
]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0clo?08:2PP28
R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0fMWI0=WIf@1Y
JFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02XZ:P0NWYj0080
Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`L7000P1JFUX0
101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT01@2IVIT0Xj>S
0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=C@1IFET0FEUI
05UIF@80Lg=c00<0EUIFooooooooool02?ooool000[ooooo00@0]kNg0;Fe]@2e]KD0]kNg0P2h^;P2
0;Fe]@80];Bd00@0]kNg0;2`/02`/;00JFUY0P2:RXX00`2YZJT0V9RH0:VYZ@020:VYZ@80[Zj^00@0
YZJV0:VYZ@2[Zj/0Zj^[0`2^[Zh01@2_[jl0Zj^[0:^[Z`1mOGd0IFEU0080VYZJ00D0TY:B09nOW`2O
Wil0XZ:R0:FUY@030:NWY`80ZJVY00D0YjNW0:j^[P2][Jd0[Jf]0;6a/@020:j^[P0504Q8B02UYJD0
YJFU0:RXZ02KVi/00P2ATI401@2DU9@0Ph>308>3P`24Q8@0PX:200<0QHF50P2HV9P01@2XZ:P0UYJF
09JFUP0o?cl0SXj>0080UYJF00<0UiNG09ZJVP2JVYX00P2LW9`209^KV`030:f][@2/[:`0[:b/00<0
ZZZZ00D0/k>c0;6a/@1_Kfl0Kfm_0:NWY`0209nOW`050:2PX02OWil0YJFU0:FUY@2OWil00P2QXJ40
1@2SXj<0YJFU0:BTY02TY:@0YJFU0080YjNW00@0PX:208^;R`2;Rh/0[:b/0`2][Jd01@2ZZZX0Z:RX
0:RXZ02VYZH0[:b/0080Zj^[00@0/;2`0:^[Z`2[Zj/0[Jf]0P2WYjL01@1>CTh0MWIf09jNWP2NWYh0
[:b/0080ZJVY00@0Zj^[0:ZZZP2WYjL0YjNW0`2SXj<01@2LW9`0XZ:R09nOW`2OWil0ZJVY0080G5aL
00D0WYjN0:b/[02/[:`0Z:RX0:ZZZP020:VYZ@050:b/[02^[Zh0[Zj^0;>c/`2_[jl00P2XZ:P30:NW
Y`0309^KV`1WIfL0IfMW0080UIFE0P2WYjL0102ZZZX0[jn_0:n_[`2^[ZhAooooo`04069RHP2HV9P0
V9RH06ATI080>c/k00D0KVi^07QhN01hN7P0JFUY05eMG@0208B4Q00505UIF@1kNg/0Ng]k06a/K01k
Ng/00P1PH6001016ATH0De=C05=CD`1eMGD208b<S00508n?S`1`L700IVIV06IVIP1HF5P00P1>CTh0
1@1QHF40M7Ad07AdM02IVIT0RXZ:0080FEUI00@0VIVI05ADE01DE5@0PH610P1`L7001@1jNWX0_kno
08F5Q@25QHD0BTY:0080DU9B00D0FEUI0:VYZ@2c/k<0/k>c0;jn_P020;Vi^@0508Z:RP2NWYh0WYjN
09VIV@2;Rh/00P1eMGD0101HF5P0IfMW06MWI`1lO7`208n?S`050:n_[`1DE5@0U9BD09BDU024Q8@0
0P2^[Zh00`37alL0fMWI09>CT`0209>CT`80aLG500D0[jn_08J6QP26QXH0RHV907=cL`02079bLP04
06e]K@2BTY80TY:B061PH080KVi^00D0emOG092@T02?Shl0Shn?09BDU00206i^KP050;Jf]P2SXj<0
bLW90<W9b@2/[:`00P21PH401@1`L700gmoO0=oOg`1_Kfl0TY:B0080Ng]k00@0N7Qh07alO01lO7`0
YjNW0P3@d=001@2NWYh0IfMW0:FUY@2UYJD0RHV90080MWIf00D0NWYj09NGU`2GUiL0_;bl07AdM002
0451@@<0@41000D0H61P08Z:RP1NGUh0GUiN04i>CP0205eMG@0506MWI`1VIVH0IVIV07EeM@1?Cdl0
0P1DE5@0101nOWh0NGUi07UiN@2EUID20;Jf]P0509FEU@2`/;00P8200820P025QHD00P2PX:001@2/
[:`0QHF5069RHP1RHV80FUYJ0080HV9R00@0Jf][08B4Q024Q8@0LG5a2_ooool000[ooooo00@0QhN7
08:2PP22PX80OGem0P1kNg/01@1mOGd0Q8B408f=S@2=SHd0RXZ:0080S8b<00D0FUYJ07alO01lO7`0
T92@079bLP0209:BTP0509BDU02LW9`0W9bL09bLW02KVi/00P2PX:00102QXJ40ZJVY0:VYZ@2XZ:P2
0:JVYP0507MgM`1?Cdl0S8b<08b<S02BTY800P2HV9P01@2PX:00XJ6Q0:2PX02PX:00Y:BT0080VYZJ
00D0[:b/0;:b/P2^[Zh0[Zj^0:b/[0020;2`/00504a<C02WYjL0YjNW0:2PX02?Shl00P2<S8`01@2A
TI40Ph>308>3P`22PX80Ng]k0080P82000@0Ogmo08B4Q024Q8@0U9BD0P2>SXh01@1GEeL0Rh^;08j>
SP2>SXh0Q8B40080QhN700D0SXj>0:2PX02OWil0WinO0:j^[P030:f][@80Zj^[00D0[jn_0:ZZZP1V
IVH0IVIV09VIV@0209NGU`0509>CT`2ATI40TI6A096AT@2FUYH00P2NWYh01@2OWil0Z:RX09jNWP2N
WYh0WinO0080XZ:R00D0NWYj0820P020P800ZJVY0:RXZ0020:NWY`050:RXZ02VYZH0YZJV0:FUY@2T
Y:@00P2VYZH30:>SX`050:JVYP2QXJ40XJ6Q05aLG01iNGT00P2GUiL01@2ZZZX0Zj^[0:^[Z`2YZJT0
Y:BT0080WIfM0`2NWYh01@2CTi<0U9BD09JFUP2FUYH0WIfM0080FEUI00<0X:2P0:JVYP2VYZH00P2[
Zj/30:NWY`80[:b/00<0[jn_0:j^[P2HV9P00P2HV9P20:FUY@0509RHV01[Jf/0Jf][08^;R`1hN7P0
0P2FUYH0102UYJD0YjNW0:NWY`2WYjLAooooo`04069RHP2YZJT0ZJVY07EeM@80C4a<00D0NWYj08F5
Q@25QHD0MWIf05aLG00208R8R00507alO02GUiL0UiNG07QhN01`L7000P1TI6@01013@d<0GemO05mO
G`1YJFT207moO`0508F5Q@1cLg<0F5QH05QHF016ATH00P0l?3`01@1MGEd0LW9b079bLP2?Shl0TY:B
0080P82000@0WYjN05YJFP1JFUX0Ogmo0`22PX80103AdM40QhN708N7Q`1SHf<207AdM00506ATI02d
];@0^;Rh0;Rh^030`<000P2h^;P01@2VYZH0R8R808R8R02OWil0Rh^;0080MGEe00@0FEUI071`L01`
L700QhN70P2CTi<01@34a<@0GUiN09NGU`2GUiL0QHF50080Zj^[00<0^k^k0<W9b@24Q8@00P24Q8@2
0;^k^`050;fm_@22PX80PX:208J6QP1lO7`00P1kNg/0101mOGd0Vi^K09^KV`1GEeL206QXJ0050<_;
b`2XZ:P0RHV908V9R@2@T9000P1WIfL01@2h^;P0[:b/0<K6aP36a/H0VYZJ0080K6a/00D0DU9B0=WI
f@3IfMT0Ogmo092@T00208N7Q`0409>CT`2EUID0UIFE0;no_`80g=cL00D0XJ6Q07EeM@2d];@0];Bd
08f=S@0208Z:RP0507=cL`2JVYX0VYZJ0<[:bP1/K6`00P15ADD01@13@d<0?3`l03`l?01FEUH0Q8B4
0080De=C00@0GEeM06QXJ01XJ6P0KFe]0P1KFe/01@1oOgl0A4A405EEE@1EEED0L71`0080KVi^00D0
RXZ:0:ZZZP2ZZZX0P8200;Ng]`0208f=S@0508R8R02HV9P0V9RH0:j^[P1mOGd00P1DE5@0101LG5`0
JVYZ06YZJP1GEeL207YjNP03069RH_oooooooooo00Sooooo000:ooooo`0408N7Q`22PX80PX:207em
O@80Ng]k00D0OGem08B4Q02=SHd0SHf=08Z:RP0208b<S00505YJFP1lO7`0O7al092@T01bLW800P2B
TY801@2DU9@0W9bL09bLW02LW9`0Vi^K0080X:2P00@0XJ6Q0:VYZ@2YZJT0Z:RX0P2VYZH01@1gMgL0
Cdm?08b<S02<S8`0TY:B0080V9RH00D0X:2P0:6QX@2PX:00X:2P0:BTY00209ZJVP050:b/[02b/[80
[Zj^0:j^[P2/[:`00P2`/;001@1<C4`0YjNW0:NWY`2PX:00Shn?0080S8b<00D0TI6A08>3P`23Ph<0
PX:207]kN`020820P00407moO`24Q8@0Q8B409BDU080SXj>00D0EeMG08^;R`2>SXh0SXj>08B4Q002
08N7Q`0508j>SP2PX:00WinO09nOW`2^[Zh00`2][Jd20:^[Z`050:n_[`2ZZZX0IVIV06IVIP2IVIT0
0P2GUiL01@2CTi<0TI6A096AT@2ATI40UYJF0080WYjN00D0WinO0:RXZ02NWYh0WYjN09nOW`020::R
XP0507YjNP20P800P8200:VYZ@2XZ:P00P2WYjL01@2XZ:P0YZJV0:JVYP2UYJD0Y:BT0080YZJV0`2S
Xj<01@2VYZH0XJ6Q0:6QX@1LG5`0NGUi0080UiNG00D0ZZZZ0:^[Z`2[Zj/0ZJVY0:BTY00209fMW@<0
WYjN00D0Ti>C09BDU02FUYH0UYJF09fMW@0205UIF@030:2PX02VYZH0YZJV0080Zj^[0`2WYjL20:b/
[0030:n_[`2^[Zh0V9RH0080V9RH0P2UYJD01@2HV9P0Jf][06][J`2;Rh/0N7Qh0080UYJF00@0YJFU
0:NWY`2WYjL0YjNW4Oooool0101RHV80ZJVY0:VYZ@1eMGD204a<C00507YjNP25QHD0QHF507IfMP1L
G5`00P28R8P01@1lO7`0UiNG09NGU`1hN7P0L71`0080I6AT00@0@d=305mOG`1OGel0JFUY0P1oOgl0
1@25QHD0Lg=c05QHF01HF5P0ATI60080?3`l00D0GEeM079bLP1bLW80Shn?09:BTP020820P00409jN
WP1JFUX0FUYJ07moO`<0PX:200@0dM7A08N7Q`27QhL0Hf=S0P1dM7@01@1TI6@0];Bd0;Rh^02h^;P0
`<300080^;Rh00D0YZJV08R8R028R8P0WinO08^;R`0207EeM@0405UIF@1`L700L71`08N7Q`80Ti>C
00D0a<C405iNGP2GUiL0UiNG08F5Q@020:^[Z`030;^k^`39bLT0Q8B40080Q8B40P2k^k/01@2m_Kd0
PX:208:2PP26QXH0O7al0080Ng]k00@0OGem09^KV`2KVi/0EeMG0P1XJ6P01@3;bl/0Z:RX08V9R@29
RHT0T92@0080IfMW00D0^;Rh0:b/[036a/H0a/K609ZJVP0206a/K005059BDP3IfMT0fMWI07moO`2@
T9000P27QhL0102CTi<0UIFE09FEU@2o_kl20=cLg0050:6QX@1eMGD0];Bd0;Bd]02=SHd00P2:RXX0
1@1cLg<0VYZJ09ZJVP3:b/X0K6a/0080ADE500D0@d=303`l?00l?3`0EUIF08B4Q00205=CD`0405eM
G@1XJ6P0J6QX06e]K@80Fe]K00D0Ogmo04A4A01EEED0EEEE071`L00206i^KP0508Z:RP2ZZZX0ZZZZ
0820P02g]kL00P2=SHd01@28R8P0V9RH09RHV02^[Zh0OGem0080E5AD00@0G5aL06YZJP1ZJVX0EeMG
0P1jNWX00`1RHV;oooooooooo`08ooooo`002_ooool0101YJFT0GemO05mOG`1ADE42030`<00504e=
C@1@D500BDU904U9B@12@T800P0i>CT01@1;Bd/0Cdm?04m?C`16ATH0BDU90080ATI600D0AdM704m?
C`1?Cdl0>CTi02TY:@0203lo?`0404I6AP1;Bd/0Bd];0451@@80?Cdm00D0>CTi02/[:`0`<300<30`
02XZ:P0202<S8`0302l_;`0V9RH08b<S00808b<S0P0Z:RX01@1<C4`0FUYJ061PH01PH600GEeM0080
BDU900D0@D5106UYJ@1YJFT0LW9b06YZJP0205EEE@0504m?C`1KFe/0Fe]K05eMG@1GEeL00P1RHV80
101[Jf/0EEEE05EEE@1HF5P205MGE`0503Lg=`0i>CT0A4A404A4A010@4000P12@T801@1=CDd0DE5A
059BDP1BDU80C4a<0080F5QH00D0EUIF05QHF01HF5P0DU9B04e=C@020492@P0306EUI@1WIfL0IfMW
0080KFe]0P1[Jf/01@1VIVH0IfMW06MWI`1TI6@0G5aL0080Hf=S00@0IFEU069RHP1RHV80DE5A0P1G
EeL01@1jNWX0P820079bLP1bLW80MGEe0080Ogmo0P21PH4207moO`04071`L01iNGT0NGUi07inOP80
Ogmo00D0BTY:06=SH`1WIfL0IfMW07IfMP0207QhN00507emO@1aLG40HV9R069RHP1IFET00P1>CTh0
1@1MGEd0Fe]K05UIF@1IFET0Hf=S0080B4Q800D0NWYj08:2PP22PX80RXZ:071`L00207EeM@0308^;
R`2BTY80TY:B0080Shn?0P23Ph<0101hN7P0RHV908V9R@1XJ6P205UIF@0507=cL`1^KVh0RXZ:08Z:
RP2PX:000P2MWId00`2LW9coooooooooo`0?ooooo`0406MWI`2MWId0WIfM079bLP80A4A400D0L71`
07]kN`1kNg/0IFEU04e=C@0206][J`0506QXJ01iNGT0NGUi06a/K01cLg<00P1KFe/0100l?3`0G5aL
05aLG01lO7`208N7Q`0507inOP1]KFd0D51@051@D01HF5P00P1FEUH01@1lO7`0Kfm_06m_K`2HV9P0
Rh^;0080NWYj00@0U9BD04i>CP1>CTh0L71`0P1VIVH01@1fMWH0/K6a06a/K01/K6`0GEeM0080FEUI
00<0H61P0:2PX02KVi/00P2KVi/309JFUP80QhN700D0TI6A08V9R@1eMGD0MGEe05YJFP020861P@05
0820P02GUiL0UiNG0<O7a`1QHF400P2PX:001@25QHD0]kNg0;Ng]`2o_kl0dm?C0080S8b<00@0TI6A
0;jn_P2n_[h0]kNg0P24Q8@01@1hN7P0Kfm_07]kN`1kNg/0NGUi0080S8b<00D0G5aL06i^KP1^KVh0
`l?309nOW`0207IfMP0508n?S`1NGUh0GUiN0;Fe]@2ZZZX00P2l_;`0102IVIT0H61P061PH01@D502
0=KFeP0507=cL`27QhL0Ph>308>3P`26QXH00P2@T9001@2/[:`0dm?C0=?Cd`2RXZ80KFe]0080/k>c
00@0W9bL09RHV02HV9P0N7Qh0P2DU9@01@3?cll0J6QX0410@010@400>SXj0080>3Ph00D0C4a<07em
O@1DE5@0E5AD06QXJ00205UIF@0506UYJ@1MGEd0GEeM06i^KP1?Cdl00P1QHF40101ZJVX0NGUi07Ui
N@2YZJT20:b/[00509^KV`30`<00UiNG09NGU`2ATI400P2a/K401@2_[jl0OWin05mOG`1OGel0H61P
0080JFUY00@0E5AD07IfMP1fMWH0FUYJ2_ooool000[ooooo00@0^[Zj0;Vi^@2i^KT0/K6a0P1_Kfl0
1@2i^KT0]KFe0;2`/02`/;00];Bd0080[Jf]00D0/[:b0;>c/`2c/k<0]kNg0;Zj^P020;jn_P050;no
_`2j^[X0^[Zj0:JVYP1JFUX00P1lO7`01028R8P0/k>c0;>c/`2j^[X20;Vi^@050;jn_P2e]KD0/[:b
0;:b/P2^[Zh00P2UYJD20:b/[080YjNW00D0BTY:0:ZZZP2ZZZX0];Bd0;>c/`020;2`/0040:f][@2`
/;00/;2`0::RXP<0[jn_00@0[:b/0:6QX@2QXJ40Vi^K0P2=SHd01@1@D500WYjN0:b/[02/[:`0YjNW
0080Y:BT0`2XZ:P01@2RXZ80WIfM09fMW@2MWId0UIFE0080WinO00D0Vi^K07alO015ADD0ADE507mo
O`0208Z:RP0508F5Q@27QhL0QhN708b<S02?Shl00P24Q8@01@2;Rh/0SXj>08j>SP2>SXh0TI6A0080
UIFE00D0S8b<05IFEP1FEUH0L71`07YjNP0207UiN@0407]kN`1fMWH0MWIf07=cL`80KFe]00D0J6QX
06ATI01HF5P0F5QH05UIF@0205MGE`0502`/;00g=cL0GUiN05iNGP1JFUX00P1EEED01@1HF5P0GUiN
05iNGP1TI6@0G5aL0080EUIF00D0HF5Q05YJFP1JFUX0B4Q803`l?00205aLG0<0IFEU00D0FEUI05EE
E@1KFe/0Fe]K06ATI00206QXJ00505mOG`1DE5@0E5AD04i>CP13@d<00P0V9RH01@0h>3P0AdM704M7
A`0n?Sh0@D5100<0?clo0P0l?3`01@15ADD0@T920492@P19BDT0CDe=0080F5QH00@0De=C03hn?P0n
?Sh0A4A44Oooool0101ZJVX0ZJVY0:VYZ@1/K6`20492@P0506e]K@1eMGD0MGEe06EUI@1IFET00P1o
Ogl01@1YJFT0P8200820P02<S8`0RXZ:0080FUYJ00@0>CTi05iNGP1NGUh0Hf=S0P21PH401@2=SHd0
NGUi05iNGP1NGUh0F5QH0080BDU900D0NGUi061PH01PH600WinO0:BTY00208>3P`040:ZZZP1MGEd0
GEeM07MgM`<0KVi^00@0_[jn08f=S@2=SHd0Fe]K0P1IFET01@1cLg<0^[Zj0<C4a034a<@0][Jf0080
[Zj^00D0/[:b09bLW02LW9`0Y:BT08^;R`0207AdM00405IFEP1`L700L71`08>3P`80WYjN00D0`l?3
05iNGP2/[:`0[:b/08f=S@020;Zj^P050<30`03Fe]H0Ti>C09>CT`29RHT00P2a/K401@2c/k<0SHf=
08f=S@1fMWH0L71`0080MgMg00@0MWIf08b<S02<S8`0Hf=S0P1cLg<01@30`<00VIVI06m_K`1_Kfl0
QhN70080H61P00D0_[jn0:b/[02^[Zh0[Zj^0:n_[`02075aL@0504];B`3Fe]H0e]KF07=cL`2CTi<0
0P1eMGD0101kNg/0LG5a075aL@2MWId20<k>cP0508R8R01RHV80_Kfm0;fm_@2TY:@00P2FUYH01@1i
NGT0S8b<08b<S037alL0K6a/0080@D510`0g=cL01@1CDe<0Kfm_06EUI@1UIFD0J6QX0080Kfm_00D0
J6QX07EeM@1eMGD0NGUi055AD@0206QXJ00405aLG028R8P0R8R809^KV`80Zj^[00D0U9BD0;Ng]`2O
Wil0WinO05]KF`0207alO00509RHV01kNg/0Jf][06][J`1NGUh00P1RHV80101KFe/0TI6A096AT@1P
H60:ooooo`002_ooool0102e]KD0];Bd0;Bd]02^[Zh2075aL@050;>c/`2d];@0]kNg0;Ng]`2b/[80
0P2^[Zh01@2a/K40[Jf]0:f][@2g]kL0^k^k0080^[Zj00D0]kNg0;6a/@2a/K40[Zj^04i>CP0208j>
SP0409FEU@2[Zj/0Zj^[0:n_[`80]kNg00D0];Bd0;6a/@2[Zj/0Zj^[0:RXZ0020:FUY@050:RXZ02T
Y:@0WYjN09jNWP1CDe<00P2_[jl01@2^[Zh0/;2`0:j^[P2^[Zh0YjNW0080/;2`0`2^[Zh00`2[Zj/0
YJFU0:^[Z`020:^[Z`80[:b/00D0H61P0:b/[02a/K40/K6a0;:b/P020;Jf]P050;Fe]@2d];@0];Bd
0;2`/02[Zj/00P2KVi/01@2MWId0[:b/0:b/[02b/[80Y:BT0080De=C00@0WinO0:FUY@2UYJD0W9bL
0P2KVi/01@2TY:@0YjNW0:JVYP2VYZH0YJFU0080Xj>S00D0YZJV0:b/[02^[Zh0[Zj^0;:b/P0207If
MP030;Vi^@2m_Kd0_Kfm0080_Kfm0`2o_kl20<30`0050;no_`2l_;`0][Jf0;Jf]P2c/k<00P2k^k/0
1@0o?cl0S8b<0:NWY`2WYjL0Z:RX00<0ZZZZ0P2_[jl00`2d];@0^;Rh0;^k^`020;^k^`80^;Rh00D0
KFe]06i^KP2TY:@0Y:BT0:VYZ@020;:b/P050;Rh^02m_Kd0^k^k0;^k^`2m_Kd00P2k^k/01@2h^;P0
/K6a0;6a/@2_[jl0WYjN0080DE5A00D0U9BD0:j^[P2^[Zh0ZJVY0:b/[0020;Bd]0040;>c/`2`/;00
/;2`0;Vi^@80]kNg00D0_[jn0;fm_@2m_Kd0_Kfm0:b/[00206YZJP030:j^[_oooooooooo00oooooo
00@0KVi^0:BTY02TY:@0LG5a0P16ATH01@1fMWH0Ph>308>3P`1cLg<0IVIV0080Ogmo00D0MGEe09:B
TP2BTY80Q8B40820P00205]KF`040492@P1]KFd0KFe]05]KF`80LW9b00D0NWYj06e]K@1<C4`0C4a<
04=3@`0204e=C@0505iNGP1@D500D51@08:2PP29RHT00P1mOGd0102EUID0EUIF05IFEP1_Kfl207Ui
N@050820P03EeMD0T92@092@T01TI6@00P1LG5`01@1`L700Z:RX0;Fe]@2e]KD0^k^k0080[jn_00D0
ZZZZ09^KV`2KVi/0Ti>C08N7Q`0207MgM`0406=SH`1jNWX0NWYj07EeM@80PH6100D0[jn_05MGE`2V
YZH0YZJV09ZJVP020;Rh^0050<;2`P3:b/X0TI6A096AT@25QHD00P2f][H01@2c/k<0V9RH09RHV01_
Kfl0Lg=c0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01@35aLD0Xj>S069RHP1RHV80LG5a0080
DU9B00D0^k^k0:j^[P36a/H0a/K60;>c/`0207YjNP0504M7A`3Ph>00h>3P0861P@2@T9000P22PX80
102<S8`0Rh^;08^;R`2d];@20=gMg@0509>CT`1[Jf/0^;Rh0;Rh^02YZJT00P2CTi<01@1aLG40OGem
07emO@34a<@0MWIf0080B4Q80`0i>CT01@10@400HV9R07QhN01hN7P0GemO0080Ph>300D0MgMg07al
O01lO7`0JVYZ05iNGP0206YZJP0406=SH`20P800P8200:ZZZP80Zj^[00D0QHF50;Ng]`2l_;`0_;bl
07AdM00208n?S`050:>SX`24Q8@0Fe]K05]KF`1[Jf/00P1ZJVX0101WIfL0RXZ:08Z:RP1gMgL:oooo
o`002_ooool0102e]KD0];Bd0;Bd]02^[Zh2075aL@050;>c/`2d];@0]kNg0;Ng]`2b/[800P2^[Zh0
1@2a/K40[Jf]0:f][@2g]kL0^k^k0080^[Zj00D0]kNg0;6a/@2a/K40[Zj^04i>CP0208j>SP0409FE
U@2[Zj/0Zj^[0:n_[`80]kNg00D0];Bd0;6a/@2[Zj/0Zj^[0:RXZ0020:FUY@050:RXZ02TY:@0WYjN
09jNWP1CDe<00P2_[jl01@2^[Zh0/;2`0:j^[P2^[Zh0YjNW0080/;2`0`2^[Zh00`2[Zj/0YJFU0:^[
Z`020:^[Z`80[:b/00D0H61P0:b/[02a/K40/K6a0;:b/P020;Jf]P050;Fe]@2d];@0];Bd0;2`/02[
Zj/00P2KVi/01@2MWId0[:b/0:b/[02b/[80Y:BT0080De=C00@0WinO0:FUY@2UYJD0W9bL0P2KVi/0
1@2TY:@0YjNW0:JVYP2VYZH0YJFU0080Xj>S00D0YZJV0:b/[02^[Zh0[Zj^0;:b/P0207IfMP030;Vi
^@2m_Kd0_Kfm0080_Kfm0`2o_kl20<30`0050;no_`2l_;`0][Jf0;Jf]P2c/k<00P2k^k/01@0o?cl0
S8b<0:NWY`2WYjL0Z:RX00<0ZZZZ0P2_[jl00`2d];@0^;Rh0;^k^`020;^k^`80^;Rh00D0KFe]06i^
KP2TY:@0Y:BT0:VYZ@020;:b/P050;Rh^02m_Kd0^k^k0;^k^`2m_Kd00P2k^k/01@2h^;P0/K6a0;6a
/@2_[jl0WYjN0080DE5A00D0U9BD0:j^[P2^[Zh0ZJVY0:b/[0020;Bd]0040;>c/`2`/;00/;2`0;Vi
^@80]kNg00D0_[jn0;fm_@2m_Kd0_Kfm0:b/[00206YZJP030:j^[_oooooooooo00oooooo00@0KVi^
0:BTY02TY:@0LG5a0P16ATH01@1fMWH0Ph>308>3P`1cLg<0IVIV0080Ogmo00D0MGEe09:BTP2BTY80
Q8B40820P00205]KF`040492@P1]KFd0KFe]05]KF`80LW9b00D0NWYj06e]K@1<C4`0C4a<04=3@`02
04e=C@0505iNGP1@D500D51@08:2PP29RHT00P1mOGd0102EUID0EUIF05IFEP1_Kfl207UiN@050820
P03EeMD0T92@092@T01TI6@00P1LG5`01@1`L700Z:RX0;Fe]@2e]KD0^k^k0080[jn_00D0ZZZZ09^K
V`2KVi/0Ti>C08N7Q`0207MgM`0406=SH`1jNWX0NWYj07EeM@80PH6100D0[jn_05MGE`2VYZH0YZJV
09ZJVP020;Rh^0050<;2`P3:b/X0TI6A096AT@25QHD00P2f][H01@2c/k<0V9RH09RHV01_Kfl0Lg=c
0080KVi^00@0Q8B408Z:RP2:RXX0M7Ad0P1eMGD01@35aLD0Xj>S069RHP1RHV80LG5a0080DU9B00D0
^k^k0:j^[P36a/H0a/K60;>c/`0207YjNP0504M7A`3Ph>00h>3P0861P@2@T9000P22PX80102<S8`0
Rh^;08^;R`2d];@20=gMg@0509>CT`1[Jf/0^;Rh0;Rh^02YZJT00P2CTi<01@1aLG40OGem07emO@34
a<@0MWIf0080B4Q80`0i>CT01@10@400HV9R07QhN01hN7P0GemO0080Ph>300D0MgMg07alO01lO7`0
JVYZ05iNGP0206YZJP0406=SH`20P800P8200:ZZZP80Zj^[00D0QHF50;Ng]`2l_;`0_;bl07AdM002
08n?S`050:>SX`24Q8@0Fe]K05]KF`1[Jf/00P1ZJVX0101WIfL0RXZ:08Z:RP1gMgL:ooooo`002_oo
ool0102e]KD0/K6a0;6a/@2VYZH206i^KP050;>c/`2h^;P0^KVi0;Vi^@2d];@00P2a/K401@2^[Zh0
Zj^[0:^[Z`2b/[80]kNg0080]KFe00D0/[:b0:b/[02/[:`0[Jf]05eMG@020:VYZ@040:>SX`2][Jd0
[Jf]0:VYZ@80YZJV00<0ZJVY0:NWY`2SXj<00P2SXj<20:NWY`050:ZZZP2PX:00RXZ:08Z:RP1OGel0
0P2^[Zh01@2/[:`0ZZZZ0:VYZ@2YZJT0WYjN0080YZJV00D0ZZZZ0:BTY02TY:@0YZJV0:NWY`020:JV
YP050:ZZZP2`/;00/;2`075aL@2a/K400P2][Jd0102d];@0/K6a0;6a/@2][Jd20:FUY@050::RXP2M
WId0XZ:R0::RXP2SXj<00P2ZZZX0102/[:`0YZJV04];B`1;Bd/309jNWP0508n?S`2GUiL0UiNG09:B
TP2NWYh00P2LW9`01@2NWYh0Y:BT0:BTY02RXZ80ZJVY0080[Jf]00D0/;2`075aL@1aLG40^KVi0;jn
_P020;no_`040<71`@32`/80`/;20;jn_P80[jn_00D0/[:b0;Jf]P2e]KD0]KFe0;Rh^0020;Vi^@05
04e=C@2TY:@0YjNW0:NWY`2[Zj/00P2YZJT01@2ZZZX0[jn_0:n_[`2b/[80]KFe0080];Bd00D0]kNg
0;Jf]P2f][H0JFUY071`L0020:NWY`050:j^[P2c/k<0/k>c0;Ng]`2k^k/00P2m_Kd30;Zj^P050;Fe
]@2b/[80/[:b0:b/[02<S8`00P1:BTX00`2KVi/0ZZZZ0:ZZZP020:j^[P80[jn_00@0/;2`0;:b/P2b
/[80^[Zj0P2h^;P01@2k^k/0^[Zj0;Vi^@2i^KT0[jn_0080M7Ad00<0/K6aooooooooool03oooool0
101OGel0UYJF09JFUP1kNg/204a<C00507=cL`1fMWH0MWIf07=cL`1NGUh00P1oOgl01@1fMWH0Rh^;
08^;R`1UIFD0IVIV0080CTi>00@0>3Ph075aL@1aLG40JFUY0P27QhL01@2;Rh/0M7Ad05YJFP1JFUX0
EEEE0080@41000D0LW9b05EEE@1EEED0TY:B08j>SP0207inOP0409bLW01TI6@0I6AT07IfMP80MGEe
00D0Ng]k0<c<c02;Rh/0Rh^;061PH002055AD@0306i^KP2YZJT0/[:b0080/[:b0P2RXZ801@2VYZH0
T92@092@T02ATI40OWin0080KVi^00@0FEUI06a/K01/K6`0NGUi0P2CTi<01@2m_Kd0GEeM08b<S02<
S8`0Shn?0080]KFe00D0_Kfm0<G5a@2<S8`0S8b<07UiN@020:^[Z`050:6QX@2GUiL0UiNG07QhN01]
KFd00P1gMgL0102CTi<0Q8B408B4Q01gMgL208R8R0050;Rh^02OWil0EeMG05MGE`1bLW800P1@D500
1@33`l<0^[Zj0;Jf]P2f][H0ZJVY0080JVYZ00D0@4100=3@d03@d=00NWYj09jNWP020861P@0407Mg
M`1XJ6P0J6QX09NGU`80alO700D0T92@07=cL`2n_[h0_[jn0;Ng]`0208:2PP0506i^KP2:RXX0RXZ:
0<[:bP2?Shl00P1?Cdl01@0n?Sh0;Rh^02h^;P14A4@0LG5a0080UIFE00@0J6QX0820P020P800MWIf
0P1mOGd01@1fMWH0FEUI07QhN01hN7P0H61P0080Ogmo00D0ZZZZ0:JVYP2VYZH0TI6A0;jn_P020;Jf
]P05071`L02FUYH0UYJF0:JVYP2ATI400P1XJ6P0101fMWH0GemO05mOG`1dM7@208f=S@0307UiNOoo
oooooooo00Sooooo000:ooooo`040:n_[`2ZZZX0ZZZZ0:NWY`80MgMg00D0]KFe0;Ng]`2h^;P0^;Rh
0:f][@020:6QX@050:BTY02YZJT0ZJVY0;>c/`2d];@00P2b/[801@2][Jd0ZJVY0:VYZ@2WYjL0F5QH
0080[Jf]00@0ZZZZ0:b/[02/[:`0[Zj^0P2TY:@01@2RXZ80YJFU09ZJVP2JVYX0X:2P0080Xj>S00D0
YjNW0:ZZZP2?Shl0Shn?05YJFP020:j^[P050:RXZ02YZJT0YjNW0:NWY`2BTY800P2IVIT01@2HV9P0
UIFE09FEU@2IVIT0Z:RX0080ZZZZ00@0YjNW0:n_[`2_[jl0I6AT0`2^[Zh0102/[:`0[Zj^0:j^[P2T
Y:@20:FUY@050:JVYP2UYJD0YZJV0:JVYP2SXj<00P2QXJ401@2UYJD0[jn_04e=C@1=CDd0WIfM0080
Vi^K00D0Ph>307moO`1oOgl0O7al08Z:RP02096AT@0409BDU02SXj<0Xj>S0:2PX0@0ZZZZ0P1bLW80
102m_Kd0`L710<30`030`<030;fm_@050;^k^`2i^KT0^KVi0;>c/`2k^k/00P2g]kL0102l_;`0^[Zj
0;Zj^P1HF5P309ZJVP0408j>SP2DU9@0U9BD0:2PX080YjNW00<0/;2`0;Fe]@2i^KT00P2i^KT20:j^
[P0304i>CP1]KFd0Zj^[0080Zj^[0P2/[:`01@2[Zj/0[Jf]0;Ng]`2g]kL0]KFe0080[Zj^00D0ZZZZ
0:>SX`2SXj<0Z:RX09BDU00204];B`0309VIV@2QXJ40XJ6Q00@0YZJV00@0UiNG0:FUY@2UYJD0X:2P
0P2QXJ401@2YZJT0/K6a0:RXZ02XZ:P0Xj>S0080OGem00<0];Bdooooooooool03oooool0101WIfL0
S8b<08b<S01kNg/204I6AP0507EeM@21PH40PH6107AdM01GEeL00P1gMgL01@1YJFT0Ogmo07moO`1h
N7P0Ng]k0080@d=300@0ADE5061PH01PH600De=C0P1nOWh01@21PH40J6QX05=CD`1CDe<0D51@0080
A4A400D0MgMg061PH01PH600VYZJ08j>SP0208N7Q`0409fMW@1fMWH0MWIf07QhN080MWIf00@0OGem
0<g=c@2GUiL0UiNG0`1RHV801@1bLW80Xj>S0;Vi^@2i^KT0^;Rh0080/k>c00D0/;2`09ZJVP2JVYX0
YJFU08b<S00207inOP04065QH@1nOWh0OWin08>3P`80T92@00D0_;bl065QH@2EUID0UIFE08N7Q`02
0;Jf]P050;bl_032`/80Shn?08n?S`2BTY800P2_[jl01@2h^;P0T92@092@T01aLG40LW9b0080N7Qh
00@0TY:B0861P@21PH40OGem0P2ATI401@2l_;`0YZJV069RHP1RHV80NWYj0080FEUI00D0`/;20;>c
/`2YZJT0ZJVY0:b/[00207alO00504];B`3Kfm/0fm_K07IfMP2?Shl00P1eMGD01024Q8@0PX:208:2
PP2][Jd20<K6aP0507moO`1WIfL0WYjN09jNWP2b/[800P1dM7@01@1YJFT0QXJ608J6QP3<c<`0UIFE
0080FUYJ00D0AdM701HF5P0F5QH0=cLg08Z:RP0208j>SP0405iNGP1mOGd0OGem07inOP80S8b<00D0
P820069RHP1TI6@0I6AT051@D00208j>SP050;>c/`2RXZ80XZ:R09nOW`2PX:000P2OWil01@1TI6@0
QXJ608J6QP28R8P0RXZ:0080Fe]K00@0Ng]k07AdM01dM7@0PH610P2IVIT00`1fMWKoooooooooo`08
ooooo`002_ooool0102_[jl0ZZZZ0:ZZZP2WYjL207MgM`050;Fe]@2g]kL0^;Rh0;Rh^02][Jd00P2Q
XJ401@2TY:@0ZJVY0:VYZ@2c/k<0];Bd0080/[:b00D0[Jf]0:VYZ@2YZJT0YjNW05QHF0020:f][@04
0:ZZZP2/[:`0[:b/0:j^[P80Y:BT00D0XZ:R0:FUY@2JVYX0VYZJ0:2PX0020:>SX`050:NWY`2ZZZX0
Shn?08n?S`1JFUX00P2^[Zh01@2XZ:P0ZJVY0:NWY`2WYjL0TY:B0080VIVI00D0V9RH09FEU@2EUID0
VIVI0:RXZ0020:ZZZP040:NWY`2_[jl0[jn_06ATI0<0[Zj^00@0[:b/0:j^[P2^[Zh0Y:BT0P2UYJD0
1@2VYZH0YJFU0:JVYP2VYZH0Xj>S0080XJ6Q00D0YJFU0:n_[`1=CDd0CDe=09fMW@0209^KV`0508>3
P`1oOgl0Ogmo07alO02:RXX00P2ATI40102DU9@0Xj>S0:>SX`2PX:040:ZZZP80LW9b00@0_Kfm0<71
`@30`<00`<300`2m_Kd01@2k^k/0^KVi0;Vi^@2c/k<0^k^k0080]kNg00@0_;bl0;Zj^P2j^[X0F5QH
0`2JVYX0102>SXh0U9BD09BDU02PX:020:NWY`030;2`/02e]KD0^KVi0080^KVi0P2^[Zh00`1>CTh0
KFe]0:^[Z`020:^[Z`80[:b/00D0Zj^[0:f][@2g]kL0]kNg0;Fe]@020:j^[P050:ZZZP2SXj<0Xj>S
0:RXZ02DU9@00P1;Bd/00`2IVIT0XJ6Q0:6QX@040:JVYP0409NGU`2UYJD0YJFU0:2PX080XJ6Q00D0
ZJVY0;6a/@2XZ:P0Z:RX0:>SX`0207emO@030;Bd]?oooooooooo00oooooo00@0IfMW08b<S02<S8`0
Ng]k0P16ATH01@1eMGD0PH610861P@1dM7@0EeMG0080MgMg00D0JFUY07moO`1oOgl0N7Qh07]kN`02
04=3@`0404E5A@1PH600H61P05=CD`80OWin00D0PH6106QXJ01CDe<0De=C051@D00204A4A00507Mg
M`1PH600H61P09ZJVP2>SXh00P27QhL0102MWId0MWIf07IfMP1hN7P207IfMP0407emO@3=cLd0UiNG
09NGU`<0HV9R00D0LW9b0:>SX`2i^KT0^KVi0;Rh^0020;>c/`050;2`/02JVYX0VYZJ0:FUY@2<S8`0
0P1nOWh0101QHF40OWin07inOP23Ph<2092@T0050;bl_01QHF40UIFE09FEU@27QhL00P2f][H01@2l
_;`0`/;208n?S`2?Shl0TY:B0080[jn_00D0^;Rh092@T02@T900LG5a079bLP0207QhN00409:BTP21
PH40PH6107emO@80TI6A00D0_;bl0:JVYP1RHV80HV9R07YjNP0205UIF@050<;2`P2c/k<0ZJVY0:VY
Z@2/[:`00P1lO7`01@1;Bd/0fm_K0=_Kf`1fMWH0Shn?0080MGEe00@0Q8B408:2PP22PX80[Jf]0P36
a/H01@1oOgl0IfMW09jNWP2NWYh0/[:b0080M7Ad00D0JFUY08J6QP26QXH0c<c<09FEU@0205YJFP05
04M7A`0F5QH05QHF03Lg=`2:RXX00P2>SXh0101NGUh0OGem07emO@1nOWh208b<S0050820P01RHV80
I6AT06ATI01@D5000P2>SXh01@2c/k<0XZ:R0::RXP2OWil0X:2P0080WinO00D0I6AT08J6QP26QXH0
R8R808Z:RP0205]KF`0407]kN`1dM7@0M7Ad0861P@80VIVI00<0MWIfooooooooool02?ooool000[o
oooo00@0CDe=04A4A014A4@0<30`0P0W9bL01@10@400@d=303Ph>00h>3P0=SHf0080<c<c00D0820P
030`<00`<300>c/k03hn?P020451@@0503dm?@0n?Sh0?Shn038b<P0/;2`00P0j>SX00`18B4P0C4a<
04a<C00304Q8B0050451@@0k>c/0B4Q804Q8B01>CTh00P1@D5001@1EEED0ATI60492@P12@T807AdM
0080G5aL00D0I6AT06IVIP1WIfL0IfMW06][J`0206MWI`05071`L01/K6`0K6a/06YZJP1fMWH00P1^
KVh01@1[Jf/0Kfm_06m_K`0m?Cd0LW9b0080MgMg00<0NGUi07]kN`1kNg/0101cLg<0101aLG40K6a/
06a/K01fMWH207QhN00507alO01iNGT0>SXj03Xj>P1mOGd00P1gMgL01@1hN7P0LG5a075aL@1VIVH0
N7Qh0080OWin0`21PH4208^;R`80QhN700D0S8b<05IFEP1FEUH0SHf=08Z:RP02092@T00408R8R027
QhL0QhN7092@T080TI6A00D0QHF509FEU@2IVIT0VIVI0::RXP020;6a/@0504];B`2IVIT0Z:RX0:RX
Z02HV9P00P2;Rh/01@2GUiL0TY:B09:BTP2HV9P0YZJV0080[Jf]00D0^;Rh0;2`/02`/;00CTi>06e]
K@0209fMW@0509bLW02NWYh0WYjN0::RXP2[Zj/00P2XZ:P0102YZJT0Y:BT0:BTY02PX:0208^;R`05
09ZJVP2>SXh0FEUI05UIF@2OWil00`2DU9@0102NWYh0XJ6Q0:6QX@2FUYH2096AT@0508V9R@2;Rh/0
Rh^;09ZJVP2TY:@00P2^[Zh0102SXj<0MWIf07IfMP2`/;0Aooooo`0405eMG@2;Rh/0Rh^;07YjNP80
DE5A00D0MgMg08F5Q@25QHD0P82005iNGP020820P00507alO01iNGT0NGUi075aL@1fMWH00P1?Cdl0
101=CDd0FEUI05UIF@1EEED207UiN@05092@T01QHF40De=C05=CD`1JFUX00P14A4@01@1kNg/0Hf=S
06=SH`2NWYh0YjNW0080Q8B400@0UIFE071`L01`L700Lg=c0P1fMWH01@1cLg<0a<C407moO`1oOgl0
FUYJ00<0Lg=c00@0UIFE0;Rh^02h^;P0`L710P2f][H01@2MWId0NGUi07UiN@2>SXh0P8200080MGEe
00@0EUIF079bLP1bLW80O7al0P2LW9`01@2g]kL0KFe]09BDU02DU9@0PH610080/[:b00D0_Kfm0<?3
``2@T900T92@07emO@030:n_[`80SXj>00D0MGEe071`L021PH40PH6109:BTP0207inOP0507]kN`2>
SXh0SXj>0;Ng]`2DU9@00P1IFET01@1gMgL0FUYJ05YJFP36a/H0`/;20080VYZJ00@0[Jf]0861P@21
PH40B4Q80P3Ng]h01@28R8P0RHV907]kN`1kNg/0Ph>30080RHV900D0[Zj^0=GEe@3EeMD0UiNG07em
O@020:b/[0040;Rh^01WIfL0IfMW07alO080LG5a00D0/k>c09VIV@1LG5`0G5aL0451@@0203<c<`05
02@T901_Kfl0JFUY06UYJ@1CDe<00P1/K6`01@1cLg<0QHF508F5Q@1iNGT0EUIF0080J6QX00@0@T92
061PH01PH600U9BD0P2KVi/01@28R8P0PH610;Rh^02h^;P0Lg=c0080S8b<00D0Vi^K08V9R@1ADE40
DE5A071`L00206UYJ@0407]kN`2MWId0WIfM08B4Q0[ooooo000:ooooo`0406][J`14A4@0A4A408>3
P`80T92@00D0Rh^;08R8R01bLW80LW9b02`/;00206=SH`0508Z:RP2;Rh/0Rh^;0861P@1nOWh00P1W
IfL0100`<300GemO05mOG`22PX8308>3P`0407MgM`1dM7@0M7Ad03Hf=P80JFUY00D0KVi^069RHP1G
EeL0EeMG05iNGP0205EEE@0502PX:00j>SX0A4A404A4A01=CDd00P1VIVH01@1RHV80>CTi02PX:00X
:2P0GUiN0080MgMg00D0Kfm_06IVIP1VIVH0J6QX06MWI`0202/[:`0503hn?P1PH600H61P06=SH`1G
EeL00P19BDT0101ADE40=cLg03Lg=`1HF5P205ADE00504Y:BP0l?3`0@4100410@00j>SX00P0Z:RX0
1@1LG5`0F5QH05QHF01HF5P0B4Q80080<30`00D0:BTY02<S8`0S8b<0:b/[02l_;`0203Ph>00503Hf
=P0[:b/0:b/[02LW9`0j>SX00P15ADD01@19BDT0@T920492@P0j>SX0=SHf0080<c<c00@0@D5103dm
?@0m?Cd0>3Ph0P0d=3@01@0R8R806ATI02HV9P0V9RH0;Bd]0080<C4a00D0:RXZ02d];@0j>SX0>SXj
04E5A@020451@@0504A4A015ADD0ADE50451@@0m?Cd00P0i>CT01012@T80EeMG05MGE`1;Bd/304a<
C0<0De=C00D0CDe=04U9B@1>CTh0CTi>05MGE`0205UIF@0505QHF01BDU80DU9B059BDP1EEED00P0f
=SH0100Z:RX0>c/k03/k>`11@D4304E5A@0405EEE@1GEeL0EeMG04Q8B080AdM70P1<C4`205aLG004
04i>CP0`<300<30`04E5AA7ooooo00@0IFEU0:>SX`2SXj<0M7Ad0P1:BTX01@1mOGd0WYjN09jNWP27
QhL0GUiN0080O7al00D0OGem09BDU02DU9@0PX:207alO00205aLG00404M7A`1UIFD0IFEU06MWI`80
Ng]k00D0L71`04];B`1MGEd0GEeM04i>CP020492@P0506m_K`1HF5P0F5QH09JFUP2WYjL00P2<S8`0
102NWYh0MWIf07IfMP1cLg<207UiN@0506YZJP2m_Kd0NGUi07UiN@1FEUH00P1PH6001@1JFUX0NWYj
0:2PX02PX:00YjNW0080YZJV00D0UIFE07YjNP1jNWX0S8b<07emO@02079bLP0405MGE`1hN7P0N7Qh
07moO`80VYZJ00D0^[Zj07=cL`2HV9P0V9RH08^;R`020::RXP050;Zj^P35aLD0UIFE09FEU@1hN7P0
0P2h^;P01@2j^[X0WIfM09fMW@1nOWh0I6AT0080MgMg00@0Ti>C08B4Q024Q8@0QHF50P2BTY801@2j
^[X0X:2P05aLG01LG5`0M7Ad0080GUiN00D0_[jn0<O7a`2g]kL0]kNg0:^[Z`0208B4Q00504A4A03G
emL0emOG09FEU@2<S8`00P24Q8@0101kNg/0OWin07inOP2[Zj/20=GEe@05092@T024Q8@0XJ6Q0:6Q
X@2n_[h00P1WIfL01@1dM7@0Fe]K05]KF`30`<00VIVI0080C4a<00D0@d=303De=@0e=CD0=3@d06QX
J002065QH@04059BDP1HF5P0F5QH07moO`80Lg=c00D0LW9b05YJFP1WIfL0IfMW055AD@0206YZJP05
08V9R@2FUYH0UYJF09FEU@2DU9@00P2][Jd00`1YJFT0X:2P0:2PX00209RHV080EeMG00@0FEUI04Q8
B018B4P0GEeM0P2:RXX00`1hN7Soooooooooo`08ooooo`002_ooool0102NWYh0?Cdm03dm?@2l_;`2
0<S8b0050<W9b@3:b/X0_Kfm0;fm_@0[:b/00P21PH401@2d];@0]kNg0;Ng]`2g]kL0^;Rh0080WYjN
00<0:2PX08b<S02<S8`0102i^KT0102/[:`0UiNG09NGU`1=CDd2096AT@0509fMW@2<S8`0RXZ:08Z:
RP2>SXh00P20P8001@1=CDd0EUIF05EEE@1EEED0IFEU0080Ph>300D0Shn?08:2PP0c<c<0<c<c08f=
S@020:j^[P0509fMW@2GUiL0UiNG0:6QX@2LW9`00P13@d<01@1eMGD0ZJVY0:VYZ@2a/K40/;2`0080
/k>c00@0^;Rh05EEE@1EEED0XJ6Q0P2=SHd01@1TI6@0GEeM05IFEP1FEUH0DE5A0080B4Q800D0]kNg
0;Vi^@2h^;P0^;Rh0;Jf]P020;:b/P0506UYJ@1KFe/0Fe]K0:NWY`2f][H00P2g]kL01@2l_;`0Zj^[
0:^[Z`12@T80RHV90080]KFe0`2d];@01@2j^[X0[Zj^04=3@`13@d<0^[Zj0080_kno00D0a<C40<G5
a@35aLD0Rh^;08>3P`020;Zj^P050;:b/P2XZ:P0Z:RX0:BTY02<S8`00P1BDU80102QXJ40ZZZZ0:ZZ
ZP2UYJD20:^[Z`050:ZZZP2TY:@0EUIF05IFEP2_[jl00P2d];@01@2l_;`0^KVi0;>c/`2c/k<0C4a<
0080K6a/00<0X:2P09>CT`2@T9000P2@T90209JFUP0505mOG`18B4P0B4Q808R8R02ATI400P2SXj<0
1@2QXJ40RHV908V9R@0k>c/0KVi^0080SHf=00@0VIVI09RHV02HV9P0VIVI0P2?Shl01@0f=SH0HF5Q
08j>SP2>SXh0VIVI0080XZ:R00<0W9bLooooooooool03oooool0101NGUh0Ti>C09>CT`1[Jf/204Q8
B00507IfMP29RHT0RHV906m_K`1FEUH00P21PH401@1mOGd0U9BD09BDU021PH40Ng]k0080HV9R00@0
F5QH06QXJ01XJ6P0J6QX0P29RHT01@2UYJD0DU9B051@D01@D500EEEE0080BDU900D0NWYj059BDP1B
DU80UiNG09fMW@0209BDU0040:>SX`1cLg<0Lg=c07EeM@80O7al00D0LW9b0<c<c024Q8@0Q8B405iN
GP02075aL@0506UYJ@1oOgl0ZJVY0:VYZ@2/[:`00P2a/K401@2:RXX0PH610861P@2BTY80Ph>30080
PH6100@0De=C07=cL`1cLg<0UYJF0P2IVIT01@2o_kl0SXj>09jNWP2NWYh0UIFE0080XZ:R00D0a<C4
0<;2`P2LW9`0W9bL07AdM0020:VYZ@050:j^[P2][Jd0[Jf]07UiN@1aLG400P2DU9@0102VYZH0OWin
07inOP28R8P208J6QP050;fm_@2[Zj/0Hf=S06=SH`1ZJVX00P1hN7P01@2RXZ80/;2`0:BTY02TY:@0
UYJF0080MWIf00D0@T920<W9b@39bLT0QXJ6092@T00207inOP04071`L01^KVh0KVi^09fMW@80aLG5
00D0Q8B408N7Q`2/[:`0[:b/0:j^[P0206i^KP0508:2PP1MGEd0GEeM0:6QX@2LW9`00P1ADE401@13
@d<0BTY:04Y:BP1ADE40Hf=S0080K6a/00@0I6AT04M7A`17AdL0G5aL0P1FEUH01@1cLg<0D51@06a/
K01/K6`0C4a<0080GemO00D0Ng]k0:6QX@2QXJ40QHF509VIV@020:^[Z`0506ATI02>SXh0SXj>07mo
O`2LW9`00P1IFET0101bLW80GEeM05eMG@1mOGd208j>SP0306m_Kooooooooooo00Sooooo000:oooo
o`0409jNWP0m?Cd0?Cdm0;bl_080b<S800D0bLW90<[:bP2m_Kd0_Kfm02/[:`020861P@050;Bd]02g
]kL0]kNg0;Ng]`2h^;P00P2NWYh00`0X:2P0S8b<08b<S0040;Vi^@040:b/[02GUiL0UiNG04e=C@80
TI6A00D0WIfM08b<S02:RXX0RXZ:08j>SP020820P00504e=C@1FEUH0EEEE05EEE@1UIFD00P23Ph<0
1@2?Shl0PX:203<c<`0c<c<0SHf=0080[Zj^00D0WIfM09NGU`2GUiL0XJ6Q09bLW00204=3@`0507Ee
M@2YZJT0ZJVY0;6a/@2`/;000P2c/k<0102h^;P0EEEE05EEE@2QXJ4208f=S@0506ATI01MGEd0EUIF
05IFEP1ADE400P18B4P01@2g]kL0^KVi0;Rh^02h^;P0][Jf0080/[:b00D0JFUY05]KF`1KFe/0YjNW
0;Jf]P020;Ng]`050;bl_02[Zj/0Zj^[0492@P29RHT00P2e]KD30;Bd]0050;Zj^P2^[Zh0@d=304=3
@`2j^[X00P2o_kl01@34a<@0aLG50<G5a@2;Rh/0Ph>30080^[Zj00D0/[:b0:RXZ02XZ:P0Y:BT08b<
S002059BDP040:6QX@2ZZZX0ZZZZ0:FUY@80Zj^[00D0ZZZZ0:BTY01FEUH0EUIF0:n_[`020;Bd]005
0;bl_02i^KT0/k>c0;>c/`1<C4`00P1/K6`00`2PX:00Ti>C092@T002092@T080UYJF00D0GemO04Q8
B018B4P0R8R8096AT@020:>SX`050:6QX@29RHT0RHV903/k>`1^KVh00P2=SHd0102IVIT0V9RH09RH
V02IVIT208n?S`0503Hf=P1QHF40SXj>08j>SP2IVIT00P2RXZ800`2LW9coooooooooo`0?ooooo`04
05iNGP2CTi<0Ti>C06][J`80B4Q800D0MWIf08V9R@29RHT0Kfm_05IFEP020861P@0507emO@2DU9@0
U9BD0861P@1kNg/00P1RHV80101HF5P0J6QX06QXJ01XJ6P208V9R@050:FUY@1BDU80D51@051@D01E
EED00P19BDT01@1jNWX0DU9B059BDP2GUiL0WIfM0080U9BD00@0Xj>S07=cL`1cLg<0MGEe0P1lO7`0
1@1bLW80c<c<08B4Q024Q8@0GUiN0080LG5a00D0JFUY07moO`2YZJT0ZJVY0:b/[0020;6a/@0508Z:
RP21PH40PH6109:BTP23Ph<00P21PH40101CDe<0Lg=c07=cL`2FUYH209VIV@050;no_`2>SXh0WYjN
09jNWP2EUID00P2RXZ801@34a<@0`/;209bLW02LW9`0M7Ad0080ZJVY00D0[Zj^0:f][@2][Jd0NGUi
075aL@0209BDU0040:JVYP1nOWh0OWin08R8R080QXJ600D0_Kfm0:^[Z`1SHf<0Hf=S06YZJP0207Qh
N0050::RXP2`/;00Y:BT0:BTY02FUYH00P1fMWH01@12@T80bLW90<W9b@26QXH0T92@0080OWin00@0
L71`06i^KP1^KVh0WIfM0P35aLD01@24Q8@0QhN70:b/[02/[:`0[Zj^0080KVi^00D0PX:205eMG@1M
GEd0XJ6Q09bLW002055AD@0504=3@`1:BTX0BTY:055AD@1SHf<00P1/K6`0101TI6@0AdM704M7A`1L
G5`205IFEP0507=cL`1@D500K6a/06a/K01<C4`00P1OGel01@1kNg/0XJ6Q0:6QX@25QHD0VIVI0080
Zj^[00D0I6AT08j>SP2>SXh0Ogmo09bLW00205UIF@04079bLP1MGEd0GEeM07emO@80SXj>00<0Kfm_
ooooooooool02?ooool000[ooooo00@0[jn_04E5A@15ADD0_[jn0P35aLD01@39bLT0b/[:0;Bd]02d
];@092@T0080QHF500D0[jn_0:f][@2][Jd0/[:b0;Bd]0020:NWY`0502HV9P2BTY80TY:B0;Ng]`2c
/k<00P2d];@0102UYJD0Ti>C09>CT`0j>SX209>CT`040;>c/`2a/K40/k>c0;>c/`<0ZJVY00D0EEEE
03dm?@0m?Cd0?Cdm04];B`0206e]K@0507]kN`1nOWh0@T920492@P28R8P00P2b/[801@2UYJD0UiNG
09NGU`2SXj<0X:2P0080>c/k00D0Ph>30;Ng]`2g]kL0]kNg0;Zj^P030;no_`80Hf=S0`2VYZH01@2@
T900L71`05mOG`1OGel0Bd];0080EUIF00D0]KFe0;Rh^02i^KT0^KVi0;bl_0020;Rh^00506QXJ01d
M7@0M7Ad0;2`/02d];@00P2i^KT01@30`<00^;Rh0;Rh^01;Bd/0U9BD0080];Bd00D0ZZZZ0:j^[P2^
[Zh0^;Rh0;bl_00206QXJ0040;fm_@31`L40`L710<;2`P80b<S800<0/k>c06m_K`2XZ:P00P2XZ:P2
09fMW@050:>SX`2WYjL0H61P061PH02WYjL00P2[Zj/01@2UYJD0XZ:R0::RXP2LW9`0SHf=0080DU9B
00D0]kNg0;^k^`2k^k/0^k^k0;Ng]`020;Rh^00506e]K@1dM7@0M7Ad09FEU@2LW9`00P2@T9001027
QhL0T92@092@T01IFET208F5Q@050:j^[P2f][H0]kNg0;Ng]`2c/k<00P2^[Zh01011@D40WinO0;Vi
^@2i^KT30;Rh^0050;>c/`2][Jd0[Jf]03hn?P2QXJ400P2XZ:P0102/[:`0/;2`0;2`/02`/;0Aoooo
o`0406ATI02NWYh0WYjN06YZJP80A4A400D0K6a/09jNWP2NWYh0Shn?07EeM@0209ZJVP0508^;R`2R
XZ80XZ:R08j>SP1iNGT00P1CDe<0101KFe/0IfMW06MWI`1XJ6P208n?S`0509fMW@1OGel0GEeM05eM
G@1JFUX00P16ATH01@1mOGd0EEEE05EEE@2PX:00UIFE0080QhN700@0[:b/07MgM`1gMgL0MWIf0P21
PH401@1_Kfl0dm?C09bLW02LW9`0I6AT0080NGUi00D0Jf][09fMW@35aLD0aLG50<30`0020<O7a`05
08n?S`2<S8`0S8b<08j>SP1gMgL00P1hN7P0101KFe/0QXJ608J6QP2ATI4209nOW`050;:b/P2LW9`0
YJFU0:FUY@2>SXh00P2IVIT01@3EeMD0];Bd0:VYZ@2YZJT0SXj>0080[Zj^00D0Xj>S08n?S`2?Shl0
OGem07]kN`0209BDU0040:ZZZP26QXH0QXJ609RHV080TI6A00D0_kno0;^k^`1iNGT0NGUi05UIF@02
07alO0050:^[Z`34a<@0Zj^[0:^[Z`2JVYX00P1_Kfl01@0n?Sh0b/[:0<[:bP25QHD0RHV90080PH61
00@0L71`06i^KP1^KVh0YJFU0P37alL01@27QhL0PH6109^KV`2KVi/0Rh^;0080M7Ad00D0C4a<05IF
EP1FEUH0VYZJ08V9R@0204];B`0503<c<`0d=3@0=3@d04];B`1SHf<00P1QHF40101ZJVX0BTY:04Y:
BP1XJ6P205eMG@0506a/K01GEeL0IVIV06IVIP1>CTh00P1IFET01@2EUID0W9bL09bLW02BTY80Rh^;
0080VYZJ00D0Hf=S0:JVYP2VYZH0T92@0:FUY@0205]KF`0406IVIP1WIfL0IfMW07inOP80QHF500<0
M7Adooooooooool02?ooool000[ooooo00@0/[:b05EEE@1EEED0^;Rh0P31`L401@30`<00a/K60:RX
Z02XZ:P0;Bd]0080Shn?00D0ZJVY0:RXZ02XZ:P0Zj^[0:RXZ00209>CT`05024Q8@2>SXh0SXj>0;>c
/`2b/[800P2/[:`0102GUiL0P8200820P00o?cl209RHV0050;Bd]02[Zj/0[:b/0:b/[02`/;000P2^
[Zh01@1?Cdl0=cLg01LG5`0G5aL06ATI00807QhN00D0@D5104E5A@0c<c<0<c<c08B4Q00209nOW`05
07moO`1jNWX0NWYj09>CT`2JVYX00P19BDT01@1oOgl0ZJVY0:VYZ@2_[jl0/;2`0080^k^k00@0_[jn
06=SH`1SHf<0W9bL0P2[Zj/01@2YZJT0Ph>3079bLP1bLW80GemO0080CTi>00D0/k>c0:j^[P2/[:`0
[:b/0;:b/P020;Bd]00506EUI@1oOgl0Ogmo0:n_[`2d];@00P2e]KD01@2g]kL0ZZZZ0:ZZZP0j>SX0
UYJF0080/K6a00D0[:b/0;:b/P2b/[80]kNg0;Fe]@02061PH0040;Zj^P2m_Kd0_Kfm0;fm_@80a/K6
00D0[jn_075aL@2VYZH0YZJV0:6QX@020:NWY`050:FUY@2GUiL0HV9R069RHP2IVIT00P2UYJD01@2M
WId0UIFE09FEU@24Q8@0QXJ60080AdM700D0/[:b0;Fe]@2e]KD0/k>c0:j^[P020;2`/00506=SH`1T
I6@0I6AT08Z:RP22PX800P1oOgl0101kNg/0MGEe07EeM@18B4P208R8R0050;:b/P2f][H0^;Rh0;Rh
^02g]kL00P2`/;001@0f=SH0Y:BT0;>c/`2c/k<0^;Rh0080][Jf00D0/K6a0:RXZ02XZ:P0=cLg09RH
V0020:FUY@040:f][@2[Zj/0Zj^[0:NWYa7ooooo00@0IFEU096AT@2ATI40LW9b0P16ATH01@1/K6`0
OWin07inOP28R8P0QHF50080Vi^K00D0P82008n?S`2?Shl0PX:206e]K@0205]KF`0404m?C`1YJFT0
JFUY04m?C`80MGEe00D0S8b<05UIF@1IFET0FEUI055AD@0204=3@`0506=SH`1CDe<0De=C09JFUP2;
Rh/00P23Ph<0102SXj<0LG5a075aL@1OGel207=cL`0506e]K@3:b/X0Ph>308>3P`1ZJVX00P26QXH0
1@1MGEd0R8R80;fm_@2m_Kd0]kNg0080`L7100@0TY:B09^KV`2KVi/0T92@0`21PH40101EEED0P820
0820P021PH420:^[Z`0509ZJVP2HV9P0Ti>C09>CT`2>SXh00P21PH401@3Jf]X0]KFe0;Zj^P2j^[X0
Shn?00<0`/;20P2NWYh01@1oOgl0Lg=c07UiN@1iNGT0TI6A0080PH6100D0VYZJ08j>SP2>SXh0]kNg
0;Jf]P02079bLP0505IFEP2DU9@0U9BD0:ZZZP2m_Kd00P2o_kl0102PX:00NGUi07UiN@13@d<20=KF
eP80SHf=0P1mOGd0101^KVh0K6a/06a/K02NWYh20;Rh^00508b<S02;Rh/0WYjN09jNWP27QhL00P2C
Ti<01@1ZJVX0GEeM05eMG@2BTY80UiNG0080E5AD00D0?Shn03/k>`0k>c/0Fe]K05YJFP0205UIF@04
06IVIP1<C4`0C4a<06MWI`80G5aL00D0Q8B404E5A@1MGEd0GEeM061PH00204E5A@0507QhN02PX:00
X:2P08n?S`25QHD00P2LW9`01@1_Kfl0ZJVY0:VYZ@25QHD0ZZZZ0080EEEE00@0GemO07AdM01dM7@0
QhN70`2=SHd:ooooo`002_ooool0102b/[80EEEE05EEE@2h^;P20<71`@050<30`036a/H0Z:RX0:RX
Z00];Bd00P2?Shl01@2YZJT0Z:RX0:RXZ02[Zj/0Z:RX0080Ti>C00D08B4Q08j>SP2>SXh0/k>c0;:b
/P020:b/[00409NGU`20P800P82003lo?`80V9RH00D0];Bd0:^[Z`2/[:`0[:b/0;2`/0020:j^[P05
04m?C`0g=cL05aLG01LG5`0I6AT00P0N7Qh01@11@D40ADE503<c<`0c<c<0Q8B40080WinO00D0Ogmo
07YjNP1jNWX0Ti>C09ZJVP0204U9B@0507moO`2YZJT0ZJVY0:n_[`2`/;000P2k^k/0102n_[h0Hf=S
06=SH`2LW9`20:^[Z`050:VYZ@23Ph<0LW9b079bLP1OGel00P1>CTh01@2c/k<0[Zj^0:b/[02/[:`0
/[:b0080];Bd00D0IFEU07moO`1oOgl0[jn_0;Bd]0020;Fe]@050;Ng]`2ZZZX0ZZZZ03Xj>P2FUYH0
0P2a/K401@2/[:`0/[:b0;:b/P2g]kL0]KFe0080H61P00@0^[Zj0;fm_@2m_Kd0_Kfm0P36a/H01@2_
[jl0LG5a0:JVYP2VYZH0XJ6Q0080YjNW00D0YJFU09NGU`1RHV80HV9R09VIV@020:FUY@0509fMW@2E
UID0UIFE08B4Q026QXH00P17AdL01@2b/[80]KFe0;Fe]@2c/k<0[Zj^0080/;2`00D0Hf=S06ATI01T
I6@0RXZ:08:2PP0207moO`0407]kN`1eMGD0MGEe04Q8B080R8R800D0/[:b0;Jf]P2h^;P0^;Rh0;Ng
]`020;2`/00503Hf=P2TY:@0/k>c0;>c/`2h^;P00P2f][H01@2a/K40Z:RX0:RXZ00g=cL0V9RH0080
YJFU00@0[Jf]0:^[Z`2[Zj/0YjNW4Oooool0101UIFD0TI6A096AT@1bLW8204I6AP0506a/K01nOWh0
OWin08R8R025QHD00P2KVi/01@20P800Shn?08n?S`22PX80KFe]0080Fe]K00@0Cdm?06UYJ@1YJFT0
Cdm?0P1eMGD01@2<S8`0FEUI05UIF@1IFET0DE5A0080@d=300D0Hf=S05=CD`1CDe<0UYJF08^;R`02
08>3P`040:>SX`1aLG40LG5a05mOG`80Lg=c00D0KFe]0<[:bP23Ph<0Ph>306YZJP0208J6QP0505eM
G@28R8P0_Kfm0;fm_@2g]kL00P31`L40102BTY80Vi^K09^KV`2@T9030861P@0405EEE@20P800P820
0861P@80Zj^[00D0VYZJ09RHV02CTi<0Ti>C08j>SP020861P@050=[JfP2e]KD0^[Zj0;Zj^P2?Shl0
0`32`/8209jNWP0507moO`1cLg<0NGUi07UiN@2ATI400P21PH401@2JVYX0SXj>08j>SP2g]kL0][Jf
0080LW9b00D0EUIF09BDU02DU9@0ZZZZ0;fm_@020;no_`040:2PX01iNGT0NGUi04=3@`80e]KF0P2=
SHd207emO@0406i^KP1/K6`0K6a/09jNWP80^;Rh00D0S8b<08^;R`2NWYh0WYjN08N7Q`0209>CT`05
06YZJP1MGEd0GEeM09:BTP2GUiL00P1DE5@01@0n?Sh0>c/k03/k>`1KFe/0FUYJ0080FEUI00@0IVIV
04a<C01<C4`0IfMW0P1LG5`01@24Q8@0ADE505eMG@1MGEd0H61P0080ADE500D0N7Qh0:2PX02PX:00
Shn?08F5Q@0209bLW00506m_K`2YZJT0ZJVY08F5Q@2ZZZX00P1EEED0101OGel0M7Ad07AdM027QhL3
08f=S@[ooooo000:ooooo`0408B4Q00c<c<0<c<c07alO080QHF500D0OWin08:2PP1fMWH0MWIf03dm
?@0205aLG00507moO`1jNWX0NWYj07IfMP27QhL00P1kNg/01@0Z:RX0GemO05mOG`1]KFd0LG5a0080
Fe]K00@0De=C05mOG`1OGel0ADE50P1RHV801@1hN7P0PX:208:2PP22PX80QXJ60080SHf=00D0ATI6
03hn?P0/;2`0;2`/03/k>`0203`l?0050451@@1DE5@0@4100410@01SHf<00P1TI6@01@1;Bd/0EEEE
05EEE@1PH600JFUY0080AdM700D0HF5Q07alO01lO7`0LW9b071`L0020820P00408N7Q`18B4P0B4Q8
09ZJVP80UiNG00D0M7Ad06ATI013@d<0@d=3065QH@0204M7A`0509>CT`2;Rh/0OWin07inOP1kNg/0
0P28R8P01@1FEUH0JFUY06UYJ@20P800Ph>30080Ti>C00D0X:2P08:2PP22PX80=cLg08R8R00209BD
U00509nOW`2PX:00X:2P0:^[Z`2TY:@00P1JFUX0102GUiL0VIVI09VIV@2e]KD20;Jf]P050:2PX01/
K6`0Z:RX0:RXZ02WYjL00P2TY:@01@2WYjL0W9bL05YJFP1JFUX0UYJF0080WinO00D0V9RH09>CT`2C
Ti<0QHF507moO`0204m?C`050:ZZZP2_[jl0[jn_0:ZZZP2TY:@00P2WYjL01@1DE5@0CTi>04i>CP29
RHT0R8R80080O7al00@0NGUi06e]K@1]KFd0CTi>0P2BTY801@2h^;P0a<C40;bl_02l_;`0^KVi0080
/k>c00D0:b/[0:2PX02f][H0][Jf0;^k^`020;Zj^P050;Vi^@2a/K40/K6a03Ti>@2TY:@00P2VYZH0
102XZ:P0/;2`0;2`/02^[ZhAooooo`0406UYJ@2^[Zh0[Zj^07alO080EEEE00D0RXZ:0:FUY@2UYJD0
Ti>C07MgM`0209bLW00507inOP2ATI40TI6A07moO`20P8000P1ADE40100o?cl0G5aL05aLG01NGUh2
07=cL`0507QhN01DE5@0GEeM05eMG@1?Cdl00P11@D401@1oOgl0HV9R069RHP2OWil0SHf=0080T92@
00@0Xj>S06][J`1[Jf/0IFEU0P1PH6001@1MGEd0aLG508f=S@2=SHd0IVIV0080Ng]k00D0FUYJ07=c
L`2][Jd0[Jf]0;Fe]@020;6a/@0508B4Q02>SXh0SXj>08Z:RP1nOWh00P2;Rh/0101`L700Shn?08n?
S`28R8P20;2`/0050:>SX`2FUYH0T92@092@T02IVIT00P1iNGT01@3Ogml0ZJVY0:b/[02/[:`0QHF5
0080`L7100D0_[jn09NGU`2GUiL0MgMg07=cL`0208B4Q00409JFUP21PH40PH610:j^[P80QhN700D0
[jn_0;fm_@1fMWH0MWIf05QHF002096AT@050:b/[02i^KT0Xj>S0:>SX`1jNWX00P1[Jf/01@0o?cl0
clo?0<o?c`2GUiL0RXZ:0080RHV900@0N7Qh07inOP1nOWh0^;Rh0P3=cLd01@2EUID0UYJF0:BTY02T
Y:@0QHF50080Y:BT00D0HV9R08f=S@2=SHd0XZ:R09jNWP0204i>CP0503Lg=`0e=CD0=CDe04m?C`1F
EUH00P1:BTX0101[Jf/0FEUI05UIF@1RHV8205=CD`0508V9R@13@d<0D51@051@D01NGUh00P1?Cdl0
1@1fMWH0S8b<08b<S02IVIT0RXZ:0080R8R800D0O7al0;Ng]`2g]kL0VIVI09:BTP02069RHP0405aL
G01iNGT0NGUi08Z:RP80Q8B400<0Lg=cooooooooool02?ooool000[ooooo00@0R8R807]kN`1kNg/0
N7Qh0P1bLW801@11@D40Fe]K071`L01`L700NGUi0080OWin00D0Kfm_06e]K@1]KFd0L71`07UiN@02
06YZJP0506QXJ01HF5P0F5QH05EEE@1HF5P00P0n?Sh01017AdL0J6QX06QXJ01_Kfl206QXJ00505iN
GP1LG5`0Bd];04];B`1EEED00P1KFe/01@1JFUX0FEUI05iNGP1NGUh0D51@0080?3`l00D0BDU906=S
H`1ZJVX0JVYZ06][J`02069RHP<0G5aL0P1OGel2069RHP0505mOG`1HF5P0F5QH05iNGP16ATH00P0j
>SX0101ADE40EeMG05MGE`1EEED305aLG00405]KF`1MGEd0GEeM069RHP80H61P00D0GemO06UYJ@1R
HV80HV9R04i>CP0205EEE@<0Fe]K00D0EUIF04e=C@16ATH0ATI604a<C00204I6AP05059BDP1RHV80
HV9R069RHP1VIVH00P1QHF401@1=CDd0BTY:0492@P12@T80>c/k0080A4A400D0C4a<04Q8B018B4P0
?Shn04];B`0205IFEP0504Y:BP1?Cdl0Cdm?055AD@1KFe/00P1CDe<0101VIVH0I6AT06ATI01QHF42
05YJFP0506ATI01KFe/0De=C05=CD`1lO7`00P1cLg<01@1]KFd0JVYZ06IVIP1VIVH0C4a<0080@410
00D0GemO06IVIP1LG5`0G5aL05eMG@0205UIF@0504a<C01ZJVX0JVYZ07QhN025QHD00P23Ph<01@1f
MWH0N7Qh07QhN011@D40Kfm_0080Ng]k00@0PH6107EeM@1eMGD0MgMg0P1aLG401@0o?cl0N7Qh07al
O01lO7`0NGUi0080Ph>300<0OWinooooooooool03oooool0101DE5@0Ti>C09>CT`1UIFD204A4A005
07YjNP2PX:00X:2P0:2PX024Q8@00P2EUID01@2=SHd0OGem07emO@1nOWh0Kfm_0080EeMG00@0ATI6
05aLG01LG5`0GUiN0P20P8001@24Q8@0B4Q806EUI@1UIFD0FEUI0080AdM700D0PX:207IfMP1fMWH0
XZ:R08f=S@0209FEU@040:f][@1jNWX0NWYj06m_K`80JVYZ00D0GEeM0;bl_025QHD0QHF507EeM@02
07]kN`05065QH@2>SXh0^KVi0;Vi^@35aLD00P2k^k/01@29RHT0WIfM09fMW@2@T900Ph>30080T92@
00@0N7Qh07YjNP1jNWX0MgMg0P2WYjL209VIV@80K6a/00D0TI6A05iNGP1NGUh0f=SH0:FUY@020:JV
YP0409JFUP2k^k/0^k^k0;fm_@80PH6100D0K6a/065QH@1kNg/0Ng]k08F5Q@0207EeM@050:2PX01]
KFd0KFe]09VIV@2PX:000P1bLW801@1ADE40S8b<08b<S02][Jd0^k^k0080YZJV00@0Shn?06][J`1[
Jf/0@d=30P3Bd]801@2FUYH0Ogmo0820P020P800Kfm_0080LW9b00D0[Zj^0<?3``33`l<0WinO09ZJ
VP020;:b/P0408n?S`2e]KD0]KFe07AdM080TY:B00D0WYjN08b<S016ATH0ATI603De=@0203<c<`05
04=3@`1<C4`0ATI604I6AP1^KVh00P1ZJVX01@1DE5@0Cdm?04m?C`23Ph<0B4Q80080BTY:00@0M7Ad
05IFEP1FEUH0NWYj0P2BTY8208Z:RP80Rh^;00D0R8R80:ZZZP2ZZZX0WIfM09jNWP0205iNGP0405EE
E@1lO7`0O7al06YZJP80JFUY00<0Jf][ooooooooool02?ooool000[ooooo00@0R8R807]kN`1kNg/0
N7Qh0P1bLW801@11@D40Fe]K071`L01`L700NGUi0080OWin00D0Kfm_06e]K@1]KFd0L71`07UiN@02
06YZJP0506QXJ01HF5P0F5QH05EEE@1HF5P00P0n?Sh01017AdL0J6QX06QXJ01_Kfl206QXJ00505iN
GP1LG5`0Bd];04];B`1EEED00P1KFe/01@1JFUX0FEUI05iNGP1NGUh0D51@0080?3`l00D0BDU906=S
H`1ZJVX0JVYZ06][J`02069RHP<0G5aL0P1OGel2069RHP0505mOG`1HF5P0F5QH05iNGP16ATH00P0j
>SX0101ADE40EeMG05MGE`1EEED305aLG00405]KF`1MGEd0GEeM069RHP80H61P00D0GemO06UYJ@1R
HV80HV9R04i>CP0205EEE@<0Fe]K00D0EUIF04e=C@16ATH0ATI604a<C00204I6AP05059BDP1RHV80
HV9R069RHP1VIVH00P1QHF401@1=CDd0BTY:0492@P12@T80>c/k0080A4A400D0C4a<04Q8B018B4P0
?Shn04];B`0205IFEP0504Y:BP1?Cdl0Cdm?055AD@1KFe/00P1CDe<0101VIVH0I6AT06ATI01QHF42
05YJFP0506ATI01KFe/0De=C05=CD`1lO7`00P1cLg<01@1]KFd0JVYZ06IVIP1VIVH0C4a<0080@410
00D0GemO06IVIP1LG5`0G5aL05eMG@0205UIF@0504a<C01ZJVX0JVYZ07QhN025QHD00P23Ph<01@1f
MWH0N7Qh07QhN011@D40Kfm_0080Ng]k00@0PH6107EeM@1eMGD0MgMg0P1aLG401@0o?cl0N7Qh07al
O01lO7`0NGUi0080Ph>300<0OWinooooooooool03oooool0101DE5@0Ti>C09>CT`1UIFD204A4A005
07YjNP2PX:00X:2P0:2PX024Q8@00P2EUID01@2=SHd0OGem07emO@1nOWh0Kfm_0080EeMG00@0ATI6
05aLG01LG5`0GUiN0P20P8001@24Q8@0B4Q806EUI@1UIFD0FEUI0080AdM700D0PX:207IfMP1fMWH0
XZ:R08f=S@0209FEU@040:f][@1jNWX0NWYj06m_K`80JVYZ00D0GEeM0;bl_025QHD0QHF507EeM@02
07]kN`05065QH@2>SXh0^KVi0;Vi^@35aLD00P2k^k/01@29RHT0WIfM09fMW@2@T900Ph>30080T92@
00@0N7Qh07YjNP1jNWX0MgMg0P2WYjL209VIV@80K6a/00D0TI6A05iNGP1NGUh0f=SH0:FUY@020:JV
YP0409JFUP2k^k/0^k^k0;fm_@80PH6100D0K6a/065QH@1kNg/0Ng]k08F5Q@0207EeM@050:2PX01]
KFd0KFe]09VIV@2PX:000P1bLW801@1ADE40S8b<08b<S02][Jd0^k^k0080YZJV00@0Shn?06][J`1[
Jf/0@d=30P3Bd]801@2FUYH0Ogmo0820P020P800Kfm_0080LW9b00D0[Zj^0<?3``33`l<0WinO09ZJ
VP020;:b/P0408n?S`2e]KD0]KFe07AdM080TY:B00D0WYjN08b<S016ATH0ATI603De=@0203<c<`05
04=3@`1<C4`0ATI604I6AP1^KVh00P1ZJVX01@1DE5@0Cdm?04m?C`23Ph<0B4Q80080BTY:00@0M7Ad
05IFEP1FEUH0NWYj0P2BTY8208Z:RP80Rh^;00D0R8R80:ZZZP2ZZZX0WIfM09jNWP0205iNGP0405EE
E@1lO7`0O7al06YZJP80JFUY00<0Jf][ooooooooool02?ooool000[ooooo00@0];Bd0;2`/02`/;00
YjNW0P2OWil00`12@T80U9BD0:^[Z`020:^[Z`80[:b/00D0YJFU0;:b/P2b/[80];Bd0;Fe]@020;2`
/0050:ZZZP2TY:@0Y:BT09FEU@2MWId00P1ZJVX0101nOWh0];Bd0;Bd]02[Zj/20:JVYP040:2PX02]
[Jd0[Jf]0:f][@<0[:b/00D0Z:RX0:ZZZP2^[Zh0[Zj^0;2`/00207=cL`0308^;R`2a/K40/K6a0080
/K6a0P2[Zj/01@2^[Zh0YZJV0:JVYP2VYZH0ZJVY0080YZJV00D0[:b/0:VYZ@2YZJT0Zj^[07QhN002
071`L0040;Vi^@2m_Kd0_Kfm0;bl_080]KFe00D0^;Rh0;Ng]`2e]KD0]KFe0;6a/@020;Bd]0050;>c
/`2i^KT0]KFe0;Fe]@1YJFT00P2^[Zh30;Jf]P050;Ng]`2c/k<0YZJV0:JVYP2ZZZX00P2`/;001@2n
_[h0^KVi0;Jf]P2f][H0`/;20080a<C40P1BDU820:RXZ0040:VYZ@2d];@0];Bd0;Bd]080/K6a00D0
ZZZZ0:FUY@2NWYh0WYjN08^;R`0207]kN`050451@@2UYJD0[jn_0:n_[`2QXJ400P22PX801@2CTi<0
S8b<08b<S02FUYH0Vi^K0080WYjN00D0WinO09VIV@2IVIT0RHV9069RHP0205IFEP0509FEU@2JVYX0
VYZJ08j>SP2JVYX00P2RXZ80102PX:00PH610861P@2HV9P20:6QX@0509NGU`2FUYH0UIFE09FEU@1B
DU800P20P8001@2LW9`0T92@08B4Q024Q8@0Kfm_0080DE5A00D0EEEE06i^KP1^KVh0RHV906YZJP02
06=SH`04065QH@1?Cdl0Cdm?04m?Ca7ooooo00@0IVIV0:2PX02PX:00NGUi0P1ADE401@1oOgl0Xj>S
0:>SX`2OWil0P8200080K6a/00D0OWin06IVIP1VIVH0Lg=c06e]K@0205mOG`0403Xj>P1EEED0EEEE
05iNGP80KFe]00D0JVYZ04I6AP1[Jf/0Jf][05UIF@0204A4A00306QXJ01JFUX0FUYJ0080Ti>C0P2P
X:00102SXj<0O7al07alO01_Kfl206a/K00505YJFP2c/k<0RHV908V9R@1lO7`00P1gMgL01@1JFUX0
Ng]k0:j^[P2^[Zh0a/K60080]KFe00D0RHV908f=S@2=SHd0T92@08:2PP02096AT@0408F5Q@1kNg/0
Ng]k0820P080/[:b00D0UYJF09VIV@23Ph<0Ph>309^KV`0206a/K0050<K6aP2UYJD0WinO09nOW`2T
Y:@00P2][Jd01@31`L40TI6A096AT@1iNGT0MWIf0080QhN700@0P82007=cL`1cLg<0QXJ60P1QHF40
1@2QXJ40ZJVY06][J`1[Jf/0D51@0080P82000D0[Jf]0;Ng]`2JVYX0VYZJ09FEU@0206YZJP0504m?
C`3MgMd0gMgM07inOP1kNg/00P1]KFd0101UIFD0KFe]06e]K@2e]KD20;Rh^00509ZJVP20P800YjNW
0:NWY`2BTY800P2ZZZX01@1LG5`0Shn?08n?S`2NWYh0RHV90080CDe=00D0>CTi02TY:@0Y:BT0@D51
04Y:BP0203hn?P0407emO@1/K6`0K6a/05]KF`80K6a/00D0MGEe06MWI`1?Cdl0Cdm?07QhN00207Ui
N@0507]kN`2IVIT0VIVI09VIV@2>SXh00P24Q8@01@2ATI40VYZJ09ZJVP2JVYX0WinO0080F5QH00@0
GEeM06ATI01TI6@0De=C0P1dM7@00`1_Kfooooooooooo`08ooooo`002_ooool0102d];@0[Zj^0:j^
[P2[Zj/20:NWY`0503Ph>02GUiL0YjNW0:NWY`2UYJD00P2RXZ801@2KVi/0YZJV0:JVYP2/[:`0Z:RX
00<0YJFU0P2SXj<01@2RXZ80W9bL06QXJ01XJ6P0PH610080[jn_00D0/K6a0:NWY`2WYjL0RHV90:FU
Y@020::RXP050:BTY02WYjL0YjNW09bLW02QXJ400P2][Jd01@2b/[80OGem07emO@2>SXh0][Jf0080
];Bd00@0/[:b0;Jf]P2f][H0/;2`0P2WYjL01@2VYZH0YjNW0:NWY`2WYjL0Zj^[0080YjNW00D0XJ6Q
08b<S02ATI40TI6A0;:b/P020;6a/@050;2`/02^[Zh0[Zj^0;>c/`2e]KD00P2d];@01@2b/[80/K6a
0;6a/@2f][H0]kNg0080][Jf00@0EeMG0:JVYP2VYZH0];Bd0P2`/;001@2a/K40/;2`0:6QX@2QXJ40
XZ:R0080YjNW00D0_kno0<30`030`<00`<300;fm_@020:j^[P0504A4A01jNWX0ZJVY0:VYZ@2_[jl0
0P2f][H01@2h^;P0[Jf]0:f][@2XZ:P0YZJV00<0Xj>S0P21PH401@15ADD0^;Rh0;Rh^02h^;P0_;bl
00<0^KVi0P2g]kL01@2f][H0Zj^[09BDU02DU9@0ZJVY0080/k>c00D0]KFe096AT@1eMGD0MGEe0;6a
/@020;:b/P050:f][@2d];@0^k^k0;^k^`2n_[h00P2j^[X01@2l_;`0^k^k0;^k^`2g]kL0[:b/0080
];Bd00D0Kfm_0:RXZ02XZ:P0/[:b0:VYZ@0209bLW00409nOW`2e]KD0]KFe0;Rh^080/k>c00D0];Bd
0:f][@2a/K40/K6a0;Rh^00207YjNP0306e]KOoooooooooo00oooooo00@0IfMW096AT@2ATI40LW9b
0P1VIVH01@21PH40Vi^K09^KV`2LW9`0RHV90080Ng]k00D0UIFE06e]K@1]KFd0OGem07MgM`0206IV
IP0404e=C@1JFUX0FUYJ08>3P`80NWYj00D0HV9R02l_;`1BDU80DU9B04I6AP0204U9B@0508N7Q`1D
E5@0E5AD08V9R@2DU9@00P2SXj<0102TY:@0Ng]k07]kN`1^KVh2071`L00506EUI@30`<00QhN708N7
Q`22PX800P1_Kfl01@1KFe/0Q8B40;Rh^02h^;P0e]KF0080[Zj^00D0KFe]0820P020P800RHV907Qh
N00209BDU0040820P01]KFd0KFe]06EUI@80XZ:R00D0Lg=c0:^[Z`2IVIT0VIVI0:NWY`0205mOG`05
0=CDe02NWYh0U9BD09BDU02QXJ400P2JVYX01@2f][H0TY:B09:BTP1gMgL0OWin0080SHf=00@0SXj>
08:2PP22PX80S8b<0P1cLg<01@2NWYh0YjNW07IfMP1fMWH0KFe]0080MgMg00D0WIfM0:JVYP2FUYH0
UYJF09>CT`02065QH@05055AD@3Jf]X0f][J092@T01cLg<00P1iNGT0101VIVH0N7Qh07QhN030`<02
0;Fe]@050:FUY@27QhL0Xj>S0:>SX`20P8000P2[Zj/01@1SHf<0Ph>308>3P`2?Shl0T92@0080H61P
00D0=3@d02/[:`0[:b/0?clo0451@@0203@d=00405UIF@1VIVH0IVIV05YJFP80IfMW00D0JVYZ061P
H01ADE40DE5A069RHP02071`L00507QhN02MWId0WIfM09FEU@28R8P00P1kNg/01@2;Rh/0YJFU0:FU
Y@2VYZH0RHV90080L71`00@0JVYZ07]kN`1kNg/0G5aL0P1cLg<00`1UIFGoooooooooo`08ooooo`00
2_ooool0102XZ:P0Xj>S0:>SX`2VYZH209nOW`0303Lg=`2JVYX0Xj>S0080Xj>S0P2RXZ801@2NWYh0
WinO09nOW`2UYJD0Z:RX0080ZJVY00D0Xj>S09fMW@2MWId0Xj>S0:2PX00206i^KP0408J6QP2`/;00
/;2`0;Rh^080/k>c00D0UiNG0:JVYP2MWId0WIfM0:2PX0020:VYZ@030:>SX`2UYJD0];Bd0080];Bd
0P2<S8`01@24Q8@0^KVi0;Jf]P2f][H0];Bd0080/k>c00@0[jn_0:JVYP2VYZH0YJFU102ZZZX20:RX
Z0050:f][@1fMWH0Kfm_06m_K`2ZZZX00P2^[Zh01@2a/K40[Jf]0:f][@2`/;00[Jf]0080/;2`00D0
[jn_0;6a/@2a/K40/;2`0;Fe]@020;Ng]`04065QH@2TY:@0Y:BT0:^[Z`80[Zj^00<0ZZZZ0:f][@2U
YJD00P2UYJD20:JVYP050;Bd]02k^k/0_kno0;no_`2n_[h00P2PX:001@0i>CT0Ogmo0:ZZZP2ZZZX0
[Jf]0080[:b/00D0[Zj^0:ZZZP2ZZZX0XZ:R0:FUY@020:>SX`0509BDU024Q8@0Q8B404U9B@2g]kL0
0P2k^k/01033`l<0_[jn0;jn_P32`/820;fm_@050;Zj^P2UYJD0Ti>C09>CT`2_[jl00P2l_;`01@2k
^k/0Ti>C0820P020P800/[:b0080];Bd00<0]KFe0;Vi^@2i^KT00P2i^KT20;Bd]0050;bl_02k^k/0
^k^k0;Rh^02`/;000P2b/[801@1WIfL0YZJV0:JVYP2c/k<0ZZZZ0080T92@00@0U9BD0;Jf]P2f][H0
^[Zj0P2i^KT01@2g]kL0]KFe0;Vi^@2i^KT0^k^k0080O7al00<0MWIfooooooooool03oooool0101d
M7@0VYZJ09ZJVP1lO7`205eMG@0507YjNP2@T900T92@09jNWP2QXJ400P1[Jf/01@1oOgl0IVIV06IV
IP1fMWH0Lg=c0080H61P00@0CTi>06ATI01TI6@0Shn?0P2GUiL01@23Ph<0>CTi071`L01`L700LW9b
0080GemO00D0OGem05EEE@1EEED0Shn?08f=S@0209^KV`040::RXP1jNWX0NWYj06][J`80LW9b00D0
FUYJ0<;2`P28R8P0R8R80861P@0207moO`0505eMG@2CTi<0^k^k0;^k^`3Jf]X00P2[Zj/01@1CDe<0
CDe=04e=C@20P800KFe]0080Q8B400@0MWIf06IVIP1VIVH0KVi^0P2a/K401@23Ph<0[Jf]09JFUP2F
UYH0XJ6Q0080FEUI00D0gmoO0::RXP2KVi/0Vi^K0;Rh^00209NGU`050<W9b@2=SHd0SHf=07alO021
PH400P2CTi<0102;Rh/0WinO09nOW`2RXZ820820P0050:NWY`2k^k/0NGUi07UiN@21PH400P1oOgl0
1@2NWYh0ZJVY0:n_[`2_[jl0Rh^;0080F5QH00D0D51@0=;BdP3Bd]80R8R806=SH`0206i^KP0405IF
EP1aLG40LG5a0<_;b`80_[jn00D0ZJVY08>3P`2KVi/0Vi^K08f=S@020;Fe]@0506=SH`1nOWh0OWin
09nOW`2TY:@00P1fMWH01@13@d<0?Shn03hn?P1CDe<0DU9B0080@T9200@0Ng]k04a<C01<C4`0Cdm?
0P1[Jf/01@1VIVH0EUIF04E5A@15ADD0A4A40080D51@00D0Ogmo0:6QX@2QXJ40UiNG08V9R@02096A
T@0508j>SP1oOgl0Ogmo09FEU@1nOWh00P1^KVh0101bLW80QXJ608J6QP1SHf<2075aL@0307MgMooo
oooooooo00Sooooo000:ooooo`040:RXZ02SXj<0Xj>S0:JVYP80WinO00<0=cLg09ZJVP2SXj<00P2S
Xj<20::RXP0509jNWP2OWil0WinO0:FUY@2XZ:P00P2YZJT01@2SXj<0WIfM09fMW@2SXj<0X:2P0080
KVi^00@0QXJ60;2`/02`/;00^;Rh0P2c/k<01@2GUiL0YZJV09fMW@2MWId0X:2P0080ZJVY00<0Xj>S
0:FUY@2d];@00P2d];@208b<S00508B4Q02i^KT0][Jf0;Jf]P2d];@00P2c/k<0102_[jl0YZJV0:JV
YP2UYJD40:ZZZP80Z:RX00D0[Jf]07IfMP1_Kfl0Kfm_0:ZZZP020:j^[P050;6a/@2][Jd0[Jf]0;2`
/02][Jd00P2`/;001@2_[jl0/K6a0;6a/@2`/;00]KFe0080]kNg00@0HF5Q0:BTY02TY:@0Zj^[0P2^
[Zh00`2ZZZX0[Jf]0:FUY@020:FUY@80YZJV00D0];Bd0;^k^`2o_kl0_kno0;jn_P020:2PX00503Ti
>@1oOgl0ZZZZ0:ZZZP2][Jd00P2/[:`01@2^[Zh0ZZZZ0:ZZZP2RXZ80YJFU0080Xj>S00D0U9BD08B4
Q024Q8@0BDU90;Ng]`020;^k^`040<?3``2n_[h0_[jn0<;2`P80_Kfm00D0^[Zj0:FUY@2CTi<0Ti>C
0:n_[`020;bl_0050;^k^`2CTi<0P8200820P02b/[800P2d];@00`2e]KD0^KVi0;Vi^@020;Vi^@80
];Bd00D0_;bl0;^k^`2k^k/0^;Rh0;2`/0020;:b/P0506MWI`2VYZH0YZJV0;>c/`2ZZZX00P2@T900
102DU9@0][Jf0;Jf]P2j^[X20;Vi^@050;Ng]`2e]KD0^KVi0;Vi^@2k^k/00P1lO7`00`1fMWKooooo
ooooo`0?ooooo`0407AdM02JVYX0VYZJ07alO080GEeM00D0NWYj092@T02@T900WYjN0:6QX@0206][
J`0507moO`1VIVH0IVIV07IfMP1cLg<00P1PH600101>CTh0I6AT06ATI02?Shl209NGU`0508>3P`0i
>CT0L71`071`L01bLW800P1OGel01@1mOGd0EEEE05EEE@2?Shl0SHf=0080Vi^K00@0XZ:R07YjNP1j
NWX0Jf][0P1bLW801@1JFUX0`/;208R8R028R8P0PH610080Ogmo00D0GEeM09>CT`2k^k/0^k^k0=[J
fP020:^[Z`0505=CD`1=CDd0CDe=0820P01]KFd00P24Q8@0101fMWH0IVIV06IVIP1^KVh20;6a/@05
08>3P`2][Jd0UYJF09JFUP2QXJ400P1IFET01@3Ogml0XZ:R09^KV`2KVi/0^;Rh0080UiNG00D0bLW9
08f=S@2=SHd0O7al0861P@0209>CT`0408^;R`2OWil0WinO0::RXP80P82000D0YjNW0;^k^`1iNGT0
NGUi0861P@0207moO`0509jNWP2YZJT0[jn_0:n_[`2;Rh/00P1HF5P01@1@D500d];B0=;BdP28R8P0
Hf=S0080KVi^00@0EUIF075aL@1aLG40bl_;0P2n_[h01@2YZJT0Ph>309^KV`2KVi/0SHf=0080]KFe
00D0Hf=S07inOP1nOWh0WinO0:BTY00207IfMP0504=3@`0n?Sh0?Shn05=CD`1BDU800P12@T80101k
Ng/0C4a<04a<C01?Cdl206][J`0506IVIP1FEUH0ADE504E5A@14A4@00P1@D5001@1oOgl0XJ6Q0:6Q
X@2GUiL0RHV90080TI6A00D0SXj>07moO`1oOgl0UIFE07inOP0206i^KP04079bLP26QXH0QXJ606=S
H`80LG5a00<0MgMgooooooooool02?ooool000[ooooo00@0/K6a0;>c/`2c/k<0/;2`0P2b/[801@1G
EeL0XZ:R0::RXP2RXZ80Xj>S0080XZ:R00D0TY:B09ZJVP2JVYX0VIVI0:RXZ0020:b/[0050:NWY`2Q
XJ40XJ6Q0:>SX`2PX:000P1RHV801020P800ZJVY0:VYZ@2_[jl20;2`/00509^KV`2][Jd0XJ6Q0:6Q
X@2VYZH00P2YZJT01@2RXZ80W9bL0::RXP2RXZ80[jn_0080Ogmo00D0OWin0:n_[`2a/K40/K6a0;Jf
]P020;Bd]0050;>c/`2/[:`0[:b/0:FUY@2][Jd00P2[Zj/01@2/[:`0Z:RX0:RXZ02OWil0FEUI0080
Fe]K00@0XZ:R0:ZZZP2ZZZX0ZZZZ0P2XZ:P01@2WYjL0Z:RX0:FUY@2UYJD0ZJVY0080ZZZZ00D0[Zj^
0;>c/`2f][H0][Jf06i^KP030:>SX`80YZJV00D0YjNW0:RXZ02YZJT0ZJVY0:f][@020:ZZZP050;Bd
]02i^KT0^[Zj0;Zj^P2k^k/00P2_[jl01@1=CDd0MWIf0:RXZ02XZ:P0YjNW0080[Jf]00D0Zj^[0:f]
[@2][Jd0ZJVY0:FUY@0208n?S`0508R8R023Ph<0Ph>305eMG@2a/K400P2f][H0102h^;P0][Jf0;Jf
]P2l_;`20;Ng]`050;bl_02XZ:P0Z:RX0:RXZ02h^;P00P31`L401@2m_Kd0UiNG08>3P`23Ph<0/[:b
0080/k>c00D0^;Rh0;Vi^@2j^[X0^[Zj0;Vi^@020;>c/`050;Fe]@2i^KT0^KVi0;>c/`2][Jd00P2`
/;001@1MGEd0Xj>S0:>SX`2c/k<0ZJVY0080PX:200@0MGEe0:>SX`2SXj<0[jn_0P2b/[801@2][Jd0
];Bd0;Bd]02d];@0]kNg0080RXZ:00<0P820ooooooooool03oooool0101UIFD0SHf=08f=S@1fMWH2
04Y:BP0508>3P`2PX:00X:2P09fMW@20P8000P1hN7P01@1jNWX0EUIF05IFEP1dM7@0Lg=c0080Fe]K
00@0<c<c03/k>`0k>c/0J6QX0P1oOgl01@1dM7@0<c<c05YJFP1JFUX0Hf=S0080DU9B00D0MWIf05YJ
FP1JFUX0TI6A09BDU0020:^[Z`040;Bd]02ATI40TI6A07AdM080K6a/00D0CDe=0;Zj^P2;Rh/0Rh^;
0820P00208B4Q00505YJFP2?Shl0];Bd0;Bd]03AdM400P2NWYh01@1jNWX0G5aL05aLG01mOGd0LG5a
0080QHF500@0Ti>C05mOG`1OGel0K6a/0P2a/K401@2;Rh/0YZJV09FEU@2EUID0Zj^[0080G5aL00D0
bl_;09BDU02BTY80TY:B0:JVYP0208V9R@050;bl_027QhL0QhN707=cL`1VIVH00P1iNGT0101cLg<0
R8R808R8R02GUiL207MgM`050:FUY@2YZJT0LW9b079bLP21PH400P1lO7`01@2@T900X:2P0;Vi^@2i
^KT0UYJF0080LG5a00D0HV9R0>7Qh@3QhN40Ti>C06ATI00208N7Q`0406MWI`1oOgl0Ogmo0=GEe@80
`<3000D0]KFe07emO@2NWYh0WYjN0861P@020;Ng]`05079bLP1mOGd0OGem09fMW@2WYjL00P1gMgL0
1@0k>c/0>SXj03Xj>P16ATH0CTi>0080@41000@0NWYj05eMG@1MGEd0D51@0P1GEeL01@1@D500Fe]K
06=SH`1SHf<0Fe]K0080D51@00D0Jf][0::RXP2RXZ80RHV909fMW@020:FUY@0509:BTP2HV9P0V9RH
0;bl_029RHT00P1mOGd0101/K6`0MgMg07MgM`1ADE4207moO`03075aLOoooooooooo00Sooooo000:
ooooo`0306EUI@1GEeL0EeMG00<0B4Q800D0<C4a0410@01;Bd/0Bd];055AD@02059BDP0504Y:BP0n
?Sh0?Shn02TY:@1;Bd/00P1SHf<01@1KFe/0CDe=04e=C@17AdL0?clo0080?Shn00@0Bd];05EEE@1E
EED0JVYZ0P1PH6000`1DE5@0A4A403Ph>00203Ph>080>CTi00D0<C4a03Ph>015ADD0ADE50410@002
03/k>`0504Y:BP1IFET0FUYJ05YJFP1UIFD00P1WIfL01@1GEeL0@T920492@P0l?3`0De=C0080DE5A
00D0CDe=0451@@11@D40?clo03Hf=P0202/[:`0405ADE01ADE40DE5A059BDP80?Shn00D0@d=303Ti
>@0e=CD0=CDe04U9B@020451@@05059BDP1=CDd0CDe=04e=C@0g=cL00P1RHV80101WIfL0HF5Q065Q
H@1SHf<306e]K@05075aL@1ZJVX0JVYZ071`L01VIVH00P1[Jf/01@1XJ6P0De=C05=CD`0/;2`0B4Q8
0080IVIV00@0HF5Q05]KF`1KFe/0IVIV0P1MGEd01@1HF5P0C4a<05eMG@1MGEd0IFEU0080HF5Q00D0
>CTi061PH01[Jf/0Jf][07=cL`02075aL@0507]kN`1eMGD0MGEe07alO01_Kfl00P1gMgL01@20P800
QHF508F5Q@23Ph<0JFUY0080EEEE00D0NWYj07alO01lO7`0Ph>30820P0020861P@0407emO@21PH40
PH6107YjNP80PX:200D0OWin07QhN01iNGT0NGUi04Y:BP0207]kN`0507UiN@1RHV80De=C05=CD`1D
E5@00P1QHF401@1aLG40NWYj07YjNP1jNWX0PX:20080SHf=00@0R8R806EUI@1UIFD0HV9R4Oooool0
101WIfL0QHF508F5Q@1dM7@204I6AP0508j>SP2QXJ40XJ6Q09^KV`2?Shl00P2FUYH01@1mOGd0IVIV
06IVIP25QHD0Ogmo0080HF5Q00@0ADE504m?C`1?Cdl0Jf][0P2ATI401@1[Jf/0<C4a05mOG`1OGel0
JVYZ0080IFEU00D0RXZ:065QH@1QHF40UiNG09VIV@020:JVYP040;2`/02;Rh/0Rh^;06][J`80K6a/
00D0EeMG0<?3``28R8P0R8R807alO00208b<S00504m?C`2@T900_;bl0;bl_03Fe]H00P2OWil01@1b
LW80HF5Q065QH@24Q8@0NWYj0080QhN700@0RXZ:05]KF`1KFe/0JVYZ0P2RXZ801@23Ph<0XJ6Q09>C
T`2CTi<0VIVI0080IfMW00D0gmoO0:>SX`2LW9`0W9bL0;>c/`0209^KV`050<k>cP2>SXh0SXj>08B4
Q01kNg/00P26QXH0101iNGT0Xj>S0:>SX`27QhL205iNGP050:>SX`2d];@0OGem07emO@1nOWh00P1g
MgL01@29RHT0X:2P0:b/[02/[:`0P8200080KVi^00D0HV9R0=cLg03Lg=`0V9RH06m_K`0207]kN`04
06YZJP1gMgL0MgMg0<G5a@80^k^k00D0^KVi0861P@2OWil0WinO07moO`020:VYZ@0507moO`23Ph<0
Ph>30::RXP2a/K400P1nOWh01@14A4@0@4100410@01PH600JVYZ0080FUYJ00@0RXZ:07AdM01dM7@0
Hf=S0P1TI6@01@1JFUX0HV9R05iNGP1NGUh0AdM70080@D5100D0P82009^KV`2KVi/0XZ:R08n?S`02
0:>SX`0507inOP24Q8@0Q8B40;6a/@20P8000P2FUYH0101YJFT0MgMg07MgM`1LG5`207YjNP0307]k
Nooooooooooo00Sooooo000:ooooo`0306EUI@1GEeL0EeMG00<0B4Q800D0<C4a0410@01;Bd/0Bd];
055AD@02059BDP0504Y:BP0n?Sh0?Shn02TY:@1;Bd/00P1SHf<01@1KFe/0CDe=04e=C@17AdL0?clo
0080?Shn00@0Bd];05EEE@1EEED0JVYZ0P1PH6000`1DE5@0A4A403Ph>00203Ph>080>CTi00D0<C4a
03Ph>015ADD0ADE50410@00203/k>`0504Y:BP1IFET0FUYJ05YJFP1UIFD00P1WIfL01@1GEeL0@T92
0492@P0l?3`0De=C0080DE5A00D0CDe=0451@@11@D40?clo03Hf=P0202/[:`0405ADE01ADE40DE5A
059BDP80?Shn00D0@d=303Ti>@0e=CD0=CDe04U9B@020451@@05059BDP1=CDd0CDe=04e=C@0g=cL0
0P1RHV80101WIfL0HF5Q065QH@1SHf<306e]K@05075aL@1ZJVX0JVYZ071`L01VIVH00P1[Jf/01@1X
J6P0De=C05=CD`0/;2`0B4Q80080IVIV00@0HF5Q05]KF`1KFe/0IVIV0P1MGEd01@1HF5P0C4a<05eM
G@1MGEd0IFEU0080HF5Q00D0>CTi061PH01[Jf/0Jf][07=cL`02075aL@0507]kN`1eMGD0MGEe07al
O01_Kfl00P1gMgL01@20P800QHF508F5Q@23Ph<0JFUY0080EEEE00D0NWYj07alO01lO7`0Ph>30820
P0020861P@0407emO@21PH40PH6107YjNP80PX:200D0OWin07QhN01iNGT0NGUi04Y:BP0207]kN`05
07UiN@1RHV80De=C05=CD`1DE5@00P1QHF401@1aLG40NWYj07YjNP1jNWX0PX:20080SHf=00@0R8R8
06EUI@1UIFD0HV9R4Oooool0101WIfL0QHF508F5Q@1dM7@204I6AP0508j>SP2QXJ40XJ6Q09^KV`2?
Shl00P2FUYH01@1mOGd0IVIV06IVIP25QHD0Ogmo0080HF5Q00@0ADE504m?C`1?Cdl0Jf][0P2ATI40
1@1[Jf/0<C4a05mOG`1OGel0JVYZ0080IFEU00D0RXZ:065QH@1QHF40UiNG09VIV@020:JVYP040;2`
/02;Rh/0Rh^;06][J`80K6a/00D0EeMG0<?3``28R8P0R8R807alO00208b<S00504m?C`2@T900_;bl
0;bl_03Fe]H00P2OWil01@1bLW80HF5Q065QH@24Q8@0NWYj0080QhN700@0RXZ:05]KF`1KFe/0JVYZ
0P2RXZ801@23Ph<0XJ6Q09>CT`2CTi<0VIVI0080IfMW00D0gmoO0:>SX`2LW9`0W9bL0;>c/`0209^K
V`050<k>cP2>SXh0SXj>08B4Q01kNg/00P26QXH0101iNGT0Xj>S0:>SX`27QhL205iNGP050:>SX`2d
];@0OGem07emO@1nOWh00P1gMgL01@29RHT0X:2P0:b/[02/[:`0P8200080KVi^00D0HV9R0=cLg03L
g=`0V9RH06m_K`0207]kN`0406YZJP1gMgL0MgMg0<G5a@80^k^k00D0^KVi0861P@2OWil0WinO07mo
O`020:VYZ@0507moO`23Ph<0Ph>30::RXP2a/K400P1nOWh01@14A4@0@4100410@01PH600JVYZ0080
FUYJ00@0RXZ:07AdM01dM7@0Hf=S0P1TI6@01@1JFUX0HV9R05iNGP1NGUh0AdM70080@D5100D0P820
09^KV`2KVi/0XZ:R08n?S`020:>SX`0507inOP24Q8@0Q8B40;6a/@20P8000P2FUYH0101YJFT0MgMg
07MgM`1LG5`207YjNP0307]kNooooooooooo00Sooooo000:ooooo`040;6a/@2:RXX0RXZ:07UiN@80
VYZJ00D0XZ:R0:VYZ@2/[:`0[:b/09jNWP0209:BTP0508f=S@21PH40PH6102HV9P2VYZH00P2WYjL0
102QXJ40X:2P0:2PX02KVi/309ZJVP0409NGU`2NWYh0WYjN09jNWP80Rh^;00D0Shn?09:BTP1DE5@0
E5AD096AT@0209bLW0050:6QX@2^[Zh0/K6a0;6a/@2c/k<00`2d];@0102f][H0[jn_0:n_[`2_[jl2
0:VYZ@0508V9R@1IFET0FEUI0:JVYP2QXJ400P2WYjL01@2XZ:P0XJ6Q0:6QX@2SXj<0WinO0080UIFE
00@0VYZJ0::RXP2RXZ80Z:RX0P2ZZZX01@1SHf<0>SXj08j>SP2>SXh0V9RH0080WYjN00D0YZJV0:VY
Z@2YZJT0ZJVY0:2PX002092@T00509BDU02SXj<0Xj>S0:f][@2WYjL00P1hN7P01@1VIVH0WIfM09fM
W@2VYZH0Y:BT0080[jn_00D0/K6a0:n_[`2_[jl0[Zj^0:JVYP0209ZJVP040:b/[02f][H0][Jf0;:b
/P80J6QX00D0L71`09^KV`2MWId0WIfM09NGU`0209JFUP0509fMW@2NWYh0WIfM09fMW@2IVIT00`2H
V9P209^KV`0508F5Q@13@d<0Jf][06][J`1hN7P00P1jNWX01@1dM7@0Lg=c07IfMP1fMWH0M7Ad0080
IfMW00D0F5QH05aLG01BDU80DU9B03Lg=`02069RHP0506YZJP1YJFT0JFUY06UYJ@1VIVH00P1/K6`0
1@1_Kfl0EeMG05MGE`1NGUh0K6a/0080Jf][00@0Lg=c05mOG`1OGel0BTY:0P1/K6`01@1[Jf/0JFUY
06MWI`1WIfL0JFUY0080J6QX00<0I6ATooooooooool03oooool0101XJ6P0SHf=08f=S@1nOWh204e=
C@0509BDU02IVIT0VIVI09JFUP2:RXX00P2DU9@01@20P800MgMg07MgM`25QHD0PX:20080HV9R00@0
De=C05mOG`1OGel0KVi^0P2CTi<01@1gMgL0=CDe05UIF@1IFET0KVi^0080IFEU00D0MGEe05aLG01L
G5`0SHf=09FEU@020:JVYP040;6a/@2FUYH0UYJF07AdM080L71`00D0GEeM0<[:bP29RHT0RHV908J6
QP0208n?S`0504U9B@2IVIT0`l?30<?3``3Cdm<00P2QXJ401@1]KFd0IVIV06IVIP2=SHd0QHF50080
QXJ600@0R8R805EEE@1EEED0J6QX0P2KVi/01@2<S8`0Shn?08B4Q024Q8@0X:2P0080KVi^00D0fMWI
0;:b/P2GUiL0UiNG0;jn_P0209JFUP050;jn_P1gMgL0MgMg07AdM01aLG400P21PH40101]KFd0X:2P
0:2PX01oOgl205]KF`050:BTY02][Jd0NGUi07UiN@27QhL00P1eMGD01@1oOgl0YJFU0:f][@2][Jd0
O7al0080Lg=c00D0EEEE0>3Ph03Ph>00S8b<06a/K00207AdM00406UYJ@26QXH0QXJ60<?3``80^[Zj
00D0]kNg06m_K`2YZJT0ZJVY0820P00209ZJVP0508F5Q@1kNg/0Ng]k09RHV02i^KT00P1fMWH01@10
@400?3`l03`l?01GEeL0KVi^0080GemO00@0KVi^06e]K@1]KFd0J6QX0P1NGUh01@1GEeL0Jf][069R
HP1RHV80FEUI0080ATI600D0Hf=S096AT@2ATI40WYjN09JFUP020;Jf]P0507MgM`2?Shl0Shn?0:b/
[020P8000P22PX80101MGEd0M7Ad07AdM01bLW8208R8R00307EeMOoooooooooo00Sooooo000:oooo
o`040;Bd]02RXZ80XZ:R092@T080Ti>C00D0Y:BT0:RXZ02a/K40/K6a09FEU@0208^;R`050::RXP2L
W9`0W9bL02`/;02KVi/00P2RXZ801@2CTi<0SHf=08f=S@2<S8`0QXJ60080P82000@0Rh^;08V9R@29
RHT0QHF50P1YJFT01@2@T900UiNG03hn?P0n?Sh0Q8B40080S8b<00D0SHf=09jNWP2PX:00X:2P09fM
W@020:JVYP050:NWY`2XZ:P0YjNW0:NWY`2SXj<00P2PX:00102CTi<0KFe]06e]K@2RXZ830:2PX005
0:>SX`2QXJ40XJ6Q0:2PX02KVi/00P2;Rh/0102HV9P0WinO09nOW`2TY:@20:ZZZP0507AdM01ADE40
YJFU0:FUY@2QXJ400P2UYJD01@2YZJT0ZZZZ0:JVYP2VYZH0Xj>S0080V9RH00D0X:2P0:FUY@2UYJD0
[Zj^0;2`/00206m_K`0507UiN@2XZ:P0Z:RX0:VYZ@2[Zj/00P2e]KD00`2b/[80[jn_0:n_[`020;Vi
^@80][Jf00@0];Bd0;Jf]P2f][H0^;Rh0P1_Kfl01@1kNg/0]kNg0;Ng]`2g]kL0/K6a0080[:b/0P2i
^KT20;>c/`040:j^[P2g]kL0]kNg0;bl_080`<3000D0/[:b03dm?@1mOGd0OGem0:NWY`020;>c/`05
0:n_[`2TY:@0W9bL09bLW02JVYX00P2<S8`01@2QXJ40/;2`0;^k^`2k^k/0J6QX0080UIFE00D0^KVi
0;6a/@2a/K40/[:b0;2`/0020;>c/`050:FUY@21PH40PH610::RXP2][Jd00P2ZZZX0102`/;00QHF5
08F5Q@22PX820;Vi^@050<30`02n_[h0`L710<71`@2h^;P00P2i^KT00`2h^;Soooooooooo`0?oooo
o`0407YjNP2=SHd0SHf=08B4Q080DU9B0`2LW9`01@2>SXh0S8b<08n?S`2?Shl0L71`0080KFe]00D0
J6QX06YZJP1MGEd0GEeM04i>CP0205aLG00506YZJP2@T900T92@06e]K@0b<S800P1DE5@0101IFET0
E5AD05ADE01fMWH205IFEP0509JFUP2EUID0YJFU0:FUY@2VYZH00P2CTi<01@1`L700MGEe07EeM@1L
G5`0a/K60080W9bL00D0OGem07IfMP1fMWH0ATI609BDU0020;Fe]@040=CDe02CTi<0Ti>C07AdM080
J6QX00D0WinO09:BTP1lO7`0O7al09bLW00206IVIP0506m_K`2a/K40/K6a0:f][@2`/;000P2RXZ80
1@2_[jl0MWIf07IfMP3Hf=P0ZZZZ0080X:2P00@0`<300:^[Z`2[Zj/0alO70P1iNGT01@1fMWH0Lg=c
06m_K`1_Kfl0CTi>0080O7al00D0LW9b06EUI@1UIFD0YZJV0;Jf]P02092@T00508J6QP1dM7@0M7Ad
08J6QP2WYjL00P2m_Kd0101_Kfl0P8200820P01HF5P20=kNgP0509VIV@1gMgL0PX:208:2PP1^KVh0
0P2?Shl01@3=cLd0`l?30<?3``2c/k<0KFe]0080XJ6Q00@0RHV909ZJVP2JVYX0N7Qh0P1mOGd01@27
QhL0_;bl06MWI`1WIfL0>3Ph0080;Rh^00D0ADE505aLG01PH600H61P05]KF`0206YZJP0505YJFP1I
FET0FEUI05QHF01OGel00P1^KVh0101bLW80EUIF05IFEP1iNGT209RHV0050:FUY@2=SHd0_kno0;no
_`1_Kfl00P27QhL01@2ZZZX0OWin06m_K`1_Kfl0E5AD0080C4a<00@0FUYJ05aLG01LG5`0Fe]K2_oo
ool000[ooooo00@0];Bd0::RXP2RXZ80T92@0P2CTi<01@2TY:@0Z:RX0;6a/@2a/K40UIFE0080Rh^;
00D0XZ:R09bLW02LW9`0;2`/09^KV`020::RXP0509>CT`2=SHd0SHf=08b<S026QXH00P20P800102;
Rh/0RHV908V9R@25QHD206UYJ@05092@T02GUiL0?Shn03hn?P24Q8@00P2<S8`01@2=SHd0WYjN0:2P
X02PX:00WIfM0080YZJV00D0YjNW0:RXZ02WYjL0YjNW0:>SX`020:2PX00409>CT`1]KFd0KFe]0::R
XP<0X:2P00D0Xj>S0:6QX@2QXJ40X:2P09^KV`0208^;R`0409RHV02OWil0WinO0:BTY080ZZZZ00D0
M7Ad055AD@2UYJD0YJFU0:6QX@020:FUY@050:VYZ@2ZZZX0YZJV0:JVYP2SXj<00P2HV9P01@2PX:00
YJFU0:FUY@2^[Zh0/;2`0080Kfm_00D0NGUi0:RXZ02XZ:P0ZJVY0:^[Z`020;Fe]@030;:b/P2_[jl0
[jn_0080^KVi0P2f][H0102d];@0][Jf0;Jf]P2h^;P206m_K`0507]kN`2g]kL0]kNg0;Ng]`2a/K40
0P2/[:`20;Vi^@80/k>c00@0[Zj^0;Ng]`2g]kL0_;bl0P30`<001@2b/[80?Cdm07emO@1mOGd0YjNW
0080/k>c00D0[jn_0:BTY02LW9`0W9bL09ZJVP0208b<S0050:6QX@2`/;00^k^k0;^k^`1XJ6P00P2E
UID01@2i^KT0/K6a0;6a/@2b/[80/;2`0080/k>c00D0YJFU0861P@21PH40XZ:R0:f][@020:ZZZP04
0;2`/025QHD0QHF508:2PP80^KVi00D0`<300;jn_P31`L40`L710;Rh^0020;Vi^@030;Rh^?oooooo
oooo00oooooo00@0NWYj08f=S@2=SHd0Q8B40P1BDU8309bLW00508j>SP2<S8`0Shn?08n?S`1`L700
0P1]KFd01@1XJ6P0JVYZ05eMG@1MGEd0CTi>0080G5aL00D0JVYZ092@T02@T900KFe]038b<P0205AD
E00405UIF@1DE5@0E5AD07IfMP80EUIF00D0UYJF09FEU@2UYJD0YJFU0:JVYP0209>CT`05071`L01e
MGD0MGEe05aLG036a/H00P2LW9`01@1mOGd0MWIf07IfMP16ATH0U9BD0080]KFe00@0e=CD09>CT`2C
Ti<0M7Ad0P1XJ6P01@2OWil0TY:B07alO01lO7`0W9bL0080IVIV00D0Kfm_0;6a/@2a/K40[Jf]0;2`
/0020::RXP050:n_[`1fMWH0MWIf0=SHf02ZZZX00P2PX:001030`<00Zj^[0:^[Z`37alL207UiN@05
07IfMP1cLg<0Kfm_06m_K`1>CTh00P1lO7`01@1bLW80IFEU06EUI@2VYZH0][Jf0080T92@00D0QXJ6
07AdM01dM7@0QXJ60:NWY`020;fm_@0406m_K`20P800P82005QHF080g]kN00D0VIVI07MgM`22PX80
PX:206i^KP0208n?S`050<g=c@33`l<0`l?30;>c/`1]KFd00P2QXJ401029RHT0VYZJ09ZJVP1hN7P2
07emO@0508N7Q`2l_;`0IfMW06MWI`0h>3P00P0^;Rh01@15ADD0G5aL061PH01PH600Fe]K0080JVYZ
00D0FUYJ05UIF@1IFET0F5QH05mOG`0206i^KP04079bLP1FEUH0EUIF07UiN@80V9RH00D0YJFU08f=
S@2o_kl0_kno06m_K`0208N7Q`050:ZZZP1nOWh0Kfm_06m_K`1DE5@00P1<C4`0101JFUX0G5aL05aL
G01KFe/:ooooo`002_ooool0102[Zj/0YJFU0:FUY@2DU9@208f=S@050:2PX02VYZH0YjNW0:NWY`2>
SXh00P29RHT01@2OWil0Ti>C09>CT`0/;2`0WYjN0080WinO00D0V9RH08R8R028R8P0Q8B407UiN@02
08B4Q00408Z:RP26QXH0QXJ608n?S`80OWin00D0Ti>C096AT@0g=cL0=cLg08:2PP0209:BTP0508J6
QP2ATI40WinO09nOW`2PX:000P2QXJ40102VYZH0ZJVY0:BTY02TY:@30:2PX00507moO`1[Jf/0Jf][
096AT@2MWId00P2GUiL01@2LW9`0WinO09nOW`2KVi/0W9bL0080U9BD00@0UYJF0:2PX02PX:00Xj>S
0P2UYJD01@1aLG40EUIF0:BTY02TY:@0YZJV0080Y:BT0P2UYJD20:NWY`040:>SX`2JVYX0VYZJ09jN
WP80YJFU00D0Z:RX0:FUY@1ZJVX0JVYZ061PH0020:6QX@050:BTY02/[:`0/k>c0;>c/`2d];@00P2^
[Zh01@2e]KD0^k^k0;Ng]`2g]kL0]KFe00<0][Jf0P1/K6`01@23Ph<0^;Rh0;Bd]02d];@0Z:RX0080
ZJVY00D0][Jf0;Ng]`2c/k<0/k>c0:ZZZP020;Ng]`<0_;bl00D0^[Zj04Q8B02CTi<0Ti>C0;Ng]`02
0;>c/`050:b/[02KVi/0VIVI09VIV@2VYZH00P2[Zj/01@2/[:`0[jn_0;Rh^02h^;P0JVYZ0080UiNG
00D0]KFe0;Bd]02d];@0/K6a0;>c/`020;:b/P050:f][@2RXZ80XZ:R0:ZZZP2[Zj/00P2WYjL0102_
[jl0N7Qh07QhN01lO7`20;Jf]P050;^k^`34a<@0_Kfm0;fm_@2][Jd00P2g]kL00`2e]KGooooooooo
o`0?ooooo`04075aL@28R8P0R8R807alO080DU9B00D0SXj>09^KV`2KVi/0M7Ad08:2PP0208j>SP05
06a/K01`L700L71`07UiN@1KFe/00P1IFET0101:BTX0EEEE05EEE@1fMWH209RHV00508F5Q@0l?3`0
IVIV06IVIP1IFET00P1CDe<01@1kNg/0F5QH05QHF02NWYh0WIfM0080[:b/00@0Zj^[09NGU`2GUiL0
KVi^0P1bLW801@1KFe/0clo?0:VYZ@2YZJT0Rh^;0080Ng]k00D0H61P07QhN02=SHd0SHf=0<?3``02
09ZJVP0507MgM`1NGUh0GUiN08f=S@2EUID00P1gMgL0102OWil0GUiN05iNGP1VIVH20<_;b`050;Zj
^P2[Zj/0W9bL09bLW02a/K400P1mOGd01@3Ph>00/K6a0:ZZZP2ZZZX0[:b/0080Zj^[00D0_kno07al
O01lO7`0QHF506i^KP0207]kN`0404m?C`2HV9P0V9RH07QhN080LW9b00D0]kNg0<?3``2TY:@0Y:BT
09JFUP0207inOP0508^;R`2YZJT0^[Zj0;Zj^P1PH6000P1mOGd01@1LG5`0gMgM0=gMg@2IVIT0Kfm_
0080MGEe00@0IFEU07=cL`1cLg<0^KVi0P2c/k<01@2_[jl0OWin08>3P`23Ph<0P8200080UYJF00D0
Ph>308b<S02<S8`0QhN70<71`@0205UIF@0503Lg=`0[:b/0:b/[04M7A`1KFe/00P1IFET0101ADE40
CTi>04i>CP1DE5@205EEE@0504Y:BP1fMWH0JFUY06UYJ@20P8000P1TI6@01@1YJFT0T92@092@T02^
[Zh0Vi^K0080e]KF00D0GemO08b<S02<S8`0YJFU09BDU00206a/K00404M7A`1ADE40DE5A06m_K`80
GemO00<0E5ADooooooooool02?ooool000[ooooo00@0YJFU0:6QX@2QXJ40Xj>S0P2MWId0102PX:00
WYjN09bLW02LW9`308n?S`0508F5Q@1mOGd0OGem03Ti>@2NWYh00P2PX:001@2VYZH0Y:BT0:BTY02K
Vi/0Q8B40080R8R800@0PH6108V9R@29RHT0T92@0P2KVi/01@2FUYH0V9RH03hn?P0n?Sh0P82000<0
Ph>300@0TY:B09JFUP2FUYH0T92@0P2=SHd01@2ATI40XJ6Q0:>SX`2SXj<0X:2P0080WYjN00D0LG5a
05MGE`1GEeL0IfMW08>3P`02096AT@0508f=S@2LW9`0W9bL09VIV@2LW9`00P26QXH0102BTY80X:2P
0:2PX02QXJ4209nOW`0508F5Q@1VIVH0WIfM09fMW@2XZ:P00P2WYjL01@2SXj<0XJ6Q0:>SX`2SXj<0
Vi^K0080Shn?00D0S8b<09>CT`2CTi<0Ti>C096AT@0207EeM@05065QH@2;Rh/0Rh^;09FEU@2PX:00
0P2WYjL01@2SXj<0XJ6Q0:6QX@2ZZZX0/K6a0080/;2`00@0];Bd0;Ng]`2g]kL0]KFe0P1bLW801@2E
UID0]kNg0;:b/P2b/[80VYZJ0080ZJVY00D0];Bd0;:b/P2^[Zh0[Zj^0:RXZ0020;Jf]P<0^KVi00D0
^;Rh0451@@2KVi/0Vi^K0;Zj^P020;Vi^@040:j^[P2KVi/0YjNW0:NWY`@0[Zj^00@0[jn_0;Vi^@2i
^KT0J6QX0P2JVYX40;6a/@040;Bd]02_[jl0[jn_0:JVYP80Z:RX00D0YJFU0:^[Z`2XZ:P0Z:RX0:j^
[P0207emO@0508:2PP2i^KT0^KVi0;^k^`31`L400P2j^[X0102[Zj/0/;2`0;2`/02d];@Aooooo`04
07emO@2KVi/0Vi^K08f=S@80Cdm?00D0TY:B09jNWP2NWYh0P82008Z:RP0209nOW`0507UiN@1kNg/0
Ng]k07inOP1LG5`00P1MGEd0100i>CT0FEUI05UIF@23Ph<209:BTP0506YZJP0a<C40ADE504E5A@0k
>c/00P1FEUH01@1]KFd0CDe=04e=C@2IVIT0Shn?0080/[:b00@0Xj>S08n?S`2?Shl0FEUI0P1KFe/0
1@1FEUH0bLW909JFUP2FUYH0QHF50080Lg=c00D0Kfm_08N7Q`2ZZZX0ZZZZ0=?Cd`02092@T00508n?
S`1`L700L71`09bLW02QXJ400P25QHD0102RXZ80Hf=S06=SH`1MGEd20;Jf]P050:NWY`2HV9P0Rh^;
08^;R`2KVi/00P1kNg/01@3@d=00/K6a09BDU02DU9@0UYJF0080U9BD00D0[jn_08B4Q024Q8@0N7Qh
07EeM@0207alO004055AD@2LW9`0W9bL07EeM@80Q8B400D0][Jf0<71`@2=SHd0SHf=09ZJVP0206][
J`0507moO`2HV9P0e]KF0=KFeP1TI6@00P22PX801@1SHf<0hN7Q0>7Qh@2CTi<0JFUY0080Ng]k0`1[
Jf/01@2`/;00_Kfm0;fm_@2YZJT0GUiN0080S8b<00@0TI6A09ZJVP2JVYX0O7al0P2;Rh/01@25QHD0
_kno04e=C@1=CDd0>SXj0080:RXZ00D0B4Q805eMG@1^KVh0KVi^04i>CP0205YJFP05051@D01BDU80
DU9B05YJFP1bLW800P1/K6`0102BTY80E5AD05ADE01YJFT2096AT@050:6QX@1bLW80`L710<71`@1F
EUH00P2OWil01@2QXJ40SXj>07inOP1nOWh0FUYJ0080H61P00@0QHF507AdM01dM7@0J6QX2_ooool0
00[ooooo00@0Lg=c06IVIP1VIVH0IfMW0P1LG5`01@10@400ATI60492@P12@T80>SXj0080>CTi00D0
9RHV02LW9`0W9bL0:BTY04E5A@0205=CD`05059BDP1CDe<0De=C0492@P18B4P00P0m?Cd01019BDT0
Cdm?04m?C`1LG5`204a<C00504=3@`0d=3@0?Shn03hn?P1CDe<00P19BDT01@1>CTh0GEeM06IVIP1V
IVH0De=C0080BTY:00D0AdM704m?C`1IFET0FEUI051@D002065QH@0504e=C@19BDT0BDU904E5A@1@
D5000P15ADD01@17AdL0Bd];04];B`1NGUh0EeMG0080Cdm?0`1FEUH01@1JFUX0EEEE05EEE@1:BTX0
ATI60080LG5a00D0Jf][06i^KP1^KVh0JVYZ06QXJ00206IVIP0406ATI01]KFd0KFe]06=SH`80H61P
00D0JVYZ06ATI01FEUH0EUIF04m?C`0204i>CP0505]KF`1`L700Lg=c07=cL`1eMGD00P1cLg<01@1Y
JFT0IFEU075aL@1aLG40Kfm_0080L71`00D0KVi^03/k>`0k>c/0Hf=S0820P00207]kN`0507EeM@21
PH40PH6108B4Q01mOGd00P23Ph<0101jNWX0O7al07alO01gMgL207alO00507IfMP0e=CD0LW9b079b
LP25QHD00P24Q8@01@1mOGd0G5aL07AdM01dM7@0OWin0080Q8B400D0S8b<092@T02BTY80TY:B05mO
G`0207EeM@0508N7Q`2:RXX0RXZ:08F5Q@1nOWh00P1hN7P01@1`L700OWin07inOP20P800R8R80080
PH6100@0PX:206EUI@1UIFD0HF5Q0P2JVYX01@2RXZ80X:2P09fMW@2MWId0Ng]k0080TI6A00<0UiNG
ooooooooool03oooool0101]KFd0QhN708N7Q`1oOgl204M7A`0508N7Q`2IVIT0VIVI07]kN`28R8P0
0P2CTi<01@1aLG40IFEU06EUI@1cLg<0EEEE0080HF5Q00@0IVIV05iNGP1NGUh0IVIV0P1iNGT0101D
E5@08B4Q04A4A014A4@305EEE@0506][J`1PH600H61P08j>SP28R8P00P2ZZZX0102VYZH0Vi^K09^K
V`1ZJVX2069RHP0505YJFP2j^[X0UiNG09NGU`1mOGd00P25QHD01@1HF5P0OWin0:VYZ@2YZJT0dm?C
0080Ph>300D0T92@07EeM@1eMGD0Y:BT0::RXP0208Z:RP0408f=S@1PH600H61P059BDP80Z:RX00D0
YZJV09^KV`2@T900T92@0:6QX@0208V9R@050=OGe`3;bl/0V9RH09RHV02IVIT00P2HV9P01@2b/[80
S8b<08b<S028R8P0IFEU0080M7Ad00@0DU9B07]kN`1kNg/0JVYZ0P2?Shl01@2TY:@0c/k>08>3P`23
Ph<0P8200080Hf=S00D0PX:209BDU03?cll0clo?05=CD`0207]kN`0506IVIP3Lg=`0g=cL08n?S`1[
Jf/00P1aLG40101LG5`0K6a/06a/K02e]KD20;^k^`050;Bd]01XJ6P0VYZJ09ZJVP2NWYh00P2HV9P0
1@21PH40SXj>08j>SP2?Shl0b/[:0080E5AD00D0@D5102XZ:P0Z:RX0C4a<07EeM@0206ATI00405]K
F`1YJFT0JFUY06IVIP80FUYJ00D0C4a<07]kN`1HF5P0F5QH07MgM`0204Q8B005059BDP1gMgL0MgMg
08J6QP2=SHd00P3;bl/01@1PH600Vi^K09^KV`2IVIT0WIfM0080GUiN00@0EeMG06ATI01TI6@0Q8B4
0P1ZJVX00`1KFe_oooooooooo`08ooooo`002_ooool0101cLg<0IVIV06IVIP1WIfL205aLG0050410
@016ATH0@T920492@P0j>SX00P0i>CT01@0V9RH09bLW02LW9`0Y:BT0ADE50080De=C00D0DU9B05=C
D`1CDe<0@T9204Q8B00203dm?@0404U9B@1?Cdl0Cdm?05aLG080C4a<00D0@d=303@d=00n?Sh0?Shn
05=CD`0204U9B@0504i>CP1MGEd0IVIV06IVIP1CDe<00P1:BTX01@17AdL0Cdm?05UIF@1IFET0D51@
0080HF5Q00D0CDe=04U9B@19BDT0ADE5051@D00204E5A@0504M7A`1;Bd/0Bd];05iNGP1GEeL00P1?
Cdl305IFEP0505YJFP1EEED0EEEE04Y:BP16ATH00P1aLG401@1[Jf/0KVi^06i^KP1ZJVX0J6QX0080
IVIV00@0I6AT06e]K@1]KFd0Hf=S0P1PH6001@1ZJVX0I6AT05IFEP1FEUH0Cdm?0080CTi>00D0Fe]K
071`L01cLg<0Lg=c07EeM@0207=cL`0506UYJ@1UIFD0LG5a075aL@1_Kfl00P1`L7001@1^KVh0>c/k
03/k>`1SHf<0P8200080Ng]k00D0MGEe0861P@21PH40Q8B407emO@0208>3P`0407YjNP1lO7`0O7al
07MgM`80O7al00D0MWIf03De=@1bLW80LW9b08F5Q@0208B4Q00507emO@1LG5`0M7Ad07AdM01nOWh0
0P24Q8@01@2<S8`0T92@09:BTP2BTY80GemO0080MGEe00D0QhN708Z:RP2:RXX0QHF507inOP0207Qh
N005071`L01nOWh0OWin0820P028R8P00P21PH401022PX80IFEU06EUI@1QHF4209ZJVP050::RXP2P
X:00WIfM09fMW@1kNg/00P2ATI400`2GUiOoooooooooo`0?ooooo`0406e]K@27QhL0QhN707moO`80
AdM700D0QhN709VIV@2IVIT0Ng]k08R8R00209>CT`05075aL@1UIFD0IFEU07=cL`1EEED00P1QHF40
101VIVH0GUiN05iNGP1VIVH207UiN@0405ADE00Q8B40A4A404A4A0<0EEEE00D0Jf][061PH01PH600
SXj>08R8R0020:ZZZP040:JVYP2KVi/0Vi^K06YZJP80HV9R00D0FUYJ0;Zj^P2GUiL0UiNG07emO@02
08F5Q@0505QHF01nOWh0ZJVY0:VYZ@3Cdm<00P23Ph<01@2@T900MGEe07EeM@2TY:@0XZ:R0080RXZ:
00@0SHf=061PH01PH600DU9B0P2XZ:P01@2VYZH0Vi^K092@T02@T900XJ6Q0080RHV900D0emOG0<_;
b`2HV9P0V9RH09VIV@0209RHV0050;:b/P2<S8`0S8b<08R8R01UIFD00P1dM7@0101BDU80Ng]k07]k
N`1ZJVX208n?S`050:BTY03>c/h0Ph>308>3P`20P8000P1SHf<01@22PX80U9BD0<o?c`3?cll0De=C
0080Ng]k00D0IVIV0=cLg03Lg=`0Shn?06][J`02075aL@0405aLG01/K6`0K6a/0;Fe]@80^k^k00D0
];Bd06QXJ02JVYX0VYZJ09jNWP0209RHV0050861P@2>SXh0SXj>08n?S`3:b/X00P1DE5@01@11@D40
:RXZ02XZ:P1<C4`0MGEe0080I6AT00@0Fe]K06UYJ@1YJFT0IVIV0P1JFUX01@1<C4`0Ng]k05QHF01H
F5P0MgMg0080B4Q800D0DU9B07MgM`1gMgL0QXJ608f=S@020<_;b`05061PH02KVi/0Vi^K09VIV@2M
WId00P1NGUh0101GEeL0I6AT06ATI024Q8@206YZJP0305]KFooooooooooo00Sooooo000:ooooo`04
0:n_[`2TY:@0Y:BT0:FUY@80UiNG00D0C4a<0820P02BTY80TY:B09VIV@0209NGU`0508^;R`2BTY80
TY:B09FEU@2QXJ400P2SXj<01@2XZ:P0YjNW0:NWY`2YZJT0UIFE0080CDe=00@0EeMG0:>SX`2SXj<0
VIVI0P20P8001@2PX:00XZ:R09nOW`2OWil0Vi^K0080V9RH00D0VYZJ09jNWP2PX:00X:2P0:NWY`02
07UiN@0506QXJ02IVIT0VYZJ09ZJVP2;Rh/00P24Q8@01@2BTY80QXJ608J6QP2>SXh0U9BD0080UIFE
00D0T92@09RHV02HV9P0TI6A05eMG@0207IfMP0409bLW02XZ:P0Z:RX0:FUY@80U9BD00D0TI6A092@
T02CTi<0Ti>C092@T00308^;R`040:2PX02TY:@0Y:BT05mOG`80M7Ad00D0R8R808N7Q`27QhL0Ogmo
08>3P`0208f=S@0508J6QP2=SHd0SHf=08Z:RP29RHT00P23Ph<01@26QXH0NGUi07UiN@16ATH0QHF5
0080P82000@0PH6108R8R028R8P0S8b<0P29RHT01@1dM7@0I6AT06=SH`1SHf<0GemO0080G5aL00D0
:b/[069RHP2:RXX0RXZ:08n?S`0208b<S003096AT@2>SXh0SXj>0080S8b<0P23Ph<01@1oOgl0PX:2
08:2PP1oOgl0MGEe0080>SXj00D0IVIV07]kN`1kNg/0Ng]k07EeM@0207=cL`0407MgM`1bLW80LW9b
071`L080JFUY00D0K6a/06IVIP1WIfL0IfMW03Lg=`020410@00505IFEP1JFUX0Cdm?04m?C`1GEeL0
0`1JFUX305eMG@0405iNGP1RHV80HV9R05eMG@80GemO00<0>c/kooooooooool03oooool0101oOgl0
TI6A096AT@20P80204];B`0508Z:RP2IVIT0VIVI07emO@1kNg/00P29RHT01@1QHF40J6QX06QXJ01g
MgL0FUYJ0080H61P00@0Fe]K06MWI`1WIfL0L71`0P1dM7@01@1QHF40<S8b05ADE01DE5@0Fe]K0080
EeMG00D0O7al04A4A014A4@0S8b<08R8R0020:^[Z`040:RXZ02KVi/0Vi^K06QXJ080IFEU00D0GemO
0<30`02JVYX0VYZJ08Z:RP0206e]K@0504=3@`2<S8`0ZJVY0:VYZ@3<c<`00P2:RXX01@2FUYH0Kfm_
06m_K`2VYZH0XZ:R00<0Rh^;0P1]KFd01@1ZJVX0YjNW0:NWY`2[Zj/0VYZJ0080TY:B00D0Z:RX09NG
U`2GUiL0bLW90<[:bP0208j>SP0409>CT`2FUYH0UYJF0:b/[080UIFE00D0S8b<06i^KP1dM7@0M7Ad
05IFEP0209VIV@0507QhN02?Shl0Shn?0:>SX`34a<@00P1eMGD01@20P800FEUI05UIF@1kNg/0WIfM
0080g=cL00@0F5QH07moO`1oOgl0L71`0P3Rh^801@2IVIT0LG5a07YjNP1jNWX0Fe]K0080IfMW00D0
YJFU0:VYZ@2YZJT0[Zj^06EUI@0208j>SP0409:BTP2EUID0UIFE08j>SP80V9RH00D0VIVI0<c<c01G
EeL0EeMG04=3@`0202`/;00303/k>`1UIFD0EeMG0080EeMG0P1aLG401@1VIVH0FEUI05UIF@1IFET0
JFUY0080H61P00@0R8R802h^;P0^;Rh0GEeM0P25QHD01@2=SHd0KVi^0:JVYP2VYZH0JFUY0080SXj>
00D0X:2P0:6QX@1KFe/0Fe]K05eMG@0206e]K@0407alO01DE5@0E5AD069RHP[ooooo000:ooooo`04
0;Jf]P2a/K40/K6a0:b/[080ZZZZ00@0C4a<08R8R02YZJT0ZJVY0`2_[jl0102a/K40/[:b0;:b/P2f
][H30;Bd]0050:JVYP2SXj<0Xj>S0:b/[02IVIT00P1GEeL0101HF5P0W9bL09bLW02GUiL208V9R@05
09VIV@2@T900RXZ:08Z:RP23Ph<00P2;Rh/01@2CTi<0Vi^K0:6QX@2QXJ40YZJV0080PX:200D0KVi^
0:b/[02VYZH0YZJV0:2PX0020:>SX`0509^KV`2OWil0WinO09nOW`2KVi/00P2QXJ401@2TY:@0VYZJ
09ZJVP2<S8`0FUYJ0080Ogmo00@0^;Rh0;Vi^@2i^KT0^;Rh0P2QXJ420:n_[`80[Jf]00D0YZJV0:NW
Y`2WYjL0YJFU0:RXZ0020:^[Z`0407AdM02WYjL0YjNW0;2`/080[jn_0P2`/;020;Bd]0050;Rh^02f
][H0][Jf0;Vi^@2j^[X00`2n_[h20;Bd]00505iNGP2j^[X0[jn_0:n_[`2ZZZX00P2b/[801@2c/k<0
^KVi0;Vi^@2d];@0/K6a0080YZJV00D0VYZJ0:2PX02PX:00<30`08Z:RP020;2`/0040:b/[02YZJT0
ZJVY0;2`/0<0]KFe00@0[Jf]0:b/[02/[:`0/K6a0P2f][H01@2l_;`0YJFU03Lg=`0g=cL0YZJV0080
/k>c00D0/K6a0;:b/P2e]KD0]KFe0;Jf]P020:b/[0050:f][@2^[Zh0[Zj^0;:b/P2^[Zh00P2ZZZX0
101TI6@0NGUi07UiN@2f][H30;Ng]`040;Zj^P2d];@0];Bd0:RXZ080Y:BT00@0/;2`0:j^[P2b/[80
/[:b0`2a/K400`1RHV;oooooooooo`0?ooooo`0407=cL`2DU9@0U9BD08J6QP80C4a<00D0TI6A0:>S
X`2SXj<0QXJ608>3P`0209BDU005079bLP1TI6@0I6AT071`L01NGUh00P1LG5`0101QHF40Hf=S06=S
H`24Q8@209ZJVP0507moO`0l?3`0KVi^06i^KP1`L7000P1LG5`01@29RHT0Bd];04];B`2PX:00U9BD
0080Zj^[00@0Z:RX09jNWP2NWYh0GUiN0P1TI6@01@1RHV80^k^k09NGU`2GUiL0QhN70080IfMW00D0
@d=307alO02[Zj/0Zj^[0<[:bP02092@T00509JFUP1/K6`0K6a/0:6QX@2`/;000`24Q8@206EUI@05
06][J`2_[jl0[jn_0;bl_02SXj<00P2TY:@01@2ZZZX0UYJF09JFUP37alL0fMWI0080UiNG00@0Shn?
0:JVYP2VYZH0Z:RX0P2WYjL01@2?Shl0Lg=c07IfMP1fMWH0GUiN0080Vi^K00D0O7al09NGU`2GUiL0
Shn?0;6a/@0206m_K`0508N7Q`1NGUh0GUiN06m_K`2ATI400P3Bd]80101>CTh0IfMW06MWI`1KFe/2
0;Jf]P0507emO@1UIFD0M7Ad07AdM01PH6000P1fMWH01@37alL0clo?0<o?c`2l_;`0LG5a0080QXJ6
00@0R8R8096AT@2ATI40PX:20P1lO7`01@25QHD0`L7105ADE01DE5@0@41000809bLW00D0>SXj05YJ
FP1CDe<0De=C05MGE`0207=cL`0506=SH`1YJFT0JFUY05aLG01OGel00P1ADE401023Ph<0>SXj03Xj
>P0j>SX2069RHP0507inOP21PH40][Jf0;Jf]P1mOGd00P23Ph<01@2HV9P0Zj^[04m?C`1?Cdl0G5aL
0080JVYZ00@0Jf][05=CD`1CDe<0Hf=S2_ooool000[ooooo00@0][Jf0;6a/@2a/K40[:b/0P2ZZZX0
101<C4`0R8R80:VYZ@2YZJT30:n_[`040;6a/@2b/[80/[:b0;Jf]P<0];Bd00D0YZJV0:>SX`2SXj<0
[:b/09VIV@0205MGE`0405QHF02LW9`0W9bL09NGU`80RHV900D0VIVI092@T02:RXX0RXZ:08>3P`02
08^;R`0509>CT`2KVi/0XJ6Q0:6QX@2VYZH00P22PX801@1^KVh0[:b/0:JVYP2VYZH0X:2P0080Xj>S
00D0Vi^K09nOW`2OWil0WinO09^KV`020:6QX@050:BTY02JVYX0VYZJ08b<S01JFUX00P1oOgl0102h
^;P0^KVi0;Vi^@2h^;P20:6QX@80[jn_0P2][Jd01@2VYZH0YjNW0:NWY`2UYJD0Z:RX0080Zj^[00@0
M7Ad0:NWY`2WYjL0/;2`0P2_[jl20;2`/080];Bd00D0^;Rh0;Jf]P2f][H0^KVi0;Zj^P030;jn_P80
];Bd00D0GUiN0;Zj^P2_[jl0[jn_0:ZZZP020;:b/P050;>c/`2i^KT0^KVi0;Bd]02a/K400P2VYZH0
1@2JVYX0X:2P0:2PX00`<300RXZ:0080/;2`00@0[:b/0:VYZ@2YZJT0/;2`0`2e]KD0102][Jd0[:b/
0:b/[02a/K420;Jf]P050;bl_02UYJD0=cLg03Lg=`2VYZH00P2c/k<01@2a/K40/[:b0;Fe]@2e]KD0
][Jf0080[:b/00D0[Jf]0:j^[P2^[Zh0/[:b0:j^[P020:ZZZP0406ATI01iNGT0NGUi0;Jf]P<0]kNg
00@0^[Zj0;Bd]02d];@0Z:RX0P2TY:@0102`/;00[Zj^0;:b/P2b/[830;6a/@03069RH_oooooooooo
00oooooo00@0Lg=c09BDU02DU9@0QXJ60P1<C4`01@2ATI40Xj>S0:>SX`26QXH0Ph>30080U9BD00D0
LW9b06ATI01TI6@0L71`05iNGP0205aLG004065QH@1SHf<0Hf=S08B4Q080VYZJ00D0Ogmo03`l?01^
KVh0KVi^071`L00205aLG00508V9R@1;Bd/0Bd];0:2PX02DU9@00P2[Zj/0102XZ:P0WYjN09jNWP1N
GUh206ATI005069RHP2k^k/0UiNG09NGU`27QhL00P1WIfL01@13@d<0O7al0:^[Z`2[Zj/0b/[:0080
T92@00D0UYJF06a/K01/K6`0XJ6Q0;2`/00308B4Q080IFEU00D0Jf][0:n_[`2_[jl0_;bl0:>SX`02
0:BTY0050:ZZZP2FUYH0UYJF0<O7a`3IfMT00P2GUiL0102?Shl0YZJV0:JVYP2XZ:P20:NWY`0508n?
S`1cLg<0MWIf07IfMP1NGUh00P2KVi/01@1lO7`0UiNG09NGU`2?Shl0/K6a0080Kfm_00D0QhN705iN
GP1NGUh0Kfm_096AT@020=;BdP0404i>CP1WIfL0IfMW05]KF`80][Jf00D0OGem06EUI@1dM7@0M7Ad
061PH00207IfMP050<O7a`3?cll0clo?0;bl_01aLG400P26QXH01028R8P0TI6A096AT@22PX8207al
O00508F5Q@31`L40E5AD05ADE010@4000P0W9bL01@0j>SX0FUYJ05=CD`1CDe<0EeMG0080Lg=c00D0
Hf=S06UYJ@1YJFT0G5aL05mOG`02055AD@0408>3P`0j>SX0>SXj03Xj>P80HV9R00D0OWin0861P@2f
][H0][Jf07emO@0208>3P`0509RHV02[Zj/0Cdm?04m?C`1LG5`00P1ZJVX0101[Jf/0De=C05=CD`1S
Hf<:ooooo`002_ooool0102c/k<0[Zj^0:j^[P2/[:`20:VYZ@0503/k>`27QhL0[Zj^0:j^[P2_[jl0
0P2ZZZX00`2][Jd0[Zj^0:j^[P040;Ng]`050:BTY02QXJ40XJ6Q0:JVYP2UYJD00P1XJ6P0101DE5@0
YJFU0:FUY@2QXJ4309NGU`0408b<S023Ph<0Ph>307]kN`80O7al00D0Shn?09jNWP2PX:00X:2P09nO
W`0208:2PP03075aL@2WYjL0YjNW0080YjNW0P2KVi/01@29RHT0W9bL09bLW02QXJ40UIFE0080XZ:R
00D0YJFU09BDU02DU9@0Ph>304a<C00207alO0@0];Bd0P2MWId01@2e]KD0[jn_0:ZZZP2ZZZX0ZJVY
0080YjNW00D0[Zj^0:f][@2[Zj/0Zj^[075aL@0209RHV0050:b/[02a/K40/K6a0:j^[P2`/;000P2g
]kL01@2h^;P0^KVi0;Vi^@2l_;`0`L710080a<C400D0_kno0:RXZ02XZ:P0HV9R0;Ng]`020;2`/0<0
Zj^[00D0[Jf]0;Jf]P2f][H0/[:b0:^[Z`020:>SX`0509nOW`2ATI40TI6A030`<01fMWH00P2][Jd0
102/[:`0[Zj^0:j^[P2_[jl20;>c/`050;:b/P2d];@0[jn_0:n_[`2e]KD00`2k^k/0102NWYh0=CDe
03De=@2VYZH20:RXZ0050:f][@2XZ:P0[Jf]0:f][@2UYJD00P2XZ:P01@2/[:`0/;2`0;2`/02`/;00
Z:RX0080Zj^[00D0Kfm_07IfMP1fMWH0/;2`0:j^[P020;2`/0040;Fe]@2[Zj/0Zj^[09VIV@80WinO
00D0Zj^[0;:b/P2a/K40/K6a0;Bd]0020;6a/@0306YZJ_oooooooooo00oooooo00@0Hf=S08R8R028
R8P0MgMg0P1?Cdl01@2BTY80Vi^K09^KV`24Q8@0RHV90080SHf=00D0I6AT06QXJ01XJ6P0KVi^05IF
EP02055AD@04069RHP1PH600H61P07YjNP80SHf=00D0LG5a03Xj>P1WIfL0IfMW065QH@0205=CD`05
07moO`1LG5`0G5aL08:2PP2EUID00P2d];@0102YZJT0WIfM09fMW@1UIFD206UYJ@0506i^KP36a/H0
]KFe0;Fe]@2HV9P00P1cLg<01@1KFe/0OGem092@T02@T900`/;20080Y:BT00D0SXj>06][J`1[Jf/0
UYJF09nOW`0207]kN`0406e]K@1XJ6P0J6QX06ATI080ZJVY00D0_[jn0:FUY@2RXZ80XZ:R0:n_[`02
09BDU0050<K6aP3@d=00SXj>08j>SP2?Shl00P2^[Zh01@2QXJ40YJFU0:FUY@22PX80Jf][0080KVi^
00@0F5QH09VIV@2IVIT0LW9b0P2BTY801@29RHT0bLW906YZJP1ZJVX0O7al0080EEEE00D0LG5a0;bl
_02j^[X0^[Zj05QHF00207IfMP0506m_K`3Rh^80h^;R09FEU@1ZJVX00P1[Jf/0101OGel0KVi^06i^
KP2d];@20<c<c0050:j^[P1TI6@0VIVI09VIV@2LW9`00P2<S8`01@25QHD0Ng]k07]kN`1dM7@0ZJVY
0080BTY:00D0?3`l02HV9P0V9RH0=CDe04U9B@0204a<C00404Q8B01aLG40LG5a06QXJ080HF5Q00D0
GemO06][J`1VIVH0IVIV07EeM@020451@@0506][J`2ZZZX0ZZZZ09bLW02XZ:P00P35aLD01@2MWId0
V9RH09RHV02ZZZX0`<300080OWin0`1kNg/0101_Kfl0IfMW06MWI`1nOWh:ooooo`002_ooool0102`
/;00ZZZZ0:ZZZP2XZ:P20:ZZZP05055AD@1eMGD0YZJV0:JVYP2XZ:P00P2RXZ801@2QXJ40YZJV0:JV
YP2[Zj/0/;2`0080YjNW00D0XZ:R0:2PX02PX:00VYZJ0:6QX@0206MWI`04059BDP2RXZ80XZ:R09ZJ
VP80UiNG00<0V9RH08N7Q`1mOGd00P1mOGd207YjNP0507]kN`24Q8@0RXZ:08Z:RP2DU9@00P1iNGT0
1@1fMWH0Y:BT0:RXZ02XZ:P0YZJV0080Vi^K00@0UiNG0:BTY02TY:@0ZJVY0`2PX:001@2SXj<0UiNG
09NGU`28R8P0DE5A0080Q8B40`2^[Zh0102/[:`0WinO09nOW`2_[jl30:b/[0050::RXP2QXJ40XJ6Q
0:^[Z`2VYZH00P2UYJD00`1SHf<0RHV908V9R@030:n_[`050:^[Z`2/[:`0Z:RX0:RXZ02OWil00P2l
_;`01@2m_Kd0`l?30<;2`P32`/80`L710080W9bL00D0GEeM0;Fe]@2c/k<0/k>c0;:b/P020:>SX`05
09nOW`2ZZZX0ZZZZ0:^[Z`2YZJT00P2TY:@01@27QhL0O7al07alO00m?Cd0J6QX0080YjNW00@0ZZZZ
0:b/[02/[:`0[jn_0P2d];@01@2b/[80][Jf0;Jf]P2f][H0/k>c0080/;2`00@0[jn_0:b/[00o?cl0
?clo0`2][Jd01@2ZZZX0/[:b0;>c/`2c/k<0[Jf]0080/;2`00D0[Zj^0;Ng]`2g]kL0^k^k0;Rh^002
0;Vi^@0507alO01gMgL0MgMg0:f][@2`/;000P2c/k<0102d];@0[jn_0:n_[`2[Zj/20:NWY`050:ZZ
ZP2d];@0]kNg0;Ng]`2j^[X00P2b/[800`1WIfOoooooooooo`0?ooooo`0405iNGP29RHT0RHV907Yj
NP80DE5A00D0Shn?0::RXP2RXZ80SHf=08V9R@0208f=S@05071`L01YJFT0JFUY07AdM01kNg/00P1=
CDd00`1>CTh0EUIF05IFEP03071`L00506UYJ@11@D40HV9R069RHP1SHf<00P1TI6@01@2:RXX0WIfM
09fMW@2SXj<0TY:B0080];Bd00@0WinO09FEU@2EUID0M7Ad0P1PH6001@1WIfL0`L710:^[Z`2[Zj/0
RHV90080GEeM00D0H61P07IfMP2IVIT0VIVI0;>c/`0209:BTP0508^;R`1`L700L71`09BDU02ATI40
0P1aLG40101CDe<0LW9b079bLP1dM7@209nOW`050:n_[`2CTi<0UIFE09FEU@2`/;000P2GUiL01@2o
_kl0`L7108>3P`23Ph<0RXZ:0080ZJVY00D0V9RH0:n_[`2_[jl0OGem08J6QP0207]kN`04061PH02L
W9`0W9bL075aL@80UYJF00D0QXJ60<_;b`26QXH0QXJ607inOP0205EEE@0507UiN@2HV9P0gMgM0=gM
g@1/K6`00P1^KVh01@1YJFT0hn?S0>?Sh`2CTi<0LW9b0080Lg=c00@0Hf=S07]kN`1kNg/0a/K60P3=
cLd01@2_[jl0M7Ad07]kN`1kNg/0TY:B0080S8b<00D0TY:B0861P@21PH40QXJ60;fm_@0205iNGP05
03/k>`0c<c<0<c<c02d];@1>CTh00P1OGel0101IFET0Lg=c07=cL`2<S8`20861P@05071`L01YJFT0
G5aL05aLG01XJ6P00P0g=cL01@1<C4`0XJ6Q0:6QX@28R8P0Q8B40080^KVi00D0WYjN06EUI@1UIFD0
RXZ:09:BTP0206YZJP040820P02WYjL0YjNW06YZJP80Hf=S00<0N7Qhooooooooool02?ooool000[o
oooo00@0/;2`0:ZZZP2ZZZX0Z:RX0P2ZZZX01@1ADE40MGEe0:JVYP2VYZH0Z:RX0080XZ:R00D0XJ6Q
0:JVYP2VYZH0Zj^[0;2`/0020:NWY`050::RXP2PX:00X:2P09ZJVP2QXJ400P1WIfL0101BDU80XZ:R
0::RXP2JVYX209NGU`0309RHV027QhL0OGem0080OGem0P1jNWX01@1kNg/0Q8B408Z:RP2:RXX0U9BD
0080NGUi00D0MWIf0:BTY02XZ:P0Z:RX0:JVYP0209^KV`0409NGU`2TY:@0Y:BT0:VYZ@<0X:2P00D0
Xj>S09NGU`2GUiL0R8R8055AD@0208B4Q0<0[Zj^00@0[:b/09nOW`2OWil0[jn_0`2/[:`01@2RXZ80
XJ6Q0:6QX@2[Zj/0YZJV0080YJFU00<0Hf=S08V9R@29RHT00`2_[jl01@2[Zj/0[:b/0:RXZ02XZ:P0
WinO0080_;bl00D0_Kfm0<?3``32`/80`/;20<71`@0209bLW00505eMG@2e]KD0/k>c0;>c/`2b/[80
0P2SXj<01@2OWil0ZZZZ0:ZZZP2[Zj/0ZJVY0080Y:BT00D0QhN707alO01lO7`0?Cdm06QXJ0020:NW
Y`040:ZZZP2/[:`0[:b/0:n_[`80];Bd00D0/[:b0;Jf]P2f][H0][Jf0;>c/`020;2`/0040:n_[`2/
[:`0?clo03lo?`<0[Jf]00D0ZZZZ0;:b/P2c/k<0/k>c0:f][@020;2`/0050:j^[P2g]kL0]kNg0;^k
^`2h^;P00P2i^KT01@1lO7`0MgMg07MgM`2][Jd0/;2`0080/k>c00@0];Bd0:n_[`2_[jl0Zj^[0P2W
YjL01@2ZZZX0];Bd0;Ng]`2g]kL0^[Zj0080/[:b00<0IfMWooooooooool03oooool0101NGUh0RHV9
08V9R@1jNWX2055AD@0508n?S`2RXZ80XZ:R08f=S@29RHT00P2=SHd01@1`L700JFUY06UYJ@1dM7@0
Ng]k0080CDe=00<0CTi>05IFEP1FEUH00`1`L7001@1YJFT0@D51069RHP1RHV80Hf=S0080I6AT00D0
RXZ:09fMW@2MWId0Xj>S09:BTP020;Bd]00409nOW`2EUID0UIFE07AdM080H61P00D0IfMW0<71`@2[
Zj/0Zj^[08V9R@0205eMG@05061PH01fMWH0VIVI09VIV@2c/k<00P2BTY801@2;Rh/0L71`071`L02D
U9@0TI6A0080LG5a00@0De=C079bLP1bLW80M7Ad0P2OWil01@2_[jl0Ti>C09FEU@2EUID0/;2`0080
UiNG00D0_kno0<71`@23Ph<0Ph>308Z:RP020:VYZ@0509RHV02_[jl0[jn_07emO@26QXH00P1kNg/0
101PH600W9bL09bLW01aLG4209JFUP0508J6QP3;bl/0QXJ608J6QP1nOWh00P1EEED01@1iNGT0V9RH
0=gMg@3MgMd0K6a/0080KVi^00D0JFUY0>?Sh`3Shn<0Ti>C079bLP0207=cL`0406=SH`1kNg/0Ng]k
0<K6aP80cLg=00D0[jn_07AdM01kNg/0Ng]k09:BTP0208b<S00509:BTP21PH40PH6108J6QP2m_Kd0
0P1NGUh01@0k>c/0<c<c03<c<`0];Bd0CTi>0080GemO00@0FEUI07=cL`1cLg<0S8b<0P21PH401@1`
L700JFUY05aLG01LG5`0J6QX0080=cLg00D0C4a<0:6QX@2QXJ40R8R808B4Q0020;Vi^@0509jNWP1U
IFD0IFEU08Z:RP2BTY800P1ZJVX01020P800YjNW0:NWY`1ZJVX206=SH`0307QhN?oooooooooo00So
oooo000:ooooo`0407EeM@1aLG40LG5a06UYJ@80Hf=S00D0=3@d05aLG01^KVh0KVi^06MWI`0306YZ
JP80Jf][00D0HF5Q06UYJ@1WIfL0IfMW06=SH`0205ADE00504i>CP1<C4`0<30`030`<00d=3@00P1]
KFd01@1eMGD0L71`071`L01`L700I6AT0080FUYJ00D0FEUI05]KF`1KFe/0De=C05YJFP02065QH@05
06QXJ00l?3`0?3`l04i>CP1fMWH00P1`L700101_Kfl0I6AT06ATI01QHF4206IVIP05071`L01OGel0
GUiN05iNGP1QHF400P1DE5@01@1<C4`0<S8b055AD@1ADE40Lg=c0080MGEe00D0LW9b06m_K`1_Kfl0
L71`07YjNP0207EeM@0506YZJP1OGel0GemO05mOG`1FEUH00P1?Cdl0100a<C40AdM704M7A`1EEED2
06EUI@0506i^KP1WIfL0IfMW06MWI`1NGUh00P1iNGT01@23Ph<0RXZ:08J6QP26QXH0Ph>30080BTY:
00D0?clo08R8R022PX80PX:208b<S00207moO`0508N7Q`22PX80PX:20820P027QhL00P1jNWX01@1W
IfL0KVi^06i^KP14A4@0HF5Q0080Shn?00@0VIVI09NGU`2GUiL0XJ6Q0P2NWYh01@2@T900PX:209FE
U@2EUID0T92@0080VYZJ00D0Ti>C0820P00f=SH0=SHf0861P@0209fMW@05092@T02DU9@0U9BD09BD
U02GUiL00P2LW9`01@2PX:00Y:BT0:BTY02XZ:P0Zj^[0080[:b/00D0P82006ATI01TI6@0UIFE0:BT
Y0020:ZZZP040:JVYP2ZZZX0ZZZZ0:FUY@80WIfM00D0XJ6Q0::RXP2TY:@0Y:BT0:ZZZP020:VYZ@03
06ATI?oooooooooo00oooooo00@0G5aL09:BTP2BTY80NWYj0P18B4P01@1kNg/0Shn?08n?S`1gMgL0
RHV90080P82000D0GUiN04U9B@19BDT0J6QX06IVIP0205YJFP0405]KF`1^KVh0KVi^096AT@80UYJF
00D0OGem0492@P1QHF40HF5Q06a/K00205mOG`0509JFUP2WYjL0YjNW0;>c/`2IVIT00P2i^KT0102/
[:`0Ti>C09>CT`1NGUh2059BDP0506a/K02m_Kd0/K6a0;6a/@2ATI400P1YJFT01@1SHf<0MgMg08b<
S02<S8`0Zj^[0080VIVI00D0SXj>06m_K`1_Kfl0WinO08J6QP0207alO00405ADE027QhL0QhN706m_
K`80VIVI00D0XZ:R09>CT`2QXJ40XJ6Q0;Zj^P0208J6QP0509jNWP2o_kl0V9RH09RHV02DU9@00P2a
/K401@2e]KD0`<300<30`020P800SHf=0080PH6100@0JFUY09jNWP2NWYh0RHV90P2][Jd01@21PH40
e=CD08N7Q`27QhL0PX:20080F5QH00D0N7Qh0:>SX`3QhN40hN7Q07=cL`0306ATI080gmoO00D0TI6A
07MgM`1]KFd0KFe]06QXJ002075aL@050;bl_03;bl/0bl_;0:j^[P1fMWH00P2:RXX0102ATI40NWYj
07YjNP1cLg<206a/K00508:2PP2QXJ40I6AT06ATI00i>CT00P0b<S801@0`<300D51@05UIF@1IFET0
CTi>0080JVYZ00D0Q8B407QhN01hN7P0NWYj06i^KP02071`L004061PH01BDU80DU9B03lo?`80TI6A
00D0WinO08b<S02`/;00/;2`0:2PX002065QH@0408R8R02JVYX0PX:208:2PP<0GEeM00@0=cLg05AD
E01DE5@0K6a/2_ooool000[ooooo00@0UiNG09RHV02HV9P0UIFE0P2@T9000`2EUID0T92@08B4Q002
08B4Q080U9BD00D0W9bL0:2PX02PX:00F5QH06QXJ00208n?S`0508f=S@21PH40PH6108:2PP29RHT0
0P2@T900102CTi<0T92@092@T029RHT208>3P`0508B4Q01oOgl0E5AD05ADE00i>CT00P1NGUh01@1P
H600I6AT06][J`1[Jf/0JFUY00<0H61P00@0K6a/06YZJP1ZJVX0KVi^0P1]KFd01@1ZJVX0ATI604I6
AP1OGel0IVIV0080K6a/00D0IVIV06i^KP1^KVh0Lg=c07inOP0207IfMP0407YjNP1fMWH0MWIf06][
J`80LG5a00<0HV9R04I6AP1_Kfl00P1_Kfl206UYJ@0506YZJP1WIfL0Jf][06][J`1dM7@00P1gMgL0
1@1/K6`0MWIf07IfMP1hN7P0MWIf0080Bd];00D0>CTi06EUI@1UIFD0L71`06][J`0206EUI@0506][
J`1_Kfl0Kfm_07MgM`1/K6`00P1^KVh0101aLG40Kfm_06m_K`1WIfL205ADE00506a/K01]KFd0JVYZ
06YZJP1bLW800`1hN7P0101dM7@0L71`071`L01/K6`206QXJ005069RHP1OGel0GemO03Ti>@0T92@0
0P0a<C401@0l?3`0?Cdm03dm?@1:BTX0AdM70080DE5A00D0DU9B05MGE`1GEeL0Bd];04m?C`0204M7
A`0403lo?`0j>SX0>SXj05mOG`80HF5Q00D0HV9R061PH01NGUh0GUiN06ATI00206=SH`0505QHF01O
Gel0G5aL05aLG01FEUH00P1@D5001@0e=CD0@d=304=3@`1QHF40GEeM0080HV9R00@0Fe]K061PH01P
H600Fe]K4Oooool0101PH600VIVI09VIV@1cLg<204A4A00507alO021PH40PH6107EeM@1mOGd00P1n
OWh01@1iNGT0EEEE05EEE@1`L700H61P0080BDU900@0E5AD06IVIP1VIVH0RHV90P28R8P01@1jNWX0
@D5106MWI`1WIfL0Fe]K0080HV9R00D0RXZ:09NGU`2GUiL0[:b/09VIV@020;Zj^P040:FUY@2HV9P0
V9RH07AdM080E5AD00D0M7Ad0<30`031`L40`L7109JFUP0206QXJ00506e]K@25QHD0V9RH09RHV03>
c/h00P2][Jd01@2KVi/0PH610861P@2i^KT0RHV90080OGem00@0HF5Q09:BTP2BTY80P8200P2JVYX0
1@2a/K40/;2`0;Fe]@2e]KD0bl_;0080SXj>00D0YZJV0;Jf]P2DU9@0U9BD08>3P`020:^[Z`050:b/
[032`/80`/;207IfMP28R8P00P24Q8@0101gMgL0U9BD09BDU023Ph<209RHV00506i^KP3Lg=`0OWin
07inOP1]KFd00P1SHf<01@29RHT0WinO0=[JfP3Jf]X0IFEU0080DE5A00D0J6QX0>3Ph03Ph>00V9RH
07IfMP0207YjNP0407emO@1jNWX0NWYj0<c<c080emOG00D0^k^k092@T02LW9`0W9bL0:FUY@0208n?
S`0509ZJVP22PX80PX:209jNWP39bLT00P1kNg/01@0j>SX0=3@d03@d=00_;bl0C4a<0080FEUI00@0
EeMG07IfMP1fMWH0MGEe0P1iNGT01@1WIfL0IFEU06i^KP1^KVh0Bd];0080Fe]K00D0EUIF08^;R`2;
Rh/0UiNG08R8R0020;^k^`050:FUY@1UIFD0IFEU08N7Q`2HV9P00P28R8P0101ZJVX0Hf=S06=SH`1<
C4`206][J`0308J6Q_oooooooooo00Sooooo000:ooooo`040;jn_P2i^KT0^KVi0;Fe]@80][Jf00D0
^;Rh0;:b/P2a/K40/K6a0:f][@020:j^[P050;2`/02d];@0];Bd065QH@1kNg/00P2YZJT0102TY:@0
WYjN09jNWP2FUYH309jNWP040:JVYP2RXZ80XZ:R0:6QX@80Y:BT00D0YjNW0:>SX`1SHf<0Hf=S055A
D@0208b<S00508V9R@2DU9@0UiNG09NGU`2JVYX00`2ZZZX0102][Jd0ZJVY0:VYZ@2ZZZX20:VYZ@05
0;6a/@1RHV80HV9R08J6QP2^[Zh00P2g]kL01@2h^;P0[Zj^0:j^[P2/[:`0[Jf]00<0[Zj^0P2/[:`0
1@2`/;00[:b/0:b/[02TY:@0JFUY0080ZZZZ00D0Xj>S09RHV02HV9P0Ti>C092@T00209nOW`040:FU
Y@2TY:@0Y:BT0:FUY@80ZJVY0P2VYZH2079bLP04061PH02ZZZX0ZZZZ0;2`/0<0/k>c00D0/K6a0;Rh
^02h^;P0]kNg0;Vi^@020;Jf]P040;Vi^@2c/k<0/k>c0:^[Z`80Ph>300D0YjNW0;6a/@2g]kL0]kNg
0;Jf]P020;>c/`050;Bd]02^[Zh0[Zj^0:j^[P2g]kL00P2i^KT01@2g]kL0^;Rh0;Rh^01`L700IVIV
0080Ogmo00D0P8200:2PX02PX:00XZ:R096AT@0207MgM`0505YJFP1jNWX0NWYj08B4Q025QHD00P23
Ph<0101OGel0CDe=04e=C@2UYJD20:b/[0050:j^[P2d];@0^KVi0;Vi^@2f][H00P2ZZZX01@2g]kL0
^KVi0;no_`2o_kl0^k^k0080^KVi00D0@d=309:BTP2BTY80ZZZZ0:VYZ@020;:b/P040;Ng]`2e]KD0
]KFe0;6a/A7ooooo00@0GEeM07emO@1mOGd0Kfm_0P15ADD01@26QXH0W9bL09bLW025QHD0R8R80080
T92@00D0NWYj05EEE@1EEED0O7al07=cL`0205=CD`0404I6AP1ZJVX0JVYZ08N7Q`80IfMW00D0F5QH
03Xj>P1NGUh0GUiN06e]K@02065QH@0508:2PP2:RXX0RXZ:0:6QX@22PX800P2b/[80102QXJ40Vi^K
09^KV`1cLg<204U9B@0507YjNP3=cLd0a<C40<C4a02:RXX00P1QHF401@1/K6`0PX:209VIV@2IVIT0
`l?30080[:b/00D0VYZJ075aL@1aLG40][Jf08J6QP0208N7Q`0406i^KP2EUID0UIFE07UiN@80X:2P
00D0/[:b0<C4a02g]kL0]kNg0<C4a00208j>SP050:VYZ@3<c<`0YJFU0:FUY@2CTi<00P2d];@01@2Z
ZZX0aLG50<G5a@1PH600OGem0080QHF500@0QhN70:JVYP2VYZH0Shn?0P2@T9001@1/K6`0fMWI08B4
Q024Q8@0I6AT0080HF5Q00D0NWYj0:6QX@3De=@0e=CD05eMG@0205=CD`0505QHF037alL0alO709:B
TP1]KFd00P1hN7P0101lO7`0MWIf07IfMP33`l<20<_;b`030::RXP1lO7`0Z:RX0080Z:RX0P2ATI40
1@2GUiL0R8R808R8R02TY:@0aLG50080M7Ad00D0>CTi03`l?00l?3`0<C4a055AD@0205ADE00405YJ
FP1eMGD0MGEe06EUI@80Lg=c00D0IfMW05QHF01@D500D51@04];B`0205iNGP0504a<C01OGel0GemO
09RHV01iNGT00P2EUID01@26QXH0M7Ad07AdM01iNGT0Q8B40080V9RH0`1`L700101MGEd0LG5a075a
L@2:RXX:ooooo`002_ooool0102n_[h0^KVi0;Vi^@2e]KD20;Jf]P050;Rh^02b/[80/K6a0;6a/@2]
[Jd00P2^[Zh01@2`/;00];Bd0;Bd]01QHF40Ng]k0080ZJVY00@0Y:BT09jNWP2NWYh0UYJF0`2NWYh0
102VYZH0XZ:R0::RXP2QXJ420:BTY0050:NWY`2SXj<0Hf=S06=SH`1ADE400P2<S8`01@29RHT0U9BD
09NGU`2GUiL0VYZJ00<0ZZZZ00@0[Jf]0:VYZ@2YZJT0ZZZZ0P2YZJT01@2a/K40HV9R069RHP26QXH0
[Zj^0080]kNg00D0^;Rh0:j^[P2^[Zh0[:b/0:f][@030:j^[P80[:b/00D0/;2`0:b/[02/[:`0Y:BT
06UYJ@020:ZZZP050:>SX`2HV9P0V9RH09>CT`2@T9000P2OWil0102UYJD0Y:BT0:BTY02UYJD20:VY
Z@80YZJV0P1bLW80101PH600ZZZZ0:ZZZP2`/;030;>c/`050;6a/@2h^;P0^;Rh0;Ng]`2i^KT00P2f
][H0102i^KT0/k>c0;>c/`2[Zj/208>3P`050:NWY`2a/K40]kNg0;Ng]`2f][H00P2c/k<01@2d];@0
[Zj^0:j^[P2^[Zh0]kNg0080^KVi00D0]kNg0;Rh^02h^;P0L71`06IVIP0207moO`050820P02PX:00
X:2P0::RXP2ATI400P1gMgL01@1JFUX0NWYj07YjNP24Q8@0QHF50080Ph>300@0GemO04e=C@1=CDd0
YJFU0P2/[:`01@2^[Zh0];Bd0;Vi^@2i^KT0][Jf0080ZZZZ00D0]kNg0;Vi^@2o_kl0_kno0;^k^`02
0;Vi^@0504=3@`2BTY80TY:B0:ZZZP2YZJT00P2b/[80102g]kL0]KFe0;Fe]@2a/K4Aooooo`0405eM
G@1mOGd0OGem06m_K`80ADE500D0QXJ609bLW02LW9`0QHF508R8R002092@T00507YjNP1EEED0EEEE
07alO01cLg<00P1CDe<01016ATH0JVYZ06YZJP27QhL206MWI`0505QHF00j>SX0GUiN05iNGP1]KFd0
0P1QHF401@22PX80RXZ:08Z:RP2QXJ40PX:20080/[:b00@0XJ6Q09^KV`2KVi/0Lg=c0P19BDT01@1j
NWX0cLg=0<C4a034a<@0RXZ:0080HF5Q00D0K6a/08:2PP2IVIT0VIVI0<?3``020:b/[00509ZJVP1a
LG40LG5a0;Jf]P26QXH00P27QhL0101^KVh0UIFE09FEU@1iNGT20:2PX0050;:b/P34a<@0]kNg0;Ng
]`34a<@00P2>SXh01@2YZJT0c<c<0:FUY@2UYJD0Ti>C0080];Bd00D0ZZZZ0<G5a@35aLD0H61P07em
O@0208F5Q@0408N7Q`2VYZH0YZJV08n?S`80T92@00D0K6a/0=WIf@24Q8@0Q8B406ATI002065QH@05
07YjNP2QXJ40e=CD0=CDe01MGEd00P1CDe<01@1HF5P0alO70<O7a`2BTY80KFe]0080N7Qh00@0O7al
07IfMP1fMWH0`l?30P3;bl/00`2RXZ80O7al0:RXZ0020:RXZ080TI6A00D0UiNG08R8R028R8P0Y:BT
0<G5a@0207AdM00503Ti>@0l?3`0?3`l034a<@1ADE400P1DE5@0101JFUX0MGEe07EeM@1UIFD207=c
L`0506MWI`1HF5P0D51@051@D01;Bd/00P1NGUh01@1<C4`0GemO05mOG`2HV9P0NGUi0080UIFE00D0
QXJ607AdM01dM7@0NGUi08B4Q00209RHV0<0L71`00@0GEeM075aL@1aLG40RXZ:2_ooool000[ooooo
00<0_[jn0;Zj^P2j^[X00`2`/;001@2f][H0[jn_0:n_[`2_[jl0[:b/0080[jn_00D0[Jf]0;6a/@2a
/K40KFe]08F5Q@020:b/[0050:6QX@2KVi/0Vi^K09FEU@2KVi/00P2IVIT0102MWId0X:2P0:2PX02S
Xj<20:FUY@050:JVYP2JVYX0H61P061PH01@D5000P2=SHd01@2BTY80Shn?09VIV@2IVIT0UIFE0080
XZ:R00D0Xj>S0:ZZZP2XZ:P0Z:RX0:>SX`0209nOW`050:FUY@1/K6`0K6a/08>3P`2/[:`00P2][Jd0
1@2`/;00XZ:R0::RXP2PX:00Zj^[0080[Jf]00@0[:b/0:VYZ@2YZJT0Z:RX0P2YZJT01@2MWId0EUIF
0:NWY`2WYjL0Xj>S0080V9RH00D0QXJ608j>SP2TY:@0Y:BT0:JVYP0209^KV`050:>SX`2XZ:P0Z:RX
0:ZZZP2WYjL00P1^KVh01@1YJFT0Zj^[0:^[Z`2_[jl0];Bd0080[jn_00D0[Zj^0;2`/02`/;00/k>c
0;Fe]@020;^k^`040;fm_@2h^;P0^;Rh0:BTY080QXJ600D0X:2P0:j^[P2d];@0];Bd0;6a/@030:n_
[`040:JVYP2/[:`0[:b/0:n_[`80]KFe00D0^;Rh0;>c/`2c/k<0IfMW09BDU0020:ZZZP05092@T02Q
XJ40XJ6Q09JFUP2IVIT00P26QXH01@1FEUH0UYJF09JFUP2WYjL0ZZZZ0080[:b/00@0MgMg05aLG01L
G5`0[:b/0P2UYJD01@2WYjL0[:b/0;:b/P2b/[80[Zj^0080Shn?00D0WYjN0;Rh^02k^k/0^k^k0;Jf
]P020;Vi^@0505aLG02CTi<0Ti>C0:f][@2`/;000P2a/K40102e]KD0/K6a0;6a/@2][JdAooooo`04
06e]K@2@T900T92@07alO080Bd];00D0SHf=08j>SP2>SXh0QHF508V9R@0209^KV`0506YZJP18B4P0
B4Q806][J`1jNWX00P1RHV801014A4@0L71`071`L02:RXX208:2PP0507=cL`11@D40De=C05=CD`1[
Jf/00P1aLG401@26QXH0Y:BT0:BTY02NWYh0QhN70080/;2`00@0W9bL09:BTP2BTY80KFe]0P1;Bd/0
1@1gMgL0a/K60;Vi^@2i^KT0PX:20080HV9R00D0IFEU07moO`2NWYh0WYjN0<G5a@020:f][@0509jN
WP1/K6`0K6a/0:b/[01kNg/00P21PH40101bLW80WYjN09jNWP1bLW8208Z:RP050:FUY@2l_;`0XJ6Q
0:6QX@2WYjL00P21PH401@2LW9`0_[jn0;6a/@2a/K40[:b/0080^;Rh00D0_;bl0<[:bP3:b/X0EeMG
08N7Q`0209JFUP0408Z:RP2<S8`0S8b<08:2PP80QXJ600D0LW9b0=gMg@1kNg/0Ng]k06=SH`0207=c
L`0508N7Q`2/[:`0g=cL0=cLg01QHF400P18B4P01@1TI6@0emOG0=OGe`26QXH0GEeM0080M7Ad00@0
Kfm_07UiN@1iNGT0_Kfm0P37alL01@2QXJ40K6a/08V9R@29RHT0X:2P0080OWin00D0SHf=08N7Q`27
QhL0V9RH0<;2`P0207UiN@0503/k>`0m?Cd0?Cdm03Hf=P1:BTX00P1QHF40101UIFD0P8200820P01/
K6`207MgM`05071`L01eMGD0FUYJ05YJFP1QHF400P1ZJVX01@1KFe/0IVIV06IVIP2LW9`0NWYj0080
V9RH00D0Lg=c06=SH`1SHf<0LG5a08n?S`0209:BTP0406IVIP1XJ6P0J6QX071`L080K6a/00<0RXZ:
ooooooooool02?ooool000[ooooo00@0/k>c0;2`/02`/;00[:b/0P2XZ:P01@2YZJT0[:b/0:^[Z`2[
Zj/0[:b/0080[Jf]00D0[Zj^0:f][@2][Jd0N7Qh08B4Q0020::RXP0509BDU01bLW80LW9b071`L01o
Ogl00P2GUiL0102PX:00Ti>C09>CT`2QXJ420:>SX`0509nOW`2@T900EEEE05EEE@1>CTh00P1oOgl0
1@21PH40SHf=096AT@2ATI40QXJ60080RXZ:00D0RHV909fMW@2PX:00X:2P09^KV`0209fMW@050::R
XP1UIFD0IFEU07moO`2ATI400P2TY:@01@2/[:`0XZ:R0::RXP2FUYH0V9RH0080YJFU00@0Y:BT0:NW
Y`2WYjL0YZJV0P2UYJD01@2HV9P0GUiN0:2PX02PX:00TY:B0080Ti>C00D0R8R808F5Q@2PX:00X:2P
0:>SX`020::RXP030:FUY@2VYZH0YZJV0080Zj^[0P1fMWH01@22PX80YZJV0:JVYP2YZJT0[:b/0080
YZJV00<0Z:RX0::RXP2RXZ800P2_[jl30;Fe]@80/K6a00D0YJFU08N7Q`27QhL0VIVI0;:b/P020:n_
[`<0[Zj^00D0ZJVY0:2PX02WYjL0YjNW0:RXZ0020:b/[0050;2`/02XZ:P0Z:RX061PH02;Rh/00P2N
WYh01@2?Shl0WIfM09fMW@2;Rh/0SHf=0080SXj>00D0FEUI09BDU02DU9@0WIfM0:NWY`020:ZZZP04
07YjNP1IFET0FEUI0:ZZZP80WIfM00D0Zj^[0:RXZ02_[jl0[jn_0:RXZ00209^KV`050;6a/@2i^KT0
^[Zj0;Zj^P2h^;P00P2i^KT0101_Kfl0Vi^K09^KV`2XZ:P30:n_[`<0[Zj^00<0Zj^[ooooooooool0
3oooool0101`L700SHf=08f=S@1mOGd204U9B@05096AT@2b/[80/[:b09fMW@2EUID00P2GUiL01@1X
J6P0C4a<04a<C01bLW80IfMW0080GEeM00@0BTY:06a/K01/K6`0NWYj0P25QHD01@1aLG40AdM705eM
G@1MGEd0Kfm_0080GUiN00D0M7Ad092@T02@T900ZJVY096AT@020;Ng]`040:6QX@2<S8`0S8b<06e]
K@80EeMG00D0Ng]k0<k>cP2o_kl0_kno08F5Q@02065QH@0507UiN@2LW9`0/;2`0;2`/03Hf=P00P30
`<001@2[Zj/0MGEe07EeM@2`/;00LW9b0080Ph>300@0NWYj09^KV`2KVi/0K6a/0P1mOGd01@2PX:00
]KFe08^;R`2;Rh/0Shn?00<0QXJ600@0Zj^[0:>SX`2SXj<0Y:BT0P2XZ:P01@2`/;00]kNg0;Ng]`1F
EUH0SXj>0080Rh^;00@0QhN708B4Q024Q8@0NGUi0P22PX801@1[Jf/0fm_K07]kN`1kNg/0GEeM0080
NGUi00D0U9BD0:^[Z`3Lg=`0g=cL0820P00205MGE`0506e]K@3Vi^H0i^KV09ZJVP1XJ6P00P21PH40
101^KVh0Ph>308>3P`35aLD20=3@d0050;Zj^P1jNWX0SXj>08j>SP2XZ:P00P2=SHd01@2>SXh0S8b<
08b<S02SXj<0`l?30080P82000D0@d=304M7A`17AdL0?clo05EEE@0206QXJ00407inOP28R8P0R8R8
07UiN@80Ph>300D0LG5a08:2PP1PH600H61P06ATI00207IfMP05069RHP1CDe<0De=C07emO@2ATI40
0P2ZZZX01@24Q8@0Kfm_06m_K`2@T900P8200080TI6A00@0LG5a06e]K@1]KFd0LW9b0P21PH400`28
R8Soooooooooo`08ooooo`002_ooool0102c/k<0/;2`0;2`/02/[:`20:RXZ0050:VYZ@2/[:`0Zj^[
0:^[Z`2/[:`00P2][Jd01@2^[Zh0[Jf]0:f][@1hN7P0Q8B40080XZ:R00D0U9BD079bLP1bLW80L71`
07moO`0209NGU`040:2PX02CTi<0Ti>C0:6QX@80Xj>S00D0WinO092@T01EEED0EEEE04i>CP0207mo
O`050861P@2=SHd0TI6A096AT@26QXH00P2:RXX01@29RHT0WIfM0:2PX02PX:00Vi^K0080WIfM00D0
XZ:R06EUI@1UIFD0Ogmo096AT@020:BTY0050:b/[02RXZ80XZ:R09JFUP2HV9P00P2UYJD0102TY:@0
YjNW0:NWY`2VYZH20:FUY@0509RHV01NGUh0X:2P0:2PX02BTY800P2CTi<01@28R8P0QHF50:2PX02P
X:00Xj>S0080XZ:R00<0YJFU0:JVYP2VYZH00P2[Zj/207IfMP0508:2PP2VYZH0YZJV0:VYZ@2/[:`0
0P2VYZH00`2XZ:P0XZ:R0::RXP020:n_[`<0]KFe0P2a/K401@2UYJD0QhN708N7Q`2IVIT0/[:b0080
[jn_0`2^[Zh01@2YZJT0X:2P0:NWY`2WYjL0Z:RX0080[:b/00D0/;2`0:RXZ02XZ:P0H61P08^;R`02
09jNWP0508n?S`2MWId0WIfM08^;R`2=SHd00P2>SXh01@1IFET0U9BD09BDU02MWId0YjNW0080ZZZZ
00@0NWYj05UIF@1IFET0ZZZZ0P2MWId01@2[Zj/0Z:RX0:n_[`2_[jl0Z:RX0080Vi^K00D0/K6a0;Vi
^@2j^[X0^[Zj0;Rh^0020;Vi^@0406m_K`2KVi/0Vi^K0:RXZ0<0[jn_0`2^[Zh00`2[Zj_ooooooooo
o`0?ooooo`04071`L02=SHd0SHf=07emO@80BDU900D0TI6A0;:b/P2b/[80WIfM09FEU@0209NGU`05
06QXJ01<C4`0C4a<079bLP1WIfL00P1MGEd0101:BTX0K6a/06a/K01jNWX208F5Q@05075aL@17AdL0
GEeM05eMG@1_Kfl00P1NGUh01@1dM7@0T92@092@T02YZJT0TI6A0080]kNg00@0XJ6Q08b<S02<S8`0
KFe]0P1GEeL01@1kNg/0c/k>0;no_`2o_kl0QHF50080HF5Q00D0NGUi09bLW02`/;00/;2`0=SHf002
0<30`0050:^[Z`1eMGD0MGEe0;2`/01bLW800P23Ph<0101jNWX0Vi^K09^KV`1/K6`207emO@050:2P
X02e]KD0Rh^;08^;R`2?Shl00`26QXH0102[Zj/0Xj>S0:>SX`2TY:@20:RXZ0050;2`/02g]kL0]kNg
05IFEP2>SXh00P2;Rh/01027QhL0Q8B408B4Q01iNGT208:2PP0506][J`3Kfm/0Ng]k07]kN`1MGEd0
0P1iNGT01@2DU9@0Zj^[0=cLg03Lg=`0P8200080EeMG00D0KFe]0>KViP3Vi^H0VYZJ06QXJ0020861
P@0406i^KP23Ph<0Ph>30<G5a@80d=3@00D0^[Zj07YjNP2>SXh0SXj>0:RXZ00208f=S@0508j>SP2<
S8`0S8b<0:>SX`33`l<00P20P8001@13@d<0AdM704M7A`0o?cl0EEEE0080J6QX00@0OWin08R8R028
R8P0NGUi0P23Ph<01@1aLG40PX:2061PH01PH600I6AT0080MWIf00D0HV9R05=CD`1CDe<0OGem096A
T@020:ZZZP0508B4Q01_Kfl0Kfm_092@T020P8000P2ATI40101aLG40KFe]06e]K@1bLW820861P@03
08R8R?oooooooooo00Sooooo000:ooooo`0408J6QP1gMgL0MgMg079bLP80MGEe0P1`L70206e]K@04
06MWI`1[Jf/0Jf][06QXJ080JVYZ00D0>3Ph061PH01mOGd0OGem08:2PP0207YjNP0504];B`1MGEd0
GUiN05iNGP1_Kfl00P1eMGD01@1]KFd0LG5a075aL@21PH40N7Qh0080?Shn00D0EUIF079bLP1bLW80
LW9b07EeM@0207=cL`0506MWI`1JFUX0FUYJ04m?C`1RHV800P1fMWH3075aL@0506][J`16ATH0ATI6
06e]K@1gMgL00P29RHT01@20P800LG5a075aL@1NGUh0E5AD0080Kfm_00@0NGUi07IfMP1fMWH0Lg=c
0P1gMgL01@1jNWX0CDe=06e]K@1]KFd0JVYZ0080M7Ad00@0KVi^06EUI@1ZJVX0JVYZ0`1OGel01@1[
Jf/0KVi^06i^KP1_Kfl0I6AT0080E5AD00D0JFUY06MWI`1WIfL0JVYZ07YjNP0207emO@0507=cL`2:
RXX0RXZ:08Z:RP29RHT00P2?Shl01022PX80Ogmo07moO`24Q8@2079bLP0506IVIP2<S8`0SHf=08f=
S@2?Shl00P2CTi<209BDU080W9bL0`2@T9001@2FUYH0QXJ608J6QP1IFET0QHF50080PX:200D0P820
07moO`1oOgl0Kfm_07UiN@0206][J`0304];B`1oOgl0Ogmo0080TI6A0P2PX:00101[Jf/0IVIV06IV
IP1kNg/207alO00509fMW@2LW9`0W9bL09bLW02BTY800P1lO7`01@2XZ:P0Y:BT09FEU@2EUID0QhN7
0080LG5a00D0EUIF06EUI@1UIFD0V9RH0:^[Z`020:FUY@040:>SX`2ZZZX0ZZZZ0;6a/A7ooooo00@0
LW9b096AT@2ATI40Ogmo0P1BDU801024Q8@0WinO09nOW`2;Rh/3096AT@0507MgM`1>CTh0CTi>07em
O@1kNg/00P1BDU801010@400GEeM05eMG@1_Kfl206e]K@0505mOG`1ADE40Hf=S06=SH`1YJFT00P1M
GEd01@1XJ6P0Ogmo07moO`2>SXh0QHF50080Y:BT00@0Ti>C06m_K`1_Kfl0G5aL0P18B4P01@1SHf<0
/k>c0:BTY02TY:@0KFe]0080EUIF00D0Kfm_09BDU02][Jd0[Jf]0=OGe`020;jn_P050:FUY@1dM7@0
M7Ad0;6a/@1gMgL00P2:RXX01021PH40SXj>08j>SP1OGel208f=S@050:ZZZP2g]kL0Ph>308>3P`2Q
XJ400P2FUYH01@2GUiL0_kno0:NWY`2WYjL0/K6a0080YJFU00D0^k^k0;Fe]@2e]KD0GemO08j>SP02
08B4Q00409^KV`21PH40PH6109jNWP80Ng]k00D0KFe]0=_Kf`2<S8`0S8b<05]KF`0207]kN`0509:B
TP2LW9`0gmoO0=oOg`2<S8`00P1FEUH01@1/K6`0i>CT0>CTi02RXZ80K6a/0080QXJ600@0JVYZ0820
P020P800`<300P32`/801@2QXJ40Kfm_08F5Q@25QHD0XZ:R0080S8b<00D0SXj>09NGU`2GUiL0ZZZZ
0<?3``0208F5Q@05059BDP16ATH0ATI604I6AP1?Cdl00P1QHF40102<S8`0QHF508F5Q@1jNWX207Mg
M`0506a/K02<S8`0IVIV06IVIP1UIFD00P1lO7`01@1WIfL0KVi^06i^KP22PX80RXZ:0080UiNG00<0
Ph>307alO01lO7`00P2FUYH207moO`0406MWI`1/K6`0K6a/09:BTP80S8b<00<0YZJVooooooooool0
2?ooool000[ooooo00@0OWin06m_K`1_Kfl0Hf=S0P16ATH01@0`<300LG5a07=cL`1cLg<0MGEe0080
NGUi00D0PX:208V9R@29RHT0RHV908B4Q00207QhN005071`L01kNg/0Ng]k07MgM`1EEED00P0^;Rh0
101MGEd0IfMW06MWI`1UIFD205mOG`80F5QH0P1FEUH0101GEeL0E5AD05ADE01?Cdl3051@D00503<c
<`0N7Qh07QhN05ADE01]KFd00`1UIFD2065QH@05069RHP1SHf<0Hf=S06ATI01LG5`00P1TI6@01@1P
H600GEeM05eMG@18B4P0<S8b0080GEeM00@0HV9R05mOG`1OGel0IFEU0P1QHF401@1PH600GUiN05]K
F`1KFe/0H61P0080GUiN00D0EUIF051@D00c<c<0<c<c02PX:00203dm?@0504I6AP12@T80@T9204A4
A01JFUX00P1OGel305aLG00505mOG`1QHF40HF5Q065QH@1IFET00P0j>SX01@17AdL0Hf=S06YZJP1Z
JVX0IVIV0080GemO00D0LW9b071`L01`L700KFe]07EeM@0207=cL`0507EeM@1jNWX0NWYj075aL@0d
=3@00P1?Cdl0101NGUh0G5aL05aLG01:BTX205YJFP80EeMG0P1CDe<01@1EEED0ATI604I6AP0j>SX0
8R8R00807AdM00D09bLW02HV9P0V9RH0>SXj04I6AP0205QHF00405eMG@1RHV80HV9R06IVIP80KFe]
00D0K6a/065QH@1@D500D51@03Lg=`0202DU9@0504Y:BP0o?cl0@D510451@@0n?Sh00P10@4001@18
B4P0DU9B059BDP1XJ6P0Lg=c0080MGEe00@0Ogmo07IfMP1fMWH0Hf=S4Oooool0101hN7P0YZJV0:JV
YP1nOWh205iNGP050861P@2VYZH0YZJV09>CT`2FUYH00P22PX801@1TI6@0BTY:04Y:BP1]KFd0Kfm_
0080GEeM00@0@d=305eMG@1MGEd0PH610P1aLG401@1cLg<0F5QH05eMG@1MGEd0JFUY0080HV9R00D0
N7Qh08f=S@2=SHd0XZ:R09>CT`020:f][@040:BTY022PX80PX:2069RHP80?Shn00D0H61P0;jn_P2j
^[X0^[Zj079bLP0205]KF`05079bLP22PX80W9bL09bLW032`/800P2/[:`01@2>SXh0HV9R069RHP2K
Vi/0I6AT0080Ng]k0`1jNWX01@1JFUX0PX:208:2PP2TY:@0^[Zj0080S8b<0`2IVIT01@2QXJ40/K6a
0:ZZZP2ZZZX0_[jn0080TY:B00D0_kno0;:b/P2b/[80IfMW0:FUY@0208Z:RP040::RXP1kNg/0Ng]k
09jNWP80R8R800D0KFe]0=_Kf`2KVi/0Vi^K05mOG`0208j>SP050:JVYP2>SXh0e=CD0=CDe01oOgl0
0P1?Cdl01@1JFUX0fm_K0=_Kf`2IVIT0IFEU0080OGem00@0JVYZ07]kN`1kNg/0_[jn0P38b<P01@2[
Zj/0K6a/08Z:RP2:RXX0YJFU0080RHV900D0S8b<09RHV02HV9P0Y:BT0<?3``0208J6QP0504A4A011
@D40@D5104e=C@1:BTX00P1BDU80101nOWh0SXj>08j>SP1`L70206a/K00506YZJP2:RXX0IfMW06MW
I`1[Jf/00P1QHF401@1ADE40Vi^K09^KV`2OWil0Vi^K0080TI6A00D0LG5a06a/K01/K6`0Vi^K09>C
T`0206e]K@0405IFEP1HF5P0F5QH07inOP80Ph>300<0XJ6Qooooooooool02?ooool000[ooooo00@0
Y:BT08N7Q`27QhL0Lg=c0P1dM7@01@0n?Sh0Z:RX0:VYZ@2YZJT0[jn_0080ZZZZ00D0Zj^[0:JVYP2V
YZH0[Jf]0:RXZ0020:ZZZP0509nOW`2WYjL0YjNW0:6QX@1oOgl00P1IFET0102][Jd0Zj^[0:^[Z`2X
Z:P20:ZZZP050:NWY`2[Zj/0Y:BT0:BTY02HV9P00P2?Shl01@2NWYh0Xj>S0:6QX@2QXJ40K6a/0080
?Cdm00D0[Zj^0:^[Z`2YZJT0ZJVY0:>SX`0209nOW`050:>SX`2PX:00X:2P0::RXP2VYZH00P2RXZ80
1@2BTY80SHf=08f=S@1nOWh0?3`l0080R8R800@0XJ6Q0:^[Z`2[Zj/0[jn_0P2d];@20;Fe]@80/k>c
00D0]kNg0;:b/P2b/[80YZJV0:j^[P02065QH@0404E5A@1cLg<0Lg=c07]kN`<0NGUi00@0Ti>C09RH
V02HV9P0Shn?0P21PH4209:BTP80R8R800D0RXZ:05YJFP1JFUX0UIFE0;2`/0020;>c/`040;Fe]@2d
];@0];Bd0;2`/0<0][Jf00@0^KVi0;Fe]@2e]KD0/;2`0`2^[Zh0100a<C40Shn?08n?S`2_[jl20;>c
/`050<71`@2f][H0][Jf0;jn_P2g]kL00P2h^;P01@2n_[h0`L710<71`@2j^[X0Zj^[0080<30`00D0
@d=308J6QP26QXH0Zj^[0:n_[`020;Bd]0040;^k^`2l_;`0_;bl0;^k^`80];Bd00D0/;2`0;6a/@2Y
ZJT0ZJVY09fMW@0207AdM080/[:b0`2TY:@20;Jf]P050;Ng]`2h^;P0^;Rh0;bl_030`<000P35aLD0
103Bd]80d=3@0=3@d01fMWHAooooo`0406e]K@2@T900T92@07IfMP80HV9R00D0PH6109^KV`2KVi/0
Shn?08f=S@0207]kN`0506][J`1EEED0EEEE07YjNP1`L7000P1GEeL0101CDe<0K6a/06a/K02CTi<2
0820P005079bLP1@D500DE5A055AD@1ZJVX00P1WIfL01@1iNGT0Q8B408B4Q02a/K40WinO0080Xj>S
00@0TI6A07QhN01hN7P0IfMW0P1;Bd/01@1UIFD0Zj^[0:BTY02TY:@0IVIV0080DU9B00D0Hf=S08Z:
RP2CTi<0Ti>C0<W9b@020<[:bP0509JFUP1/K6`0K6a/0:f][@1^KVh00P2@T9001025QHD0LG5a075a
L@1UIFD207inOP050::RXP31`L40Ph>308>3P`2IVIT00P2;Rh/01@2MWId0^[Zj0:NWY`2WYjL0c/k>
0080R8R800D0[Jf]0;Bd]02d];@0Hf=S09VIV@0206][J`0407EeM@1fMWH0MWIf09BDU080JVYZ00D0
IFEU0=KFeP2][Jd0[Jf]05iNGP0209:BTP0508b<S02;Rh/0g]kN0=kNgP2EUID00P1IFET01@1GEeL0
hn?S0>?Sh`2ZZZX0IVIV0080R8R800@0KVi^08J6QP26QXH0a<C40P3>c/h01@2/[:`0JVYZ08N7Q`27
QhL0XJ6Q0080Q8B400D0R8R8096AT@2ATI40U9BD0:^[Z`0207MgM`0504E5A@0n?Sh0?Shn04];B`14
A4@00P18B4P0101^KVh0Ng]k07]kN`1JFUX2059BDP05065QH@1nOWh0MWIf07IfMP1cLg<00P1TI6@0
1@1GEeL0K6a/06a/K01kNg/0W9bL0080UYJF00D0S8b<08:2PP22PX80YJFU0:JVYP0207inOP03071`
L01_Kfl0Kfm_00<0P82000<0O7alooooooooool02?ooool000[ooooo00@0Y:BT08N7Q`27QhL0Lg=c
0P1dM7@01@0n?Sh0Z:RX0:VYZ@2YZJT0[jn_0080ZZZZ00D0Zj^[0:JVYP2VYZH0[Jf]0:RXZ0020:ZZ
ZP0509nOW`2WYjL0YjNW0:6QX@1oOgl00P1IFET0102][Jd0Zj^[0:^[Z`2XZ:P20:ZZZP050:NWY`2[
Zj/0Y:BT0:BTY02HV9P00P2?Shl01@2NWYh0Xj>S0:6QX@2QXJ40K6a/0080?Cdm00D0[Zj^0:^[Z`2Y
ZJT0ZJVY0:>SX`0209nOW`050:>SX`2PX:00X:2P0::RXP2VYZH00P2RXZ801@2BTY80SHf=08f=S@1n
OWh0?3`l0080R8R800@0XJ6Q0:^[Z`2[Zj/0[jn_0P2d];@20;Fe]@80/k>c00D0]kNg0;:b/P2b/[80
YZJV0:j^[P02065QH@0404E5A@1cLg<0Lg=c07]kN`<0NGUi00@0Ti>C09RHV02HV9P0Shn?0P21PH42
09:BTP80R8R800D0RXZ:05YJFP1JFUX0UIFE0;2`/0020;>c/`040;Fe]@2d];@0];Bd0;2`/0<0][Jf
00@0^KVi0;Fe]@2e]KD0/;2`0`2^[Zh0100a<C40Shn?08n?S`2_[jl20;>c/`050<71`@2f][H0][Jf
0;jn_P2g]kL00P2h^;P01@2n_[h0`L710<71`@2j^[X0Zj^[0080<30`00D0@d=308J6QP26QXH0Zj^[
0:n_[`020;Bd]0040;^k^`2l_;`0_;bl0;^k^`80];Bd00D0/;2`0;6a/@2YZJT0ZJVY09fMW@0207Ad
M080/[:b0`2TY:@20;Jf]P050;Ng]`2h^;P0^;Rh0;bl_030`<000P35aLD0103Bd]80d=3@0=3@d01f
MWHAooooo`0406e]K@2@T900T92@07IfMP80HV9R00D0PH6109^KV`2KVi/0Shn?08f=S@0207]kN`05
06][J`1EEED0EEEE07YjNP1`L7000P1GEeL0101CDe<0K6a/06a/K02CTi<20820P005079bLP1@D500
DE5A055AD@1ZJVX00P1WIfL01@1iNGT0Q8B408B4Q02a/K40WinO0080Xj>S00@0TI6A07QhN01hN7P0
IfMW0P1;Bd/01@1UIFD0Zj^[0:BTY02TY:@0IVIV0080DU9B00D0Hf=S08Z:RP2CTi<0Ti>C0<W9b@02
0<[:bP0509JFUP1/K6`0K6a/0:f][@1^KVh00P2@T9001025QHD0LG5a075aL@1UIFD207inOP050::R
XP31`L40Ph>308>3P`2IVIT00P2;Rh/01@2MWId0^[Zj0:NWY`2WYjL0c/k>0080R8R800D0[Jf]0;Bd
]02d];@0Hf=S09VIV@0206][J`0407EeM@1fMWH0MWIf09BDU080JVYZ00D0IFEU0=KFeP2][Jd0[Jf]
05iNGP0209:BTP0508b<S02;Rh/0g]kN0=kNgP2EUID00P1IFET01@1GEeL0hn?S0>?Sh`2ZZZX0IVIV
0080R8R800@0KVi^08J6QP26QXH0a<C40P3>c/h01@2/[:`0JVYZ08N7Q`27QhL0XJ6Q0080Q8B400D0
R8R8096AT@2ATI40U9BD0:^[Z`0207MgM`0504E5A@0n?Sh0?Shn04];B`14A4@00P18B4P0101^KVh0
Ng]k07]kN`1JFUX2059BDP05065QH@1nOWh0MWIf07IfMP1cLg<00P1TI6@01@1GEeL0K6a/06a/K01k
Ng/0W9bL0080UYJF00D0S8b<08:2PP22PX80YJFU0:JVYP0207inOP03071`L01_Kfl0Kfm_00<0P820
00<0O7alooooooooool02?ooool000[ooooo00@0[Zj^09FEU@2EUID0J6QX0P1cLg<01@1GEeL0/;2`
0:j^[P2^[Zh0[:b/0080ZZZZ00D0YJFU0:JVYP2VYZH0Y:BT0:VYZ@0208F5Q@0507emO@2IVIT0VIVI
09ZJVP2@T9000P1LG5`0102[Zj/0[Zj^0:j^[P2^[Zh30:ZZZP040:^[Z`2RXZ80XZ:R0:6QX@80UYJF
00D0W9bL0:6QX@2NWYh0WYjN07QhN00203dm?@050:ZZZP2][Jd0Z:RX0:RXZ02QXJ400P2NWYh01@2L
W9`0WIfM09fMW@2RXZ80XJ6Q00<0XZ:R0P2PX:001@1nOWh0?clo09fMW@2MWId0Y:BT0080ZJVY00D0
Zj^[0:f][@2][Jd0ZJVY0:n_[`020:j^[P050;2`/02/[:`0[:b/0:NWY`2][Jd00P1aLG400`1GEeL0
MGEe07EeM@0306i^KP0506YZJP1gMgL0KVi^06i^KP1YJFT00P1SHf<00`1fMWH0RHV908B4Q00208B4
Q080EEEE00D0QhN70;:b/P2e]KD0]KFe0;>c/`0209nOW`0309JFUP2_[jl0[jn_0080/k>c0P2_[jl0
1@2`/;00[Zj^0:j^[P2XZ:P0=SHf0080U9BD00@0ZJVY0:RXZ02XZ:P0/K6a0P2_[jl0102g]kL0^;Rh
0;Fe]@2e]KD30;Rh^0050;Zj^P2e]KD0ATI604I6AP1fMWH00P2][Jd01@2SXj<0T92@09VIV@2IVIT0
Zj^[0080/K6a00D0/[:b0;>c/`2c/k<0[Zj^0:f][@020:ZZZP050:VYZ@1bLW80LW9b0;Ng]`2d];@0
0P2a/K40102`/;00][Jf0;Jf]P2b/[820;Bd]0050;^k^`2g]kL0^k^k0;^k^`32`/800P30`<000`1a
LG7oooooooooo`0?ooooo`0406YZJP25QHD0QHF507=cL`80D51@00D0RXZ:09fMW@2MWId0S8b<092@
T00207EeM@0506a/K01=CDd0CDe=08:2PP1hN7P00P1GEeL0101@D500GUiN05iNGP1aLG42071`L005
06e]K@12@T80EeMG05MGE`1iNGT00P1ZJVX01@1gMgL0R8R808R8R02h^;P0YZJV0080Xj>S00@0WYjN
07AdM01dM7@0GemO0P1GEeL01@1[Jf/0]KFe0;Rh^02h^;P0LW9b0080GEeM00D0G5aL07IfMP27QhL0
QhN70;fm_@020;Rh^00508b<S01CDe<0De=C09>CT`1XJ6P00P21PH401026QXH0H61P061PH01RHV82
07YjNP0509nOW`2d];@0Ng]k07]kN`2@T9000P28R8P01@2MWId0ZJVY09FEU@2EUID0[jn_0080Lg=c
00D0XJ6Q09NGU`2GUiL0E5AD07AdM00206=SH`0408>3P`1iNGT0NGUi08V9R@80JFUY00D0GemO0=7A
d@2NWYh0WYjN05=CD`0208j>SP0507]kN`27QhL0c<c<0<c<c02EUID00P1ADE401@1@D500hN7Q0>7Q
h@2l_;`0Lg=c0080S8b<00@0IFEU07QhN01hN7P0/k>c0P31`L401@2c/k<0LW9b09BDU02DU9@0WYjN
0080QhN700D0PH61096AT@2ATI40/K6a0<S8b00207IfMP050451@@12@T80@T9204I6AP19BDT00P1G
EeL0101cLg<0Ng]k07]kN`1XJ6P205iNGP0506EUI@1hN7P0Jf][06][J`1gMgL00P1dM7@01@1SHf<0
Xj>S0:>SX`2BTY80ZZZZ0080X:2P00D0PH6108B4Q024Q8@0X:2P0:JVYP02065QH@0405iNGP1bLW80
LW9b08B4Q080OWin00<0TI6Aooooooooool02?ooool000[ooooo00@0[:b/09ZJVP2JVYX0Lg=c0P1K
Fe/01@1WIfL0]KFe0;Fe]@2e]KD0ZZZZ0080[Jf]00D0/;2`0;>c/`2c/k<0/;2`0:^[Z`0206YZJP05
07alO02^[Zh0[Zj^0:ZZZP2?Shl00P1QHF440:b/[080ZZZZ00<0Z:RX0:b/[02IVIT01@2IVIT0102?
Shl0TI6A096AT@1/K6`203lo?`80/;2`0P2TY:@0102XZ:P0X:2P0:2PX02XZ:P20:NWY`050:^[Z`2W
YjL0X:2P0:2PX02SXj<00P2PX:001@1nOWh0;bl_09fMW@2MWId0UiNG0080W9bL00D0YJFU0:ZZZP2Z
ZZX0YjNW0:VYZ@020:b/[0050:n_[`2ZZZX0ZZZZ0:VYZ@2^[Zh00P1aLG401013@d<0IFEU06EUI@1V
IVH206YZJP0506][J`1ZJVX0J6QX06QXJ01HF5P00P1?Cdl01@1NGUh0MGEe07EeM@1eMGD0Lg=c0080
B4Q800D0Ph>30:n_[`2a/K40/K6a0:j^[P020:>SX`0509bLW02MWId0WIfM0;>c/`2d];@00P2/[:`0
1@2_[jl0/k>c0;>c/`2_[jl0=cLg0080TY:B00@0ZZZZ0:b/[02/[:`0[:b/0P2b/[801@2f][H0_;bl
0;Vi^@2i^KT0`<300080^k^k00D0`<300;Jf]P1BDU80DU9B07emO@020:^[Z`050:FUY@2IVIT0YJFU
0:FUY@2/[:`00P2d];@01@2a/K40/[:b0;:b/P2`/;00[Zj^0080[:b/00<0ZZZZ06e]K@1]KFd00P2a
/K420:n_[`030:f][@2b/[80/[:b00<0/k>c00<0][Jf0;Fe]@2h^;P0102h^;P00`1dM7Cooooooooo
o`0?ooooo`0407AdM021PH40PH6108B4Q080B4Q800D0NWYj07alO01lO7`0Kfm_07EeM@0207moO`05
069RHP12@T80@T9206a/K01bLW800P1FEUH01013@d<0O7al07alO027QhL206][J`05069RHP12@T80
DU9B059BDP1eMGD00P1IFET01@1LG5`0PH610861P@2^[Zh0VIVI0080S8b<00@0QXJ6075aL@1aLG40
H61P0P1EEED01@1aLG40/;2`0;Ng]`2g]kL0NGUi0080J6QX00D0MGEe08Z:RP2;Rh/0Rh^;0=GEe@02
0=?Cd`0509NGU`0n?Sh0?Shn09VIV@1oOgl00P2=SHd0102?Shl0Fe]K05]KF`1ZJVX207emO@050:FU
Y@2YZJT0Q8B408B4Q02SXj<00P2@T9001@2PX:00[jn_0:6QX@2QXJ40aLG50080NWYj00D0/[:b0:j^
[P2^[Zh0K6a/096AT@0207EeM@0408B4Q02EUID0UIFE0:FUY@80NWYj00D0N7Qh0=;BdP31`L40`L71
05UIF@0208V9R@0508^;R`2QXJ40fMWI0=WIf@2HV9P00P14A4@01@1?Cdl0eMGE0=GEe@2XZ:P0Kfm_
0080Q8B400@0Hf=S079bLP1bLW80WIfM0P2a/K401@2NWYh0Hf=S0861P@21PH40UIFE0080Ng]k00D0
N7Qh08Z:RP2:RXX0]kNg0<G5a@0207inOP<0ATI600D0@T9204e=C@1OGel0GemO08:2PP0208^;R`05
07YjNP1QHF40HF5Q069RHP1lO7`00P1aLG40101PH600HF5Q065QH@1[Jf/209NGU`0509FEU@2a/K40
Y:BT0:BTY022PX800P2ATI401@2ZZZX0/[:b0820P020P800K6a/0080IFEU00@0IfMW05]KF`1KFe/0
MWIf2_ooool000[ooooo00@0[:b/09ZJVP2JVYX0Lg=c0P1KFe/01@1WIfL0]KFe0;Fe]@2e]KD0ZZZZ
0080[Jf]00D0/;2`0;>c/`2c/k<0/;2`0:^[Z`0206YZJP0507alO02^[Zh0[Zj^0:ZZZP2?Shl00P1Q
HF440:b/[080ZZZZ00<0Z:RX0:b/[02IVIT01@2IVIT0102?Shl0TI6A096AT@1/K6`203lo?`80/;2`
0P2TY:@0102XZ:P0X:2P0:2PX02XZ:P20:NWY`050:^[Z`2WYjL0X:2P0:2PX02SXj<00P2PX:001@1n
OWh0;bl_09fMW@2MWId0UiNG0080W9bL00D0YJFU0:ZZZP2ZZZX0YjNW0:VYZ@020:b/[0050:n_[`2Z
ZZX0ZZZZ0:VYZ@2^[Zh00P1aLG401013@d<0IFEU06EUI@1VIVH206YZJP0506][J`1ZJVX0J6QX06QX
J01HF5P00P1?Cdl01@1NGUh0MGEe07EeM@1eMGD0Lg=c0080B4Q800D0Ph>30:n_[`2a/K40/K6a0:j^
[P020:>SX`0509bLW02MWId0WIfM0;>c/`2d];@00P2/[:`01@2_[jl0/k>c0;>c/`2_[jl0=cLg0080
TY:B00@0ZZZZ0:b/[02/[:`0[:b/0P2b/[801@2f][H0_;bl0;Vi^@2i^KT0`<300080^k^k00D0`<30
0;Jf]P1BDU80DU9B07emO@020:^[Z`050:FUY@2IVIT0YJFU0:FUY@2/[:`00P2d];@01@2a/K40/[:b
0;:b/P2`/;00[Zj^0080[:b/00<0ZZZZ06e]K@1]KFd00P2a/K420:n_[`030:f][@2b/[80/[:b00<0
/k>c00<0][Jf0;Fe]@2h^;P0102h^;P00`1dM7Coooooooooo`0?ooooo`0407AdM021PH40PH6108B4
Q080B4Q800D0NWYj07alO01lO7`0Kfm_07EeM@0207moO`05069RHP12@T80@T9206a/K01bLW800P1F
EUH01013@d<0O7al07alO027QhL206][J`05069RHP12@T80DU9B059BDP1eMGD00P1IFET01@1LG5`0
PH610861P@2^[Zh0VIVI0080S8b<00@0QXJ6075aL@1aLG40H61P0P1EEED01@1aLG40/;2`0;Ng]`2g
]kL0NGUi0080J6QX00D0MGEe08Z:RP2;Rh/0Rh^;0=GEe@020=?Cd`0509NGU`0n?Sh0?Shn09VIV@1o
Ogl00P2=SHd0102?Shl0Fe]K05]KF`1ZJVX207emO@050:FUY@2YZJT0Q8B408B4Q02SXj<00P2@T900
1@2PX:00[jn_0:6QX@2QXJ40aLG50080NWYj00D0/[:b0:j^[P2^[Zh0K6a/096AT@0207EeM@0408B4
Q02EUID0UIFE0:FUY@80NWYj00D0N7Qh0=;BdP31`L40`L7105UIF@0208V9R@0508^;R`2QXJ40fMWI
0=WIf@2HV9P00P14A4@01@1?Cdl0eMGE0=GEe@2XZ:P0Kfm_0080Q8B400@0Hf=S079bLP1bLW80WIfM
0P2a/K401@2NWYh0Hf=S0861P@21PH40UIFE0080Ng]k00D0N7Qh08Z:RP2:RXX0]kNg0<G5a@0207in
OP<0ATI600D0@T9204e=C@1OGel0GemO08:2PP0208^;R`0507YjNP1QHF40HF5Q069RHP1lO7`00P1a
LG40101PH600HF5Q065QH@1[Jf/209NGU`0509FEU@2a/K40Y:BT0:BTY022PX800P2ATI401@2ZZZX0
/[:b0820P020P800K6a/0080IFEU00@0IfMW05]KF`1KFe/0MWIf2_ooool000[ooooo00@0TI6A08R8
R028R8P0K6a/0P1>CTh01@1?Cdl0Rh^;08F5Q@25QHD0Lg=c0080MgMg00D0PX:207EeM@1eMGD0MgMg
07moO`0205aLG00506MWI`21PH40PH6108J6QP1UIFD00P1<C4`01021PH40MGEe07EeM@1gMgL207in
OP0508J6QP28R8P0Ph>308>3P`25QHD00P1XJ6P01@1bLW80HF5Q069RHP1RHV80B4Q80080@41000D0
Rh^;096AT@2@T900T92@08^;R`0208B4Q00507emO@1iNGT0NGUi079bLP28R8P00P1dM7@01@1aLG40
K6a/06a/K01NGUh0;bl_0080OGem00@0Ng]k075aL@1aLG40PH610P23Ph<01@28R8P0QXJ607emO@1m
OGd0N7Qh0080LW9b00D0LG5a071`L01=CDd0CDe=034a<@02030`<00502d];@0f=SH0=SHf03Lg=`14
A4@00P0n?Sh30410@00504a<C015ADD0E5AD05ADE01>CTh00P18B4P01@1nOWh0TI6A08n?S`2?Shl0
UIFE0080QHF500D0QhN707inOP1nOWh0SHf=08Z:RP0208^;R`0508b<S02CTi<0Ti>C08F5Q@0h>3P0
0P1HF5P01022PX80QXJ608J6QP29RHT207inOP0507emO@21PH40P8200820P01oOgl00`1aLG40101g
MgL0>CTi03Ti>@1PH60209ZJVP050:JVYP2TY:@0Xj>S0:>SX`2XZ:P00P2^[Zh01@2][Jd0ZJVY0:VY
Z@2SXj<0[:b/0080WYjN00D0Ng]k06=SH`1SHf<0TI6A09JFUP0209BDU004092@T02CTi<0Ti>C09VI
V@80Vi^K00D0WIfM0:BTY02YZJT0ZJVY0:FUY@0209RHV00305ADE?oooooooooo00oooooo00@0O7al
08F5Q@25QHD0UIFE0P1NGUh01@2SXj<0ZZZZ0:ZZZP28R8P0TI6A0080VYZJ00D0PX:205IFEP1FEUH0
R8R808^;R`0205EEE@0403dm?@1SHf<0Hf=S09BDU080MGEe00D0Fe]K05YJFP1@D500D51@05iNGP02
065QH@0506ATI025QHD0QHF50<30`02RXZ800P2MWId0102WYjL0N7Qh07QhN01VIVH205aLG00506=S
H`2NWYh0U9BD09BDU01RHV800P1SHf<01@1cLg<0QHF508f=S@2=SHd0c<c<0080bLW900D0TI6A0410
@010@400Z:RX08n?S`0209ZJVP0408n?S`1HF5P0F5QH06i^KP80NGUi00D0Zj^[0:j^[P2IVIT0VIVI
0:^[Z`020:RXZ0050::RXP2f][H0Xj>S0:>SX`2LW9`00P1bLW801@2k^k/0_;bl0;bl_01eMGD0SHf=
0080MGEe00@0NGUi08V9R@29RHT0VYZJ0P1hN7P01@1eMGD0bl_;0;Jf]P2f][H0Fe]K0080MgMg00D0
SHf=08n?S`3De=@0e=CD0:f][@0203Xj>P0505ADE03Ng]h0g]kN09:BTP1gMgL00P29RHT0101YJFT0
PX:208:2PP2l_;`20<G5a@050:ZZZP1QHF40QXJ608J6QP2<S8`00P29RHT01@1jNWX0Q8B408B4Q02l
_;`0bLW90080QhN700D0BDU904i>CP1>CTh0B4Q8051@D00205]KF`040820P01bLW80LW9b07UiN@80
G5aL00D0Hf=S08N7Q`1_Kfl0Kfm_071`L00206IVIP0504e=C@1`L700L71`08:2PP2NWYh00P2VYZH0
1@26QXH0QhN708N7Q`2ZZZX0][Jf0080QXJ600@0S8b<07emO@1mOGd0IFEU0P1NGUh00`1SHf?ooooo
ooooo`08ooooo`002_ooool01011@D40@T920492@P1NGUh206IVIP0506e]K@1VIVH0GEeM05eMG@0f
=SH00P19BDT01@1IFET0D51@051@D01EEED0FEUI0080DE5A00D092@T03Lg=`0g=cL0EeMG055AD@02
061PH004069RHP1QHF40HF5Q04I6AP80@41000D0=cLg04M7A`1CDe<0De=C05ADE00204m?C`0502/[
:`0S8b<0>3Ph03Ph>016ATH00P1@D5001@1=CDd0<C4a024Q8@0Q8B40>3Ph0080ADE500D0C4a<055A
D@1ADE40EeMG04A4A002034a<@0503hn?P1SHf<0Hf=S06UYJ@1ZJVX00P1KFe/0101NGUh09RHV02HV
9P0M7Ad204e=C@05059BDP1ADE40CTi>04i>CP1BDU800P0/;2`01@0n?Sh0CTi>05YJFP1JFUX0HV9R
0080G5aL00D0DE5A02TY:@0Y:BT0?Shn05QHF002051@D00505QHF01RHV80HV9R03lo?`0W9bL00P1C
De<0101WIfL0J6QX06QXJ01QHF4305mOG`0403Hf=P1LG5`0G5aL06IVIP80EeMG00D0G5aL05iNGP1D
E5@0E5AD02HV9P0204U9B@80HV9R0P1UIFD0101NGUh0AdM704M7A`15ADD2069RHP0506ATI01RHV80
De=C05=CD`1NGUh00P0i>CT01@1EEED0GEeM05UIF@1IFET0ATI60080B4Q800D0=cLg02TY:@0a<C40
<C4a03Xj>P02030`<00503Ph>00f=SH0=SHf02XZ:P0[:b/00P0g=cL01@11@D40>CTi03Ti>@11@D40
>SXj008092@T00@0;bl_03dm?@0m?Cd0@T920P1>CTh01@19BDT0@D5103<c<`0c<c<0CDe=0080C4a<
00<0B4Q8ooooooooool03oooool306m_K`0407moO`1<C4`0C4a<0:VYZ@80/;2`00D0UYJF08j>SP2G
UiL0UiNG079bLP0205=CD`0506QXJ01/K6`0FEUI05UIF@0n?Sh00P1aLG401@2HV9P0RXZ:08Z:RP1_
Kfl0FEUI0080C4a<00@0DU9B06EUI@1UIFD0HF5Q0P1fMWH01@33`l<0X:2P08V9R@29RHT0[jn_0080
OGem00D0KFe]075aL@1aLG40LG5a0:6QX@020:RXZ00508N7Q`1_Kfl0Kfm_07]kN`24Q8@00P27QhL0
1036a/H0`<300<30`029RHT204M7A`050:FUY@2@T900XZ:R0::RXP2;Rh/00P1DE5@01@1bLW80OWin
07inOP2YZJT0/k>c0080VYZJ00D0ZJVY09ZJVP2JVYX0XJ6Q0<30`00209NGU`0408J6QP1VIVH0IVIV
0::RXP80YjNW00D0FEUI07AdM01^KVh0KVi^07inOP0208>3P`0508V9R@1eMGD0MGEe07QhN03<c<`0
0P2g]kL01@1kNg/0RXZ:08Z:RP2@T900YJFU0080dM7A00@0_kno06ATI01TI6@0GEeM0P3QhN401@2c
/k<0Ng]k08J6QP26QXH0Jf][0080R8R800D0b/[:0<;2`P32`/80]KFe06i^KP02092@T00409fMW@2K
Vi/0Vi^K08j>SP80TI6A00D0_Kfm09fMW@2TY:@0Y:BT05ADE003059BDP0405EEE@1MGEd0GEeM08F5
Q@80QhN700D0KVi^06=SH`1SHf<0Fe]K08R8R002075aL@0407emO@1TI6@0I6AT0410@080K6a/00D0
MgMg07inOP2:RXX0RXZ:08B4Q0020820P005092@T02MWId0QhN708N7Q`2QXJ400P1WIfL0101YJFT0
JVYZ06YZJP1_Kfl:ooooo`002_ooool01011@D40@T920492@P1NGUh206IVIP0506e]K@1VIVH0GEeM
05eMG@0f=SH00P19BDT01@1IFET0D51@051@D01EEED0FEUI0080DE5A00D092@T03Lg=`0g=cL0EeMG
055AD@02061PH004069RHP1QHF40HF5Q04I6AP80@41000D0=cLg04M7A`1CDe<0De=C05ADE00204m?
C`0502/[:`0S8b<0>3Ph03Ph>016ATH00P1@D5001@1=CDd0<C4a024Q8@0Q8B40>3Ph0080ADE500D0
C4a<055AD@1ADE40EeMG04A4A002034a<@0503hn?P1SHf<0Hf=S06UYJ@1ZJVX00P1KFe/0101NGUh0
9RHV02HV9P0M7Ad204e=C@05059BDP1ADE40CTi>04i>CP1BDU800P0/;2`01@0n?Sh0CTi>05YJFP1J
FUX0HV9R0080G5aL00D0DE5A02TY:@0Y:BT0?Shn05QHF002051@D00505QHF01RHV80HV9R03lo?`0W
9bL00P1CDe<0101WIfL0J6QX06QXJ01QHF4305mOG`0403Hf=P1LG5`0G5aL06IVIP80EeMG00D0G5aL
05iNGP1DE5@0E5AD02HV9P0204U9B@80HV9R0P1UIFD0101NGUh0AdM704M7A`15ADD2069RHP0506AT
I01RHV80De=C05=CD`1NGUh00P0i>CT01@1EEED0GEeM05UIF@1IFET0ATI60080B4Q800D0=cLg02TY
:@0a<C40<C4a03Xj>P02030`<00503Ph>00f=SH0=SHf02XZ:P0[:b/00P0g=cL01@11@D40>CTi03Ti
>@11@D40>SXj008092@T00@0;bl_03dm?@0m?Cd0@T920P1>CTh01@19BDT0@D5103<c<`0c<c<0CDe=
0080C4a<00<0B4Q8ooooooooool03oooool306m_K`0407moO`1<C4`0C4a<0:VYZ@80/;2`00D0UYJF
08j>SP2GUiL0UiNG079bLP0205=CD`0506QXJ01/K6`0FEUI05UIF@0n?Sh00P1aLG401@2HV9P0RXZ:
08Z:RP1_Kfl0FEUI0080C4a<00@0DU9B06EUI@1UIFD0HF5Q0P1fMWH01@33`l<0X:2P08V9R@29RHT0
[jn_0080OGem00D0KFe]075aL@1aLG40LG5a0:6QX@020:RXZ00508N7Q`1_Kfl0Kfm_07]kN`24Q8@0
0P27QhL01036a/H0`<300<30`029RHT204M7A`050:FUY@2@T900XZ:R0::RXP2;Rh/00P1DE5@01@1b
LW80OWin07inOP2YZJT0/k>c0080VYZJ00D0ZJVY09ZJVP2JVYX0XJ6Q0<30`00209NGU`0408J6QP1V
IVH0IVIV0::RXP80YjNW00D0FEUI07AdM01^KVh0KVi^07inOP0208>3P`0508V9R@1eMGD0MGEe07Qh
N03<c<`00P2g]kL01@1kNg/0RXZ:08Z:RP2@T900YJFU0080dM7A00@0_kno06ATI01TI6@0GEeM0P3Q
hN401@2c/k<0Ng]k08J6QP26QXH0Jf][0080R8R800D0b/[:0<;2`P32`/80]KFe06i^KP02092@T004
09fMW@2KVi/0Vi^K08j>SP80TI6A00D0_Kfm09fMW@2TY:@0Y:BT05ADE003059BDP0405EEE@1MGEd0
GEeM08F5Q@80QhN700D0KVi^06=SH`1SHf<0Fe]K08R8R002075aL@0407emO@1TI6@0I6AT0410@080
K6a/00D0MgMg07inOP2:RXX0RXZ:08B4Q0020820P005092@T02MWId0QhN708N7Q`2QXJ400P1WIfL0
101YJFT0JVYZ06YZJP1_Kfl:ooooo`002_ooool0101jNWX0Fe]K05]KF`2TY:@20:FUY@050:ZZZP2a
/K40]kNg0;Ng]`1NGUh00P1kNg/01@2ATI40R8R808R8R02HV9P0XJ6Q0080UiNG00D0:RXZ04e=C@1=
CDd0U9BD09VIV@0209>CT`0409bLW02YZJT0ZJVY04m?C`80Hf=S00D0UYJF09ZJVP2DU9@0U9BD08f=
S@0207alO080>c/k0P1QHF401@1cLg<0EeMG05MGE`1hN7P0TY:B0080?Cdm00@0Ng]k0:>SX`2SXj<0
X:2P0P2SXj<01@2^[Zh0SHf=0410@010@400JFUY0080Shn?00D0Vi^K09jNWP2ATI40TI6A09:BTP02
03Ti>@0506YZJP2/[:`0[:b/0:>SX`28R8P00P25QHD01@2NWYh0BTY:04Y:BP1^KVh0Zj^[0080XZ:R
00@0YZJV09fMW@2MWId0XZ:R0P19BDT01@2>SXh0[jn_0;6a/@2a/K40]KFe0080_Kfm00D0YjNW02HV
9P2@T900T92@0;6a/@020;Bd]0050;Jf]P2h^;P0_[jn0;jn_P0j>SX00P2SXj<01@31`L40^KVi0;Vi
^@2a/K40[Zj^0080WinO00D0;bl_08:2PP22PX80R8R809:BTP0209RHV004092@T01eMGD0MGEe07Qh
N080[jn_00D0[Zj^0:b/[02_[jl0[jn_0;Ng]`0205eMG@0509JFUP2PX:00YJFU0:FUY@2ZZZX00P2Y
ZJT01@1dM7@09RHV09ZJVP2JVYX0aLG50080`L7100D0_;bl0:n_[`2_[jl0Fe]K03lo?`030:RXZ080
YjNW00D0Xj>S09RHV01<C4`0C4a<06QXJ00208j>SP<0[Zj^00D0][Jf0:2PX011@D40@D510;2`/003
0;Rh^17ooooo00@0L71`07MgM`1gMgL0UIFE0P1>CTh30:6QX@0409>CT`2?Shl0Xj>S0:>SX`<0IfMW
00D0PH6106ATI01:BTX0BTY:038b<P0205MGE`0506i^KP1eMGD0MGEe05iNGP1>CTh00P1?Cdl0101A
DE40MgMg07MgM`1IFET208J6QP050<S8b02VYZH0R8R808R8R02[Zj/00P1iNGT01@1dM7@0LG5a075a
L@2>SXh0Zj^[0080]KFe00D0QHF507inOP1nOWh0Q8B4096AT@020:j^[P040<k>cP33`l<0`l?309BD
U080B4Q800D0[:b/09JFUP2OWil0WinO09BDU00204Y:BP0507emO@2@T900T92@0;:b/P2m_Kd00P2U
YJD01@2i^KT0RHV908V9R@2DU9@0`L710080[jn_00@0WinO07UiN@1iNGT0_kno0P30`<001@1kNg/0
VYZJ075aL@1aLG40PX:20080V9RH00D0[Jf]06m_K`1_Kfl0O7al0;bl_0020;Jf]P0509^KV`1dM7@0
M7Ad08:2PP2KVi/00P34a<@0102j^[X0FUYJ05YJFP1PH6020=oOg`0509jNWP20P800RHV908V9R@1T
I6@00P1mOGd01@34a<@0_;bl0;bl_02j^[X0MWIf0080V9RH00@0W9bL0:FUY@2UYJD0RHV90P2BTY80
1@2g]kL0U9BD09^KV`2KVi/0GEeM0080DU9B00D0BDU904];B`1FEUH0EUIF06IVIP0207AdM005065Q
H@1[Jf/0Jf][04m?C`1oOgl00P1eMGD0101OGel0M7Ad07AdM01=CDd206e]K@0507]kN`2^[Zh0V9RH
09RHV020P8000P1mOGd01@2RXZ80UYJF07]kN`1kNg/0YJFU0080J6QX00@0F5QH06MWI`1WIfL0F5QH
2_ooool000[ooooo00@0Rh^;06i^KP1^KVh0X:2P0P2UYJD01@2XZ:P0]KFe0;^k^`2k^k/0Hf=S0080
FUYJ00D0Xj>S08n?S`2?Shl0WinO0:RXZ0020;2`/00504U9B@1CDe<0De=C08j>SP2EUID00P2@T900
102=SHd0V9RH09RHV01JFUX2065QH@0509^KV`2JVYX0SXj>08j>SP1mOGd00P1cLg<01@0j>SX0>CTi
05eMG@1MGEd0OWin0080I6AT00D0MgMg08J6QP1<C4`0C4a<07QhN00209FEU@0509VIV@2EUID0UIFE
0:RXZ02@T9000P1<C4`01@1_Kfl0Vi^K09^KV`2XZ:P0X:2P0080VYZJ00@0W9bL04i>CP1>CTh0LW9b
0P2_[jl01@2ZZZX0X:2P09jNWP2NWYh0Vi^K0080Bd];00D0KVi^0:ZZZP2XZ:P0Z:RX0:JVYP0209^K
V`0509fMW@19BDT0BDU909JFUP2h^;P00P2f][H01@2i^KT0_[jn0;jn_P2f][H0De=C0080WYjN00D0
/K6a0:b/[02/[:`0/;2`0;Zj^P020;^k^`0403dm?@2YZJT0ZJVY0;no_`80_;bl00D0]KFe0;:b/P2I
VIT0VIVI038b<P0207emO@0508f=S@2?Shl0TI6A096AT@21PH400P1RHV801@1ZJVX0[Zj^0:j^[P2c
/k<0]kNg0080`L7100D0`<3005EEE@1EEED0QXJ609nOW`020::RXP050:FUY@2PX:00X:2P079bLP0h
>3P00P2e]KD0102f][H0]kNg0;Ng]`2e]KD20;Ng]`0506ATI01eMGD0[jn_0:n_[`2WYjL00P2YZJT0
1@2][Jd0YjNW04M7A`17AdL0NWYj0080VIVI00D0XZ:R0:JVYP2VYZH0[jn_0;:b/P0204m?C`040;>c
/`2h^;P0^;Rh0;Rh^17ooooo00@0O7al08J6QP26QXH0V9RH0P1ADE401@2JVYX0ZJVY0:VYZ@2GUiL0
TY:B0080Vi^K00D0K6a/05mOG`1OGel0P82007]kN`0205]KF`0404A4A01VIVH0IVIV07moO`80PX:2
00D0Lg=c071`L01^KVh0KVi^05YJFP02092@T00506QXJ026QXH0QXJ60;^k^`2MWId00P24Q8@0102e
]KD0N7Qh07QhN01hN7P207emO@0508j>SP2d];@0bLW90<W9b@2@T9000P2=SHd01@20P800RHV90:6Q
X@2QXJ40c<c<0080_;bl00D0Ti>C04A4A014A4@0VIVI08V9R@0208n?S`0408V9R@19BDT0BDU907al
O080Rh^;00D0^;Rh0<k>cP2TY:@0Y:BT0;fm_@0209>CT`05092@T03:b/X0Zj^[0:^[Z`2OWil00P1b
LW801@2XZ:P0_Kfm0;fm_@1lO7`0TI6A0080KFe]0`1mOGd01@2LW9`0PX:208:2PP2:RXX0`L710080
[Jf]00D0Vi^K06e]K@1]KFd0Ogmo0:JVYP020;Zj^P0409^KV`11@D40@D5105]KF`80`l?300D0V9RH
08:2PP1fMWH0MWIf065QH@0207UiN@050;jn_P2f][H0][Jf0;bl_01bLW800P2KVi/0102@T900Z:RX
0:RXZ01ZJVX209RHV0050:BTY02PX:00RXZ:08Z:RP1YJFT00P1IFET01@1ADE40Bd];055AD@1ADE40
M7Ad0080Q8B400D0Ng]k07QhN01hN7P0EUIF08Z:RP0208N7Q`0406UYJ@1hN7P0N7Qh051@D080QXJ6
00D0RXZ:08^;R`2EUID0UIFE09BDU00207AdM00507EeM@1jNWX0Ph>308>3P`2EUID00P1BDU80101K
Fe/0IVIV06IVIP1JFUX:ooooo`002_ooool0102?Shl0MgMg07MgM`2ZZZX20:JVYP050;6a/@2n_[h0
_kno0;no_`1JFUX00P1cLg<01@2XZ:P0SXj>08j>SP2WYjL0];Bd0080[Jf]00D0A4A406UYJ@1YJFT0
W9bL092@T00208f=S@0408j>SP2QXJ40XJ6Q059BDP80IVIV00D0Shn?07moO`1_Kfl0Kfm_06e]K@02
065QH@0503@d=00i>CT0DE5A055AD@1IFET00P1KFe/01@1QHF40MGEe03hn?P0n?Sh0Ng]k0080Vi^K
00D0XJ6Q0:NWY`2WYjL0Z:RX09NGU`0204M7A`0507YjNP2OWil0WinO09NGU`2DU9@00P27QhL0102C
Ti<0DU9B059BDP1jNWX20:f][@050:RXZ02LW9`0TY:B09:BTP2MWId00P1:BTX01@1bLW80XZ:R0:FU
Y@2UYJD0Y:BT0080YjNW00D0UiNG03lo?`0o?cl0V9RH0;Rh^0030;Ng]`80^;Rh00D0/[:b04e=C@2I
VIT0VIVI0:VYZ@020:NWY`050:ZZZP2c/k<0^KVi0;Vi^@0k>c/00P2XZ:P01@2m_Kd0^[Zj0;Zj^P2h
^;P0^KVi0080Y:BT00D0=cLg0820P020P800R8R807moO`0207]kN`0408J6QP1XJ6P0J6QX079bLP80
/[:b00D0^;Rh0;Vi^@30`<00`<300;^k^`0205QHF00509jNWP2YZJT0YjNW0:NWY`2VYZH00P2QXJ40
1@1[Jf/0Bd];0;Fe]@2e]KD0/[:b0080[jn_00D0];Bd0;>c/`2c/k<0L71`07IfMP020;2`/0<0ZZZZ
00D0/K6a0:f][@0l?3`0?3`l07alO00209JFUP<0YJFU00D0Vi^K06IVIP19BDT0BDU90;:b/P020;Zj
^P030;Ng]ooooooooooo00oooooo00@0KVi^07=cL`1cLg<0QHF50P14A4@01@2:RXX0T92@092@T020
P800QhN70080T92@00D0K6a/05MGE`1GEeL0LW9b071`L00205MGE`0404U9B@1bLW80LW9b0861P@80
QHF500D0Kfm_07]kN`1]KFd0KFe]05EEE@0208>3P`0505YJFP24Q8@0Q8B40;Ng]`2HV9P00P28R8P0
102^[Zh0Ng]k07]kN`1kNg/20861P@0407]kN`2b/[80_;bl0;bl_0<0Ph>300D0OGem092@T02IVIT0
VIVI0=CDe0020;^k^`0509>CT`10@400@41009>CT`28R8P00P2BTY801022PX80ATI604I6AP1kNg/2
08:2PP050:>SX`2i^KT0ZJVY0:VYZ@2`/;000P2EUID01@29RHT0bLW90;Fe]@2e]KD0XJ6Q0080MWIf
00D0_kno0<C4a034a<@0Ogmo08J6QP0206m_K`0407QhN026QXH0QXJ609^KV`80N7Qh00D0RHV90;^k
^`2SXj<0Xj>S08Z:RP0206UYJ@0507UiN@2TY:@0^;Rh0;Rh^02i^KT00P1ADE401@1ZJVX0h^;R0>;R
hP25QHD0QXJ60080MGEe00@0IVIV075aL@1aLG40^;Rh0P2[Zj/01@2b/[80MWIf08b<S02<S8`0M7Ad
0080Zj^[00D0GemO09NGU`2GUiL0[:b/09bLW002096AT@0505IFEP1>CTh0CTi>04i>CP19BDT00P1E
EED0101VIVH0NWYj07YjNP1`L70206YZJP0505IFEP2;Rh/0TI6A096AT@1XJ6P00P1VIVH01@1BDU80
LW9b079bLP2:RXX0VIVI0080VYZJ00D0YjNW07alO01lO7`0MGEe07inOP0209:BTP040820P015ADD0
ADE506ATI080JFUY00<0IFEUooooooooool02?ooool000[ooooo00@0Shn?07MgM`1gMgL0ZZZZ0P2V
YZH01@2a/K40_[jn0;no_`2o_kl0FUYJ0080Lg=c00D0Z:RX08j>SP2>SXh0YjNW0;Bd]0020:f][@05
04A4A01YJFT0JFUY09bLW02@T9000P2=SHd0102>SXh0XJ6Q0:6QX@1BDU8206IVIP0508n?S`1oOgl0
Kfm_06m_K`1]KFd00P1QHF401@0d=3@0>CTi055AD@1ADE40FEUI0080Fe]K00D0HF5Q07EeM@0n?Sh0
?Shn07]kN`0209^KV`050:6QX@2WYjL0YjNW0:RXZ02GUiL00P17AdL01@1jNWX0WinO09nOW`2GUiL0
U9BD0080QhN700@0Ti>C059BDP1BDU80NWYj0P2][Jd01@2XZ:P0W9bL09:BTP2BTY80WIfM0080BTY:
00D0LW9b0::RXP2UYJD0YJFU0:BTY0020:NWY`0509NGU`0o?cl0?clo09RHV02h^;P00`2g]kL20;Rh
^0050;:b/P1=CDd0VIVI09VIV@2YZJT00P2WYjL01@2ZZZX0/k>c0;Vi^@2i^KT0>c/k0080Z:RX00D0
_Kfm0;Zj^P2j^[X0^;Rh0;Vi^@020:BTY00503Lg=`20P800P82008R8R01oOgl00P1kNg/01026QXH0
J6QX06QXJ01bLW820;:b/P050;Rh^02i^KT0`<300<30`02k^k/00P1HF5P01@2NWYh0ZJVY0:NWY`2W
YjL0YZJV0080XJ6Q00D0Jf][04];B`2e]KD0]KFe0;:b/P020:n_[`050;Bd]02c/k<0/k>c071`L01f
MWH00P2`/;030:ZZZP050;6a/@2][Jd0?3`l03`l?01lO7`00P2FUYH30:FUY@0509^KV`1VIVH0BDU9
04U9B@2b/[800P2j^[X00`2g]kOoooooooooo`0?ooooo`0406i^KP1cLg<0Lg=c08F5Q@80A4A400D0
RXZ:092@T02@T900P82008N7Q`02092@T00506a/K01GEeL0EeMG079bLP1`L7000P1GEeL01019BDT0
LW9b079bLP21PH4208F5Q@0506m_K`1kNg/0KFe]06e]K@1EEED00P23Ph<01@1JFUX0Q8B408B4Q02g
]kL0V9RH0080R8R800@0[Zj^07]kN`1kNg/0Ng]k0P21PH40101kNg/0/[:b0;bl_02l_;`308>3P`05
07emO@2@T900VIVI09VIV@3De=@00P2k^k/01@2CTi<0@4100410@02CTi<0R8R80080TY:B00@0PX:2
04I6AP16ATH0Ng]k0P22PX801@2SXj<0^KVi0:VYZ@2YZJT0/;2`0080UIFE00D0RHV90<W9b@2e]KD0
]KFe0:6QX@0207IfMP050;no_`34a<@0a<C407moO`26QXH00P1_Kfl0101hN7P0QXJ608J6QP2KVi/2
07QhN00508V9R@2k^k/0Xj>S0:>SX`2:RXX00P1YJFT01@1iNGT0Y:BT0;Rh^02h^;P0^KVi0080DE5A
00D0JVYZ0>;RhP3Rh^80QHF508J6QP0207EeM@0406IVIP1aLG40LG5a0;Rh^080Zj^[00D0/[:b07If
MP2<S8`0S8b<07AdM0020:^[Z`0505mOG`2GUiL0UiNG0:b/[02LW9`00P2ATI401@1FEUH0CTi>04i>
CP1>CTh0BDU90080EEEE00@0IVIV07YjNP1jNWX0L71`0P1ZJVX01@1FEUH0Rh^;096AT@2ATI40J6QX
0080IVIV00D0DU9B079bLP1bLW80RXZ:09VIV@0209ZJVP050:NWY`1lO7`0O7al07EeM@1nOWh00P2B
TY801020P800ADE504E5A@1TI6@206UYJ@0306EUIOoooooooooo00Sooooo000:ooooo`0408f=S@1R
HV80HV9R09bLW0<0X:2P00@0YJFU09bLW02LW9`0Cdm?0P14A4@01@26QXH0V9RH09RHV02^[Zh0/K6a
0080XJ6Q00D0=3@d05aLG01LG5`0XJ6Q09:BTP02092@T00408f=S@2IVIT0VIVI04M7A`80;2`/00D0
R8R808Z:RP1eMGD0MGEe07alO00207emO@0504i>CP1IFET0MgMg07MgM`1eMGD00P1UIFD01@1LG5`0
P82004];B`1;Bd/0QHF50080VYZJ00D0Zj^[0;:b/P2b/[80ZJVY0:2PX00204=3@`05061PH02WYjL0
YjNW09nOW`2@T9000P22PX801028R8P0E5AD05ADE01`L70209VIV@0509fMW@2BTY80QXJ608J6QP1g
MgL00P13@d<01@1dM7@0WIfM08N7Q`27QhL0PX:20080V9RH00@0Vi^K06IVIP1VIVH0Vi^K0`2b/[80
1@2e]KD0Zj^[0:^[Z`2=SHd0@T920080VIVI00@0Xj>S0:ZZZP2ZZZX0/K6a0`2h^;P0101<C4`0Xj>S
0:>SX`2e]KD20;2`/0050:RXZ02TY:@0T92@092@T00b<S800P1;Bd/00`1NGUh0K6a/08>3P`0208>3
P`80G5aL00D0EUIF08b<S02<S8`0UiNG09JFUP0209RHV0050::RXP2ATI40TI6A0:f][@2b/[800P2a
/K401@2[Zj/0YZJV0:JVYP1bLW80I6AT0080][Jf0`2d];@01@2i^KT0^k^k0;^k^`1bLW80Ph>30080
/;2`00D0Zj^[0:b/[02/[:`0/;2`0:j^[P0204I6AP0407]kN`2^[Zh0[Zj^0:RXZ080X:2P00D0TY:B
07emO@1BDU80DU9B0;:b/P020;>c/`030;Bd]?oooooooooo00oooooo00@0MWIf0820P020P800QXJ6
0P1:BTX01@2>SXh0V9RH09RHV02:RXX0UYJF0080V9RH00D0NGUi05EEE@1EEED0O7al06MWI`0204Y:
BP040451@@1/K6`0K6a/096AT@80R8R800D0LG5a06m_K`1@D500D51@04m?C`0205eMG@0505ADE01X
J6P0J6QX0::RXP2?Shl00P22PX80102TY:@0Lg=c07=cL`1oOgl207]kN`0506MWI`2/[:`0YjNW0:NW
Y`1^KVh00P1oOgl01@1bLW80P82009jNWP2NWYh0f][J0080aLG500D0TY:B05eMG@1MGEd0ZJVY09RH
V00209fMW@0408N7Q`18B4P0B4Q807YjNP80RXZ:00D0Zj^[0<?3``2g]kL0]kNg0:f][@02096AT@05
0820P034a<@0/k>c0;>c/`2RXZ800P26QXH00`32`/80a<C40<C4a00208V9R@80O7al00@0P82008R8
R028R8P0V9RH0P23Ph<01@1gMgL0[Zj^0;Bd]02d];@0TI6A0080MgMg00D0O7al0;^k^`2h^;P0^;Rh
0;2`/002059BDP0506=SH`3MgMd0gMgM09:BTP2:RXX00P1mOGd0101iNGT0OWin07inOP2k^k/20;Bd
]0050:FUY@1^KVh0OGem07emO@1dM7@00P2ATI401@1IFET0S8b<08b<S02CTi<0IfMW0080UiNG00D0
EeMG04];B`1;Bd/0@D5104A4A00205]KF`04071`L01lO7`0O7al06i^KP80FUYJ00D0EeMG07moO`25
QHD0QHF505UIF@0205eMG@0504m?C`1]KFd0KFe]0820P01PH6000P1`L7001@2LW9`0I6AT06ATI01m
OGd0MWIf0080SHf=00@0MgMg0451@@11@D40I6AT0P1bLW800`1cLg?oooooooooo`08ooooo`002_oo
ool0101YJFT0F5QH05QHF01@D50203lo?`05038b<P0d=3@0=CDe03De=@0c<c<00P0k>c/01@19BDT0
Cdm?04m?C`1>CTh0De=C0080D51@00D0Bd];05EEE@1EEED0EUIF03lo?`0203Ti>@0404Q8B01=CDd0
CDe=055AD@80Bd];00D0D51@05=CD`1JFUX0FUYJ055AD@0204I6AP0503Xj>P0b<S80?Shn03hn?P0T
92@00P0Z:RX01@1<C4`0A4A403Xj>P0j>SX0Bd];0080CTi>00D0JFUY06][J`1[Jf/0Kfm_069RHP02
05=CD`0505mOG`1HF5P0F5QH02d];@1CDe<00P1JFUX01015ADD0B4Q804Q8B017AdL206QXJ005079b
LP1hN7P0D51@051@D01HF5P00P1GEeL01@1:BTX0>3Ph02@T900T92@0C4a<0080FEUI00D0GUiN05QH
F01HF5P0Fe]K06IVIP0306MWI`80FUYJ00D0De=C04U9B@1;Bd/0Bd];04M7A`0202l_;`0504];B`1J
FUX0HV9R069RHP1IFET00P1]KFd01@1aLG40J6QX06QXJ01VIVH0I6AT0080FUYJ00D0FEUI05ADE01D
E5@0@D5103Lg=`0204];B`0405MGE`12@T80@T9204E5A@80EUIF00D0FUYJ051@D01HF5P0F5QH06i^
KP0207moO`0507UiN@1^KVh0@T920492@P1GEeL00P1UIFD01@1QHF40IVIV08>3P`23Ph<0Q8B40080
OWin0`1lO7`01@1HF5P0GUiN05aLG01LG5`0DU9B0080EeMG00D0HV9R05eMG@1;Bd/0Bd];05eMG@02
069RHP0505eMG@1FEUH0EUIF05ADE012@T800P0k>c/0101=CDd0De=C05=CD`1FEUHAooooo`04075a
L@23Ph<0Ph>308J6QP80Cdm?00D0RHV909FEU@2EUID0R8R809BDU00209JFUP0507=cL`1CDe<0De=C
08^;R`1dM7@00P1ADE401011@D40IVIV06IVIP1gMgL207]kN`0506e]K@1bLW80BDU904U9B@1@D500
0P1OGel01@1PH600OGem07emO@2h^;P0YjNW0080Ph>300@0^[Zj0820P020P800QhN70P2?Shl01@1`
L700ZZZZ0;2`/02`/;00MWIf0080Ti>C00D0HF5Q075aL@2JVYX0VYZJ0=?Cd`020;Jf]P0509ZJVP1R
HV80HV9R0:6QX@2JVYX00P2FUYH01027QhL0Bd];04];B`1lO7`2096AT@050:f][@2/[:`0[jn_0:n_
[`2SXj<00P28R8P01@2:RXX0b<S80:j^[P2^[Zh0VYZJ0080Rh^;00D0alO70<c<c03<c<`0Shn?08R8
R00207IfMP0406m_K`2ATI40TI6A0:FUY@80TY:B00D0RHV90<;2`P2`/;00/;2`096AT@020820P005
07=cL`2h^;P0];Bd0;Bd]02^[Zh00P0k>c/01@1UIFD0g=cL0=cLg02IVIT0UIFE0080T92@00@0Kfm_
07alO01lO7`0`<300P2o_kl01@2UYJD0MgMg08R8R028R8P0Ph>30080PX:200D0MgMg09^KV`2KVi/0
YZJV06i^KP0209:BTP0504i>CP1BDU80DU9B03dm?@16ATH00P1PH600101iNGT0QhN708N7Q`1dM7@2
05aLG00506UYJ@27QhL0SXj>08j>SP1IFET00P1LG5`01@1:BTX0EUIF05IFEP1eMGD0QXJ60080QHF5
00D0ZJVY06m_K`1_Kfl0MWIf07emO@0209BDU00406=SH`11@D40@D5106=SH`80EEEE00<0I6AToooo
ooooool02?ooool000[ooooo00@0JFUY05QHF01HF5P0D51@0P0o?cl01@0b<S80=3@d03De=@0e=CD0
<c<c0080>c/k00D0BDU904m?C`1?Cdl0CTi>05=CD`02051@D00504];B`1EEED0EEEE05IFEP0o?cl0
0P0i>CT01018B4P0CDe=04e=C@1ADE4204];B`05051@D01CDe<0FUYJ05YJFP1ADE400P16ATH01@0j
>SX0<S8b03hn?P0n?Sh092@T0080:RXZ00D0C4a<04A4A00j>SX0>SXj04];B`0204i>CP0506UYJ@1[
Jf/0Jf][06m_K`1RHV800P1CDe<01@1OGel0F5QH05QHF00];Bd0De=C0080FUYJ00@0ADE504Q8B018
B4P0AdM70P1XJ6P01@1bLW80N7Qh051@D01@D500F5QH0080EeMG00D0BTY:03Ph>00T92@092@T04a<
C00205UIF@0505iNGP1HF5P0F5QH05]KF`1VIVH00`1WIfL205YJFP0505=CD`19BDT0Bd];04];B`17
AdL00P0_;bl01@1;Bd/0FUYJ069RHP1RHV80FEUI0080KFe]00D0LG5a06QXJ01XJ6P0IVIV06ATI002
05YJFP0505UIF@1DE5@0E5AD0451@@0g=cL00P1;Bd/0101GEeL0@T920492@P15ADD205IFEP0505YJ
FP1@D500F5QH05QHF01^KVh00P1oOgl01@1iNGT0KVi^0492@P12@T80EeMG0080IFEU00D0HF5Q06IV
IP23Ph<0Ph>308B4Q00207inOP<0O7al00D0F5QH05iNGP1LG5`0G5aL059BDP0205MGE`05069RHP1M
GEd0Bd];04];B`1MGEd00P1RHV801@1MGEd0EUIF05IFEP1DE5@0@T920080>c/k00@0CDe=05=CD`1C
De<0EUIF4Oooool0101aLG40Ph>308>3P`26QXH204m?C`0508V9R@2EUID0UIFE08R8R02DU9@00P2F
UYH01@1cLg<0De=C05=CD`2;Rh/0M7Ad0080DE5A00@0@D5106IVIP1VIVH0MgMg0P1kNg/01@1]KFd0
LW9b04U9B@19BDT0D51@0080GemO00D0H61P07emO@1mOGd0^;Rh0:NWY`0208>3P`040;Zj^P20P800
P82008N7Q`80Shn?00D0L71`0:ZZZP2`/;00/;2`07IfMP0209>CT`05065QH@1aLG40VYZJ09ZJVP3C
dm<00P2f][H01@2JVYX0HV9R069RHP2QXJ40VYZJ0080UYJF00@0QhN704];B`1;Bd/0O7al0P2ATI40
1@2][Jd0[:b/0:n_[`2_[jl0Xj>S0080R8R800D0RXZ:0<S8b02^[Zh0[Zj^09ZJVP0208^;R`050<O7
a`3<c<`0c<c<08n?S`28R8P00P1fMWH0101_Kfl0TI6A096AT@2UYJD209:BTP0508V9R@32`/80/;2`
0;2`/02ATI400P20P8001@1cLg<0^;Rh0;Bd]02d];@0[Zj^0080>c/k00D0IFEU0=cLg03Lg=`0VIVI
09FEU@02092@T00406m_K`1lO7`0O7al0<30`080_kno00D0YJFU07MgM`28R8P0R8R808>3P`0208:2
PP0507MgM`2KVi/0Vi^K0:JVYP1^KVh00P2BTY801@1>CTh0DU9B059BDP0m?Cd0ATI60080H61P00@0
NGUi08N7Q`27QhL0M7Ad0P1LG5`01@1YJFT0QhN708j>SP2>SXh0FEUI0080G5aL00D0BTY:05IFEP1F
EUH0MGEe08J6QP0208F5Q@050:VYZ@1_Kfl0Kfm_07IfMP1mOGd00P2DU9@0101SHf<0@D510451@@1S
Hf<205EEE@0306ATI?oooooooooo00Sooooo000:ooooo`040:ZZZP2WYjL0YjNW09fMW@80KVi^00D0
=cLg08^;R`2LW9`0W9bL0:2PX0050:NWY`050:b/[02^[Zh0[Zj^0:j^[P2ZZZX00P2/[:`01@2XZ:P0
MWIf06=SH`1SHf<0T92@0080S8b<00D0W9bL08>3P`23Ph<0Q8B409ZJVP0209fMW@0509FEU@2=SHd0
SHf=07QhN02;Rh/00P2=SHd01@1QHF40HV9R069RHP2QXJ40YZJV0080YjNW00@0YJFU0::RXP2RXZ80
YZJV0P2[Zj/00`2^[Zh0/K6a0;6a/@020;6a/@80/[:b00@0C4a<09>CT`2XZ:P0Z:RX0`2OWil01@2I
VIT0Zj^[0:^[Z`2^[Zh0[:b/0080YZJV00D0XZ:R0:ZZZP2ZZZX0X:2P0:BTY00203`l?0040:JVYP2Z
ZZX0ZZZZ0:n_[`80Z:RX0P2UYJD20:b/[0050:^[Z`2^[Zh0[Zj^0;2`/02a/K400`2b/[820492@P05
09nOW`2XZ:P0/[:b0;:b/P2_[jl00P2a/K401@2h^;P0/K6a0;6a/@2b/[80[:b/0080YJFU00D0Z:RX
0:b/[02/[:`0W9bL08F5Q@020;Bd]0040;Rh^02ZZZX0ZZZZ0:FUY@80/K6a00D0[Zj^0;Jf]P2c/k<0
/k>c0;bl_0020;Zj^P050;6a/@2^[Zh0EUIF05IFEP2[Zj/00P2c/k<01@2i^KT0]kNg0;Zj^P2j^[X0
^k^k0080^[Zj00D0^;Rh0;6a/@2a/K40YjNW0:BTY0020:j^[P05071`L01TI6@0I6AT08f=S@2GUiL0
0P2RXZ800`2/[:`0/;2`0;2`/0030:j^[P050;:b/P2a/K40/k>c0;>c/`2g]kL00P2^[Zh00`1QHF7o
ooooooooo`0?ooooo`04069RHP1lO7`0O7al07emO@80BTY:00D0QHF509ZJVP2JVYX0TI6A09VIV@02
09BDU00507YjNP1ADE40DE5A07alO01^KVh00P1PH600101<C4`0L71`071`L02=SHd208n?S`0507Yj
NP1iNGT0BDU904U9B@1GEeL00P1[Jf/01@1XJ6P0QHF508F5Q@2c/k<0WIfM0080Ogmo00@0_kno08^;
R`2;Rh/0Shn?0P22PX801@1`L700WinO0:BTY02TY:@0OWin0080QXJ600D0Hf=S06a/K02RXZ80XZ:R
0=GEe@020:VYZ@050:6QX@1WIfL0IfMW09ZJVP2WYjL00P20P8001023Ph<0CTi>04i>CP21PH4209FE
U@050:FUY@2VYZH0_;bl0;bl_02RXZ800P2BTY801@1/K6`0^[Zj0:NWY`2WYjL0SXj>0080Ph>30`2o
_kl01@21PH40N7Qh07AdM01dM7@0JVYZ0080Ph>300D0TY:B08j>SP2>SXh0R8R80;fm_@020:VYZ@05
08:2PP1kNg/0Ng]k06IVIP2j^[X00P2^[Zh0102YZJT09RHV02HV9P1]KFd20=kNgP0508B4Q02RXZ80
PX:208:2PP1YJFT00P1`L7001@2/[:`0YZJV0:JVYP2JVYX0QHF50080Ogmo00@0S8b<07UiN@1iNGT0
K6a/0P23Ph<01@2PX:00LG5a09VIV@2IVIT0GUiN0080K6a/00D0@41004m?C`1QHF40HF5Q08J6QP02
09BDU00507EeM@1QHF40HF5Q069RHP2<S8`00P2QXJ40101DE5@0GEeM05eMG@1FEUH206QXJ00507in
OP1mOGd0Ph>308>3P`2_[jl00P1eMGD01@1jNWX0Ph>308V9R@29RHT0MGEe0080EUIF00@0KVi^06EU
I@1UIFD0GUiN2_ooool000[ooooo00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH01@1QHF40Z:RX09jNWP2N
WYh0RXZ:0080V9RH00D0X:2P09fMW@2MWId0WYjN0:6QX@020:BTY00509nOW`2TY:@0Y:BT0:>SX`28
R8P00P1XJ6P0102IVIT0VYZJ09ZJVP2RXZ8208b<S00508V9R@2?Shl0VYZJ09ZJVP2?Shl00P2>SXh0
1@2=SHd0UiNG096AT@2ATI40J6QX0080Q8B400D0Y:BT0:VYZ@2UYJD0YJFU0:6QX@0209jNWP0509bL
W02MWId0WIfM09nOW`2SXj<00P2VYZH01@2ZZZX0/[:b0;:b/P1XJ6P0VIVI0080ZJVY00@0WYjN09NG
U`2GUiL0SHf=0P2VYZH01@2ZZZX0YjNW0:VYZ@2YZJT0VIVI0080YZJV00D0XJ6Q0:BTY01OGel0GemO
0:2PX0020:BTY0050:JVYP2TY:@0Y:BT092@T02JVYX00P2TY:@01@2RXZ80YJFU0:FUY@2VYZH0ZZZZ
00<0[Jf]0P0o?cl01@2TY:@0Z:RX0:j^[P2^[Zh0/[:b0080/K6a00D0[Jf]0:BTY02TY:@0WinO0:ZZ
ZP020:f][@050;:b/P2a/K40/K6a0:2PX026QXH00`2h^;P20:f][@050:^[Z`2j^[X0^[Zj0;Fe]@2l
_;`00P2g]kL01@31`L40_kno0;no_`2i^KT0/k>c0080GUiN00D0[Zj^0;Bd]02d];@0][Jf0;jn_P02
0;fm_@<0`<3000D0_[jn0;:b/P2b/[80YZJV0:NWY`020;Fe]@0507IfMP1hN7P0N7Qh0:RXZ02[Zj/0
0P2XZ:P0102[Zj/0[Jf]0:f][@2WYjL20:VYZ@80YjNW0P2ZZZX0102[Zj/0[Jf]0:f][@1VIVHAoooo
o`0405eMG@21PH40PH6107moO`80De=C00<0LW9b08b<S02<S8`00P2>SXh207inOP0506YZJP1BDU80
DU9B07emO@1OGel00P1VIVH0101GEeL0Ng]k07]kN`28R8P209NGU`0507IfMP20P800G5aL05aLG01O
Gel00P1fMWH01@1WIfL0RXZ:08Z:RP2a/K40XJ6Q0080RXZ:00<0^k^k08:2PP22PX800`21PH401@1`
L700W9bL0;Fe]@2e]KD0RHV90080W9bL00D0CTi>065QH@2HV9P0V9RH0<S8b0020:VYZ@0509RHV01`
L700L71`09NGU`2a/K400P22PX80101`L700DU9B059BDP1bLW8209NGU`0508n?S`2TY:@0^[Zj0;Zj
^P2ZZZX00P2FUYH01@1mOGd0_;bl09:BTP2BTY80Shn?0080SHf=00D0]kNg0<O7a`37alL0S8b<07Ad
M00207emO@0406i^KP2BTY80TY:B09^KV`80W9bL00D0QXJ60;jn_P2/[:`0[:b/08:2PP0207AdM005
05mOG`2g]kL0Xj>S0:>SX`2XZ:P00P0^;Rh01@1]KFd0e=CD0=CDe01kNg/0UiNG0080PH6100@0KFe]
07=cL`1cLg<0_[jn0P2o_kl01@2WYjL0^KVi07EeM@1eMGD0SXj>0080RXZ:00D0PH610820P020P800
Ph>308^;R`0209RHV00506a/K01NGUh0GUiN03dm?@1@D5000P1JFUX0101XJ6P0Rh^;08^;R`26QXH2
06MWI`0505eMG@27QhL0OWin07inOP1HF5P00P1EEED01@17AdL0G5aL05aLG01_Kfl0NGUi0080Rh^;
00@0[Zj^07alO01lO7`0Ogmo101iNGT204Q8B0<0GemO00<0KFe]ooooooooool02?ooool000[ooooo
00@0Zj^[0:BTY02TY:@0ZZZZ0P1VIVH01@1QHF40Z:RX09jNWP2NWYh0RXZ:0080V9RH00D0X:2P09fM
W@2MWId0WYjN0:6QX@020:BTY00509nOW`2TY:@0Y:BT0:>SX`28R8P00P1XJ6P0102IVIT0VYZJ09ZJ
VP2RXZ8208b<S00508V9R@2?Shl0VYZJ09ZJVP2?Shl00P2>SXh01@2=SHd0UiNG096AT@2ATI40J6QX
0080Q8B400D0Y:BT0:VYZ@2UYJD0YJFU0:6QX@0209jNWP0509bLW02MWId0WIfM09nOW`2SXj<00P2V
YZH01@2ZZZX0/[:b0;:b/P1XJ6P0VIVI0080ZJVY00@0WYjN09NGU`2GUiL0SHf=0P2VYZH01@2ZZZX0
YjNW0:VYZ@2YZJT0VIVI0080YZJV00D0XJ6Q0:BTY01OGel0GemO0:2PX0020:BTY0050:JVYP2TY:@0
Y:BT092@T02JVYX00P2TY:@01@2RXZ80YJFU0:FUY@2VYZH0ZZZZ00<0[Jf]0P0o?cl01@2TY:@0Z:RX
0:j^[P2^[Zh0/[:b0080/K6a00D0[Jf]0:BTY02TY:@0WinO0:ZZZP020:f][@050;:b/P2a/K40/K6a
0:2PX026QXH00`2h^;P20:f][@050:^[Z`2j^[X0^[Zj0;Fe]@2l_;`00P2g]kL01@31`L40_kno0;no
_`2i^KT0/k>c0080GUiN00D0[Zj^0;Bd]02d];@0][Jf0;jn_P020;fm_@<0`<3000D0_[jn0;:b/P2b
/[80YZJV0:NWY`020;Fe]@0507IfMP1hN7P0N7Qh0:RXZ02[Zj/00P2XZ:P0102[Zj/0[Jf]0:f][@2W
YjL20:VYZ@80YjNW0P2ZZZX0102[Zj/0[Jf]0:f][@1VIVHAooooo`0405eMG@21PH40PH6107moO`80
De=C00<0LW9b08b<S02<S8`00P2>SXh207inOP0506YZJP1BDU80DU9B07emO@1OGel00P1VIVH0101G
EeL0Ng]k07]kN`28R8P209NGU`0507IfMP20P800G5aL05aLG01OGel00P1fMWH01@1WIfL0RXZ:08Z:
RP2a/K40XJ6Q0080RXZ:00<0^k^k08:2PP22PX800`21PH401@1`L700W9bL0;Fe]@2e]KD0RHV90080
W9bL00D0CTi>065QH@2HV9P0V9RH0<S8b0020:VYZ@0509RHV01`L700L71`09NGU`2a/K400P22PX80
101`L700DU9B059BDP1bLW8209NGU`0508n?S`2TY:@0^[Zj0;Zj^P2ZZZX00P2FUYH01@1mOGd0_;bl
09:BTP2BTY80Shn?0080SHf=00D0]kNg0<O7a`37alL0S8b<07AdM00207emO@0406i^KP2BTY80TY:B
09^KV`80W9bL00D0QXJ60;jn_P2/[:`0[:b/08:2PP0207AdM00505mOG`2g]kL0Xj>S0:>SX`2XZ:P0
0P0^;Rh01@1]KFd0e=CD0=CDe01kNg/0UiNG0080PH6100@0KFe]07=cL`1cLg<0_[jn0P2o_kl01@2W
YjL0^KVi07EeM@1eMGD0SXj>0080RXZ:00D0PH610820P020P800Ph>308^;R`0209RHV00506a/K01N
GUh0GUiN03dm?@1@D5000P1JFUX0101XJ6P0Rh^;08^;R`26QXH206MWI`0505eMG@27QhL0OWin07in
OP1HF5P00P1EEED01@17AdL0G5aL05aLG01_Kfl0NGUi0080Rh^;00@0[Zj^07alO01lO7`0Ogmo101i
NGT204Q8B0<0GemO00<0KFe]ooooooooool02?ooool000[ooooo00@0[jn_0:VYZ@2YZJT0[:b/0P1M
GEd01@17AdL0YJFU09nOW`2OWil0SHf=0080TI6A00D0XZ:R0:JVYP2VYZH0YjNW0:BTY0020:2PX005
09jNWP2WYjL0YjNW0:BTY02<S8`00P1UIFD0102QXJ40XZ:R0::RXP2UYJD209nOW`0509ZJVP2<S8`0
S8b<08b<S02IVIT00P22PX801@1hN7P0QhN708f=S@2=SHd0JFUY0080Q8B400D0Xj>S09^KV`2QXJ40
XJ6Q09jNWP0209VIV@0508J6QP29RHT0RHV909^KV`2OWil00P2KVi/01@2VYZH0[:b/0:b/[01ZJVX0
W9bL0080Z:RX0`2SXj<01@2ATI40XZ:R0::RXP2QXJ40YJFU0080Zj^[00D0XZ:R0:FUY@2UYJD0Xj>S
09fMW@0205eMG@030::RXP2MWId0WIfM00<0VYZJ00D0U9BD09ZJVP2GUiL0UiNG08f=S@020:2PX005
0:BTY02VYZH0Z:RX0:RXZ02][Jd00P1>CTh01@2TY:@0XZ:R0:BTY02TY:@0[Jf]0080[:b/00D0[Zj^
0:FUY@2UYJD0XZ:R0:n_[`020;2`/0<0[Jf]00D0X:2P08B4Q02h^;P0^;Rh0;bl_0020;:b/P050:j^
[P2f][H0][Jf0;Jf]P2n_[h00P2k^k/01@32`/80_Kfm0;fm_@2l_;`0]kNg0080Kfm_0`2b/[801@2k
^k/0`/;20;bl_02l_;`0_[jn0080_Kfm00D0^k^k0:^[Z`2[Zj/0XJ6Q0:VYZ@020;>c/`0506QXJ01a
LG40LG5a0:2PX02VYZH00P2ZZZX0102YZJT0YZJV0:JVYP2NWYh209fMW@050:2PX02QXJ40Z:RX0:RX
Z02SXj<00P2XZ:P00`1gMgOoooooooooo`0?ooooo`0406EUI@2<S8`0S8b<08B4Q080DU9B00D0O7al
0:2PX02PX:00WIfM09>CT`0208R8R00507UiN@1QHF40HF5Q07alO01ZJVX00P1VIVH0101JFUX0Jf][
06][J`1cLg<208>3P`0504m?C`20P800FUYJ05YJFP1=CDd00P1_Kfl01@1SHf<0RXZ:08Z:RP2][Jd0
VYZJ0080QXJ600@0/;2`08>3P`23Ph<0T92@0P1oOgl01@1UIFD0Shn?0:b/[02/[:`0UYJF0080WinO
00D0EUIF06e]K@2_[jl0[jn_0<g=c@020;Ng]`050;Fe]@1gMgL0MgMg09RHV030`<000P1oOgl0101g
MgL0D51@051@D024Q8@20:>SX`0509^KV`2c/k<0a<C40<C4a02`/;000P2/[:`01@22PX80bLW909jN
WP2NWYh0SHf=0080TY:B00D0ZZZZ0;bl_02l_;`0R8R8061PH00207=cL`0406UYJ@1mOGd0OGem096A
T@80VIVI00D0Shn?0<;2`P2VYZH0YZJV07emO@0207YjNP0505QHF02j^[X0YjNW0:NWY`2`/;000P0n
?Sh01@1]KFd0g=cL0=cLg025QHD0XJ6Q0080MgMg0`1aLG401@2l_;`0^KVi0;Vi^@2WYjL0/[:b0080
Rh^;00@0WYjN08B4Q024Q8@0IfMW0P1nOWh01@1dM7@0UYJF09BDU02DU9@0JVYZ0080BDU900D0=CDe
04Q8B01JFUX0FUYJ05IFEP0207UiN@0507inOP1ZJVX0JVYZ05eMG@2;Rh/00P2=SHd0101UIFD0J6QX
06QXJ01`L70206m_K`0507alO02DU9@0Ti>C09>CT`2c/k<00P27QhL208>3P`80QXJ600@0JFUY04e=
C@1=CDd0HF5Q0P1GEeL00`1[Jf_oooooooooo`08ooooo`002_ooool30;Rh^0050;Jf]P1bLW80LW9b
0451@@2MWId00P2SXj<0102PX:00Xj>S0:>SX`2MWId209nOW`050:FUY@2XZ:P0[Zj^0:j^[P2/[:`0
0P2WYjL01@2QXJ40Q8B406=SH`1SHf<0Ti>C0080XJ6Q00D0YZJV0:BTY02TY:@0XJ6Q09nOW`0209fM
W@0509ZJVP29RHT0RHV907EeM@1kNg/00P2IVIT01@1UIFD0Q8B408B4Q02RXZ80W9bL0080WinO00@0
WIfM0:6QX@2QXJ40S8b<0P24Q8@01@1nOWh0R8R808Z:RP2:RXX0XZ:R0080UIFE00D0ADE509JFUP2H
V9P0V9RH08B4Q00209RHV00509^KV`2ZZZX0ZZZZ0:RXZ02WYjL00P2VYZH01@2MWId0WinO09nOW`2N
WYh0VYZJ0080AdM700<0PH6108F5Q@25QHD00`1lO7`01@1iNGT0Q8B408J6QP26QXH0Ti>C0080VYZJ
00D0WinO0:NWY`2XZ:P0Z:RX0:ZZZP0204i>CP80WinO0P2VYZH0102/[:`0ZZZZ0:ZZZP2UYJD209ZJ
VP0509FEU@2HV9P0WYjN09jNWP2QXJ400P2LW9`01@1nOWh0N7Qh0;2`/02`/;00/[:b0080Y:BT00D0
XJ6Q0;Bd]02d];@0^KVi0;^k^`020;Ng]`050;Vi^@2m_Kd0_Kfm0;Vi^@2e]KD00P1aLG401@2PX:00
Xj>S0:>SX`2c/k<0]kNg00<0^;Rh0P2c/k<01@2b/[80Xj>S0:>SX`2GUiL0Xj>S0080[jn_00@0Fe]K
06ATI01TI6@0Zj^[0`2UYJD0102VYZH0Xj>S0:>SX`2LW9`309nOW`0409VIV@2NWYh0WYjN0:JVYP80
X:2P00<0Ph>3ooooooooool03oooool0101`L700SHf=08f=S@1lO7`2055AD@05071`L02BTY80TY:B
09:BTP2IVIT00P2BTY80101mOGd0GemO05mOG`1hN7P306EUI@04051@D01DE5@0E5AD04=3@`80PX:2
00D0Jf][07QhN012@T80@T9203Ph>00206YZJP0505eMG@1cLg<0Lg=c0:JVYP2MWId00P1kNg/0102]
[Jd0Ph>308>3P`22PX820861P@0506e]K@2DU9@0/K6a0;6a/@2;Rh/00P2FUYH01@1ADE40E5AD092@
T02@T900YZJV0080UYJF00D0UIFE06i^KP1^KVh0OWin0::RXP0207QhN00407UiN@1CDe<0De=C08^;
R`80][Jf00D0UIFE0:n_[`35aLD0aLG50:BTY00209bLW00508N7Q`3Hf=P0[Jf]0:f][@2?Shl00P2@
T9001@2i^KT0d=3@0=3@d02SXj<0Ng]k0080Ogmo00@0MWIf08b<S02<S8`0NWYj0P2?Shl01@23Ph<0
Z:RX09JFUP2FUYH0Lg=c0080IFEU00D0CDe=0:ZZZP2f][H0][Jf0:j^[P0204=3@`0506m_K`3Jf]X0
f][J07UiN@2GUiL00P1eMGD0101/K6`0Jf][06][J`2c/k<20;no_`050:BTY02CTi<0TY:B09:BTP2:
RXX00P2EUID01@1_Kfl0UYJF09JFUP1_Kfl0YZJV0080UiNG00D0NWYj05UIF@1IFET0>c/k055AD@02
04m?C`04065QH@1]KFd0KFe]06a/K080Kfm_00D0I6AT08Z:RP24Q8@0Q8B4075aL@0206e]K@05069R
HP24Q8@0Q8B40861P@2<S8`00P27QhL01@2f][H0P8200820P023Ph<0QXJ60080U9BD00@0Jf][0492
@P12@T80EeMG0P1PH6000`1DE5Coooooooooo`08ooooo`002_ooool0101VIVH0JFUY06UYJ@1TI6@2
05ADE00503lo?`1@D500GUiN05iNGP1KFe/00P1WIfL01@1NGUh0A4A404A4A011@D40BTY:00<0Bd];
0P0/;2`01@0[:b/0;Rh^02l_;`0_;bl0<c<c0080@D5100D0Bd];05YJFP1JFUX0Cdm?03dm?@0203@d
=00503Xj>P0i>CT0>CTi05UIF@1@D5000P1RHV801@14A4@0Fe]K05]KF`1YJFT0IfMW0080Fe]K00@0
CDe=0410@010@400=cLg0P0l?3`00`19BDT0Cdm?055AD@02055AD@80=CDe00D0:2PX03`l?010@400
@41003hn?P0203dm?@050410@01=CDd0CDe=03Ti>@0a<C400P0n?Sh01@0o?cl0@4100410@012@T80
?3`l0080=3@d00@0<30`03/k>`0k>c/0<30`0P0f=SH01@0_;bl0;Rh^02@T900T92@0<S8b0080>c/k
00D0De=C04Q8B01?Cdl0Cdm?04U9B@0202h^;P0504Q8B01=CDd0EEEE05EEE@1IFET00P1<C4`01@1A
DE40<S8b038b<P14A4@0ATI60080FEUI00D0Fe]K05mOG`1OGel0K6a/06IVIP02061PH00406ATI01K
Fe/0Fe]K04I6AP80?clo00D0=3@d038b<P1=CDd0CDe=04Y:BP02059BDP05051@D01CDe<0BTY:04Y:
BP19BDT00P1BDU801@1MGEd0F5QH05]KF`1KFe/0EEEE0080IVIV00D0GemO065QH@1QHF40F5QH06YZ
JP0206][J`0504Y:BP0c<c<0<c<c04a<C01;Bd/00P13@d<01012@T80@D510451@@1>CTh205MGE`05
04m?C`1OGel0De=C05=CD`1>CTh00P18B4P00`0i>CWoooooooooo`0?ooooo`04071`L028R8P0R8R8
09>CT`80FEUI00D0Ogmo09JFUP2FUYH0UYJF09NGU`0208f=S@0507emO@1KFe/0Fe]K06i^KP1`L700
0P1_Kfl0101fMWH0Ph>308>3P`1YJFT20820P00506a/K01YJFT0ADE504E5A@0f=SH00P1bLW801@1c
Lg<0S8b<08b<S02WYjL0S8b<0080L71`00<0];Bd09BDU02DU9@00`28R8P01@1SHf<0Shn?0;>c/`2c
/k<0TI6A0080V9RH00D0GemO06=SH`2/[:`0[:b/0;Fe]@020;>c/`050:FUY@24Q8@0Q8B408J6QP2a
/K400P20P800101jNWX0D51@051@D024Q8@209nOW`0508f=S@2n_[h0aLG50<G5a@2RXZ800P2GUiL0
1@21PH40f=SH0:f][@2][Jd0V9RH0080Vi^K00D0^[Zj0<o?c`3?cll0ZZZZ07IfMP0207MgM`0406IV
IP2CTi<0Ti>C0861P@80VIVI00D0SXj>0:j^[P2VYZH0YZJV092@T00206i^KP0505IFEP36a/H0^[Zj
0;Zj^P2_[jl00P1<C4`01@1[Jf/0g]kN0=kNgP1fMWH0Zj^[0080RHV900@0K6a/06QXJ01XJ6P0ZJVY
0P36a/H01@2[Zj/0O7al092@T02@T900SHf=0080TY:B00D0LW9b09>CT`2CTi<0J6QX0:VYZ@020:>S
X`0507=cL`1:BTX0BTY:03Lg=`1<C4`00P1;Bd/0101iNGT0IFEU06EUI@1XJ6P206][J`0506IVIP22
PX80NWYj07YjNP1YJFT00P1/K6`01@1bLW80Ph>308>3P`2=SHd0Xj>S0080Z:RX00D0^[Zj08b<S02<
S8`0QHF507QhN00209>CT`0407inOP1FEUH0EUIF05YJFP80Fe]K00<0FEUIooooooooool02?ooool0
00[ooooo00@0IVIV06UYJ@1YJFT0I6AT0P1DE5@01@0o?cl0D51@05iNGP1NGUh0Fe]K0080IfMW00D0
GUiN04A4A014A4@0@D5104Y:BP0304];B`80;2`/00D0:b/[02h^;P0_;bl0;bl_03<c<`020451@@05
04];B`1JFUX0FUYJ04m?C`0m?Cd00P0d=3@01@0j>SX0>CTi03Ti>@1IFET0D51@0080HV9R00D0A4A4
05]KF`1KFe/0JFUY06MWI`0205]KF`0404e=C@10@400@41003Lg=`80?3`l00<0BDU904m?C`1ADE40
0P1ADE4203De=@0502PX:00l?3`0@4100410@00n?Sh00P0m?Cd01@10@400CDe=04e=C@0i>CT0<C4a
0080?Shn00D0?clo0410@010@400@T9203`l?00203@d=004030`<00k>c/0>c/k030`<080=SHf00D0
;bl_02h^;P0T92@092@T038b<P0203/k>`0505=CD`18B4P0Cdm?04m?C`19BDT00P0^;Rh01@18B4P0
CDe=05EEE@1EEED0FEUI0080C4a<00D0DE5A038b<P0b<S80A4A404I6AP0205UIF@0505]KF`1OGel0
GemO06a/K01VIVH00P1PH600101TI6@0Fe]K05]KF`16ATH203lo?`0503@d=00b<S80CDe=04e=C@1:
BTX00P1BDU801@1@D500De=C04Y:BP1:BTX0BDU90080DU9B00D0GEeM05QHF01KFe/0Fe]K05EEE@02
06IVIP0505mOG`1QHF40HF5Q05QHF01ZJVX00P1[Jf/01@1:BTX0<c<c03<c<`1<C4`0Bd];0080@d=3
00@0@T920451@@11@D40CTi>0P1GEeL01@1?Cdl0GemO05=CD`1CDe<0CTi>0080B4Q800<0>CTioooo
ooooool03oooool0101`L700R8R808R8R02CTi<205UIF@0507moO`2FUYH0UYJF09JFUP2GUiL00P2=
SHd01@1mOGd0Fe]K05]KF`1^KVh0L71`0080Kfm_00@0MWIf08>3P`23Ph<0JFUY0P20P8001@1/K6`0
JFUY04E5A@15ADD0=SHf0080LW9b00D0Lg=c08b<S02<S8`0YjNW08b<S002071`L0030;Bd]02DU9@0
U9BD00<0R8R800D0Hf=S08n?S`2c/k<0/k>c096AT@0209RHV00505mOG`1SHf<0[:b/0:b/[02e]KD0
0P2c/k<01@2UYJD0Q8B408B4Q026QXH0/K6a0080P82000@0NWYj051@D01@D500Q8B40P2OWil01@2=
SHd0_[jn0<G5a@35aLD0XZ:R0080UiNG00D0PH610=SHf02][Jd0[Jf]09RHV00209^KV`050;Zj^P3?
cll0clo?0:ZZZP1fMWH00P1gMgL0101VIVH0Ti>C09>CT`21PH4209VIV@0508j>SP2^[Zh0YZJV0:JV
YP2@T9000P1^KVh01@1FEUH0a/K60;Zj^P2j^[X0[jn_0080C4a<00D0Jf][0=kNgP3Ng]h0MWIf0:^[
Z`0208V9R@0406a/K01XJ6P0J6QX0:VYZ@80a/K600D0Zj^[07alO02@T900T92@08f=S@0209:BTP05
079bLP2CTi<0Ti>C06QXJ02YZJT00P2SXj<01@1cLg<0BTY:04Y:BP0g=cL0C4a<0080Bd];00@0NGUi
06EUI@1UIFD0J6QX0P1[Jf/01@1VIVH0PX:207YjNP1jNWX0JFUY0080K6a/00D0LW9b08>3P`23Ph<0
SHf=0:>SX`020:RXZ0050;Zj^P2<S8`0S8b<08F5Q@1hN7P00P2CTi<0101nOWh0EUIF05IFEP1JFUX2
05]KF`0305UIFOoooooooooo00Sooooo000:ooooo`040:RXZ02SXj<0Xj>S0:>SX`80XJ6Q00D0X:2P
0:>SX`2UYJD0YJFU09jNWP0209bLW00509FEU@1FEUH0EUIF069RHP2`/;000P2[Zj/01@2RXZ80ZZZZ
0:ZZZP2UYJD0YjNW0080Z:RX00<0ZJVY0;2`/02`/;000`2c/k<01@2`/;00DU9B05EEE@1EEED0T92@
0080U9BD00D0UIFE0:2PX02VYZH0YZJV0:n_[`020;2`/0050::RXP2MWId0VYZJ09ZJVP2VYZH00P2M
WId01@1LG5`0B4Q804Q8B02XZ:P0Xj>S0080X:2P00<0Z:RX0:ZZZP2ZZZX00P2TY:@20:6QX@040:BT
Y02/[:`0[:b/0:n_[`80/K6a00D0OGem02`/;020P800P82008V9R@0209>CT`0509FEU@2MWId0UYJF
09JFUP2HV9P00P2CTi<01@2KVi/0UIFE09FEU@2TY:@0UIFE0080?Cdm00D0GemO06EUI@1UIFD0K6a/
06e]K@0207IfMP0508F5Q@2CTi<0Ti>C09VIV@2BTY800P29RHT01025QHD0Vi^K09^KV`1TI6@204a<
C0050;:b/P2e]KD0/k>c0;>c/`2[Zj/00P2c/k<01@2k^k/0_Kfm0;fm_@2m_Kd0`/;20080][Jf00D0
UiNG07alO01lO7`0FUYJ08:2PP020<_;b`050<?3``2m_Kd0_Kfm0;Ng]`2e]KD00P2g]kL00`2c/k<0
/[:b0;:b/P020;Jf]P80V9RH00<0L71`0;Jf]P2f][H00`2j^[X01@2a/K40/;2`0;Fe]@2e]KD0^;Rh
0080/k>c00D0[Zj^0;2`/02_[jl0[jn_08B4Q00203`l?0050:FUY@2NWYh0WYjN0::RXP2b/[800P2e
]KD0102c/k<0[Zj^0:j^[P2^[ZhAooooo`0407MgM`2CTi<0Ti>C09RHV080FUYJ00D0R8R809jNWP2N
WYh0XJ6Q09bLW00208j>SP0507EeM@1IFET0FEUI06][J`1XJ6P00P1RHV80101YJFT0MGEe07EeM@1/
K6`208:2PP0506IVIP1cLg<0F5QH05QHF01:BTX00P1VIVH01@1hN7P0SXj>08j>SP2ZZZX0RHV90080
OGem00@0Xj>S07]kN`1kNg/0IfMW0P1gMgL01@1JFUX0QhN70;Rh^02h^;P0UiNG0080U9BD00D0I6AT
069RHP2o_kl0_kno0;Fe]@020<C4a0050:NWY`2CTi<0Ti>C07moO`2WYjL00P25QHD0101nOWh0EEEE
05EEE@2=SHd20:VYZ@0509ZJVP33`l<0bLW90<W9b@2TY:@00P2IVIT01@20P800h>3P0:n_[`2_[jl0
XJ6Q0080X:2P00D0_kno0=;BdP3Bd]80VYZJ07EeM@0208F5Q@0406EUI@2UYJD0YJFU08>3P`80Vi^K
00D0SHf=0;2`/02YZJT0ZJVY08j>SP0206MWI`0504i>CP2g]kL0Zj^[0:^[Z`2UYJD00P1CDe<01@1J
FUX0d=3@0=3@d01^KVh0Y:BT0080P82000@0KVi^065QH@1QHF40/[:b0P3=cLd01@2b/[80Ph>308Z:
RP2:RXX0S8b<0080QXJ600D0NGUi09bLW02LW9`0HV9R09nOW`020::RXP0507=cL`18B4P0B4Q803Ph
>017AdL00P18B4P01020P800DU9B059BDP1oOgl207QhN00306QXJ028R8P0KVi^0080KVi^0P1SHf<0
1@1eMGD0V9RH09RHV02FUYH0Rh^;0080UYJF00D0`<3009>CT`2CTi<0S8b<08n?S`020:>SX`0409BD
U01[Jf/0Jf][06YZJP<0IFEU2_ooool000[ooooo00@0YZJV09fMW@2MWId0VYZJ0P2@T90208b<S080
WIfM00@0UYJF08j>SP2>SXh0Shn?0P1MGEd01@1[Jf/0[Jf]0:j^[P2^[Zh0XZ:R0080Xj>S00D0XJ6Q
0::RXP2RXZ80XZ:R0:NWY`020:VYZ@050;>c/`2d];@0];Bd0:n_[`1oOgl00P1WIfL01@2GUiL0Ng]k
07]kN`1iNGT0W9bL0080X:2P00D0WinO09VIV@2IVIT0VIVI08b<S00208n?S`0408Z:RP28R8P0R8R8
065QH@80=SHf00D0UYJF0:2PX02IVIT0VIVI09fMW@020:6QX@0509fMW@2NWYh0R8R808R8R02SXj<0
0P2ZZZX30:j^[P050861P@15ADD0YjNW0:NWY`2SXj<00P2VYZH01@2TY:@0YZJV0:JVYP2VYZH0Z:RX
0080YZJV00D0YjNW08^;R`2;Rh/0XZ:R0:VYZ@0205YJFP0506EUI@1bLW80LW9b07IfMP23Ph<00P1k
Ng/01@1aLG40O7al07alO025QHD0Q8B40080Ng]k00@0PH6107YjNP1jNWX0HF5Q0P0o?cl01@2NWYh0
[Zj^0:j^[P2^[Zh0Xj>S0080[Jf]00D0/K6a0;:b/P2d];@0];Bd0;Jf]P030;Bd]080]KFe00@0KFe]
09:BTP2k^k/0^k^k0`2h^;P01@2d];@0/K6a0;6a/@2a/K40[Jf]0080/K6a00<0/;2`0:VYZ@1_Kfl0
0P1_Kfl20;Ng]`050;Jf]P2e]KD0]KFe0;Bd]02g]kL00P2e]KD01@2g]kL0];Bd0;Bd]02_[jl0[Jf]
0080[Zj^00@0WIfM059BDP1BDU80XZ:R0P2SXj<01@2VYZH0/k>c0;6a/@2a/K40[Zj^0080[Jf]00<0
/[:booooooooool03oooool0101bLW80QhN708N7Q`20P80204e=C@0508R8R02JVYX0VYZJ09NGU`2?
Shl00P2BTY801@1gMgL0GUiN05iNGP1[Jf/0L71`0080Jf][00@0Hf=S07UiN@1iNGT0G5aL0P20P800
1@1mOGd0DE5A02d];@0];Bd0DE5A0080I6AT00D0MgMg08J6QP26QXH0/[:b08b<S00208J6QP040:n_
[`2EUID0UIFE07alO080Kfm_00D0BTY:06m_K`2RXZ80XZ:R08j>SP0208:2PP0505eMG@1@D500[Jf]
0:f][@2^[Zh00P2j^[X01@2KVi/0XZ:R0::RXP1hN7P0Vi^K0080Q8B400@0M7Ad05]KF`1KFe/0P820
0P2/[:`01@2GUiL0_Kfm0<71`@31`L40ZJVY0080Vi^K00D0OGem0=gMg@2[Zj/0Zj^[09RHV00209jN
WP050;Ng]`3@d=00d=3@09nOW`1]KFd00P1[Jf/0101FEUH0UiNG09NGU`22PX8209VIV@0508^;R`2a
/K40[Jf]0:f][@2LW9`00P1UIFD01@1;Bd/0_[jn0;Ng]`2g]kL0`L710080De=C00D0G5aL0=CDe03D
e=@0JVYZ0::RXP0207alO00406EUI@1SHf<0Hf=S09VIV@80[jn_00D0WYjN08N7Q`22PX80PX:20820
P00209FEU@0507UiN@2TY:@0Y:BT061PH02YZJT00P2KVi/01@1/K6`0@4100410@00e=CD0B4Q80080
CTi>00@0MWIf05]KF`1KFe/0LG5a0P1eMGD01@1iNGT0UYJF07EeM@1eMGD0NGUi0080HV9R00D0JFUY
0820P020P800LG5a07]kN`0207UiN@0509ZJVP1dM7@0M7Ad07moO`1iNGT00P2FUYH0102=SHd0LG5a
075aL@1gMgL207YjNP0307UiNOoooooooooo00Sooooo000:ooooo`040:JVYP2MWId0WIfM09ZJVP80
T92@0P2<S8`209fMW@0409JFUP2>SXh0SXj>08n?S`80GEeM00D0Jf][0:f][@2^[Zh0[Zj^0::RXP02
0:>SX`050:6QX@2RXZ80XZ:R0::RXP2WYjL00P2YZJT01@2c/k<0];Bd0;Bd]02_[jl0Ogmo0080IfMW
00D0UiNG07]kN`1kNg/0NGUi09bLW0020:2PX00509nOW`2IVIT0VIVI09VIV@2<S8`00P2?Shl0102:
RXX0R8R808R8R01QHF4203Hf=P0509JFUP2PX:00VIVI09VIV@2MWId00P2QXJ401@2MWId0WYjN08R8
R028R8P0Xj>S0080ZZZZ0`2^[Zh01@21PH40ADE50:NWY`2WYjL0Xj>S0080YZJV00D0Y:BT0:JVYP2V
YZH0YZJV0:RXZ0020:JVYP050:NWY`2;Rh/0Rh^;0::RXP2YZJT00P1JFUX01@1UIFD0LW9b079bLP1f
MWH0Ph>30080Ng]k00D0LG5a07alO01lO7`0QHF508B4Q00207]kN`040861P@1jNWX0NWYj065QH@80
?clo00D0WYjN0:j^[P2^[Zh0[Zj^0:>SX`020:f][@050;6a/@2b/[80];Bd0;Bd]02f][H00`2d];@2
0;Fe]@0406e]K@2BTY80^k^k0;^k^`<0^;Rh00D0];Bd0;6a/@2a/K40/K6a0:f][@020;6a/@030;2`
/02YZJT0Kfm_0080Kfm_0P2g]kL01@2f][H0]KFe0;Fe]@2d];@0]kNg0080]KFe00D0]kNg0;Bd]02d
];@0[jn_0:f][@020:j^[P0409fMW@1BDU80DU9B0::RXP80Xj>S00D0YZJV0;>c/`2a/K40/K6a0:j^
[P020:f][@030;:b/_oooooooooo00oooooo00@0LW9b08N7Q`27QhL0P8200P1=CDd01@28R8P0VYZJ
09ZJVP2GUiL0Shn?0080TY:B00D0MgMg05iNGP1NGUh0Jf][071`L00206][J`0406=SH`1iNGT0NGUi
05aLG080P82000D0OGem055AD@0];Bd0;Bd]055AD@0206ATI00507MgM`26QXH0QXJ60;:b/P2<S8`0
0P26QXH0102_[jl0UIFE09FEU@1lO7`206m_K`0504Y:BP1_Kfl0XZ:R0::RXP2>SXh00P22PX801@1M
GEd0D51@0:f][@2][Jd0[Zj^0080^[Zj00D0Vi^K0::RXP2RXZ80N7Qh09^KV`0208B4Q00407AdM01K
Fe/0Fe]K0820P080[:b/00D0UiNG0;fm_@31`L40`L710:VYZ@0209^KV`0507emO@3MgMd0Zj^[0:^[
Z`2HV9P00P2NWYh01@2g]kL0d=3@0=3@d02OWil0KFe]0080Jf][00@0EUIF09NGU`2GUiL0PX:20P2I
VIT01@2;Rh/0/K6a0:f][@2][Jd0W9bL0080IFEU00D0Bd];0;jn_P2g]kL0]kNg0<71`@0205=CD`05
05aLG03De=@0e=CD06YZJP2RXZ800P1lO7`0101UIFD0Hf=S06=SH`2IVIT20:n_[`0509jNWP27QhL0
PX:208:2PP20P8000P2EUID01@1iNGT0Y:BT0:BTY01PH600ZJVY0080Vi^K00D0K6a/0410@010@400
=CDe04Q8B00204i>CP0407IfMP1KFe/0Fe]K075aL@80MGEe00D0NGUi09JFUP1eMGD0MGEe07UiN@02
069RHP0506UYJ@20P800P820075aL@1kNg/00P1iNGT01@2JVYX0M7Ad07AdM01oOgl0NGUi0080UYJF
00@0SHf=075aL@1aLG40MgMg0P1jNWX00`1iNGWoooooooooo`08ooooo`002_ooool0102XZ:P0Xj>S
0:>SX`2PX:0309:BTP0408:2PP2DU9@0U9BD09FEU@80Rh^;00D0Q8B4065QH@1QHF40IVIV0:^[Z`02
0:b/[0050::RXP2MWId0WIfM09fMW@2JVYX00P2TY:@0102PX:00YZJV0:JVYP2ZZZX20;6a/@050:^[
Z`20P800J6QX06QXJ02CTi<00P21PH401@26QXH0RXZ:08f=S@2=SHd0[:b/0080ZJVY00D0[Zj^0:^[
Z`2/[:`0[:b/0:NWY`0209RHV00506YZJP0];Bd0;Bd]09ZJVP2WYjL00P2TY:@01@2ZZZX0YZJV0:JV
YP2SXj<0WinO0080T92@00@0Y:BT0:f][@2][Jd0/k>c0P2^[Zh01028R8P0B4Q80:VYZ@2YZJT30;Bd
]0050:ZZZP2SXj<0YjNW0:NWY`2TY:@00P2VYZH01@2PX:00OWin07inOP2PX:00Zj^[0080GEeM00D0
IVIV07moO`1oOgl0Rh^;08V9R@0207moO`<0OGem00D0Ogmo08N7Q`25QHD0QHF508R8R00207UiN@05
06QXJ012@T80@T9208:2PP1lO7`00P1YJFT01@1]KFd0WinO09nOW`2ZZZX0[Zj^0080Zj^[0`2_[jl3
0:f][@0505mOG`2BTY80/k>c0;>c/`2a/K400P2b/[801@2ZZZX0Zj^[0:ZZZP2ZZZX0ZJVY0080YJFU
00D0Y:BT0:FUY@1IFET0FEUI07inOP020<[:bP050<C4a02m_Kd0_Kfm0;Bd]02f][H00P2d];@00`2f
][H0^;Rh0;Rh^0040;>c/`040:RXZ01NGUh0GUiN09jNWP80XJ6Q00D0YjNW0:f][@2_[jl0[jn_0:RX
Z0020:b/[0030:j^[_oooooooooo00oooooo00@0Jf][096AT@2ATI40OGem0P1>CTh00`23Ph<0VYZJ
09ZJVP0209ZJVP80TI6A00D0MgMg061PH01PH600M7Ad06i^KP02059BDP04071`L01]KFd0KFe]05eM
G@80P82000D0MGEe04E5A@1FEUH0EUIF04m?C`0205ADE00507]kN`29RHT0RHV90:f][@2?Shl00P1b
LW80102/[:`0X:2P0:2PX026QXH206e]K@0505MGE`2EUID0^[Zj0;Zj^P2BTY800P23Ph<01@1WIfL0
ATI60:NWY`2WYjL0X:2P0080_Kfm00D0YJFU0:>SX`2SXj<0NWYj09JFUP0208Z:RP0407UiN@1bLW80
LW9b08^;R`80XJ6Q00D0YJFU0;Bd]02h^;P0^;Rh0:VYZ@0209:BTP0507alO03De=@0Zj^[0:^[Z`2S
Xj<00P2VYZH01@38b<P0eMGE0=GEe@2LW9`0N7Qh0080P82000@0G5aL09:BTP2BTY80QhN70P2QXJ40
1@28R8P0]kNg0:BTY02TY:@0Ti>C0080GemO00D0D51@0;fm_@2g]kL0]kNg0<o?c`0205EEE@0506m_
K`3MgMd0gMgM07EeM@2`/;000P1lO7`0101QHF40Kfm_06m_K`2[Zj/20<;2`P0509fMW@1hN7P0QHF5
08F5Q@2JVYX00P2HV9P01@1eMGD0X:2P0:2PX01MGEd0ZZZZ0080WinO00D0HV9R03`l?00l?3`0>3Ph
05UIF@0205=CD`0405MGE`1KFe/0Fe]K06IVIP80KFe]00D0G5aL08j>SP1]KFd0KFe]055AD@0207=c
L`0507emO@2IVIT0VIVI09FEU@2;Rh/00P28R8P01@2f][H0Ph>308>3P`25QHD0QXJ60080R8R800@0
OWin05IFEP1FEUH0GUiN0P1MGEd00`1cLg?oooooooooo`08ooooo`002_ooool0102UYJD0Xj>S0:>S
X`2IVIT209^KV`0508n?S`2=SHd0TI6A096AT@28R8P00P2?Shl01@2CTi<0JVYZ06YZJP1LG5`0ZZZZ
0080YjNW00D0Xj>S0:BTY02TY:@0WIfM09ZJVP0209nOW`040:2PX02YZJT0ZJVY0:ZZZP80[Zj^00D0
YJFU06YZJP1aLG40LG5a08b<S00208Z:RP0507QhN021PH40Ph>308>3P`2NWYh00P2WYjL00`2[Zj/0
[Jf]0:VYZ@020:VYZ@80XZ:R00D0JVYZ038b<P0b<S80V9RH0:j^[P020:f][@050;6a/@2/[:`0[:b/
0:b/[02UYJD00P2QXJ40102YZJT0[:b/0:b/[02`/;020:NWY`0509RHV010@400YJFU0:FUY@2RXZ80
0`2WYjL0102QXJ40TY:B09:BTP2IVIT20::RXP050:2PX02:RXX0RXZ:08f=S@2UYJD00P1ZJVX01@1g
MgL0WinO09nOW`2OWil0V9RH0080NWYj00D0KVi^07IfMP1fMWH0O7al08n?S`0209:BTP0408F5Q@26
QXH0QXJ607=cL`80JFUY00D0X:2P09jNWP2NWYh0WYjN06a/K0020820P00508Z:RP2QXJ40Xj>S0:>S
X`2KVi/00P2MWId01@2CTi<0Rh^;08^;R`0n?Sh0P8200080WinO00D0VIVI09RHV02HV9P0UYJF0:6Q
X@0209bLW0030:2PX02KVi/0Vi^K0080VIVI0P1PH6000`1bLW80_;bl0;bl_0030;bl_0050;Fe]@2_
[jl0ZJVY0:VYZ@2QXJ400P2XZ:P01@2`/;00X:2P09jNWP2NWYh0VYZJ0080EEEE00D0W9bL09jNWP2N
WYh0YJFU0:ZZZP020:f][@040:FUY@2SXj<0Xj>S0:RXZ17ooooo00@0MgMg0:2PX02PX:00OGem0P1?
Cdl01@2ATI40W9bL09bLW02PX:00UIFE0080SHf=00D0Ogmo05mOG`1OGel0Jf][07IfMP0203dm?@04
06][J`1kNg/0Ng]k06UYJ@80XJ6Q00D0QHF507MgM`1lO7`0O7al05eMG@02055AD@0508>3P`27QhL0
QhN70;:b/P2?Shl00P1/K6`0102^[Zh0XZ:R0::RXP29RHT2079bLP0505ADE026QXH0]KFe0;Fe]@2O
Wil00`1eMGD01019BDT0`L710<71`@2i^KT20<K6aP050:b/[02TY:@0Y:BT07emO@2HV9P00P2GUiL0
101fMWH0MGEe07EeM@29RHT20:FUY@050:b/[02l_;`0c/k>0<k>cP2`/;000P2CTi<01@1lO7`0emOG
0;2`/02`/;00WinO0080WIfM00D0^;Rh0=KFeP3Fe]H0TI6A079bLP020820P004065QH@2IVIT0VIVI
08N7Q`80V9RH00D0O7al0;:b/P2JVYX0VYZJ08f=S@0205]KF`0505EEE@35aLD0YjNW0:NWY`2VYZH0
0P0n?Sh01@1PH600emOG0=OGe`1dM7@0^KVi0080Ogmo00@0N7Qh07IfMP1fMWH0/k>c0P3GemL01@2U
YJD0Lg=c096AT@2ATI40Y:BT0080UiNG00D0NWYj09VIV@2IVIT0G5aL0:n_[`0209VIV@0506i^KP0j
>SX0>SXj04A4A01WIfL00P1dM7@0101KFe/0JVYZ06YZJP1dM7@207YjNP0507AdM02EUID0MGEe07Ee
M@1hN7P00P1jNWX01@1`L700WinO09nOW`25QHD0YZJV0080WYjN00D0/;2`07AdM01dM7@0MGEe08J6
QP0207QhN00407=cL`1dM7@0M7Ad07QhN080Bd];00<0LG5aooooooooool02?ooool000[ooooo00@0
IFEU05QHF01HF5P0AdM70P0i>CT00`0k>c/0@T9204Q8B00204Q8B080BDU900D0?clo02HV9P0V9RH0
;2`/061PH002075aL@0507QhN01dM7@0M7Ad06UYJ@17AdL00P19BDT0101=CDd0BDU904U9B@1?Cdl2
04Y:BP0503hn?P0/;2`0?3`l03`l?013@d<00P1;Bd/204=3@`80ATI600D0C4a<059BDP1BDU80CTi>
05=CD`02065QH@0405iNGP0n?Sh0?Shn02@T9080:b/[00@0BDU905ADE01LG5`0G5aL0`1?Cdl01@12
@T80ATI604M7A`17AdL0@d=30080B4Q800D0A4A402l_;`0_;bl0>CTi03Lg=`0204e=C@05051@D01<
C4`0C4a<03lo?`11@D400P0a<C40100`<300<c<c03<c<`11@D430492@P0404=3@`10@400@4100410
@080ATI600D0C4a<04U9B@0o?cl0?clo030`<00203Ph>00503@d=00k>c/0=cLg03Lg=`0i>CT00P0o
?cl01@0b<S80>c/k03/k>`0o?cl0=CDe0080@41000D0AdM704=3@`13@d<0;Bd]024Q8@0203Ph>004
03/k>`11@D40@D5103dm?@80>c/k00D0>CTi0410@01;Bd/0Bd];04=3@`0203lo?`0504A4A00l?3`0
8b<S02<S8`0c<c<00P0f=SH01@0e=CD0?3`l04A4A014A4@0?Cdm0080A4A400D0B4Q804U9B@19BDT0
B4Q803<c<`02038b<P0501`L700^;Rh0;Rh^03`l?00g=cL00P0f=SH01014A4@0BTY:04Y:BP1DE5@2
05UIF@0306=SH`1MGEd0CTi>0080CTi>0P16ATH00`1KFe_oooooooooo`0?ooooo`0406IVIP2IVIT0
VIVI07]kN`80Bd];00D0Ti>C09bLW02LW9`0WYjN0:6QX@0208b<S00507]kN`1KFe/0Fe]K07IfMP1i
NGT00P24Q8@0101iNGT0MgMg07MgM`1RHV8209fMW@0507]kN`1WIfL0L71`071`L01GEeL00P1>CTh0
1@1lO7`0QXJ608J6QP2c/k<0Shn?0080NWYj00@0ZJVY0:FUY@2UYJD0Rh^;0P1cLg<01@1/K6`0YJFU
0<c<c03<c<`0YjNW0080OWin00D0Ng]k04];B`2l_;`0_;bl0:j^[P020<O7a`050:NWY`2DU9@0U9BD
08F5Q@20P8000P1cLg<0101ZJVX0MGEe07EeM@22PX8209:BTP0509bLW02OWil0_[jn0;jn_P2RXZ80
0P2;Rh/01@1nOWh0f][J0;Bd]02d];@0V9RH0080WYjN00D0/;2`0=[JfP3Jf]X0U9BD07MgM`0208F5
Q@0406IVIP2BTY80TY:B08F5Q@80W9bL00D0Ogmo0:BTY02RXZ80XZ:R0:VYZ@0206ATI00505mOG`39
bLT0]kNg0;Ng]`36a/H00P16ATH01@1`L700emOG0=OGe`1fMWH0YZJV0080O7al00@0P820075aL@1a
LG40[jn_0P3@d=001@2VYZH0O7al0;2`/02`/;00[jn_0080WinO00D0QXJ60:f][@2][Jd0G5aL0;Bd
]0020:6QX@0508>3P`0i>CT0>CTi0410@01SHf<00P1]KFd0101;Bd/0KFe]06e]K@1WIfL207=cL`05
08:2PP2HV9P0Lg=c07=cL`1eMGD00P1mOGd01@21PH40XJ6Q0:6QX@2UYJD0WYjN0080R8R800D0[Zj^
06e]K@1]KFd0L71`08>3P`0207moO`0408b<S01dM7@0M7Ad06e]K@80GUiN00<0PX:2ooooooooool0
2?ooool000[ooooo00@0IFEU05QHF01HF5P0AdM70P0i>CT00`0k>c/0@T9204Q8B00204Q8B080BDU9
00D0?clo02HV9P0V9RH0;2`/061PH002075aL@0507QhN01dM7@0M7Ad06UYJ@17AdL00P19BDT0101=
CDd0BDU904U9B@1?Cdl204Y:BP0503hn?P0/;2`0?3`l03`l?013@d<00P1;Bd/204=3@`80ATI600D0
C4a<059BDP1BDU80CTi>05=CD`02065QH@0405iNGP0n?Sh0?Shn02@T9080:b/[00@0BDU905ADE01L
G5`0G5aL0`1?Cdl01@12@T80ATI604M7A`17AdL0@d=30080B4Q800D0A4A402l_;`0_;bl0>CTi03Lg
=`0204e=C@05051@D01<C4`0C4a<03lo?`11@D400P0a<C40100`<300<c<c03<c<`11@D430492@P04
04=3@`10@400@4100410@080ATI600D0C4a<04U9B@0o?cl0?clo030`<00203Ph>00503@d=00k>c/0
=cLg03Lg=`0i>CT00P0o?cl01@0b<S80>c/k03/k>`0o?cl0=CDe0080@41000D0AdM704=3@`13@d<0
;Bd]024Q8@0203Ph>00403/k>`11@D40@D5103dm?@80>c/k00D0>CTi0410@01;Bd/0Bd];04=3@`02
03lo?`0504A4A00l?3`08b<S02<S8`0c<c<00P0f=SH01@0e=CD0?3`l04A4A014A4@0?Cdm0080A4A4
00D0B4Q804U9B@19BDT0B4Q803<c<`02038b<P0501`L700^;Rh0;Rh^03`l?00g=cL00P0f=SH01014
A4@0BTY:04Y:BP1DE5@205UIF@0306=SH`1MGEd0CTi>0080CTi>0P16ATH00`1KFe_oooooooooo`0?
ooooo`0406IVIP2IVIT0VIVI07]kN`80Bd];00D0Ti>C09bLW02LW9`0WYjN0:6QX@0208b<S00507]k
N`1KFe/0Fe]K07IfMP1iNGT00P24Q8@0101iNGT0MgMg07MgM`1RHV8209fMW@0507]kN`1WIfL0L71`
071`L01GEeL00P1>CTh01@1lO7`0QXJ608J6QP2c/k<0Shn?0080NWYj00@0ZJVY0:FUY@2UYJD0Rh^;
0P1cLg<01@1/K6`0YJFU0<c<c03<c<`0YjNW0080OWin00D0Ng]k04];B`2l_;`0_;bl0:j^[P020<O7
a`050:NWY`2DU9@0U9BD08F5Q@20P8000P1cLg<0101ZJVX0MGEe07EeM@22PX8209:BTP0509bLW02O
Wil0_[jn0;jn_P2RXZ800P2;Rh/01@1nOWh0f][J0;Bd]02d];@0V9RH0080WYjN00D0/;2`0=[JfP3J
f]X0U9BD07MgM`0208F5Q@0406IVIP2BTY80TY:B08F5Q@80W9bL00D0Ogmo0:BTY02RXZ80XZ:R0:VY
Z@0206ATI00505mOG`39bLT0]kNg0;Ng]`36a/H00P16ATH01@1`L700emOG0=OGe`1fMWH0YZJV0080
O7al00@0P820075aL@1aLG40[jn_0P3@d=001@2VYZH0O7al0;2`/02`/;00[jn_0080WinO00D0QXJ6
0:f][@2][Jd0G5aL0;Bd]0020:6QX@0508>3P`0i>CT0>CTi0410@01SHf<00P1]KFd0101;Bd/0KFe]
06e]K@1WIfL207=cL`0508:2PP2HV9P0Lg=c07=cL`1eMGD00P1mOGd01@21PH40XJ6Q0:6QX@2UYJD0
WYjN0080R8R800D0[Zj^06e]K@1]KFd0L71`08>3P`0207moO`0408b<S01dM7@0M7Ad06e]K@80GUiN
00<0PX:2ooooooooool02?ooool000[ooooo00@0/[:b0:RXZ02XZ:P0Xj>S0P1JFUX01@1lO7`0TY:B
07AdM01dM7@0OGem0080UiNG00D0U9BD0:BTY02TY:@0ZZZZ08n?S`020:b/[0050:ZZZP2WYjL0YjNW
0:FUY@0i>CT00P1XJ6P01028R8P0XZ:R0::RXP2][Jd20:n_[`050:j^[P2/[:`0ZZZZ0:ZZZP2RXZ80
0P2QXJ401@2RXZ80X:2P0:VYZ@2YZJT0F5QH0080NWYj00D0YZJV0:RXZ02[Zj/0Zj^[0:>SX`020:NW
Y`050:2PX02UYJD0YJFU0:ZZZP2QXJ400P2XZ:P01@2_[jl0WYjN09jNWP16ATH0L71`0080PH6100@0
SHf=09ZJVP2JVYX0Vi^K0P2PX:000`2LW9`0XJ6Q0:6QX@020:6QX@<0VYZJ00@0UiNG04U9B@19BDT0
WinO0P2][Jd01@2_[jl0];Bd0;Bd]030`<00]kNg0080/;2`00D0[Jf]0;2`/02`/;00[Zj^0;>c/`02
0;Bd]00509FEU@1YJFT0JFUY0:BTY02^[Zh00P2[Zj/0102^[Zh0]kNg0;Ng]`2j^[X20;^k^`050;Ng
]`2f][H0];Bd0;Bd]02`/;000P2c/k<01@17AdL0HF5Q0;Vi^@2i^KT0_;bl0080^[Zj00D0[jn_0;Bd
]02d];@0^k^k0;fm_@020;Zj^P050;fm_@2l_;`0_;bl0;Zj^P2WYjL00P0m?Cd00`2k^k/0]kNg0;Ng
]`040;Zj^P030;Jf]P2d];@0];Bd00<0/K6a00D0/[:b0:f][@2UYJD0YJFU06QXJ0020::RXP050;Bd
]02`/;00];Bd0;Bd]02a/K400`2`/;020:ZZZP050:BTY02VYZH0Y:BT0:BTY02ZZZX00P1aLG400`2P
X:3oooooooooo`0?ooooo`0406e]K@2RXZ80XZ:R07]kN`80Bd];00D0UIFE09VIV@2IVIT0WYjN0:BT
Y00208^;R`0507UiN@1GEeL0EeMG07moO`1lO7`00P1gMgL0101`L700IVIV06IVIP1HF5P209FEU@05
07QhN01FEUH0Jf][06][J`1KFe/00P1EEED307YjNP050;:b/P2=SHd0QhN708N7Q`2XZ:P00P2UYJD0
1@2<S8`0I6AT06ATI01HF5P0VIVI0080c/k>00D0XZ:R07YjNP1jNWX0NGUi04I6AP020;bl_0040:BT
Y02n_[h0_[jn0:JVYP80Ogmo00D0Ng]k07inOP20P800P82007QhN00208R8R00508f=S@2<S8`0S8b<
09:BTP2f][H00P3<c<`01@2e]KD0VIVI09VIV@1hN7P0fm_K0080][Jf00@0UiNG0:2PX02PX:00^;Rh
0P3De=@01@2RXZ80MWIf08b<S02<S8`0IfMW0080UYJF00D0QhN70:6QX@2QXJ40Rh^;0:n_[`020:NW
Y`05096AT@1IFET0FEUI05iNGP2[Zj/00P2^[Zh0102k^k/0>SXj03Xj>P1jNWX20=CDe00507UiN@2e
]KD0MgMg07MgM`24Q8@00P1nOWh01@2][Jd0fm_K0=_Kf`2UYJD0NWYj0080TY:B00@0Z:RX09VIV@2I
VIT0Q8B40P2CTi<01@1JFUX0_[jn09FEU@2EUID0OWin0080=CDe00D0?Cdm05aLG01KFe/0Fe]K04a<
C00205=CD`05051@D01JFUX0FUYJ05eMG@1gMgL00P1FEUH0101[Jf/0HV9R069RHP1/K6`208V9R@05
09jNWP2OWil0R8R808R8R02d];@00P28R8P208N7Q`80LW9b00@0Shn?071`L01`L700Lg=c0P1ZJVX0
0`1mOGgoooooooooo`08ooooo`002_ooool0102ZZZX0YjNW0:NWY`2UYJD206ATI00507QhN02DU9@0
G5aL05aLG01jNWX00P29RHT01@1kNg/0TY:B09:BTP2EUID0IFEU00D0WYjN00D0WIfM02d];@1UIFD0
IFEU07YjNP020820P00509fMW@2JVYX0VYZJ09JFUP2HV9P00P2GUiL01@2ATI40U9BD09BDU02BTY80
UiNG0080Z:RX00<0IVIV08R8R028R8P00P2ZZZX20:JVYP040:FUY@2TY:@0Y:BT09bLW080XJ6Q00D0
X:2P09jNWP2VYZH0YZJV0:ZZZP020:^[Z`0505YJFP1iNGT0VIVI09VIV@2HV9P00P2OWil01@2SXj<0
YJFU0:FUY@2PX:00VYZJ0080T92@00D0SXj>08f=S@2=SHd0Shn?08Z:RP0203lo?`040:>SX`2b/[80
/[:b0;Rh^080]KFe00D0^k^k0;Bd]02`/;00/;2`0:n_[`020:b/[0050:j^[P2[Zj/0/;2`0;2`/02G
UiL00P1YJFT01@2MWId0Xj>S0:b/[02/[:`0/k>c0080[jn_00D0/k>c0;Rh^02h^;P0][Jf0;:b/P02
0:^[Z`050:b/[02^[Zh0[Zj^04e=C@22PX800P2m_Kd01035aLD0_kno0;no_`2d];@20;Ng]`050<30
`02o_kl0a<C40<C4a035aLD00P36a/H01@2n_[h0[Jf]04E5A@15ADD0];Bd0080/K6a00D0];Bd0;>c
/`2d];@0];Bd0:NWY`030:JVYP80[Zj^0P2_[jl20:VYZ@05061PH02][Jd0[Jf]0;Fe]@2][Jd00P2`
/;00102a/K40/;2`0;2`/02f][H20:b/[0050:RXZ02`/;00/K6a0;6a/@2b/[800P1iNGT00`2/[:co
ooooooooo`0?ooooo`0406YZJP2FUYH0UYJF07alO080ADE500D0RXZ:09BDU02DU9@0UYJF0:JVYP02
08>3P`0507AdM01IFET0FEUI08B4Q01gMgL00P1eMGD0101SHf<0KFe]06e]K@1HF5P208b<S00507in
OP1:BTX0G5aL05aLG01GEeL00P1<C4`01@1eMGD0LG5a075aL@2[Zj/0QXJ60080Shn?00@0XZ:R0:2P
X02PX:00Ph>30P1VIVH01@1GEeL0RHV90<O7a`37alL0WIfM0080JVYZ00D0HV9R0492@P2d];@0];Bd
09^KV`020;Vi^@050:JVYP26QXH0QXJ607alO01nOWh00P1cLg<0101OGel0P8200820P01lO7`209BD
U00508V9R@2e]KD0_Kfm0;fm_@2a/K400P2DU9@01@1oOgl0d];B0;Rh^02h^;P0ZZZZ0080XJ6Q00D0
^[Zj0<c<c03<c<`0XJ6Q07UiN@0207inOP04065QH@2EUID0UIFE092@T080X:2P00D0TI6A0:^[Z`2V
YZH0YZJV08Z:RP0205=CD`05065QH@2GUiL0ZJVY0:VYZ@3AdM400P0o?cl01@2ATI40i>CT0>CTi01n
OWh0[:b/0080NWYj00@0Ph>307YjNP1jNWX0[Jf]0P3Jf]X01@2TY:@0VYZJ08^;R`2;Rh/0[Zj^0080
Shn?00D0UiNG092@T02@T900Lg=c0<C4a0020::RXP0507moO`0m?Cd0?Cdm0410@01SHf<00P1RHV80
101OGel0IfMW06MWI`1XJ6P207EeM@0506e]K@1nOWh0H61P061PH01UIFD00P1[Jf/01@1LG5`0NGUi
07UiN@2FUYH0Rh^;0080RXZ:00D0]KFe08B4Q024Q8@0OWin09:BTP020820P00308F5Q@1dM7@0M7Ad
00<0MgMg00<0Shn?ooooooooool02?ooool000[ooooo00@0ZZZZ0:NWY`2WYjL0YJFU0P1TI6@01@1h
N7P0U9BD05aLG01LG5`0NWYj0080RHV900D0Ng]k09:BTP2BTY80UIFE06EUI@0509jNWP0509fMW@0]
;Bd0IFEU06EUI@1jNWX00P20P8001@2MWId0VYZJ09ZJVP2FUYH0V9RH0080UiNG00D0TI6A09BDU02D
U9@0TY:B09NGU`020:RXZ00306IVIP28R8P0R8R80080ZZZZ0P2VYZH0102UYJD0Y:BT0:BTY02LW9`2
0:6QX@050:2PX02NWYh0YZJV0:JVYP2ZZZX00P2[Zj/01@1JFUX0NGUi09VIV@2IVIT0V9RH0080WinO
00D0Xj>S0:FUY@2UYJD0X:2P09ZJVP02092@T00508j>SP2=SHd0SHf=08n?S`2:RXX00P0o?cl0102S
Xj<0/[:b0;:b/P2h^;P20;Fe]@050;^k^`2d];@0/;2`0;2`/02_[jl00P2/[:`01@2^[Zh0Zj^[0;2`
/02`/;00UiNG0080JFUY00D0WIfM0:>SX`2/[:`0[:b/0;>c/`020:n_[`050;>c/`2h^;P0^;Rh0;Jf
]P2b/[800P2[Zj/01@2/[:`0[Zj^0:j^[P1=CDd0PX:20080_Kfm00@0aLG50;no_`2o_kl0];Bd0P2g
]kL01@30`<00_kno0<C4a034a<@0aLG50080a/K600D0_[jn0:f][@15ADD0ADE50;Bd]0020;6a/@05
0;Bd]02c/k<0];Bd0;Bd]02WYjL00`2VYZH20:j^[P80[jn_0P2YZJT01@1PH600[Jf]0:f][@2e]KD0
[Jf]0080/;2`00@0/K6a0;2`/02`/;00][Jf0P2/[:`01@2XZ:P0/;2`0;6a/@2a/K40/[:b0080NGUi
00<0[:b/ooooooooool03oooool0101ZJVX0UYJF09JFUP1lO7`204E5A@0508Z:RP2DU9@0U9BD09JF
UP2VYZH00P23Ph<01@1dM7@0FEUI05UIF@24Q8@0MgMg0080MGEe00@0Hf=S06e]K@1]KFd0F5QH0P2<
S8`01@1nOWh0BTY:05aLG01LG5`0EeMG0080C4a<00D0MGEe075aL@1aLG40Zj^[08J6QP0208n?S`04
0::RXP2PX:00X:2P08>3P`80IVIV00D0EeMG08V9R@37alL0alO709fMW@0206YZJP05069RHP12@T80
];Bd0;Bd]02KVi/00P2i^KT01@2VYZH0QXJ608J6QP1lO7`0OWin0080Lg=c00@0GemO0820P020P800
O7al0P2DU9@01@29RHT0]KFe0;fm_@2m_Kd0/K6a0080U9BD00D0Ogmo0=;BdP2h^;P0^;Rh0:ZZZP02
0:6QX@050;Zj^P3<c<`0c<c<0:6QX@1iNGT00P1nOWh0101QHF40UIFE09FEU@2@T9020:2PX005096A
T@2[Zj/0YZJV0:JVYP2:RXX00P1CDe<01@1QHF40UiNG0:VYZ@2YZJT0dM7A0080?clo00D0TI6A0>CT
i03Ti>@0OWin0:b/[00207YjNP0408>3P`1jNWX0NWYj0:f][@80f][J00D0Y:BT09ZJVP2;Rh/0Rh^;
0:j^[P0208n?S`0509NGU`2@T900T92@07=cL`34a<@00P2RXZ801@1oOgl0?Cdm03dm?@10@400Hf=S
0080HV9R00@0GemO06MWI`1WIfL0J6QX0P1eMGD01@1]KFd0OWin061PH01PH600IFEU0080Jf][00D0
G5aL07UiN@1iNGT0UYJF08^;R`0208Z:RP050;Fe]@24Q8@0Q8B407inOP2BTY800P20P8000`25QHD0
M7Ad07AdM00307MgM`0308n?Sooooooooooo00Sooooo000:ooooo`040:6QX@2MWId0WIfM09nOW`80
GEeM00D0Lg=c08Z:RP1DE5@0E5AD08V9R@02096AT@0507moO`2CTi<0Ti>C0861P@1VIVH00P2JVYX3
09RHV00409nOW`0g=cL0GUiN05iNGP<0NGUi00D0WYjN09bLW02LW9`0UiNG096AT@020861P@0308R8
R02@T900T92@0080TY:B0P2DU9@01@1BDU80Lg=c07=cL`2QXJ40Xj>S00<0XJ6Q0P2PX:001@2CTi<0
UYJF09JFUP2BTY80Ti>C0080X:2P00D0Y:BT0:6QX@2QXJ40BTY:06UYJ@0209VIV@0409ZJVP2QXJ40
XJ6Q09fMW@80SXj>00D0RXZ:08V9R@25QHD0QHF508B4Q00208j>SP0508b<S029RHT0@D510451@@2K
Vi/00`2][Jd20:j^[P050;Bd]02`/;00ZJVY0:VYZ@2WYjL00P2TY:@01@2SXj<0YJFU0:VYZ@2YZJT0
Xj>S0080IFEU00D0TY:B09JFUP2PX:00X:2P0:RXZ0020:6QX@050:b/[02^[Zh0[Zj^0:b/[02XZ:P0
0P2TY:@01@2WYjL0ZZZZ0:ZZZP1<C4`0SHf=0080_kno00@0`/;20;no_`2o_kl0^k^k0P2j^[X01@2n
_[h0`l?30<W9b@39bLT0aLG50080_Kfm00D0^k^k0;:b/P1:BTX0BTY:0;>c/`020;6a/@050;Fe]@2f
][H0/K6a0;6a/@2WYjL00P2OWil01@2IVIT0V9RH09RHV02OWil0ZJVY0080Xj>S00D0EUIF0:f][@2]
[Jd0/[:b0:f][@020:b/[0040:j^[P2_[jl0[jn_0;6a/@<0[Jf]00@0];Bd0;Jf]P2f][H0[jn_0P1f
MWH00`2YZJWoooooooooo`0?ooooo`0407inOP2LW9`0W9bL0820P080CDe=00D0SXj>09JFUP2FUYH0
VIVI0;6a/@0209>CT`0507inOP1IFET0FEUI08^;R`1kNg/00P1oOgl0101hN7P0QhN708N7Q`1QHF42
09:BTP05071`L01RHV80KVi^06i^KP1BDU800P1:BTX01@1iNGT0QXJ608J6QP2^[Zh0RXZ:0080R8R8
00@0X:2P09VIV@2IVIT0Lg=c0P1KFe/01@1GEeL0SXj>0;Fe]@2e]KD0UiNG0080IVIV00D0MGEe04M7
A`2WYjL0YjNW09^KV`020<;2`P050:b/[029RHT0RHV907MgM`25QHD00P26QXH0101eMGD0Shn?08n?
S`1cLg<209^KV`0509>CT`2c/k<0`L710<71`@2c/k<00P2KVi/01@21PH40h>3P0;:b/P2b/[80XJ6Q
0080WIfM00D0^[Zj0<k>cP3>c/h0Z:RX07EeM@0208j>SP0406QXJ02IVIT0VIVI08b<S080XJ6Q00D0
TI6A0:ZZZP2^[Zh0[Zj^09NGU`0205aLG00507MgM`2VYZH0[Zj^0:j^[P3?cll00P0_;bl01@2=SHd0
gMgM0=gMg@1nOWh0/[:b0080R8R800@0Ogmo07IfMP1fMWH0];Bd0P3EeMD01@2NWYh0UYJF09JFUP2F
UYH0/;2`0080Ti>C00D0WYjN08^;R`2;Rh/0NWYj0;no_`020:2PX00507AdM01;Bd/0Bd];04=3@`1P
H6000P1RHV800`1DE5@0KVi^06i^KP0307EeM@05075aL@1fMWH0LG5a075aL@1bLW800P1/K6`01@25
QHD0UiNG09NGU`2SXj<0RHV90080RXZ:00D0/K6a09JFUP2FUYH0QXJ609jNWP0207UiN@0308R8R01e
MGD0MGEe00<0Jf][00<0RXZ:ooooooooool02?ooool000[ooooo00@0XJ6Q09bLW02LW9`0Vi^K0P1U
IFD01@1aLG40Shn?06m_K`1_Kfl0WinO0080Vi^K00D0VYZJ0:BTY02TY:@0P82007emO@020:6QX@05
0:2PX02MWId0WIfM09>CT`13@d<00P1NGUh01023Ph<0S8b<08b<S02LW9`20:>SX`0509nOW`2JVYX0
TI6A096AT@2@T9000P2>SXh01@2=SHd0Ti>C08:2PP22PX80=3@d0080MGEe0P2NWYh209fMW@0409NG
U`2PX:00X:2P09RHV080SHf=00@0R8R809>CT`2GUiL0UiNG0`2IVIT01@1?Cdl0Hf=S08R8R028R8P0
UIFE0080VYZJ00D0VIVI08n?S`2?Shl0Ph>307moO`0207inOP050820P025QHD0QHF508R8R01gMgL0
0P12@T80102:RXX0WYjN09jNWP2TY:@209fMW@050:BTY02VYZH0WinO09nOW`2GUiL00P2DU9@01@2A
TI40WIfM09ZJVP2JVYX0UiNG0080Fe]K00D0UiNG08J6QP29RHT0RHV909fMW@0309VIV@80WYjN00D0
VIVI09JFUP2GUiL0UiNG09jNWP0209ZJVP0503Ti>@20P800YjNW0:NWY`2TY:@00P2`/;001@2^[Zh0
[jn_0:n_[`2/[:`0Xj>S0080];Bd00D0YZJV0:NWY`2WYjL0[jn_09VIV@02055AD@0508b<S02=SHd0
SHf=09VIV@2ZZZX00P2WYjL0102BTY80QXJ608J6QP27QhL208R8R00508B4Q02DU9@0V9RH09RHV01K
Fe/00`2SXj<30:BTY0040:VYZ@2JVYX0VYZJ09nOW`80UYJF00D0Xj>S0:BTY02PX:00X:2P09ZJVP02
05eMG@0309FEUOoooooooooo00oooooo00@0MWIf09NGU`2GUiL0PH610P1EEED01@2NWYh0Xj>S0:>S
X`2RXZ80]kNg0080UiNG00D0MgMg05YJFP1JFUX0Ti>C07UiN@03079bLP80MgMg00D0G5aL08n?S`2?
Shl0Q8B405YJFP0207MgM`0406UYJ@1PH600H61P08n?S`80T92@00D0/K6a09RHV02KVi/0Vi^K0;Rh
^0020:b/[00508B4Q01ZJVX0JVYZ05mOG`2VYZH00P3@d=001@2a/K40KVi^06i^KP1hN7P0De=C0080
X:2P00@0Ti>C0<C4a034a<@0/K6a0P20P8001@1[Jf/0N7Qh08R8R028R8P0MWIf0080Vi^K00D0IFEU
08^;R`2;Rh/0TI6A0:>SX`020:BTY0050:NWY`2>SXh0SXj>07QhN03EeMD00P2c/k<0102UYJD0Zj^[
0:^[Z`2j^[X20=SHf0050:f][@1kNg/0QXJ608J6QP1PH6000P2FUYH01@26QXH0Y:BT0:BTY02;Rh/0
W9bL0080VIVI00D0M7Ad059BDP1BDU80Kfm_08n?S`020:JVYP040<30`00b<S80<S8b09bLW080f=SH
00D0O7al0:2PX023Ph<0Ph>307YjNP0207=cL`050;Vi^@3AdM40dM7A09ZJVP1jNWX00P2a/K40102]
[Jd0XZ:R0::RXP2YZJT208n?S`050861P@2n_[h0RHV908V9R@1SHf<00P1ADE401@0m?Cd0HF5Q05mO
G`1OGel0Bd];0080HF5Q00D0OGem06][J`1[Jf/0JFUY07=cL`0206i^KP0406][J`1cLg<0Lg=c07mo
O`80RXZ:00D0XJ6Q09JFUP2KVi/0Vi^K0;:b/P0208j>SP0507inOP22PX80GUiN05iNGP1UIFD00P1/
K6`0101JFUX0G5aL05aLG01oOgl:ooooo`002_ooool0102QXJ40W9bL09bLW02KVi/206EUI@05075a
L@2?Shl0Kfm_06m_K`2OWil00P2KVi/01@2JVYX0Y:BT0:BTY020P800OGem0080XJ6Q00D0X:2P09fM
W@2MWId0Ti>C04=3@`0205iNGP0408>3P`2<S8`0S8b<09bLW080Xj>S00D0WinO09ZJVP2ATI40TI6A
092@T00208j>SP0508f=S@2CTi<0PX:208:2PP0d=3@00P1eMGD209jNWP80WIfM00@0UiNG0:2PX02P
X:00V9RH0P2=SHd01028R8P0Ti>C09NGU`2GUiL309VIV@0504m?C`1SHf<0R8R808R8R02EUID00P2J
VYX01@2IVIT0Shn?08n?S`23Ph<0Ogmo0080OWin00D0P82008F5Q@25QHD0R8R807MgM`020492@P04
08Z:RP2NWYh0WYjN0:BTY080WIfM00D0Y:BT0:JVYP2OWil0WinO09NGU`0209BDU005096AT@2MWId0
VYZJ09ZJVP2GUiL00P1KFe/01@2GUiL0QXJ608V9R@29RHT0WIfM00<0VIVI0P2NWYh01@2IVIT0UYJF
09NGU`2GUiL0WYjN0080VYZJ00D0>CTi0820P02WYjL0YjNW0:BTY0020;2`/0050:j^[P2_[jl0[jn_
0:b/[02SXj<00P2d];@01@2VYZH0YjNW0:NWY`2_[jl0VIVI0080DE5A00D0S8b<08f=S@2=SHd0VIVI
0:ZZZP020:NWY`0409:BTP26QXH0QXJ608N7Q`80R8R800D0Q8B409BDU02HV9P0V9RH05]KF`030:>S
X`<0Y:BT00@0ZJVY09ZJVP2JVYX0WinO0P2FUYH01@2SXj<0Y:BT0:2PX02PX:00VYZJ0080GEeM00<0
UIFEooooooooool03oooool0101fMWH0UiNG09NGU`21PH4205EEE@0509jNWP2SXj<0Xj>S0::RXP2g
]kL00P2GUiL01@1gMgL0FUYJ05YJFP2CTi<0NGUi00<0LW9b0P1gMgL01@1LG5`0Shn?08n?S`24Q8@0
FUYJ0080MgMg00@0JFUY061PH01PH600Shn?0P2@T9001@2a/K40V9RH09^KV`2KVi/0^;Rh0080[:b/
00D0Q8B406YZJP1ZJVX0GemO0:JVYP020=3@d0050;6a/@1^KVh0KVi^07QhN01CDe<00P2PX:00102C
Ti<0a<C40<C4a02a/K420820P00506][J`1hN7P0R8R808R8R01fMWH00P2KVi/01@1UIFD0Rh^;08^;
R`2ATI40Xj>S0080Y:BT00D0YjNW08j>SP2>SXh0N7Qh0=GEe@020;>c/`040:FUY@2[Zj/0Zj^[0;Zj
^P80f=SH00D0[Jf]07]kN`26QXH0QXJ6061PH00209JFUP0508J6QP2TY:@0Y:BT08^;R`2LW9`00P2I
VIT01@1dM7@0DU9B059BDP1_Kfl0Shn?0080YZJV00@0`<30038b<P0b<S80W9bL0P3Hf=P01@1lO7`0
X:2P08>3P`23Ph<0NWYj0080Lg=c00D0^KVi0=7Ad@3AdM40VYZJ07YjNP020;6a/@040:f][@2RXZ80
XZ:R0:VYZ@80Shn?00D0PH610;jn_P29RHT0RHV906=SH`02055AD@0503dm?@1QHF40GemO05mOG`1;
Bd/00P1QHF401@1mOGd0Jf][06][J`1YJFT0Lg=c0080KVi^00@0Jf][07=cL`1cLg<0Ogmo0P2:RXX0
1@2QXJ40UYJF09^KV`2KVi/0/[:b0080SXj>00D0OWin08:2PP1NGUh0GUiN06EUI@0206a/K00405YJ
FP1LG5`0G5aL07moO`[ooooo000:ooooo`0405UIF@1;Bd/0Bd];04Y:BP80>CTi00D0>c/k04];B`0o
?cl0?clo04A4A00204Q8B00504m?C`1>CTh0CTi>03/k>`1:BTX00P1@D5001@17AdL0A4A404A4A00j
>SX06a/K008092@T0`0l?3`303Ph>0050492@P0h>3P0;Bd]02d];@0j>SX00P1<C4`01@1?Cdl0De=C
03`l?00l?3`07alO0080ATI600@0GUiN05UIF@1OGel0GemO0`1EEED01@1>CTh0BTY:04Y:BP17AdL0
ATI60080D51@00D0CDe=04Q8B018B4P08B4Q03Lg=`0204];B`04059BDP1CDe<0De=C059BDP80CDe=
00D0DE5A04E5A@18B4P0B4Q804=3@`020492@P0503Xj>P0g=cL0820P020P800/;2`00P0_;bl01@0^
;Rh09RHV02HV9P0m?Cd0@T920080>3Ph00D0=cLg02l_;`0_;bl0:BTY030`<00203<c<`0502TY:@0V
9RH09RHV04i>CP11@D400P0l?3`0100k>c/0>SXj03Xj>P11@D4204I6AP0503Hf=P0`<300<C4a034a
<@0];Bd00P0S8b<01@0O7al07QhN02@T900T92@09BDU0080:RXZ00D0;2`/02HV9P0V9RH0:2PX03Xj
>P020410@0050451@@19BDT0BDU904a<C01=CDd00P12@T801@0n?Sh0>SXj03Xj>P0S8b<09bLW0080
:2PX00@04Q8B020P800P82009bLW0P0V9RH01@0O7al09RHV02HV9P0V9RH05QHF00806ATI00D0820P
01/K6`0R8R808R8R01XJ6P0200d=3@0301HF5P0W9bL09bLW0080<C4a0P0_;bl0100Y:BT08R8R028R
8P0R8R8Aooooo`04079bLP2FUYH0UYJF08:2PP80EeMG00D0V9RH09JFUP2FUYH0WinO0:f][@0207Ee
M@0506m_K`1IFET0FEUI08:2PP1[Jf/00P1gMgL0101iNGT0Lg=c07=cL`1fMWH20:2PX00508:2PP1C
De<0Hf=S06=SH`1]KFd00P1LG5`01@1aLG40N7Qh07QhN02VYZH0RHV90080TI6A00@0Zj^[0:6QX@2Q
XJ40MWIf0P1[Jf/01@1OGel0Zj^[0=gMg@3MgMd0^k^k0080J6QX00D0Ogmo051@D02OWil0WinO09ZJ
VP020<30`0050;bl_022PX80PX:206i^KP21PH400P2ATI40101nOWh0VYZJ09ZJVP1WIfL208^;R`05
09^KV`2e]KD0`/;20<;2`P2c/k<00P2NWYh01@1cLg<0^;Rh0:FUY@2UYJD0Vi^K0080ZZZZ00D0YjNW
0<[:bP3:b/X0P820079bLP0207alO00406UYJ@2VYZH0YZJV08j>SP80YjNW00D0S8b<0:ZZZP2SXj<0
Xj>S08^;R`0205UIF@0507]kN`2VYZH0/K6a0;6a/@34a<@00P0k>c/01@2WYjL0h>3P0>3Ph022PX80
UiNG0080OGem00@0LW9b069RHP1RHV80XZ:R0P2l_;`01@2;Rh/0J6QX0:n_[`2_[jl0WIfM0080Shn?
00D0SXj>08b<S02<S8`0X:2P0<S8b00208Z:RP0505]KF`1JFUX0FUYJ04=3@`1XJ6P00P1TI6@0101I
FET0LG5a075aL@24Q8@207]kN`0507AdM01VIVH0K6a/06a/K01[Jf/00P1oOgl01@26QXH0WYjN09jN
WP2XZ:P0NGUi0080Ti>C00@0/k>c08n?S`2?Shl0Ogmo0`2;Rh/0101IFET0C4a<04a<C01TI6@206IV
IP0306YZJ_oooooooooo00Sooooo000:ooooo`0409>CT`28R8P0R8R808N7Q`80PH6100<0OGem07Ui
N@1dM7@00P1dM7@207UiN@0507emO@24Q8@0Q8B4030`<018B4P00P1[Jf/01@1jNWX0MGEe07EeM@1k
Ng/0P8200080MWIf0`1nOWh01@1lO7`0LW9b079bLP1^KVh0J6QX008092@T00D0O7al08Z:RP2:RXX0
QXJ608n?S`0209fMW@050:JVYP2JVYX0VYZJ09RHV02KVi/00P2EUID01028R8P0SHf=08f=S@23Ph<2
02l_;`0505eMG@1mOGd0RHV908V9R@23Ph<00P1iNGT01@1gMgL0M7Ad06ATI01TI6@0JVYZ0080KVi^
00D0Jf][06a/K01/K6`0MGEe03<c<`0206m_K`05071`L01WIfL0IfMW07AdM01hN7P00P20P8001024
Q8@0RXZ:08Z:RP2>SXh309JFUP04092@T01dM7@0M7Ad06i^KP80V9RH00D0S8b<09BDU02MWId0WIfM
09VIV@0209bLW080UiNG0P2XZ:P0102YZJT0Zj^[0:^[Z`1UIFD208>3P`0309ZJVP2CTi<0SXj>0080
SXj>0P2CTi<01@2JVYX0VIVI09nOW`2OWil0XZ:R0080WinO00D0XJ6Q07YjNP1jNWX0J6QX09RHV002
09jNWP050;2`/02e]KD0]KFe0:RXZ02^[Zh00P2MWId01@2KVi/0X:2P0:2PX02JVYX0RHV90080Y:BT
00@0E5AD08Z:RP2:RXX0GUiN0P1lO7`01@2GUiL0XZ:R09bLW02LW9`0Lg=c0080Ng]k00D0OGem08^;
R`2RXZ80XZ:R0:2PX002061PH0050861P@2QXJ40XJ6Q0:BTY02UYJD00`2WYjL209bLW00308J6Q_oo
oooooooo00oooooo00@0FUYJ08>3P`23Ph<0NGUi0P1:BTX01@2GUiL0Vi^K09^KV`2MWId0UYJF0080
W9bL00D0MWIf05ADE01DE5@0NGUi07alO00206IVIP0405EEE@17AdL0AdM705=CD`80RHV900D0KFe]
0492@P1JFUX0FUYJ04a<C00205IFEP0507=cL`1nOWh0OWin09bLW029RHT00P2GUiL0102[Zj/0Z:RX
0:RXZ01cLg<2075aL@0505aLG02DU9@0dM7A0=7Ad@2IVIT00P1SHf<01@1mOGd0EeMG09FEU@2EUID0
V9RH0080a<C400D0/;2`07YjNP1jNWX0KFe]075aL@0208^;R`0407=cL`2HV9P0V9RH07=cL`80T92@
00D0VIVI0;Fe]@33`l<0`l?30;Bd]00209fMW@0507MgM`3EeMD0`<300<30`02b/[800P2i^KT01@2Y
ZJT0f][J0=[JfP2>SXh0Ogmo0080R8R800@0JVYZ09^KV`2KVi/0QXJ60P2XZ:P01@1nOWh0YZJV08n?
S`2?Shl0PX:20080G5aL00D0OWin09^KV`2^[Zh0[Zj^0<O7a`0203lo?`050:>SX`3Ph>00h>3P08f=
S@2KVi/00`1oOgl206m_K`050;:b/P3;bl/0bl_;09jNWP1RHV800P1LG5`01027QhL0XJ6Q0:6QX@2>
SXh208f=S@0508n?S`2ZZZX0Q8B408B4Q01CDe<00P17AdL01@0l?3`0DU9B05QHF01HF5P0EUIF0080
J6QX00D0NGUi07EeM@1eMGD0JVYZ07IfMP0205eMG@0406YZJP1/K6`0K6a/06][J`80PX:200D0S8b<
05IFEP1kNg/0Ng]k09^KV`0207AdM005071`L029RHT0Ph>308>3P`1RHV800P1_Kfl0101bLW80NWYj
07YjNP2LW9`:ooooo`002_ooool00`2_[jl0XJ6Q0:6QX@030:6QX@0509fMW@2UYJD0YZJV0:JVYP2S
Xj<00P2RXZ801@2KVi/0XJ6Q0:6QX@0l?3`0RXZ:0080UiNG00D0X:2P0:BTY02TY:@0WIfM09JFUP02
08f=S@0409nOW`2TY:@0Y:BT0:>SX`80Ti>C00D0SHf=08:2PP0];Bd0;Bd]08Z:RP0209^KV`0409RH
V02MWId0W9bL09bLW0<0Y:BT00D0Xj>S0:BTY02IVIT0VIVI08b<S00208^;R`0508V9R@1;Bd/0Bd];
09^KV`2CTi<00P2MWId01@2QXJ40YZJV0:JVYP2SXj<0VYZJ0080Ti>C00@0Ph>308J6QP26QXH0MWIf
0P20P8000`2FUYH0=3@d08V9R@0208V9R@80RXZ:00D0QhN709NGU`2MWId0WIfM09:BTP02092@T005
08n?S`2QXJ40XJ6Q0::RXP2BTY800P1gMgL01@1CDe<0RXZ:08Z:RP2=SHd0Ti>C0080VIVI00<0Vi^K
09nOW`2OWil00P2PX:020:VYZ@<0ZZZZ00D0CDe=09^KV`2KVi/0YZJV09jNWP020:2PX00509jNWP2X
Z:P0Z:RX0:ZZZP2UYJD00P2ZZZX0102/[:`0Zj^[0:^[Z`2SXj<208:2PP0405YJFP2SXj<0XZ:R0::R
XP<0Zj^[00D0TY:B0:>SX`22PX80PX:208j>SP0209JFUP0508n?S`26QXH0VYZJ09ZJVP1JFUX00P24
Q8@01@17AdL0T92@092@T02JVYX0WinO0080VIVI00D0L71`06e]K@1]KFd0J6QX071`L00209>CT`04
0:JVYP1/K6`0K6a/07]kN`80Ti>C00D0WYjN0:2PX02TY:@0Y:BT0:NWY`020:>SX`030:JVY_oooooo
oooo00oooooo00@0K6a/09FEU@2EUID0OWin0P1BDU801@2>SXh0T92@092@T02GUiL0SHf=0080S8b<
00D0Kfm_04Y:BP1:BTX0K6a/07=cL`0206QXJ00406YZJP1WIfL0IfMW05=CD`80S8b<00D0LW9b0451
@@1UIFD0IFEU04M7A`0204U9B@0506YZJP1iNGT0NGUi0::RXP1nOWh00P2KVi/0102QXJ40U9BD09BD
U01TI6@206a/K005061PH02>SXh0`<300<30`02FUYH00P1NGUh01@20P800F5QH09bLW02LW9`0YjNW
0080a/K600D0ZJVY07MgM`1gMgL0LG5a06e]K@0208:2PP04075aL@2ATI40TI6A06i^KP80QhN700D0
U9BD0;Bd]02RXZ80XZ:R0:>SX`02096AT@0506EUI@3Bd]80^k^k0;^k^`2BTY800P2_[jl01@2`/;00
h>3P0>3Ph02DU9@0RHV90080PX:200@0H61P09fMW@2MWId0QHF50P2XZ:P01@1mOGd0[:b/0:BTY02T
Y:@0S8b<0080GUiN00D0Ogmo09ZJVP2NWYh0WYjN0=;BdP0204I6AP050:>SX`3Shn<0hn?S0861P@2>
SXh00P1nOWh01025QHD0Lg=c07=cL`2_[jl20<o?c`050:FUY@1EEED0GEeM05eMG@26QXH00P2IVIT0
1@29RHT0UYJF09JFUP2LW9`0^k^k0080NGUi00D0@41004A4A014A4@0=SHf05aLG00205YJFP04069R
HP1/K6`0K6a/07UiN@80L71`00D0JFUY06e]K@1XJ6P0J6QX05aLG00206a/K00507MgM`2BTY80TY:B
08^;R`1RHV800P1lO7`01@2HV9P0Ph>308>3P`1nOWh0MWIf0080Kfm_00@0Hf=S06i^KP1^KVh0Kfm_
0P1/K6`00`1hN7Soooooooooo`08ooooo`002_ooool00`2_[jl0XJ6Q0:6QX@030:6QX@0509fMW@2U
YJD0YZJV0:JVYP2SXj<00P2RXZ801@2KVi/0XJ6Q0:6QX@0l?3`0RXZ:0080UiNG00D0X:2P0:BTY02T
Y:@0WIfM09JFUP0208f=S@0409nOW`2TY:@0Y:BT0:>SX`80Ti>C00D0SHf=08:2PP0];Bd0;Bd]08Z:
RP0209^KV`0409RHV02MWId0W9bL09bLW0<0Y:BT00D0Xj>S0:BTY02IVIT0VIVI08b<S00208^;R`05
08V9R@1;Bd/0Bd];09^KV`2CTi<00P2MWId01@2QXJ40YZJV0:JVYP2SXj<0VYZJ0080Ti>C00@0Ph>3
08J6QP26QXH0MWIf0P20P8000`2FUYH0=3@d08V9R@0208V9R@80RXZ:00D0QhN709NGU`2MWId0WIfM
09:BTP02092@T00508n?S`2QXJ40XJ6Q0::RXP2BTY800P1gMgL01@1CDe<0RXZ:08Z:RP2=SHd0Ti>C
0080VIVI00<0Vi^K09nOW`2OWil00P2PX:020:VYZ@<0ZZZZ00D0CDe=09^KV`2KVi/0YZJV09jNWP02
0:2PX00509jNWP2XZ:P0Z:RX0:ZZZP2UYJD00P2ZZZX0102/[:`0Zj^[0:^[Z`2SXj<208:2PP0405YJ
FP2SXj<0XZ:R0::RXP<0Zj^[00D0TY:B0:>SX`22PX80PX:208j>SP0209JFUP0508n?S`26QXH0VYZJ
09ZJVP1JFUX00P24Q8@01@17AdL0T92@092@T02JVYX0WinO0080VIVI00D0L71`06e]K@1]KFd0J6QX
071`L00209>CT`040:JVYP1/K6`0K6a/07]kN`80Ti>C00D0WYjN0:2PX02TY:@0Y:BT0:NWY`020:>S
X`030:JVY_oooooooooo00oooooo00@0K6a/09FEU@2EUID0OWin0P1BDU801@2>SXh0T92@092@T02G
UiL0SHf=0080S8b<00D0Kfm_04Y:BP1:BTX0K6a/07=cL`0206QXJ00406YZJP1WIfL0IfMW05=CD`80
S8b<00D0LW9b0451@@1UIFD0IFEU04M7A`0204U9B@0506YZJP1iNGT0NGUi0::RXP1nOWh00P2KVi/0
102QXJ40U9BD09BDU01TI6@206a/K005061PH02>SXh0`<300<30`02FUYH00P1NGUh01@20P800F5QH
09bLW02LW9`0YjNW0080a/K600D0ZJVY07MgM`1gMgL0LG5a06e]K@0208:2PP04075aL@2ATI40TI6A
06i^KP80QhN700D0U9BD0;Bd]02RXZ80XZ:R0:>SX`02096AT@0506EUI@3Bd]80^k^k0;^k^`2BTY80
0P2_[jl01@2`/;00h>3P0>3Ph02DU9@0RHV90080PX:200@0H61P09fMW@2MWId0QHF50P2XZ:P01@1m
OGd0[:b/0:BTY02TY:@0S8b<0080GUiN00D0Ogmo09ZJVP2NWYh0WYjN0=;BdP0204I6AP050:>SX`3S
hn<0hn?S0861P@2>SXh00P1nOWh01025QHD0Lg=c07=cL`2_[jl20<o?c`050:FUY@1EEED0GEeM05eM
G@26QXH00P2IVIT01@29RHT0UYJF09JFUP2LW9`0^k^k0080NGUi00D0@41004A4A014A4@0=SHf05aL
G00205YJFP04069RHP1/K6`0K6a/07UiN@80L71`00D0JFUY06e]K@1XJ6P0J6QX05aLG00206a/K005
07MgM`2BTY80TY:B08^;R`1RHV800P1lO7`01@2HV9P0Ph>308>3P`1nOWh0MWIf0080Kfm_00@0Hf=S
06i^KP1^KVh0Kfm_0P1/K6`00`1hN7Soooooooooo`08ooooo`002_ooool0102a/K40Y:BT0:BTY02Q
XJ4209jNWP0509JFUP2ATI40W9bL09bLW02QXJ400P2DU9@01@23Ph<0QHF508F5Q@0j>SX0JFUY0080
Ph>300D0Shn?09ZJVP2JVYX0T92@08R8R00208>3P`04092@T02NWYh0WYjN09:BTP80QHF50P1gMgL2
02h^;P050861P@2?Shl0Shn?092@T02?Shl00P1nOWh01@1iNGT0Ogmo07moO`2;Rh/0WYjN0080OWin
00@0KFe]07IfMP1fMWH0L71`0P0m?Cd01@2>SXh0WinO0::RXP2RXZ80YJFU0080Y:BT00D0XJ6Q09JF
UP2;Rh/0Rh^;079bLP0208>3P`0507emO@2?Shl0Shn?09fMW@0`<3000P2JVYX01@2LW9`0WYjN09jN
WP2ATI40UIFE0080Ti>C00@0Ph>308R8R028R8P0PH610P2JVYX01@2QXJ40U9BD06m_K`1_Kfl0GemO
0080UYJF00D0TI6A09bLW02MWId0WIfM092@T00209BDU00508n?S`2NWYh0YjNW0:NWY`2][Jd00P2[
Zj/0101TI6@0X:2P0:2PX02UYJD40:NWY`80YZJV00D0ZJVY0:FUY@2WYjL0YjNW0:VYZ@020:JVYP05
0:BTY02=SHd0SHf=061PH02OWil00P2SXj<01@2_[jl0UYJF09JFUP2/[:`0WIfM0080PX:200D0U9BD
09ZJVP2JVYX0VIVI09:BTP0209bLW00403lo?`1<C4`0C4a<055AD@<0QXJ600@0R8R808V9R@29RHT0
Fe]K0P1XJ6P01@1CDe<0M7Ad09VIV@2IVIT0XJ6Q0080Fe]K00D0O7al0861P@21PH40UiNG09bLW002
0:FUY@040:2PX02OWil0WinO0:>SXa7ooooo00@0IfMW0:JVYP2VYZH0NGUi0P1DE5@01@2ATI40W9bL
09bLW02PX:00XZ:R0080PX:200D0MgMg05MGE`1GEeL0NWYj07EeM@0205QHF004079bLP1TI6@0I6AT
071`L080R8R800D0KFe]03hn?P1ZJVX0JVYZ05IFEP0205ADE00507QhN01bLW80LW9b09^KV`1oOgl0
0P2IVIT0102/[:`0Xj>S0:>SX`1UIFD206IVIP05065QH@2;Rh/0`l?30<?3``2@T9000P1EEED01@1j
NWX0De=C07emO@1mOGd0Ti>C0080b<S800D0[jn_07emO@1mOGd0Kfm_06=SH`0207moO`04079bLP28
R8P0R8R8071`L080QhN700D0S8b<0;Fe]@2[Zj/0Zj^[09RHV00209FEU@0506e]K@3Jf]X0aLG50<G5
a@2LW9`00P1jNWX01@2<S8`0YZJV0:JVYP1lO7`0MgMg0080LW9b00@0Fe]K092@T02@T900PX:20P2V
YZH01@1mOGd0/[:b0:f][@2][Jd0QXJ60080I6AT00D0QHF50:f][@2^[Zh0[Zj^0<[:bP020410@005
0:FUY@3Ti>@0i>CT08B4Q02CTi<00P23Ph<01026QXH0M7Ad07AdM02h^;P20=3@d0050:NWY`1OGel0
TI6A096AT@2@T9000P2BTY801@23Ph<0Vi^K09^KV`2;Rh/0^;Rh0080K6a/00D0CDe=04A4A014A4@0
=cLg05MGE`0205YJFP04069RHP1WIfL0IfMW07alO080JFUY00D0KFe]07EeM@1ADE40DE5A069RHP02
05MGE`0505]KF`1gMgL0MgMg09ZJVP1ZJVX00P2;Rh/0102ATI40HF5Q065QH@1NGUh306MWI`04059B
DP1PH600H61P06=SH`80KVi^00<0P820ooooooooool02?ooool000[ooooo00@0Zj^[0:FUY@2UYJD0
YJFU0P2OWil01@2JVYX0TI6A09^KV`2KVi/0WIfM0080SHf=00D0Q8B408V9R@29RHT0@D5107QhN002
08b<S00508F5Q@2;Rh/0Rh^;08Z:RP27QhL00P28R8P01023Ph<0UiNG09NGU`2:RXX206YZJP05065Q
H@1aLG40;bl_02l_;`26QXH00P2CTi<01@2IVIT0R8R807UiN@1iNGT0NWYj0080NGUi00D0QhN70:BT
Y02;Rh/0Rh^;06UYJ@0206EUI@0505IFEP0`<300<30`0861P@29RHT00P2DU9@01@2GUiL0Ti>C09>C
T`2<S8`0RHV90080NGUi00@0MWIf0820P020P800Ti>C0P2FUYH01@2<S8`0@41009>CT`2CTi<0UiNG
0080SXj>00D0Ph>308V9R@27QhL0QhN708V9R@0209ZJVP0308n?S`2CTi<0Ti>C0080Shn?0P1YJFT0
1@1BDU80IFEU06EUI@1RHV80J6QX0080KVi^00D0Kfm_07AdM01dM7@0LG5a07UiN@0208f=S@0409FE
U@1hN7P0N7Qh04m?C`80OWin00@0UiNG09FEU@2QXJ40XJ6Q0`2UYJD01@2WYjL0Xj>S09NGU`2GUiL0
YZJV0080VIVI00@0Vi^K08F5Q@25QHD0J6QX0`2FUYH01@2`/;00]KFe0;Fe]@2ZZZX0UIFE0080W9bL
00D0Rh^;09NGU`2GUiL0VYZJ09NGU`0209jNWP0403Ti>@1@D500D51@06ATI080TY:B00D0RHV908^;
R`1SHf<0Hf=S04Q8B00205YJFP03051@D01iNGT0Ph>30080Ph>30P0n?Sh01@1YJFT0UiNG09NGU`2R
XZ80VIVI0080TI6A00@0WYjN0:6QX@2QXJ40X:2P4Oooool0101]KFd0[Jf]0:f][@1mOGd206MWI`05
08N7Q`2OWil0WinO0:NWY`2d];@00P2>SXh01@1lO7`0H61P061PH029RHT0Shn?0080Fe]K00@0MgMg
06IVIP1VIVH0OGem0P2@T9001@1_Kfl0B4Q805MGE`1GEeL0@4100080AdM700D0IFEU071`L01`L700
];Bd08R8R00209BDU0040:JVYP2HV9P0V9RH05aLG080I6AT00D0MgMg09^KV`3@d=00d=3@09fMW@02
05aLG0050820P01HF5P0QhN708N7Q`2EUID00P3;bl/01@2e]KD0PX:208:2PP1iNGT0GemO0080O7al
00@0M7Ad08B4Q024Q8@0I6AT0P1nOWh01@2:RXX0ZZZZ09RHV02HV9P0QXJ60080Shn?00D0LG5a0=KF
eP2o_kl0_kno0;>c/`0206EUI@050<O7a`2GUiL0UiNG06IVIP1fMWH00P1hN7P0101SHf<0TY:B09:B
TP20P8020:>SX`0508J6QP2ZZZX0[Zj^0:j^[P2;Rh/00P1RHV801@27QhL0YjNW0:n_[`2_[jl0_Kfm
0080@41000D0XZ:R0>;RhP3Rh^80Shn?09VIV@0207emO@0407moO`1kNg/0Ng]k0;2`/080d=3@00D0
YZJV06ATI02`/;00/;2`09:BTP020:BTY00508n?S`2XZ:P0Z:RX092@T02XZ:P00P1[Jf/01@1IFET0
>SXj03Xj>P1;Bd/0PX:20080IFEU00@0L71`07]kN`1kNg/0PX:20P1cLg<01@24Q8@0KFe]071`L01`
L700Lg=c0080MWIf00D0MgMg09ZJVP2JVYX0_kno07inOP020:j^[P050;6a/@2<S8`0S8b<07EeM@25
QHD00P1nOWh0101dM7@0DE5A055AD@1VIVH2079bLP0307YjN_oooooooooo00Sooooo000:ooooo`04
0:^[Z`2UYJD0YJFU0:FUY@80WinO00D0VYZJ096AT@2KVi/0Vi^K09fMW@0208f=S@0508B4Q029RHT0
RHV90451@@1hN7P00P2<S8`01@25QHD0Rh^;08^;R`2:RXX0QhN70080R8R800@0Ph>309NGU`2GUiL0
RXZ:0P1ZJVX01@1QHF40LG5a02l_;`0_;bl0QXJ60080Ti>C00D0VIVI08R8R01iNGT0NGUi07YjNP02
07UiN@0508N7Q`2TY:@0Rh^;08^;R`1YJFT00P1UIFD01@1FEUH0<30`030`<021PH40RHV90080U9BD
00D0UiNG09>CT`2CTi<0S8b<08V9R@0207UiN@0407IfMP20P800P82009>CT`80UYJF00D0S8b<0410
@02CTi<0Ti>C09NGU`0208j>SP0508>3P`29RHT0QhN708N7Q`29RHT00P2JVYX00`2?Shl0Ti>C09>C
T`0208n?S`80JFUY00D0DU9B06EUI@1UIFD0HV9R06QXJ00206i^KP0506m_K`1dM7@0M7Ad075aL@1i
NGT00P2=SHd0102EUID0N7Qh07QhN01?Cdl207inOP0409NGU`2EUID0XJ6Q0:6QX@<0YJFU00D0YjNW
0:>SX`2GUiL0UiNG0:JVYP0209VIV@0409^KV`25QHD0QHF506QXJ0<0UYJF00D0/;2`0;Fe]@2e]KD0
ZZZZ09FEU@0209bLW00508^;R`2GUiL0UiNG09ZJVP2GUiL00P2NWYh0100i>CT0D51@051@D01TI6@2
09:BTP0508V9R@2;Rh/0Hf=S06=SH`18B4P00P1JFUX00`1@D500NGUi08>3P`0208>3P`80?Shn00D0
JFUY09NGU`2GUiL0XZ:R09VIV@02096AT@0409jNWP2QXJ40XJ6Q0:2PX17ooooo00@0KFe]0:f][@2]
[Jd0OGem0P1WIfL01@27QhL0WinO09nOW`2WYjL0];Bd0080SXj>00D0O7al061PH01PH600RHV908n?
S`0205]KF`0407MgM`1VIVH0IVIV07emO@80T92@00D0Kfm_04Q8B01GEeL0EeMG0410@00204M7A`05
06EUI@1`L700L71`0;Bd]028R8P00P2DU9@0102VYZH0V9RH09RHV01LG5`206ATI00507MgM`2KVi/0
d=3@0=3@d02MWId00P1LG5`01@20P800F5QH08N7Q`27QhL0UIFE0080bl_;00D0]KFe08:2PP22PX80
NGUi05mOG`0207alO00407AdM024Q8@0Q8B406ATI080OWin00D0RXZ:0:ZZZP2HV9P0V9RH08J6QP02
08n?S`05075aL@3Fe]H0_kno0;no_`2c/k<00P1UIFD01@37alL0UiNG09NGU`1VIVH0MWIf0080N7Qh
00@0Hf=S09:BTP2BTY80P8200P2SXj<01@26QXH0ZZZZ0:j^[P2^[Zh0Rh^;0080HV9R00D0QhN70:NW
Y`2_[jl0[jn_0;fm_@020410@0050::RXP3Rh^80h^;R08n?S`2IVIT00P1mOGd0101oOgl0Ng]k07]k
N`2`/;020=3@d0050:JVYP1TI6@0/;2`0;2`/02BTY800P2TY:@01@2?Shl0Z:RX0:RXZ02@T900Z:RX
0080Jf][00D0FEUI03Xj>P0j>SX0Bd];08:2PP0206EUI@04071`L01kNg/0Ng]k08:2PP80Lg=c00D0
Q8B406e]K@1`L700L71`07=cL`0207IfMP0507MgM`2JVYX0VYZJ0;no_`1nOWh00P2^[Zh01@2a/K40
S8b<08b<S01eMGD0QHF50080OWin00@0M7Ad055AD@1ADE40IVIV0P1bLW800`1jNW[oooooooooo`08
ooooo`002_ooool0101`L700IfMW06MWI`1[Jf/206QXJ005069RHP1SHf<0I6AT06ATI01VIVH00P1C
De<01@1HF5P0HF5Q065QH@0f=SH0ATI60080EUIF0`1DE5@01@1BDU80De=C04e=C@1=CDd0AdM70080
C4a<00D0CTi>03Lg=`0g=cL0>SXj0410@00201hN7P05055AD@1KFe/0Fe]K06ATI01QHF400P1TI6@0
1@1RHV80GEeM05eMG@1SHf<0I6AT0080H61P00@0Cdm?04E5A@15ADD0=cLg0P0/;2`01@1FEUH0FEUI
05YJFP1JFUX0GemO0080Fe]K00D0BTY:04A4A01ADE40DE5A04I6AP0204Q8B0<0Bd];00D0@d=301`L
701RHV80HV9R05iNGP0206ATI00505iNGP1HF5P0DU9B059BDP1IFET00P1VIVH01@1BDU80GemO05mO
G`1MGEd0ADE50080>3Ph00D0;bl_04A4A014A4@0@d=303Xj>P02038b<P0403De=@12@T80@T92051@
D0<0De=C00@0EEEE02XZ:P0Z:RX09BDU0P0N7Qh01@19BDT0EUIF05QHF01HF5P0B4Q80080BDU900D0
Bd];03dm?@10@400@41005ADE00204Q8B00503/k>`0Q8B408B4Q02DU9@0];Bd00P0F5QH01@0U9BD0
<30`030`<00Y:BT0=CDe00808B4Q00D0820P02HV9P0V9RH09BDU02TY:@0201lO7`0400`<300A4A40
4A4A01hN7P<09BDU00@06a/K01`L700L71`061PH0P0I6AT01@0M7Ad09bLW02LW9`0W9bL0;Bd]0080
92@T00@09RHV02XZ:P0Z:RX0<S8b0`0T92@01010@400@D510451@@14A4@Aooooo`0407YjNP2n_[h0
_[jn08J6QP80IFEU00D0Q8B40:2PX02PX:00YZJV0:j^[P0208j>SP0507moO`1LG5`0G5aL08>3P`2C
Ti<00P1VIVH0101SHf<0Fe]K05]KF`1bLW8207YjNP050451@@14A4@0OGem07emO@1LG5`00P1HF5P3
06MWI`050:^[Z`27QhL0T92@092@T02d];@00P2TY:@01@1RHV80JFUY06UYJ@1aLG40Z:RX0080c<c<
00D0Xj>S06YZJP1ZJVX0SHf=05aLG0020861P@040::RXP3:b/X0b/[:0;:b/P80O7al00D0N7Qh05mO
G`23Ph<0Ph>3079bLP0208F5Q@0506ATI01hN7P0N7Qh08j>SP2c/k<00P2SXj<01@2<S8`0Xj>S0:>S
X`1eMGD0a<C40080]kNg00@0]KFe08^;R`2;Rh/0_;bl0P2c/k<01@28R8P0PX:207UiN@1iNGT0DU9B
0080P82000D0OGem09VIV@2IVIT0QXJ60:FUY@020:f][@0508:2PP1NGUh0GUiN08R8R02JVYX00P2a
/K401031`L40@T920492@P2QXJ420=SHf00508F5Q@2>SXh0MWIf07IfMP1oOgl00P1dM7@01@2_[jl0
dM7A0=7Ad@2OWil0JFUY0080][Jf00@0S8b<09NGU`2GUiL0P8200P2XZ:P01@22PX80[jn_075aL@1a
LG40D51@0080?3`l00D0G5aL08B4Q01RHV80HV9R09>CT`02071`L00507EeM@1iNGT0NGUi07inOP23
Ph<00P1bLW80101fMWH0KFe]06e]K@1nOWh209VIV@050;6a/@1QHF40Ti>C09>CT`2YZJT00P2@T900
1@2>SXh0UYJF07moO`1oOgl0Q8B40080OGem00@0Kfm_07YjNP1jNWX0Q8B42_ooool000[ooooo00@0
IfMW05EEE@1EEED0@d=30P0i>CT01@0H61P0<C4a05aLG01LG5`0@4100080Cdm?00D0De=C04e=C@1=
CDd0G5aL06EUI@0205iNGP<0GEeM00D0FUYJ05IFEP19BDT0BDU904i>CP0207]kN`05079bLP1ZJVX0
JVYZ06MWI`1XJ6P00P1]KFd01@1[Jf/0KVi^06i^KP1hN7P0KFe]0080Lg=c00D0K6a/0410@010@400
H61P06UYJ@02065QH@0405mOG`1IFET0FEUI05iNGP<0H61P00@0HF5Q069RHP1RHV80Fe]K0P1TI6@0
1@1NGUh0@T9206EUI@1UIFD0IVIV0080Hf=S00D0Bd];04e=C@1=CDd0HF5Q06i^KP0205iNGP0505IF
EP1IFET0FEUI05iNGP1UIFD00P0k>c/01012@T80K6a/06a/K01kNg/207QhN00507]kN`1hN7P0LW9b
079bLP1eMGD00P1aLG401@1SHf<0IfMW06][J`1[Jf/0JVYZ0080:BTY00D0BTY:06IVIP1eMGD0MGEe
075aL@0207inOP0508R8R026QXH0QXJ608B4Q02:RXX00P1iNGT01@1hN7P0PX:208:2PP1bLW80:b/[
0080Ng]k00@0QHF509BDU02DU9@0R8R80P2>SXh01@2VYZH0WYjN0::RXP2RXZ80X:2P0080XZ:R00D0
WinO09bLW00n?Sh0?Shn07YjNP0208F5Q@0508n?S`2GUiL0UiNG09NGU`2JVYX00P2RXZ801@2SXj<0
WinO09nOW`2OWil0V9RH0080Ti>C00D0IfMW07AdM01dM7@0TY:B08j>SP0208J6QP040861P@1QHF40
HF5Q06YZJP80RXZ:00D0U9BD08f=S@2=SHd0SHf=09FEU@0208^;R`0306ATI?oooooooooo00oooooo
00@0P8200;Jf]P2f][H0R8R80P1[Jf/01@2<S8`0WYjN09jNWP2b/[80[Jf]0080S8b<00D0Ph>306IV
IP1VIVH0QXJ609:BTP02075aL@0406UYJ@18B4P0B4Q806m_K`80RHV900D0>SXj05IFEP1mOGd0OGem
06MWI`0206e]K@0507AdM01`L700L71`0:n_[`2CTi<00P2?Shl0102MWId0Vi^K09^KV`1XJ6P205YJ
FP0506=SH`2HV9P0`l?30<?3``2EUID00P1NGUh01@1oOgl0I6AT08R8R028R8P0/[:b0080d];B00D0
/[:b08Z:RP2:RXX0Ph>306=SH`0208j>SP0407emO@2ATI40TI6A06m_K`80H61P00D0OWin0:6QX@2G
UiL0UiNG07QhN00208F5Q@0507MgM`3AdM40`l?30<?3``2h^;P00P2EUID01@2MWId0/[:b0;:b/P2<
S8`0QXJ60080OGem00@0GUiN08^;R`2;Rh/0O7al0P2CTi<01@1hN7P0Y:BT0;6a/@2a/K40QXJ60080
FUYJ00D0QhN70:6QX@2_[jl0[jn_0<[:bP0204Y:BP050:NWY`3Kfm/0fm_K07EeM@24Q8@00P20P800
1025QHD0Lg=c07=cL`2a/K420<[:bP0509BDU01[Jf/0_[jn0;jn_P2>SXh00P2FUYH01@24Q8@0[:b/
0:b/[020P800^[Zj0080KVi^00D0Cdm?03`l?00l?3`0GUiN08>3P`0206QXJ00408Z:RP1VIVH0IVIV
071`L080JFUY00D0OGem07UiN@1[Jf/0Jf][06m_K`0205iNGP0507=cL`22PX80PX:209ZJVP1KFe/0
0P2DU9@01@2NWYh0NGUi07UiN@1WIfL0O7al0080JFUY00@0O7al06UYJ@1YJFT0Hf=S0P1hN7P00`22
PX;oooooooooo`08ooooo`002_ooool0101WIfL0EEEE05EEE@13@d<203Ti>@0501PH600a<C40G5aL
05aLG010@4000P1?Cdl01@1CDe<0CDe=04e=C@1LG5`0IFEU0080GUiN0`1MGEd01@1JFUX0EUIF04U9
B@19BDT0CTi>0080Ng]k00D0LW9b06YZJP1ZJVX0IfMW06QXJ00206e]K@0506][J`1^KVh0KVi^07Qh
N01]KFd00P1cLg<01@1/K6`0@4100410@01PH600JFUY0080HF5Q00@0GemO05UIF@1IFET0GUiN0`1P
H600101QHF40HV9R069RHP1KFe/206ATI00505iNGP12@T80IFEU06EUI@1VIVH00P1SHf<01@1;Bd/0
CDe=04e=C@1QHF40KVi^0080GUiN00D0EUIF05UIF@1IFET0GUiN06EUI@0203/k>`040492@P1/K6`0
K6a/07]kN`80N7Qh00D0Ng]k07QhN01bLW80LW9b07EeM@02075aL@0506=SH`1WIfL0Jf][06][J`1Z
JVX00P0Y:BT01@1:BTX0IVIV07EeM@1eMGD0LG5a0080OWin00D0R8R808J6QP26QXH0Q8B408Z:RP02
07UiN@0507QhN022PX80PX:2079bLP0[:b/00P1kNg/01025QHD0U9BD09BDU028R8P208j>SP050:JV
YP2NWYh0XZ:R0::RXP2PX:000P2RXZ801@2OWil0W9bL03hn?P0n?Sh0NWYj0080QHF500D0Shn?09NG
U`2GUiL0UiNG09ZJVP020::RXP050:>SX`2OWil0WinO09nOW`2HV9P00P2CTi<01@1WIfL0M7Ad07Ad
M02BTY80SXj>0080QXJ600@0PH61065QH@1QHF40JVYZ0P2:RXX01@2DU9@0SHf=08f=S@2=SHd0UIFE
0080Rh^;00<0I6ATooooooooool03oooool01020P800][Jf0;Jf]P28R8P206][J`0508b<S02NWYh0
WYjN0;:b/P2][Jd00P2<S8`01@23Ph<0IVIV06IVIP26QXH0TY:B0080LG5a00@0JFUY04Q8B018B4P0
Kfm_0P29RHT01@0j>SX0EUIF07emO@1mOGd0IfMW0080KFe]00D0M7Ad071`L01`L700[jn_09>CT`02
08n?S`0409fMW@2KVi/0Vi^K06QXJ080FUYJ00D0Hf=S09RHV033`l<0`l?309FEU@0205iNGP0507mo
O`1TI6@0R8R808R8R02b/[800P3Bd]801@2b/[80RXZ:08Z:RP23Ph<0Hf=S0080SXj>00@0OGem096A
T@2ATI40Kfm_0P1PH6001@1nOWh0XJ6Q09NGU`2GUiL0N7Qh0080QHF500D0MgMg0=7Ad@33`l<0`l?3
0;Rh^00209FEU@0509fMW@2b/[80/[:b08b<S026QXH00P1mOGd0101NGUh0Rh^;08^;R`1lO7`209>C
T`0507QhN02TY:@0/K6a0;6a/@26QXH00P1JFUX01@27QhL0XJ6Q0:n_[`2_[jl0b/[:0080BTY:00D0
YjNW0=_Kf`3Kfm/0MGEe08B4Q0020820P00408F5Q@1cLg<0Lg=c0;6a/@80b/[:00D0U9BD06][J`2n
_[h0_[jn08j>SP0209JFUP0508B4Q02/[:`0[:b/0820P02j^[X00P1^KVh01@1?Cdl0?3`l03`l?01N
GUh0Ph>30080J6QX00@0RXZ:06IVIP1VIVH0L71`0P1YJFT01@1mOGd0NGUi06][J`1[Jf/0Kfm_0080
GUiN00D0Lg=c08:2PP22PX80VYZJ05]KF`0209BDU00509jNWP1iNGT0NGUi06MWI`1lO7`00P1YJFT0
101lO7`0JFUY06UYJ@1SHf<207QhN00308:2P_oooooooooo00Sooooo000:ooooo`040:n_[`2a/K40
/K6a0;Bd]080ZZZZ00D0?Shn05eMG@2CTi<0Ti>C05=CD`0205EEE@0507moO`25QHD0QHF508n?S`28
R8P00P2<S8`01@25QHD0Q8B408B4Q01nOWh0MgMg0080EEEE00@0QHF50;bl_02l_;`0_;bl0P2k^k/0
1@2e]KD0][Jf0;Jf]P2f][H0];Bd0080/;2`00D0/k>c0;2`/02b/[80/[:b0:n_[`0205aLG00507em
O@26QXH0NGUi07UiN@1aLG400P1YJFT01@1WIfL0IFEU06EUI@1QHF40I6AT0080Jf][00D0K6a/07Mg
M`1gMgL0OGem05aLG00209ZJVP0409BDU02GUiL0UiNG0:>SX`80ZJVY00D0Z:RX0:ZZZP2TY:@0Y:BT
0:6QX@020::RXP050:BTY02YZJT0M7Ad07AdM01ZJVX00P2UYJD01@2XZ:P0Zj^[0:^[Z`2ZZZX0Xj>S
0080YJFU00D0Y:BT0:>SX`2SXj<0Y:BT0:>SX`0209nOW`050:2PX00g=cL0=cLg07=cL`2PX:000P2S
Xj<0102VYZH0YjNW0:NWY`2VYZH20:BTY0050::RXP2UYJD0Shn?08n?S`2CTi<00P2JVYX01@1oOgl0
De=C09FEU@2EUID0XZ:R0080Vi^K00D0V9RH0:2PX02PX:00XZ:R0:NWY`020:JVYP050:FUY@2WYjL0
YjNW0:VYZ@2JVYX00P0f=SH01@2LW9`0X:2P0:2PX02XZ:P0[jn_0080Z:RX00@0XZ:R0:FUY@2UYJD0
YZJV0P2UYJD01@2LW9`0UYJF09RHV02HV9P0G5aL0080P82000D0WYjN09ZJVP28R8P0R8R8092@T002
09RHV00509VIV@27QhL0QhN708Z:RP2<S8`00P2=SHd0102PX:00Rh^;08^;R`1eMGDAooooo`0406i^
KP2ZZZX0ZZZZ08B4Q080Hf=S00D0PH610:RXZ02XZ:P0`<300:BTY00208b<S00508V9R@1/K6`0K6a/
08>3P`2NWYh00P22PX80101bLW80E5AD05ADE01oOgl209fMW@05061PH01JFUX0Rh^;08^;R`1lO7`0
0P1`L7001@1mOGd0N7Qh07QhN02e]KD0UiNG0080WIfM00@0/[:b0;^k^`2k^k/0LG5a0P1QHF401@1^
KVh0Y:BT0=;BdP3Bd]80Y:BT0080IFEU00D0PH6107emO@2EUID0UIFE0;Bd]0020=gMg@050;Fe]@2?
Shl0Shn?08N7Q`1QHF400P2>SXh0101eMGD0Q8B408B4Q01/K6`207IfMP050:JVYP2d];@0YjNW0:NW
Y`2CTi<00P2GUiL01@22PX80b<S80;Vi^@2i^KT0][Jf0080UIFE00D0UiNG0:f][@2][Jd0Ph>307al
O00207QhN00405aLG02FUYH0UYJF09:BTP80V9RH00D0Kfm_0:6QX@2][Jd0[Jf]07QhN00205eMG@05
08J6QP2>SXh0/k>c0;>c/`38b<P00P1;Bd/01@2WYjL0hn?S0>?Sh`1cLg<0UYJF0080QHF500@0Shn?
08>3P`23Ph<0^;Rh0P3IfMT01@2JVYX0JFUY0;Jf]P2f][H0UiNG0080S8b<00D0PH610:NWY`2WYjL0
IVIV0;^k^`0206UYJ@0503hn?P0/;2`0;2`/055AD@1kNg/00P1HF5P0102ATI40KVi^06i^KP1^KVh2
06QXJ00506ATI01aLG40Jf][06][J`1ADE400P1GEeL01@1XJ6P0Rh^;08^;R`2[Zj/0J6QX0080Shn?
00D0QhN706YZJP1ZJVX0GEeM06ATI00206e]K@0406UYJ@1VIVH0IVIV05eMG@80RXZ:00<0Rh^;oooo
ooooool02?ooool000[ooooo00@0/k>c0;2`/02`/;00[jn_0P2XZ:P01@11@D40FEUI08R8R028R8P0
BDU90080E5AD00D0NGUi07MgM`1gMgL0Ogmo07YjNP0207alO0050820P01gMgL0MgMg07alO01cLg<0
0P1?Cdl01028R8P0][Jf0;Jf]P2h^;P20;>c/`050:^[Z`2][Jd0ZJVY0:VYZ@2PX:000P2SXj<01@2U
YJD0VYZJ0:NWY`2WYjL0YJFU0080HV9R00D0MWIf08N7Q`25QHD0QHF506=SH`0207=cL`0506QXJ01Q
HF40HF5Q05]KF`1CDe<00P1FEUH01@1QHF40HV9R069RHP1XJ6P0EEEE0080UIFE00@0XJ6Q09fMW@2M
WId0XJ6Q0P2UYJD01@2VYZH0[Zj^0:JVYP2VYZH0Vi^K00<0X:2P00@0YJFU06IVIP1VIVH0JVYZ0`2W
YjL20:b/[0050:BTY02QXJ40Y:BT0:BTY02RXZ800P2QXJ401@2RXZ80Y:BT0::RXP2RXZ80W9bL0080
?3`l00@0LG5a08n?S`2SXj<0Xj>S0`2TY:@01@2IVIT0X:2P0:2PX02SXj<0X:2P0080OWin00D0U9BD
09VIV@2IVIT0KFe]059BDP0209RHV00409ZJVP2KVi/0Vi^K09nOW`80YJFU00D0X:2P0:>SX`2@T900
T92@09nOW`020:ZZZP050:6QX@1`L7009BDU02DU9@2CTi<00P2PX:001@2ZZZX0/;2`0:f][@2][Jd0
[Zj^0080Zj^[00D0XJ6Q09jNWP2NWYh0WYjN09RHV00208^;R`0505ADE01fMWH0MWIf09FEU@2JVYX0
0P2OWil0102;Rh/0R8R808R8R02OWil208Z:RP0507YjNP2>SXh0Y:BT0:BTY02ZZZX00P2<S8`00`1a
LG7oooooooooo`0?ooooo`0406i^KP23Ph<0Ph>306i^KP80GEeM00D0P82009VIV@2IVIT0YZJV08J6
QP0207emO@0507YjNP1ZJVX0JVYZ08j>SP2HV9P00P1hN7P01018B4P0CDe=04e=C@1/K6`20861P@05
06UYJ@1EEED0SXj>08j>SP1YJFT00P1WIfL01@1fMWH0LG5a075aL@2h^;P0T92@0080WIfM00@0/K6a
0;:b/P2b/[80IfMW0P1OGel01@1aLG40Y:BT0<S8b038b<P0Zj^[0080GemO00D0PX:206m_K`28R8P0
R8R80;bl_0020=cLg0050;6a/@21PH40PH610861P@1MGEd00P2<S8`01022PX80Q8B408B4Q01UIFD2
05mOG`0508b<S02RXZ80Vi^K09^KV`24Q8@00P2?Shl01@1oOgl0a/K60;Jf]P2f][H0^[Zj0080VIVI
00D0YZJV09ZJVP2JVYX0Q8B4075aL@02079bLP0305EEE@2IVIT0VIVI00<0V9RH00D0OWin0:BTY02Z
ZZX0ZZZZ075aL@0205]KF`0508J6QP2NWYh0[Zj^0:j^[P34a<@00P19BDT01@2][Jd0gmoO0=oOg`1T
I6@0U9BD0080N7Qh00@0MGEe07moO`1oOgl0[Zj^0P33`l<01@25QHD0IVIV0:b/[02/[:`0UIFE0080
QhN700D0Q8B408j>SP2>SXh0Fe]K0<71`@0206i^KP0504A4A00];Bd0;Bd]05=CD`1iNGT00P1CDe<0
0`2:RXX0LG5a075aL@0306UYJ@80M7Ad0P1]KFd0101UIFD0L71`071`L02<S8`209bLW0050::RXP1i
NGT0UIFE09FEU@2ATI400P1hN7P01@1QHF40L71`06YZJP1ZJVX0EEEE0080LG5a00@0DE5A079bLP1b
LW80S8b<2_ooool000[ooooo00@0[Jf]0:RXZ02XZ:P0Y:BT0P2BTY801@10@400B4Q807inOP1nOWh0
ADE50080EeMG00D0PX:207YjNP1jNWX0Ng]k07inOP02071`L00507YjNP1iNGT0NGUi07YjNP1hN7P0
0P16ATH0101nOWh0/;2`0;2`/02ZZZX309jNWP0409nOW`2PX:00X:2P09ZJVP80S8b<00D0T92@08>3
P`2CTi<0Ti>C09:BTP0206QXJ00506m_K`26QXH0Ph>308>3P`1[Jf/00P1bLW801@1hN7P0QHF508F5
Q@2<S8`0TI6A0080TY:B00D0QXJ607EeM@1eMGD0Lg=c05QHF00208n?S`0409JFUP2CTi<0Ti>C09fM
W@80WYjN00D0XJ6Q0::RXP2HV9P0V9RH08j>SP0208V9R@0508^;R`2FUYH0FUYJ05YJFP1ZJVX00P2S
Xj<30:6QX@0509VIV@2HV9P0WIfM09fMW@2IVIT00P2@T9001@2SXj<0YJFU0::RXP2RXZ80WinO0080
=CDe00D0E5AD07emO@2IVIT0VIVI0::RXP0209NGU`0509BDU02LW9`0W9bL0:>SX`2MWId00P1WIfL0
1@1jNWX0L71`071`L01VIVH0Hf=S0080Xj>S00@0XJ6Q0::RXP2RXZ80YJFU0P2VYZH01@2PX:00UiNG
07MgM`1gMgL0P8200080T92@00D0O7al075aL@0n?Sh0?Shn09:BTP0209jNWP050:^[Z`2YZJT0YZJV
0:JVYP2XZ:P00P2TY:@01@2OWil0WYjN09jNWP2GUiL0WYjN0080Q8B400<0?clo07EeM@1eMGD00P2;
Rh/209FEU@0408B4Q01lO7`0O7al096AT@80MgMg00D0NWYj09nOW`2OWil0WinO0:RXZ00208>3P`03
06][Jooooooooooo00oooooo00@0PX:20;2`/02`/;00Q8B40P1nOWh01@2JVYX0/[:b0;:b/P2UYJD0
RXZ:0080MgMg00D0RHV907=cL`1cLg<0G5aL07]kN`0207inOP0406i^KP25QHD0QHF508>3P`80QhN7
00D0F5QH04U9B@2:RXX0RXZ:06MWI`0205UIF@0507MgM`1WIfL0IfMW0:>SX`20P8000P2EUID0102^
[Zh0X:2P0:2PX01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/01@25QHD0Rh^;08R8
R028R8P0`<300080emOG00D0][Jf08J6QP26QXH0RHV905eMG@0208Z:RP040861P@1mOGd0OGem07If
MP80Hf=S00D0XZ:R0:2PX02`/;00/;2`09NGU`0209BDU00508j>SP3=cLd0`<300<30`032`/800P2T
Y:@01@2`/;00X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0T92@0P2UYJD01@24Q8@0
X:2P0:JVYP2VYZH0KVi^0080HV9R00D0Ng]k09RHV02][Jd0[Jf]0=OGe`0204Q8B00509RHV03Rh^80
h^;R07alO02PX:000`28R8P20861P@050;:b/P3EeMD0eMGE0:BTY01XJ6P00P2NWYh01026QXH0T92@
092@T02=SHd208b<S00505=CD`2a/K40PH610861P@1NGUh00P0n?Sh01@1DE5@0RHV905aLG01LG5`0
Shn?0080MGEe00@0HF5Q05UIF@1IFET0KFe]0`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@050:>S
X`23Ph<0Ti>C09>CT`2<S8`00P1gMgL01@1_Kfl0RHV906][J`1[Jf/0F5QH0080G5aL00@0DE5A06m_
K`1_Kfl0KVi^2_ooool000[ooooo00@0[Jf]0:RXZ02XZ:P0Y:BT0P2BTY801@10@400B4Q807inOP1n
OWh0ADE50080EeMG00D0PX:207YjNP1jNWX0Ng]k07inOP02071`L00507YjNP1iNGT0NGUi07YjNP1h
N7P00P16ATH0101nOWh0/;2`0;2`/02ZZZX309jNWP0409nOW`2PX:00X:2P09ZJVP80S8b<00D0T92@
08>3P`2CTi<0Ti>C09:BTP0206QXJ00506m_K`26QXH0Ph>308>3P`1[Jf/00P1bLW801@1hN7P0QHF5
08F5Q@2<S8`0TI6A0080TY:B00D0QXJ607EeM@1eMGD0Lg=c05QHF00208n?S`0409JFUP2CTi<0Ti>C
09fMW@80WYjN00D0XJ6Q0::RXP2HV9P0V9RH08j>SP0208V9R@0508^;R`2FUYH0FUYJ05YJFP1ZJVX0
0P2SXj<30:6QX@0509VIV@2HV9P0WIfM09fMW@2IVIT00P2@T9001@2SXj<0YJFU0::RXP2RXZ80WinO
0080=CDe00D0E5AD07emO@2IVIT0VIVI0::RXP0209NGU`0509BDU02LW9`0W9bL0:>SX`2MWId00P1W
IfL01@1jNWX0L71`071`L01VIVH0Hf=S0080Xj>S00@0XJ6Q0::RXP2RXZ80YJFU0P2VYZH01@2PX:00
UiNG07MgM`1gMgL0P8200080T92@00D0O7al075aL@0n?Sh0?Shn09:BTP0209jNWP050:^[Z`2YZJT0
YZJV0:JVYP2XZ:P00P2TY:@01@2OWil0WYjN09jNWP2GUiL0WYjN0080Q8B400<0?clo07EeM@1eMGD0
0P2;Rh/209FEU@0408B4Q01lO7`0O7al096AT@80MgMg00D0NWYj09nOW`2OWil0WinO0:RXZ00208>3
P`0306][Jooooooooooo00oooooo00@0PX:20;2`/02`/;00Q8B40P1nOWh01@2JVYX0/[:b0;:b/P2U
YJD0RXZ:0080MgMg00D0RHV907=cL`1cLg<0G5aL07]kN`0207inOP0406i^KP25QHD0QHF508>3P`80
QhN700D0F5QH04U9B@2:RXX0RXZ:06MWI`0205UIF@0507MgM`1WIfL0IfMW0:>SX`20P8000P2EUID0
102^[Zh0X:2P0:2PX01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/01@25QHD0Rh^;
08R8R028R8P0`<300080emOG00D0][Jf08J6QP26QXH0RHV905eMG@0208Z:RP040861P@1mOGd0OGem
07IfMP80Hf=S00D0XZ:R0:2PX02`/;00/;2`09NGU`0209BDU00508j>SP3=cLd0`<300<30`032`/80
0P2TY:@01@2`/;00X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0T92@0P2UYJD01@24
Q8@0X:2P0:JVYP2VYZH0KVi^0080HV9R00D0Ng]k09RHV02][Jd0[Jf]0=OGe`0204Q8B00509RHV03R
h^80h^;R07alO02PX:000`28R8P20861P@050;:b/P3EeMD0eMGE0:BTY01XJ6P00P2NWYh01026QXH0
T92@092@T02=SHd208b<S00505=CD`2a/K40PH610861P@1NGUh00P0n?Sh01@1DE5@0RHV905aLG01L
G5`0Shn?0080MGEe00@0HF5Q05UIF@1IFET0KFe]0`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@05
0:>SX`23Ph<0Ti>C09>CT`2<S8`00P1gMgL01@1_Kfl0RHV906][J`1[Jf/0F5QH0080G5aL00@0DE5A
06m_K`1_Kfl0KVi^2_ooool000[ooooo00@0P82006YZJP1ZJVX0B4Q80P1EEED01@0m?Cd0EEEE06][
J`1[Jf/0CDe=0080HV9R00D0GEeM06IVIP1VIVH0MgMg06MWI`0205UIF@0506a/K01_Kfl0Kfm_06EU
I@1DE5@00P0g=cL0101FEUH0UiNG09NGU`2DU9@2092@T00508V9R@21PH40MWIf07IfMP1eMGD00P1c
Lg<01@1ZJVX0I6AT051@D01@D500A4A40080<c<c00D09RHV05EEE@1?Cdl0Cdm?04Y:BP02055AD@03
04m?C`1UIFD0IFEU0080FUYJ0P1WIfL01@1FEUH0DE5A055AD@1?Cdl09BDU0080D51@00@0FUYJ05IF
EP1FEUH0J6QX0P1/K6`01@1PH600IVIV071`L01`L700IfMW0080FUYJ00D0DU9B05iNGP11@D40@D51
04e=C@0207QhN005075aL@1TI6@0I6AT06QXJ01RHV800P1VIVH01@1GEeL0DE5A055AD@1SHf<0KFe]
0080K6a/00D0IVIV02l_;`0_;bl0?Cdm05MGE`0205aLG00406e]K@1bLW80LW9b06m_K`<0LW9b00@0
IVIV04];B`1;Bd/0DE5A0P0i>CT01@0X:2P0@41005IFEP1FEUH0FEUI0080EEEE0`1NGUh01@1OGel0
FUYJ05iNGP1NGUh0Fe]K0080IfMW00D0EeMG04e=C@0Q8B408B4Q04I6AP0205EEE@05061PH01HF5P0
EeMG05MGE`1OGel00P1NGUh01@1KFe/0E5AD05ADE01DE5@0BTY:0080?Shn00D0:RXZ04=3@`13@d<0
D51@04E5A@0205=CD`0405MGE`1CDe<0De=C05ADE080B4Q800D0A4A404Q8B018B4P0B4Q804a<C002
038b<P0303Ph>?oooooooooo00oooooo00@0QXJ60;>c/`2c/k<0RHV90P2BTY801@2KVi/0Zj^[0:^[
Z`2YZJT0UYJF0080SHf=00@0S8b<07alO01lO7`0Ng]k0`27QhL0101SHf<0GUiN05iNGP1dM7@209nO
W`0506EUI@1?Cdl0Ph>308>3P`1WIfL00P1ADE4306m_K`050:FUY@2DU9@0XZ:R0::RXP2XZ:P00P2K
Vi/01@1QHF40CDe=04e=C@1aLG40WYjN0080b/[:00D0UIFE05EEE@1EEED0P82008N7Q`0208^;R`04
0;Zj^P3De=@0e=CD0:JVYP80PX:200D0SXj>06=SH`21PH40PH6108V9R@0208J6QP0508Z:RP1^KVh0
KVi^0<C4a02TY:@00P2d];@01@2NWYh0UYJF09JFUP27QhL0`L710080aLG500@0^KVi09^KV`2KVi/0
/K6a0P2VYZH01@2=SHd0QHF50820P020P800F5QH0080X:2P00D0T92@09fMW@2MWId0Q8B409nOW`02
0:FUY@05079bLP1SHf<0Hf=S08:2PP2MWId00P2HV9P0103@d=00ATI604I6AP29RHT20=[JfP0508n?
S`2GUiL0Q8B408B4Q01fMWH00P1kNg/01@2WYjL0dM7A0=7Ad@2SXj<0VIVI0080Z:RX00@0XZ:R09fM
W@2MWId0XZ:R0P2MWId01@1EEED0Shn?08n?S`2?Shl0EEEE0080>3Ph00D0D51@07QhN01@D500D51@
08F5Q@0206m_K`0506a/K01BDU80DU9B06ATI01nOWh00P1dM7@0101YJFT0De=C05=CD`1lO7`207Mg
M`0509fMW@20P800WinO09nOW`2CTi<00P1^KVh01@1dM7@0WIfM07=cL`1cLg<0HF5Q0080Fe]K00@0
EUIF06QXJ01XJ6P0Kfm_2_ooool000[ooooo00@0H61P030`<00`<300:2PX0P1DE5@01@1KFe/0DE5A
04A4A014A4@0?Shn008071`L00D08R8R05=CD`1CDe<0De=C04];B`0204U9B@0503Hf=P0L71`071`L
00X:2P1ADE400P1LG5`0101]KFd0J6QX06QXJ01ZJVX20492@P05024Q8@0k>c/0B4Q804Q8B01<C4`0
0P1ADE40101KFe/0A4A402TY:@0Y:BT305]KF`80GUiN0P1QHF401018B4P09RHV02HV9P1GEeL206YZ
JP05075aL@1cLg<0NWYj07YjNP0o?cl00P0U9BD205YJFP80GemO00@0Hf=S05aLG01LG5`0:2PX0P0g
=cL01@1UIFD0LG5a0861P@21PH40MgMg0080LW9b0P0[:b/304E5A@80Cdm?00D0De=C020P800P8200
:RXZ06EUI@0206a/K00505eMG@1RHV80HV9R05mOG`10@4000P19BDT306QXJ00506ATI01QHF40?clo
03lo?`0N7Qh00P16ATH01@1SHf<0HV9R069RHP1[Jf/0Lg=c0080:RXZ00D0AdM707QhN01hN7P0QHF5
08R8R00207]kN`0406IVIP0[:b/0:b/[06YZJP80PH6100D0QhN708V9R@28R8P0R8R804Y:BP020492
@P0506][J`24Q8@0SXj>08j>SP2;Rh/00P1JFUX01@071`L0<c<c05ADE01DE5@0A4A40080>3Ph00D0
HV9R05=CD`1CDe<06ATI06ATI00207]kN`0508R8R02:RXX0RXZ:07emO@1:BTX00P0f=SH306e]K@05
071`L01lO7`0O7al07inOP0n?Sh00P1TI6@01022PX80SXj>08j>SP2DU9@Aooooo`0407emO@2YZJT0
ZJVY08:2PP80WIfM00D0U9BD0:JVYP2VYZH0Zj^[09>CT`0208F5Q@0407QhN01lO7`0O7al07MgM`<0
Ph>30`1kNg/01@1gMgL0Ti>C09>CT`1PH600CDe=0080QXJ600@0Fe]K05UIF@1IFET0IfMW0P1]KFd0
1@2[Zj/0UiNG0:BTY02TY:@0ZZZZ0080WYjN00D0IFEU05aLG01LG5`0Ogmo0:JVYP020=;BdP050:>S
X`1PH600H61P08f=S@2FUYH00P1mOGd0102VYZH0b/[:0<[:bP28R8P206a/K00508J6QP1UIFD0PX:2
08:2PP20P8000P1_Kfl01@1gMgL0GUiN05iNGP30`<00XZ:R0080YJFU00D0U9BD096AT@2ATI40Ng]k
0<W9b@020<C4a0040;bl_02XZ:P0Z:RX0;jn_P80Z:RX00D0Rh^;07inOP1nOWh0OWin05eMG@0209JF
UP0508^;R`2YZJT0ZJVY08^;R`2SXj<00P2g]kL01@1mOGd0K6a/06a/K02=SHd0]KFe0080[jn_00@0
eMGE04I6AP16ATH0WinO0P3De=@01@2/[:`0VIVI08V9R@29RHT0L71`0080QhN700D0Y:BT0<c<c03<
c<`0S8b<08J6QP020:6QX@040:JVYP27QhL0QhN709bLW080WYjN00D0HV9R0:ZZZP2<S8`0S8b<05MG
E`0203Ti>@0505eMG@1nOWh0E5AD05ADE021PH400P1VIVH01@1PH600E5AD05ADE01VIVH0Q8B40080
Kfm_00@0GUiN05=CD`1CDe<0O7al0P21PH401@2h^;P0P8200:FUY@2UYJD0TI6A0080MWIf00D0RXZ:
0:2PX01fMWH0MWIf06EUI@0206YZJP0406IVIP1dM7@0M7Ad08B4Q0[ooooo000:ooooo`04061PH00`
<300<30`02PX:080E5AD00D0Fe]K055AD@14A4@0A4A403hn?P0201`L7005028R8P1CDe<0De=C05=C
D`1;Bd/00P19BDT01@0f=SH071`L01`L700:2PX0DE5A0080G5aL00@0KFe]06QXJ01XJ6P0JVYZ0P12
@T801@0Q8B40>c/k04Q8B018B4P0C4a<0080DE5A00@0Fe]K04A4A00Y:BT0:BTY0`1KFe/205iNGP80
HF5Q00@0B4Q802HV9P0V9RH0EeMG0P1ZJVX01@1aLG40Lg=c07YjNP1jNWX0?clo00809BDU0P1JFUX2
05mOG`0406=SH`1LG5`0G5aL02PX:080=cLg00D0IFEU075aL@21PH40PH6107MgM`02079bLP80:b/[
0`15ADD204m?C`0505=CD`0P8200820P02XZ:P1UIFD00P1/K6`01@1MGEd0HV9R069RHP1OGel0@410
0080BDU90`1XJ6P01@1TI6@0HF5Q03lo?`0o?cl07QhN0080ATI600D0Hf=S069RHP1RHV80Jf][07=c
L`0202XZ:P0504M7A`1hN7P0N7Qh08F5Q@28R8P00P1kNg/0101VIVH0:b/[02/[:`1ZJVX20861P@05
08N7Q`29RHT0R8R808R8R01:BTX00P12@T801@1[Jf/0Q8B408j>SP2>SXh0Rh^;0080FUYJ00D01`L7
03<c<`1DE5@0E5AD04A4A00203Ph>005069RHP1CDe<0De=C01TI6@1TI6@00P1kNg/01@28R8P0RXZ:
08Z:RP1mOGd0BTY:0080=SHf0`1]KFd01@1`L700O7al07alO01nOWh0?Shn0080I6AT00@0PX:208j>
SP2>SXh0U9BD4Oooool0101mOGd0ZJVY0:VYZ@22PX8209fMW@0509BDU02VYZH0YZJV0:^[Z`2CTi<0
0P25QHD0101hN7P0O7al07alO01gMgL308>3P`<0Ng]k00D0MgMg09>CT`2CTi<0H61P04e=C@0208J6
QP0405]KF`1IFET0FEUI06MWI`80KFe]00D0Zj^[09NGU`2TY:@0Y:BT0:ZZZP0209jNWP0506EUI@1L
G5`0G5aL07moO`2VYZH00P3Bd]801@2SXj<0H61P061PH02=SHd0UYJF0080OGem00@0YZJV0<[:bP3:
b/X0R8R80P1/K6`01@26QXH0IFEU08:2PP22PX80P8200080Kfm_00D0MgMg05iNGP1NGUh0`<300::R
XP020:FUY@0509BDU02ATI40TI6A07]kN`39bLT00P34a<@0102l_;`0Z:RX0:RXZ02n_[h20:RXZ005
08^;R`1nOWh0OWin07inOP1MGEd00P2FUYH01@2;Rh/0ZJVY0:VYZ@2;Rh/0Xj>S0080]kNg00D0OGem
06a/K01/K6`0SHf=0;Fe]@020:n_[`040=GEe@16ATH0ATI609nOW`80e=CD00D0[:b/09VIV@29RHT0
RHV9071`L00208N7Q`050:BTY03<c<`0c<c<08b<S026QXH00P2QXJ40102VYZH0QhN708N7Q`2LW9`2
09jNWP05069RHP2ZZZX0S8b<08b<S01GEeL00P0i>CT01@1MGEd0OWin05ADE01DE5@0PH610080IVIV
00D0H61P05ADE01DE5@0IVIV08B4Q00206m_K`0405iNGP1CDe<0De=C07alO080PH6100D0^;Rh0820
P02UYJD0YJFU096AT@0207IfMP0508Z:RP2PX:00MWIf07IfMP1UIFD00P1ZJVX0101VIVH0M7Ad07Ad
M024Q8@:ooooo`002_ooool0102l_;`0JFUY06UYJ@1DE5@20:ZZZP0509BDU027QhL0RHV908V9R@2@
T9000P0h>3P01@19BDT0UiNG09NGU`2TY:@0/;2`0080/k>c00D0Xj>S051@D01@D500:RXZ0;:b/P02
0;>c/`040;Rh^02k^k/0^k^k0;bl_080OGem00D06QXJ09JFUP2UYJD0YJFU09^KV`0309ZJVP0407Qh
N00d=3@0=3@d08J6QP80Q8B400D0MGEe0861P@1kNg/0Ng]k05=CD`0204A4A00508>3P`2=SHd0SHf=
09BDU02<S8`00P2@T9001@1GEeL0=CDe03De=@2RXZ80Vi^K0080UYJF00@0X:2P0::RXP2RXZ80EEEE
0P1QHF400`2UYJD0YZJV0:VYZ@020:VYZ@80TI6A00D0?Shn07alO02;Rh/0Rh^;08R8R00208b<S004
07inOP1iNGT0NGUi055AD@<0XZ:R00D0ZJVY0:^[Z`2[Zj/0R8R806=SH`0207AdM0050:2PX02FUYH0
UYJF08N7Q`2HV9P00P2NWYh01012@T80WIfM09fMW@2KVi/209FEU@050:2PX02NWYh0EUIF05IFEP1i
NGT00P2PX:001@2VYZH0YjNW0:JVYP2VYZH0V9RH0080>CTi00D0S8b<0:RXZ02XZ:P0ZZZZ0:FUY@02
0:BTY00505MGE`1cLg<0Lg=c0:j^[P2d];@00P2c/k<01@2d];@0QHF508F5Q@0E5AD0Ng]k0080YZJV
00@0XZ:R0:FUY@2UYJD0Zj^[0P2BTY801@0N7Qh0Rh^;08n?S`2?Shl0TI6A0080W9bL00D0Y:BT05QH
F00e=CD0=CDe09NGU`020:2PX0050:f][@2d];@0];Bd0;Bd]016ATH00P2@T900102ZZZX0/[:b0;:b
/P2h^;PAooooo`0408N7Q`2/[:`0[:b/08>3P`80Rh^;00D0PH610:RXZ02XZ:P0XZ:R09VIV@0208b<
S00508:2PP1gMgL0MgMg06][J`25QHD00P2@T9001028R8P0PH610861P@24Q8@209JFUP0506m_K`1E
EED0NGUi07UiN@1aLG400P1QHF401@1lO7`0KFe]06e]K@2][Jd0W9bL0080XJ6Q00@0/;2`0:>SX`2S
Xj<0IVIV0P1YJFT01@29RHT0[jn_0=KFeP3Fe]H0WYjN0080GEeM00D0Ph>308N7Q`24Q8@0Q8B40:ZZ
ZP020=OGe`050;>c/`27QhL0QhN709fMW@1JFUX00P24Q8@0101kNg/0OGem07emO@25QHD2071`L005
0<;2`P2`/;00/K6a0;6a/@2HV9P00P2PX:001@28R8P0b/[:0<?3``33`l<0Xj>S0080VIVI00D0_[jn
09jNWP2NWYh0SXj>0820P00207inOP0406MWI`2BTY80TY:B09JFUP80XJ6Q00D0RHV90:RXZ02ZZZX0
ZZZZ06m_K`0206MWI`0507inOP2UYJD0];Bd0;Bd]03>c/h00P14A4@01@2TY:@0hn?S0>?Sh`2_[jl0
TY:B0080S8b<00@0QXJ60::RXP2RXZ80_;bl0P3Cdm<01@2GUiL0PH610:f][@2][Jd0[:b/0080Ogmo
00D0VYZJ09nOW`2OWil0HV9R0:ZZZP0209BDU00504Q8B00`<300<30`061PH02:RXX00P1OGel0101h
N7P0IVIV06IVIP1IFET2055AD@0506YZJP26QXH0Q8B408B4Q02;Rh/00P1FEUH01@20P800UIFE09FE
U@2][Jd0MGEe0080VYZJ00D0NGUi07alO01lO7`0S8b<0;bl_002092@T00405aLG01>CTh0CTi>061P
H080LG5a00<0OGemooooooooool02?ooool000[ooooo00@0^k^k069RHP1RHV80CDe=0P2SXj<01@2V
YZH0X:2P09>CT`2CTi<0Ogmo0080<C4a00D0BDU90:BTY02TY:@0WinO09jNWP020:^[Z`050:RXZ01F
EUH0EUIF02TY:@2^[Zh00P2i^KT0102l_;`0]kNg0;Ng]`2i^KT207AdM00501lO7`2RXZ80YJFU0:FU
Y@2@T9000P2=SHd01@2?Shl0LW9b02d];@0];Bd0R8R80080T92@00D0V9RH092@T01kNg/0Ng]k04M7
A`0203<c<`0507MgM`2ATI40TI6A09VIV@2ATI400P2JVYX01@1DE5@0;2`/02`/;02MWId0XZ:R00<0
W9bL0P2OWil01@1CDe<0J6QX06QXJ02UYJD0ZJVY0080Z:RX00D0X:2P09BDU02DU9@0@d=307QhN002
07]kN`04092@T02DU9@0U9BD06e]K@80C4a<00D0EUIF09:BTP2JVYX0VYZJ0:JVYP020:j^[P050:ZZ
ZP1HF5P0MgMg07MgM`2EUID00P23Ph<01@24Q8@0S8b<08:2PP22PX80CDe=0080XJ6Q00D0X:2P08j>
SP2>SXh0QXJ609JFUP0205YJFP0507inOP2/[:`0[:b/0:ZZZP2YZJT00P2JVYX0102@T900A4A404A4
A02PX:020;2`/0050;>c/`2a/K40[Zj^0:j^[P1XJ6P00P1iNGT01@2][Jd0][Jf0;Rh^02h^;P0][Jf
0080RHV900D03`l?06m_K`2QXJ40XJ6Q0:NWY`020:ZZZP050:f][@2VYZH0YZJV01dM7@21PH400P2E
UID01@2MWId0X:2P0:2PX02KVi/0C4a<0080@D5100@0YjNW0:VYZ@2YZJT0Zj^[0P2/[:`01@2UYJD0
@d=308^;R`2;Rh/0Zj^[0080[Jf]00<0];Bdooooooooool03oooool0101jNWX0YJFU0:FUY@25QHD2
08J6QP0508Z:RP2_[jl0[jn_0:j^[P2EUID00`2=SHd2079bLP0506=SH`1jNWX0Q8B408B4Q01cLg<0
0P1nOWh01@27QhL0ZJVY0:VYZ@1gMgL0DU9B0080RHV900@0NGUi06YZJP1ZJVX0QXJ60P1oOgl01@2h
^;P0VIVI08Z:RP2:RXX0ZZZZ0080X:2P00D0IVIV06ATI01TI6@0J6QX0::RXP020=3@d00509VIV@1N
GUh0GUiN08V9R@2=SHd00P29RHT0102a/K40dm?C0=?Cd`2WYjL207MgM`0507EeM@17AdL0Lg=c07=c
L`1jNWX00P1hN7P01@1TI6@0F5QH05QHF01mOGd0X:2P0080Vi^K00D0VYZJ09jNWP2NWYh0R8R80<K6
aP020;bl_0040;2`/029RHT0RHV90;jn_P80V9RH00D0R8R808^;R`1iNGT0NGUi07MgM`02092@T005
09jNWP2QXJ40XJ6Q08b<S02^[Zh00P2`/;001@1`L700J6QX06QXJ01dM7@0UiNG0080/K6a00@0bl_;
04=3@`13@d<0VIVI0P3Shn<01@2e]KD0UIFE08V9R@29RHT0Rh^;0080Z:RX00D0_[jn0=GEe@3EeMD0
W9bL08>3P`020;:b/P040:f][@27QhL0QhN70::RXP80WYjN00D0Fe]K0:^[Z`2DU9@0U9BD061PH002
03Ph>005079bLP2QXJ40QhN708N7Q`24Q8@00P1bLW801@1`L700CTi>04i>CP1TI6@0Lg=c0080L71`
00@0PH6104];B`1;Bd/0LW9b0P23Ph<01@2][Jd0SHf=0:f][@2][Jd0Shn?0080Ogmo00D0U9BD0:f]
[@2EUID0UIFE05iNGP0206IVIP0405]KF`1YJFT0JFUY07IfMP[ooooo000:ooooo`040;Ng]`1WIfL0
IfMW05EEE@80Y:BT00D0YJFU0:>SX`2MWId0WIfM08:2PP0203`l?00504a<C02OWil0WinO09jNWP2J
VYX00`2TY:@205QHF00502PX:02][Jd0^;Rh0;Rh^02b/[800P2_[jl01@2d];@0MGEe07EeM@0R8R80
WYjN0080XZ:R00D0W9bL09RHV02HV9P0U9BD06e]K@0203Lg=`0508f=S@2IVIT0VIVI08F5Q@2;Rh/0
0P2@T900101OGel0?Cdm03dm?@2>SXh20:BTY0050:ZZZP2TY:@0Y:BT0:BTY01gMgL00P16ATH01@2Q
XJ40XZ:R0::RXP2RXZ80TI6A0080WIfM00D0GUiN06MWI`1WIfL0YjNW0:j^[P020:n_[`050::RXP2C
Ti<0Ti>C03/k>`2>SXh00P2OWil0102ATI40QXJ608J6QP1RHV8203Xj>P050451@@1fMWH0Ogmo07mo
O`2:RXX00P2CTi<01@28R8P0DE5A07UiN@1iNGT0S8b<0080Ogmo00D0Ph>308Z:RP2=SHd0SHf=04M7
A`0208n?S`0509nOW`2HV9P0V9RH08^;R`2JVYX00P1PH6001@1aLG40Z:RX0:RXZ02XZ:P0YjNW0080
W9bL00@0Ti>C03Xj>P0j>SX0[Jf]0P2h^;P01@2d];@0/k>c0;:b/P2b/[80G5aL0080Rh^;00D0]kNg
0;Vi^@2f][H0][Jf0:ZZZP0208J6QP0504A4A021PH40YJFU0:FUY@2[Zj/00P2a/K401@2`/;00WinO
09nOW`0R8R80RXZ:0080UIFE00D0X:2P0:>SX`2SXj<0YjNW05mOG`0205aLG0040:^[Z`2TY:@0Y:BT
096AT@80OGem00D0O7al03Lg=`2;Rh/0Rh^;0:JVYP020:ZZZP030:^[Zooooooooooo00oooooo00@0
RXZ:0:JVYP2VYZH0Rh^;0P22PX801@2MWId0[:b/0:b/[02_[jl0WYjN0080PX:200D0RXZ:07=cL`1c
Lg<0HF5Q07emO@0208^;R`04071`L025QHD0QHF507YjNP80Vi^K00D0Ng]k05IFEP1oOgl0Ogmo065Q
H@02061PH00507]kN`1]KFd0KFe]0;Bd]02DU9@00P25QHD0102a/K40Z:RX0:RXZ01/K6`206QXJ005
065QH@2JVYX0emOG0=OGe`2WYjL00P1YJFT208B4Q080Shn?00@0][Jf0=GEe@3EeMD0[jn_0P1mOGd0
1@24Q8@0GemO09:BTP2BTY80NGUi0080UIFE00D0IFEU07UiN@1iNGT0/K6a0;Ng]`020;:b/P0509FE
U@2NWYh0WYjN08N7Q`3@d=000P34a<@0102[Zj/0R8R808R8R02e]KD208^;R`0507alO021PH40MGEe
07EeM@1nOWh00P2;Rh/01@2SXj<0XJ6Q0:6QX@22PX80_;bl0080Y:BT00D0P82006YZJP1ZJVX0IfMW
09fMW@020;Ng]`040<[:bP1;Bd/0Bd];09jNWP80i>CT00D0/K6a08J6QP1`L700L71`0820P0020:NW
Y`050;:b/P3>c/h0c/k>09fMW@1nOWh00P2`/;000`2VYZH0Ogmo07moO`0309BDU00506m_K`32`/80
TI6A096AT@1?Cdl00P0/;2`01@1cLg<0W9bL07]kN`1kNg/0LW9b0080MGEe00D0N7Qh06QXJ01XJ6P0
Kfm_079bLP0207MgM`0408Z:RP1>CTh0CTi>07]kN`80WinO00D0Y:BT09jNWP2i^KT0^KVi08b<S002
09:BTP050:JVYP2d];@0V9RH09RHV01IFET00P1OGel0101MGEd0GemO05mOG`20P80:ooooo`002_oo
ool0102g]kL0IfMW06MWI`1EEED20:BTY0050:FUY@2SXj<0WIfM09fMW@22PX800P0l?3`01@1<C4`0
WinO09nOW`2NWYh0VYZJ00<0Y:BT0P1HF5P01@0X:2P0[Jf]0;Rh^02h^;P0/[:b0080[jn_00D0];Bd
07EeM@1eMGD08R8R09jNWP020::RXP0509bLW02HV9P0V9RH09BDU01]KFd00P0g=cL01@2=SHd0VIVI
09VIV@25QHD0Rh^;0080T92@00@0GemO03dm?@0m?Cd0SXj>0P2TY:@01@2ZZZX0Y:BT0:BTY02TY:@0
MgMg0080ATI600D0XJ6Q0::RXP2RXZ80XZ:R096AT@0209fMW@0505iNGP1WIfL0IfMW0:NWY`2^[Zh0
0P2_[jl01@2RXZ80Ti>C09>CT`0k>c/0SXj>0080WinO00@0TI6A08J6QP26QXH0HV9R0P0j>SX01@11
@D40MWIf07moO`1oOgl0RXZ:0080Ti>C00D0R8R8055AD@1iNGT0NGUi08b<S00207moO`0508>3P`2:
RXX0SHf=08f=S@17AdL00P2?Shl01@2OWil0V9RH09RHV02;Rh/0VYZJ0080H61P00D0LG5a0:RXZ02X
Z:P0Z:RX0:NWY`0209bLW00409>CT`0j>SX0>SXj0:f][@80^;Rh00D0];Bd0;>c/`2b/[80/[:b05aL
G00208^;R`050;Ng]`2i^KT0][Jf0;Jf]P2ZZZX00P26QXH01@14A4@0PH610:FUY@2UYJD0Zj^[0080
/K6a00D0/;2`09nOW`2OWil08R8R08Z:RP0209FEU@050:2PX02SXj<0Xj>S0:NWY`1OGel00P1LG5`0
102[Zj/0Y:BT0:BTY02ATI4207emO@0507alO00g=cL0Rh^;08^;R`2VYZH00P2ZZZX00`2[Zj_ooooo
ooooo`0?ooooo`0408Z:RP2VYZH0YZJV08^;R`80PX:200D0WIfM0:b/[02/[:`0[jn_09jNWP0208:2
PP0508Z:RP1cLg<0Lg=c065QH@1mOGd00P2;Rh/0101`L700QHF508F5Q@1jNWX209^KV`0507]kN`1F
EUH0Ogmo07moO`1QHF400P1PH6001@1kNg/0KFe]06e]K@2d];@0U9BD0080QHF500@0/K6a0:RXZ02X
Z:P0K6a/0P1XJ6P01@1QHF40VYZJ0=OGe`3GemL0YjNW0080JFUY0P24Q8@208n?S`040;Jf]P3EeMD0
eMGE0:n_[`80OGem00D0Q8B405mOG`2BTY80TY:B07UiN@0209FEU@0506EUI@1iNGT0NGUi0;6a/@2g
]kL00P2b/[801@2EUID0WYjN09jNWP27QhL0d=3@0080a<C400@0Zj^[08R8R028R8P0]KFe0P2;Rh/0
1@1lO7`0PH6107EeM@1eMGD0OWin0080Rh^;00D0Xj>S0:6QX@2QXJ40PX:20;bl_0020:BTY0050820
P01ZJVX0JVYZ06MWI`2MWId00P2g]kL0103:b/X0Bd];04];B`2NWYh20>CTi0050;6a/@26QXH0L71`
071`L020P8000P2WYjL01@2b/[80c/k>0<k>cP2MWId0OWin0080/;2`00<0YZJV07moO`1oOgl00`2D
U9@01@1_Kfl0`/;2096AT@2ATI40Cdm?0080;2`/00D0Lg=c09bLW01kNg/0Ng]k079bLP0207EeM@05
07QhN01XJ6P0J6QX06m_K`1bLW800P1gMgL0102:RXX0CTi>04i>CP1kNg/209nOW`050:BTY02NWYh0
^KVi0;Vi^@2<S8`00P2BTY801@2VYZH0];Bd09RHV02HV9P0FEUI0080GemO00@0GEeM05mOG`1OGel0
P8202_ooool000[ooooo00@0RHV9059BDP1BDU80FEUI0P2KVi/01@2:RXX0VYZJ09^KV`2KVi/0S8b<
0080AdM700D092@T04M7A`17AdL0RXZ:08j>SP0208^;R`0508F5Q@19BDT0BDU901`L7013@d<00P1f
MWH0102FUYH0Vi^K09^KV`1RHV8205aLG003024Q8@27QhL0QhN70080QhN70P21PH401@1hN7P0>c/k
02LW9`0W9bL0BTY:0080FEUI00D0IVIV07IfMP25QHD0QHF505=CD`0204M7A`0507QhN02<S8`0S8b<
09:BTP2CTi<00P2@T9001@19BDT0:BTY02TY:@1^KVh0NWYj0080Ng]k00@0NGUi08b<S02<S8`0DU9B
0P1ADE401@1_Kfl0O7al07UiN@1iNGT0Ng]k0080KFe]00D0;Rh^07EeM@25QHD0QHF506QXJ00205=C
D`0504A4A018B4P0B4Q803<c<`1XJ6P00P1]KFd01@1SHf<0JFUY06UYJ@1VIVH0;bl_0080C4a<00D0
HF5Q06IVIP1VIVH0Hf=S06][J`02069RHP0401HF5P00000000000410@080De=C00D0FEUI06a/K014
A4@0A4A4028R8P0203dm?@0506i^KP1/K6`0JFUY06UYJ@1JFUX00P0`<3001@1EEED0F5QH05QHF01E
EED0B4Q80080A4A400D09BDU05EEE@1EEED0Fe]K06IVIP0206EUI@0505iNGP0b<S80<S8b01DE5@1J
FUX00P1dM7@307MgM`0506a/K01QHF40HF5Q02PX:01;Bd/00P1MGEd306UYJ@0506m_K`10@40071`L
01`L701WIfL00P1YJFT01@1MGEd0Bd];04];B`1:BTX0<c<c0080HV9R00@0JFUY06ATI01TI6@0H61P
4Oooool01023Ph<0Ti>C09>CT`1iNGT207IfMP0509ZJVP2VYZH0YZJV0;>c/`2OWil00P22PX801@2C
Ti<0PX:208:2PP1/K6`0O7al0080RHV900@0Lg=c08b<S02<S8`0L71`0P2IVIT01@1`L700E5AD07Yj
NP1jNWX0F5QH0080CDe=00D0Lg=c07QhN01hN7P0YZJV08J6QP0207IfMP040:6QX@2JVYX0VYZJ06i^
KP80JFUY00D0IFEU09nOW`3MgMd0gMgM0;>c/`02075aL@0508V9R@25QHD0X:2P0:2PX031`L400P3G
emL01@2k^k/0Shn?08n?S`26QXH0Hf=S0080TY:B00@0QHF508^;R`2;Rh/0IfMW0P1lO7`01@2l_;`0
];Bd0;Bd]02d];@0UiNG0080WIfM00D0Shn?0=GEe@36a/H0a/K60:RXZ00208n?S`050<S8b02HV9P0
V9RH08f=S@2ATI400P1cLg<01022PX80S8b<08b<S02VYZH209VIV@050820P034a<@0/K6a0;6a/@2B
TY800P1UIFD01@1/K6`0WYjN0:^[Z`2[Zj/0dm?C0080ATI600D0UiNG0>3Ph03Ph>00YjNW07MgM`02
06EUI@0407MgM`2VYZH0YZJV0;2`/080dM7A00D0Ti>C06UYJ@2YZJT0ZJVY09VIV@0208b<S00508V9
R@2EUID0UIFE08b<S033`l<00P25QHD01@0o?cl0:BTY02TY:@1iNGT0RHV90080Lg=c00@0JVYZ06QX
J01XJ6P0F5QH0P1QHF401@1cLg<0QHF508N7Q`27QhL0U9BD0080FEUI00D0Lg=c09jNWP2NWYh0WinO
08Z:RP020;2`/00508Z:RP2EUID0UIFE0:JVYP2a/K400P2CTi<0101RHV80LW9b079bLP1QHF42061P
H003071`L?oooooooooo00Sooooo000:ooooo`0405mOG`1JFUX0FUYJ04i>CP80820P00D04a<C02DU
9@0R8R808R8R03dm?@0303lo?`80;2`/00D08b<S02`/;00a<C40<C4a03Xj>P020492@P0504U9B@0F
5QH020P800P8200E5AD00P0Q8B401@0S8b<0:RXZ02XZ:P0];Bd0<S8b0080<c<c00@0<C4a03`l?00l
?3`0?Cdm0`10@4001@0R8R802PX:00X:2P12@T80BDU90080@T9200@0>CTi02/[:`0[:b/0?Cdm0P15
ADD01@1<C4`0CDe=04m?C`1?Cdl0EUIF0080EeMG00D0?Cdm01LG5`0^;Rh0;Rh^03dm?@0203Xj>P05
0410@01:BTX0BTY:05IFEP1=CDd00P10@4001@0f=SH0>c/k03/k>`1ADE40DU9B0080;Bd]00@08B4Q
04A4A014A4@0@T920P1<C4`01011@D40@d=304Q8B018B4P304i>CP05059BDP1RHV80Hf=S06=SH`1N
GUh00P0R8R801@0l?3`0EEEE06IVIP1VIVH0MGEe0080Ph>300D0QXJ608B4Q024Q8@0N7Qh079bLP02
08>3P`0508J6QP2=SHd0SHf=06YZJP0g=cL00P1UIFD0101ADE40I6AT06ATI01XJ6P206a/K00506i^
KP1WIfL0EEEE05EEE@1[Jf/00P1nOWh01@21PH40HV9R02`/;00/;2`0D51@0080OWin00D0R8R808J6
QP1cLg<0Lg=c079bLP0207IfMP03079bLP1TI6@0I6AT0080NGUi0P1ZJVX01@11@D40CDe=04e=C@1Z
JVX0KVi^0080PH6100@0QHF50820P020P800Lg=c0P1IFET01@19BDT0JFUY08b<S02<S8`0R8R80080
>SXj00<0DE5Aooooooooool03oooool0101hN7P0TI6A096AT@23Ph<206m_K`050:BTY02SXj<0Xj>S
0::RXP2JVYX00P2<S8`01@2LW9`0Ng]k07]kN`1oOgl0OWin0080SHf=00@0N7Qh07IfMP1fMWH0FEUI
0P2BTY801@1XJ6P0EEEE06m_K`1_Kfl0CDe=0080EeMG00D0OWin07QhN01hN7P0[Jf]092@T00207Ui
N@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0GemO09NGU`3?cll0clo?0:FUY@02061PH0050861P@1T
I6@0UiNG09NGU`2UYJD00P3;bl/01@2ZZZX0P8200820P022PX80HF5Q0080SHf=00@0P82008N7Q`27
QhL0GUiN0P1^KVh01@2IVIT0WinO09nOW`2OWil0T92@0080UIFE00D0MGEe0=WIf@3Bd]80d];B0::R
XP0208B4Q0050<?3``2PX:00X:2P08F5Q@20P8000P1YJFT01020P800M7Ad07AdM02DU9@208N7Q`05
0820P03AdM40Xj>S0:>SX`2MWId00P1_Kfl01@1XJ6P0YjNW0::RXP2RXZ80bl_;0080Bd];00D0TI6A
0=cLg03Lg=`0SHf=07UiN@0206UYJ@0407]kN`2e]KD0]KFe0;Zj^P80clo?00D0UiNG05eMG@2_[jl0
[jn_08n?S`0209>CT`0506IVIP21PH40PH610:BTY02o_kl00P1hN7P01@0h>3P0<C4a034a<@24Q8@0
T92@0080DE5A00@0Lg=c07MgM`1gMgL0H61P0P1aLG401@1JFUX0O7al07QhN01hN7P0QHF50080EUIF
00D0NWYj0:FUY@2UYJD0UiNG08>3P`020:f][@0507alO02=SHd0SHf=0;Fe]@2`/;000P2:RXX0101N
GUh0MGEe07EeM@1ZJVX2065QH@0306MWIooooooooooo00Sooooo000:ooooo`0405mOG`1JFUX0FUYJ
04i>CP80820P00D04a<C02DU9@0R8R808R8R03dm?@0303lo?`80;2`/00D08b<S02`/;00a<C40<C4a
03Xj>P020492@P0504U9B@0F5QH020P800P8200E5AD00P0Q8B401@0S8b<0:RXZ02XZ:P0];Bd0<S8b
0080<c<c00@0<C4a03`l?00l?3`0?Cdm0`10@4001@0R8R802PX:00X:2P12@T80BDU90080@T9200@0
>CTi02/[:`0[:b/0?Cdm0P15ADD01@1<C4`0CDe=04m?C`1?Cdl0EUIF0080EeMG00D0?Cdm01LG5`0^
;Rh0;Rh^03dm?@0203Xj>P050410@01:BTX0BTY:05IFEP1=CDd00P10@4001@0f=SH0>c/k03/k>`1A
DE40DU9B0080;Bd]00@08B4Q04A4A014A4@0@T920P1<C4`01011@D40@d=304Q8B018B4P304i>CP05
059BDP1RHV80Hf=S06=SH`1NGUh00P0R8R801@0l?3`0EEEE06IVIP1VIVH0MGEe0080Ph>300D0QXJ6
08B4Q024Q8@0N7Qh079bLP0208>3P`0508J6QP2=SHd0SHf=06YZJP0g=cL00P1UIFD0101ADE40I6AT
06ATI01XJ6P206a/K00506i^KP1WIfL0EEEE05EEE@1[Jf/00P1nOWh01@21PH40HV9R02`/;00/;2`0
D51@0080OWin00D0R8R808J6QP1cLg<0Lg=c079bLP0207IfMP03079bLP1TI6@0I6AT0080NGUi0P1Z
JVX01@11@D40CDe=04e=C@1ZJVX0KVi^0080PH6100@0QHF50820P020P800Lg=c0P1IFET01@19BDT0
JFUY08b<S02<S8`0R8R80080>SXj00<0DE5Aooooooooool03oooool0101hN7P0TI6A096AT@23Ph<2
06m_K`050:BTY02SXj<0Xj>S0::RXP2JVYX00P2<S8`01@2LW9`0Ng]k07]kN`1oOgl0OWin0080SHf=
00@0N7Qh07IfMP1fMWH0FEUI0P2BTY801@1XJ6P0EEEE06m_K`1_Kfl0CDe=0080EeMG00D0OWin07Qh
N01hN7P0[Jf]092@T00207UiN@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0GemO09NGU`3?cll0clo?
0:FUY@02061PH0050861P@1TI6@0UiNG09NGU`2UYJD00P3;bl/01@2ZZZX0P8200820P022PX80HF5Q
0080SHf=00@0P82008N7Q`27QhL0GUiN0P1^KVh01@2IVIT0WinO09nOW`2OWil0T92@0080UIFE00D0
MGEe0=WIf@3Bd]80d];B0::RXP0208B4Q0050<?3``2PX:00X:2P08F5Q@20P8000P1YJFT01020P800
M7Ad07AdM02DU9@208N7Q`050820P03AdM40Xj>S0:>SX`2MWId00P1_Kfl01@1XJ6P0YjNW0::RXP2R
XZ80bl_;0080Bd];00D0TI6A0=cLg03Lg=`0SHf=07UiN@0206UYJ@0407]kN`2e]KD0]KFe0;Zj^P80
clo?00D0UiNG05eMG@2_[jl0[jn_08n?S`0209>CT`0506IVIP21PH40PH610:BTY02o_kl00P1hN7P0
1@0h>3P0<C4a034a<@24Q8@0T92@0080DE5A00@0Lg=c07MgM`1gMgL0H61P0P1aLG401@1JFUX0O7al
07QhN01hN7P0QHF50080EUIF00D0NWYj0:FUY@2UYJD0UiNG08>3P`020:f][@0507alO02=SHd0SHf=
0;Fe]@2`/;000P2:RXX0101NGUh0MGEe07EeM@1ZJVX2065QH@0306MWIooooooooooo00Sooooo000:
ooooo`040:BTY02MWId0WIfM0:2PX080E5AD00D0BTY:071`L01ZJVX0JVYZ09ZJVP020:6QX@050:2P
X022PX80PX:206e]K@21PH400P2;Rh/01@2[Zj/0[jn_0:n_[`2VYZH0@410008030`<00@0VYZJ0:RX
Z02XZ:P0YjNW0P2XZ:P01@2RXZ80YJFU09nOW`2OWil0T92@0080R8R800D0Vi^K09RHV02LW9`0W9bL
06=SH`0201HF5P050:RXZ02UYJD0WYjN09jNWP2DU9@00P1oOgl01@2BTY80[Zj^0:j^[P2^[Zh0/;2`
0080[Jf]00D0[jn_0;Bd]02d];@0Vi^K024Q8@0209RHV00409nOW`2CTi<0Ti>C08Z:RP80Ph>300D0
TI6A09:BTP2>SXh0SXj>07AdM00208:2PP050:>SX`2[Zj/0P8200820P01=CDd00P2ZZZX01@2KVi/0
V9RH09RHV020P800QXJ60080Ti>C00@0UIFE09fMW@2MWId0WYjN0`2WYjL01@2SXj<0?clo03lo?`1M
GEd0QHF50080Ph>30`2EUID01@2CTi<0UYJF09JFUP2HV9P0Ti>C0080WYjN00D0WinO0::RXP2RXZ80
XZ:R06e]K@0209jNWP0408N7Q`29RHT0RHV90::RXP80X:2P00<0Xj>S09:BTP2?Shl00P2?Shl20:j^
[P050;Bd]02`/;00AdM704M7A`2[Zj/00P2XZ:P01@2RXZ80YjNW0:JVYP2VYZH0Y:BT0080YjNW0`2R
XZ801@2LW9`0UYJF0:>SX`2SXj<0J6QX0080RXZ:00D0XJ6Q09ZJVP2ATI40TI6A09nOW`020:6QX@05
09VIV@1kNg/0Ng]k059BDP24Q8@00P2NWYh0102YZJT0?3`l03`l?01XJ6PAooooo`0406IVIP20P800
P82007alO080Ti>C00D0LG5a09NGU`2GUiL0X:2P08^;R`0208f=S@0509>CT`1cLg<0Lg=c08F5Q@21
PH400P20P8001024Q8@0WYjN09jNWP1YJFT209fMW@0506UYJ@1SHf<0OWin07inOP1DE5@00P1QHF40
1@21PH40NGUi07UiN@2SXj<0QXJ60080MGEe00@0Y:BT09NGU`2GUiL0OGem0P1_Kfl01@1OGel0Z:RX
0=SHf03Hf=P0[Jf]0080GUiN00D0PX:205YJFP2`/;00/;2`0:NWY`020=GEe@050;Zj^P23Ph<0Ph>3
08:2PP1[Jf/00P2EUID0101mOGd0RXZ:08Z:RP1XJ6P2071`L00509nOW`2NWYh0VIVI09VIV@28R8P0
0P2BTY801@1TI6@0b<S80;:b/P2b/[80SHf=0080Ogmo00D0a<C40:j^[P2^[Zh0P82008V9R@0206i^
KP0408V9R@1oOgl0Ogmo09FEU@80MGEe00D0Ng]k0=CDe02LW9`0W9bL0::RXP0207=cL`0506=SH`2b
/[80[Jf]0:f][@2o_kl00P14A4@01@2JVYX0g]kN0=kNgP2b/[80Kfm_0080JVYZ00@0OGem0;Vi^@2i
^KT0alO70P3@d=00102j^[X0HF5Q0:b/[02/[:`308R8R005065QH@28R8P0R8R80;Ng]`2BTY800P1m
OGd01@14A4@0=3@d03@d=01eMGD0O7al0080?3`l0`1lO7`01@1jNWX0M7Ad07AdM01RHV80Q8B40080
Ph>300@0Ti>C05UIF@1IFET0L71`0P2PX:001@2IVIT0QHF50<O7a`37alL0RXZ:0080TI6A00D0YjNW
0:ZZZP1kNg/0Ng]k06IVIP0207alO004071`L01VIVH0IVIV07AdM0[ooooo000:ooooo`0409fMW@2D
U9@0U9BD09RHV080DU9B00D0H61P092@T01dM7@0M7Ad09BDU002092@T00509BDU026QXH0QXJ606UY
J@1nOWh00P2?Shl30:JVYP050:ZZZP1;Bd/0=SHf03Hf=P2RXZ800P2VYZH01@2WYjL0ZZZZ0:ZZZP2Z
ZZX0YZJV0080WinO00<0T92@0861P@21PH400P2CTi<209JFUP0506=SH`0H61P061PH0:2PX02SXj<0
0P2LW9`0102FUYH0OGem07emO@25QHD30:JVYP040:b/[02_[jl0[jn_0:n_[`80/K6a00D0XJ6Q02PX
:02IVIT0VIVI09RHV00209VIV@0508Z:RP1gMgL0MgMg08V9R@2@T9000P2?Shl01@25QHD0Q8B408B4
Q02JVYX0Y:BT0080OWin00@0AdM70:JVYP2VYZH0YJFU0P29RHT01@1kNg/0N7Qh08:2PP22PX80SXj>
0080V9RH00D0VYZJ0:JVYP2XZ:P0Z:RX0:FUY@0204M7A`0506MWI`20P800Rh^;08^;R`2<S8`00P27
QhL01@24Q8@0RHV908V9R@27QhL0QHF50080T92@00D0U9BD08b<S02<S8`0UiNG075aL@020:f][@04
0:2PX02BTY80TY:B09bLW080UYJF00D0WIfM09bLW02ATI40TI6A09FEU@020:FUY@050:ZZZP2_[jl0
C4a<04a<C02DU9@00P2PX:020:ZZZP80YjNW00@0WYjN0:>SX`2SXj<0Y:BT0P2OWil01@2MWId0XJ6Q
0:>SX`2SXj<0Cdm?0080RXZ:00D0WYjN09:BTP23Ph<0Ph>309JFUP0209^KV`0509RHV023Ph<0Ph>3
055AD@24Q8@00P2PX:00102TY:@0ATI604I6AP1cLg<Aooooo`0408B4Q02CTi<0Ti>C08b<S080]kNg
00D0SHf=0:FUY@2UYJD0^;Rh096AT@0208V9R@0509:BTP1YJFT0JFUY08>3P`22PX800P1VIVH01024
Q8@0SHf=08f=S@1UIFD20:>SX`05071`L01_Kfl0QHF508F5Q@1/K6`00P1YJFT01@1kNg/0K6a/06a/
K02RXZ80Ti>C0080MWIf00@0Z:RX08j>SP2>SXh0N7Qh0P1eMGD01@1EEED0Vi^K0=CDe03De=@0Vi^K
0080L71`00D0NWYj04a<C02ZZZX0ZZZZ0:JVYP020=CDe0050<C4a020P800P82007emO@1_Kfl00P2E
UID0101lO7`0UiNG09NGU`1=CDd206IVIP0509FEU@2KVi/0V9RH09RHV02@T9000P2?Shl01@1[Jf/0
f][J0;fm_@2m_Kd0Vi^K0080NWYj00D0`<3009bLW02LW9`0MWIf09:BTP0207EeM@04096AT@20P800
P82009VIV@80M7Ad00D0KVi^0=CDe02GUiL0UiNG092@T00206a/K00505QHF02f][H0YjNW0:NWY`3<
c<`00P16ATH01@2LW9`0gmoO0=oOg`2o_kl0P8200080Jf][00@0MGEe0;>c/`2c/k<0cLg=0P3@d=00
1@2g]kL0Kfm_09^KV`2KVi/0Rh^;0080HV9R00D0MGEe07alO01lO7`0[jn_07IfMP0208b<S00505]K
F`0j>SX0>SXj08F5Q@1lO7`00P1RHV80101WIfL0LW9b079bLP1eMGD20820P005069RHP25QHD0MGEe
07EeM@2?Shl00P1NGUh01@2;Rh/0[:b/0:b/[02@T900MgMg0080aLG500D0QHF509NGU`2GUiL0[jn_
0:VYZ@0208:2PP0405aLG01/K6`0K6a/05IFEP80CTi>00<0K6a/ooooooooool02?ooool000[ooooo
00@0WIfM09BDU02DU9@0V9RH0P1BDU801@1PH600T92@07AdM01dM7@0U9BD0080T92@00D0U9BD08J6
QP26QXH0JFUY07inOP0208n?S`<0YZJV00D0ZZZZ04];B`0f=SH0=SHf0::RXP020:JVYP050:NWY`2Z
ZZX0ZZZZ0:ZZZP2VYZH00P2OWil00`2@T900PH610861P@0209>CT`80UYJF00D0Hf=S01PH600H61P0
X:2P0:>SX`0209bLW00409JFUP1mOGd0OGem08F5Q@<0YZJV00@0[:b/0:n_[`2_[jl0[jn_0P2a/K40
1@2QXJ40:2PX09VIV@2IVIT0V9RH0080VIVI00D0RXZ:07MgM`1gMgL0RHV9092@T00208n?S`0508F5
Q@24Q8@0Q8B409ZJVP2TY:@00P1nOWh01017AdL0YZJV0:JVYP2UYJD208V9R@0507]kN`1hN7P0PX:2
08:2PP2>SXh00P2HV9P01@2JVYX0YZJV0:RXZ02XZ:P0YJFU0080AdM700D0IfMW0820P02;Rh/0Rh^;
08b<S00208N7Q`0508B4Q029RHT0RHV908N7Q`25QHD00P2@T9001@2DU9@0S8b<08b<S02GUiL0LG5a
0080[Jf]00@0X:2P09:BTP2BTY80W9bL0P2FUYH01@2MWId0W9bL096AT@2ATI40UIFE0080YJFU00D0
ZZZZ0:n_[`1<C4`0C4a<09BDU0020:2PX080ZZZZ0P2WYjL0102NWYh0Xj>S0:>SX`2TY:@209nOW`05
09fMW@2QXJ40Xj>S0:>SX`1?Cdl00P2:RXX01@2NWYh0TY:B08>3P`23Ph<0UYJF0080Vi^K00D0V9RH
08>3P`23Ph<0DE5A08B4Q0020:2PX0040:BTY016ATH0ATI607=cLa7ooooo00@0Q8B409>CT`2CTi<0
S8b<0P2g]kL01@2=SHd0YJFU0:FUY@2h^;P0TI6A0080RHV900D0TY:B06UYJ@1YJFT0Ph>308:2PP02
06IVIP0408B4Q02=SHd0SHf=06EUI@80Xj>S00D0L71`06m_K`25QHD0QHF506a/K00206UYJ@0507]k
N`1/K6`0K6a/0::RXP2CTi<00P1fMWH0102XZ:P0SXj>08j>SP1hN7P207EeM@0505EEE@2KVi/0e=CD
0=CDe02KVi/00P1`L7001@1jNWX0C4a<0:ZZZP2ZZZX0YZJV0080e=CD00D0a<C40820P020P800OGem
06m_K`0209FEU@0407alO02GUiL0UiNG04e=C@80IVIV00D0UIFE09^KV`2HV9P0V9RH092@T00208n?
S`0506][J`3Jf]X0_Kfm0;fm_@2KVi/00P1jNWX01@30`<00W9bL09bLW01fMWH0TY:B0080MGEe00@0
TI6A0820P020P800VIVI0P1dM7@01@1^KVh0e=CD09NGU`2GUiL0T92@0080K6a/00D0F5QH0;Jf]P2W
YjL0YjNW0<c<c00204I6AP0509bLW03Ogml0gmoO0;no_`20P8000P1[Jf/0101eMGD0/k>c0;>c/`3=
cLd20=3@d0050;Ng]`1_Kfl0Vi^K09^KV`2;Rh/00P1RHV801@1eMGD0O7al07alO02_[jl0MWIf0080
S8b<00D0Fe]K03Xj>P0j>SX0QHF507alO002069RHP0406MWI`1bLW80LW9b07EeM@80P82000D0HV9R
08F5Q@1eMGD0MGEe08n?S`0205iNGP0508^;R`2/[:`0[:b/092@T01gMgL00P35aLD01@25QHD0UiNG
09NGU`2_[jl0ZJVY0080PX:200@0G5aL06a/K01/K6`0EUIF0P1>CTh00`1/K6coooooooooo`08oooo
o`002_ooool0102YZJT0Xj>S0:>SX`2NWYh205YJFP0505aLG02OWil0NGUi07UiN@2LW9`00P2MWId0
1@2KVi/0V9RH09RHV01dM7@0V9RH0080UiNG00D0YJFU0:b/[02/[:`0Z:RX05MGE`02034a<@040:>S
X`2][Jd0[Jf]0:n_[`80[Zj^00D0Zj^[0:NWY`2RXZ80XZ:R09>CT`0207emO@80SHf=0P2>SXh01@1e
MGD061PH01PH602LW9`0VIVI0080W9bL00@0XJ6Q08J6QP26QXH0O7al0P2RXZ801@2[Zj/0[Zj^0:n_
[`2_[jl0/;2`0080[:b/00D0XJ6Q03Lg=`2KVi/0Vi^K09fMW@020::RXP0509nOW`25QHD0QHF509JF
UP2JVYX00P2LW9`01@27QhL0Q8B408B4Q02MWId0V9RH0080OGem00@0D51@09JFUP2FUYH0YJFU0P2;
Rh/01@1nOWh0O7al08Z:RP2:RXX0VYZJ0080W9bL00D0Xj>S0:FUY@2XZ:P0Z:RX0:BTY00204U9B@05
05QHF01hN7P0SXj>08j>SP2HV9P00P25QHD01@1lO7`0N7Qh07QhN01eMGD0PX:20080R8R800D0RHV9
09BDU02DU9@0SHf=06i^KP020:RXZ0030:BTY02;Rh/0Rh^;00<0WinO00D0Y:BT09NGU`2=SHd0SHf=
09ZJVP020:VYZ@80Zj^[0P11@D401@2JVYX0YjNW0:NWY`2/[:`0[Zj^0080[jn_00@0[Jf]0:ZZZP2Z
ZZX0Zj^[0P2YZJT01@2IVIT0UIFE09BDU02DU9@0De=C0080TI6A00@0Vi^K09fMW@2MWId0WIfM0`2L
W9`01@2SXj<0Ph>308>3P`1LG5`0RHV90080XJ6Q00@0Xj>S05EEE@1EEED0P8204Oooool0101mOGd0
Shn?08n?S`20P8020;2`/00508:2PP2YZJT0ZJVY0;Zj^P2ATI400P23Ph<01@2EUID0LW9b079bLP25
QHD0PX:20080EEEE00@0Rh^;0::RXP2RXZ80HV9R0P2QXJ401@1_Kfl0Lg=c0861P@21PH40JVYZ0080
Fe]K00D0NWYj07]kN`1kNg/0_;bl08^;R`0207MgM`040:FUY@2KVi/0Vi^K07UiN@80Kfm_00D0D51@
08Z:RP39bLT0bLW90:>SX`02071`L00507]kN`18B4P0^KVi0;Vi^@2[Zj/00P3Jf]X01@3Cdm<0S8b<
08b<S02;Rh/0OGem0080TI6A00@0Ogmo09fMW@2MWId0IfMW0P1gMgL01@2^[Zh0];Bd09fMW@2MWId0
WYjN0080Ti>C00D0MGEe0>3Ph034a<@0a<C40:2PX00207emO@050;^k^`2DU9@0U9BD06i^KP2JVYX0
0P1kNg/0102SXj<0S8b<08b<S02UYJD207]kN`0506][J`3Bd]80WYjN09jNWP2GUiL00P1fMWH01@1H
F5P0^;Rh0:VYZ@2YZJT0`<300080>CTi00D0Vi^K0>;RhP3Rh^80^;Rh075aL@0206][J`0407EeM@2/
[:`0[:b/0<O7a`80^k^k00D0Zj^[07UiN@2>SXh0SXj>09ZJVP02065QH@0508Z:RP23Ph<0Ph>309JF
UP2DU9@00P1UIFD01@1/K6`0?clo03lo?`2<S8`0L71`0080SXj>00@0LW9b06][J`1[Jf/0M7Ad0P2<
S8`01@1MGEd0NWYj079bLP1bLW80V9RH0080L71`00D0QhN70:RXZ02XZ:P0S8b<07UiN@020<c<c005
09:BTP2QXJ40XJ6Q0;:b/P2NWYh00P29RHT0101WIfL0J6QX06QXJ01NGUh206i^KP030:FUYOoooooo
oooo00Sooooo000:ooooo`0409jNWP2CTi<0Ti>C08J6QP80;Bd]00D0DE5A09RHV01fMWH0MWIf08j>
SP02092@T00509JFUP2DU9@0U9BD06IVIP21PH400P1lO7`01@2ATI40T92@092@T02LW9`0CTi>0080
51@D00@0Rh^;09:BTP2BTY80Rh^;0P29RHT01@27QhL0P82007emO@1mOGd0MWIf0080J6QX00D0Fe]K
06ATI01JFUX0FUYJ04Q8B00200h>3P0506e]K@1aLG40N7Qh07QhN01eMGD00P1dM7@00`1OGel0PH61
0861P@0207emO@80M7Ad00D0Lg=c06e]K@1]KFd0F5QH02XZ:P02061PH004071`L01mOGd0OGem06AT
I080HF5Q00D0M7Ad079bLP1^KVh0KVi^069RHP0205EEE@05061PH01UIFD0>SXj03Xj>P0m?Cd00P1c
Lg<01@1gMgL0N7Qh07QhN01`L700Jf][0080H61P00D0IfMW06QXJ01XJ6P0H61P05QHF003065QH@80
>SXj00@0>c/k04m?C`1FEUH0EUIF0`1bLW801@1NGUh0IVIV06IVIP1LG5`0CDe=0080A4A400D0=cLg
02DU9@0U9BD0CDe=01/K6`0205IFEP0405]KF`1?Cdl0Cdm?06=SH`80GemO00D0IVIV05ADE01:BTX0
BTY:05iNGP0205eMG@0506=SH`1YJFT08R8R028R8P1OGel00P1`L7001@1]KFd0L71`05QHF01HF5P0
JFUY0080L71`00D0J6QX06UYJ@1YJFT0E5AD03Ph>00203dm?@0504a<C01@D500D51@05YJFP1QHF40
0P1SHf<0101PH600GUiN05iNGP1KFe/204I6AP0503Xj>P11@D40D51@051@D019BDT00P0/;2`00`0d
=3Coooooooooo`0?ooooo`0407moO`2BTY80TY:B0861P@80VYZJ00D0NGUi0:6QX@2QXJ40]kNg09:B
TP0208^;R`0509JFUP1kNg/0Ng]k0861P@2=SHd00P1KFe/01025QHD0XZ:R0::RXP1_Kfl20:BTY004
06m_K`1YJFT0MGEe07EeM@<0FUYJ00D0Ogmo07UiN@1iNGT0^;Rh09>CT`0208:2PP030:f][@2MWId0
WIfM00<0O7al00D0FEUI09:BTP3?cll0clo?0:ZZZP0207UiN@0507emO@18B4P0_;bl0;bl_02IVIT0
0P3Cdm<01@39bLT0QHF508F5Q@1dM7@0KFe]0080R8R800@0MgMg09BDU02DU9@0KFe]0P1^KVh01@2R
XZ80/[:b0:2PX02PX:00WIfM0080V9RH00D0NWYj0=WIf@2i^KT0^KVi09RHV00208R8R0050:n_[`2G
UiL0UiNG06QXJ02MWId00P2;Rh/0102OWil0S8b<08b<S02VYZH207QhN00506ATI03Cdm<0X:2P0:2P
X023Ph<00P1oOgl01@1HF5P0`<300:^[Z`2[Zj/0aLG50080=3@d00D0XJ6Q0>?Sh`3Shn<0_;bl06YZ
JP0206QXJ00407AdM02WYjL0YjNW0;^k^`80a/K600D0UYJF07alO029RHT0RHV909VIV@0207IfMP05
07QhN020P800P82006QXJ02m_Kd00P1VIVH01@1CDe<0;2`/02`/;01ZJVX0IFEU0080R8R800@0RXZ:
079bLP1bLW80KVi^0P1nOWh01@1MGEd0Lg=c05eMG@1MGEd0Ph>30080Lg=c00D0PH6109nOW`2OWil0
Ph>306e]K@020<G5a@05092@T02?Shl0Shn?0;2`/02KVi/00P2RXZ80101aLG40HV9R069RHP1YJFT2
07emO@030:>SXooooooooooo00Sooooo000:ooooo`0403dm?@0c<c<0<c<c034a<@80;Bd]00D0=3@d
03Ph>00n?Sh0?Shn03Ph>00203`l?004020P800?3`l03`l?018B4P<04a<C00D0410@01PH600H61P0
9BDU03De=@02038b<P0402XZ:P0];Bd0;Bd]03De=@80<C4a00D0<c<c014A4@0a<C40<C4a02h^;P02
02TY:@0502DU9@0R8R806a/K01/K6`0R8R800P0S8b<01@0O7al08b<S02LW9`0W9bL092@T00807AdM
00D04a<C02TY:@0Y:BT0;Bd]028R8P03034a<@80:b/[00D0<C4a03lo?`0o?cl0?clo03@d=00202XZ
:P05030`<00M7Ad07AdM01dM7@0e=CD00P0X:2P01@0Q8B409BDU02DU9@0_;bl0=SHf0080>CTi00@0
?Shn03<c<`0c<c<092@T0P0V9RH01@0I6AT04A4A01hN7P0N7Qh0;Bd]0080;bl_00D0?clo04M7A`0n
?Sh0?Shn03Ti>@0202d];@0503Xj>P0f=SH0BDU904U9B@0m?Cd00P0];Bd01@0S8b<0Cdm?04m?C`1=
CDd0Cdm?0080D51@00D0GEeM06IVIP1VIVH0IVIV05eMG@0204M7A`0403/k>`1:BTX0BTY:04U9B@80
92@T00D0AdM705]KF`1MGEd0GEeM05iNGP0205QHF005065QH@1JFUX0H61P061PH01KFe/00P1HF5P0
1@1DE5@0EeMG02HV9P0V9RH0ADE50080H61P00D0KFe]071`L01`L700MgMg07QhN00208R8R0050820
P01dM7@0M7Ad06YZJP1[Jf/00P20P800101EEED0<30`030`<01TI6@207AdM00507QhN023Ph<0U9BD
09BDU02IVIT00P2NWYh00`2KVi_oooooooooo`0?ooooo`0408B4Q02=SHd0SHf=07UiN@80RXZ:00D0
QXJ60;Jf]P2f][H0/[:b09:BTP0208B4Q00509^KV`1eMGD0MGEe07EeM@2=SHd00P1JFUX01026QXH0
VIVI09VIV@1fMWH208R8R00406YZJP1RHV80PX:208:2PP<0Fe]K00D0Lg=c07moO`1oOgl0/;2`08B4
Q00207alO0<0Xj>S00D0Q8B407inOP1nOWh0GUiN0:2PX0020<c<c0050:RXZ01mOGd0OGem08B4Q014
A4@00P2h^;P0102MWId0f][J0=[JfP3Bd]82096AT@0508N7Q`1TI6@0S8b<08b<S01nOWh00P2FUYH0
1@1oOgl0MWIf07IfMP2YZJT0/k>c0080XZ:R00D0X:2P08n?S`2?Shl0NGUi0=CDe0020;6a/@0408n?
S`1nOWh0OWin0:VYZ@80QhN700D0H61P09JFUP2=SHd0SHf=0:JVYP0208^;R`050:BTY01eMGD0MGEe
05iNGP3=cLd00P2JVYX01@28R8P0QXJ608J6QP1HF5P0`/;20080Zj^[00@0a/K602PX:00X:2P0/;2`
0P3Ti>@01@2`/;00Kfm_07EeM@1eMGD0LW9b0080WYjN00D0`l?30<g=c@3=cLd0XJ6Q09:BTP0208n?
S`040:JVYP1jNWX0NWYj08n?S`80P82000D0O7al0:BTY01]KFd0KFe]04U9B@02038b<P05075aL@1V
IVH0LG5a075aL@2@T9000P1jNWX01@1iNGT0Lg=c07=cL`1_Kfl0Jf][0080KVi^00@0MgMg075aL@1a
LG40NWYj0P2RXZ801@1dM7@0IfMW0<C4a034a<@0UYJF0080QhN700D0[Jf]08N7Q`1/K6`0K6a/07Yj
NP02079bLP0406][J`1iNGT0NGUi06i^KP[ooooo000:ooooo`0403dm?@0c<c<0<c<c034a<@80;Bd]
00D0=3@d03Ph>00n?Sh0?Shn03Ph>00203`l?004020P800?3`l03`l?018B4P<04a<C00D0410@01PH
600H61P09BDU03De=@02038b<P0402XZ:P0];Bd0;Bd]03De=@80<C4a00D0<c<c014A4@0a<C40<C4a
02h^;P0202TY:@0502DU9@0R8R806a/K01/K6`0R8R800P0S8b<01@0O7al08b<S02LW9`0W9bL092@T
00807AdM00D04a<C02TY:@0Y:BT0;Bd]028R8P03034a<@80:b/[00D0<C4a03lo?`0o?cl0?clo03@d
=00202XZ:P05030`<00M7Ad07AdM01dM7@0e=CD00P0X:2P01@0Q8B409BDU02DU9@0_;bl0=SHf0080
>CTi00@0?Shn03<c<`0c<c<092@T0P0V9RH01@0I6AT04A4A01hN7P0N7Qh0;Bd]0080;bl_00D0?clo
04M7A`0n?Sh0?Shn03Ti>@0202d];@0503Xj>P0f=SH0BDU904U9B@0m?Cd00P0];Bd01@0S8b<0Cdm?
04m?C`1=CDd0Cdm?0080D51@00D0GEeM06IVIP1VIVH0IVIV05eMG@0204M7A`0403/k>`1:BTX0BTY:
04U9B@8092@T00D0AdM705]KF`1MGEd0GEeM05iNGP0205QHF005065QH@1JFUX0H61P061PH01KFe/0
0P1HF5P01@1DE5@0EeMG02HV9P0V9RH0ADE50080H61P00D0KFe]071`L01`L700MgMg07QhN00208R8
R0050820P01dM7@0M7Ad06YZJP1[Jf/00P20P800101EEED0<30`030`<01TI6@207AdM00507QhN023
Ph<0U9BD09BDU02IVIT00P2NWYh00`2KVi_oooooooooo`0?ooooo`0408B4Q02=SHd0SHf=07UiN@80
RXZ:00D0QXJ60;Jf]P2f][H0/[:b09:BTP0208B4Q00509^KV`1eMGD0MGEe07EeM@2=SHd00P1JFUX0
1026QXH0VIVI09VIV@1fMWH208R8R00406YZJP1RHV80PX:208:2PP<0Fe]K00D0Lg=c07moO`1oOgl0
/;2`08B4Q00207alO0<0Xj>S00D0Q8B407inOP1nOWh0GUiN0:2PX0020<c<c0050:RXZ01mOGd0OGem
08B4Q014A4@00P2h^;P0102MWId0f][J0=[JfP3Bd]82096AT@0508N7Q`1TI6@0S8b<08b<S01nOWh0
0P2FUYH01@1oOgl0MWIf07IfMP2YZJT0/k>c0080XZ:R00D0X:2P08n?S`2?Shl0NGUi0=CDe0020;6a
/@0408n?S`1nOWh0OWin0:VYZ@80QhN700D0H61P09JFUP2=SHd0SHf=0:JVYP0208^;R`050:BTY01e
MGD0MGEe05iNGP3=cLd00P2JVYX01@28R8P0QXJ608J6QP1HF5P0`/;20080Zj^[00@0a/K602PX:00X
:2P0/;2`0P3Ti>@01@2`/;00Kfm_07EeM@1eMGD0LW9b0080WYjN00D0`l?30<g=c@3=cLd0XJ6Q09:B
TP0208n?S`040:JVYP1jNWX0NWYj08n?S`80P82000D0O7al0:BTY01]KFd0KFe]04U9B@02038b<P05
075aL@1VIVH0LG5a075aL@2@T9000P1jNWX01@1iNGT0Lg=c07=cL`1_Kfl0Jf][0080KVi^00@0MgMg
075aL@1aLG40NWYj0P2RXZ801@1dM7@0IfMW0<C4a034a<@0UYJF0080QhN700D0[Jf]08N7Q`1/K6`0
K6a/07YjNP02079bLP0406][J`1iNGT0NGUi06i^KP[ooooo000:ooooo`0309BDU02IVIT0VIVI00<0
YjNW00D0Zj^[0:ZZZP2_[jl0[jn_0:^[Z`020:FUY@0405]KF`0@4100410@07MgM`<0OGem00D0Ng]k
08Z:RP2:RXX0TI6A08V9R@0208^;R`0409>CT`2LW9`0W9bL09ZJVP80XJ6Q00D0VIVI02l_;`2MWId0
WIfM09BDU00209FEU@0508J6QP1lO7`0Ogmo07moO`27QhL00P2DU9@01@27QhL0Shn?09FEU@2EUID0
U9BD0080MGEe00D0:b/[09RHV02HV9P0VYZJ0:FUY@020:NWY`050:BTY027QhL0QhN70::RXP2VYZH0
0P2YZJT0102ZZZX0WYjN09jNWP2UYJD2079bLP0506IVIP2VYZH0YZJV0:JVYP2TY:@00P2LW9`01@2S
Xj<0XZ:R0:NWY`2WYjL0Y:BT0080Xj>S00D0Y:BT0:VYZ@2YZJT0TI6A04M7A`02079bLP0509ZJVP2K
Vi/0Vi^K09^KV`2CTi<00P2LW9`01@2FUYH0R8R808R8R02FUYH0Ti>C0080XJ6Q00@0[:b/09NGU`2G
UiL0FEUI0P2][Jd01@2ZZZX0Xj>S0:RXZ02XZ:P0[Jf]0080[:b/00D0/K6a0:n_[`2WYjL0YjNW0:j^
[P020:f][@050:NWY`1BDU80DU9B09RHV02`/;000P2WYjL01@2UYJD0Xj>S0:>SX`2WYjL0XZ:R0080
Xj>S00D0SHf=07alO01lO7`0Ph>30:VYZ@0205EEE@040820P02_[jl0[jn_0:n_[`80[Jf]00D0YZJV
09RHV02VYZH0YZJV09fMW@020:6QX@050:2PX026QXH0YjNW0:NWY`1fMWH00P1=CDd01@2IVIT0RXZ:
08Z:RP2JVYX0YJFU0080[jn_00@0/k>c0;Fe]@2e]KD0/[:b4Oooool01022PX80UYJF09JFUP23Ph<2
09:BTP0508R8R02e]KD0]KFe0:VYZ@2EUID00P26QXH01@2WYjL0Ogmo07moO`1/K6`0RHV90080De=C
00@0QHF5096AT@2ATI40MGEe0P2MWId01@20P800Jf][07=cL`1cLg<0DU9B0080D51@00D0NWYj07Qh
N01hN7P0/k>c08N7Q`0207inOP040:NWY`2NWYh0WYjN08B4Q080QXJ600D0IFEU08Z:RP37alL0alO7
0:VYZ@0208:2PP0508V9R@18B4P0]kNg0;Ng]`2UYJD00P3MgMd01@3De=@0TY:B09:BTP23Ph<0GemO
0080SHf=00@0KFe]08b<S02<S8`0Ph>30P1XJ6P01@2TY:@0YJFU09fMW@2MWId0XJ6Q0080SHf=00D0
PH610=?Cd`2TY:@0Y:BT096AT@0207emO@050:b/[028R8P0R8R806IVIP2DU9@00P23Ph<0102;Rh/0
OGem07emO@2DU9@207IfMP05065QH@3=cLd0V9RH09RHV01`L7000P1mOGd01@1GEeL0b/[:0:ZZZP2Z
ZZX0`/;200806QXJ00D0]kNg0>;RhP3Rh^80Ti>C07inOP0207UiN@0407EeM@2SXj<0Xj>S0;jn_P80
_;bl00D0Rh^;0::RXP2>SXh0SXj>0:ZZZP0207]kN`0509ZJVP1/K6`0K6a/0:VYZ@2ATI400P1/K6`0
1@17AdL0;bl_02l_;`1lO7`0HV9R0080FEUI00@0V9RH06a/K01/K6`0IfMW0P1OGel01@2BTY80Kfm_
075aL@1aLG40J6QX0080Ph>300D0Ogmo09VIV@2IVIT0Ph>306EUI@020<71`@0509nOW`1mOGd0OGem
0:6QX@2=SHd00P24Q8@0101NGUh0IVIV06IVIP1IFET20861P@0306ATI?oooooooooo00Sooooo000:
ooooo`040:2PX025QHD0QHF5092@T0<0W9bL00@0XJ6Q0:FUY@2UYJD0YJFU0P2MWId01@2;Rh/08R8R
028R8P23Ph<0T92@0080WIfM00D0UYJF08J6QP26QXH0QhN707moO`0208B4Q004092@T02BTY80TY:B
09bLW080VYZJ00D0V9RH03`l?02BTY80TY:B0:JVYP020:>SX`050:6QX@28R8P0P8200820P02;Rh/0
0`2DU9@0102EUID0SXj>08j>SP2MWId208^;R`0503De=@1/K6`0K6a/079bLP1lO7`00P1fMWH01@29
RHT0RXZ:08Z:RP2JVYX0UiNG0080Y:BT00@0X:2P0::RXP2RXZ80Xj>S0P1oOgl01@1>CTh0PH6108R8
R028R8P0OWin0080Q8B400D0Ph>308^;R`2DU9@0U9BD092@T00208j>SP05092@T02ATI40TI6A09:B
TP1KFe/00P1OGel01@2;Rh/0Shn?08n?S`2LW9`0Ti>C0080T92@00D0QhN708B4Q024Q8@0Shn?09NG
U`0209ZJVP040:RXZ02@T900T92@06QXJ080Zj^[00D0[Jf]0:NWY`2XZ:P0Z:RX0:ZZZP020:^[Z`05
0:RXZ02/[:`0[Jf]0:f][@2e]KD00P2`/;001@2XZ:P0Fe]K05]KF`2ZZZX0[Zj^0080Y:BT00D0Vi^K
0::RXP2RXZ80ZZZZ0:^[Z`020:b/[00509^KV`2IVIT0VIVI0:>SX`2YZJT00P1PH6000`27QhL0[Jf]
0:f][@030:f][@050:NWY`2MWId0Y:BT0:BTY02RXZ800P2NWYh01@2PX:00Ti>C0:RXZ02XZ:P0Lg=c
0080GemO00D0UIFE08R8R028R8P0U9BD09FEU@0209ZJVP040:FUY@2^[Zh0[Zj^0;6a/A7ooooo00@0
Rh^;08V9R@29RHT0K6a/0P1hN7P01@1lO7`0[jn_0:n_[`2][Jd0V9RH0080P82000D0YZJV08J6QP26
QXH0NWYj08b<S00205MGE`0408N7Q`1mOGd0OGem06i^KP80XJ6Q00D0LG5a061PH01_Kfl0Kfm_04];
B`0204a<C005071`L01eMGD0MGEe0:ZZZP21PH400P1fMWH0102WYjL0W9bL09bLW01kNg/208F5Q@05
06UYJ@2JVYX0b/[:0<[:bP2TY:@00P1jNWX01@22PX80BTY:0;Rh^02h^;P0YJFU0080fm_K00D0b/[:
08f=S@2=SHd0Ng]k065QH@0208N7Q`0406i^KP2@T900T92@06YZJP80HV9R00D0Vi^K06IVIP25QHD0
QHF509NGU`0208n?S`0507moO`3IfMT0[Zj^0:j^[P2;Rh/00P1]KFd0102VYZH0SXj>08j>SP1_Kfl3
09VIV@0409ZJVP2@T900T92@0:2PX080Ng]k00D0HV9R0<c<c02IVIT0VIVI06e]K@0207inOP05055A
D@2k^k/0XZ:R0::RXP33`l<00P0n?Sh0102UYJD0hn?S0>?Sh`2@T90308F5Q@0407]kN`2HV9P0V9RH
0<c<c080b<S800D0NWYj0:NWY`29RHT0RHV90:JVYP0207moO`0509BDU01/K6`0K6a/09fMW@2FUYH0
0P1VIVH01@1BDU80@4100410@01aLG40G5aL0080H61P00@0TY:B09BDU02DU9@0O7al0P1_Kfl01@2M
WId0JFUY06MWI`1WIfL0D51@0080PH6100D0Ph>309>CT`2CTi<0Q8B406QXJ0020;Zj^P0509jNWP1d
M7@0M7Ad08f=S@2GUiL00P1mOGd0101KFe/0FEUI05UIF@1dM7@209BDU00308J6Q_oooooooooo00So
oooo000:ooooo`040:2PX025QHD0QHF5092@T0<0W9bL00@0XJ6Q0:FUY@2UYJD0YJFU0P2MWId01@2;
Rh/08R8R028R8P23Ph<0T92@0080WIfM00D0UYJF08J6QP26QXH0QhN707moO`0208B4Q004092@T02B
TY80TY:B09bLW080VYZJ00D0V9RH03`l?02BTY80TY:B0:JVYP020:>SX`050:6QX@28R8P0P8200820
P02;Rh/00`2DU9@0102EUID0SXj>08j>SP2MWId208^;R`0503De=@1/K6`0K6a/079bLP1lO7`00P1f
MWH01@29RHT0RXZ:08Z:RP2JVYX0UiNG0080Y:BT00@0X:2P0::RXP2RXZ80Xj>S0P1oOgl01@1>CTh0
PH6108R8R028R8P0OWin0080Q8B400D0Ph>308^;R`2DU9@0U9BD092@T00208j>SP05092@T02ATI40
TI6A09:BTP1KFe/00P1OGel01@2;Rh/0Shn?08n?S`2LW9`0Ti>C0080T92@00D0QhN708B4Q024Q8@0
Shn?09NGU`0209ZJVP040:RXZ02@T900T92@06QXJ080Zj^[00D0[Jf]0:NWY`2XZ:P0Z:RX0:ZZZP02
0:^[Z`050:RXZ02/[:`0[Jf]0:f][@2e]KD00P2`/;001@2XZ:P0Fe]K05]KF`2ZZZX0[Zj^0080Y:BT
00D0Vi^K0::RXP2RXZ80ZZZZ0:^[Z`020:b/[00509^KV`2IVIT0VIVI0:>SX`2YZJT00P1PH6000`27
QhL0[Jf]0:f][@030:f][@050:NWY`2MWId0Y:BT0:BTY02RXZ800P2NWYh01@2PX:00Ti>C0:RXZ02X
Z:P0Lg=c0080GemO00D0UIFE08R8R028R8P0U9BD09FEU@0209ZJVP040:FUY@2^[Zh0[Zj^0;6a/A7o
oooo00@0Rh^;08V9R@29RHT0K6a/0P1hN7P01@1lO7`0[jn_0:n_[`2][Jd0V9RH0080P82000D0YZJV
08J6QP26QXH0NWYj08b<S00205MGE`0408N7Q`1mOGd0OGem06i^KP80XJ6Q00D0LG5a061PH01_Kfl0
Kfm_04];B`0204a<C005071`L01eMGD0MGEe0:ZZZP21PH400P1fMWH0102WYjL0W9bL09bLW01kNg/2
08F5Q@0506UYJ@2JVYX0b/[:0<[:bP2TY:@00P1jNWX01@22PX80BTY:0;Rh^02h^;P0YJFU0080fm_K
00D0b/[:08f=S@2=SHd0Ng]k065QH@0208N7Q`0406i^KP2@T900T92@06YZJP80HV9R00D0Vi^K06IV
IP25QHD0QHF509NGU`0208n?S`0507moO`3IfMT0[Zj^0:j^[P2;Rh/00P1]KFd0102VYZH0SXj>08j>
SP1_Kfl309VIV@0409ZJVP2@T900T92@0:2PX080Ng]k00D0HV9R0<c<c02IVIT0VIVI06e]K@0207in
OP05055AD@2k^k/0XZ:R0::RXP33`l<00P0n?Sh0102UYJD0hn?S0>?Sh`2@T90308F5Q@0407]kN`2H
V9P0V9RH0<c<c080b<S800D0NWYj0:NWY`29RHT0RHV90:JVYP0207moO`0509BDU01/K6`0K6a/09fM
W@2FUYH00P1VIVH01@1BDU80@4100410@01aLG40G5aL0080H61P00@0TY:B09BDU02DU9@0O7al0P1_
Kfl01@2MWId0JFUY06MWI`1WIfL0D51@0080PH6100D0Ph>309>CT`2CTi<0Q8B406QXJ0020;Zj^P05
09jNWP1dM7@0M7Ad08f=S@2GUiL00P1mOGd0101KFe/0FEUI05UIF@1dM7@209BDU00308J6Q_oooooo
oooo00Sooooo000:ooooo`040:2PX027QhL0QhN708Z:RP80UIFE00D0Ti>C09jNWP2IVIT0VIVI09JF
UP0208^;R`0507alO00e=CD0=CDe08J6QP2EUID00`2NWYh208b<S00508j>SP1lO7`0KFe]06e]K@2>
SXh00P2LW9`01@2TY:@0WYjN09jNWP27QhL0@T920080V9RH00D0Xj>S0:ZZZP2ZZZX0ZZZZ09RHV002
08V9R@050:6QX@2SXj<0Xj>S0:BTY02VYZH00P2RXZ80102VYZH0QHF508F5Q@0f=SH209VIV@0509nO
W`2VYZH0WIfM09fMW@20P8000P2ATI401@2HV9P0Q8B408V9R@29RHT0S8b<0080Vi^K00D0XZ:R08>3
P`23Ph<0CDe=08>3P`0208N7Q`0508B4Q01iNGT0NGUi07alO01oOgl00P26QXH0102>SXh0QHF508F5
Q@2=SHd20820P00507inOP1?Cdl0KVi^06i^KP2BTY800P2@T9001@2HV9P0YZJV09nOW`2OWil0Rh^;
0080Shn?00D0W9bL09fMW@2HV9P0V9RH0:>SX`0208b<S00505QHF02a/K40/K6a0;>c/`2][Jd00P2`
/;001@2][Jd0[:b/0:b/[02^[Zh0/[:b0080];Bd00@0]kNg0;Fe]@2e]KD0[Jf]0P18B4P01@2NWYh0
/;2`0:ZZZP2ZZZX0[Jf]0080[jn_00D0]KFe0:j^[P2e]KD0]KFe0:b/[0020:6QX@050:VYZ@2/[:`0
FEUI05UIF@25QHD00P2^[Zh30:b/[0030:NWY`2RXZ80Z:RX00@0Z:RX00D0YjNW0:6QX@2f][H0][Jf
08F5Q@0206QXJ00508R8R01kNg/0Ng]k08R8R021PH400P26QXH0102QXJ40Z:RX0:RXZ02XZ:PAoooo
o`0407emO@25QHD0QHF507AdM080U9BD00D0Shn?0;2`/02`/;00^KVi096AT@020820P00509jNWP1k
Ng/0Ng]k0820P02EUID00P1MGEd0102=SHd0UIFE09FEU@1]KFd209bLW00506i^KP1OGel0HV9R069R
HP1;Bd/00P1:BTX01@1gMgL0IVIV06IVIP2LW9`0NWYj0080PH6100@0ZZZZ0:FUY@2UYJD0QXJ60P1k
Ng/01@1IFET0SXj>0<C4a034a<@0Zj^[0080N7Qh00D0O7al04e=C@2^[Zh0[Zj^08n?S`020=?Cd`05
0<_;b`2;Rh/0Rh^;07moO`1/K6`00P2>SXh0101]KFd0Shn?08n?S`1WIfL206YZJP050:j^[P2>SXh0
UiNG09NGU`2MWId00P2;Rh/01@1gMgL0e=CD0:>SX`2SXj<0SHf=0080QHF500D0[Zj^09VIV@2IVIT0
NGUi08j>SP0209jNWP04096AT@2=SHd0SHf=0:BTY080PX:200D0GUiN0=CDe02NWYh0WYjN079bLP02
08b<S00505]KF`2k^k/0XJ6Q0:6QX@2n_[h00P1EEED01@2OWil0h^;R0>;RhP2>SXh0Ogmo0080Rh^;
00@0RXZ:09^KV`2KVi/0`L710P2m_Kd01@23Ph<0ZJVY08j>SP2>SXh0W9bL0080RXZ:00D0U9BD07Ad
M01dM7@0Y:BT09JFUP0206i^KP0505EEE@1<C4`0C4a<07YjNP1TI6@00P1YJFT0101eMGD0QhN708N7
Q`1fMWH207]kN`05096AT@1_Kfl0F5QH05QHF018B4P00P1WIfL01@1iNGT0Ti>C09>CT`2@T900I6AT
0080Xj>S00D0UiNG07alO01lO7`0Rh^;09ZJVP02075aL@0408:2PP1HF5P0F5QH06ATI080SXj>00<0
NGUiooooooooool02?ooool000[ooooo00@0XZ:R09:BTP2BTY80VYZJ0P2NWYh01@2:RXX0SHf=096A
T@2ATI40RHV90080Ng]k00D0MWIf02LW9`0W9bL0P82009RHV00209fMW@050:JVYP2LW9`0W9bL09fM
W@2IVIT00P2=SHd01020P800U9BD09BDU02JVYX208>3P`0506EUI@17AdL0WYjN09jNWP2RXZ800P2V
YZH01@2[Zj/0WinO09NGU`2GUiL0WIfM0080X:2P00D0Y:BT09jNWP2FUYH0UYJF09:BTP0207]kN`05
030`<02:RXX0RXZ:09VIV@2MWId00P2RXZ801@23Ph<0Ng]k07]kN`1oOgl0KFe]0080K6a/00@0KFe]
08V9R@29RHT0PH610P1EEED01@15ADD0LW9b07MgM`1gMgL0Ng]k0080NGUi0P1YJFT207=cL`0406a/
K01^KVh0KVi^07alO080MWIf00D0P82004a<C01NGUh0GUiN07UiN@0208:2PP0308F5Q@28R8P0SHf=
0080SHf=0P1kNg/01@2;Rh/0QHF508F5Q@25QHD0PH610080FUYJ00D0:BTY08J6QP26QXH0Ti>C08j>
SP0208n?S`0508>3P`21PH40PH6108:2PP25QHD00P27QhL0102:RXX0QXJ608J6QP1oOgl202d];@05
06QXJ022PX80Ogmo07moO`2>SXh00P29RHT01@2:RXX0L71`07IfMP1fMWH0OWin0080Lg=c00D0KVi^
06UYJ@0a<C40<C4a04U9B@02071`L005075aL@1_Kfl0Kfm_06][J`1UIFD00`1EEED205YJFP0505IF
EP1CDe<0A4A404A4A00S8b<00P0Y:BT01@0l?3`0=cLg03Lg=`0l?3`0A4A40080EUIF00@0HV9R05mO
G`1OGel0Fe]K4Oooool01029RHT0Ng]k07]kN`24Q8@209:BTP0508N7Q`2XZ:P0Z:RX0:RXZ02@T900
0P2=SHd01@2HV9P0NWYj07YjNP2;Rh/0SXj>0080I6AT00@0T92@09RHV02HV9P0MgMg0P2MWId01@1n
OWh0Kfm_079bLP1bLW80BDU90080DU9B00D0NWYj07alO01lO7`0/K6a08J6QP0208^;R`040:JVYP2O
Wil0WinO08F5Q@80Ph>300D0FEUI09bLW03:b/X0b/[:0:n_[`0207]kN`0508>3P`1EEED0`l?30<?3
``2XZ:P00P3Ng]h01@3@d=00T92@092@T02;Rh/0M7Ad0080SHf=00@0NWYj09nOW`2OWil0HV9R0P1`
L7001@2l_;`0SHf=0:n_[`2_[jl0X:2P0080Rh^;00D0Ph>30=GEe@2QXJ40XJ6Q08f=S@020820P005
0;6a/@2XZ:P0Z:RX07UiN@2:RXX00P2NWYh0102=SHd0UIFE09FEU@2PX:0208:2PP0506MWI`3MgMd0
WIfM09fMW@1/K6`00P2?Shl01@1PH600`l?30:VYZ@2YZJT0][Jf0080;bl_00D0YJFU0>CTi03Ti>@0
R8R80861P@0207IfMP0407YjNP2IVIT0VIVI0<o?c`80a/K600D0T92@09jNWP2OWil0WinO09jNWP02
08R8R00509BDU01gMgL0MgMg0;Vi^@2?Shl00P1_Kfl01@13@d<0<C4a034a<@1/K6`0GUiN0080O7al
00@0Hf=S07UiN@1iNGT0H61P0P1kNg/01@23Ph<0Ogmo06ATI01TI6@0MGEe0080PX:200D0QXJ608b<
S02<S8`0V9RH06ATI0020;fm_@050:JVYP1oOgl0Ogmo08^;R`2?Shl00P1RHV801023Ph<0Cdm?04m?
C`1>CTh207=cL`0306m_Kooooooooooo00Sooooo000:ooooo`040::RXP2BTY80TY:B09ZJVP80WYjN
00D0RXZ:08f=S@2ATI40TI6A08V9R@0207]kN`0507IfMP0W9bL09bLW0820P02HV9P00P2MWId01@2V
YZH0W9bL09bLW02MWId0VIVI0080SHf=00@0P82009BDU02DU9@0VYZJ0P23Ph<01@1UIFD0AdM709jN
WP2NWYh0XZ:R0080YZJV00D0Zj^[09nOW`2GUiL0UiNG09fMW@020:2PX0050:BTY02NWYh0UYJF09JF
UP2BTY800P1kNg/01@0`<300RXZ:08Z:RP2IVIT0WIfM0080XZ:R00D0Ph>307]kN`1kNg/0Ogmo06e]
K@0206a/K00406e]K@29RHT0RHV90861P@80EEEE00D0ADE5079bLP1gMgL0MgMg07]kN`0207UiN@80
JFUY0P1cLg<0101/K6`0KVi^06i^KP1lO7`207IfMP050820P01<C4`0GUiN05iNGP1iNGT00P22PX80
0`25QHD0R8R808f=S@0208f=S@80Ng]k00D0Rh^;08F5Q@25QHD0QHF50861P@0205YJFP0502TY:@26
QXH0QXJ609>CT`2>SXh00P2?Shl01@23Ph<0PH610861P@22PX80QHF50080QhN700@0RXZ:08J6QP26
QXH0Ogmo0P0];Bd01@1XJ6P0PX:207moO`1oOgl0SXj>0080RHV900D0RXZ:071`L01fMWH0MWIf07in
OP0207=cL`0506i^KP1YJFT0<C4a034a<@19BDT00P1`L7001@1aLG40Kfm_06m_K`1[Jf/0IFEU00<0
EEEE0P1JFUX01@1FEUH0De=C04A4A014A4@08b<S0080:BTY00D0?3`l03Lg=`0g=cL0?3`l04A4A002
05IFEP04069RHP1OGel0GemO05]KFa7ooooo00@0RHV907]kN`1kNg/0Q8B40P2BTY801@27QhL0Z:RX
0:RXZ02XZ:P0T92@0080SHf=00D0V9RH07YjNP1jNWX0Rh^;08j>SP0206ATI004092@T02HV9P0V9RH
07MgM`80WIfM00D0OWin06m_K`1bLW80LW9b04U9B@02059BDP0507YjNP1lO7`0O7al0;6a/@26QXH0
0P2;Rh/0102VYZH0WinO09nOW`25QHD208>3P`0505UIF@2LW9`0b/[:0<[:bP2_[jl00P1kNg/01@23
Ph<0EEEE0<?3``33`l<0Z:RX0080g]kN00D0d=3@092@T02@T900Rh^;07AdM00208f=S@0407YjNP2O
Wil0WinO069RHP80L71`00D0_;bl08f=S@2_[jl0[jn_0:2PX00208^;R`0508>3P`3EeMD0XJ6Q0:6Q
X@2=SHd00P20P8001@2a/K40Z:RX0:RXZ01iNGT0RXZ:0080WYjN00@0SHf=09FEU@2EUID0X:2P0P22
PX801@1WIfL0gMgM09fMW@2MWId0K6a/0080Shn?00D0H61P0<?3``2YZJT0ZJVY0;Jf]P0202l_;`05
0:FUY@3Ti>@0i>CT08R8R021PH400P1fMWH0101jNWX0VIVI09VIV@3?cll20<K6aP05092@T02NWYh0
WinO09nOW`2NWYh00P28R8P01@2DU9@0MgMg07MgM`2i^KT0Shn?0080Kfm_00D0@d=3034a<@0a<C40
K6a/05iNGP0207alO00406=SH`1iNGT0NGUi061PH080Ng]k00D0Ph>307moO`1TI6@0I6AT07EeM@02
08:2PP0508J6QP2<S8`0S8b<09RHV01TI6@00P2m_Kd01@2VYZH0Ogmo07moO`2;Rh/0Shn?0080HV9R
00@0Ph>304m?C`1?Cdl0CTi>0P1cLg<00`1_Kfooooooooooo`08ooooo`002_ooool0100/;2`09BDU
02DU9@0J6QX201hN7P05018B4P0A4A404a<C01<C4`0;2`/00P0=3@d01@092@T02PX:00X:2P0F5QH0
6QXJ008061PH00<07alO020P800P82000P0M7Ad201TI6@0401<C4`0E5AD05ADE01TI6@8051@D00D0
7QhN03Ph>00_;bl0;bl_02TY:@0202HV9P809BDU0P0Q8B401@0K6a/06QXJ01XJ6P0W9bL0:2PX0080
92@T0`0N7Qh01@0G5aL071`L01`L700@41005ADE00806QXJ00D0820P00l?3`0?3`l07AdM02@T9002
01HF5P04024Q8@0T92@092@T02d];@80<30`00D0=3@d03<c<`0T92@092@T02<S8`0201lO7`0501XJ
6P0C4a<0:b/[02/[:`0d=3@00P0c<c<01@0i>CT0=CDe03De=@0^;Rh0>3Ph0080@41000D0ADE50451
@@11@D40?Cdm03Xj>P02028R8P05020P800V9RH09RHV03<c<`0i>CT00P16ATH0101;Bd/0AdM704M7
A`1=CDd204A4A00503Hf=P0d=3@0;bl_02l_;`0a<C400P0O7al01@0X:2P0<c<c02HV9P0V9RH0=cLg
0080;Rh^00D0?3`l04I6AP16ATH0AdM704e=C@0204Y:BP0504e=C@1?Cdl0Cdm?02<S8`0g=cL00P1L
G5`01@1RHV80GUiN05iNGP1QHF40Hf=S0080JVYZ00@0KFe]06MWI`1WIfL0J6QX0P1WIfL01@1^KVh0
HV9R03Xj>P0j>SX0KFe]0080Lg=c00D0NWYj07moO`1jNWX0NWYj07AdM002075aL@0506][J`1`L700
L71`07AdM01jNWX00P1mOGd0100W9bL0IVIV06IVIP2=SHdAooooo`0409>CT`1jNWX0NWYj07moO`80
SXj>00D0RHV90;Fe]@2e]KD0/K6a09RHV00209BDU0050:>SX`1lO7`0O7al07alO02=SHd00P1`L700
1020P800R8R808R8R01SHf<208J6QP0507IfMP1YJFT0Kfm_06m_K`17AdL00P1BDU801@1fMWH0OWin
07inOP2[Zj/0Q8B40080PX:200@0/K6a0:2PX02PX:00QhN70P2;Rh/01@1GEeL0SHf=0<C4a034a<@0
XZ:R0080NGUi00D0Ogmo059BDP2n_[h0_[jn09^KV`020=WIf@050<W9b@2CTi<0Ti>C08V9R@1[Jf/0
0P1gMgL00`1`L700U9BD09BDU00306IVIP050:ZZZP23Ph<0^[Zj0;Zj^P2VYZH00P2KVi/01@1oOgl0
i>CT0:n_[`2_[jl0Ti>C0080MWIf00D0XZ:R09bLW02LW9`0LG5a0861P@0308R8R080RHV900D0XZ:R
08F5Q@25QHD0FEUI0=3@d00208b<S00507EeM@2LW9`0W9bL07UiN@2m_Kd00P2RXZ80102LW9`09BDU
02DU9@3Ph>020>KViP05092@T025QHD0R8R808R8R01kNg/00P2ATI401@32`/80^k^k0;^k^`2=SHd0
Zj^[0080WYjN00@0[Jf]09BDU02DU9@0VIVI0P24Q8@01@2YZJT0PX:206MWI`1WIfL0>3Ph0080?clo
00D0SHf=051@D023Ph<0Ph>305QHF00208B4Q00505mOG`1dM7@0M7Ad08j>SP1mOGd00P1_Kfl0102;
Rh/0OWin07inOP2;Rh/209RHV0050:2PX01cLg<0b<S80<S8b02l_;`00P1bLW801@2BTY80WIfM05mO
G`1OGel0M7Ad00<0?clo0P1QHF400`1NGUkoooooooooo`08ooooo`002_ooool0102KVi/0UIFE09FE
U@2:RXX205=CD`030:n_[`2WYjL0Q8B40080Q8B40P2ATI4309fMW@050:>SX`2][Jd0Z:RX0:RXZ02e
]KD00P2b/[801@1fMWH0?3`l092@T02@T900XJ6Q0080YZJV00D0[:b/0:BTY02TY:@0XZ:R09jNWP02
09JFUP0508V9R@26QXH0QXJ608^;R`2MWId00P0i>CT01@1LG5`0UYJF09JFUP2MWId0ZJVY0080UiNG
00<0T92@08n?S`2?Shl00`28R8P01@27QhL0W9bL09nOW`2OWil0VYZJ0080:RXZ00@0PX:209>CT`2<
S8`0S8b<0`2@T9001@2HV9P0X:2P0:2PX02OWil0X:2P0080XZ:R0`2NWYh01@1_Kfl0>SXj0:NWY`2W
YjL0YJFU0080YjNW00D0XJ6Q09FEU@2EUID0UiNG0:6QX@020::RXP050:FUY@2VYZH0YZJV0:FUY@2Q
XJ400P1>CTh01@1[Jf/0V9RH09RHV02HV9P0U9BD0080XZ:R00<0YjNW0:b/[02/[:`00`2^[Zh01@2Z
ZZX0Xj>S07]kN`1kNg/0TI6A0080A4A400D0X:2P0;^k^`2n_[h0_[jn0;bl_0020;Zj^P<0^KVi00D0
_kno0<C4a033`l<0`l?30<G5a@020<O7a`0504m?C`1jNWX0/k>c0;>c/`2h^;P00P2b/[800`2_[jl0
/;2`0:b/[0020:b/[080YJFU00D0SXj>09:BTP2BTY80V9RH08B4Q00204e=C@<0R8R800D0Rh^;09:B
TP2?Shl0Shn?08V9R@0208^;R`0508R8R02CTi<0Ti>C09NGU`2PX:000P2MWId0100k>c/0X:2P0:2P
X02d];@Aooooo`0408^;R`1bLW80LW9b07emO@80QhN700D0Ng]k09^KV`2KVi/0[Zj^0:2PX00209NG
U`0509RHV020P800P82008n?S`25QHD00P1KFe/0101gMgL0T92@092@T01CDe<206][J`80BDU90P1L
G5`0101EEED0HV9R069RHP1kNg/208R8R0050;Bd]02=SHd0P8200820P02_[jl00P2MWId01@21PH40
Ti>C09>CT`1NGUh0SHf=0080a/K600D0YjNW07alO01lO7`0PX:204e=C@020;jn_P04096AT@3Fe]H0
e]KF0<?3``80VYZJ00D0PH61079bLP21PH40PH6107QhN00209^KV`05075aL@1_Kfl0Kfm_0:VYZ@2G
UiL00P35aLD01@2SXj<0YJFU0:FUY@1lO7`0emOG0080YZJV00@0Vi^K08N7Q`27QhL0Zj^[0P2UYJD0
1@1jNWX0Ng]k08f=S@2=SHd0Q8B40080TI6A00D0_;bl096AT@2ATI40QXJ60:2PX0020:JVYP05079b
LP2PX:00X:2P0820P02o_kl00P2c/k<0102YZJT0:RXZ02XZ:P3Lg=`20>?Sh`0508F5Q@1mOGd0Ng]k
07]kN`1iNGT00P2DU9@01@3=cLd0_;bl0;bl_01nOWh0XJ6Q0080Shn?00@0UIFE08^;R`2;Rh/0O7al
0P2ATI401@30`<00Rh^;06QXJ01XJ6P0B4Q80080?Shn00D0P82004e=C@2:RXX0RXZ:06ATI00208>3
P`0507UiN@1`L700L71`08R8R01aLG400P1gMgL0101QHF40MWIf07IfMP25QHD207inOP0508b<S01b
LW80^[Zj0;Zj^P30`<000P1VIVH01@2?Shl0_Kfm06=SH`1SHf<0QHF50080FEUI00@0CTi>075aL@1a
LG40GemO2_ooool000[ooooo00@0Zj^[0:NWY`2WYjL0ZJVY0P1<C4`20:ZZZP80WinO00@0V9RH09VI
V@2IVIT0XJ6Q0`2UYJD0102WYjL0[Jf]0:f][@2/[:`20:j^[P05096AT@0n?Sh0SHf=08f=S@2IVIT0
0P2HV9P01@2JVYX0TI6A096AT@2ATI40TY:B0080Shn?00D0Ti>C08B4Q024Q8@0P82009RHV00204U9
B@0306m_K`2NWYh0WYjN0080YZJV0P2DU9@01028R8P0QhN708N7Q`24Q8@207inOP0508>3P`2GUiL0
VYZJ09ZJVP2ATI400P0T92@01@1aLG40MGEe07UiN@1iNGT0PH610080SXj>00D0VYZJ08j>SP2>SXh0
UIFE09>CT`020:BTY0050:RXZ02VYZH0YZJV06EUI@0l?3`00P2TY:@0102RXZ80WYjN09jNWP2NWYh2
0:6QX@0509ZJVP2EUID0U9BD09BDU02EUID00P2>SXh01@2DU9@0XJ6Q05aLG01LG5`0Hf=S0080SXj>
00D0TY:B09RHV027QhL0QhN708f=S@0209jNWP0509NGU`2ATI40TI6A08f=S@29RHT00P2;Rh/01@1o
Ogl0@d=304=3@`2`/;00_Kfm0080^[Zj00@0]kNg0;>c/`2c/k<0^[Zj0P2c/k<01@2d];@0^k^k0;Zj
^P2j^[X0_kno0080`L7100<0Hf=S08:2PP2/[:`00P2/[:`20:6QX@050:>SX`2QXJ40W9bL09bLW02J
VYX00P2IVIT01@1dM7@0L71`071`L01gMgL0KFe]0080BDU90`20P8001@27QhL0PX:208B4Q024Q8@0
Ogmo0080OGem00D0Ogmo07]kN`1kNg/0QHF509>CT`0209RHV00403Lg=`2LW9`0W9bL0:VYZA7ooooo
00@0Shn?07QhN01hN7P0RXZ:0P2MWId01@2<S8`0[Jf]0:f][@30`<00[:b/0080Shn?00D0Vi^K06UY
J@1YJFT0QhN709BDU002069RHP0408J6QP2HV9P0V9RH06][J`80Vi^K00D0O7al06a/K01VIVH0IVIV
04e=C@0205YJFP0507inOP29RHT0RHV90:n_[`2>SXh00P20P800102`/;00WIfM09fMW@25QHD207mo
O`0504m?C`2?Shl0^k^k0;^k^`2UYJD00P1fMWH01@2;Rh/0Bd];0<K6aP36a/H0WYjN0080h>3P00D0
_[jn0:NWY`2WYjL0Q8B406m_K`0208J6QP040820P02QXJ40XJ6Q07inOP80Ng]k00D0VYZJ0;:b/P2k
^k/0^k^k09FEU@0209nOW`0509:BTP3De=@0Z:RX0:RXZ02d];@00P29RHT01@2TY:@0WinO09nOW`20
P800O7al0080Ogmo00@0JVYZ07EeM@1eMGD0YjNW0P2JVYX01@1jNWX0c/k>09NGU`2GUiL0HV9R0080
UYJF00D0PH610::RXP2_[jl0[jn_09VIV@0203Xj>P050>7Qh@3UiND0iNGU07QhN01kNg/00P28R8P0
102<S8`0Z:RX0:RXZ035aLD20;Vi^@05079bLP2XZ:P0U9BD09BDU023Ph<00P1fMWH01@22PX80R8R8
08R8R02g]kL0MWIf0080MgMg00D0@d=303hn?P0n?Sh0Ng]k05QHF00207UiN@04069RHP1gMgL0MgMg
0820P080QHF500D0UiNG06e]K@1nOWh0OWin06IVIP0206a/K00507inOP2<S8`0S8b<0:VYZ@1iNGT0
0P2i^KT01@30`<00HF5Q065QH@2>SXh0aLG50080Fe]K00@0K6a/061PH01PH600IfMW0`1]KFd:oooo
o`002_ooool0102[Zj/0YjNW0:NWY`2YZJT204a<C080ZZZZ0P2OWil0102HV9P0VIVI09VIV@2QXJ43
0:FUY@040:NWY`2][Jd0[Jf]0:b/[080[Zj^00D0TI6A03hn?P2=SHd0SHf=09VIV@0209RHV00509ZJ
VP2ATI40TI6A096AT@2BTY800P2?Shl01@2CTi<0Q8B408B4Q020P800V9RH0080BDU900<0Kfm_09jN
WP2NWYh00P2VYZH209BDU00408R8R027QhL0QhN708B4Q080OWin00D0Ph>309NGU`2JVYX0VYZJ096A
T@0202@T9005075aL@1eMGD0NGUi07UiN@21PH400P2>SXh01@2JVYX0SXj>08j>SP2EUID0Ti>C0080
Y:BT00D0Z:RX0:JVYP2VYZH0IFEU03`l?0020:BTY0040::RXP2NWYh0WYjN09jNWP80XJ6Q00D0VYZJ
09FEU@2DU9@0U9BD09FEU@0208j>SP0509BDU02QXJ40G5aL05aLG01SHf<00P2>SXh01@2BTY80V9RH
08N7Q`27QhL0SHf=0080WYjN00D0UiNG096AT@2ATI40SHf=08V9R@0208^;R`0507moO`13@d<0@d=3
0;2`/02m_Kd00P2j^[X0102g]kL0/k>c0;>c/`2j^[X20;>c/`050;Bd]02k^k/0^[Zj0;Zj^P2o_kl0
0P31`L400`1SHf<0PX:20:b/[0020:b/[080XJ6Q00D0Xj>S0:6QX@2LW9`0W9bL09ZJVP0209VIV@05
07AdM01`L700L71`07MgM`1]KFd00P19BDT30820P00508N7Q`22PX80Q8B408B4Q01oOgl00P1mOGd0
1@1oOgl0Ng]k07]kN`25QHD0Ti>C0080V9RH00@0=cLg09bLW02LW9`0ZJVY4Oooool0102?Shl0N7Qh
07QhN02:RXX209fMW@0508b<S02][Jd0[Jf]0<30`02/[:`00P2?Shl01@2KVi/0JFUY06UYJ@27QhL0
U9BD0080HV9R00@0QXJ609RHV02HV9P0Jf][0P2KVi/01@1lO7`0K6a/06IVIP1VIVH0CDe=0080FUYJ
00D0OWin08V9R@29RHT0[jn_08j>SP020820P0040;2`/02MWId0WIfM08F5Q@80Ogmo00D0Cdm?08n?
S`2k^k/0^k^k0:FUY@0207IfMP0508^;R`1;Bd/0a/K60<K6aP2NWYh00P3Ph>001@2n_[h0YjNW0:NW
Y`24Q8@0Kfm_0080QXJ600@0P8200:6QX@2QXJ40OWin0P1kNg/01@2JVYX0/[:b0;^k^`2k^k/0UIFE
0080WinO00D0TY:B0=CDe02XZ:P0Z:RX0;Bd]00208V9R@050:BTY02OWil0WinO0820P01lO7`00P1o
Ogl0101ZJVX0MGEe07EeM@2WYjL209ZJVP0507YjNP3>c/h0UiNG09NGU`1RHV800P2FUYH01@21PH40
XZ:R0:n_[`2_[jl0VIVI0080>SXj00D0hN7Q0>GUi@3UiND0N7Qh07]kN`0208R8R00408b<S02XZ:P0
Z:RX0<G5a@80^KVi00D0LW9b0:RXZ02DU9@0U9BD08>3P`0207IfMP0508:2PP28R8P0R8R80;Ng]`1f
MWH00P1gMgL01@13@d<0?Shn03hn?P1kNg/0F5QH0080NGUi00@0HV9R07MgM`1gMgL0P8200P25QHD0
1@2GUiL0KFe]07inOP1nOWh0IVIV0080K6a/00D0OWin08b<S02<S8`0ZJVY07UiN@020;Vi^@050<30
`01QHF40HF5Q08j>SP35aLD00P1KFe/0101/K6`0H61P061PH01WIfL306e]K@[ooooo000:ooooo`04
0:JVYP2OWil0WinO0:VYZ@80CDe=0P2WYjL20:FUY@040::RXP2HV9P0V9RH09nOW`80WYjN00D0UiNG
09RHV02WYjL0YjNW0:n_[`020:b/[00508f=S@0o?cl0S8b<08b<S02KVi/00P2UYJD01@2WYjL0Y:BT
0:BTY02MWId0XJ6Q0080YjNW00D0WinO08J6QP26QXH0SXj>09FEU@0204I6AP0506IVIP2SXj<0Xj>S
0:RXZ02TY:@00P2HV9P0102?Shl0QhN708N7Q`1kNg/207QhN005079bLP24Q8@0VIVI09VIV@2ATI40
0P0b<S801@1dM7@0O7al08f=S@2=SHd0Rh^;0080RXZ:0`2QXJ401@2OWil0V9RH09^KV`2KVi/0Xj>S
0080Vi^K00D08b<S0410@02WYjL0YjNW0:RXZ0020::RXP050:>SX`2MWId0WIfM09>CT`2EUID00P2C
Ti<409jNWP040:JVYP1SHf<0Hf=S05IFEP80OWin00D0RXZ:09VIV@2IVIT0VIVI09jNWP020:BTY005
09fMW@2PX:00X:2P0:BTY02DU9@00P2:RXX01@2IVIT0BDU904U9B@2`/;00`<300080^;Rh00@0]kNg
0;Bd]02d];@0];Bd0P2][Jd20:RXZ080[Jf]00D0_Kfm0<[:bP3:b/X0IFEU08B4Q0020:VYZ@030:>S
X`2LW9`0W9bL0080V9RH0P2DU9@0102BTY80TI6A096AT@1lO7`207EeM@05075aL@1WIfL0DE5A055A
D@2EUID00P2HV9P01@2BTY80R8R808B4Q024Q8@0N7Qh0080PX:200D0P82007moO`1oOgl0RHV909JF
UP0209VIV@0402TY:@2:RXX0RXZ:09JFUQ7ooooo00@0SXj>07QhN01hN7P0RHV90P2][Jd01@2CTi<0
[Jf]0:f][@30`<00[Jf]0080V9RH00D0W9bL07YjNP1jNWX0SHf=08j>SP02069RHP040861P@2FUYH0
UYJF08F5Q@80[:b/00D0MWIf07AdM01oOgl0Ogmo05QHF002069RHP0508J6QP1kNg/0Ng]k0;Fe]@2L
W9`00P1lO7`0102d];@0Xj>S0:>SX`25QHD208n?S`0506ATI02@T900`<300<30`02VYZH00P1jNWX0
1@2:RXX0Bd];0<G5a@35aLD0UYJF0080d];B00D0_;bl0:f][@2][Jd0PX:206e]K@0208R8R00407]k
N`2EUID0UIFE07UiN@80OGem00D0R8R809^KV`2k^k/0^k^k07inOP0208^;R`050:f][@35aLD0YJFU
0:FUY@2j^[X00P25QHD01@2/[:`0XJ6Q0:6QX@2=SHd0P8200080QhN700@0J6QX07moO`1oOgl0R8R8
0P2OWil01@21PH40cLg=09JFUP2FUYH0IVIV0080R8R800D0PX:20:j^[P2b/[80/[:b08B4Q00203/k
>`050=gMg@3QhN40hN7Q06EUI@1hN7P00`1dM7@209fMW@050<C4a02h^;P0^;Rh06e]K@2PX:000P28
R8P0101nOWh0MWIf07IfMP1YJFT208N7Q`050:j^[P1WIfL0KVi^06i^KP16ATH00P0l?3`01@1cLg<0
F5QH06EUI@1UIFD0QHF50080SHf=00D0LW9b07AdM01dM7@0PH6105eMG@0207IfMP0406a/K01YJFT0
JFUY08B4Q080PH6100D0S8b<06m_K`2a/K40/K6a0:>SX`0206e]K@0508Z:RP2WYjL0DE5A055AD@1F
EUH00P1[Jf/0101FEUH0KVi^06i^KP1bLW8:ooooo`002_ooool0102/[:`0YZJV0:JVYP2HV9P204];
B`050:^[Z`2WYjL0WinO09nOW`2PX:000P2HV9P01@2GUiL0Q8B408B4Q02@T900PH610080UiNG00D0
Vi^K08n?S`2?Shl0NGUi0410@00208J6QP0409bLW02XZ:P0Z:RX0:VYZ@80[:b/00D0[Zj^0:VYZ@2U
YJD0YJFU09^KV`0209ZJVP0509bLW02;Rh/09BDU02DU9@1]KFd00P2QXJ401@2CTi<0XJ6Q09>CT`2C
Ti<0MGEe0080M7Ad00D0MGEe06i^KP1^KVh0L71`07moO`0209VIV@0509BDU00i>CT0>CTi07moO`22
PX800P2:RXX0102DU9@0R8R808R8R02FUYH309^KV`04096AT@2=SHd0SHf=09fMW@80U9BD00D0EEEE
0492@P2TY:@0Y:BT0:VYZ@030:ZZZP80Xj>S00D0UIFE08J6QP1iNGT0NGUi09JFUP0309RHV00409ZJ
VP1XJ6P0J6QX04e=C@80N7Qh00D0Rh^;0:6QX@2UYJD0YJFU0:JVYP0209BDU00509fMW@2GUiL0UiNG
092@T02;Rh/00P1lO7`01@2HV9P0De=C05=CD`2LW9`0VYZJ0080[:b/00@0_[jn0;2`/02`/;00Y:BT
0P2HV9P01@2PX:00UIFE096AT@2ATI40SHf=0080WYjN00D0CDe=079bLP1nOWh0OWin07IfMP0207in
OP0507EeM@1bLW80MgMg07MgM`1cLg<00P1bLW801@1MGEd0EeMG05MGE`19BDT0>3Ph0080<c<c00D0
G5aL06=SH`1SHf<0IFEU05]KF`0204U9B@0404=3@`19BDT0BDU905=CD`80CDe=0P1CDe<204I6AP04
01`L701NGUh0GUiN06YZJQ7ooooo00@0SHf=07alO01lO7`0U9BD0P2[Zj/01@2=SHd0[jn_0:n_[`30
`<00Xj>S0080UiNG00D0W9bL07QhN01hN7P0QXJ609BDU00205UIF@0407alO02HV9P0V9RH07inOP80
YZJV00D0JVYZ069RHP1kNg/0Ng]k04m?C`0206ATI00507emO@2BTY80TY:B0;>c/`2NWYh00P1mOGd0
102n_[h0Y:BT0:BTY028R8P208b<S00506QXJ02CTi<0alO70<O7a`2ZZZX00P1mOGd01@29RHT0BTY:
0<O7a`37alL0VIVI0080bLW900D0^KVi0:^[Z`2[Zj/0R8R80861P@0208^;R`0407emO@2FUYH0UYJF
08J6QP80U9BD00D0W9bL0;2`/02n_[h0_[jn08n?S`0209nOW`050:^[Z`3Cdm<0XJ6Q0:6QX@36a/H0
0P21PH401@2^[Zh0Xj>S0:>SX`1nOWh0Ng]k0080QHF500@0HV9R09FEU@2EUID0S8b<0P2SXj<01@2W
YjL0gMgM08f=S@2=SHd0KVi^0080RHV900D0TY:B09NGU`2k^k/0^k^k07moO`02034a<@050=KFeP3M
gMd0gMgM069RHP1cLg<00P24Q8@01022PX80/K6a0;6a/@35aLD20;Rh^00506YZJP2RXZ80Shn?08n?
S`2;Rh/00P1iNGT01@1bLW80Jf][06][J`2h^;P0JFUY0080I6AT00D0@D5103Ph>00h>3P0N7Qh06YZ
JP0206MWI`040820P027QhL0QhN706i^KP80Shn?00D0P82007AdM01]KFd0KFe]06=SH`02065QH@05
06][J`1oOgl0Ogmo09FEU@1fMWH00P2][Jd01@28R8P0Lg=c07=cL`2=SHd0[:b/0080FUYJ00@0Cdm?
05UIF@1IFET0EUIF0P1WIfL00`1PH63oooooooooo`08ooooo`002_ooool0102/[:`0YZJV0:JVYP2H
V9P204];B`050:^[Z`2WYjL0WinO09nOW`2PX:000P2HV9P01@2GUiL0Q8B408B4Q02@T900PH610080
UiNG00D0Vi^K08n?S`2?Shl0NGUi0410@00208J6QP0409bLW02XZ:P0Z:RX0:VYZ@80[:b/00D0[Zj^
0:VYZ@2UYJD0YJFU09^KV`0209ZJVP0509bLW02;Rh/09BDU02DU9@1]KFd00P2QXJ401@2CTi<0XJ6Q
09>CT`2CTi<0MGEe0080M7Ad00D0MGEe06i^KP1^KVh0L71`07moO`0209VIV@0509BDU00i>CT0>CTi
07moO`22PX800P2:RXX0102DU9@0R8R808R8R02FUYH309^KV`04096AT@2=SHd0SHf=09fMW@80U9BD
00D0EEEE0492@P2TY:@0Y:BT0:VYZ@030:ZZZP80Xj>S00D0UIFE08J6QP1iNGT0NGUi09JFUP0309RH
V00409ZJVP1XJ6P0J6QX04e=C@80N7Qh00D0Rh^;0:6QX@2UYJD0YJFU0:JVYP0209BDU00509fMW@2G
UiL0UiNG092@T02;Rh/00P1lO7`01@2HV9P0De=C05=CD`2LW9`0VYZJ0080[:b/00@0_[jn0;2`/02`
/;00Y:BT0P2HV9P01@2PX:00UIFE096AT@2ATI40SHf=0080WYjN00D0CDe=079bLP1nOWh0OWin07If
MP0207inOP0507EeM@1bLW80MgMg07MgM`1cLg<00P1bLW801@1MGEd0EeMG05MGE`19BDT0>3Ph0080
<c<c00D0G5aL06=SH`1SHf<0IFEU05]KF`0204U9B@0404=3@`19BDT0BDU905=CD`80CDe=0P1CDe<2
04I6AP0401`L701NGUh0GUiN06YZJQ7ooooo00@0SHf=07alO01lO7`0U9BD0P2[Zj/01@2=SHd0[jn_
0:n_[`30`<00Xj>S0080UiNG00D0W9bL07QhN01hN7P0QXJ609BDU00205UIF@0407alO02HV9P0V9RH
07inOP80YZJV00D0JVYZ069RHP1kNg/0Ng]k04m?C`0206ATI00507emO@2BTY80TY:B0;>c/`2NWYh0
0P1mOGd0102n_[h0Y:BT0:BTY028R8P208b<S00506QXJ02CTi<0alO70<O7a`2ZZZX00P1mOGd01@29
RHT0BTY:0<O7a`37alL0VIVI0080bLW900D0^KVi0:^[Z`2[Zj/0R8R80861P@0208^;R`0407emO@2F
UYH0UYJF08J6QP80U9BD00D0W9bL0;2`/02n_[h0_[jn08n?S`0209nOW`050:^[Z`3Cdm<0XJ6Q0:6Q
X@36a/H00P21PH401@2^[Zh0Xj>S0:>SX`1nOWh0Ng]k0080QHF500@0HV9R09FEU@2EUID0S8b<0P2S
Xj<01@2WYjL0gMgM08f=S@2=SHd0KVi^0080RHV900D0TY:B09NGU`2k^k/0^k^k07moO`02034a<@05
0=KFeP3MgMd0gMgM069RHP1cLg<00P24Q8@01022PX80/K6a0;6a/@35aLD20;Rh^00506YZJP2RXZ80
Shn?08n?S`2;Rh/00P1iNGT01@1bLW80Jf][06][J`2h^;P0JFUY0080I6AT00D0@D5103Ph>00h>3P0
N7Qh06YZJP0206MWI`040820P027QhL0QhN706i^KP80Shn?00D0P82007AdM01]KFd0KFe]06=SH`02
065QH@0506][J`1oOgl0Ogmo09FEU@1fMWH00P2][Jd01@28R8P0Lg=c07=cL`2=SHd0[:b/0080FUYJ
00@0Cdm?05UIF@1IFET0EUIF0P1WIfL00`1PH63oooooooooo`08ooooo`002_ooool0101MGEd0AdM7
04M7A`0h>3P202HV9P0503Lg=`0l?3`0>3Ph03Ph>00j>SX00P0g=cL01@0c<c<0;2`/02`/;00L71`0
8B4Q00809RHV00D092@T02XZ:P0Z:RX08R8R010@400203lo?`0404M7A`11@D40@D5104I6AP80B4Q8
00D0Bd];05UIF@16ATH0ATI603Hf=P0203<c<`0503Ti>@0J6QX01PH600H61P0=3@d00`0C4a<0100K
6a/06ATI01TI6@0L71`201dM7@0501hN7P0I6AT06ATI01hN7P0P82000P0M7Ad01@0O7al07AdM01dM
7@0G5aL06a/K00807alO00@0820P01XJ6P0J6QX0820P0P0S8b<01@0I6AT09bLW02<S8`0S8b<09BDU
00<0820P00@08B4Q02/[:`0[:b/0?Shn0P0o?cl01@0i>CT0=3@d03@d=00/;2`08b<S008020P800D0
5aLG02/[:`0[:b/0<S8b034a<@02030`<00502`/;00j>SX0>SXj03Ph>010@4000P1CDe<0101ADE40
=cLg03Lg=`0T92@201lO7`0502HV9P0Y:BT0=cLg03Lg=`0n?Sh00P0k>c/01@0j>SX0=cLg04A4A014
A4@0Bd];0080CTi>00D0C4a<03De=@0e=CD07QhN03/k>`0203dm?@050492@P13@d<0@d=304e=C@16
ATH00`14A4@203dm?@0504M7A`19BDT0BDU904U9B@0L71`00P0k>c/01@1PH600GemO05mOG`1QHF40
Jf][0080JVYZ00D0HV9R071`L01`L700PH6107emO@0207alO00406IVIP0i>CT0>CTi07moO`80NGUi
00D0Ng]k0820P024Q8@0Q8B408b<S00207YjNP0306m_Kooooooooooo00oooooo00@0TI6A07]kN`1k
Ng/0UIFE0P2/[:`01@2@T900Z:RX0:RXZ02n_[h0YZJV0080QXJ600D0TY:B07AdM01dM7@0QXJ6096A
T@02051@D00408>3P`2NWYh0WYjN08Z:RP80Y:BT00D0H61P06ATI01lO7`0O7al05ADE00207QhN005
0820P02>SXh0SXj>0<30`02GUiL00P20P800102n_[h0X:2P0:2PX026QXH2092@T00506i^KP2@T900
^k^k0;^k^`2][Jd00P26QXH01@2FUYH0DE5A0;Zj^P2j^[X0UYJF0080dm?C00D0^KVi0:ZZZP2ZZZX0
QHF506IVIP0208f=S@040820P02>SXh0SXj>08b<S080WinO00D0U9BD0:BTY02a/K40/K6a09:BTP02
09>CT`050;Jf]P3@d=00WinO09nOW`2h^;P00P1iNGT0102>SXh0SHf=08f=S@1eMGD30861P@04055A
D@2?Shl0Shn?075aL@80V9RH00D0Z:RX0=KFeP29RHT0RHV908:2PP0208>3P`050;>c/`2OWil0clo?
0<o?c`1gMgL00P1=CDd01@3Rh^80g=cL0=cLg01ZJVX0PH610080M7Ad00@0Jf][0;fm_@2m_Kd0`L71
0P2k^k/01@1oOgl0WIfM09:BTP2BTY80UIFE0080K6a/00D0SHf=05iNGP1NGUh0Z:RX075aL@02065Q
H@05051@D00m?Cd0?Cdm07IfMP1YJFT00P1LG5`0101hN7P0OWin07inOP1UIFD208B4Q005071`L01g
MgL0MgMg07MgM`1WIfL00P1/K6`01@1fMWH0QXJ608J6QP2DU9@0M7Ad0080`l?300D0OGem07moO`1o
Ogl0TI6A0:VYZ@02069RHP0405MGE`1IFET0FEUI04e=C@80Jf][00<0Hf=Sooooooooool02?ooool0
00[ooooo00@0V9RH09BDU02DU9@0UYJF0P2IVIT01@2JVYX0V9RH08f=S@2=SHd0V9RH00<0X:2P0P2C
Ti<01@0R8R80JFUY08V9R@29RHT0QHF50080UYJF00D0Ti>C08b<S01nOWh0OWin07alO0020820P005
096AT@2JVYX0VYZJ0:6QX@2NWYh00P0b<S801@1TI6@0QHF508F5Q@26QXH0R8R80080Y:BT00D0Xj>S
09RHV02HV9P0Xj>S0:2PX00309bLW080V9RH00D0OWin03Hf=P0f=SH0QhN709bLW00209ZJVP0509^K
V`2PX:00X:2P09fMW@2RXZ800P2OWil0102PX:00XZ:R0::RXP2SXj<20:FUY@0503De=@21PH40OWin
07inOP20P8000P1gMgL01@1^KVh0MGEe096AT@2ATI40UYJF0080Ti>C00D0TI6A08>3P`23Ph<0PX:2
075aL@02038b<P0507]kN`26QXH0QXJ609>CT`2HV9P00P2LW9`01@2JVYX0UIFE09FEU@2DU9@0XJ6Q
0080X:2P00@0YjNW0:BTY02TY:@0EUIF0P1lO7`01@2ZZZX0YJFU0:BTY02TY:@0YZJV0080Y:BT00D0
YJFU0:>SX`2XZ:P0Z:RX09ZJVP0207=cL`05079bLP1_Kfl0Kfm_051@D02f][H00P2[Zj/00`2NWYh0
Xj>S0:>SX`020;>c/`80ZZZZ00D0WYjN08n?S`2?Shl0YJFU0:ZZZP020:BTY004059BDP2QXJ40XJ6Q
09^KV`80Rh^;00D0O7al07AdM024Q8@0Q8B407IfMP0207alO00509BDU02IVIT0U9BD09BDU01bLW80
0P0e=CD309ZJVP0509RHV02KVi/0X:2P0:2PX02:RXX00P24Q8@00`1iNGWoooooooooo`0?ooooo`04
096AT@1lO7`0O7al08j>SP80Vi^K00D0Shn?0:RXZ02XZ:P0^;Rh0:b/[00208J6QP0509^KV`1XJ6P0
J6QX08j>SP2EUID00P1PH600101mOGd0W9bL09bLW027QhL209RHV00506][J`1TI6@0LG5a075aL@1=
CDd00P1fMWH01@1`L700QhN708N7Q`2g]kL0V9RH0080MGEe00@0_Kfm09^KV`2KVi/0RHV90P2EUID0
1@1YJFT0UIFE0<30`030`<00Zj^[0080SXj>00D0U9BD04Y:BP32`/80`/;20:BTY0020<k>cP050;Bd
]02RXZ80XZ:R08^;R`1VIVH00P20P800101cLg<0NGUi07UiN@1nOWh209NGU`050;2`/02XZ:P0Z:RX
0:RXZ02BTY800P2FUYH01@2IVIT0WYjN0:JVYP2VYZH0]kNg0080Ogmo00D0Z:RX09^KV`2KVi/0Ph>3
08b<S00208:2PP04051@D02LW9`0W9bL07moO`80TY:B00D0/K6a0=GEe@2ATI40TI6A08N7Q`0206e]
K@050:^[Z`2QXJ40f][J0=[JfP1ZJVX00P1:BTX30=kNgP0507UiN@1YJFT0MgMg07MgM`1IFET00P39
bLT01@2XZ:P0/;2`0;2`/028R8P0UYJF0080SHf=00@0U9BD07EeM@1eMGD0TI6A0P1XJ6P01@1oOgl0
Ti>C05eMG@1MGEd0C4a<0080?Cdm00D0Ogmo061PH01GEeL0EeMG06e]K@0207]kN`0505aLG01jNWX0
NWYj07=cL`1`L7000P1jNWX0101]KFd0LW9b079bLP1oOgl209JFUP0508f=S@1mOGd0eMGE0=GEe@1b
LW800P2BTY80102JVYX0XZ:R06e]K@1]KFd306=SH`04059BDP1dM7@0M7Ad06][J`[ooooo000:oooo
o`0409RHV02DU9@0U9BD09JFUP80VIVI00D0VYZJ09RHV02=SHd0SHf=09RHV0030:2PX080Ti>C00D0
8R8R06UYJ@29RHT0RHV908F5Q@0209JFUP0509>CT`2<S8`0OWin07inOP1lO7`00P20P8001@2ATI40
VYZJ09ZJVP2QXJ40WYjN0080<S8b00D0I6AT08F5Q@25QHD0QXJ608R8R0020:BTY0050:>SX`2HV9P0
V9RH0:>SX`2PX:000`2LW9`209RHV00507inOP0f=SH0=SHf08N7Q`2LW9`00P2JVYX01@2KVi/0X:2P
0:2PX02MWId0XZ:R0080WinO00@0X:2P0::RXP2RXZ80Xj>S0P2UYJD01@0e=CD0PH6107inOP1nOWh0
P8200080MgMg00D0KVi^07EeM@2ATI40TI6A09JFUP0209>CT`05096AT@23Ph<0Ph>308:2PP1aLG40
0P0b<S801@1kNg/0QXJ608J6QP2CTi<0V9RH0080W9bL00D0VYZJ09FEU@2EUID0U9BD0:6QX@020:2P
X0040:NWY`2TY:@0Y:BT05IFEP80O7al00D0ZZZZ0:FUY@2TY:@0Y:BT0:JVYP020:BTY0050:FUY@2S
Xj<0Z:RX0:RXZ02JVYX00P1cLg<01@1bLW80Kfm_06m_K`1@D500][Jf0080Zj^[00<0WYjN0:>SX`2S
Xj<00P2c/k<20:ZZZP0509jNWP2?Shl0Shn?0:FUY@2ZZZX00P2TY:@0101BDU80XJ6Q0:6QX@2KVi/2
08^;R`0507alO01dM7@0Q8B408B4Q01fMWH00P1lO7`01@2DU9@0VIVI09BDU02DU9@0LW9b0080=CDe
0`2JVYX01@2HV9P0Vi^K0:2PX02PX:00RXZ:0080Q8B400<0NGUiooooooooool03oooool0102ATI40
O7al07alO02>SXh209^KV`0508n?S`2XZ:P0Z:RX0;Rh^02/[:`00P26QXH01@2KVi/0J6QX06QXJ02>
SXh0UIFE0080H61P00@0OGem09bLW02LW9`0QhN70P2HV9P01@1[Jf/0I6AT075aL@1aLG40CDe=0080
MWIf00D0L71`08N7Q`27QhL0]kNg09RHV00207EeM@040;fm_@2KVi/0Vi^K08V9R@80UIFE00D0JFUY
09FEU@30`<00`<300:^[Z`0208j>SP0509BDU01:BTX0`/;20<;2`P2TY:@00P3>c/h01@2d];@0XZ:R
0::RXP2;Rh/0IVIV0080P82000@0Lg=c07UiN@1iNGT0OWin0P2GUiL01@2`/;00Z:RX0:RXZ02XZ:P0
TY:B0080UYJF00D0VIVI09jNWP2VYZH0YZJV0;Ng]`0207moO`050:RXZ02KVi/0Vi^K08>3P`2<S8`0
0P22PX80101@D500W9bL09bLW01oOgl209:BTP050;6a/@3EeMD0TI6A096AT@27QhL00P1]KFd01@2[
Zj/0XJ6Q0=[JfP3Jf]X0JVYZ0080BTY:0`3Ng]h01@1iNGT0JFUY07MgM`1gMgL0FEUI0080bLW900D0
Z:RX0;2`/02`/;00R8R809JFUP0208f=S@0409BDU01eMGD0MGEe096AT@80J6QX00D0Ogmo09>CT`1M
GEd0GEeM04a<C00203dm?@0507moO`1PH600EeMG05MGE`1]KFd00P1kNg/01@1LG5`0NWYj07YjNP1c
Lg<0L71`0080NWYj00@0KFe]079bLP1bLW80Ogmo0P2FUYH01@2=SHd0OGem0=GEe@3EeMD0LW9b0080
TY:B00@0VYZJ0::RXP1]KFd0KFe]0`1SHf<0101BDU80M7Ad07AdM01[Jf/:ooooo`002_ooool00`2g
]kL0/;2`0;2`/0030:j^[P050;2`/02^[Zh0YjNW0:NWY`2UYJD00P2TY:@01@2ZZZX0Zj^[0:^[Z`0f
=SH0Shn?00<0ZJVY0P2TY:@01@2:RXX0MgMg08J6QP26QXH0Vi^K0080QXJ600D0Rh^;0:6QX@2QXJ40
Y:BT09nOW`0203Ti>@0409:BTP2PX:00X:2P09>CT`<0YZJV00D0XZ:R09:BTP2BTY80SHf=08B4Q002
09NGU`040:2PX02>SXh0SXj>07UiN@80@D5100D0R8R80:6QX@2MWId0WIfM0::RXP0209VIV@0509fM
W@2IVIT0RHV908V9R@2<S8`00P2HV9P01@2UYJD0ZJVY0:VYZ@0i>CT0IVIV00<0OWin0P1iNGT0101/
K6`0LG5a07MgM`1gMgL407emO@80O7al00D0Ng]k0820P013@d<0@d=30861P@0207moO`0507YjNP25
QHD0QXJ608J6QP23Ph<00P2@T9001@2:RXX0Ti>C09ZJVP2JVYX0X:2P0080[:b/00D0H61P07moO`1o
Ogl0Z:RX0::RXP0208^;R`0508J6QP22PX80PX:208B4Q02=SHd00P2KVi/0102FUYH0OWin07inOP1h
N7P206=SH`0504A4A02][Jd0Z:RX0:RXZ02WYjL00P2RXZ801@2UYJD0Zj^[0:JVYP2VYZH0Y:BT0080
XJ6Q00D0Y:BT0:>SX`2KVi/0Vi^K04I6AP0209fMW@0508f=S@25QHD0QHF507MgM`1^KVh00P1jNWX0
1@1eMGD0LW9b079bLP29RHT0Ti>C0080XJ6Q00@0N7Qh034a<@0a<C40S8b<0P2=SHd01@29RHT0Shn?
0:2PX02PX:00QXJ60080NWYj00<0Ph>3ooooooooool03oooool0102@T900Ph>308>3P`2?Shl209VI
V@0508j>SP2_[jl0[jn_0:RXZ02e]KD00P26QXH01@2?Shl0Fe]K05]KF`2ATI40R8R80080IVIV00@0
TY:B08f=S@2=SHd0R8R80P2JVYX01@1_Kfl0GUiN071`L01`L700G5aL0080KVi^00D0M7Ad08N7Q`27
QhL0]KFe09:BTP0208R8R0040<[:bP2PX:00X:2P092@T080Ti>C00D0IVIV096AT@30`<00`<300:RX
Z00208V9R@0508F5Q@1:BTX0^k^k0;^k^`2][Jd00P3;bl/01@2`/;00VIVI09VIV@1oOgl0KFe]0080
SHf=00@0K6a/07=cL`1cLg<0QhN70P2;Rh/01@2EUID0VIVI0:ZZZP2ZZZX0SXj>0080R8R800D0]kNg
0:^[Z`2ZZZX0ZZZZ0;Bd]00208n?S`050;Jf]P29RHT0RHV908N7Q`2BTY800P1mOGd0101FEUH0SHf=
08f=S@27QhL20820P0050:n_[`3Bd]80RXZ:08Z:RP2?Shl00P1PH6001@2[Zj/0XJ6Q0=cLg03Lg=`0
HV9R0080CDe=00D0f=SH0=7Ad@3AdM40Ng]k06UYJ@0207MgM`04055AD@3>c/h0c/k>0;Zj^P80^;Rh
00D0U9BD07EeM@1/K6`0K6a/08V9R@0206YZJP0507moO`1jNWX0NWYj07IfMP2GUiL00P1DE5@01@10
@400D51@051@D025QHD0NGUi0080HV9R00@0H61P08:2PP22PX80QHF50P27QhL01@1[Jf/0IFEU06UY
J@1YJFT0NGUi0080Ph>300D0Rh^;0;6a/@2a/K40Q8B407UiN@020=OGe`0507AdM02EUID0UIFE09jN
WP2EUID00P1IFET0101XJ6P0GEeM05eMG@1>CTh206][J`0306a/K?oooooooooo00Sooooo000:oooo
o`040;Ng]`2^[Zh0[Zj^0;6a/@80[Jf]00D0];Bd0:n_[`2ZZZX0ZZZZ0:NWY`020:ZZZP050;:b/P2I
VIT0VIVI02XZ:P2;Rh/00P2TY:@01@2WYjL0XZ:R0::RXP22PX80N7Qh00<0PH610P1nOWh01@2<S8`0
V9RH09RHV02TY:@0X:2P0080=cLg00D0Vi^K09RHV02HV9P0Shn?09fMW@0209JFUP0509fMW@2FUYH0
UYJF092@T024Q8@00P2<S8`0102GUiL0Rh^;08^;R`1nOWh203dm?@05096AT@2QXJ40XJ6Q0:6QX@2O
Wil00P2EUID01@2KVi/0UIFE09NGU`2GUiL0T92@0080TY:B00D0Xj>S0:FUY@2UYJD0<c<c069RHP02
07=cL`0507moO`26QXH0QXJ606QXJ01WIfL00P1bLW80101hN7P0P8200820P022PX8208R8R00508J6
QP1oOgl0B4Q804Q8B01oOgl00P1fMWH01@1^KVh0N7Qh0861P@21PH40O7al0080N7Qh00D0Ogmo07al
O02BTY80TY:B09>CT`020:^[Z`0506a/K01kNg/0Ng]k0:JVYP2RXZ800P2JVYX01@2ATI40Ti>C09>C
T`2@T900Ti>C0080XZ:R00@0S8b<08>3P`23Ph<0Q8B40P1XJ6P01@1EEED0ZZZZ0:RXZ02XZ:P0/;2`
0080[:b/00D0[jn_0:VYZ@2XZ:P0Z:RX0:NWY`020:2PX0050::RXP2MWId0S8b<08b<S00T92@00P2L
W9`01@2UYJD0QXJ608J6QP1_Kfl0JFUY0080GUiN00D0JFUY06IVIP1VIVH0T92@09^KV`0209jNWP04
07emO@18B4P0B4Q80::RXP80WinO0P2VYZH20:n_[`040:JVYP2PX:00X:2P0:>SXa7ooooo00@0R8R8
07inOP1nOWh0R8R80P26QXH01@25QHD0/k>c0;>c/`2QXJ40_[jn0080Shn?00D0Rh^;05]KF`1KFe/0
U9BD08Z:RP0206UYJ@0408F5Q@2EUID0UIFE0861P@80UIFE00D0MWIf05mOG`1`L700L71`05QHF002
06IVIP0507EeM@2:RXX0RXZ:0<C4a02CTi<00P26QXH0102o_kl0SXj>08j>SP25QHD207emO@05069R
HP2@T900/K6a0;6a/@2GUiL00P2<S8`01@20P800CTi>0;bl_02l_;`0Vi^K0080_;bl00D0/[:b09nO
W`2OWil0OGem06i^KP0208R8R00407EeM@1_Kfl0Kfm_08f=S@80Shn?00D0/k>c0:ZZZP2VYZH0YZJV
0:BTY002092@T0050:ZZZP36a/H0XZ:R0::RXP2OWil00P25QHD01@2k^k/0Ogmo07moO`2;Rh/0Shn?
0080Rh^;00@0LG5a09ZJVP2JVYX0R8R80P1cLg<01@2`/;00alO70820P020P800WYjN0080GUiN00D0
X:2P09NGU`3Ogml0gmoO05MGE`0205eMG@050>7Qh@31`L40`L7109VIV@1hN7P00P1mOGd0101KFe/0
`/;20<;2`P3;bl/20:^[Z`0509^KV`2LW9`0RHV908V9R@2VYZH00P1gMgL01@20P800Ti>C09>CT`2C
Ti<0VYZJ0080N7Qh00D0@D5105ADE01DE5@0P82007emO@0207moO`04071`L02:RXX0RXZ:069RHP80
Lg=c00D0Jf][06YZJP1UIFD0IFEU0861P@0308j>SP80^[Zj00D0NWYj08V9R@3Lg=`0g=cL05MGE`02
09bLW00509FEU@29RHT0Ph>308>3P`1eMGD00P1ZJVX0101DE5@0LW9b079bLP1iNGT:ooooo`002_oo
ool0102h^;P0/k>c0;>c/`2d];@20:ZZZP050:VYZ@2^[Zh0ZJVY0:VYZ@2ZZZX00P2SXj<01@2PX:00
WinO09nOW`19BDT0WinO0080X:2P00D0XJ6Q09NGU`2GUiL0RHV907alO00207emO@0407QhN02ATI40
TI6A09ZJVP80Vi^K00D0Xj>S09NGU`0m?Cd0?Cdm09^KV`0209VIV@0509:BTP2TY:@0X:2P0:2PX02U
YJD00P2<S8`01@2@T900MWIf08N7Q`27QhL0QHF50080Ph>300D0MGEe04E5A@15ADD0Ti>C09bLW002
09>CT`05096AT@2NWYh0WYjN09jNWP2IVIT00P2GUiL0102?Shl0U9BD09BDU02NWYh209fMW@0504E5
A@1ZJVX0KFe]06e]K@21PH400P1kNg/01@20P800IVIV07AdM01dM7@0MGEe0080LG5a00D0Jf][07al
O01lO7`0MWIf07MgM`0204];B`05065QH@1PH600H61P06=SH`1[Jf/00P1aLG401@1ZJVX0Lg=c07=c
L`1kNg/0R8R80080Shn?00@0UYJF09ZJVP2JVYX0JFUY0P1oOgl01@26QXH0MWIf08>3P`23Ph<0S8b<
0080R8R800D0TI6A09JFUP2;Rh/0Rh^;07emO@0206YZJP0506IVIP1;Bd/0Bd];04];B`2?Shl00P2<
S8`01@2?Shl0RXZ:08Z:RP2<S8`0RHV90080OGem00D0Ogmo07YjNP1jNWX0NWYj07]kN`0205iNGP04
01LG5`1ZJVX0JVYZ07AdM080IVIV00D0CTi>03`l?00f=SH0=SHf03hn?P0203Hf=P0504a<C01LG5`0
G5aL05aLG016ATH00P0^;Rh01@14A4@0CDe=04e=C@1?Cdl0@D510080AdM700@0FUYJ06IVIP1VIVH0
I6AT4Oooool0102HV9P0RXZ:08Z:RP27QhL20820P00507inOP2_[jl0[jn_0;>c/`2d];@00P23Ph<0
1@26QXH0FUYJ05YJFP2OWil0TY:B0080H61P00@0KFe]09RHV02HV9P0QhN70P2BTY801@28R8P0IfMW
06i^KP1^KVh0D51@0080GUiN00D0NWYj08R8R028R8P0[Zj^09:BTP0207emO@040<30`023Ph<0Ph>3
0861P@80SHf=00D0J6QX09FEU@2d];@0];Bd09RHV00209VIV@050820P01GEeL0][Jf0;Jf]P2RXZ80
0P38b<P01@2][Jd0ZJVY0:VYZ@1hN7P0LG5a0080QhN700@0NGUi059BDP1BDU80P8200P2ATI401@2l
_;`0Y:BT09BDU02DU9@0WIfM0080Ogmo00D0[Jf]0=CDe02SXj<0Xj>S0:JVYP0208V9R@050<;2`P1k
Ng/0Ng]k07IfMP25QHD00P2BTY801020P800SXj>08j>SP2MWId206EUI@050:JVYP2j^[X0Q8B408B4
Q02WYjL00P1HF5P01@2ATI40UIFE0=oOg`3Ogml0D51@0080Lg=c00D0i>CT0;fm_@2m_Kd0UiNG07Yj
NP0207MgM`0406][J`2[Zj/0Zj^[0=OGe`80WinO00D0PH6109^KV`2>SXh0SXj>09^KV`0207]kN`05
08V9R@2PX:00X:2P0:RXZ02MWId00P1mOGd01@10@400FUYJ05YJFP2ATI40EUIF0080X:2P00@0LW9b
07QhN01hN7P0J6QX0P1bLW801@1aLG40KVi^06e]K@1]KFd0OGem0080UiNG00D0TI6A0;>c/`2c/k<0
KVi^09BDU0020=;BdP0505=CD`2:RXX0RXZ:092@T02;Rh/00P2BTY80101>CTh0K6a/06a/K01>CTh2
075aL@0306YZJ_oooooooooo00Sooooo000:ooooo`040;Rh^02c/k<0/k>c0;Bd]080ZZZZ00D0ZJVY
0:j^[P2YZJT0ZJVY0:ZZZP020:>SX`050:2PX02OWil0WinO04U9B@2OWil00P2PX:001@2QXJ40UiNG
09NGU`29RHT0O7al0080OGem00@0N7Qh096AT@2ATI40VYZJ0P2KVi/01@2SXj<0UiNG03dm?@0m?Cd0
Vi^K0080VIVI00D0TY:B0:BTY02PX:00X:2P0:FUY@0208b<S005092@T01fMWH0QhN708N7Q`25QHD0
0P23Ph<01@1eMGD0ADE504E5A@2CTi<0W9bL0080Ti>C00D0TI6A09jNWP2NWYh0WYjN09VIV@0209NG
U`0408n?S`2DU9@0U9BD09jNWP80WIfM00D0ADE506YZJP1]KFd0KFe]0861P@0207]kN`050820P01V
IVH0M7Ad07AdM01eMGD00P1aLG401@1[Jf/0O7al07alO01fMWH0MgMg0080Bd];00D0HF5Q061PH01P
H600Hf=S06][J`02075aL@0506YZJP1cLg<0Lg=c07]kN`28R8P00P2?Shl0102FUYH0VYZJ09ZJVP1Y
JFT207moO`0508J6QP1fMWH0Ph>308>3P`2<S8`00P28R8P01@2ATI40UYJF08^;R`2;Rh/0OGem0080
JVYZ00D0IVIV04];B`1;Bd/0Bd];08n?S`0208b<S00508n?S`2:RXX0RXZ:08b<S029RHT00P1mOGd0
1@1oOgl0NWYj07YjNP1jNWX0Ng]k0080GUiN00@05aLG06YZJP1ZJVX0M7Ad0P1VIVH01@1>CTh0?3`l
03Hf=P0f=SH0?Shn0080=SHf00D0C4a<05aLG01LG5`0G5aL04I6AP0202h^;P0504A4A01=CDd0CDe=
04m?C`11@D400P17AdL0101JFUX0IVIV06IVIP1TI6@Aooooo`0409RHV02:RXX0RXZ:08N7Q`80P820
00D0OWin0:n_[`2_[jl0/k>c0;Bd]00208>3P`0508J6QP1JFUX0FUYJ09nOW`2BTY800P1PH600101]
KFd0V9RH09RHV027QhL209:BTP0508R8R01WIfL0KVi^06i^KP1@D5000P1NGUh01@1jNWX0R8R808R8
R02^[Zh0TY:B0080OGem00@0`<3008>3P`23Ph<0PH610P2=SHd01@1XJ6P0UIFE0;Bd]02d];@0V9RH
0080VIVI00D0P82005MGE`2f][H0][Jf0::RXP020<S8b0050:f][@2YZJT0ZJVY07QhN01aLG400P27
QhL0101iNGT0DU9B059BDP20P802096AT@050;bl_02TY:@0U9BD09BDU02MWId00P1oOgl01@2][Jd0
e=CD0:>SX`2SXj<0YZJV0080RHV900D0`/;207]kN`1kNg/0MWIf08F5Q@0209:BTP040820P02>SXh0
SXj>09fMW@80IFEU00D0YZJV0;Zj^P24Q8@0Q8B40:NWY`0205QHF005096AT@2EUID0gmoO0=oOg`1@
D5000P1cLg<01@3Ti>@0_Kfm0;fm_@2GUiL0NWYj0080MgMg00@0Jf][0:^[Z`2[Zj/0emOG0P2OWil0
1@21PH40Vi^K08j>SP2>SXh0Vi^K0080Ng]k00D0RHV90:2PX02PX:00Z:RX09fMW@0207emO@050410
@01JFUX0FUYJ096AT@1FEUH00P2PX:00101bLW80N7Qh07QhN01XJ6P2079bLP05075aL@1^KVh0KFe]
06e]K@1mOGd00P2GUiL01@2ATI40/k>c0;>c/`1^KVh0U9BD0080d];B00D0De=C08Z:RP2:RXX0T92@
08^;R`0209:BTP0404i>CP1/K6`0K6a/04i>CP80LG5a00<0JVYZooooooooool02?ooool000[ooooo
00@0HF5Q05MGE`1GEeL0HF5Q0P1<C4`01@15ADD0>3Ph03hn?P0n?Sh0@4100080?Cdm00D0=3@d02TY
:@0Y:BT05ADE055AD@02051@D00504m?C`13@d<0@d=304M7A`19BDT00P1ADE401019BDT0?3`l03`l
?014A4@204M7A`0504E5A@0o?cl06QXJ01XJ6P10@4000P19BDT0100o?cl0>SXj03<c<`0c<c<303Hf
=P0502XZ:P0O7al05aLG01LG5`0H61P00P0F5QH01@0?3`l04Q8B018B4P0Z:RX0<c<c0080=CDe00D0
=3@d03Xj>P0j>SX0=3@d030`<00202`/;00401dM7@0_;bl0;bl_034a<@8071`L00D0:RXZ02@T900M
7Ad07AdM01hN7P02024Q8@806a/K0P0S8b<0100_;bl0:BTY02TY:@0R8R8202h^;P0502/[:`0/;2`0
;Rh^02h^;P0d=3@00`0b<S80100[:b/0:2PX02PX:00T92@202TY:@0505ADE01HF5P0DU9B059BDP0n
?Sh00P0^;Rh01@0i>CT0?3`l03`l?00k>c/0?3`l0080>SXj00D0=3@d03<c<`0c<c<06ATI030`<002
04U9B@04051@D01GEeL0EeMG04i>CP80F5QH101MGEd01@1NGUh0CTi>04i>CP1?Cdl0;Rh^0080:RXZ
0`10@4001@19BDT0B4Q804e=C@1=CDd0De=C0080DU9B00D0Bd];04m?C`1?Cdl0B4Q804i>CP0202h^
;P0506IVIP1`L700L71`08Z:RP2HV9P00P2FUYH0102RXZ80VYZJ09ZJVP2CTi<208^;R`0509NGU`2F
UYH0QHF508F5Q@11@D400P25QHD00`2@T93oooooooooo`0?ooooo`<0SHf=00@0QXJ607inOP1nOWh0
Ogmo0P2e]KD01@39bLT0aLG509JFUP2FUYH0RHV90080GemO00D0VIVI07inOP1NGUh0GUiN07AdM002
09NGU`<0RHV900D0Q8B406EUI@1WIfL0IfMW04a<C002059BDP0507inOP20P800P8200:b/[02DU9@0
0P1jNWX0102o_kl0Rh^;08^;R`24Q8@208F5Q@0506i^KP28R8P0`L710<71`@2PX:000P2YZJT01@24
Q8@0FEUI0;jn_P2n_[h0/K6a0080clo?00D0/K6a0;Fe]@2e]KD0Ng]k07emO@0208j>SP0408V9R@1O
Gel0GemO08n?S`80YZJV00D0[:b/0:6QX@2CTi<0Ti>C0::RXP0208^;R`030:JVYP3<c<`0Y:BT0080
Y:BT0P2>SXh01@2g]kL0MWIf07IfMP1cLg<0PH610080SXj>00@0TY:B09ZJVP2JVYX0^;Rh0P1^KVh0
1@2YZJT0]KFe096AT@2ATI40YZJV0080J6QX00D0RXZ:0:ZZZP3UiND0iNGU04m?C`0207MgM`050>?S
h`2^[Zh0[Zj^09VIV@25QHD00P1`L700101kNg/0_Kfm0;fm_@3Ng]h209RHV00506EUI@2PX:00UiNG
09NGU`20P8000P1jNWX01@1[Jf/0TI6A096AT@2i^KT0Shn?0080LG5a00D0BDU906=SH`1SHf<0RXZ:
04U9B@020::RXP0407IfMP1ZJVX0JVYZ07QhN080Jf][00D0OWin06YZJP1^KVh0KVi^07EeM@0208Z:
RP05096AT@2PX:00X:2P06m_K`2=SHd00P3@d=001@1FEUH0Ng]k07]kN`2<S8`0Q8B40080TI6A00@0
JFUY05YJFP1JFUX0Fe]K0P1kNg/00`1iNGWoooooooooo`08ooooo`002_ooool01025QHD0Ng]k07]k
N`26QXH203dm?@0505IFEP2IVIT0S8b<08b<S02?Shl00P1mOGd01@24Q8@0QhN708N7Q`2FUYH0Z:RX
0080Xj>S00D0WYjN0:VYZ@2YZJT0ZJVY03@d=00203`l?00307moO`1lO7`0O7al00@0Ph>300@0QHF5
08J6QP26QXH0SXj>0P26QXH0102?Shl0UiNG09BDU02DU9@305=CD`0506MWI`2KVi/0XJ6Q0:6QX@2T
Y:@00P2XZ:P01@2LW9`0YJFU0:FUY@2XZ:P0ZJVY0080Y:BT00D0SXj>0:ZZZP2ZZZX0?3`l06][J`02
09ZJVP0408>3P`1kNg/0Ng]k08N7Q`80Shn?00D0TI6A08:2PP1nOWh0OWin07IfMP0208:2PP0508>3
P`1kNg/05QHF01HF5P1nOWh00P2SXj<01@2LW9`0YjNW0:NWY`2CTi<0X:2P0080XZ:R00D0YjNW08N7
Q`27QhL0T92@09:BTP020:^[Z`0507moO`1KFe/0Fe]K0:NWY`26QXH00P2SXj<0102][Jd0/[:b0;:b
/P2^[Zh20:NWY`050:FUY@2LW9`0UIFE09FEU@2IVIT00P2KVi/01@10@400TI6A0;Jf]P2f][H0];Bd
0080/K6a00D0[:b/0:n_[`2_[jl0]KFe0;bl_0020;jn_P050<G5a@32`/80`/;20<G5a@1cLg<00P2G
UiL01@2i^KT0]KFe0;Fe]@2h^;P0^[Zj0080^k^k00<0_Kfm0<;2`P32`/800`31`L401@2l_;`0];Bd
05ADE01DE5@0UYJF0080/[:b00D0/k>c0;6a/@2XZ:P0Z:RX0:JVYP020:^[Z`050:b/[02[Zj/0Zj^[
0:^[Z`2^[Zh00P2SXj<0101GEeL0W9bL09bLW02TY:@Aooooo`0408b<S02XZ:P0Z:RX07moO`80NGUi
00D0P8200;Rh^02h^;P0b<S80<;2`P0209VIV@0508J6QP1OGel0GemO0:2PX02@T9000P1MGEd0101Z
JVX0QXJ608J6QP2:RXX208j>SP0508>3P`1_Kfl0J6QX06QXJ01;Bd/00P1JFUX01@22PX80PH610861
P@2/[:`0V9RH0080RXZ:00@0`l?308f=S@2=SHd0RXZ:0P2?Shl01@1WIfL0QXJ60<30`030`<00WIfM
0080ZJVY00D0Ng]k05QHF02^[Zh0[Zj^0:NWY`020<k>cP050:^[Z`2/[:`0[:b/07UiN@1kNg/00P24
Q8@01028R8P0D51@051@D025QHD20:ZZZP050<30`02JVYX0UYJF09JFUP2WYjL00P2QXJ401@2UYJD0
clo?0:b/[02/[:`0WIfM0080U9BD00D0`/;2075aL@1aLG40M7Ad0861P@0208Z:RP0409VIV@2ATI40
TI6A0;Jf]P80Lg=c00D0XZ:R0:BTY027QhL0QhN709nOW`02079bLP0508J6QP2VYZH0gMgM0=gMg@1<
C4`00P28R8P00`3UiND0W9bL09bLW00208n?S`80QXJ600@0QHF50;:b/P2b/[80fm_K0P2ATI401@1R
HV80WinO09ZJVP2JVYX0SHf=0080WinO00D0Ogmo08N7Q`27QhL0/[:b07emO@0208N7Q`0505YJFP1Q
HF40HF5Q07]kN`12@T800P2JVYX0101hN7P0HV9R069RHP1iNGT207=cL`05092@T01VIVH0VIVI09VI
V@1YJFT00P2PX:001@2HV9P0X:2P0:2PX01UIFD0RXZ:0080`<3000D0IFEU07YjNP1jNWX0WinO08>3
P`0207QhN00407alO01KFe/0Fe]K05YJFP80Q8B400<0MGEeooooooooool02?ooool000[ooooo00@0
QHF507]kN`1kNg/0QXJ60P0m?Cd01@1FEUH0VIVI08b<S02<S8`0Shn?0080OGem00D0Q8B408N7Q`27
QhL0UYJF0:RXZ0020:>SX`0509jNWP2YZJT0ZJVY0:VYZ@0d=3@00P0l?3`00`1oOgl0O7al07alO004
08>3P`0408F5Q@26QXH0QXJ608j>SP80QXJ600@0Shn?09NGU`2DU9@0U9BD0`1CDe<01@1WIfL0Vi^K
0:6QX@2QXJ40Y:BT0080Z:RX00D0W9bL0:FUY@2UYJD0Z:RX0:VYZ@020:BTY00508j>SP2ZZZX0ZZZZ
03`l?01[Jf/00P2JVYX01023Ph<0Ng]k07]kN`27QhL208n?S`05096AT@22PX80OWin07inOP1fMWH0
0P22PX801@23Ph<0Ng]k01HF5P0F5QH0OWin0080Xj>S00D0W9bL0:NWY`2WYjL0Ti>C0:2PX0020::R
XP050:NWY`27QhL0QhN7092@T02BTY800P2[Zj/01@1oOgl0Fe]K05]KF`2WYjL0QXJ60080Xj>S00@0
[Jf]0;:b/P2b/[80[Zj^0P2WYjL01@2UYJD0W9bL09FEU@2EUID0VIVI0080Vi^K00D0@410096AT@2f
][H0][Jf0;Bd]0020;6a/@050:b/[02_[jl0[jn_0;Fe]@2l_;`00P2n_[h01@35aLD0`/;20<;2`P35
aLD0Lg=c0080UiNG00D0^KVi0;Fe]@2e]KD0^;Rh0;Zj^P020;^k^`030;fm_@32`/80`/;200<0`L71
00D0_;bl0;Bd]01DE5@0E5AD09JFUP020;:b/P050;>c/`2a/K40Z:RX0:RXZ02VYZH00P2[Zj/01@2/
[:`0Zj^[0:^[Z`2[Zj/0[Zj^0080Xj>S00@0EeMG09bLW02LW9`0Y:BT4Oooool0102<S8`0Z:RX0:RX
Z01oOgl207UiN@050820P02h^;P0^;Rh0<S8b032`/800P2IVIT01@26QXH0GemO05mOG`2PX:00T92@
0080GEeM00@0JVYZ08J6QP26QXH0RXZ:0P2>SXh01@23Ph<0Kfm_06QXJ01XJ6P0Bd];0080FUYJ00D0
PX:20861P@21PH40[:b/09RHV00208Z:RP040<?3``2=SHd0SHf=08Z:RP80Shn?00D0IfMW08J6QP30
`<00`<3009fMW@020:VYZ@0507]kN`1HF5P0[Zj^0:j^[P2WYjL00P3>c/h01@2[Zj/0[:b/0:b/[01i
NGT0Ng]k0080Q8B400@0R8R8051@D01@D500QHF50P2ZZZX01@30`<00VYZJ09JFUP2FUYH0YjNW0080
XJ6Q00D0YJFU0<o?c`2/[:`0[:b/09fMW@0209BDU0050<;2`P1aLG40LG5a07AdM021PH400P2:RXX0
102IVIT0TI6A096AT@2f][H207=cL`050::RXP2TY:@0QhN708N7Q`2OWil00P1bLW801@26QXH0YZJV
0=gMg@3MgMd0C4a<0080R8R800<0iNGU09bLW02LW9`00P2?Shl208J6QP0408F5Q@2b/[80/[:b0=_K
f`80TI6A00D0HV9R09nOW`2JVYX0VYZJ08f=S@0209nOW`0507moO`27QhL0QhN70;:b/P1mOGd00P27
QhL01@1JFUX0HF5Q065QH@1kNg/0@T920080VYZJ00@0N7Qh069RHP1RHV80NGUi0P1cLg<01@2@T900
IVIV09VIV@2IVIT0JFUY0080X:2P00D0V9RH0:2PX02PX:00IFEU08Z:RP020<30`00506EUI@1jNWX0
NWYj09nOW`23Ph<00P1hN7P0101lO7`0Fe]K05]KF`1JFUX208B4Q00307EeMOoooooooooo00Sooooo
000:ooooo`040:^[Z`2b/[80/[:b0;2`/080BTY:00D0Jf][09nOW`2KVi/0Vi^K092@T00308F5Q@80
RXZ:00@0UiNG0::RXP2NWYh0WYjN0`2XZ:P01@2`/;00GemO05]KF`1KFe/0UiNG0080PH6100D0PX:2
07moO`1oOgl0Ng]k07MgM`0207=cL`0507inOP21PH40PH6107UiN@26QXH00P2HV9P01@1ADE40HV9R
069RHP1TI6@0TI6A0080YjNW00@0YZJV0:6QX@2QXJ40Ph>30P2JVYX01@2MWId0Y:BT0:BTY02TY:@0
SXj>0080[:b/00D0@d=3075aL@2>SXh0SXj>07]kN`0207UiN@0307YjNP1mOGd0OGem0080OWin0P1l
O7`307inOP0508F5Q@1oOgl0820P020P802;Rh/00P2PX:001@2QXJ40Xj>S0:>SX`2GUiL0WIfM0080
YZJV00D0Y:BT07UiN@1iNGT0NWYj08J6QP020:b/[00309NGU`1NGUh0GUiN0080UYJF0P2MWId0102N
WYh0XZ:R0::RXP2SXj<209ZJVP0509nOW`2KVi/0TI6A096AT@2JVYX00P2CTi<0100o?cl0/[:b0;fm
_@2m_Kd40;Rh^080_;bl00D0_[jn0<71`@31`L40`L710;^k^`020<30`0050;jn_P1YJFT0QXJ608J6
QP2ZZZX00P2_[jl01@2VYZH0XJ6Q09RHV02HV9P0XZ:R0080Z:RX00D0]kNg0:j^[P2^[Zh0[Zj^0:RX
Z00205MGE`050:>SX`2VYZH0YZJV0:>SX`2UYJD01@2TY:@01@2RXZ80YJFU0:FUY@2WYjL0Zj^[0080
V9RH00@0Cdm?08^;R`2;Rh/0WIfM4Oooool0102;Rh/0YZJV0:JVYP1mOGd207=cL`0507inOP2^[Zh0
[Zj^0<?3``2WYjL00P2CTi<01@1lO7`0GEeM05eMG@2LW9`0SHf=0080Hf=S00@0LW9b07moO`1oOgl0
V9RH0`26QXH0101dM7@0JFUY06UYJ@12@T8204i>CP0507inOP1fMWH0MWIf0;Vi^@2LW9`00P26QXH0
102h^;P0SHf=08f=S@2:RXX208^;R`0505eMG@1iNGT0/[:b0;:b/P2GUiL00P2PX:001@23Ph<0Fe]K
0;Zj^P2j^[X0Zj^[0080bl_;00D0YZJV0:BTY02TY:@0NWYj08>3P`0208F5Q@0408R8R01=CDd0CDe=
0820P080Xj>S00D0/k>c0:>SX`2GUiL0UiNG0:6QX@0209ZJVP050:2PX038b<P0Xj>S0:>SX`2IVIT0
0P2=SHd01@2n_[h0MWIf07IfMP1bLW80PX:20080Shn?00@0UYJF09bLW02LW9`0`<300P1lO7`01@2T
Y:@0Z:RX08j>SP2>SXh0UIFE0080Ogmo00D0V9RH0:ZZZP3Ph>00h>3P03`l?00209>CT`050>?Sh`2F
UYH0UYJF07inOP22PX800P2ATI40102LW9`0a/K60<K6aP3Jf]X208V9R@0505MGE`2DU9@0VIVI09VI
V@24Q8@00P2>SXh01@24Q8@0Xj>S0:>SX`2o_kl0SXj>0080Ogmo00D0ATI605iNGP1NGUh0PH6104];
B`0208V9R@0407IfMP1lO7`0O7al08Z:RP80QHF500D0RXZ:07MgM`2d];@0];Bd06=SH`0208f=S@05
08^;R`2^[Zh0[Zj^06e]K@2KVi/00P2WYjL01@1aLG40Lg=c07=cL`2/[:`0RXZ:0080O7al00@0HF5Q
05=CD`1CDe<0De=C0P1kNg/00`1/K6coooooooooo`08ooooo`002_ooool0102ZZZX0[:b/0:b/[02Z
ZZX204I6AP0506ATI02HV9P0W9bL09bLW02FUYH00P2;Rh/01@28R8P0Rh^;08^;R`27QhL0Shn?0080
SHf=00D0V9RH09nOW`2OWil0YjNW05QHF00204M7A`0407emO@2:RXX0RXZ:08Z:RP80Q8B400@0NWYj
07QhN01eMGD0MGEe0`26QXH207QhN080Rh^;00D0F5QH069RHP1RHV80FUYJ08>3P`020:FUY@0409nO
W`2KVi/0Vi^K07MgM`80UYJF00D0Vi^K09jNWP2OWil0WinO07alO0020:6QX@0403hn?P1TI6@0OWin
07inOP<0M7Ad0`1_Kfl01@1eMGD0N7Qh07QhN01hN7P0OGem0080N7Qh00D0NGUi07IfMP0^;Rh0;Rh^
08b<S00208Z:RP0509NGU`2ATI40TI6A09JFUP2NWYh00P2TY:@01@2VYZH0QhN708N7Q`23Ph<0Rh^;
0080Y:BT00D0Shn?04a<C01<C4`0Vi^K09VIV@0209nOW`040::RXP2OWil0WinO0:>SX`<0WinO00@0
SXj>09>CT`2CTi<0TY:B0P2CTi<0100n?Sh0/;2`0;jn_P2n_[h40;fm_@80^KVi00D0^[Zj0;Vi^@2g
]kL0]kNg0;>c/`020;6a/@050:b/[01DE5@0NGUi07UiN@2JVYX00P2ATI401@1fMWH0MGEe08V9R@29
RHT0UiNG0080I6AT00D0YjNW09:BTP2BTY80U9BD08n?S`0205IFEP0509BDU02QXJ40XJ6Q09nOW`2L
W9`00P2IVIT409RHV0<0XZ:R00@0Y:BT08B4Q024Q8@0=SHf0P2;Rh/00`2IVIWoooooooooo`0?oooo
o`0408V9R@2YZJT0ZJVY0820P080KVi^00D0Ng]k0:j^[P2^[Zh0_kno0::RXP020:2PX00507emO@1U
IFD0IFEU09FEU@2<S8`00P1WIfL0101iNGT0OWin07inOP2UYJD208V9R@0508Z:RP1jNWX0Hf=S06=S
H`1:BTX00P1FEUH01@20P800HF5Q065QH@2i^KT0/K6a0080U9BD00@0bLW909>CT`2CTi<0Shn?0P2C
Ti<01@1^KVh0PH610<k>cP3>c/h0XJ6Q0080ZJVY00D0Ng]k05EEE@2b/[80/[:b0:ZZZP020<K6aP<0
[:b/00D0Ogmo07]kN`27QhL0QhN708J6QP0204a<C00507emO@2VYZH0YZJV0;Bd]02`/;000P20P800
1@2TY:@0YJFU0:FUY@2a/K40f][J0080Xj>S00@0X:2P09bLW02LW9`0a<C40P1gMgL207]kN`80Ti>C
00@0SXj>0:^[Z`2[Zj/0[Jf]0P2;Rh/01@2YZJT0/[:b096AT@2ATI40QXJ60080VIVI00D0UiNG0;6a
/@3MgMd0gMgM03/k>`0209fMW@050>?Sh`2KVi/0Vi^K07]kN`1cLg<00P26QXH0102LW9`0cLg=0<g=
c@30`<0209BDU00505ADE02MWId0Shn?08n?S`1iNGT00P2?Shl01@2:RXX0U9BD09BDU02a/K40RHV9
0080PH6100D0<30`05YJFP1JFUX0MWIf04Y:BP0207EeM@0407alO01oOgl0Ogmo07UiN@80S8b<00D0
Lg=c08:2PP2l_;`0_;bl07=cL`02096AT@0409JFUP2/[:`0[:b/07emO@<0ZJVY00D0QhN707IfMP1f
MWH0W9bL09^KV`0208R8R00405mOG`1@D500D51@051@D080T92@00<0P820ooooooooool02?ooool0
00[ooooo00@0[Zj^0:f][@2][Jd0Xj>S0P11@D400`1GEeL0Vi^K09nOW`0209nOW`80VYZJ00D0VIVI
0::RXP2RXZ80WinO09FEU@0207alO00508b<S02EUID0UIFE0:FUY@1>CTh00P0^;Rh0101aLG40MgMg
07MgM`24Q8@208:2PP0407emO@2:RXX0SHf=08f=S@<0Rh^;0P26QXH208n?S`0505YJFP1=CDd0CDe=
06ATI02<S8`00P2FUYH0102>SXh0TY:B09:BTP1[Jf/207EeM@0508:2PP2ATI40Rh^;08^;R`1ZJVX0
0P1YJFT01@0/;2`0@d=307]kN`1kNg/0NWYj0080N7Qh00D0KFe]075aL@1aLG40Ng]k0820P0020861
P@0507QhN01]KFd0KFe]06MWI`1RHV800P0n?Sh00`26QXH0Rh^;08^;R`0408J6QP0409:BTP2JVYX0
VYZJ0:NWY`80Vi^K00D0U9BD08V9R@2;Rh/0Rh^;05=CD`0201LG5`0508F5Q@2?Shl0QHF508F5Q@23
Ph<00P2;Rh/01@2<S8`0QhN708N7Q`24Q8@0Ph>30080SHf=00D0Ogmo07UiN@1iNGT0>3Ph08N7Q`02
09bLW00409:BTP2?Shl0Shn?09>CT`80QhN700D0PX:2096AT@2?Shl0Shn?08j>SP0208b<S00507Ui
N@10@400KFe]06e]K@1HF5P00P19BDT01@0k>c/0ADE504U9B@19BDT0@D510080ADE500D0B4Q803Hf
=P0f=SH0?clo03Lg=`02034a<@0504I6AP1<C4`0C4a<05EEE@1;Bd/00P1=CDd01018B4P0Bd];04];
B`1>CTh204U9B@050451@@0j>SX08R8R028R8P0C4a<00P0S8b<00`0g=cOoooooooooo`0?ooooo`04
08R8R02c/k<0/k>c08N7Q`80NWYj00D0RHV90;Rh^02h^;P0aLG509jNWP0209nOW`0508:2PP1]KFd0
KFe]08J6QP1mOGd00P1WIfL0101TI6@0G5aL05aLG02[Zj/208J6QP0508Z:RP1mOGd0IVIV06IVIP15
ADD00P1EEED01@0a<C40FUYJ05YJFP2a/K40XJ6Q0080UYJF00@0_kno08f=S@2=SHd0RHV90P27QhL0
1@1aLG40QXJ60<30`030`<00UiNG0080WIfM00D0Kfm_065QH@34a<@0a<C40;Jf]P020<K6aP050:b/
[02e]KD0]KFe07emO@1nOWh00P2@T900102BTY80BDU904U9B@1bLW820:VYZ@050:JVYP2d];@0O7al
07alO02a/K400P2f][H01@2h^;P0fMWI09^KV`2KVi/0UYJF0080W9bL00D0`l?307]kN`1kNg/0Ogmo
07]kN`0308f=S@80WYjN00D0W9bL09jNWP2NWYh0/;2`0:^[Z`0209FEU@0507EeM@2UYJD0YJFU0:FU
Y@2i^KT00P3Fe]H01012@T80Zj^[0:^[Z`3Vi^H20:VYZ@0507UiN@1UIFD0PH610861P@2LW9`00P2f
][H01@2DU9@0Zj^[0:^[Z`1TI6@0/;2`0080VIVI00@0Rh^;09bLW02LW9`0S8b<0P2=SHd01@2XZ:P0
SHf=07emO@1mOGd0=SHf0080KVi^00D0Ph>304M7A`1XJ6P0J6QX07=cL`0206YZJP0506i^KP2ATI40
TI6A08:2PP2<S8`00P2m_Kd0101eMGD0Rh^;08^;R`29RHT209bLW0050861P@2CTi<0WIfM09fMW@26
QXH00P2VYZH01@2XZ:P0ZJVY07UiN@1iNGT0Fe]K0080CDe=00@0G5aL07IfMP1fMWH0K6a/2_ooool0
00[ooooo00@0[Zj^0:f][@2][Jd0Xj>S0P11@D400`1GEeL0Vi^K09nOW`0209nOW`80VYZJ00D0VIVI
0::RXP2RXZ80WinO09FEU@0207alO00508b<S02EUID0UIFE0:FUY@1>CTh00P0^;Rh0101aLG40MgMg
07MgM`24Q8@208:2PP0407emO@2:RXX0SHf=08f=S@<0Rh^;0P26QXH208n?S`0505YJFP1=CDd0CDe=
06ATI02<S8`00P2FUYH0102>SXh0TY:B09:BTP1[Jf/207EeM@0508:2PP2ATI40Rh^;08^;R`1ZJVX0
0P1YJFT01@0/;2`0@d=307]kN`1kNg/0NWYj0080N7Qh00D0KFe]075aL@1aLG40Ng]k0820P0020861
P@0507QhN01]KFd0KFe]06MWI`1RHV800P0n?Sh00`26QXH0Rh^;08^;R`0408J6QP0409:BTP2JVYX0
VYZJ0:NWY`80Vi^K00D0U9BD08V9R@2;Rh/0Rh^;05=CD`0201LG5`0508F5Q@2?Shl0QHF508F5Q@23
Ph<00P2;Rh/01@2<S8`0QhN708N7Q`24Q8@0Ph>30080SHf=00D0Ogmo07UiN@1iNGT0>3Ph08N7Q`02
09bLW00409:BTP2?Shl0Shn?09>CT`80QhN700D0PX:2096AT@2?Shl0Shn?08j>SP0208b<S00507Ui
N@10@400KFe]06e]K@1HF5P00P19BDT01@0k>c/0ADE504U9B@19BDT0@D510080ADE500D0B4Q803Hf
=P0f=SH0?clo03Lg=`02034a<@0504I6AP1<C4`0C4a<05EEE@1;Bd/00P1=CDd01018B4P0Bd];04];
B`1>CTh204U9B@050451@@0j>SX08R8R028R8P0C4a<00P0S8b<00`0g=cOoooooooooo`0?ooooo`04
08R8R02c/k<0/k>c08N7Q`80NWYj00D0RHV90;Rh^02h^;P0aLG509jNWP0209nOW`0508:2PP1]KFd0
KFe]08J6QP1mOGd00P1WIfL0101TI6@0G5aL05aLG02[Zj/208J6QP0508Z:RP1mOGd0IVIV06IVIP15
ADD00P1EEED01@0a<C40FUYJ05YJFP2a/K40XJ6Q0080UYJF00@0_kno08f=S@2=SHd0RHV90P27QhL0
1@1aLG40QXJ60<30`030`<00UiNG0080WIfM00D0Kfm_065QH@34a<@0a<C40;Jf]P020<K6aP050:b/
[02e]KD0]KFe07emO@1nOWh00P2@T900102BTY80BDU904U9B@1bLW820:VYZ@050:JVYP2d];@0O7al
07alO02a/K400P2f][H01@2h^;P0fMWI09^KV`2KVi/0UYJF0080W9bL00D0`l?307]kN`1kNg/0Ogmo
07]kN`0308f=S@80WYjN00D0W9bL09jNWP2NWYh0/;2`0:^[Z`0209FEU@0507EeM@2UYJD0YJFU0:FU
Y@2i^KT00P3Fe]H01012@T80Zj^[0:^[Z`3Vi^H20:VYZ@0507UiN@1UIFD0PH610861P@2LW9`00P2f
][H01@2DU9@0Zj^[0:^[Z`1TI6@0/;2`0080VIVI00@0Rh^;09bLW02LW9`0S8b<0P2=SHd01@2XZ:P0
SHf=07emO@1mOGd0=SHf0080KVi^00D0Ph>304M7A`1XJ6P0J6QX07=cL`0206YZJP0506i^KP2ATI40
TI6A08:2PP2<S8`00P2m_Kd0101eMGD0Rh^;08^;R`29RHT209bLW0050861P@2CTi<0WIfM09fMW@26
QXH00P2VYZH01@2XZ:P0ZJVY07UiN@1iNGT0Fe]K0080CDe=00@0G5aL07IfMP1fMWH0K6a/2_ooool0
00[ooooo00@0IVIV06a/K01/K6`0HF5Q0P0c<c<01@0b<S80H61P06IVIP1VIVH0HF5Q0080Fe]K0`1L
G5`01@1JFUX0H61P05]KF`1KFe/0I6AT0080FUYJ00@0HV9R03De=@0a<C40<C4a0`13@d<01@0k>c/0
A4A404A4A00g=cL0=CDe0080;2`/00D0=cLg030`<00`<300=cLg02d];@0202/[:`0502<S8`0R8R80
8R8R02PX:00_;bl00P0a<C40100R8R805ADE01DE5@0F5QH2018B4P0501DE5@0^;Rh09bLW02LW9`0N
7Qh00P0G5aL00`0A4A405ADE02/[:`0202/[:`80<C4a00D0BDU903hn?P0n?Sh0@d=304I6AP0204Q8
B0<0<S8b00D0@d=303/k>`0B4Q804Q8B01/K6`0202<S8`05030`<00o?cl0?clo03`l?00/;2`00P0b
<S801@10@400>c/k03/k>`0b<S80;2`/00806ATI00D07QhN02l_;`0_;bl0=cLg02XZ:P0201@D5004
02DU9@0e=CD0=CDe03/k>`80@D5100D0@T9201HF5P0Q8B408B4Q038b<P02034a<@0502d];@0c<c<0
=cLg03Lg=`0K6a/00P0_;bl00`19BDT0CTi>04i>CP0204i>CP80=SHf00D0Bd];051@D01@D500IFEU
07]kN`0208Z:RP0506IVIP1ADE40DE5A075aL@1`L7000P1_Kfl0101[Jf/0I6AT06ATI00S8b<206i^
KP0507AdM01ZJVX0J6QX06QXJ01SHf<00P0Y:BT01@0[:b/0H61P06UYJ@1YJFT0MWIf0080OWin00<0
MWIf01`L700L71`00P1cLg<207YjNP0408n?S`27QhL0QhN704Y:BQ7ooooo00@0RHV909fMW@2MWId0
S8b<0P1]KFd01@2?Shl0/;2`0;2`/036a/H0XZ:R0080Z:RX00D0T92@07EeM@1eMGD0U9BD07QhN002
06YZJP0406EUI@1OGel0GemO0:FUY@80OWin00D0MWIf07]kN`1SHf<0Hf=S051@D00205IFEP0503hn
?P1kNg/0Ng]k0:VYZ@2PX:000P2BTY80102m_Kd0TY:B09:BTP2?Shl208Z:RP0507QhN02CTi<0^[Zj
0;Zj^P2HV9P00P2PX:02071`L080`/;200@0^[Zj0<C4a034a<@0/;2`0P2YZJT01@23Ph<0OGem08n?
S`2?Shl0UIFE0080ATI600D0M7Ad0:NWY`2WYjL0]KFe0;Vi^@0207=cL`050:^[Z`2g]kL0]kNg0<?3
``3Ogml00P2IVIT309bLW0050;Zj^P25QHD0QHF508^;R`1cLg<00P2<S8`0101jNWX0WYjN09jNWP2B
TY820:>SX`050;Bd]02`/;00PH610861P@1aLG400P2XZ:P01@2`/;00`/;20=GEe@3EeMD0>CTi0080
[Zj^00D0jn_[0;Jf]P2f][H0NGUi05MGE`020820P004096AT@2j^[X0^[Zj0;Zj^P80[:b/00D0JVYZ
0:ZZZP27QhL0QhN708Z:RP0209ZJVP05092@T02<S8`0S8b<0;Fe]@2:RXX00P29RHT01@0m?Cd0OGem
07emO@1nOWh0D51@0080N7Qh00@0K6a/06][J`1[Jf/0Jf][0`20P8001029RHT0Y:BT0:BTY01]KFd2
07emO@0508N7Q`2HV9P0V9RH08:2PP2BTY800P2;Rh/01@22PX80Shn?08n?S`2TY:@0/k>c0080NWYj
00@0JVYZ04i>CP1>CTh0JFUY0P1hN7P00`1TI6Coooooooooo`08ooooo`002_ooool0101fMWH0D51@
051@D01lO7`207YjNP0507IfMP1nOWh0PX:208:2PP0e=CD00P0f=SH01@1cLg<0Ng]k07]kN`1jNWX0
S8b<0080Rh^;00D0:2PX055AD@1ADE40W9bL09^KV`020:RXZ0040:b/[02DU9@0U9BD03hn?P80Kfm_
00D0VIVI09bLW02LW9`0W9bL096AT@0207MgM`0502PX:02EUID0ZZZZ0:ZZZP2][Jd00P2XZ:P01@2^
[Zh0G5aL02/[:`0[:b/0SHf=0080U9BD00D0Shn?08Z:RP2:RXX0RXZ:04I6AP02028R8P0504=3@`1J
FUX0FUYJ05eMG@1cLg<00P23Ph<0100m?Cd0=CDe03De=@1ZJVX206EUI@05075aL@1`L700Kfm_06m_
K`0`<3000P0^;Rh01@1ZJVX0NGUi07MgM`1gMgL0Kfm_0080I6AT00D0;bl_06e]K@1]KFd0PX:207Ee
M@020861P@0509BDU01HF5P0F5QH00`<301jNWX00P2EUID01@2BTY80S8b<08b<S02NWYh0MGEe0080
=CDe00@0ZZZZ0:n_[`2_[jl0[Jf]0P2TY:@01@2NWYh09bLW07IfMP1fMWH0[Jf]0080[jn_00D0/k>c
0;fm_@2f][H0][Jf02h^;P020:FUY@050;^k^`2i^KT0^KVi0;^k^`2g]kL00P1FEUH01@2MWId0^;Rh
0;Rh^02i^KT0][Jf0080/[:b00D0Q8B4075aL@1aLG40ZJVY0;Fe]@020;Jf]P040;Bd]02XZ:P0Z:RX
03De=@80ZJVY00<0[jn_0:RXZ02WYjL00P2WYjL20451@@0306a/K02YZJT0/K6a0080/K6a0P2d];@0
1@2QXJ407alO01lO7`20P800MgMg0080HF5Q00@0Jf][06a/K01/K6`0@4104Oooool0101iNGT0Ti>C
09>CT`27QhL205EEE@0509RHV02UYJD0YJFU0;bl_02KVi/00P2/[:`01@22PX80NGUi07UiN@2EUID0
Ph>30080M7Ad00@0LG5a07QhN01hN7P0/K6a0P29RHT01@1lO7`0QhN706m_K`1_Kfl0I6AT0080F5QH
00D0I6AT08:2PP22PX80/;2`09^KV`0209BDU0040:j^[P2<S8`0S8b<08f=S@80QXJ600D0QhN709RH
V033`l<0`l?309fMW@0209nOW`0506][J`1cLg<0[:b/0:b/[033`l<00P32`/801@2ZZZX0VYZJ09ZJ
VP21PH40N7Qh0080QXJ600@0WYjN04e=C@1=CDd0IfMW0P2VYZH01@2][Jd0[Zj^07MgM`1gMgL0YZJV
0080Y:BT00D0bLW90=_Kf`2EUID0UIFE09fMW@0208n?S`050:^[Z`20P800P82008Z:RP1jNWX00P2<
S8`01023Ph<0VIVI09VIV@25QHD20::RXP050;>c/`2_[jl0NWYj07YjNP1TI6@00P2PX:001@2b/[80
alO70=?Cd`3Cdm<0<S8b0080[jn_00D0i^KV0;fm_@2m_Kd0O7al05eMG@0207inOP0409RHV02g]kL0
]kNg0;bl_080[jn_00D0Lg=c09ZJVP21PH40PH6108n?S`020861P@0508f=S@1mOGd0OGem0<C4a020
P8000P1mOGd01@0];Bd0J6QX06QXJ01OGel0DE5A0080Ph>300@0I6AT07]kN`1kNg/0OGem0P2:RXX0
1@23Ph<0NGUi08V9R@29RHT0NGUi0080Ph>30`2FUYH01@2=SHd0ZZZZ07moO`1oOgl0Shn?0080UiNG
00D0ZJVY0:BTY01gMgL0MgMg0820P00206=SH`0406][J`1mOGd0OGem079bLP[ooooo000:ooooo`04
07IfMP1@D500D51@07alO080NWYj00D0MWIf07inOP22PX80PX:203De=@0203Hf=P0507=cL`1kNg/0
Ng]k07YjNP2<S8`00P2;Rh/01@0X:2P0DE5A055AD@2LW9`0Vi^K0080Z:RX00@0[:b/09BDU02DU9@0
?Shn0P1_Kfl01@2IVIT0W9bL09bLW02LW9`0TI6A0080MgMg00D0:2PX09FEU@2ZZZX0ZZZZ0:f][@02
0:RXZ0050:j^[P1LG5`0:b/[02/[:`2=SHd00P2DU9@01@2?Shl0RXZ:08Z:RP2:RXX0ATI600808R8R
00D0@d=305YJFP1JFUX0GEeM07=cL`0208>3P`0403dm?@0e=CD0=CDe06YZJP80IFEU00D0LG5a071`
L01_Kfl0Kfm_030`<00202h^;P0506YZJP1iNGT0MgMg07MgM`1_Kfl00P1TI6@01@0_;bl0KFe]06e]
K@22PX80MGEe0080PH6100D0U9BD05QHF01HF5P030`<07YjNP0209FEU@0509:BTP2<S8`0S8b<09jN
WP1eMGD00P0e=CD0102ZZZX0[jn_0:n_[`2][Jd20:BTY00509jNWP0W9bL0MWIf07IfMP2][Jd00P2_
[jl01@2c/k<0_Kfm0;Jf]P2f][H0;Rh^0080YJFU00D0^k^k0;Vi^@2i^KT0^k^k0;Ng]`0205IFEP05
09fMW@2h^;P0^;Rh0;Vi^@2f][H00P2b/[801@24Q8@0LG5a075aL@2YZJT0]KFe0080][Jf00@0];Bd
0:RXZ02XZ:P0=CDe0P2YZJT00`2_[jl0Z:RX0:NWY`020:NWY`80@D5100<0K6a/0:VYZ@2a/K400P2a
/K420;Bd]0050:6QX@0O7al07alO0820P01gMgL00P1QHF40101[Jf/0K6a/06a/K010@40Aooooo`04
07UiN@2CTi<0Ti>C08N7Q`80EEEE00D0V9RH0:FUY@2UYJD0_;bl09^KV`020:b/[00508:2PP1iNGT0
NGUi09FEU@23Ph<00P1dM7@0101aLG40N7Qh07QhN02a/K4208V9R@0507alO027QhL0Kfm_06m_K`1T
I6@00P1HF5P01@1TI6@0PX:208:2PP2`/;00Vi^K0080U9BD00@0[Zj^08b<S02<S8`0SHf=0P26QXH0
1@27QhL0V9RH0<?3``33`l<0WIfM0080WinO00D0Jf][07=cL`2/[:`0[:b/0<?3``020<;2`P050:ZZ
ZP2JVYX0VYZJ0861P@1hN7P00P26QXH0102NWYh0CDe=04e=C@1WIfL20:JVYP050:f][@2^[Zh0MgMg
07MgM`2VYZH00P2TY:@01@39bLT0fm_K09FEU@2EUID0WIfM0080Shn?00D0Zj^[0820P020P800RXZ:
07YjNP0208b<S00408>3P`2IVIT0VIVI08F5Q@80XZ:R00D0/k>c0:n_[`1jNWX0NWYj06ATI0020:2P
X0050;:b/P37alL0dm?C0=?Cd`0b<S800P2_[jl01@3Vi^H0_Kfm0;fm_@1lO7`0GEeM0080OWin00@0
V9RH0;Ng]`2g]kL0_;bl0P2_[jl01@1cLg<0VYZJ0861P@21PH40Shn?0080PH6100D0SHf=07emO@1m
OGd0a<C40820P00207emO@0502d];@1XJ6P0J6QX05mOG`1ADE400P23Ph<0101TI6@0Ng]k07]kN`1m
OGd208Z:RP0508>3P`1iNGT0RHV908V9R@1iNGT00P23Ph<309JFUP0508f=S@2ZZZX0Ogmo07moO`2?
Shl00P2GUiL01@2YZJT0Y:BT07MgM`1gMgL0P8200080Hf=S00@0Jf][07emO@1mOGd0LW9b2_ooool0
00[ooooo00@0Ti>C05ADE01DE5@0Zj^[0P2`/;001@2[Zj/0/;2`0;6a/@2a/K40GEeM0080L71`00D0
]KFe0;Ng]`2g]kL0^;Rh0;bl_0020;fm_@0503Hf=P1RHV80HV9R0:j^[P2c/k<00P2i^KT30;Ng]`05
04M7A`23Ph<0Ph>30;Fe]@2c/k<00P2_[jl01@2`/;00Ph>308>3P`0P8200VIVI0080XJ6Q00D0YjNW
0:JVYP2VYZH0Z:RX06EUI@020492@P040:BTY02[Zj/0Zj^[0:VYZ@80[Zj^00D0[:b/05UIF@0f=SH0
=SHf05YJFP0206MWI`0406][J`1^KVh0K6a/06a/K0<0=CDe0`1eMGD01@1gMgL0JFUY06=SH`1SHf<0
:2PX0080;Rh^00D0GUiN06YZJP1^KVh0KVi^06QXJ00206EUI@05028R8P1VIVH0IVIV07YjNP1bLW80
0P1aLG401@2<S8`0G5aL05aLG00=3@d0NWYj00<0W9bL0P2JVYX01@2DU9@0HV9R05IFEP1FEUH0[jn_
0080/K6a00D0Y:BT09FEU@2EUID0SHf=02HV9P0207EeM@050:VYZ@2XZ:P0Z:RX0;>c/`2k^k/00P2a
/K40100];Bd0/;2`0;2`/02l_;`20;Vi^@050;^k^`2i^KT0E5AD05ADE02IVIT00P2g]kL01@2j^[X0
^k^k0;Vi^@2i^KT0QHF50080LG5a00D0/;2`0;6a/@2/[:`0[:b/0:RXZ0020::RXP0503`l?02XZ:P0
Z:RX0:n_[`2ZZZX00`2TY:@20492@P0308>3P`2d];@0/;2`0080/;2`0P2c/k<01@2LW9`08R8R028R
8P27QhL0NWYj0080IfMW00@0O7al08J6QP26QXH0CDe=4Oooool0101mOGd0VIVI09VIV@2;Rh/205]K
F`050:2PX02IVIT0VIVI0:NWY`2FUYH00P2ZZZX01@24Q8@0KFe]06e]K@26QXH0QHF50080PH6100@0
MWIf06UYJ@1YJFT0[:b/0P2GUiL01@1nOWh0Ti>C06i^KP1^KVh0GEeM0080AdM700D0?Shn08B4Q024
Q8@0^;Rh09jNWP020:2PX0040;fm_@2>SXh0SXj>09>CT`80RHV900D0Ogmo0:>SX`33`l<0`l?309^K
V`0209bLW00507AdM01jNWX0YJFU0:FUY@3Hf=P00P3AdM401@2h^;P0UiNG09NGU`26QXH0O7al0080
OGem00@0Vi^K069RHP1RHV80J6QX0P2PX:00102c/k<0Vi^K07AdM01dM7@30:>SX`050=GEe@3Cdm<0
XJ6Q0:6QX@2YZJT00P27QhL01@2ZZZX0Shn?08n?S`27QhL0QXJ60080QHF500@0Ogmo09JFUP2FUYH0
Ogmo0P2CTi<01@2d];@0/k>c08>3P`23Ph<0HV9R0080WYjN00D0ZZZZ0<;2`P32`/80`/;202`/;002
0;Fe]@050>[ZjP30`<00`<30079bLP1RHV800P1FEUH0102<S8`0XJ6Q0:6QX@2h^;P20;6a/@0508N7
Q`2YZJT0T92@092@T02PX:000P1iNGT01@2GUiL0K6a/06a/K02g]kL0QXJ60080Ogmo00D0>CTi07mo
O`1oOgl0LG5a069RHP0209>CT`0405mOG`1iNGT0NGUi06m_K`80SHf=00D0MgMg07YjNP1oOgl0Ogmo
08>3P`0208N7Q`0509jNWP2?Shl0Shn?092@T02QXJ400P2:RXX01@2KVi/0UYJF09JFUP2JVYX0V9RH
0080K6a/00@0MGEe05aLG01LG5`0KFe]0P1mOGd00`1`L73oooooooooo`08ooooo`002_ooool0102D
U9@0EUIF05IFEP2TY:@20:^[Z`050:ZZZP2TY:@0WinO09nOW`1?Cdl00P1iNGT0102i^KT0_;bl0;bl
_02i^KT30;Zj^P0504];B`1XJ6P0J6QX0:BTY02d];@00P2h^;P0102i^KT0]kNg0;Ng]`0o?cl208J6
QP050:n_[`2`/;00[:b/0:b/[02_[jl00P2HV9P00`0g=cL0Zj^[0;6a/@020;6a/@80/;2`00D0Zj^[
065QH@0f=SH0=SHf09VIV@020:ZZZP050:f][@2_[jl0[jn_0:j^[P1EEED00P0a<C401@1IFET0GUiN
05iNGP1KFe/0Bd];0080IfMW00@0?clo04I6AP16ATH0S8b<0P27QhL01@20P800LW9b06MWI`1WIfL0
:2PX0080;bl_00D0EeMG05QHF01QHF40HF5Q06=SH`02065QH@0502DU9@1dM7@0M7Ad08^;R`24Q8@0
0P1nOWh01@2BTY80GemO05mOG`0=3@d0Ti>C0080]KFe00D0[Zj^0:BTY02TY:@0XJ6Q06MWI`0206=S
H`030;6a/@2b/[80/[:b00<0/K6a00D0[Jf]03<c<`1oOgl0Ogmo0:VYZ@020:n_[`050;Bd]02j^[X0
]KFe0;Fe]@0d=3@00`2g]kL30;no_`040;Zj^P1DE5@0E5AD09^KV`80_Kfm00D0^[Zj0;Jf]P2e]KD0
]KFe08V9R@0207=cL`050:2PX02MWId0W9bL09bLW02BTY800P1oOgl01@0f=SH0YZJV0:JVYP2/[:`0
Zj^[0080Z:RX00@0Xj>S03lo?`0o?cl0P8200`2^[Zh0102`/;00[:b/0:b/[02VYZH203Lg=`050:^[
Z`2;Rh/0QhN708N7Q`2ATI400P27QhL00`1:BT[oooooooooo`0?ooooo`040861P@2HV9P0V9RH08^;
R`80Hf=S00D0WYjN09RHV02HV9P0^;Rh09ZJVP020:n_[`0508V9R@2ATI40TI6A096AT@1eMGD00P1^
KVh0101/K6`0F5QH05QHF02NWYh208B4Q00506UYJ@2?Shl0Kfm_06m_K`1BDU800P1XJ6P01@14A4@0
QXJ608J6QP2i^KT0UYJF0080Shn?00@0XZ:R08J6QP26QXH0N7Qh0P21PH401@23Ph<0][Jf0<C4a034
a<@0X:2P0080U9BD00D0K6a/07]kN`2SXj<0Xj>S0=3@d0020<;2`P050;6a/@28R8P0R8R80861P@29
RHT00P20P800102HV9P0M7Ad07AdM01cLg<209:BTP050:b/[02JVYX0NWYj07YjNP2QXJ400P2MWId0
1@3QhN40d];B0:f][@2][Jd0X:2P0080RHV900D0Xj>S09NGU`2GUiL0QHF509BDU00207UiN@0407Ad
M02@T900T92@08R8R080W9bL00D0/K6a0:>SX`1]KFd0KFe]06ATI00209RHV0050:FUY@34a<@0alO7
0<O7a`0V9RH00P2n_[h01@3WinL0_;bl0;bl_01bLW80MWIf0080H61P00@0WIfM0:JVYP2VYZH0_Kfm
0`2EUID0102/[:`0TY:B09:BTP2GUiL206IVIP0509jNWP1aLG40LG5a0::RXP2UYJD00P1YJFT01@0m
?Cd0KVi^06i^KP1HF5P0HV9R0080UYJF00@0EeMG075aL@1aLG40L71`0P26QXH01@1`L700P82006a/
K01/K6`0RHV90080PX:200D0^KVi09NGU`2GUiL0UYJF0:NWY`02092@T00509^KV`2DU9@0U9BD09ZJ
VP2BTY800P1dM7@0101aLG40IVIV06IVIP1YJFT207QhN00307]kNooooooooooo00Sooooo000:oooo
o`0409BDU01FEUH0EUIF0:BTY080Zj^[00D0ZZZZ0:BTY02OWil0WinO04m?C`0207UiN@040;Vi^@2l
_;`0_;bl0;Vi^@<0^[Zj00D0Bd];06QXJ01XJ6P0Y:BT0;Bd]0020;Rh^0040;Vi^@2g]kL0]kNg03lo
?`80QXJ600D0[jn_0;2`/02/[:`0[:b/0:n_[`0209RHV00303Lg=`2[Zj/0/K6a0080/K6a0P2`/;00
1@2[Zj/0HF5Q03Hf=P0f=SH0VIVI0080ZZZZ00D0[Jf]0:n_[`2_[jl0[Zj^05EEE@02034a<@0505UI
F@1NGUh0GUiN05]KF`1;Bd/00P1WIfL0100o?cl0ATI604I6AP2<S8`208N7Q`050820P01bLW80IfMW
06MWI`0X:2P00P0_;bl01@1GEeL0F5QH065QH@1QHF40Hf=S0080HF5Q00D09BDU07AdM01dM7@0Rh^;
08B4Q00207inOP0509:BTP1OGel0GemO00d=3@2CTi<00P2e]KD01@2^[Zh0Y:BT0:BTY02QXJ40IfMW
0080Hf=S00<0/K6a0;:b/P2b/[800`2a/K401@2][Jd0<c<c07moO`1oOgl0ZJVY0080[jn_00D0];Bd
0;Zj^P2e]KD0]KFe03@d=0030;Ng]`<0_kno00@0^[Zj05ADE01DE5@0Vi^K0P2m_Kd01@2j^[X0][Jf
0;Fe]@2e]KD0RHV90080Lg=c00D0X:2P09fMW@2LW9`0W9bL09:BTP0207moO`0503Hf=P2VYZH0YZJV
0:b/[02[Zj/00P2XZ:P0102SXj<0?clo03lo?`20P8030:j^[P040;2`/02/[:`0[:b/0:JVYP80=cLg
00D0Zj^[08^;R`27QhL0QhN7096AT@0208N7Q`0304Y:B_oooooooooo00oooooo00@0PH6109RHV02H
V9P0Rh^;0P1SHf<01@2NWYh0V9RH09RHV02h^;P0VYZJ0080[jn_00D0RHV9096AT@2ATI40TI6A07Ee
M@0206i^KP0406a/K01HF5P0F5QH09jNWP80Q8B400D0JFUY08n?S`1_Kfl0Kfm_059BDP0206QXJ005
04A4A026QXH0QXJ60;Vi^@2FUYH00P2?Shl0102RXZ80QXJ608J6QP1hN7P20861P@0508>3P`2f][H0
a<C40<C4a02PX:000P2DU9@01@1/K6`0Ng]k0:>SX`2SXj<0d=3@0080`/;200D0/K6a08R8R028R8P0
PH6108V9R@020820P00409RHV01dM7@0M7Ad07=cL`80TY:B00D0[:b/09ZJVP1jNWX0NWYj0:6QX@02
09fMW@050>7Qh@3Bd]80[Jf]0:f][@2PX:000P29RHT01@2SXj<0UiNG09NGU`25QHD0U9BD0080NGUi
00@0M7Ad092@T02@T900R8R80P2LW9`01@2a/K40Xj>S06e]K@1]KFd0I6AT0080V9RH00D0YJFU0<C4
a037alL0alO702HV9P020;jn_P050>OWi`2l_;`0_;bl079bLP1fMWH00P1PH600102MWId0YZJV0:JV
YP2m_Kd309FEU@040:b/[02BTY80TY:B09NGU`80IVIV00D0WYjN075aL@1aLG40XZ:R0:FUY@0206UY
J@0503dm?@1^KVh0KVi^05QHF01RHV800P2FUYH0101GEeL0LG5a075aL@1`L70208J6QP05071`L020
P800K6a/06a/K029RHT00P22PX801@2i^KT0UiNG09NGU`2FUYH0YjNW0080T92@00D0Vi^K09BDU02D
U9@0VYZJ09:BTP0207AdM004075aL@1VIVH0IVIV06UYJ@80N7Qh00<0Ng]kooooooooool02?ooool0
00[ooooo00@0U9BD05YJFP1JFUX0Y:BT0P2[Zj/20:NWY`80XZ:R00@0DU9B07MgM`1gMgL0[jn_0`2`
/;00102b/[80^;Rh0;Rh^01CDe<206ATI0050861P@2<S8`0WinO09nOW`2PX:000P2JVYX01@0a<C40
R8R808R8R02][Jd0ZZZZ0080YZJV00D0Zj^[08J6QP26QXH0>c/k0:FUY@020:NWY`<0[Jf]00D0Vi^K
05YJFP1HF5P0F5QH0:>SX`030:^[Z`<0/;2`00@0GUiN071`L01`L700IFEU0P1cLg<01@1DE5@0H61P
07=cL`1cLg<0FEUI0080Kfm_00D0Y:BT09VIV@2IVIT0QhN707emO@0206m_K`0402`/;00^;Rh0;Rh^
04=3@`<0BTY:00@0?Shn0451@@11@D4071`L0P2;Rh/01@2IVIT0T92@08f=S@2=SHd0UIFE0080EEEE
00D071`L09JFUP2ZZZX0ZZZZ0:^[Z`020:>SX`0509NGU`1_Kfl0De=C05=CD`2OWil00`2YZJT20:FU
Y@050:>SX`0h>3P0J6QX06QXJ01dM7@00P1cLg<01@2XZ:P0/k>c0;:b/P2b/[80=SHf0080QHF500D0
PX:208R8R028R8P0PH6107EeM@02038b<P0307IfMP23Ph<0Ph>30080Ogmo0P1]KFd01@11@D40DE5A
055AD@1]KFd0JFUY0080IVIV00@0G5aL05IFEP1FEUH0:2PX0P1JFUX2069RHP80Fe]K00D0ATI602<S
8`0S8b<0@d=3055AD@02059BDP0404U9B@13@d<0@d=3038b<P807QhN00D0?clo038b<P0e=CD0=CDe
034a<@02030`<00301/K6ooooooooooo00oooooo00@0QhN709FEU@2EUID0T92@0P1EEED01@2MWId0
VYZJ09ZJVP2d];@0U9BD0080]KFe00D0TY:B0:BTY02TY:@0T92@07MgM`0207alO00406a/K01bLW80
LW9b0:JVYP80PX:200D0QHF50:2PX025QHD0QHF5051@D00206a/K00504A4A028R8P0R8R80;Zj^P2<
S8`00P2HV9P0102TY:@0M7Ad07AdM01UIFD2079bLP0507=cL`2b/[80_kno0;no_`2CTi<00P2?Shl0
1@1`L700KFe]0:6QX@2QXJ40gMgM0080alO700D0/[:b08F5Q@25QHD0Shn?06i^KP0208B4Q00408j>
SP1iNGT0NGUi07AdM080TI6A00D0[:b/08R8R01cLg<0Lg=c096AT@0209>CT`050>?Sh`35aLD0/[:b
0;:b/P2YZJT00P2@T9001@2/[:`0SXj>08j>SP22PX80[Zj^0080PH6100@0Ogmo0:RXZ02XZ:P0Q8B4
0P2IVIT01@2e]KD0[Zj^08F5Q@25QHD0Ph>30080U9BD00D0alO70<[:bP2YZJT0ZJVY03@d=0020<C4
a0050>OWi`2ZZZX0ZZZZ07]kN`24Q8@00P1<C4`0102DU9@0X:2P0:2PX03AdM4209FEU@050:>SX`1o
Ogl0Y:BT0:BTY02GUiL00P1XJ6P01@28R8P0Ph>308>3P`24Q8@0^KVi0080De=C00D0>3Ph09JFUP2F
UYH0I6AT07=cL`02096AT@0405]KF`1aLG40LG5a05]KF`80LW9b00D0Hf=S06m_K`1SHf<0Hf=S08^;
R`0209VIV@050;Ng]`2TY:@0Y:BT08n?S`2a/K400P2/[:`01@2SXj<0][Jf0;Jf]P2HV9P0MgMg0080
P82000@0KVi^05eMG@1MGEd0Jf][0P20P8000`1^KVkoooooooooo`08ooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-7.08559, \
-2.21307, 0.704095, 0.704095}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-146.827, -2.21307, 0.704095, 0.704095}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute horizontal and vertical filtered images", "Subsection"],

Cell[BoxData[{
    \(\(filter = {1/4, \(-1\)/2, 1/4}\  // \ N;\)\), "\[IndentingNewLine]", 
    \(\(filterH = Table[filter, {5}];\)\), "\[IndentingNewLine]", 
    \(\(filterV = filterH\  // \ Transpose;\)\)}], "Input"],

Cell[BoxData[{
    \(\(wood1 = 
        ListConvolve[filterH, 
          wood[\([1, 1]\)], {\(-1\), \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(\(wood2 = 
        ListConvolve[filterV, 
          wood[\([1, 1]\)], {\(-1\), \(-1\)}];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(brick1 = 
        ListConvolve[filterH, 
          brick[\([1, 1]\)], {\(-1\), \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(brick2 = 
        ListConvolve[filterV, 
          brick[\([1, 1]\)], {\(-1\), \(-1\)}];\)\)}], "Input"],

Cell[BoxData[
    \(\(g1 = \(ListDensityPlot[#, Mesh \[Rule] False, Frame \[Rule] False, \ 
              PlotRange \[Rule] Automatic, \ 
              DisplayFunction \[Rule] Identity] &\)\  /@ \ {wood1, wood2, 
            brick1, brick2};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show horizontal and vertical filtered images", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[g1, 2]], ImageSize \[Rule] 400, \ 
        GraphicsSpacing \[Rule] 0.02];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.495285 0.495285 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
808E80AB60A7FF3B899E907682FF5FA399A1A543FF5382999B806FFF5591908BAA3FFF88
82919A947CFF60898FA0A4978D3EFF64928F9B5895FF2F8EAC9D4F96FF399D9C9A5897FF
4CB9A6956DDDC0419F999835FF7F739D928E4EFF458C9F8C3EFFA65EA09974B3CD69979A
972CFF7D779A9761C6DA628DA69629FF529556FF
888E66DD5E99FF5986A1908389D8799F84B4BB3EFF6D84989C8789F868939172D054E992
8496959389E96F8F9285C9958058FF6DA08F8F728CFF408DC78662A7FE508F9DA8738DE4
569FC09E6FC9B3599D99974EFF8B7492B0885EFF578DA28954FFA76B9998929AC274979D
953FFF857D989866CEBA7491A79A41FF689582CF
948D4FFF559CE171899F93918CB68A9D6FC4D043CF8886989C8F9FC07F959257FF56B8A3
869D90948EC7819A9069F38E7C70D57CA791848C91FC4F88DF7B74ADCA6E869BAE967FC7
6C7ADBAA6EB1AE6E9A999A64EA947B7FCD8C64F56C8EA5836AE7A8759785C184B67D93A4
8B54FFA66F968A80D09F8096A49A58ED7D9293AE
A19037FF499FB884919C98949B9A979957D6E34CA2958B99A1999BA48E97933DFF4B95A8
939A929394A295A58F50FF897786A888A99486999BC36D80F56E86B09B8C799DB7AE73A3
954AFAB46D9DA08996969B80BC9E836CEF8770C98094A1837CCFA67D9866FC72A2858FA9
7A70DFD55F8E7E99D683899CA1996EC9918FA190
9D9327FF429CB38895959C919B9B999649E1F4449F92919C9D9B92A1959C8F27FF3B8AAE
939B929298939EAA8E35FF866D949885AD9686A79AA07D7BFF6090BA74A27198C4C76393
9E31FFB661929C9A979994979F97905BFF847C9E959A9F868CB59E899948FF5D8B9091A8
6A8FC8EE56866DBDD26992A5989887A3A08FBA77
9B953BFF45A4AC898CB093919B999A9551D2ED52989191AB9D92939D99999235FF3C92AB
8FAA938898969CB08A35FF886C989B89A39D86A798A3797CFF628DBD729F729DC2CC628E
9F2AFFBF578E9F9C9C949997949C9148FF797892A19E998D8CA7A38F962AFF50768F9CA5
63A5C0E6608261D9C95A93AC96969892A18E9E96
9C9554FF57A3A18E76DE7F919B9A9A9365C0D964959083CE8D8E93A0969C924CFF4295A8
79D284889B969AAF8850FF88799788AD9A9390A0A4967C82F3758FA873B8759CB1C46F8F
9E43FFB55F8E9BAE978F9C97969B9655FF817F8AB0A2918E8AA9A28F9930FF617286AE9B
61AABBE2648363DBB66D91AB96998F999E91A68A
9C9370E7709F9D925DFF679199999B9877ADC77494916FF7798D92A0959B9468FF5C94A2
68F378859D9B98A68E6BE58F7F987FC298899B96A693808DD98290A073CE719EA8B18092
9A5DE3AF6A8F91C68B8E9B99979B9668EC848675D2A285918AA6A0939842FF747271D984
68ACBCC773886DCAAF7B8B9FB58C8E9A9796B180
9A938BB68B9D969845FF569B939B969A9096B586949360FF649192A095989882CD7A949C
55FF6883A09C9D99967DC196849A70D69E7E9A9CA0928895BB8E909977DC719C9CA88C96
9774C6AA758D84E57D8E9A979B98997AC98C8E5FF1A777928C9FA1969760FD85795BFF77
70AAB8A5888E7ABBA4888595D67C8B9A939CB27D
9E9697949B9E98952FFF4C9E9193989AA28BA3938E9555FF5B8B969F9593A192A0949995
47FF57859E9E9C929F969A998F9955F7A0769C9BA38C969A9C99909184E66E9C949B9997
978AA8A6808C78FF6E8E9A96999C9789AD92944CFFA26C9391999E9B977DCA918245FF6D
77A4AB9099948BA3A0957E92EB71899B90A0B775
9B9898999B9C9C9438FF5E96939699989E98989692994FFF568F98999995A18FA796968F
4FFF508E9AA19C90A297989A939346FF9B739D98A48B9D979795939082FA649590969DA1
97929E9A89867EFF58A18E989F96939D929B973EFFA06195919D969D989B989D8D31FF5E
7A9E9F9598969591A49C7593FD688C9590A6A580
968CAAA58D9D9C9252FF6E989198989590C47E96929B5CFF639398999C9191BA92929493
65FF638F99A09C8C99B38D99939358EF9D7EA196A28990AD9591959391DD699891999A9C
9A9B969E8B8980F7699F8E969C9E90989B96984AFF966A99909899A1979A9999893EFF62
799E9F9894989593A4967091FF60928D94AB938E
9183BDAA849B9C926BE1859691999C8E7AF467998EA06EE57495969D9E907CE677919794
79E56C92999D9C8E88D48196919565DD9A869F989F8A7AD88190969696C7749993969994
93C377AB89888ADE769F8E82ADB87C9799959B61FA9379988F85B3A58C999D988854FF74
79A19B89B09390989F927A9CED689A8F959FAB81
8F76CFAF7B9A9D8F82BE93909396A68668FF53988AA47DC38990989E9C9262FF5B8E9697
90C17B95969D959676F86E93939574C9978E9E979F8D60FF6893979A99B67D9994979A8C
8EE15EB48E8596BE879E8D6DC0D0659A99929B78D89086998D78C6AA8398A296886CF780
80A19873DF86889A9C9382A1CE799D8E9692BF7A
8D65EBB7689D9D8B9D999E909493AF8255FF3D978BA58EA59590979F9B9742FF45869999
A1A18896959D959661FF5B92959589AD99929B979E8F4EFF528FA2A18EA9879A95969B85
8CFD4AB690889DA6949B8D5DCFE9519B97949B8DB59292978D67E0AB7A94AA948882CC8B
89A0925AFF6E8399999589A2B983A28B9784D373
8E5FF9B561A0978D9E9A98959591AD8751FF2A9A899F9C99999391AA939D30FF3F82999E
A1938D94A1939B9450FF4791958FA198A08B9BA5958B41FF3C8BB29E9393929C949C9678
86FF3EB291939397A68C964EE1F83F9B97949E9E93959E958F53FEA87290B293889A98A0
8FA08E40FF58809B929792A5A68E9D928F7CF65D
9070E6A671A09881AD989896968FAA8F60FF479B8796A2A7939193A593A03EFF5780989D
97AA8495A1929E945EFF57919489A2A898879BA5949349FF3B97B0929C988BA49095A07A
7AFF44B1908E99989C969543E7F83F9F9499979D969A99929644FFB3698EB1938F958FA5
8EA48931FF537698969597A7979898987F7EFF5A
947BD3A179A0996DCB978B9F958DA68F79FA5D9A8C7FB1BD8092989E949E54FF70819796
87DB6E90A1939D9473FF649495888AD486849DA2939364FF4E98B18E8CBC7BA193969F80
85F565A295879EA98F979756D1E3539D9798938FAE9C8F94995AECAB748EAC93958CA49C
919F8A3FFF577D97989295A8A19593977F86FF55
9688BF9C82A0985DE7967EA8948E9E9888D3709A9071B7D47094979E949C6EE08C819A90
6EFF578D9F979E9182E27798938470FF72839DA390957FDF6399B28A7CDB6DA193969E85
8ADD7B979482A8B680989B6BB8CF6B9A959B927CCD998A949867DAA77C8FAA959479CD88
919F8C56FF6484969B8B95A7B58B93987E8FEE5C
9997A597909E9452FF976EB29094929F97AC869A9065BDE75F9B959C95998BABA388978E
54FF4387A09B989790BC8B9E917B5EFF5D829FA28F9893B27B9CAD866CFD5EA492999A8D
8DC38C959577B7BB78999A7CABB77F9B959C8F64F19982929A78C0A48791A4959863F479
8C9F8F71F17C86969E8A9299D07E97967F97DD61
9C9C969799989647FF9163C386988F9EA0929A95935FB6FF4F9C9B959996969D9D8C998F
34FF2A889BA2909DA0959CA0987D46FF4D8A9F999997A28D91A0A1865DFF52A295969E97
8FA5939C966BC4C66B9A9C899BA69299939D8E52FF997F8E998AA2A78E91A1969C4FFF64
8C9E918CBB938A91A58D8E8AE670A691829CC86D
9B93A8929598965BFF8D69C1869B8A9DA79397919867AFFA539E9E919A9899A3948F9A89
40FF2A8398A7939D9BA19698A1823EFF56899F9D9593A68F929A9E9151FF519B989B959B
98989899986BC7CF6392A097939D97939C9B9042FF93838B9895939C98989E95A047FF55
918E9F9F9595958FA297808EF163B38E8B94A28D
9883CF7D959A9371E48F74BA899A878EC28F9F8796799EE5669BA0919782CC8D908F9990
4CFF3F8995A79091BA929299A28254FF688AA39A8E8EC1858E9E9D9061FF609C989B9291
AB96939B9674C1BE7090A2988BA99F89999F934EFF9390869494A29894989F999F4FFF5C
938E9AAD938F998DA29D8386E96BB58A889EA586
9575F26D96969485C5957FB08B9B8774EE7EA583977F9ACF769CA18D976FF87690909699
5DFF588B9BA2917CE37D8F98A2876DEC7992A7958C79E9748C9E9E916FEB6E9C9899937F
CE84929B967EB7B07C90A19C67DF91829D9C9562E793958683A8B18897969C97A260F66C
968A8AD389879B8F9EA28783D873B6867DC39385
9269FF5A95949797A8988CA590998D5BFF67AB7F998C92B98898A489946AFF618E9292A1
77DF738F99A09765FF699390A28F82BE8F92A8948B63FF6388A398997DCB81979B97966B
F271929B9688A8AE858FA39B4AFF7C819E9B9878C4929D896DC0BE7C969899999E78CE7A
9A8181FA78839C909DA28C8CBF7EB1876FE58086
935CFF49959495A9929E979397978F47FF51AA82969B929A9C97A48B8D62FF4193948DA7
91AA9095929C9F4BFF5294909C988FA19C95A495894AFF5182A996A08CAA92939E93945B
FF5C969896939BA4948BA59A2FFF697FA29B998AA8929F8B57E3C769969B969B998BA98B
9E7C74FF63839C9593A78E96AC8C9F8C6AFF797F
9164FF4A9396969D9FA0919594979447FF55A8849599959A9D969F8B8E58FF2A969690A9
9199999D90999C3FFF409498939B9797999DA193893BFF3888A698A78B9C9B959D939849
FF4E949599999398A48EA29A12FF587A9CA3969B95959D893EFFCD5A98949C9897949492
A77E60FF51899E978FA19B94A493968867FF5C8C
AE66FF608F87BB96969C938F8CB4954CFF57A27DB68B9499A293919E8D70FF3A8F9DA39F
8D929F9D82AEA243FF519F8EA19297959D9C99A98242FF4291A49BA790959997A3919953
FF53989996989494A6969C9A1AFF548599A3949A99959C9238FFC16298969B9797939791
A8805CFF5A8C9A97929E939BA392988567FF4298
ED56DA718A65FA8A8B97958974F0855AF5639C74DC7F8C9EA38E85B18B87FF4E888CD38C
8294A49A68D5A24CF965A171D278929FA09894CC6A54FF5582B2B0988D96937ED28A8C64
FF5F7FD677999285B4A88B963FFF58B285A096989882CA7C4CF5B155BC9C899C9796879B
BE756FFF5F86BB90909B909B8BB8998074F8557F
FF43B7828545FF7B7F96958754FF7064CC759664FF6D849F9E906FC49591E65F857BF97F
7497A9964EFF9C51D7789C5BFD678B9DA1989BE4536AE86A71C5C18491958E65FF80817A
DD7068FF61999779A7CB7A9462F35AD8759C96989677F56260DDA64DD3A38297999A77B5
BE7376E1716DF47D889B8D9D6DF3808281D66464
FF3796947C2FFF64779696833CFF5C6F9E899559FF5B79A69B8F55D89BA1C27F7A76FF69
669FB08E39FF965DAD8F9B40FF598693A6999BFF3489BA7F61DCC7749296874FFF71798C
B98153FF4999997199EE68997AC362F9649597959C65FF4975BA9F48E8AE75969C9B6BD4
B57084B7824EFF648A91919B4FFF6D7F88BD7848
FF23899D7B20FF6963989E7B2BFF556B918D9D51FF5B759E9E913FEF95B3A38F806BFF61
5CACAF8A33FF956293A1992DFF3F7E99A2A68EFF1F9899974EF1C96699967C40FF5F769A
9E8C3EFF379E946E89FF56969B8E64FF558A9C8F9C5CFF378B979D3EFCBF63979D9A66F3
A3708A979828FF4C898E92962DFF5185929E9825
FF2F82B17F2AFF68719C9E7A37FF5B76899AA15AFF667C99A09447DD99AE9DA08E60FF67
66AEAD8A44FF8F6E8FA59C32FF4C7D9A9EAA8FFF31929AA149EFC466989D7B43FF5D799A
9A903CFF409E91708DFF519C9D8E5CFF54889C95975CFF2695949D36FFCC5C909F9B64FF
9D6F8F8F941BFF44838D9B9020FF3E8B9A8C9834
FF4F6EE07348FF6F839A9D7F50FF688879B1AC57FF7589929E9950CF9CA988BC9867E474
76A8AB8F59FD8C7B83B0B23BFF6486909EA892EA519087C94CDDAB7699A1825DFF658997
79B46EFF629B917F80F75F9D90BE4DFF6299929C976FFF3B9191A565CDC2748C9C9183F4
80808C83B825FF49868EA39936FF44969695B132
F96E51FF6364EB7D94979B8470F57C926CCAB35ECB7FA288A39763C398A373D5A16DC17E
82A7A69374CF90897FB6BB4BE5768E9299A98AD569906DFA4FBFA08495A4877DF0709490
5EE184CB789A8C888DD56F9785EE42DA739C919D9678FF529088A692A7BA7F919A8A96D8
8087936FDB35FF5A91939F9754FF609784A3C83A
C7833AFF557BAF909D979C8888B8929A60E2B8619E8AB87FA59A78B29D9667D5BA64A68D
919EA09A8AAB929570C0CF56BC80949A95A88AB4878E52FF54A1989293A68B9CB7819B85
4BFF93908F9C88909BB47C947BFF30BE7BA48EA08C8AE36A8E7EAABA84AF8C8F9A89A5B8
8590975BFF46E3709C9D989670E1799875B3D347
9B9625FF4588968BAE949B8D98949F9B57F7B6618E86C67AA9998BA1A38F5AE1C4619894
9893A09F939B919D5DCFE45892969D95999999999E8F3BFF578F969790A895AC8B929B85
31FFA85EA1929095A391909570FF299B88AB8BA5839BC2808D75ACE4639F9B92978BAC9E
8B979F42FF5B9782A8AE8F968CA7939966C0EE45
989B2AFF458A968EAA91A8918C969E9961F2AE6C8986C37FA59A8AA5A38F5CDDC1639C94
9390A3A78C9C909C63CBE950968EA691999F93A0959539FF4D8E9A9B8CA595AA859B9882
30FFAA549C978E979B99948D67FF27928BAE88A483A1B58C8A6DAEF955949F97938EAB96
8C97A538FF5D768DAEB78C96968CA2965ACCEC47
A0A83BFF548B9692A27EE4708A979F9471DDA87B838CBD71C68C8AA5A08F6DC6BD6B9E94
898FC3909098909E70BED764968F8F9BBC8B90A192974AFF6393989884A9A99C889E9284
50FF917397967CAFA48F958E75FF3F9890A18F9979BEAE8B8B75A8E362989E9591A99397
9194A749FF6A8289B3B1829F8C9B9C965EC7E644
9FAE5BFF6B869C9C9563FF53839AA0947ECD9F867FA4A55FF07B8CA59A9080B1B7769D93
8989D9819198919E73B4D76C968F7DA1DD7492A0929664F27A97989675B9B28A8EA08F87
6CFB927F98986BC4B07F939781F85C97969F8F935FF29C86897DA7CD6FA4999378CE8F8C
9595A35AF4898286B19F92B17D9B9A9273B9CF55
9AB47DC98282A1A48B48FF358398A09491B897937CB5934EFF6A88AA97908BA9A6839D94
818EE7788E9B919B85A4C87D94916DA9F86090A190987AC78E99999369C4C67691A18F8D
83CC978A9A9758E0B570949B90C778959F9B909246FF857F8C85A5BE7AA3999661F18886
9598A06DCD9C8689AC86ABC16F9C94908CA6BD65
9DB0999A967EA5A5853BFF1D87969C92A89C989C7EB68A3DFF598AAD918C9C9E9C8C9B96
7595F2778C959797978ABE8E939166A7FF528EA091998CA49F9B979262C5D96993A18C91
9EA59299989846FDB56B8BA598A28D95A696928F2CFF71798C8CA8AB85A29A9948FF7E7F
97989B84A7AA8F8FA767C3D2639A938D9F9CA874
A1A99A99957FA9A38B3DFF1C8B989599A19E979B7FB98942FF5091AC8E899F9B9F90939F
709AEE738D999A98928AB49893945DADFF3E989797989295A4A0998C63C6DD6A99988E95
A195969F99923EFFB45A8DAD9F8A9892AB91998922FF65748D8CB6988DA19C973BFF8077
9898999092B49689A55BC9E458959289B68F9B7F
9E9791BC8C80A69E9252FF3C8E95979293B5A78680C28253FF5E93AA908B91A3B0858DA3
7D98D2898999A09287A1B4918F9175A5FB5198989E9480AF9E9798936FBACD739D939292
96B685989C954FFAAC698EAC91A89489A89296902EFF6E798D89A8B58A9C959C42FF8A78
9B979984A9AF9089A861C8D660969286B986AE7C
9E9274E984839F969A6FFF599096998B86C3BC7284B8836EF27395A6938C82A9C6738EA5
7CA2B8978B989E917EBBB1838F8B8F9CDA679897A09570CE8E95989583A5C1819C92958F
7EE9699A9F9365DF9F7790B16CE2887DA596969348FF758192838FEF728E979E5BEC9084
99959876C8A7858CA66CBBC872949388B671DB68
A28F4FFF7B809891A38ACC778D9C988C70CFDB5889B08786C686A29F8F8E7BABDA678EA1
84A8A4999792999273DAB1719185AB8EBD7D99999E9563EA859196989396AD939B91948C
6DFF539A9F947BC1968693AA52FF8570A098989367F1838C917D77FF5690949F6FCD948D
99929B66DCB0778FA479A9C08292958BAE61FF52
A19334FF7F769295A49B9E8F8D9F999357DCF2408AB680A19E96A49D919270B0E45F8D9E
91A897929D988F9666FEA5669483B98AA7869F9C9A9554FF8283979A9993A7949C919782
63FF3D999C9891A3969092A545FF8B609A9B9A9189B79295947F51FF3A8F979A86AC9A96
978F9F57E8C16791A1879BB39293968DA54FFF39
9C962EFF7B7093999F979C90919CA08E54DFFF318EB57E9B9D9F9D9E939A5FBFE7529495
9EA59887A7958B9468FFA25F9285BC8A96929CA197954EFF8582929A9D8EAF8B99929874
72FF23A1959F9A8B9B9490A73AFF8C5A94A19391999E979E918333FF2F839C9A95999B9A
998F9E4BE6DA5C939C9192A1A39597979441FF2D
989A41FF83769A999884B199859BA39563C7EE4792A88592A2B0929E94966CBAD95B9A91
97A4A383A8938B9776F3A264948EB386A8899BA2909C63F8828E9295909ABC8595939978
7DFF399F929E999C938F94A645FF9064969E96879DAA959A968044FF3685A295939CA592
96919C5AD5D3669496928DABA88B99969549FF40
989B5AFF8B7D9D99996BD09E7B989FA16DB7D95C969F8A81AFC181A293967AB1C36C9B8E
9D89C4859D928B9A81DC9C729692A77CCA7698A48FA170DA8E918F9681A3D6719492997D
90FE549F8C9F8FB38C9092A166F3A071949A9875B0B18DA28E8359FF61839F948BA4BF7C
94949C6ABACF739592956FDF95889A96935EFF53
969E79CA9786A0969B55ECA272959DA67BAEBD73979C8974BAD46DA19A9387ABB1789A92
A16DDD8E8C958C9E8FBD998197989774F35E96A098A57ABC9894919471B3EA6094909C83
9DD46E9E899B8BC6898E8FA47DC3A88094999563D0AD7DAE888F68F19E759E917FA8DC64
98979979A0CE868E8F9C57FF8B839B969370F463
959C93A89394A2949947FEAA658EA7A78FA09C92939A8B66C5E45FA1988E95A3AA7F9A96
A057F79089928B9E9DA3988E969B8C6DFF4B989A9FAC859E999E939164C6E65E938F9F8A
A9A7889C8B9682D68C87969F8AA5A78F95999153EEA774B67F9584A7DA689B9173AAFD48
A1959B868FC7908C8F9E42FF81809B969682CF75
989E9C92989AA2939A3CFFAA5F8E99B8929B8A9C999C8858D9E45A9E978BA292AC8C929A
9C4CFF8F87898E9BA59E9293989D8B5EFF439B92A0AF87939F9B949261D2D664978F9BA2
96909F9294927FD7978298989692A5939B988F4EFF927BB27F9F8D7AFE6A929660B6FF42
A98C9B8F88C48C8C929A43FF877894969A94AA82
9A9A9BAC89969F979B4FF8A26C9692AE91B4829998998B62D6D2639F9686A7A4A187929A
9E55FA928C898B97A3B585939C969161FF519B8FA2A78B9E9F92989967C9C66E9B8E959C
A199968F959B7CCBA181969A9485BD9097949753FF877DB07DA08E80FA748B9B5CB6F84C
A78A9A8B8CD67A92929B4BFF867E8F9B9294A587
9C9E8CDA6B999A98996AD79E769B8FA292D36E9898988F6FC8BD7B999678A5D48089909B
9E6BDC919288919294DB778F9998916EF8669A8BA78B9AB4948E9A9F70BCAB89978C998C
C190918D969B88B4A880989B9364F77C91988F6CEE8085A782A373A8F672859C66AFDB61
AA8A988C86EB6D8D989F66ED96858D9E907DC577
99AB80FD50999999997DC08F8BA4879C88F5599898999379BEA68F9B91729AFF6289909C
9B7DC78B9E87958689FF608F97989381CC7E9A8DA375A9C685919AA578AF98A19789997F
DB8E858D93A2939FAB819B9A9249FF698A9B8F82CB85949A8A9E5DDBDA6D86A477A5BC79
A58A978F7FFF56939B9F7DC69F88909E8F68E566
93AF88FF3C969C999989AE7AAEB2709181FF4B909A9B977FB6969B95966C94FF3E8B9697
9F8CB18B9C8D987F79FF44919997948FAB939491A25BB4DD7B9298A6869A93B099859776
F18E788D92A59B98A3869E9A912BFF59839B9393AC89A08F969444FFBC6D84AD84A19A93
9D8F949370FF47959CA090A6A889939E8F56FF55
8BAC93FF2B93A09C919B9771C1B9757588FF3C9898989C8AA18DAE8D9C6799FF23889C95
A1969B9B8F99997D6DFF3392A191959A949E9097A34EBAE2779896AC839299B2918E956D
FF8470958AA89E9D91919E9B8C1AFF617699969D9595A08B9E8F38FFAA6A85A998949198
949C8E9077FF49969BA492999F93999A8A47FF3A
92AB91FF3B8BAF9A8BA19870B6C67C738FFF45949F98A1899D8CA693A46D96FF2495A593
9E959C968BA59F7A6CFF4285ABA38999949E86A8A253B4D57994A5A87E9899A594A1906E
FA82768CA0999DA38D9193B08D22FF6176A3959B9392A583AE8C30FFB35F88AD9C8F9694
93A2929270FF528EA5A48E9B97959AA38849FF48
AC92A1D75870D29784A599699EE88A698DF35E78BCA1938A9E8992A7B17688FF4176CE8D
90999C8A81C89B7577FF5470D2A875949BA46BCAA357AABD877DD0977B9D9B957BE47973
DC8A7E67E18590A48D8F79E57845FF6E79A8AA879791A569D9824CFFA4598BE288849794
7FB0B97677F46180BEA29192988D86D9705FF264
C777ABBA6E57E8AE69AF957478FD9F5D95D07665D0AE82899B8E81B7BD7E7DF35D64EA88
8996A28074E59E767AE66E5BF2AE65909FA358EAA758A1AC9564FD87779D9C8A63FF6979
C48E8646FF6B80A98F8B62FF695EEF7D7AB0BD739994A14DFF7D63D7A05F8AFF63879795
6ACAC46489D37268E59A8E8F988E68FF5973BF80
E164A5A8803EFFB654BF937F47FFB1529CB0904BEBB47190998B78C7BF857EC98053FF83
7D989F7D64FF9C7287B09443FFB3588D9FA841FFA85E9C97994FFF786FA19A8247FF5980
AA939123FF5277A4968747FF5979B79475BBCA6497989B37FF7178B09E6091FF47879C92
59DED3529BB1824BFF8E8C8B95836DFF3E829399
FF559C9A8F2FFFC94DBC8C8521FFBF469E9AA52DF9D45A8B9F9260DEBF8375B59F3DFF7A
7C959B7558FFA85F8E8EB035FFBA4D8BA1A737FFA5569E97943DFF6D6EA097793FFF497F
9A9D9504FF3A749C9C8233FF5D899C8B75C5DE55929A9D33FF69899399609FFF2F87A092
45F3E04A999F8B31FF8C7C8C938068FF279166AB
FD589DA28F36FFCB52B68E862BFFB94A9DA4A434F0D8538E9E9368D8BD7B7FC09A39FF79
848E9C7758FF9C5DA68AA34CFFB4528B95B240FFA557B0939342FF6D749B93873CFF4E7F
AA98920AFF3E77999D833FFF5C92A38B70C6DA598FA3993FFF6D83A99260A1FF278A9C95
3EFBDB49A29C8B31FF877C89997D6CFF2B916B9F
DE629AC77D4CE6CB5AB18F8B45FFAD4FA8B19555C7D6668B9B9572D1AE7498C08C56F87E
928D998363FF9E48D7809767E7B6638F8DAB61ECA24CE57B9058FF787F98938F58FF6268
E281922CFF537D9B99865CFF6C8FB78371C0D064939E9B56F57C6DD87F6EA6FF3A969C96
50EDBB52B0AC8443FF837C92988381FF4481A482
CC5AABD96963D9B371A8918B61F09E56AAC6846BACCE788F96967FC59F6BBBB58668DD83
9990938F6FE59C3BFE778E7EC7B86F8E8CA67DC89D49FF6D8C6EE48C8894949272F87051
FF65954EFF6A839D9D8972E87791CC7B72B8C4709699A270C9825EFF6D78ABDD5D969C92
67D6B34FBFB87B5AFE887F9695869EE95E6ED769
BA53B7F8517CBDAF839993907CCC9762A4E06F868FC88593968F8BBE9864CDB57780BB8A
9C9698917EC59F33FF6F8294A6BF79918C9C9AA59A46FF589183B29F8F929C908BC7823B
FF4C9674D383869EA08C89B78691E06A79AEB97D9A95A8869C914FFF5B88A4B47D959A90
7BC7A549D4C07377CD92819C999199C27B63FD53
9E4FBDFF3D8CAD989299989693A38F729FF7629E7EA89E998E8D97B59956E8B3619B9B96
969C9D9592AA8936FF5A77AF8BBE7F968D9BA7899B42FF42939495AB93949E9598999722
FF369A919B958BA1A1919C958099EF617FA8AF859C92A88E8E983FFF4F9896999393998D
90B59E3CECD05F95A2918F9F9A91A29D915CFF46
9A4FBBFF3D88AE908FA1999693969A7A9AF2679D829E9C9B978CA1A99B54EEA96998939A
91A79F9892A28744FF5E7DA88EB87C9A9F8BAA8D9A42FF4D8F9C8FAA939BA097909B9522
FF339D958F9E85AC9D9895968791E766859FAF88A2959C92929A45FF549D9095989B928F
97B19B35EBDC5D969B95969F949C9798945BFF44
9D58BDFE4F89AF9180B4AC809399988891E076968C967EBAA97DA3A19E61DF947B9A9894
80B3BF7C93A5855EFF6A86A78EB17193CD76A78F985BFF67929B93A17DBE97988E9D9740
FF479C9A958891CC8497919A8C92D3738597AB8AB4A18396939A5DFF6A9F918C96BA808F
95B19948DBCD67958F8FC88096A19396966EFF59
9B6BAEEB6985A59575C5BA6E929A999092CC8396928F70C0C365AAA89A69CB947FA19695
76B1E5648FA88472F06D9BA18EA76B91F75FA193976EE7779495A69566DA969690989763
FF5E999E928390EE6A958DA28F93BF818795A77CCEA6739A939A73DD809F8E80A5CE6D92
95AE955EC8C07498897FF46898A38E969784D56F
997EA2C78E849C9271D0CC5C8E999D959AAD9595958B68C1D15EADA19C7CB195879E9793
71A7FF4E8DA68286D074A99C929A6789FF4B9B929981C18C918CBA8B50F393968D96987F
D478969E90828DFF539595AD8895A7908A93A469EFA4669E909E85B7919D8F6FC1D95796
93AD9377B1B48098876EFF5597A38B979792B780
989399A3A7839F9463D7E645909B9B9C9D96A19698885AD3D75AAAA194999594909A998F
6AA3FF3489A28A9AA28BB39097936A75FF319A919894A19B9284C28D3CFF9C8C8A919D9E
A4928F9A967D91FF419488C38C92919C918D9F5AFF9C5B9F92A1929A9B9B9260D6EA4299
91A693909CA38F9A865EFF4099A488939C9A9E8F
99979F9AA7869B9663D9EF3E8EA09195A7959C99948D5BDAD05D9CAE8DA78794979F9587
6BA8FF30899C95929E8EB392938C7B6EFF2F988E9E8FA4989B7CC58C3DFE9F88918B9FAA
929A8C9C9C73A1FF42958BBF859A9A93958D9B5BFF955E9D979C91A39599995ED5E84796
93999D94A495919D895CFF409F998D959BA58B94
9985BB9699939E9078C2D564869B9576D2919996928D73BFC06D9EAB928EA89B899F8E90
779FFF488D999081C088B091918D8879FF4496929C7FCE879481C18E52DEA886958795A7
B191899D968798E65D968CBD66C0AB7B98909F5DFF8B759B979678E470999966D6CA5998
96969B86C68A89A09264FF5D9C988F998AC0858C
9776D1977EB19B8690ABB8927A989657FF86959B8C8E80B8AB8595A39D79C5998399918F
7FA4F65F94958F6DDD8F9999918E927CFC629495996DFD719186B68F6AC6A78A918F8D9B
CC878C98978E9BC1729A92B74DEAAD6D968EA273E18B809B959460FF4F9C9A75C3BA6D9A
94949A73F17884A29673E76E9E9991997ADB7B8B
9866E59C60D2917EA296A5BA6F97963AFF878BA580918AB09F958DA29E5EE99B7A979392
85ADC67B9C919056FD96839E8F8E9E84CF7A9A949857FF5C8E8EA59281B0A28E9592888C
E87A909698939EA4859E8DAB3DFFAB5E958EA289BE918799998F46FF339D9888A2B0849C
9692975EFF6480A49A84C27D9E9B919969F96D8C
9C55FB9E4DEC7F7FB18295DB65959626FF8B82A97D92989D9B9D929D9A47FF956F999198
8DAC9D95A08F9240FF9A799D8D8F9F9A9C979995944FFF4D8D90A28B959C9C999B948377
FF619A9F8E9A9D90959E9C9527FFA856968EA39B95A1899B9C843DFF269F999289A39C9C
9797944DFF50869F9C91A18CA298909C59FF6387
A04FFCA046F27E83B37491E2649A9626FF8E7DA581969493A49E929B9245FF94659991A2
8AA4979BA4918E3BFF9B77998F9299999A9A9C95914FFF498992AA86929E9999A1958172
FF509F9F8CA1968C9B9A9C962DFFA05A9790A09D979D8C9C98873EFF299B9E9187A99B9B
96A18C4EFF5288A29491A68F9F9A92965BFF757A
A261DFA454E97B8BAE5EB8D667959943FF977DA982999383D0888D9F905CFF94719692A4
898CBA9B9A8C9350FF9E7F9891929E82BE8A9B999064FF5E8C92A68A8CA3A48CA5968678
FA5FA7998B8FB28B929B9E954CFF9170969391A2AB938E9A939150FF4E969C9D6BCD80AE
959E8953FF5B92A28F80C0919797939469F2867B
A572C7A569D08091A847F6A775939661E3A87DA1869C916FFF7189A08B75E5947B9491A7
8A78E2839C8B9564E19E859B8C9AA362F1719B989775EA778E999F89889FBD7DA7948E7E
DF6BA9978E74E07B8E9F9B9865EE927D9993869FCC7D92978F9E5AFF6C919DA458E664D0
869D875CFF6D99A68B6CD2979291969377D69675
A684AEA582B18797A33CFF8C80928F80BDB08590919C955EFF5E87A0868BCD92898894AE
8968FF70958E957ABE998EA589A49F40FF5498979C86BA9190A2998682A4D16CAB918C92
BF7CA597905CFF6D8E9E999880C1988A9A937F97E96D978E9A9670DB868D9CAB3DFF61DC
759C8B63E97AABA68357EE91968B989285BAA96D
A7919C9F98999098A434FF7883968F92A1AC93858EA59C49FF4A85988D9FA59C987993B3
8B62FF58988C948EA69198AA8DA29C2CFF3D9397A68E99A38CAA93897AA8DB66A9958BA2
9C93A38F8C58FF6A86A1959A9A929E9D8E9B7896FF59A685949C86B09E8899B325FF5DE3
679A8378D286B89E7F49FF9686899A989299B86D
A793969DA0958B9EA72AFF7A8295909994A89D8586AAA23EFF3E889496A092A49F7594B2
8C62FF4D94919293989795B08EA29727FF2B9595A49393A784B4868882A7E55FA39692A3
919FA08E8060FF7D7B9C92A0998CA1A3849C779CFC54B28290A180B4A08B93B029FF61E3
6793887BCE86BD988447FF9489859EA18B98B571
A4978FADA580959BA349FF73899B8C9995A8AA7788AAA450FF538F8B999E8EB6977398AC
9376FF519A93988D93AC86AF8AA89A3AFF3E9B90A785A2B07DAE8A8887A3D66BA3969490
AE9C988E8473FF7F859595A29180C8918793879CE163AD86949C6ED9918E95A247FC7ACE
69968D7AD08CB1958C50F59B8B81A0A48993B772
A19376D0AD61A7A89667E688879E8E998FB7AF6A8CA5A764FF6796879C9A7AD5907099A8
9586EA6B96939A8E8AC576AC929F955BFF559C91A377B2C06EA98E8B8CA5BD7AA1959673
DC988A90848BD0918C8C9D9F8A7DE3838396919CC375AA899B8C64FF779396965EE195A9
78989272E08BA4899765DF9394839FA98091CB69
9E925DF1AF45C0B0867FC18F8B9B989486CBAC658BA5A676D57D9A84A79266EB8E798DAF
9293C67C9D96989085DC6C9C9A99957FD371A094A067C8CA61A28F92949EAA8B9D979955
FF8D898B869BB19F8B84AC9B7C83FC708497979FA87FB192888B60FF6094968F7BC3959E
87969174E8948E88987FCA8F91929FA87591E15E
9D904BFFB629D9B574969F9499949A9478EAA45F8EA29F8DAA8FA186AE895BF58E8089AF
949BA48F9B9499957DF55B969B9B9990A586A5969E55DCD1589E8F92A0979E9896959A38
FF8C82898BA19CA58F73C2947B87FF578C939D9F9385B69A83914EFF4497948C99A09698
95979364FD937A939494B481A2A194A56B95F74F
969E42FFB61BECA777A78695A78F979177FAAA4D959A9E97959A9F8AA98D5AF39F738DB1
93A18D9C9F8B9F996FFF588FA198979E8895A19BA34AE3D854949896A09198A596929628
FF937D8C93949E969372D0887D96FF4D93979E979090A99F808D4DFF3C988D929E979398
98979064FF8F729D8F96B27DA4A98F9F6A9DFD44
A1AA3EFFB030D9B58693869BA18D9AAA69F7995E899BAD9295999E86A3A557DFA57984AF
A79A8A9BA07BA3B367F8618D9AA39A96918C9F89B65FCFD1598AA7A593899FA58A9D9D31
FF947992A39299999162E78A7AA3DE5E87C08E8E988C9AAD8F8962FF3D8FB0919097A48A
8CBD816CF58671A7A38EA879A79BA99A6AA4E24B
B2CB3BDEAE51ADC7A0818A959F79A8D94CE2966C7892E8758F9C9D7F99D056BCB37A79B6
BA8B8A95A26CA7DB52DE788882BDAB83948B9878DC62BEC0648C9EC77A8B9E9B8AADA33F
F7A18177D579999E8C56FD8A7AA6C06977EF7C88958F86C9977F77FF4B7CEB858396A582
75F9627CDE8764B6C076AB7D9F7EDC8870A3CC42
C4EA3FB9A66D89DBBD648F979A67AEFF32C6977A668FFF54899E9E7A87FF51A4AF7B7AB1
D97F8591A455B2FF3BC5888E6BD7B77297899267FF67B1AC698CAED36A8E9C9774CCA44B
D3A97F70FB658FA19449FF927AA2A17D65FF678892956AE1A67E7CCF5A68FF7A7696A77E
51FF4E84C48557C8E656A4899C5BFF8272A4B33B
D4FF3BA0988669ECDD4B8DA09156B5FF1EA59A8B5586FF3389A099757BFF488EB28271AD
F96D828EA74CB2FF2AAE909853EDC66398869151FF6894A2728BBDDE5D919D8A6DE89E5E
B3A78162FF5486A09F43FFA46C9F8C8F4EFF4B85939B48FFAF7086A8675FFF746D98A578
35FF3E90A18E48D8FF3C9895993FFF70789F9D35
E8FF2F9C95904DFCEC51859D874BBDFF248F898D6478FF18869F9B668AFF448CA2905FB4
FF5E878AA242B9FF259498A238FFD259938C8D42FF647D9B8192B1F54D929F8161FF9E67
9EA7824CFF6D789DA637FFBD70868D9149FF4483929B42FFAB708C906364FF66649AA379
27FF3A90919340D4FF2B93979B37FF647D979735
DCF442A990964EF1DB618C9B8C4DBAFF3F958F887075FF1A88A296708BFF53A1968C66B5
FE648A8AA155AFFF30A396A047EFCA5D91949059FF538BA579A49BEB5C9898846CF29661
B6A7894BFF6D7F98A853E2B86E85AB825EFF4F8891995EFF9A6B8AAC7264FF65769A9286
3CFF448CA29C44D0FF379091A156FF5B6EB4A52E
CDC171B480A35CD2C375989A9858AAE871C96D85827DFF368CA29E7396E064E2668F6EAB
F475838E9C67A9F435E4749D5DD8C16C8F8FA16EFF528DCB60A59FD274939B8C6EE18E55
DBA1806CEE868193AA6AC2B87678C8717BFF57908D9B73F18B7770E36375FF7383998F90
53FF6679B99A52C4EE4C8C8DA08DFE6452DEAA34
BE909EBF6DB662B8AC8BA4959E67A19CA6EE52829681FE58909DA576A1A674FF4690779D
E5877F94977CA2C636FF539C6EBCC0788E8EA587DC5284F8529C97C886939C8E86C08C49
F89D8174C79E888EA383A6B2886AE65C8CEE67978C998ADD7E8256FF5E89D37F8D9E8E91
77EC7B65E2915EB1D8648A889AC1C9693FFFA940
AE64C7D251CF65A09999B888A47A9756D3FF357EA886C678909AB07CA67976FF1A928691
CAA47C969588A19E35FF3D9580A2BD848F8CAAA3A55E87FF49928EBE9693989491A6903B
FFA1808598B09090A09590AA9264FF4B9CC37E9C879AA7B97B8D3AFF508FAF85949E9195
91B19553FF83709EC27B8F7E93EB9A7230FFA54C
9C40FFD239E36D988485DD81AC829627D5FF1E8B9B9499958F9AB190956871FF01939587
B4BB7598939C957E3EFF348F8B99BA839388AEB77F60A0FF3A8C92ABA19C92949F949034
FFA3819D8293A48F9BA68E989C59FF3F9FB681A18399B79E898C29FF4E86968AA69C9097
9796A358FF837E99A28F937A91F689772DFFB447
A148F9C93FD877908C87D882AA869838C6FF228F97978EA88696B48F95746DFF10979487
ABC671969A97958943FF33948D91BF8F8A89ADB484699AFF438D93A9A69C91979A939341
FF9E89958197B4859BA09596A55BFF549CB677B58198AB9D919132FF4C8F9B80B7998E97
8F9AAB58F77F889B9593AD748BEB8A7F41FF9D63
A05AE8BB4DC7828094B5B383A492994DBBFF4590999571E56997A897978674FF3F989382
94F65B9899948EA057FF51969180C4A77A8FA1B388799AEB618B9193C49E8499959B9059
F197998F7D8DDA6E9B9F9794A868E46C93AE69DE7A8BAD9599914FFF6996A161D9998495
8F98AD66E18089AB7899D06196D0908161E6927E
A76ECEB361B5897B81F08E849D969D65ABF45E9395955AFF59919F959B997AF46398987E
79FF5797969C88A96EEC6B979577B6C6708CA3AA8E869BC27C928E81D1A87A9D8D9F8F74
D2989C957588F55E999D9997A177C88290A75AFF688AA9969D8F6CE37E9AA24CFA957A97
8D95B37ABA8D8EB55BA6E654A5B297897CBE8D89
AE82B8A579A2907A72FF698C9693A575A0D8759392914EFF479193959BAB87B788959A7D
67FF4599929696A881BB85999573A4E663919CA7968DA09E90978D71E2A9739F90998E92
B8909D9C737DFF4693A19995A77EB093949947FF5A82A595A18C8CAA92A2A235FF956E98
8F92B58A979B8EBD48ABF552AE96A0958C9B8B92
B6958FA1968F957C60FF43909093A58C98A79D93898F4FFF3293938AA1B1918E9E939E77
5FFF3B95958B9EB082A490A19664A6FD58939A9C9C9D8F93A1939460F6A7709F90958F98
B685A2957180FF358FA19799989792A2978F39FF5878A295A185AA8699A9A02EFF9B6795
9593A98C9C968FBB45B5F951AE91A1998E91859A
B29A88A5968F95835EFF418E938FA28C9CA89C9389925DFF3C95938AA1AD949399929F7A
5EFF3C9E8E8F99B57EA29A9F9369A1F55F95969A9CA78A95A48B9763F0A5719C9294949C
B1889E9C7081FF4091A19594A29A8FA7889A41FF5D7BA497919BAB8195AB9E3EFF9A6D97
96909DAB91968CB356B4E05EB1909E85B68D799B
AE92AF8B8E9B99955BFF5D8C99869591C0949896839877FF5B959A8C7ED0998C948BA483
68FF58A18B8E83DC719C9EA1907994E1709499899DD16E95A189A373CEA77B9B937AB6A2
9E8B9E9A798BFE579295A67BCE8A8AA28B9C57FF6A82A2976EC9AD7991A5975EEF97769F
988B8CD07D9894A06BB4BE7AA7939B6CED787497
A678E5708B9E9D9A72F3748D9C898884E9809895839A90D76F969C9A5DEB9C849288A08F
7AFA69A48B846DFF6298A3A1907C9DC38295937AA1F85594A18AA083BF9C849C9B62CDAA
8F8D999D8689E1699494A26EFD6E86A08E9F66F38084A49253EDB0738AA59772D29876A8
9C8780EC6E9995997DACAB8BA497984FFF627698
A35AFF548F9D9D9F7FC888929D8B7B7DFF629B94869E9FAD7F92A79F45FEAA758F879E9A
85CC81AB908248FF5A939F9E9980A2A492989158CAFF39979E8E9C92A89F8B9A9C53DFB2
8591969A908EBD819193AB54FF5680A18FA27DC1938CA49133FFAE6B8AA19989B0997CAB
9E857AFF5D9695938EAD9897A09D922AFF4C7A96
9A4AFF338DA29C9F8EA393A2978C7575FF5590958E9F9E8E9495A89E2DFFA563998099A7
949D98B193832BFF4D909F91AA8899919E9E8C4DD1FF24939B9196A396A8899B9C44E6CA
7598909B94989396968FBA37FF4186A188A392A097959F9C17FF9F65949B9B99979581B0
9D8580FF5298919496A59599A09B8C23FF3E749B
9D45FF2D8AA798A08C9D9BA393907271FF4B8A97909B9C8E9497AA9431FFA35D9F7F9BA5
96989FAC918430FF52969791AB8896999D9C8B4FD2FF2B919794969E92B48D979A4AE0CD
6F9C919790979B9B9293B639FF4091978E9C8DA2A4919F9B26FF9B6E959E99978CAD81A6
9B8C85F364988C98919EB582A39B8C3DFF479781
A051FF478FA3949E8C80CC9D849A7C70FF618F9B92999A73C1909F9158FF9A719A8799A2
918AC99590874EFF679A9592A98979CC889F875BD8FC438E9992959788D87C98995FC0C8
7CA1889C8D83BB9E859DA653FF51999387A68C99C9739DA04AF5957C97A7939576DA6E9C
9B9595CC7A9C86988A95E363A49B904FFF5BAF72
A06CFF6091A4929E8C61FF8B7F987F80FE7587A199929859F38195926FE4957F9B939598
9181E9858D8D66F079979993A98D54F97D9C876AD6D5608D9891989874F96D949B73AAC2
82A58E958C72D8A17897AF61F46D9F8E82A88C94EC589DA066D48F8899A5939461FF5C95
969BA2AF89A186977D8CFF4C9F9C955FF079BD64
9E85D47591A4969B854CFF737B987F93D98387A89A93903DFF698A9880CA898E9C9B9591
9270FF6C88947BC986969C96A78F35FF72998A7FB6C47A8F9594979469FF5F949E8797B4
8CA1998E925EEAA87094A87DC186A98286AA8696FF3F9C9E87AE8F9398A7909248FF4387
98A2A49C97B07E937580FF329F9A9B7AB892C162
A293A7928FA4969A8A2CFF52809A819DBA8F92A697958D28FF4D88A4929D86A88CAE9489
8E69FF55809E969996969A9FA18E1FFF67988A91A1AF908F959C93965CFF60969F958EA5
93A29C8F9648FFA46A9F9B949E999F828EAD8098FF299E96A48C939D92AD8F883FFF357C
97A4A4939CBA80916C7DFF339997A485989DCA5E
A68CA29397A196998B2CFF418295899FAA9595A997938928FF4180B08E9886A68AB29589
8D6EFF527F9C9997949698AA99892CFF6C998C8DA3AF8E8F96A18F9761FF5C9A9F968EA3
A19496919E4DFBA06B9B9C9896A79B7E8FAA8B96FF319E92A6889AA38EAA8E8A4CFF3289
93A59CAD8ABD828C767DFF479D939F76C48CBC69
AA75BD9F849F91A28D4BFF468B938C80CEA280A897948C45FF428EAF848F9AA696A5938A
8E80FF628497A674BD9883AE9F8849FF8496958A9C90CC7F8AAA83A56AEC63A59F9C7DA6
BF73AB899F5FDB9F779A9E997CD78D79959F8E9FEB4E9F8BA575BCA484A2938C61FF478C
92A37EE27AB1878D7F87F7629E929B6CE87DA678
A659E1A6769C91A3906DFF5396929366DAB175A791998E5FFF5492AC8B78B59FA3988F91
8898E2708A8EB84CE89771B0A08B69DC899E958E9377FF6985AA80A87DC769B19EA66E98
E360AE889E76BBA0829D9E9466FF707A9C9A93A1C66B9D8FA15EDEA57C9D958D7BFD6684
96A064FF66A88C8B8F8FCA7C9F909269FF6C9986
A240FFAF69998EA49A82E064A0939B48E6C76B9F9098957AEA6B90AA9561CA99B2908497
80B8B2828E85CE22FF916AB09A908AAF91A194998B61FF4E8AA485AA8AA872B89CAB658B
FF4CA98D9690A4998AA49D924FFF5180989899A0AA8399929E49FFA472959E9691AEA477
9A9957FF5C98948D9995A49899928661FF56958A
9E2BFFBA5A968FA49C96B077AB949E2CF1E452A58E959F8DB78690A49E4EDD9BBF7C849B
77CF91958D7CD216FF995CAD9697A38C99999B98934EFF3E889F8BAB959871B99AAF5986
FF30A58F9A9C8F9E919F97983CFF46789C959B9B9C9198949741FF8E7694A49D9988B777
A49354FF5C9190959D9797999A977C60FF5B9982
932AFFC84A9490A79D989C84AF929F1EFAEE4E9E9490A393A889999EA14ADFA1BF7A7D9C
7DCB8D9F867CD119FF9E59A5A0949E919991A09F8B43FF428A9A8AA79B996EB79CAA6086
FF35A59E9992919E84AF9A9142FF4574A99B919B9E8BA495974AFF7980A09E9B9889A99B
948B61FF5A9CA18D9A9B9283C5838272FF5CC171
A435FFC05F7AABB18F92A18594B4AB29DCDC5A8ABB8E9893A38986D28C56CC9E9E90A683
7EC5908D9093C139FF9D55B2AB85A4929681ABB38157FF548AB58895A49A63A8D18E6A83
FF428ED47C93909D67E591835CFF4C5CEE82889B9C73D08B8E60F36E92B3929897858FD9
78887AEA49CBA780969A8E66FF65838CE760E653
CF39E5BE6D64C7BB7C90A2896BE7B12EC7C87165EB8C8A92A07F7AFF6C6DB2A3809FD06B
82B893769FADAC5BDCA053BCBB73A58E9871BDBC7B6DEC6C7ED97E88A5A45A93FF72718D
F14597F16390929B4FFF847974F9633FFF61839D9B59FF7E8976D35EA3CD8098928672FF
5A878EC142F9A173979B8749FF4687A6C059FF30
F741C0B67A53E9BF6A90A08B49FFBA3AB3B47B49FF857D919D7C6AFF487FA1A760A9FF54
87A69A5EAECB8F7EB3AF4BC6CE5DA38D9A62D3C47182BD856AFF6C7FA6AD4F83FF527398
CC4CA3FF508D959934FF7C6F8BC37C21FF3E86999A3FFF73808CB254B4E46C93919544FF
37879CA036FF9C669799862AFF1D98B68E5FFF10
FF479CAB8A3FFFC35893A29021FFBB51A7948A2CFF786D93A17061FF2A9194984EC2FF3F
919A9848CFCB8D82A8A84ED4D9489F909A56E6C76D899C9B62FF5276A9AE4284FF337D97
9C60ACFF3B8C959917FF7969AA918808FF258D949334FF648098915FC3E75D95939339FF
2489999536FF9D609698832CFF10A1B28658FF00
FF4F90968551FFA15792A18418FF9E639D8D8C1FFF6367979C6F42FF158E92964AA9FF35
8B999742C8EC8080A4A352D4D337C882955CE1B276BC78995FFF437BC9954D83FF2274B0
9668B0FF2DA2A18424FF7855D7838011FF227EC17E3BFF6962BC955FC2D759A29E8849FF
3677BD8F3EFF8C629FAB773FFF248BDF7765FF27
FB5D8C907669FF7562949B7A2FFF827A9C90921AFF496F97A16A3BFF169192935F84FF43
89929A51B8F974829EA569C4C22CF274936CD1917EED67936DFF3C87EC766688FF2A7ACC
7C85BAE03FBAA97046FF7D4CFF767C36FF3577E66C55FF7754DD955EBFC161A8A88167FF
5464DE8A57FF8A64A9B9715DFF4177FD6971DB63
C86F8D8E6682FF4F6E96987448FF6F909E93901DFF3F77969C6C4FFF26928F916E69FF5A
7F939967A6FF677F99AB77B3B024FF6B8D7ABF7484FF449187E63691FF537C90FF2E84EF
56A5B2C149D2B85562FC833FFF6D7758FF5567FF596CEA8047FC9662B6AC6CABB37981E3
704FFF7B6CD68D68AFC76D77E96162FF5A85A9A8
A27E90906299FF467A9E947466FF639EA195913AFF47779C9A7468FF3C928F948556FF70
8094997E96FF68829BA289A79B2CFF6B8688AD5F8EFF2C919CC43891FF388E9DC63E91FE
4BB6A5AE5DDCBE4482C39332FF716D7CD07554FF4782BE843BFF9F5EAE9B70B2C26E8FB3
8C39FF777CAB9268B8D56390B38A3FFF529265EC
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.504715 0.0238095 0.97619 0.495285 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
55514D4C4E505358595E61636465626060615C5957565251555352525552535756555052
50565A61626462605F5D5B5B5A5C5D5E5E5E5F65666666655E5D5B5A5958585A5A5D6062
646765605E5D5C5B5E5D5D5F61626162605E5D5D5B5D5C5A5B5C5C5E5B57545351545757
5A5F616466615C5B59595957555556575A5C5B57
2A22283536322D2210090E16202A33332E35393A39382D2D2D3237372F2B2D353F444B49
46454B4640383128282C30353738393A37393F3B3C3F3D394245444443403E3F423A3A39
34313F474C535A564F514D4C4E5255585C5E5D5C5D5B5854514E4D4F5254595B5D606161
5D5A5855535658595B5B5C5D5B585B5E5A504538
C9CECBC0C1CDD9E7FAFEF6EBE0D3C5C0C3BCBCBEC7C8D5D8D6CEC7C1BFBDB6AA9E969599
9EA19FA0A1A19D97918A87898F8A86807771736E6A67635B595F5F5D5E5B5152555D646C
7378716A5D4D3F3A383D413D332C1D12161211111008131F25292D2621201C1A1A16151E
2324272928282B2E32393D3E43413931496385AA
2B312E2D2A221917171716191F242B3332302C2C282B2D2D2D32373D454C504D4E4E4A49
4D4C4747474E5E6D7783877D7C83858B95988D9293949EAFACA7B0B2B4BBC5C4C1C0BEB4
AAA9A5A8B6C3CCD3DAD6D9E1E7E0E8ECE6E9F4F7F6FDF6F0EBE7DEDBDCDDDBD7D5CEC5BC
BAB7B4B2AEA9A8A39A91887C7B85909A8A755A3F
57575B5F62605F5B54504F4E4D4C4F5252555857565552504C49464542444C53575D605A
5452515051514A48443D3A3E393638353332373A4145423D3E342927231F1F1C1B170F13
191A1A1A15111112120F0D0B0F1B212527241D1E21232324272931373A3C4248505B625E
5557595D677473787E88919E9A928982716A655E
6262615E5E5E5F616565666462605E5C5D5D5D5E5E5D5E5E5F5F5F5D5C5C585655524F52
5353565A5D5E5E605F5E5E5D5C5F5E60686C6D6E6A615D595658595A5A5B61626161615C
5C5C5D5E5F606263636362605D5A5957555555514F4F4D4D4E4F4C4C47433F3D39373432
3433333539343434322C2A2726292C2D3A454E58
55504D4E4D4A4E4F4F5251545555585A565454514F5151515051525454585A5C5D605E5E
5D5D5B5A59575858585B5B585858585B5A5A5854505454595C5E5F6061625E5E5E5E5D61
62636363615F5C5A5A595A5B5C5F616162615D5B5A5A5A58575655585C5D5E5C5855565A
626565625C5858585A5D5C5C5D5C5B5B59585755
646B6E6E6E6557534F4C4E545455585A5F64645B534B494A51575C59595D574E49413231
373C424B5254535D605C575543352D251F1D1E2128333A3D3E3D34302D2E313134363638
3B3C3E3F3B3C4143464947454644424748484C505153585959595B5A5A595754504F535C
646463605D595B5E5F5C5C5C5C5C5D5C5C5A5A5C
7473747677868F939899928E8C8B86878785869399A1A3A19A989194979197A0A7AFBABC
B2A79B918582827A797F8A94A1AFBBC2C3CACCC9C5BFBEB9B6B2ADA9ACACAAAFAAA29D9B
9C9E9C9A948D868079747476757E80766F6A5B55534F4949484543515252565B575C6365
60605C55514E40332A1F1818191A1A1E3044576B
43413E3C3D3B3F41414245413E3D3B36353737363B3A393A3A363634302C2B2723232C2C
32393E3B41414141413F3A353A38322F3027232424201C1E202638454A4F514D4F555C5B
555150515E6A727A818485858378757C848899A0A2A5AEB1B1B3B6A6A5A6A49DA6A2998F
8D8E929CA5AFBCC9CFD4DCD9D8D8DDD9BB9C7E5F
5F6060606060615D59575758606569696762616062636362636060616466666564605D5E
5E5D5F616060615E5D5C5B5C5B5B5A5856585A5B5C5D5F5F5F5D59534E48464545444544
46494B4946423E3A3838393A3B3E3D393637333132322B292A2A292B2B2A2A302D2E2F30
2C2D2D2B282624212128282A2A2B262833414C57
6362615F5D5A58595F63676B6965615F5F6162625F5A5857585B5F60606061616161615F
5F626367666562626163656662605F5F5F5F5E5D5C5B5A5B5B59585858595B5D60605E5E
5D5A58595D5D5E60605E5C5C5B5A5A5C5D5E62616060605C5C5D5D5B5C5D5D5B5E5E5E5E
5F5D5D5E5E5E5E5D5D5F5E5E5F5E5B5A5B5B5C60
1D1B19191D21292C2D2A26191311111314121010161B21262A26221E1913111011111A1D
20232522272D31343634312F353A3F434948464545444444434848474848403C38343435
3A404542424342444A4C4F5354555657575757595A5B5B5E5E5D5D5E5E5D5D5E5F606163
63616161605E5D5E5D5B5B595756595A53493E2D
CBD3DADFE3E7E0DEDADBDCE4E3E1D9DBDBDFE5EFEAE6DDD4C9C7C7CAC8D4D9DCDDE8DFD7
D0C7BEB9B1A99E98938F8E939492908D888182827B7977716F727A7A797677737676716D
6359525B5C5758524339362F3234393B3C44453E3A33231815151516191D1E292A2B2A2B
212325272B323536393A363738383738526E8EAC
2F2B27241D161614161616161B212B2928251D1111151B232A3033343A36322E2B212127
2D32373E4248535B646D73747274777A7D868686898F92989A978D8B8B8F959DA0A4A5A9
AEB5BABDBDC8CACFD9D7CDCEC8C2C4C8C7BEBBC3C9CFE1E7E5E3E3DEDFE0E2DBDBD9D4CA
C7B8AEA69E9496938F94999A9A9C998F7A654D3A
5D5D5C5B5B5B5A5957565758595758595A5A60615F5D5D5B5D5F605E5D59575858575858
555557575653514E4843403B38353331302F2F303331302E2E2A2D2F302E2C2926263030
33312E211D151412111B27292B2D27201F20201E1B19151D2428292E27211D19181B222E
3C4A575F697073777A7674767674767B756E6A67
5A5A5A5B5C5C5B5B5C5C5D5E5D5F606060616161616261605E5C5A5B5A5A5C5C5D606160
605E5B5A5C5D5D5D5E5D5C5C5D5C5B5C5C5C5B5958595A595B5D5E5E6162626262605A58
5959595D5D5B595A5A5C5B5B5D5F5D5D5E5D5D5D5D5E5F595856555356585A595A57534F
4D4C4A4945423D3835333230303234363F484F54
4745454744444647474542423F3D3F403F41413C3A38363536363634383735383C394045
47474846454548494C505352525353505155595C61656463605E5C5A5959595B5D5E5C5A
58585B5D60605F5D5C595D5E5D5D5E5C5B5B5C5D5C5C5B5D5D5D5E61606060615F606060
5E605D5B5A5A585A5A5C5D5D5C5C5B5A55504A49
91918F898278747172757C8084868783807C7876767A7D7F82888D92979D9F9990856C5D
5554535C5F6066625C544C3F383531322F2A25272923242C2E262627221F232221273032
33342E24212324252A3233322F2D28282A2C2C2B2B2C2E323132343736393B3B3B3C3B3B
3A3E3C404347474B4F4F4E4E505050525D687485
5A606469727A7D818284838281817A7D807F818685858483827E7A7972716F7176818B98
A2A5A7A59F978B8E949CA6BCBFC4CACDCDD5DAD7D1D4D5CFCEDAD3CED2D2C8CFCFC8C8CC
CBCACDCCC5C3C4C4C2C3C0C1C4C5C6C2BAAAA09995919399A1A09F9B92847D73716E7071
787D8179726A5E534C47474545465054585D655E
49454341404243413E3B35312F2E30313336353A3D3B3B3D373333302D2D2F33353A4442
3E3C3933363D3F3D39342F282B2A2725251F1D1E1D1E1C1D1E1D262C2C2D32292829231F
2021222A33363737372F2D2D2E30363E4858636D767D7E766F6D6967707E858D92969595
948C8A909498A3A9ABAAA9A9A9A9A6A593806A59
5A59595A5A5B5B5C5D606163646362605E5D5F5C5D5E5B595D5F61646462615F5C5C5A58
5858575857555759595B5D5B5C5C5D5E605E5E5D5E5C5D5D5C5B58575757565A5A5A5B5B
5A5B5B5B5C5B5A5A58555353514F50504C4947433F3A373736363A3B3B37363836343533
2E2D2C2C2D2E31353B3F41413D36302B343D4750
40404243464A4E5051525150525557585B5B5B5C5B5A5D5D5D5E5E5C5B5D5E5F5F5E5E5E
5D5E5F5F60616161625F5C5D605F60605D5A5B5C5E6162615F5E5E5C5C5B5B595A5B5B5D
5F5F5E5D5A5A5A5A5B5F6060615F5D5A5A5E60616163605E5E5F5D5D5C5E5B5C5D5E5E61
6160615F5E5C5A5754545554555A5A5B57534C45
63605B5652514E4B4E4D47433E332F2C2928282B333433322C1F1A18191A1E2229283235
3A404741444444474C4E4D4B48403B3A3A3A3A38322E2929282A31373C444B4C4C4B4741
3C3B3A3D42444647454445464849494A4A4A4B4B49464442413F3D3C3D3C3E4646484A48
444647484B5051514F504F53575C5F6060616361
AEB3B8BEC5C1C0C2BEBDC7CCCECFCBC6C7C9D1D6D8DBDCDEE3EDF1E9E9E4DACFCDC9BEB9
B3ACA3A7A29899968E92A0A4A8B4B9BABDBEB7ABAAA7A6A7B1B3AFA9A49B908E8D87878B
8B8B90918B857D7670685F595657585E636766696C6F6866696F79808687857E7A726762
59514C49424044444B505454554B413A4A5E7792
272525231D1E1D1B1C1B1817181E2831312E261A0F0C0B0B0D0D0C191A1C22292325282A
2D2E33363C4749494A45393835312D2C2A2F39474E5559564E4C4B4C4D505456575F686D
757A7A787B828B939CA5A5AAA9A7A4A6A19B9A9A999A9F9F9A948B8C8D8F93939598A0A5
AEB5BABDC3CBCACCC8C2BFBCB7B9B9BDA184644C
5E5E5D5E5F5E5E5E5D5D5D5D5D60626162645F5E5D5B5B5D5E5F5E5E5D5D5C5D5C5C5959
595A5A5A5858565657585553514E5255565655514D4B4A4C49494849494B4B4D4C4A4541
3C393535312D29262525303437383A302E2D2B2827252A2F34383A332D2A262526272724
29292827281F1B1A19171818191D272937444D51
5F5F5F5D5A58595A5B5E5F5F5E5B585757595D606262615E5D5E615F60605F5C5E5E5C5B
5A5A5B5D5D5A595958595C5F60646463605E5C5E5F60605D5B5A59595B5C5E5D5D5E5F5E
5E5E5C5C5F60636464615F5A585451515455595D5F5F5D5C5A59585A595859585958595C
5F5F605E5A5957565453515353555859595B5D5F
201D191A1A19191A1917191B1C252424252620232326292B2C2B2A2D2D2E34363A3F4449
4C4946423D3E3E3F40424041413F3E3D3F42414648484C55575B5E5D5856524F4D4D4946
44413F4041414244454A4D535A6365686660595655585E60605F5D5A5B5C5D5E5D5B5B5A
5B5C5D5D5E5D5F5F6061605D6162605F5446362D
BEC5CFC4C1C7CACAD3D2C1B9BAB4B8BEBDB0AFA9A9A5A6A2958E8C8E8E928A8076737072
77786F6C6E727274736B6563636265615A5A5D616060574D433F3D3E403B3B3E40474C4F
4D4F4C4B48473F37322A2E2B26262D262C34342F2A262D34383F433A3332303032393B3D
3F3833322E2A3136383C3F3E3833312C445B7D9B
555255595D57514D4C50585F5E5B5657555C61646368676B747976706D69737A8486867F
7D7E848A8E8C92999E9FA7A399928E8C8F959B9BA4AFB2B2C0C6C5CDD7D0CAC8C4BAC4C9
C1C3CCCED2DDE2E9ECEDE7E3D4CBC3C6C3CACECACFD0C7BFC4B0A6ADB0ADB6BAAFA09D9A
9BAEBCB6B8BAAEA9B1B2A5A2A3A5AABBB0A0896E
4642373C40424447403E44464646453D3D3E41454C4F525656504C49433E3C4141414447
40414343413F3C342E33333946505155574A40362D20232B2925251D131F27282A291C17
272726252116151111120B12252C2F322D201B232326272821313A3C424539333C4D5358
554B3D41444C53544C464D57585851453C414146
5B5C5B5D5E5F60605E59595757595C5C5B5E5E5C57534E494A52565553504745484C4C4E
504F545757585752535555555555585D5D5F5E5B56585857575A5A5957555454575C5F5E
585654545656595C5D60655E5A58545358585C5C5B5A5B5857545253504F545553504E4A
4B4A4D4F4E4A484947484C4748494B4951555658
3E3C3D4544474948454C52524F4A423A3D454647494741444A505B6B7D848B887A686056
4F4D504E4C4948434041484B49494441444A4D514E494B4A494849494A51555555565354
575554555453565A5C5C5D615F5F60615F64626564635F5F5D5D5C5D6163656869666565
636060605D5D5E5F60636365656362635B544E47
7D7A73717679797A776D71717174797A7A797B79736C675E5D5F6463625F5D5D636E757A
7D7D7974706F6D6865695C555A5C6068706A6861635E636362605C524F524F525451443E
3E3D3C3A3830342F2F31302B353C3F44454143494A4B484640454D4E4F524E4C504F4A44
3E3635414545464538353C3D414447404D5F6A75
757C867F797A7879838C84848688878E8C847F828892A0A9A59D8F877E7E7F7F7E808181
868985878D90919BA4A0A9B0AFA8A59A8F92939999A29C9B9FA9ADB8BFB8B4B0ACACAEAA
AAB0B4C1CFD9CFCAC4BAAAABA59F9A9E9A9898959391928C8A8A8A8A8F9597919091908E
908B8784848485817C7A7A7877756D656662666E
47464543413B3736343130303334383A3A393A35312D2926252529292E31333538363333
33323232312F343A36322F271E202327282A2C2D302F2E2C2A2222211F1E212425242F3C
393839301F1E20252C34444846474F4B5158564948474B5867655E5B514647514E4E5358
58646C636262626E87908B8C8886899687746151
595B5C5D60616162636362615F5E5D5D5F6061646565666563636463635F5D5C5C5A5B5B
5B5C5E5E5F615C545354535961605F5D5D5B5C5C60616161615E5E6061605E5C5B5B5D5A
5B5A57555A595A5B585758565558524F4D4A4A51545655524F4C4B4D504F4E4948474749
4C4C4A4C4B4A48413833333336383A3D424A5356
6C6A6866635D5D5C5B5B5E5F5F5F5D5B59575556585B5E5F5F5D595754555558585C5C5F
60605F5F5E5B5A5C5B5B5D5E5B5C5B5C5B5C5C5D5D5E5E5D5E5D5D5E5F6060605F626462
6262605D6062625E5E5D5D5C5E5B5A5756565A5E606161605C5C5C5C5B5C5D5E5E5E5D5C
5B5C5C5C5D5D5B585755545556575A5C5F646769
221F22252B2C2E2D2B2C29292A2A303435393B352E2A231F1A1D21222931333235322C28
25242222232630383B3D3D322A26242323242424272B2F34383A3A3837373433312D2E34
35373A3833302D33383E42443F3B373739393938373737383B3C3D3E3D3C3B3C3D3D3E3F
3F4446454245464445484741434444443F362E25
BCC2C7C8C2C1BCB3B6B5B6B7BFC0BEBCBBB4ACADB3B0BAC4CFD4DCDFDCD4D0CCC4BEBCB6
BBBDC1C6CECCC9C6C2BEBCC5C2BEC1C1C0C5CFCECCC2B9B2ACA7A29B99969AA3B0B8BDBC
B9B7B6B4AEADAFA8A1A1A4A1A3A5A8A39E988D847F78747A7F7F7D79756D656468696B71
73757272777B7C83827D79746D6C6C6B7A8B9CAE
37332B24262E3642403F3B33272520202123272E3036332E251E15110E1013171D242E3A
383937302526221F22242525313D3F41443C2E2B272D3336383F41494B4E4D483C362E2B
303031363F4042494E4B444647484A545860666B71797D7D7A79787D8798A1A4A29F9895
958C89898580817D7D8188929C9E9D9A8572624E
5758595B5C5A555758585D6364636766666A6F6C69696662646565676665676664645F5A
585755595B5C5D60606161605B5956555556585B5B5B5B5B5A58595553535554595B5A59
57565657575A5854514F4C4C4D4E4D4C4B494E5253514E4540404747433B393431333734
31363D3F3F403E39393734322D2A292A323B434D
626061615F5C5B5D5B5B5F64666A6967645F5D5D6061625E5F5F5C5A5B585556595B5E5D
59565755575B5D5A5B5B5A5A60616160615F5D5D5D5B59565555595E5E5F5E5B56565656
57595A5B5E6060605F5E5D5D5D5D5D5C5D5C5A5857585A5D60625D5C5B59595D5E5D5D5D
5D5B585757585A5F626263615F5F5E5D5F5E5E61
342F2C2B2A2D2F353536332D2326252C313834332C32343B4046424241413F3B36353942
4C53514D433B363A3A3A393934353A3A3B3E3E3B3D4145484C4F4C4D4C49484847484743
413C3836363537393F414444464442403E3B40414242433C3A3A3C3E42454B4B4B4A4A44
43424042444546484747494B4B4A4C4B4946433C
A4A8AEB5BBC6CCC6C6C4C0BDC5C0B8ACA9A09FA9BAB5B5B6B0A5A6AAA7A4A9ADACAAAAA0
9C9AA1A5AFB0AAA3A2A1A6ADB1AEA59F9994959B95908E8B84878D8C9095959391898084
85888D96999790897E6F6262646A7383898E918F8A8782817976747066686969696A6B6B
6B6865625D58585C605D5A55504F514E60727E8F
454544423E3835333334312F2C2C333C3C4044382B27241E20272E30363D3E3F44484447
46443C3D38383E43444545413F3F464B5155544F53595A606A6861605D5A5B6268717877
7674706A64666F78819197928B82776C67665E5F66696E777B7F80828A8F89888A8B8B92
9597999EA3ACB0AEA8A7A7A7ACAFAFAD957F6A56
55555553524F4C4A4B4D5256595C5F5E60626262646464636362605D5D5C58575653504F
4F4F525356575757565452514F504F4F4E4F525554504C484340444343444442423E413F
4042444142403A3837333A3D41444B474A494A4846464340454240413F36343434343535
34383835322D24202124272A2C2D2D343B434C54
62605E5E5D585959595758595A59595958565759595A5D615E5B585754565A5D5C5E6263
63666561616262646463605F5C5C5D5C5B5B595858595B5C5D5D5B57585858595C5C5B5C
5D5E5D5E5C5C5B5C595A5C5C5B5F5E5D5D5D5D5E5D5B5A5D5E5F63646465676666656564
64646463626161636666666564615F5D5E5D5C5C
3B4141414445403E3E3E3B38383636393C4146474749484A4C4E4F504D4A4742403F3C39
3836353535353A3A3C3E403E3E3F3E3E3D3B3836373836363835353B3C3C3C3B38383D3E
3F4147484A4C4E4C4C5054585B5B585753514C4A48494B4B4D4B4A494B494C4B4C4D4E4E
4E4F5051535554555555555452525354504D4841
9E9C9A9896949896939494959DA6ACAEAAA2978C857D77747372757A81828080817D7E7D
7C7E8081888F939494908A837E7675767A7E8A92989DA09F9A968D837E7A7372737B8180
807D716663626263696C6F716D655F544C46443F3F3C3D404D5254545147403D3C3B3A3B
3C3F474849484438302D2F30353A3C425364798E
54515557565A585859595A5C564F474040444B5661656B6F7074757474777C8081838482
80818284817D716C696A717C83888986837D767169646566686E767B8287909597918888
86868C97969493958F8A827B7B838C9DAAB0B5BBBBC0C3BFAB9F9591909FA7A8A9ACADB1
B8B5ACADADAEB7C6C2C3BEBAB4BAB8B3A2907A67
4747454547494A5054555453504F4F4F50504F4D4B4B4B494A4946433E38363432343339
3C3B3939322E3135393B3A39373736393B3D3F414140403E3F3F4144423F3C3833313130
313234333838373536333334363532302D2D343A3E3D3934353A454E5454555550494137
2C2826222222201F2E3034383B2F2D2B2F343B41
5A5B5C5C5C5E5D5E5C5B5955514F5154575B5D5C5B5B5B5A5858585757575656575A5D5D
5D5B5A595D5D5E5D5C5A5B5D5E62615E5E605B5B5C5F5E5E5F605F6160605F5D5A5A5B5C
5B5A595A5A5B5E5F5E5F5F5E5E5E5D5C5B5C554F4E4E4E52585B5852504C484A4E53595C
5F606569696869645E5F5E5C5C5C5B5C5C5B5B5B
43403F3D3B373735393D45525B5F5C564E4843474B4C53595C5B5A5754504D4B49474547
4A4E51524F4B4542434343434647474B4C4C4C4C47413D3938373B3C3B3C404141474A4B
4B4C4848494747494A494D51545556565454575758575554515051535256565A55545354
505452504F4C4845433E41474E535A5D59544E49
6D707277808C919A9893877B736D6B6E716D6D6B666A645E5D5C5655555F696D73777574
726F6A666265696F7070706F6B6D6D6D6B6B686462656767696F706F7478747072655B58
57565F64676E6D6B6A6860544B47444049514F5053514D4A4748433D3E3C3F45515A5D57
52473E3834353B44505D5F5C555046404B555D63
7F8082847D756E635E60666C71777B7F848D92969894939392929A9F9F9C94908C8A8987
85888B8C90918A8586898B929896979898979D9C9B99979594928D8A84808183858C969B
A0A4A59D9893918E8E8F9293999EA5B1B6B2B3B5AFB4BDC7C1B7B8BAB5BDC2B7ACA09B9F
A7B1BBC5CED0CECEC5BAB4AFAAA9ACA89D928781
524F4B47463F414245413C39383A3F3F3E3D373333313134333333343735383A38343636
3735353A3E3F474C494340362D2928262628282F393E3F433E35302D2D2B2F35393D3B39
36332B2B2B2A2B2F33363741423F3931241E1D1D1F1C191622323B3C3B2D1D171B22282B
2D2D2C29252525211F2020202426262D343E464D
5A5B5C5A5D6062646465676A6A6867635E5B5D5C5C5B5A5A5A58585758595B5C60606163
646464605C5B5755555655585C5E5F60605F605D585556565A6167696968655F5B595A5B
5B5C6063626364625E6061605E5F606062636362626363615F585252585E656C6C676361
605D5D5B5A5858585A5B5C5F60606062605E605C
52504C483F3D3A3839424647494A45424444444344484D4C4C4D4A494F4E4D4F4E4B4947
41403F3F40444A4C5052534C4D4B494744413D3E45474849474444495057565957585757
5656504D4F4E4B4C4B48474C494847494343403E39363333353A414B53565A5A5A595959
585353524F4E514E4E4E4F505254545251504F53
5B6269696660626466655F5854565B62696B665C57504C515354585F5E5F594E433D4048
57595A5B5F616C6F6F6659504D4B4F59595C62686E7B86878887837D7E787370716F6C67
62524D4E50505857504C4F545F676965635E61656D6C6E7075716854402B1E18181B1B19
1D29323940413A3736373A383332333C40464D57
8C898D8F969E9C989997949596938E8F8F898A9BA2A4AAA79C95918A81839096A3B7BAB2
AFADA4A0988F7D7E7C8191A4AAADAEA6A19C9F998E857E74767C8385878C88868382818E
989EA6A7A7A6A9ABAAA9A29489868388949C9EA1A2A09F9E93939EA7AABFCED9E2F0EADE
D8CDC3C4C9C1C0C2C4C2C7CCC8C7C8C0B9B5A897
403C333835383B3E3A3F464A4948473B333B403B3A3C33313A414449504C434642342F30
2727333A41484B46454945403D3E3A3941443C3839353037373633322B29383D3F404030
2A32353433362D2B35393F42443D3D3936353534323635343330292B3636302A2111162C
32363731242B3337333028232C2F2E2F3332353A
5E60615E65626060635856595B5A5D646560615F5A54565456595B555452514F555A5E63
676762615C58565552515455585754555557595D5C5E5D5D5D5C5A595A5853515152555A
5C5C5B5B5C5B5C5F6061605E5A5C5E626466635D595A5F6164676761605C5C5B5D5B5F57
565657565B5B59585A5C5B52514F4E50595B5D5D
524F4E5149474D5150575B555457595A5C5D5454595F6370747374797574737069666460
5D5D5D595A5D5E5F63635E5B58575855565758555653555A5E6163625B575859595B6062
626463605E5B5653524C4A4D55555959554D49474954585C61645E616261616261626162
605F5E5E5C5F5F626263616E6C6C6C6A5D585555
3D372D33424A4B473E313944464744382F3B50555559503B3B3B332D2F33333B403F3736
33323E4A4941433D333C474A4A4F4C5057554C49453C3A3F3F39373534394443413B3022
212B343A3E433E404C5B636460564D4D4F5354534E47423D322A2B30363F4345403A3D3D
3A37352F2B353C3B3A3C36303835332E34393E3E
A6B2C0BEBABFBBB9BEC5BBB3AFAAA4ADB2A79997959095A19E9EA3A7A6A8ACAAABB1B4B1
B0B0A6A0A4A7A5AAB3ABA8A7A59CA19F989BABA9ADB7B9ABADACACADB5B7B2B6BDBABEC7
C5B6B4AEABA8B0B0A49D9A999DA9AFAFB0AEB2B5B7AFAAA6A3A7AFAFA9A69E9A9CA1A1A1
A7A7A5A7ABA19FA6AAADB6BDBCC2C5BFB7B0AAA4
4243413931201B1A1E201F20222A32373D3F3E3D3A383735353635383D3836322D252729
2D2D2B292730343837372C2A2C303133312E283332323134272A2B2D2C2B26231F272A2E
31342F2E2D2C2D2D2F2F30302C2826262528282A2C2F3337403F3C37363134373C3E3B39
363A41494C4B453A322B28231D1A1A262D32393D
55515054555F65686766666663605E5D5B5A5D5F6060625F595455524F545556575B5A5B
5D5E5E60605B5A5A5A5D626362625F6060605F5B5A5959596061605F605E5D5E6062605F
5E5D5A5C5E626464605E5B59595C5D5D5C5C5B5B5A5B5B5C5D5D5E5F5F5D5D5C5A59595A
5A59565350505355595B5C5D5E5F5F6060605F5F
666564656561605E5D5C5E60615F5D59585858575C61606467656364625F615F60616565
625F5D5956545554504F54575B5F615F5D5A5A59565553504F5152585A5D60625E5C5C5C
5D5D605F5D5A565354535153555453565758595B5B5B5A5A5958565554565859595B5B5A
5B5C5B5E605F5F605E60616160605E5D5E605F63
37393C3C3932302D2C28211D1B1D24282B2E2E292522212028323941474340403A332E2D
32373F4140443E3A3E3E312F291F1D1F20242733383D424842403C36302D292829302F31
31332C2C2B2D2F34363C464C4A49473C2F271F1A17181C21282C3134352F2D2C2D303439
3A42453E3A362B24282A2B31343332312C29292C
AAABACAAABADA7A7AEB8BFD0DDDEDCDFDAD5D0D0C5BDBBBCB1B2B0ABA5A9A7A8ABB3B4B1
B3B0A9AFBEBFC5CBCBCAD0D0CFC8C4C0BEBEC7C1C3C1C2BFC8C8C4BFBBB0AAAAACACB4B6
B6B3B8B0ADB4BCBBC0C2B7ACAEB0B3BCC4C4CAD2D9DDE2DFD5D0CCC8C7C8C0BEBDB9B9B9
B7B2B4B9C1C9CDC3C0BAB5B2BCBEC4C7C8C4BFB5
2C272625282F3B413E3A37291C1A161214161B1E303C3F3C3D3029242427292929292D32
2D31342C211E1C1717181B1B22323D4449483A342F2E2B2925252E353E4A524E493E332B
272B2D363B342B2D251F242726242328333D423C32251B161A1C1E1F1F202A2C2C2E302C
2C2A2625201C2437383C403B2B2A252123272B2C
6768666564615F5D5C5B5B5C5D5D5E5E5E5D5D5C575454585E61626667666E747777746F
6D6765686867676966656463605D58565554555856555355565756575859595C61646468
6B68696969655E534C494B51585E5F5A524E4B4D51595C5E5D5D5B5B5D5F616467686562
605E5D5D5F605E5D5C5B595A5C5C5D5C5D5E6063
5B5E5F5F5F63616062605D5E6060606160605F605C5D5B5C595C5D5A5758534E4E4F5156
5A5D5D5E5C5D5E5F60605E5D5D5B5B585553555356595B5D5E5E6061606264625D595A59
5B5D5F60636A75828882786C5E565757555352525353545657585B5C5C605D5956565355
58585756545251515255585B5E5E5D5D5C5B5A5B
2E2B2B2E3230313532353C3F3D3C38332E2928262B2F32353C3B3C3C3A34302D2C292C35
343234302621211F1E1E1F1E1E2A2C3135362B2C29252627292A30332E2928282B333738
322F2B2A2B2820191E242C2F35302B2B3342464747453A35302B2824262E3533312D241B
1B1A1B1B1F222733383B3D3D32302E2D2F31322F
B7B9B5AEB0B2B7BEBEBAB1A59E98989EA8B1C1CDD2D0CEC8C0BBBBB2AFB3B6B4BAC4C5C0
C3C6C0C0C5BDBAB9B7B8C2CDD3CCCAC7BFBFC7C1C7CFD0D1DADAD1CCCDCAC7C9C9BFC0C1
C5C9D2D4D1D2D7DAD3D2C7C2C5CFD4DDDED2CECCCDCED6D8D3D7D9DDDEDED6D6D4D4DDE5
E6E4E6E9E6E6E4D5CDC4B8B2BBBCBBBCBBB8B8B7
3435363A322D251C181A202A333E43423A35261A11101013161B1F2D35383B3D352B2621
1D1C1F232A393E4448473B322B2522202221232B2A27272519181918181C1D1C1D242220
211F161312120F0F1315212D2D2C2C221717171918181A1C2623201D1A0D0E0F12151618
1A1E1E1D1D1A17181C21292F3233383836353435
59585B5E63666A686B6A6765666462636667676A6A6766646362605B55525053565A5B5B
5B5B5A5B5955535150525554545455585D616364625F5B595759595A5B5A5A5B5D5D5E5D
5C59595959595A5B5B5C5C5A5A5958595C5B5D5D5B595959595B5E5F61616363625E5C59
575758595B5C5C5D5C5C5C5B5B5B595858585858
6263666765676866676967676360606061636363646568676665605D60616060615E5F5F
6062615F5F61615F5F5D5B5D61626464605E5B5B5959595A595A5B595A5A5A5A58585B5B
5A5D5F5B5B5B5A595A59585654515050515352504F4F50515453504E504F515356585858
5A5C5B5A5B5B5958585655535251515155595B60
363636322D272324292A2A2B2A2D3032322F28231F1D1E24292E3642444444433B383637
3734363836363B3D3E3F3D39393B3D3E3F3C3C3D3B36322B252424272A2A2829272C2D33
37383334312E2F2E2A272F2F2D2E2C1F1A191C1F242B2E31393D4040382C242122262C2E
2B2B26211C1A12131317191E22252B2C30313331
ABAAA5A4A6A6A9A499979999A4AFB3B3B4B5B8B8B9B2B0ACAAA7B0B0B1B1B3ADA8A8A99D
9A9C9B9CA6ACA8A39F9B979696908F909197A2A6AFBBC4D0D8D7D3CBC8C9CDD3DBD7D0CA
C7C5CAC7C6C8C7C6D0DAD4D6DDE2E5F0F0E9E3DEDAD8D7D4C7C3C1C6CDDEE1E4D9D4D0D5
D8D9E0E0E2E5F3F1F4F2EEE9EAE9E3E1D5CABFB7
494C5054585A575A63666669625148454242494E505552504D4A3C322F2D2C323D3F3F4C
57585B5E574D4E5558585C5D5A5C5B5A5B57514A443A332B2A2A2D2F2C2A27211D1E2225
252525262A2D2F34312B2926221D1C1B1F23272929241F1C191A1B191A181D1D24282A22
211F1919181511161617191A1413151B26313C45
4C4743403E3C3D423C3B3B3B373F4243454442404146494C4F504D4B49484A494A4D4E4B
45484949494C49444244494E51565858565855514F4F4E505356575D63646668625D5957
5657596261605F5E5757565555545557595D5C5E5F5E616367686B68696761595B555153
575156595F63645F605C595B5E5D5C5855524F4C
5F626363636566666C6F6D686864626162625F5D5E5E5E626464676B6C6D6D6F6D6A6766
615A5755535154555A5C60605E5E5B5653534F52585F656665615E58514D46404045494D
504F4C484749494D5156585B5B5C5B5A5859595859615E5E63625B5D5C595D65686B6E6E
6564605F5C5C585854585E6160635F5D5B5E5E5D
3A3B3C3E3E404045434142433F41403F3C3C3F45454B4A46414242464B4E4A4545464953
5656524E4846434544423C393535373C4246484848433C3B3D3B3E444C515A5E5E5A5756
5452514F4844433F36333029292A2D2D2E2E2C26201711120E13191A1719202629282B22
262E363D403B383F3F39332C211C20242B2E3237
6A636464697073737B7C7E8385828182898D9396999693908F8A837E75707273747A7F7D
7E80828081858685888B898A8F948F8D877F787774777F818793989999979394958E8A86
8381919FB0B5B8B1B1ABAAA7ACAAABB0BFC5D0DDE8ECF2F0E2DAD6D3D5E1E0E0DDDEDBE1
DFD6CDC7C1C0C5BDB9BBBEC4D4D9D5CAB6A28E7B
A7A9A398867E7C767073716C6D706E706E707072706E6F7171737A7B7C7B78756E675F57
535253596062666A696B747C7D787E7D7D80898A88847C787168615E5C5E60616368696C
6E7167594C4741454A4F505A5757534F3D31271F18161919242C3134362E251C16131011
14191E20242729323C3B39352923263147617C98
2A2D303B47464343413A3B3D40424746443F39302C2A292A2C2B2D2F363A41494E505356
565855524F49484444433E37353230313333313136383C3E40404040403E3C3D3B414442
42423E3E434548484A4C4B4A4C4B4D50535659575658555254504D4D4F4E5458595B5D5D
5A5B5A57555A57514F514E515C61605E56483A2C
5858595A5D5F6364666664636261605F5D5C59595A5A5D5E5D5E5C595B5B5B5B5E5D5F64
6C737E82827F776D645E5A585859595856545557585A5B5B5A595959595A5B5B5D5D5959
5858585C5C5D5D5E5A5556585A5F656361605D5C595652585E626568625C5957585A5A5D
5F5D5D5E5C57595856555B5D595A5B5956595958
444C525D625D5758535155575453535150515757585754535253514E47413C3C3E414240
3A312825272D343A3E3F3E403F404345484A4B4D4C4B4A4946444341423E3D3C3C414A4E
4F504D48464646494B4D4D4D433B33302E30343E474D5557504841383432333335353633
333B3E40444540424346463E38332D2F363A3B3F
726E6C62514A4C4B4D58554C484C525E646A5F4F4244464D5A5E626F7B888F948B7F7573
7379827F7976797B808982767575747C847E76736F67676560646C727C85807B7977777C
7D736B6664657070717C8A8E9CA39990908F92968E827C7A83929B928C8579747E827A81
8D9298A39F948E8886899293999FA8ACA4978D7F
9189888B8C9598999DA0A8ADAEABA2959494999EABACACA8A69D92867A6C65605F687071
717067696C72747879797F898B8A857C71717C81869193969A989292857F8185837B7571
777E8F979A9288828176685F57545D676D6B655C5D676D6F68615B62708294A19D979588
715F514949515D676B6B6767666059535F6B7687
353D3D373E3E3B38362C24252C2E3236312B2F3A393838352B2E373C434E525153514948
47484C4F504A46413D373B3D3C3D41404147423D3D3A352F3533322F373A3E4142433F3C
33383534353A373C3D4147494746494B4A4E535153524D4947424349443D37302A2E383D
4851544F5255524E4C483E403F4245483E3C3B35
5F5D5B5C5D606061605E5D5E5E5D5C5B5B5B5C5C5C5C5F6163656765625957575B5F696E
6D6A676769696767615D5E5D5E5F605F605E6166646264645B5A5B57504B4D4F52586061
66635F5E5F5E6164635F5B595A5D5D5D5D5B585A57595B5C5C5E5C6165676869635C5B5E
5D5C5F60626464635D55505052555A5C5D5E6061
5154565758564E4D4B494B5354484344443C464D4D4C51504C4949444042464549524E4B
4A4A4642413F3E3D45494D504E4944413F4647474747454E575D63645E5D58524F4E4A4A
49483C342E2E2D383C3939383636433D38322D1F262A292C302D2C2D30333436393A403E
3F4140383B3635363B404A5455524A433D3F454C
473A281F2A3E52565651443D4E60625B4E4A3F464B5046443E4C5863676A6055504D4947
4843424E5C6261625746454E565B62605C5E5D56565B595964655E5D605E6B7678716F66
637096AAB7BBB09A9CA4A19C9687787E8B949FA6A9A6A7A0948C9498989B998D8380848B
8D85817E7B86909699978A85858783847E776A59
A7B1C1CAC2B5ACAAABB4C2C3B3A8A0A9BACBD6D5CDC6C4C0C6B8A9A099989EA9AAADAEB2
B3BABFB7A8A59EA0AAB9B3AEA29D989DA49FA0A5A3A2A8A193919191959B908886858288
86765D4D413E4952504D545D69797F7C736F69706764626B70807C6F64605A64747D7168
676C6F7C7E6E655B565864615D5B5E62727C8797
363A3C3B332A26242529272322293837342F241314171C2122242529323130312E252624
23212021232632302E3031292E3233363633302F2F2A2C2C2E2B2C2D2D2C2D3032394042
474B49494B48474645444241414244444341403D4141413C4036373C423E4545413D3F44
4341423F3B3E414446494C4D4F5054534E464039
635E5B5B5D6366696A67666663605A585859595E5F5E5E5E5F5F5E605F605F5F5E606061
63626160605D5D5E5F6063656868696461605E5D605F5C5F6060656867686662605E5959
595B5E61616261605F6363615E5C56575A5E5F605F5E5E5F5E626260606362626364635E
5B5D5D5D6269676769666261605F615F61646566
4C4C4F50535353514E4C4C4A4C4F5150504C49484645474A49494945464647484947494A
4848443F3C393C3C3D3F3E3B3D3D3B40413F403F404446484E4F4B49453E373534394046
474949484C52524D473933302E2D353435363736363535353A3A3C3D3C333131302F3233
32393A3A3B3A3334323338363433342F353B4243
46454947392E292725242529252D3E42444B473A3A3E3F40464B4F555D5A59554F43413F
4140474C535B646867625E564D4C4F4B4E5659646A666058483D3D414855656C7071706B
6C66605957535B6B7D929CA7A69C8E87767175797C8489868786827E7C757374787C8493
A1A0A3A1968D8C8282868792A2ADB2BCA2866A5D
C4C7C4C3CBCFC6C8C9CCD3DFE4D7C5C1BEBAC5D4CCC9C8C4C0C2BFBBB2B5B9BCC3CDC3C4
C4C8C9D2CEC9B8B3B3B7B9C2C4C4C4C7C9C9C7BDB1B2B8BFCACFCCC7C1B8B1AFABA4A0A3
9FA3ACAEAEAFA59991837C7478859199A4A49C96908D888983817F7F818C9195948E8474
645A54575D646C74746F6B625448403A54708FA9
150F0F12142334383C4038282424211E1D201D1C2727292C30282B292724221F1F242D27
231B0F00080B11181A17171D1E1C1611080204070D0E0E0B0D171B1E2225202022252422
2323202827272C2F292C2D2C2C2926252B2E313334302F32343A42484649473E373A393C
424748474948474B4B4A494843454547443B2F22
6264615E5D54545352505556595C5D60616060605F5F5C5A595B5A5E61636466645F5E67
6E7886897F756B5E5B5958585D63686D6F706C6966666565625C5E5F6061686766676A68
6563615B5C5B5C5C616062626260605F5B5758595C61656463605C58595755585B5B5D5E
5E5E606161626462605E5C595A5C5E5E5D5F6060
6362615F5D5E5C5A5A59585D5F636A6965625B525356585A5B5B5B58575654504F51524E
4C4945484B4F545855585651504F4F515858595A585555575A5F5D5B58544D4C504E4C4F
504D4B4B494746464445444241403F3F444646464641403E3B393937373B3C3B3C3D3A39
36322F2C28242022252A313A40403F3E4348515B
121314171D1E292B29241F110B08070C0F121A273030302C201311100F1113161A202D2E
2B272016171E273238393B4248484A473B3533343B41434440414346474A473E3332302F
353F4B5D615F5A4F403C3E4142424447525A5E6260584E4F555B616D747B85888887837F
7F868C929AA7B0B4B5B5B1A9A395908F735A482E
E7ECEFEFF7F4E9EAEDF1F4FFFCEEE9E5E5ECF8F4E4DDD6D2D6E5DDDADEDFE0EAEEE8DBD8
DBE0E8F1E8E1D6CFCAD3D2CEC5C3C3C5CDD2CCCBC6C1C2C6C5C0BAB7B8B7BDC0C4C8CAC8
C9C4BBABACB2B9BFCDC9C9CBD4D9E4E2D2C7C2BBBAC5C4BEB7AFA69F9A8E837F7A767A7B
78736C655E544D4848484A4F545F686986A2B5C5
231C1D1B131616100A0806050E1D1F201F130300040A131B1F1E2A2F2D2D2C1F16161516
161311101A1B1A1B1B12131517181615161923232222201B1E1E1F1F1A1719232626282A
1F1B1C1B15121016172227281C190C0A0B0E101211111E262A2E31292526282B2F303134
3A3E434A4C4B4C4B49464341414342433E373030
5557585A585756575757595B595A5C5B5E666B6E70706D6968655F5C5B57575A5F606161
5F5B5B5C5E62686D6E6C6A6A686766635D545254575B62605E5E5E60676C6B68655F5C5B
61676A6E7374736F716C6460625D5E5F5F5E5C5B5C5E5C5D5D5D5D5F6161626165696B6C
6D6C6C6A6B6B6866656667696765605C58545254
5F5E5B5C5C5B585A5B595756545555585A5A595A5A58575B5A5A595D5A58585B55535756
595F616161605E5B5B5C5956575655575A6A6B6B6A6A5D5E605F5B5955525255575B5E61
605F5B59565150514E525552525655575A5B5B5955504D4A47494C4C4B4D4F4F4D4D4B49
47433E3B3A373B3D3E3E3E3B383E41454F5B595B
2B2929271F2328272A2A29282D303335312D26201F212220201E2A29272824161B23272D
322E282328242124231A1B1B181B1D1C1D202724252422181A1D20202223222530363836
322A2723222324262A333438332F28292723292E3337484E5355575355554F50565B6477
84878B8C898C8F8C8E908E919EA29F9A82654C3F
C5CDCFCFD5D5D4CCC8CACACDD6D6CDC4BFBBBDC3C4B9B6B6B5BECCD8E2EEF3FBF7F0E5D3
CBCBD0D7DCE2E4E3E3EDEFF0E7E1DBD7D1CEC4C8C6C4CDD5D2CFCBCECFD0D4D5CBC5C3C1
C0C4C9C9CBD5DBD8DBD1CDCBCECECFC5BFBCBFC6CBCEC5BEBAB6B2B6B4B2B2B3A99D8D77
605B57565A5A565756565858534746485B7498AC
383331302F2D2B343A3E4241302324292E333B38323C46484A493321170B010307070F20
2425262416120F0C0807080A191D23282D26292522201D1D21273132312D261A15151819
1F24232A2D27231F130D0D0C0F152330373D372D27231D1F1F1F232627282A25282E363D
454B4F4F4C4F515453514D49464B4E5354524A41
4F50515255575553504B474A4E555856565752545B5B5654524D4C50555B63646363615C
5D5E5D5B5D5C5D61666665645E5E5C5D60605D616365686B6A66625E5B5B5D616462605E
5C595A5B5B5B5C62676E7376746E6763616264656463636363635F5C5C5A585B5F606063
615B5A5C5E5E5F6365676E727171737068635C54
5D5C5B5B5A585B6164666864615E5E616565666663605E5D5E61636663625F5C5A5B595C
5B5B5A5A5A5C5D5E5E5E5D5B606262626060606060615A5652515353545859585A5D5E62
646763615D59524F4F4B4D52535454504D4D4B4B4B4A4847454546474748504F4A4A4B43
484D4C46433D3938332F2921191A1A1D2C3B4853
2824232020201F222325272D2E33383C3835312B262E2F30302C2320201E232428252628
2827292B252423201C1D1D1C23282B2B302727262A2D36373A3A3D4146494A47433E3E3D
3D38363433353E433E3E352A2B313B4A5B6465625F57504C4A49494C5159646A6C6F6F6E
6E77838F96A1A9ACB2B4B8BDC1B2ACA58565553F
A2ADB3BBC6CECECDCBCAC7C4C2B2A19A9694A1B1B8B7BAB9BABFC7C3C0C0C2C7D4E5EEED
EAE7E1DADCCEC7C8CCC8D2DBD1CBCBCAC3CCCDC0BBBCBBBECBD0CAC6BEBAB7BEBEBDBBB2
ABAFBDC2CCD0CBC2C5C7C4C9CBC5BCB7A89B9BA0A4B0BDBFC4C8C8C6C7BFAEAAA9A6A5AA
9F8D7E6D5E54493D3939383B424E51546A7D8691
655950463C32322A28242524283B4C5156594A3B352D29292522262D3438353124130704
04050A13192A32312E32261D1D1E1C1E222425333532302D1E1719191C1A1B181F252731
362F231F1512151C1F20282C2C2C302A292C2D2B28221D1E1A1817170F0D0E0C0C0D0E11
1D282F374142464C4F4F4E4C4A4A4A4A4D555961
474A4F56575B5C5C5A59555555504C494A4D545B63656767696763615E5A5A5B585A5D5E
6061605D5A58565658595B5E5F5F5F5E5D5A595A595757575658595C61656766625C5B57
595F6362666662615F5D5D5A595A59585A595856575858585A5A5856555759575A5B5754
5856585B5C5C5E5D5B5B5C5D5C5A5C5C58524E4A
5E5F5E5F606264686B6A6966625E5E5F5C59595A5A606262646564646262625E5D605D57
5656555553545256575E606565656664625F5C5B5A5E5E605E5D595A5A5D5D5C56514D4C
4B4D4F504E4E525355555853504B484342404245474A4C5054514F52514B485149424142
3A3B3A38373433353634312D2B3230303C464754
424344433A34302C2E353B4044494E4D4F4F4A3E352B282422222427303333353126262A
2A2B2F31363F4748443F3C37393B3C38393E44444039332E2F30312D261F1F202D444B4B
4C433232373D39353535393F4341413E424A5050514F525F6977838D8E959B9992999E9F
A2A89D908B8D8F99A29BA1A5ACB1C4C1A4866C52
8E8F948B848283858F95898385898DA2ACA6A3A9AEB7C3C9BDBEC0C2C4D3CDBDC0C9CAD4
E3D8C6BBB2A3A5AEACA39F9991929494908D8D93A2AFB0B2B2B0B2BEBFB5B5BBB9B2C1C1
B6BDCED0CFD0C4C2C3C6C5D0D5CDCFD4CDC5C9BEB9B9B39E91817064676A6C6D73716D6B
68666C787D827F786B6B61594B3823243547657E
62626169767D7E7F766B6E6E665C4F3B33383F42443E37323C39342A210F172A32363B35
2831414A4E50453533393E47504D47494D4B4841372F33363A3C382E3240403D3B352321
2F2C272624162428272522130E1B1E2024271D2629292C3232394246443E373237383B3E
3F383C3E3E3D3E3B3A4149505B676D7172726E66
46423A3A3C3B3B3C3C3C44494D515553505152504E504E51595E63696967635C56524E4C
4C4D4D4D4F4F4E53585D6266646463636363615E5E5D5E6165676B6B6865666463636666
61606060636B6D6E6C69636161625F5F5F5F5D5E60605F5E5D5C5C595859575455575758
5C5E5E5B595858585D6164666A69635E59564F4B
5F61636462615D59575858595753504E4C4E5357595D5D585653504F5252555D61636565
605F67696C6E736D6D6C6B6562615E5F5E5D5D5C5754545556595C5D5B5D5B5754555053
545454544F4E4F4C494549494C52534F4841393C3D3D3E403C383B3E4044494C504B4742
392F3536353332292126201F1D1F192532404F5A
595F504F57585D696E605859595A60656264666768696565605B58554F556159514A4030
323E39424C5E62757A7B71615E5D61718B918B9193949FA18D6F5B464D61706D604C3731
3B48494B535262778A8A877A71737C898A96979F9FAA9F96929B9EAAACA6A1A1A4ADB4AA
A9AEAFB2C1C4C1C9D4D4DFE5D7D1D4CFAFA68A6F
696677766B6A6557536268656668636169655E5B5854585B60686C71777264656B747F8E
907F786A5E4E4C403A363D4C505251432C2A312D2E2F231E2F495C73715E505562778E93
887974736E6E5B493A414552584E443B423E473D3D323D464E494335343B3F413B322C38
3C3F373023242B2B261C110B1B1F232034314357
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.504715 0.495285 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B373A282A361BB7388CA55BE63A2949C8B6CA9997AC161B5726CE049C27D91C433A295BC
947B7B9F809E879583949C91A78751D9709D965ADA658FAC39EC62B877879CB27569B382
AD996C9075ABD72D96B97F8FB47F7179C88D72A391AE3F9BB08BB185709E988B89A26BAC
81AC8585A274A68E73B5846A9DAD8A9787879483
B672A380A859C37287C858BD5FAA8F9F8B6BA39C7EBC66B3726BE04DBE7C95BE37A294BD
927A8198809F899681959792A78952D66DA98A61DC5F94AA3BE965B77B80A2B27862B684
A2A668916EB4C93695C17A8CB2857077C5916CAC8AB04297B28BAD8C73969A8A8AA16AAC
85A68985A46AB18282AD866A9CAD8B948D83987F
B470A77EAC54C77385C95AB95BB685A48C6C9E9C81BC66B37367E14FBE7999BB36A394BE
917A84987F9F8A987E979593A78756D863B58461DB6095A83DE767B37F80A0B27C5FB58A
9AA9679569B9BE4093C5758DAF8C6978CD866AB786AF4496B28EA69473929D8887A26BAF
84A28C85A765B9798AAA866A99AE8D93878B977D
B56FA881AD4ACF6D89CA57BC57BD84A08B76949D83B96BB17365E153BD759CBB37A194C5
8E7884987D9E8F937D9B9198A48758D567B3845FDA6492A741E667B1807DA3AF8357B78C
98A7699A63BEB44893C47191AD8F647ACE8566C080AE4795B0929D9B798A9F8A81A967AD
86A1898CA75BC56999A58A6995AE9194848C967E
B46CAC80AC48CF7285CB55C04FC1869B8B75949B89B073AF7561E056BC749FBA34A395C5
8F768198809C938D839B8F9AA08759D46BB1845ED9698CA743E965B1827CA3AC8957B28E
9BA36F9566BBB34D92C56D94AB8F6879CB8865C27FAE4895AD9796A07C87A08882AA66AB
8B9F8A8CA759CA5DA3A2876C95AE919781879E7A
B667B57FAD44CC7685CC53C24BC48D93907394988FAA7AAB765DE454BF759BB932A794C3
8F79809A7F9C938A8797929D9A885CD16DB1855BD87086A940EE64AF827AA4AF8657AF92
98A4719568B5AF5791BE6E98AA916775D18366BE87AD4397AB9893A27B8B9B907BAF64AB
8E9A8D85AC59CE51B397877390B0909781899B7A
B563BA7CAA51C07B85CC52C447C693889473949991A682A4795CE553BE7896BD33A495C1
90797E9D7F9C91898C91979B998A5AD072A78F56D67286AA3CF166AE80829EAE845EA49C
95A2788D6FB0AC658CB27796AB926675D57C6CB393AC4392AB9A93A07E8B97917AB067A6
909E8887AD5ACF46BF91857B8FAE9096838C977C
B460BF7AA758BA7C86CB52C843C49F789A73949A949E8B9E7C5AE751BC7F92BD35A494C3
9176809B7F9F8F86938A9C9A978F53D077A1925BCD7A82AD37F764AD7F7FA2B27D629DA2
97A07F8078ABA8718CA18197A8986574CE846CA99EAC4789AF97989E7C9091957DAB709B
98988B8AA660CA3ECF8B837F8FA696918D81997E
B25CC477A660B38482C758C444C1A96F9D6F9A97979894967E5CE650BB8491BA39A096C0
9473829B7E9E91869485A596959254CD79A38D62C48080AA38FA63AA838199BC766A90A6
9D9D837880A3A97E8593928FAD966479CA80769AA7AF4980B0979B9B7A968A977FA77C8D
9E968F879D70C03DD9848184929C999190819A7E
B05DC674A267B08285C261BB4ABEB063A56E99939C939991805DE54FBB8593B53E9C96C0
9572869A7E9D91879184AA91979451CF77A78869B78B81A636FD62A5888495BB777088A6
A696877380A4AC857D889F8DAF92657CCD797D8DAFAF5272B5989A9E7598889B80A28785
9C96918A967FAF41E27C82888F9B9A8B9A7F9682
A65FCA70A06CB07F89BB6AAF53BAB35EA67197959C8FA08B8161E051BA829CAD44939BC2
956E89997D9D94868D89A88F9A954BD771AD846EA996829F3CFC62A18A8A8EB9806A8BA0
B18B966482A5B287708AA58EAE8B6D7EC8758585B2AE5F65B69C97A079948699869D8C83
9B95948B8C8CA147E878838891959A8C9A819687
9D63CF6C9F69B77D8AB86CA95CB5B85AA6798E969C919F8C8162DC53BB81A3A44A8C9EC5
937088977E9E9585888DAC8A9A934CDC6DB27F739DA37E9A42FB639C8E8B87BA8A609396
BD809C6285A2B58B6391A492AB887281BE7C8487B0A86A5EB5A18FA57895839C859D8E83
9698958E82949B4FE7797E89938DA18B9783968D
9567D16A9D6CBB7A8DB3709F68ADB563A180839D9B909F8E7E67D755BB7CAC9E4F85A3C3
92718B947E9B9A838592AD88999151DE65B97C7398AA838D4CF4689692937AB4A14F9A8F
C47C9D6582A6B19151A69F8EAF817584B4858286B2A0735EB1A38AA97B90859B859D8B85
939D92927D979A53E37B7F889589A589918C968F
8C6BD6679772BB7891A9799774A3B6689F82809F9A9597937B6BD456BC77B29B5183A3C3
8D7A898F819E97828793AC879A8E52E25EBF7B768FAF898451F26B8F949876A8B73FA28A
C67AA0657FAAAD9643BA9590AC7F837BB08A818AB0967B63AAA48BA77D8F8A97869B8890
8AA08E9B79989954E17D7E86968AA982928D9693
806FDA689179BC7596A07E937B9CB76D9A837EA5949A9099796BD851C172B899517EA9C0
8E7B888C82A196818892AC869B8C55E35AC2787C86B0907E57EA7489959E6FA2CC2AAD89
C27EA06584A5A99D37C98E8FA8848A74A9947A8FB0917D6CA0A293A08293849B839C8297
899F8DA26F9C9B55DB847C839788A985908E9A95
7777D56D8A81B9749A98848F8096BA70988081A3969B899F756FD650C36EBC975086A2C0
8E7A868F839E99808990AF859D8A55E25AC477817EB0977A5EDB80819B9F6D9ADC21AE8A
BC84977081A59EAA2CD58B89A68F886EA69F7393AE917D719AA0999E809681A17F9B8298
86A189A96A9D9B54DA877C809A8AA686928B9B97
6D7CD2758187B96FA18E8F888692B87698788B9E979A89A37075D151C667C2984C8BA0BF
927587928297A27C8C8FAC889B8E51E35AC2788478B19F7366CD8C789FA16998E419B589
B38E957579AB94B525E0808DA1978B66A2A87190AF987673989C9F9F809185A08496819C
85A187AB6C9C9854DE81827B998EA78296899F98
6683CF77808AB570A38596868695B973996F9799959E88A36D7BCD51C764C2994B8C9FBE
937688947F989F7C8F8DAA8B9A914CE65DBB79896FB3A3736BC29374A2A0679AE617B986
AA99917B74A991BD1FE775939A9F905D9EB06D91AC9E7372979E9F9F7F8E899F86967D9F
82A782AB72959C53DC82817A9A939F879A819F9E
5D8ACB797E8DB36CA98397848899B27698709995979C8AA26C7BCD4FCA63C2984A8E9DC0
9B6B8B977C97A37A8F8CAC8A9B9544EA5EB87B8B69B5A87270BA9576A1A1649FE117BF87
9DA28C8272A58FC819E8729994A58A5C9CBC6295ABA2756A9AA19BA182878C9E89977B97
8AA982A5788EA058D088847699949E8A9A7CA3A1
5890C8797F8FB169AE7E9A808B9EAA7D93719C90979D8DA06C7FC84FCB64BA9F47939EB8
A1698D96799B9E7D8F8BAB8D979742EC5EB67F8B65B7AB6D77B1947D9EA260A9D71DC089
91AE80916BA18ED312EC6B9D92A9895B97C66095A6A57B609DA596A58778979B8E94808E
91AB7EA38282A65BC98A86739A989B8D997B9FA8
5491C878808EB269AE799C828AA59F839174999095A18D9E6F80C450CC6AAEA94394A5A9
AB688F917B9A9F7C908AAD8E939E3CEE5FB3818B62B9AD6B77B18F8599A35CB3CD25BA8D
87BC749B679C91DD10E769A28FA88B5995CB5D989EA88156A3A692A58D6AA494928D8C7D
9FA77CA28975B25ABD928970989D9C879F76A0AC
5392C678818DB26EAB789D808BAA98878C7A959692A387A07083C04FCD6FA5AC439AA4A1
B067928C809B9A7F908AB089959E3AF15DB6808E5EBAAD6C77B08B9094A15DB8C62FAE98
7CC966A2699298E20BE3709F90A58C5A93D2569D96A88D4AA7A792A29365A990948B9473
A7A180A38772B75DAF9D876F98A09787A471A0AE
4D95C67A7F8FB26BAD7A997C90AF8E8E897E909792A77FA77180BE4DCE739EB2419CA69C
B5648E8E87959C7E8F8BB189959C3BF45AB77E915CB9AE6E78AC8A978FA15FB8C039A2A4
72D45CA471869EEA06DE74A08EA68E5796D6529D8EAA9841A9A792A19666A691918C986D
B0958C9B8874B7619FA9896D989D9A86A969A6AF
4D95C57A7F8FB070AA79987D90B4859585818D9A91A67CAC7482B550CE7997B93D9EAA94
B5698D8A8C909B838D8CAF87949E3CF35AB57F925EB6AF7079A29396909C66B3BE4094AF
6FDD52A6747F9EF303DA789D8DA7905398D754988AADA23AAAA6939F9A699E978B8D9874
AF8E929A8673BB6590B2896E94A49387AB69A0B4
5092C57B828DB075A578997F90B97B9B84828A9D8FAB72B47284AD56C97E94BB3AA0A599
B06C8C8A9485A0828E8CAF86969F3AF25EB27D9360B2B1717B9A9896939171AFB64D86BA
6DE14E9F7B7B9DFA02D7779D8CAA90529CD655918BB0A538A7A6939F9C72909C87909477
B1839F978079BC6882BC887091A78D8CA9699FB5
588CC67B828CAF76A47B987899B578A181828B9E8DAD6BBD6D88AB5AC18296BA3D9CA59F
A872898B95849E82908BB083989E3CF060B37B9364B0AD757D939E9695897FA8AF5580C0
6CE34B9B85759BFE00D9749F8BAA9051A0D25D8393ADA93AA0A690A59F7483A584958B81
AB7FAC917984B07377C584798AAB8892A4699FB3
5C89C57C8389B075A27E97779FAF76A8827A919C8BB267C16D83AC5FBA8792BF3A99AB9B
A57A858A9385A280928AAF86989A42EA63B27C9168ABB1757E8FA096978289A3AA5A7EC3
6DE34994927094FF00D575A18AAC8F4FA5CC6476A3A2AE4394A691A2A7757AAF7E998484
AC79B48F7983AB8464CB877A83B282999F6998B8
5E88C67E8086B3799F7A9A799EAC76A7817B98968CB168C06F82A966B28C8EC1379DAB95
A48284889087A4809289AF84999A46E16BAD808D6BA6B6727F8D9F9A997A929DA66079C6
6FE24C8E93748EFF03CC7D9C8DAB8E50A8C27266B198B9448AAA8FA1AD7377B184918686
A979B3937786A48E5ECE80827AB97E9F9B6E91BB
5F87C57F7E86B7779E7B9A7B9FA77CA68270A49488B761C66C83A769AD8F8CC4369FAD8F
A48A808A8A8BA67D9484B387949A4CD573AB85896FA1BA7381899EA093759C99A36576C6
76D5578798778BFF08C87D9A90AB8D52ACB8795FBC8BBE4D7DAE90A0AB737BA7908B8D7E
AD74B4937D839F945CD07A8E6FBE7AA6956F91BC
5C8BC4847687B8769F7D957CA49E82A6826AAC9187B85FC96A84A869AA9288C9359CB385
A88F7C8E8095A47C9681B784929858C774AA8F7E799AB975808C9EA19173A292A66874BE
85C463809A7A88FF0BC2839792AB8A52B0AF7E64B68BC15279AD939EA971869A9B84927C
AA76B2977D83989D5BD2729766C17DA3927192BB
5A8EC2867987B3769F7D93839EA081A78565B28E88B662C96983A966A99884CC32A1B37B
AE937890789E9D80977DBB82968E6AB67CA2A06F858EC171828B9CA29173A58BA96B72B8
97AF717D947F86FF0EBC879296AC8955AFA87D72AA8AC45B70AD99989F7B8E8CA67E9B72
B176A4A4827A98A15AD36AA05EC384A08F788BBF
5392C386758AB372A57994839DA480A58568B3898BB661CA658BA563AA9885CF309FB378
B197759175A695849A7BBB80998876A98595B55D9385C570828B9DA29173AB7EB0716AB2
A99A7D7D8B8984FF12B78B8D99AE8558B2A17C85929BB8636CB09A9C91829580AB7AA766
B57D99A7857C939B68D061A75DBE8C9C8B7D8EBF
5393C2867888B073A28091859CA281A68564B7888AB860C66394A261AB9786D030A0B076
B596758F72B08B879C78B7829D8084969586CA49A081C0737E909EA18E75B071B87469A9
B989857C8A8B87FF13B48D8B9AB0805FAF9F759B79ABA7706AAE9C9C8A879C78A582AC5B
B8868AAF867A949873C662A85DBC94908A858BBF
5293C3887885A97D99898D8698A780A3836DB6808CB865C264979D64A89887D1349FAA76
B996768A74B288899E7AAD84A672928C9D7BD83FA882B57A76999B9F8D7BAE6CBE7667A3
C185857B8D898BFF0FB68F8B9AB27967A7A372A963C196756EAC9AA18786A7719F8AA760
AF957FAE887E8D9880B768A360BA9A87928788BF
5793BE877D84A2888D958A8791AB85988473B97B90B663C16998966AA59889CF35A69F7A
B898798079B68689A178A589AE64A37FA56CE836AB87AC83709A9D9C8C81AA6BC07868A4
BC87847E8E8690FC0FB3958A9DB171739EA66FB357C88C7E6DA89BA28587AC739491A363
AA9E7BA7927B8C968CAA709A6CB29E7F9A858ABB
5895BC897D849897829E898591AB8E8C8375C3758EB660C26B9A906EA49688D235A69A7F
B9957F757BB99081A4799A91B05EAC77A963F52DAC919994679F9E9C8689A36BC27B65A8
B090827F8D8597F411AE9D85A2B3687A97AB70B54FD2858070A29EA18686B36B9499996E
9FA280A2927D8B94939C808C7BA99F78A2858EB6
5E91BD887F8293A078AA83888BAB96878174CA758BB363C16F9A8C729F9985D636A99480
BD8F846D82B3997DA57D8B9DB257B471AC5CFC2CAC9987A55FA29B9D83919B6FC27969AC
A397838488829DEE10ADA57FA6B45F858BB46EB84CCE8A807299A39F8885B667939E8F7F
95A083A09774949191978E7F85A49E74AE7F8DB2
668CC1848085909F79AE80868BAB9A857B79CC758AAF63C670988A759B9C83D934AA957A
C48D866688AEA377A48082A5B054BA71A460FB2BAC9F7BB258A39A9B829B8B79C47766B1
979D868781879EE912ACA97EA7B55A8C81BB6DB84EC890827092A8A18684B864959F878E
8C998EA0947590968B97987295959F76B37B8EAE
6B88C57D848791977FAD81838FA79D877679CF7A86AB64C772978B76979E83DB2FAE9573
CE8686638BADA974A2847BACAF56B873A45FFE28AAA571BA53A9989B81A47D80C57667B5
8AA18D8877909AE913A7AF7BAAB1599178C369BB55BA9987698FADA08782B36C959A8895
8A9191A693758E9B7CA29A68A487A676B07B8FAC
7181CF74858B918E8BA6848390A699906F79D07C83A969C66F998A7891A181DF2FA99A6F
D680885F92A6B26F9B9071B2AD5AAD7AA361FA2CA9A76DBC4EB1939A7FAF7483C67568B3
86A2938A6AA18FEB14A6B07AACAE5B9173CB67B65CB29C8E5E93ADA18A81AC7194998997
8B8C8EAE8F788BA369AE9F62A783A67EA87F91A6
757DD46F8093988095A182888EA499946C79CE7C87A969C66E99897C8CA482E02FA49B71
D2818D5D979DB472929D64B8B15AA281A362F332A7A474B551B58D9D7BBA698BC6706DAC
86A2978962B182EE15A4B07CA9AD5E9270CA6BB366A89998519CABA28B80A27E8F958C9F
858F86AE957D85AA55C39863A381A9879D8097A0
777AD76C7F9B96789E9A818F8CA69693697DCB7C8EA26AC96A9C858087A884DE2EA39978
CA848F5A9E98B5738AA561B7B65A9A87A269EA38A1A579AE55B48D9A78C55C97C1706CAC
82A7988C54C378F015A5AD80A4AE648D6ECE6DA970A494A343A9A4A68B83938E8B948E9F
81967BB3938378BB42D58B6B9F80AB918C889B9B
7978D86D7CA19476A19680978BA096946B7EC97E8E9F6FC56A9F818582A986DB339F9A7B
C5879155A890B87385A962B3BD5A928CA36AE24296A87FA95BB2899E75C75E9FB27967AE
7FAB969345D470F015A7AC80A5AD678B6DD26F9F78A38FAC36B69DA98E7F8D9988918FA4
79A06FB29B837ABD34E47F778E8EA6987E8DA196
7B77D76F78A59373A5947D9F879F9590707FC67D91A169CB66A37D887EAC88D8379A9783
C0879551B185BE7181AC64AEC15B8D8FA26FD74E8DA888A163AC87A075CA5CA6A48261B1
7DB1939A34E36CEC19A4AD7DA5AF688A6CD177977DA48AB12DC096AA927D8B9E849190A3
79A661BD988378C232E67D7D809CA19B7598A28E
7877D77274A69571A49878A3889B998C737DC97A8FA464D262A57C8A7AAF8AD33A9B9288
BC8B9352B57DC1757BAA6BABC25D88949F74CD5C7FAA92996FA086A375CB57AE978D5BB8
76B3939F28EB6FE320A4AC7DA4B368876BCD7E9380A08BB22AC691AB937A8D9F82928EA4
76AF56BE9D847AC034E17D876FAA9F97739E9E92
7678D87176A39571A5977AA28D969A8B7481C77B8DA664CE68A4788C77B18ECC40998F8B
BD899354B57AC2757AA579A2BF6582979D78C46971B196917C928CA279C857B3899D4DC4
71B797972AEC72DE20A5AC7EA4B36C816BD6798E869C8DB22BC78EAB957B8DA37B93909F
7BAD54C59C7C83B841D1828C68B1999379A1949A
747AD57276A19574A3997D97978E9B8B7A7FC77B89AB68BF70A5788E78AC92C847938E8F
BC8A9159B07BC1757B9E8B98B96F7D9A9C78BE7269B59A888985929F7DC459B67EAC44C3
74B8959729E878DB20A6A980A7B16A806FD07F8A8C9492B02EC391A59B7990A27E8D8F9E
7EAB58C4A1718DB04EB8968B61BB968386A48AA2
6F7DD37477A19277A29D7F9199929B867D7CC77A88B067B871A7778E79AC96C24B908999
B5899262A67DC1737F979C8BB5757B9E9A74BA7E65B39E8192789F9682C457B776B93FC3
73BA98952AE081D920A8A684A4B26B7C74CA8387909097AA38B9959F9E7E8DA4808A9195
8AA162BCAA6C8AB05C9EAA8864B3987C95A281A9
6880D1747AA08F7D98A37F8C9F919D837E7AC9788CAF6FA976A975907BA69FBB52888AA1
AA8E96649E83C06D8692A980B27C7B9D996EBD8366ADA57A9A6BAC8F85BD5DB46FCA34C2
7AB796962DD78DD51FA8A4889EB669787BC28784958A9EA63EAF9D9B9F8289A5808A8C95
8E9578A9B26B8BAD628DB88869A89A7AA29B77B6
6882CF757AA08D7F94A97D87A097987D867DC37B8BAD79997BAE70927D9EAAB4567F8EA8
A08F9A679786C164938AB473B3807F979B69BE8767A9A7789F5EBD8888B762B06FD629BD
85B3969330D193D51DA6A68C98B96A7582C184809C86A2A144A7A594A28488A4808B8C93
918E8A9CB27184AE6A85B98977949E7AAA966FBD
6882D0747D9E8F7C90B17E809DA293798B7DBF828AA8848C7BB46E938097B4AE587C92AA
9C9297699783C65A9F85BA69B286848E9D69BD8D6BA2A67C9E53CF8187AE6DA971DC23B8
91AC929E27CE9ED11DA7A88A96B9697686BB8A7BA184A49C489FAE8EA58687A2818F8992
8F90928EB27F76B46A84BA8A7F87A37CA8976EBD
6980D2747B9E8F7A90B7798696A88E7C887EBE8586A8878D78B66D928196B7AA5A7896AC
9B8E9B689581CC50AC81B862B58B8883A06EB6966D9BA382994FDA7D89A378A273E31BB9
9BA2929C2CC6A7CE1DA5AD8796B86A7684BD8978A286A5974F98B28CA4888A9C7E968695
8A919B81AB9371AE6C89B588897AA589A39270BB
6D80D1757B9C927A8DBB778397AC8B7D8A82B78686A28D8D7AB46D918791B9A959769BAD
998D9C669481D04BB382B064B88D8977A872AE9A6E9B9D8A954FE1798F94889480E217B4
AA9890A12EBEAECB1FA0B5809BB66A7785BD8B76A387A2974F97B38DA18B8F927E9C849C
80989E7CA29D73A86E91AC878B7BA49195976BBD
6E82CD7C769C907A91BB788192B18A7B8E84AF8D82A2908C7AB26F8D8A90B9AB5773A1AD
968E99699180D24AB981A668BC8D8A6EAD7AA59C719C8E998B53E6719688968887E01BAB
B6908CA831B7B0CD1F9DB97BA0B16C7783C28B73A38C9C985395B38F9B8F968A7C9E869E
76A2967EA69A769F7499A7838B7FA4988B9A6BBC
6C86C680779A8D7E92B9788292AF8D7C8D83AC92829F928E79AB758B8F8FB5AD5872A4AB
978B9C6B8A84D248BE7E9E71B8918A67B47E9F9C74A07BAB8358E7679D83A07D8FDD20A0
C2858BB133ABB5D11B9AC074A7AC6E787FC3906FA48F96995793B193949499857C9E8CA0
71A29183A69482937999AA7E8589A19C849972B8
6D88C483749B88888DBB738496A8907D8D82AB937EA1919673A67C859491AFAF5B6EA7A9
9889A06B8487D249C07F9181B3928864BA809B9A76A56EB97B61DF65A67CA57595DD2594
CD7B8CB6389EB7D91C90C470ACAA6F7A7BC58E72A09595955995B09490959D807E9B91A0
71A18F84AC8592877F9BA9797F979E9B839872B9
7285C282799C87898BBC748098AB8C799382A9967AA09598719F84839690ACAD606BAAA6
9788A66A7D87DA4ABB808693AB928666BD7B9E9678AA61C87466D964AC7CA66C9ED83182
D9768FB73B95BBDB1F8CC46FADA8737A7BC68C739F9895905A96AF958E969F7E7E97979F
739C9089B0799882849FA47D74A09C9B809E72B4
787FC57D799E88888ABD757E99AD8F729585A49A7B9D979C699D8B7F9891A9AD636BACA2
9689AB6A7687E348B6817EA39F99826BB77E9C947BA75FD26F67D465AB849F6D9FD33B76
DD768EB84089C2DD1B90C06FAEA7757977CA87789B9A9A8B5B95B2938F959F7E81929C9E
749A8C8DB4759B7F83A1A47E70A79696879B7EA8
8576CF737C9D8D848ABC767D99B08C729189A29C7F979AA2609A97779B94A0AC6A6EA7A0
9787B0697188EB48B27F7AB1949E7F6FB57C9E9675A765D26F64D16CA88A9771A2CD4371
D97896B04B7CC5E01D8DBF70B0A5737D74CC857D969B9F7F6B8BB49191949F7D83909CA0
749A898CB37A9B80839EA0846FAB89998B99869E
8F69DB697F9D917A92B8768097B489778D8D9F99878CA4A15C98A16EA0969DA7716EA79E
958CAB6A7383F349AA8273BF8C9E7D76B078A19973A06FD26A66CC70A88C9370A7C44D73
C88597A85870CBDD1E93B771B2A66F8470CD82848D9EA3747983B58F95949B7F859195A7
71989085B7789E7C84A19F8273B07B9C91968C96
9561E1677F9C977199B3797F95B887768B939895967DACA05A96AB65A5959BA3776DA89A
948FA96A7580F849A48372C885A07C78AF73A2A16D9D76D26D63CB6FA88F946FA8BB5876
B597959E606AD1D5229AAD78B0A76B896DCF7E8C81A99D73847EB08F95949D7F85908FB0
6E929780B97C98818599A0857CA96EA69490988B
985EE4657F9D97709BB0798095B68A7A869A8F92A66FB2A05897B05CAA9595A6796EA996
9690A6697A7EF64CA28173CE7FA17F78A975A0AA669780D06C61C873A78F956FAAB45C80
A1A296986D60D5D21EA7A17FADAA64906ACE7A9B6EB695728E76B09193959B8384928BB6
6D8D997DBB819485898CA38984A168AF938A9D88
975FE566819B95709DAE788694B4887E84998C92A96CB2A25995B459AE9291AA786CAC90
9994A3677D81F051A08173D27C9E8477A576A1B2609583CC6E63C377A68E9571A7B16384
94A6A087795ED1D120A99B86A8AD62936AC97BA166C08B71A368AE92939798887F9588B8
7084A07CB9818C8D917CA9888F9566BB8E879B8B
9360E16B829B92729DB2708897B18783839B8696A86DB29E5D91B856B2908DAF7769B682
A2979E65837FEB569C8472D57B9B847B9E77A2B65E9386CA6E65BD7AA495946FA6B06687
8DA8A87C805ADAC91FB29387A6AF62916FC47BA366C48373A966AD8F9699948B7E938CB3
7678AC7BB3888B8A9870AF88958772BC888A9C8C
8D66DC70809C8E7994B9708796B18881849D7E9DA573AD9E6190BB52B38D89B7746BB67C
A69B9D5F8C7CE360928C72D37B998582938198C05A928AC66F66B7839D9892779CB16687
92A0B36E8755E6C01EBC878EA3B0648F76B9819F6BC48072AF63B0889C9896897D9193AF
7A6EB180AD8A84949C62B18F977B7DBD818E9891
876CD376819B8A7F8FBB6C8F92B0868480A078A49E7AAB9C658EBB53B38D85BC746CB771
AF9D9A5D917ED86B869178CC80908C8A878893C358958EBF7067B18E93A08B7D95B46684
9997BE64914DEEBB18C77F8FA1B3648B84A1929775B88475B25DB185A296938E7B8D9AAB
7B6EB086A6908394A05BB48D977A82BD7E938F9A
8070CE7D7F978A848CBC6A9490AD88877BA871A89B7EA79A688CBC53B38885BD786EB468
B8A49060957CD077779B7ACA8388918E7F8E8DC8559894B47768A9998CA38B828DB86683
9E8ECA58964BF2B71ACA79939EB5658690919F8884AE857EAD5EAC85A79390927B8A9CA9
7B6EB0889F938592A259B48C967B87B87D978AA0
7B75C8857D9589868CB96C978BAA869673AA6CAAA17AA7996A89C052B18A85B97F6CB162
BDA988669A78C7846BA37AC7857D999279948ACA509999AE7C67A39F88A6858B88B66585
A089D2579449F7B219D172959EB76683968BA18688AA8190996AA685AC8E92927C8B98AA
7A73AC8A9F908D8BA559B190947A8BB57E968F9F
7B74C6887E92898A89B573988AA4849D6FAA6EA7A974A7966D8BC153AC8C85B8856CAC64
BCAE7E6F9979BD9260AA7BC58677A58C759885CF4B9B9BA881689BA785A97F9582B36985
9D8AD850954CF4B315DC68999BB96A7F968BA18685AC7AA586719E8BAD89988C838B93AC
7879A88D9D8C908BA25CAE8F977C86B28492929E
7C72C58A7F8F8A8B8BB178988C9E82A46CAC6FA1AD76A4946E8EBC58A79280B98A67AA63
BDB4727D8F80B09E5DA87DC58672AD85769A86D045A09BA3876697AD80B0749E7EB26D85
978DDB4E9552E6BB14E0649A98BE6B7995909E8984AE6FBC74779595AA879C8294848FAD
74889C929C87928CA15EAB90997B85B08793939D
7D72CA867F8E8D888BAD80928E9B7FAC6DA275A5A97A9D976A93B95DA19380BB8E67A36C
B4BC68888887A0A95FA57EC5866FB181779C85D5409F9EA08A6692AF80B56DA47CAE7187
8F91DF4C9453DEC410E65F9C98BC70778F9C938F7EB661CD697A929CA787A0779E858DAA
729095979983968AA460AB8F9D7788AB8A91969A
7C74CB83818F8C868DAC828E96947EB17092889FA584949A6993BC5F989781BD8D64A274
A8C75F937F9190B0679E83BD8872AE81799989D43FA09CA2886693AD7FBC65AA78B07288
8799DE4C9450DDC60EEC5A9A9CB975728BA98D927BB957D96379949EA782A473A38789AB
6E9597949D7E948EA65DAC8E9C7984AB8C90959A
7876CF7C858D8E878CAB8783A58D7DB0708F9295A0938A9C6796BE60919783BF8E639A83
9AD4559A799886B66D958BB58B79A8817A968CD63EA19AA18B6297AD7BC361AA77B46F8C
80A0DE459A50DBC90CF0529E9BB77A6C8AB08C8C7FB756DF5E7893A5A3839D78A48689A9
6B9B95939E799A8BA260AD90978185A4889C8D9E
707CD276878D8C898CAC8684A28E7FB46A8F9A8F98A183A06398BA668C9689BD8C63958F
8DDF4DA0739C82B2779092AA8E7D9F8A78948ED53EA09C9F8F5C9EAC78C462A975B7708E
78A6DB459E49E0C60EEF52A296B87A6A8DB3898982B750E65A7C8DACA28292889C898BA6
68A19392A077978BA85BB093908983A187A382A8
6783D471898E8A8B8BAF8484A08D81B96589A58995A77EA66099B96B879092BD8B61919A
81E848A3739986AB808B999D91839C8C78908FD73F9C9F9D915C9CAD76C366A774B86F8F
75ACD44A9E41ECBC13EF4EA993B3816490B5898682B553EB508487B3A1808A9790908BA3
68A49191A07A9586AC5BB1928B937FA086A67CAF
6284D56E8B90829189B37E879E8C84BA628AAC7D96AD79AA5E9BB571848F96BC8A5D8FA2
7CED43A872938FA4858AA19193879C8C798D92D4439A9C9E905D9DAD74C26AA474B6718E
77B1C8559F39FAAF17ED4EAF8FB4845D96B28F7B8DAB5EE74D8882B7A17D85A1899488A3
6AA4948BA47F8E88AD59B097829A7F9F86A975B5
6285D76B8D927D9487B8798C96937FBF5E90A87B97B078AA5D9FAD76829098B98B5E8AAB
75EE42AA718F959F8888A5869C839F8B788D92D542999D9F925F99B172C26AA476B3768B
76B7BB5E9E33FFA31CEB50B08AB7855A9CAD9177969E6BE04B8C80B7A17F82A686948B9C
73A48C91A1828A8BAC5CAB9C7BA27E9A88AA73B5
6584D86A8D97769589BD6F978B977FBF608BAE7A95AF78A95FA2A47A80929BBA885D88AF
74E847AF6D899D9B8C88A779A6829F897E8991D542999D9C936293B372C26BA575AE7D85
7BB9AD6E9B2CFF9324E658AC89B9825B9FAE8B7A9A9278D84A9184AFA57D84A6878F8E99
79A08E939A8C7F91AB5FA69C7AA67D9691A472B6
6883D7698F97719A89BE6A9A8C9582BA6387B27E90AD7BAA60A59E7C7F9599BD875C83B7
71E44CAF6F81A19F8D83AB6FB080A28481888ED647999C99956296B174C367A775AD7D82
81BCA179982AFF862AE35DA88BB9815BA1B0877C9C8B89C64B948EA3A97B89A28C898E97
829B8F92988E799CA563A09E7B9E86998F9E7AAF
6D80D7698F9676948BBD6B978D9686B66486B47E92AA7DA565A59A7D7B9D93BD895A82BC
70DC56AE6E7EA1A08F7EAF67B97DA08483878CD64A999A949C5C9CAC76C266A972B07B85
82BD98819828FF7E2FDC66A28BBD7C5E9DAE8D7F988892B654909999AA7D8AA28D858E97
85999290998D74AA9C659FA17A959394919E72B4
6E81D46990927D8E8CBD6F94909288B76288B57996A880A167A8967E7AA48FBC885B82C2
6AD760AA6C7DA49F947BAF64BD809C82888788DC4795A28DA355A4A777C463AD6CB57886
83BE92829B27FF7A31D86E9E8BBF7A6194B98B848F8E94AC5692A48FAC7C8BA18E819196
8A949591968974B1976A9C9E7F919890919D77B1
6884D26A909080908BBB728E988A91AE6683BD7696A67FA368AA927E78AA8CBA8C5783C6
68D06AA86A7CA69B9A78AE65BA849B7E8A8A84DF4890A18FA554AA9D7CC362AF67BC7485
88BC91829B2AFF7733D4769C88C178648AC7828B88968FA95499A68AAD7C8E9B927D9495
86999290998B6FB78F6CA09A8589A18E919A77B6
618ACB718F8E80928AB97885A1849AA46786BB7699A282A662AD907F76B08CB2915386C9
64CC71A5697CA895A178AA6AB6869C7A8A917FE1498E97A3915CB3947FC063B066BF7284
87BE90809B2EFF7934CF799E87BE7B6584CE7C9281A087A5579CA290AB7695969180968F
8B99918F9E8A67C3876E9F9C87839E978D957ABA
5890C5798B8D838E89BA7D79A7859D9D688FBA6CA09F82AA5EAE917D74B58CAD92548AC7
63C87BA1677FA98EA875A96DB2889D768D9779E3488F8FB08665B0917FC067AE67BE7480
8BBD8C85992FFF7A35CD7BA085BD7D6482D178987BA77BAD579E9E99A5739F8896839690
859C8D949D8B61CA8370A09A858C9892939577C0
5396BE808B8B7E9686B97E77AA81A297659EB369A09D83B059AD927E74B491A9915788C8
63C3839A6782A989AF74A670AC909B728E9E78E04A8E89B87F6DAC8E81C069AC6ABC7878
8EBF8A859A30FF7A34CF7E9E84BD7D6286D963A07EAC71B64EA49BA0A16DA87D9C849A8A
899A8C98998E5ECD7E739E9B84948E95959181BA
4E99B98889877E9C84B78273AA80AD8C64A7B06A9D9D83B558AA977F6EB497A78F5788C8
68B98B996485A785B670A573A99695758BA378D84F927DC07C75A98E82BF6BA66DBD7A72
94BE878B9336FF7A33D37B9E85BB7E608CDE52A682AF65C546A897A89C68B272A0859A8B
87988C9A999157D278779E9E84938B959C8981BF
5699B38D8882859A85B58470A18BAD8965AAAE669F9A86B852AA99806BB49BA68C5C83CA
6BB590936487A880BB6EA275A79F8E778AA579D1549778BF787CA59080C16BA074B97D6F
97BD848F9038FF7831DB769F89B5805E93DB4DA685AB63D03EA897B09663BC69A08B9989
8C92929B958F5BD1787B99A182948D8FA3887FBA
599AB18D86808C9C81AC8E749596A58A65AFB15E9E9D83BA54AA987F6AB39DA58D5D7ECE
70A99B8A6789A97DBF6C9F7A9EAA847F85A47EC95A977CAF867B9C957EC7689E75B87E6C
9DB885919232FF7B2EE0739E89B5815C95D850A588A662DD37A498B19561C35FA18F988D
878D999D8E9061C97A7E99A17E969387A98484B4
5E9EA98E867D929B82A5937A8C9AA58F60ACB4609BA181B958A894836BAFA4A08F5B7FD0
769FA187668EA979C0709A8194B8738C81A085C35F947FAA897D9A967DCA639D76B97E6B
A1B5878C9A2CFF822CDF749B8DB1845C9ACB5C9E8E9D63E33D999AB19660C4609F8D9D8E
858A99A2879566C079809BA478959588A98388AD
60A49D93847D9699879D977E889E9B9464A3BB5B9DA281B75AA991836CB1A69B915B7DD3
7893A8876193AC74BF74948B8EC16395819D86C2619380AA838498987CCC629E75B78269
A6B08A889E29FF8333D3769896A88A599FC06993979466E641919CB3965FC7609C8E9E93
80899CA3849A63BD77859E9F75949D85A88587AD
62A99498818395968A979B8384A09498689EBC5D9BA57EB95BA7918170B1A697925A7ED4
788FAC876192B06DC276909086C95B9B7F9E85C2638F87AB788D94997CCA659D76B28369
A9AB9082A127FF823AC47F959DA08C5BA2B9718BA08B6AE44A869FB5945EC466988FA191
7F8C91AD7F9B65BC758C9EA16A94A18AA18A8BA5
5EAC8E9D7E8595978892A386839D919C639FBE6097A87CB75EA3957E73B0A49A925684D3
7A88AE896192B06CC3788E9284C95E99819A85C2658C88B17091969482C16C9C76B18369
ABA69581A025FF8740B18B949E9B8F5BA2B57686A6866AE3547E9EB9935EBC6E988BA791
7D8F86B77E9F62BB7190A29D6692A38F9D8A90A4
62AA8E9C818592978992A288809E90A0619BBE6498A67DB95D9E9C7D73AFA0A08F5489CE
7B8BAB8C5F93B06DC37693898EC36096839C82C564898AB66995998F8AB4789579B57C6F
A8A49C7F9D2AFF8647A29596A291935CA6B1787FAF836CE0557AA2BF8C61B3799787A691
809576C1809B66B96B98A298688DA88F98928BA3
68A793998383909B8790A58980A086A66498BD659AA57DB75C9CA47974B099A7905487CC
7C8FA68D6290AF70C471978398BA6591849F80C760898DB9609B988A93A6858C7DBA7474
A2A5A17E992BFF844A999B99A388965BA4BB717FAF8672D84E80A4C58266AA82938DA290
82976FC487906CB967A19E936D88AF8B979589A0
6D9EA08F84858E9F7F96A28C7DA183AD6197B9699BA778B75C99AE7474B093AE8F5386CA
799D9A91668AAE73C66E9B7AA3AF708C85A07ECA5D8491BF5A9D99869D97928284BE6582
98A3A97C992DFF88439D9C9FA280965E9DC86588A3917AC74E84A8C87A66AB878D929A96
849867C78C8479B563AA9B8D7184B48895978D9B
739B9B928682919F7A9C9B8E80A479B75B9BB666A2A478B45D98B47078AA8FB88C5383CC
74AD89966787AC7BC06C9E74ACA77789879F7BD1578591C45798A081A68A9B7B8DC15791
8BA3B3759B2FFF8A4398A0A1A37B966490D45E91959D83AD5B86A7C97468B2858D91949C
839965C6927D81B45CAE9B877688B580969A8A9C
799D91968A7E93A077A2938D8A9E73C1589FAD69A5A179B45F94B86C7FA68BBE8C5285C6
72BF789D6982AF7FBC69A66AB7A4728D869F7AD94F8594C55595A57CAB82A17594C747A0
81A3BD69A12EFF894692A3A3A678936B86D95D9295A0908E7181A7CB6B6FB3878A9688A4
7F9C64C693728AB953B69883788CB47E949F8B96
7CA381A18979989F75A88B899B946CCB52A6A56DA2A47AB25E96B96B82A289C18C5385C3
6ED165A56A7BB083B56EA569B7A4728B8B997CDE498696C75392AD75B17AA6709BCB3EA7
7CA1C65EA62DFF88478EA8A1A9788C7380D8638E999C987D7C899DCC627FA9898C9A7DAE
7AA065C1956F8CC14AB9967F7D8EB07E97A0829B
7DA575AD87769C9C74AD8782AA8D69CF4FAA9F71A3A279B55B96B96A84A185C48C5387BE
6AE253B26876B287AF6FA866B5A5768691957BE3448797C4588BB771B075A96C9FD035AB
8196D254A92EFF844A88AE9EAA78897880D06D879D9B9682759295CC6188A485909976B5
77A667BA956D90C842B9997A858AAC8497A079A2
7EAA6ABA81749F9D73AD8B77BA8866CB55AA9F70A2A27DB35A9AB66D869D82C88A5589B8
69EE46BA6971B388AF70AA66B0A9768394907FE0418C97C05B89C06BAE73AA68A1D531AA
888CDC4DA92CFF79507FB699AB7E837B84C07E7BAA8E9789769490CC61949A8295947BAE
7DA46CB2986994CD3DB59D768A90A189999B7BA0
7DAB6EB87D769DA26FA9936DC6806AC75AA69E739FA57CB4569DB46E869F7EC690558DB0
69F442BC696DB389B16EAE67A9AF7583978A87DA419294BE5C8DC368AB75AB699EDB2FA4
9582E345AD26FF6D4E89B196AC81807995A7916DB97CA38872988CCE5C9E947D9A94849D
85A179A4996A95D13DACA4719289A28A9F90869A
7CAA77B5777B99A86CA49A68CB7C70C25BA39F73A1A67DB153A2B27082A27DC391598AAF
69F73EBF686EB089B36EAE6AA0B46C8E96868AD5419395BC5F8CC36AA479A96A9BDD309E
9F79E742AE27FF6B4995AD91AA887D73A9909F68B976A88F64A48BC95DA3957698949089
91998B939C6E93D241A1AB7391889F929E86899A
7DA87EB0777C99A96BA29F63CC7B74BD5EA1A074A3A679B256A3AE7182A27DC3915B89AE
6AF43EC3666FAE8AB56BB16C9DB7669693858CD2419796B6648BC0729882A66B98E22E9A
AB70E941B02AFF6D44A1A98EA78E7C6DB980A56CB076AF8A669F93C162A09D7492959A7A
97959A8A9C718DD34996B0788B91949A9F7A9793
84A482AC758098A96AA49C65CB7879B9629DA074A5A679B057A7A97482A17CC58E5E87AF
6AF340C26670AF86B76BB268A1B95CA48B8491CE409B95B76489BC7B8F8AA16F95E32B99
B26AEA41AF2CFF6C3EB09E8EA695766FBF7AA570B071BE707C9698BE61A09B7D8A999E71
9A93A0869A7985D64C8EB27D81A1859EA272A488
8BA182AC768198A76BA49B69C57A7ABC629B9E77A7A677B058A7AA7185A179C6905D87AF
6DF040C36572AE87B36FB364A5BA54B380878FD03C9E93B96885B7828A909E7191E7289B
B866E445AB35FF6040BB988DA4997271C473A573AC72C46189919DBD59AB8D8E7EA19E6C
99979D8796837AD95183B88477A67FA4A371A780
949C82AB7B7E98A271A6936FC17E75BE639E9D79A6A27BAC5AA6AB6F86A374CA8F5E87AF
6EEE3CC86276AA8BAC76B05FACB652BC758E89D53B9F92B76C80B38B84959D6D93DC3992
BD63DD4EA53EFF5942BE968DA29F6D71C772A27AA280BA5F8D919EBA58B678A374A19B71
98959E8A908B76D65877C08B66B870AAA273A779
9C987FAB807C97A072AD8D70BF836EC1669C9A7CA6A07CAA5DA4AB6F88A074CE8C6084B1
6CF138CC5E7DA38DAA7AAE60ACB35EB0719787D13EA58BB5727EAE91819B9F6C90DA3B91
C262D15B9A49FF4A46C3968DA09C6F73C8729B839D86B4599988A4B954BC6CAE769F9676
999399918E916FD75F6DC88E57C869A9A278A973
A4947CAD827D949D75AF8974BB876FBD669E997AA99E7EAA5E9FB26B89A370CE8D6185B2
68F633CD5E859991A97DAA62ABAC6BAC66A38AC248A880BA747EA89480A09A748AD44091
C466C6658D56FF3849CC908FA3996D72CB7198879991AB53A680A5BB53BD6DAB76A09576
9F8E949689966FD55E6ACD8E4FCC729EA37DA96C
A69379AF847A949D75AF8B71BC8A6DBD62A39B76AB9B82A56397BB648BA470CA906086B2
66FA2FCE5E8B9096A67FA869A6A37BA265AC88BB4DAF72C17480A4967FA7927D87C94695
C16EB4787D66FF2C4CD3918BA593716FD3699A889795AA4DAE7EA5BA52B977A378A19178
A38895998A9570CF616ECD9048CB7E96A17FAB6A
A99275AF897790A077B0886DC5886DBA5DAB9B74AE9486A56295BF618DA572C6916484B3
62FC2FCE5D918899A97BA671A2988B9669AE8EAA57B568C27781A2957AB4848C86B94E98
BA7C9F8B6A79FF2F4ADA8B8DAC87776DD56998889C8FB247B1809FBB5AAC88967EA18B81
A2819D968B9671CC5A7EC29345C8898EA27FAB6B
A99174AF8A788CA671B6876AC68971B45CAB9B72B58D8BA46291C55C90A373C4906785B1
5FFF30C95F958597AD7AA37AA090918F70AD939B68B160C77684A09178C1749C84B544A6
AC908B9D5591FF324ADA8E88BA72846DD06D9785A482B652A6849CBB5DA1978C7DA88287
A0829A988F8F75CD4C99AF924EBF9488A380A96C
A79176AE877F86A871BA816EC58579AB5EAD9E6FB5898FA46192C75794A373C1936687AC
63FE34C265948696AE75A4849A8D919370AA9C8A77AC61C8708D9F8C79C868A38CA548AF
99A87AA744A6FF344ED59083CA608C70C1799B7DA780B16492919BB86197A18B7BA87D91
9A889696938482CC3BB59C8F5BB99485A87DA96D
A58D7EAD80897DAA70C07C71C48579A963A7A270B38696A05E97C4539A9E77C091688BA5
68FB38BD69928895AD75A08F93908A927B9F9F8B76AA67C668969D897BCA62A19D944CBB
84BC6BB631BAFC335CC4987ED6558D7AB47FA074AE7CAE728494A0B365939C9377AC7997
929093919C7591C92BD2888E6AAD9289A97DA770
A18D85AC7D8F75AE70C77275C08978A56D9EA274B18795A25D9AC34FA19C76C08E6A909B
6FF53EB869948597AE73999E8C9481948693A98776A570C35FA29B877DC46A95AD8953BF
6FCF65BB22D2E8346CB59B7FD9568584AB84A170B27DA2837894A8AE60A28B9C78A87D97
9193938C9F68A4C11FE67D8C799B9C83AE7BA870
9A8D8CAC799171AD71CE687EB98E78A17893A478AC8F8FA25F97C44BA69878BE9166988E
78F142B26C97809EA87791AB86967C948E8AAB8A76A178C055AC998881B77780C07F5CBE
65D56DB619E3DA337DA49F82D55B7A8DAD809E77A88D94897593B0A65CB476A27F9E878F
95959289A061B3B91AF17989878E9D87AD7BA476
8D9291AD759270A978CF6281B68F7B9C7D8DA37CA89886A56198C04BAA967ABC94639F83
83E848AF6C9A7AA6A17B87B8829478979484AC8E6CA382BB4CB7968A87A58A6ECD7965BD
5ED277B015F2C831919C9A89C96C6796B37B9B809B9A907D8588B69F5EC363A58A939086
9F8C9D81A05DBFAE1FEF7D81908A978DAC7AA37E
829696AC768A78A27ECE6080B4957D958788A07DA99E7EAB6096C04CAC947ABA9761A47B
89E44AAF6A9E76AB9A837BC4829175969C80A79962A587B948BA978E88999561D3766EB8
61C981AC11FFB42FA097988EB97B589EC072938B93A29070957DBB9B5BD257A38F919580
A779AC7CA15BC99D2FE6877899809C8FAC76A483
779A99AB7A7E859885CA6280B395858891859A82A9A175B4618FC14CAD9577B8A05AA975
8EE050AC69A272AE978773CC848A7890A67DA39C5EA78AB548BB97918795985DD17875AE
70B78DA511FFA132A6999693AC7F5A9ACF6A8C9989A394669E77C19758DC549E968D9284
AD65BA7A9E5FCA9045CF9774967E9F92AD6FA689
6B9E9CA97B798F8F8BC26783AE91977698859485AA9980B75C8FBD51AC937AB3A655AB72
94DD50A86CA470AF96896DD08A7F8386B07C9AA15DA78FAF4ABD949489949666C47B7CA2
87A1969D16FF9236A89B9994A37A6C8BDA628AA27FA49962A273C68F5CD860959A8E8E87
B155C47B9C66C38C58C099758F89959DA770A492
689DA3A27E749A878EBD6B85A88FA6679C8A8D89A9918FB05E8FB855AB927CB3A357AB71
9AD653A56FA174AC978A67D48D7D837EBB7C94A25AAB91AB4CBC8E9A859A8E76B47E7C9F
9A8F979A1AFF833CA39EA28E9F797783DC5F90A27D9E9F62A66CCF8663CF6A939793878D
B14ACB7C9C69BE856EAF9C77849591A1A170A892
6B94AF968470A47D95B56F8AA28EAF5CA18E878DA39196AD5E90B35BA99082ACA358AA71
A0CD5A9D769E79A8998C62D494788A73C579979B59B28EA953B88A9F81A08389A5817A9D
AC8296961DFF774499A1AB8C9A76837ADB5F969B8696A55DA669D97B6CC66F988F988195
A953C2859770B77A87A19C7D7D9990A29D73A694
6E8CBB888A73A77698AF758D9A8EB7569F967F939C8EA6A26092AE5DAB8E88A99F5AAB71
A7C168907C9980A29B905ECE9C768971CD759B905DB689AA5AB3889F81A47A9B9A81789B
BB77998F26FF6E4B8EA5AA9492798B72D75F9E909188B357A766E07077BF6D9E8A9F799B
9F64B38D8E7EAB799398968775A18BA59877A496
7386C37C9371AA739CA67992948EBE539BA077949E83BB916198A764A6908CA89463A774
ADB575858293899F97955EC5A0798574CB74A38365B388AB64A88D9787A479A29280789D
BE75978A2BFF645285ABA49E89828879C963A385A17ABC5A9B71DD6984BA63A9879F799B
9679A297828AA27A9C93918A75A787A5927FA196
7B7CD06F9A70AD6FA19B7C989091B9569BA57292A281BF8A629FA168A5938DAA8968A677
ACAE8377878C98939B9663BAA37F7C7EC476AD7272AD85AD6AA1958A8FA772A9917E76A3
B77F8F8436FF5C5586AF96AD828E748DB1789C7DAE74BA678781DC5C95B05CB580A17B9B
8E8E949C7990A4769F908F8A80A285A5927EA293
8677CD6C9E70AD6DA1A275A18592B464959E7E909A90A8966397AB62AC8F8FB17276A386
A8A1867B878C9A8F969871ACA5827196AF7EB0648AA281AF63B08C8E8E9F79AB8D7A809C
BD7D898647FF794A8AAF8CB2888C708FB17E957BB378A575878BD25F94AC65B17EA276A0
8A9C8B9979969E7D94998B828BA484A48C829D92
9376C172A06DAF709BA86FAA7E91B3708F938B8E96959E9C658EB85BB38B8BBB5C839F96
A1978482878D9A8C9198819EA68764A9A184AC5BA59082B05ABC86938B9A80AD86768F92
BD81828658FB943E8FB282B391866F8FB2838D7FB18389898593C96290A770AA80A56FA5
85A785957D949A8886A0897D91A585A38A849A8D
A074B777A16AB27396AE69B27595AA7E9380988E949D8CA56884C654B78A8CBF49929AA1
9E8F7E8D8792938E8E948F96A5895CBD8D8EA856BA7F88AE4FCC7D9B879589AE7E759B8E
B68B788865DDAE3594B67CAC9B846F8DB48C8288AB91689B8798C16B87A47BA385A071A8
81AB858F86909A8E7BAA82799AA7839F8C849A86
AB71AF7CA364B77291BA60B66D9D9E8D9173A19189AE78AC6C7AD24DBF848EC13E9B97AE
96887D9683988E8F8C919793A58954CD7C97A155CD718BAD43DD71A7808E90B4786DAB86
AE996D8C71C1C23098B57CA1A7836C83BD9076959FA34DA19695BC737CA18A9983A36FA9
83AC8784987EA38E77B081729FA7869C88879784
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.504715 0.504715 0.97619 0.97619 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00751202 0.0192308 0.00751202 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
B9A88675716058666F8392A59B84737575879BA5A5A7A9AEABA3937E7B7A757D8F8B848B
8A8689929198A4ACADB8BFB8ABB19F9193A597A3ACADA0A4A19387848477767C71697685
86979D9A93929196939485827D7F7C8A857D7F7E7F838C8C94A8ABB2BDCBC3B0978B7E6D
7A7F726C77858FA6A393838A8998A4A3A8AEB0AF
798FB8CFDCE4E9D9C6A69C9094ABA7A7A3917A8B8C8C8A8981848D9692929C978996A59F
AABEBBAAA79C7F6B61503E45585E70838D86918C8577797E8798ABAEA6A6ACA6AEBABAA4
9D92898C8C949C958985898A8E8B998D7A7D7A68697374808A8081838E9BA5B4C3B39FA7
948C9C937D5B35000E2C555E8191888E96918185
CBC7AB9B8D8B84939EBBBFC7C9C5BFB4B2B8C1B4ADA19B959397999698A6A7A6ABA2979F
A3989B9F9997ABBBC5C9D5C8B8A9A4A0A0A9AEB3B5C0B8B09F908590A2A7A3B6A99099A1
93919E899494969EB4B5BDB8ABAA9692A6B8B8C7C2B8A59D9996938F8878828B95A8C6C5
BDBDA5B6D0FFFFFFFFFFFDE5B192968E91A3B5B4
6D637A879599A29086746B5657566A7A94939A94989FACA6ACA4988F9487797879767680
7A7D7B808897918B868A8698A6B49FA39B92838F887F808B9195A1917F7B7A5A66706A6F
8DA3B4C5C4BCAA9D8B8081839497B4B8C0B4C2B7BDBAC1BEB9BCB5B0A5A5978A80777776
9CB0C8BFB47E6C4C41495E6E849591968B807B77
9A9C877C6B685D66727C849A958B8883747E7A80837E77858890A8BBB5B8C2B6A7A0937A
6A6472848C979F99948E8F8278748B7C8C959989928C8F8484877A93A5ADA7BFABAEB4B7
A3886F59556B8A929AA19289766B747D767F86837A7F85867D7A7A7F8286868C8D9B8A8C
6D5435393254688193A3A4A6A6A799A2A3A7A2AE
8495AFBFDAD9D5CFBCADB6AFB9C1B0ACA9999E9B97A39F9A9B957D7576797A8FA4BDDEF8
FFFFEDC5AB897980828791A3A19DA3A595969D96969D9DA7A7ACB49E978C91879D96948B
95A2ADBEBDA6908E807E89919FBB8D837F6E55757E7E878E999C9F998C84817A7977808A
95A7D1E1F3EDDFC4B08F8F8A898AB1A9A6979375
C8B28D765456697B8BA59E9895A2B1A3A29F918C9A98A19E99999C979289827A74614F47
494B6784939BA39DA7B5BCBDCDCEBBB5AE9F99A5A6A8AAA7A5A09EA69A9D989D8F90827D
7D747A7E8385918B9DA19994998CA6A7B2B5B8A4A8A69F9896938A93AEB3B9C3C2ACA7A2
B3B3A495816A6162626E716C73847B798CA4AFC3
51688BABCECDC0B3A48F8B8D88766E7E868F9AA293877F82817D818F9CABBCC3BBB8A18B
7B6E5D636C7B8C968C7C64454046566A7D837F79737F7973797B737F91A0A4AAAAB0B0B8
A7B0AEA9A0ADB3B1ACAEB4B1A6989392827C82847A7A868D8E8D86765A514E5C69919E9B
7E68443D47688DB4C5D7CEC8B9977D8674605D57
CAB0826748424D636E7881889BA3A5998F86838394A6A9AAB0B8B4A491786157627497B0
BED2DFD7CFCFBEB3B3AFB1CECAC4BEB29CA0A19E9E9094949387806E6B605F605D50626B
848D8A838D8A888F94877A6F75788A87A3B4B8A6BAB1A4A1B2B2CADBF5EEEABEA97B7274
92B3E3FFFFF4C89D7B60687F8C9AA4928F9BAAC0
828FB1B3C5D2CAAAACA19A93898792A0B1C0CCC9B59C908379767D859BB4CBDBDAD3CAC2
B8A89280786A6C757A808B888687838288969DB2B8C1BDCACEE5FAFCE5E5D9C2CBD1BEB4
B2A3A8A3978B8F897B83868B8BA29CB9AAA7A3B49FA9B0AC9AA0938E7F8988A0B0D3DECF
BAA7815F4D4749668CBACFC8C4B9BDC7D1CDBB9A
A7A9A39D8D7F7F8B97A2A6A3998F81776C665854667E879DA6A399998F887E6D6B63605B
63728D99A3B2A999949182706D6B72829B979C938F7E82725E3A323E4F4C688C8E95AEB4
98928D9096AE9D9FB1B0C1DBDDCFBE918C90878B958D7D827E797678717372737471657A
8782899BA3AEC8CBC0A38F89808B8473686A6E8C
77818AA5B8B7B2AA9582838B9498A1A8AFAFC1D1C7B9BCADA3A7B0A8A9A09896928F8A8C
8B86818F948C909B9DA1B0CCD0D4CEBCA39A888084969DB8D8F2EADEDDCBAE93917C7572
909A8E8B9786849694958F81817E879CA59BA892868286879399A5A2ACB5B8B5AB9F9380
6E727B878E98977E6B6B5C586F7684A5AEA09883
A39F8E7B7A7E8B97A4B0ADA89A9F979483886B5D5B635F7583868A908D99ABABACB3ADA6
AEB2A69B96969EB4B7B4AB8D78797A8190979B9C92867A665C6473878B9DACA7939E8F6F
6B6B7A838F9597877D777070687572716B6E606E758E999C9B8B7E878B808E9C8C89A1B4
BDD5D4B9A99A90A8CADBEBEBC6B3937064828897
988E95A19BA0A0B0A7A79F979595949CB1ABB8C8C0BABFAF9C9A8B888F8B85989EA4ABB8
A799969C959C9D8380817F8BADA7A49F958890979CA1A7A196867D6B6C6A69768E98B3DD
C8BDB5AC88949B9CA2ACAFB5BAA8A29D96A0BCC9CDC0AE9995A5A79C979F9792B1B8A39A
978181878D9788807567677A92A8C3D0D9B7A99F
ABA59C888990917B868292998E80816A546E7E75808A837D8F9FB4BCB3AB9B888B919A94
9C9FA086806351565F6F899A98ACABAAABA89B98A3A4AEB5C0BBB4B1AAA7ACAC9E97877E
95AFB9D2DAC4ACA8988B88908B8A92A5A89A88816C6A878F8F9497929A9497948D869181
7371767981858C7B7573675C6A625F718197ADB8
839097A19B8B837F7D8B9296BCCDD6D4E0BC9F95A0979399836B5B5F6C7C8793908A7E87
7E7D7FA5B1CAE1EAD0B8A3856F5E696D708094928A8E81807C828C9399968F929B98958D
735F534150667F91A8B6B4979FABA68E989A9693AAB29B999E9D8F97948F8789829396AA
B8BCACB4BCC3DAF1EAD7D1C3A397A39B8D8C8978
9F9D979FACB3B4BBAE99878379807E9597A1B4BCB0B2BCAEBFC3C4B0AB999C8B84727A6E
7E8A967A797A6F6C838B879BA4A5A6ADA9AAA7A19288867F84908B85878C938F8E928E89
A2A7B3C1C3AEA98A7668677A817E87A8A19C9B97847987918D828B9896A1A6A8A0938D8F
9AA7BFBCA9906F5A5E7C8899A2A6928B8D9897A0
89868B89756F6E686D7980877F7A7C7D848C8681857D778F87848491808878898EA4AEC6
B7BAB7BAB8BCBCB5B0B2B9B3B2B6AD9C98887A7A83889AA0A19CA39C96988A878999A9C0
B1B49E856E7A748F9FB3B4B8A9A090796D74727D9299939893929B908B86807780878D88
7B695A5D69769BABB1A4A59E9EA7B5BCAEA19193
8A939FA4BDC7C9CDCABFB2A8A7A09B9A989698968E939B9DAFC4C9C4C6C4CEBEB8AA8F6E
71686A737876777879796F7377767E9295979B989B968B8E8A837E8A8B99A39FA0967E6B
777B8493A19CA1ACA4A2AB998F9BA299ACA9ABACAEA0A09B9A9FABA5AEA8AFA7AF9D9E9B
A0A2AAA0958C7F7C818A8A828A85766A7B6E7776
8F7D796E585866676F838B8F8E939088797D7B808B9489786D626375827E81898A959FA4
B4BBB7CED3C2BABBA7A3AFAFAEB0AA99959A9BA3A3A7A5A5A1AAB0B0A69E999E9DA0ACBA
ACA3AEACA3A1997B786D6E86979398AB9CA2B2B2A3B4B5ACB2B0959285837C929AA9A4A8
9F9BA3A8B0C0AC9585715E7B7D8BA9C1B1B8B3A7
C7DAD2D0DAC8ACACAD99A8B8B8ABA7A7A6969AA09C95A7A7A3988F838C9793938B7B8CA9
A0A0A076636E7A7F94979997948D8E92979BA2A4A7A7A9AFABA19A999A9F9EA09B9A968F
8B8976686D7D949BA4B0B2A7B0B5B0A09F9F9788867A6D6A706F78878F94978B837C7E7B
8A8A8081868693ADBECED5B7AB8F71526B7E92A7
574F5B696F8196938B92826D7389909BADBEB5AEACA491939AA0A9AD988A8C849EAE9D8B
947C759096928D9183877B706B6A63646C707A838887887971716E687277818E989B9DA6
ACB6C8D5D0C3B0ADAE9C8B7E6B5E66738B8F8A8E9797A2AEAEB0B9B4ABAAA58D7C828792
99A6B0AEA195998F83838D9DA5BECCE7CCB2947B
D4D9D3C0B2B7B6B7B6B9ADAD9E9288836E63686C6B7489A4A3A8A7A7A3B2B1C5C0BBBBBC
A6A8B59CA0A3A593A9A7B0C4CECFD2D0B8A3907F747F8590A7B4B9C6C1AF9F958680827F
7D7A6E645F5865737D9DB6C5D2D4CCC0A7A5A5A39F9D97978F867E77858F9AB1C4B8AE9A
8C7D6F667683868D9B90847F85736E616C7B9CB6
6D6160635F514144505970839B9FA6A3ADAFB9C8CBD1BA937C75665964544F4741434B49
4552455C627382958F90918986858D93A3B1B9C6C5B5AC9D877D7D6F7A8A8F8A8F8A837F
898C9297A6ACA3988D6E6059535961677F868C92959291868A8E8C95998D898F7E899AA2
A6C4C1D1CFC4B4BCA6A9B6B4A1A9A8A0A198887A
A4A7A3B1C4CAD9E5E2D0C8BA93838A9097A3987F72677D95B3C4CFD0CCD1E0D8D4DDDDE1
FCFFFFFFF8DDC3AD948A8A8787979691939290838083898F9EA3A3A7A29B9FA09F9BA0A3
A49DAAB2ACABB2B1A0A295928A8380918C838D8E838A93989AA7A1A59EADA7B4B9BAA7A2
9A7A7C6F6B68603F43494B648493A3A9ABB8B2A7
9BA4B2ADA2A19D85768080819BA5958571606C707A796B5D544B546D7F97939F9F897166
574B454F585F6B8398A1938B816D77858C878B8B95979EA09F959B999F9DA3A3A1969087
809492969BA09597A6B2C7D2E1E6E2C2B0A792868F93969CA193918F89879991858E8C8F
8CA4A09F99ADC3E3F5F7E1C4AB9E8A9E97898C9E
8783817675757672746E6A71859CB2C3D6DEC6CBCCD2CFD9D1D1C4AFA1877A6D6E788F98
9797998C8D919286808198ADBDBFAC97848289908A857C8584939C9F929E8E878A9A98A5
B09D8C7C76666E7C817162543C3C4C6C87929AA7A6A9AFAE9CA2A8ACB3AF9D8E96869598
9E8B91979F8C868373728F9B979B9E8880858783
9A9B999EA0978BA0B5B9CAC39C7A6D5A5A60757A868B938F93939498989FA5AAB4B4ACA9
ADAEB1BEC3C7C4C6CBC4B09F969796A1A9AB9FAEB3C4C0B5AA9F868A938994A0A9ABB4A8
9B93959FACC0C0AD99A0B0C5DBDAC296766E7475848485878983907E747A868797A5968C
8D928C9C92837B71616965667E8D9AA3B0A39F96
999E9FA5A5B4B9A9979A898BA1AFB0B4B3AFAB9F9A959996928B8A7E7E7E7877777B7C89
8F887D6D5E514C505662747D89929B9294939681817272788A8F9E9B9391897E7573757B
90989C9A92848F94A2A29D8A8D97ACC9D8D1C9B3928C8876969F897F8668626F756C7D87
756B73585687A5B0D6D9C5B29A7C767C7B8D95A0
A0A29493968C919EA6ACAEA8A4A38D8D897874828278777D8B979FABA7A0A3A291857E6C
5A6272879BAFBABAB3AEA4A59D979A9B95989898A1ACB3B4A89B938F939AA6B3B4AFADA4
93A19F9DA2A28C9294918E8E8374716E6F7C7E84A09E90A094939EB3B4BEB9AB9EA1A0A3
C0C9C3D5DFB6A2A78D7E959B8B8A796673889193
786A6E6C6E737C82827B868E8E97C0C2BCCCCBAFA4B3A6A2968F8C9198A4B0B4C4CED3DA
E2DECBC0B4ABA7A69EA3A099A4AAA1A8ADA1A1A29080837B86A2B4AFB29F8E868D8D9E95
89726C5B656E7780817E7F877F84838F8B95A1AD909BA19794AEADACB6AF948E897A7C88
837E8C7C7F8C90787B7C768AB3D8E7EACEA4877F
A9B6C3D0DAE2D5C3B19F928A83806E778584839B9C94969197969292969193938E8D9C9F
A6AFBCB3A69787868F879294897F847D88898BA0ADAA9B9C8D77708B8D98A5AEAEA591A2
B3B8C6D3C2B5B0A0A1A7A7ABB8BAB19E8B835E5E75746F87775D69646682A7B4BBC8BAA8
9AB0A1B3A79E8EA8AEB8BFAD95756D73899AACB0
947E786D6050595F62767B8B8B817371686D7B7279787D818684827A767766717B74646A
5D4E556D8097ABA699918A7D7B7B837A7A88958794ACBAB7BAA7886E696A72766E7B8A8A
879A95939CADABAFA49F9A8F83878F98ADC0E4E3DADBD6BDC4CEBBB6A5988889958F8E9B
9872817B7786A497928C807D8797A1ADA99D9D98
BEDCD1C3BDB49E9AB5ADA797A5A2A8ABB5A69CB5BCC1C4CBB7AFB4AC9E9CAC9A929D9B88
8F96897D7D74798FA5B3B5C4B6B3AEB8A9A38E847464606A728CA9B5C2BCACA3A6A09697
937963655F566C7C8E97A9B7CAC4C0B8AA9481939C9898A18972777A87919C9691948D86
97AC9AA1AF988C9CA492A4A69D8D927372898C9A
4038516C77939D9D818B8E9E96ADB4A7A3AFAC9297938D86959CA1AFB9B3A2A8A09EB5C9
C9D0D4CBC4BFB1A084746A646E7072707374879BA1A89E99857E737466666962646F777D
8FA1BFC6CACCB99B8C806E63596268798E9CA7978B7A7970858E969C9999959A909495A4
A0A8B0A295A19E868A9C8B89948C74837A62635D
E3D5BDA2866F6A6C7A8A8F8D927D6B787A7680846A636A71758488827E879293948F7B6B
6863676E75797E839BA9B4B9B6C6C3CCC4C7ACA38D94A3AFC1CED1C5B5AAAEB9B4BCB2A4
918B8285898F8B95918D8D9F9B998C7E73675B65727B8FA4A4A7A39B9E9B9FABA9AFBBA9
A7A99EA7B09F9F9E8D878A92878FA4ABB5D3E2DF
787A8698ADC0D2DCDCC2BFB7BEC7D0B8A58C8293A6B6BCB5A1969396A0A5A3A3A19EA1AD
B4B5A59A8E83848981746C5D6D738484A095948B95807D787A798897ACBFBCAFB0AFA3A0
9F9B8A8588879798AAB3C0B0B5AEB8B4A9ABB19F95A3A3919AA19993807774686A70726A
6662726B7285808D9C97A5AEB7BEC3B0A6846A73
9C958D8C8B7B766D6068747C79869EB5CBF2F3CEC3B1928596938B8E89858784909AA29D
9B92937F81867C798D9EACCBC6B8A0957D899CB0B4C3BBB6A8A18C9599999FB0A69BA5A7
A6B7B8B0A79C848379726D7881888B919F9E9EA6B5ADABB7BBB7BDC6DDCCBEB6AF8E9192
8385868F96AEAD97888A706A7A878199A1B1B9AC
7B939C8A9B9B8B8FAA9E8A775E452F343430384F586D8EA8B0B8C0B6AA9D938E8C8B8782
7C7C9BC1C8D5E1D5B8B0A39883838F9A908C846A6261696A6E656A534B4E585063696E6C
7775879BAAB9C8C8C8CFCEC5BAAE9E9A8F8F9294878B8574686260625D7A8E8D8CA2A2B4
CDC9C1A7988995B3D3D4DDD6AE8A87756F717569
A99B98ACACAFC4CDBDBACBD8E2EFEDDBCCC3BEC8C7BCB29A84766D7084959FA6A597929B
A3A7968F8D8983878D8980788A887C869FABB4CED9D5CED1D9DCDBECDEC1B0B0A1A2A8AC
A39083776C5F677A7678776E66737E87979396949897A1A9ABB9C4CECECCC3C3C5BEAC91
7B7F7B9CA09D806F484E5C6883A6A7A9B0ABA0AF
A4A1988A77797E777C8887848C899499969493776F6D6A758A97A6ACA7A49F9D999DA19F
959897939599979998979AA39A95A09B888E8D817875675F52555C5C6E868F8F96978F8C
97A3A6A8A4A6988A888C93A0A8A39B95908E8E9187847E7B7D746A685A515A5D6075869D
AF9E9C8B8384A0AFBFB99C9283858A979AA3A39F
9895979C9C93827667666669737D767B847C768A8D95A2A99A9486848282908E81858472
7D82868B98979B9FABABB7C5D2DCDCCFC7A698909BA4BABCC5B4A0867C7C8392ADABA5AC
A49F9FA2A2A0A5AFB5B0B0ABA99FA39E9C9E97949993899087867E80868C879295888A95
9AAFC0C1B7AD968683898E8F8772594F5662758E
757F7A7A7E8E95B2BBBAB5ADA0A1B0B5C1C3C5B8B6ABA5A2A7A7A8A19D9C969FB0BDADA4
928E7F8480837C76717A80756B666866728A9B978E827C81889FB4D0D3D8D1C4A7A6A9A2
A0999084868689817C76655D5A66757C818B9593A4ADAFA7A7A8AFABAC9B968F8C979B93
91877179888F9DA9A7A7A8AAB8CED8D9CFB99F87
BCB4BAB7C0C0C2ACABA6999AA0937875594B536265767A777A7A787977766E6D706D87B4
CCCAD8D1C1B7C7BDB7A88F7872675D6E71746B756E767B7D83888C7F8885827A72716262
60818F9FA8B3A39BA0A5ACB4BEB598A1A79F98A79586838D95969AA6A7B8B9B8B9AA9C9D
8F89998B716B6769737F9CA7A6A6BABDB8BEC9C0
616A747D72706565667398A79B97997B89B4BBBECEBDA7A3A29EB1BCC6BDBDABA9948E77
71646B707A7C7A797B7E8692A6B4C1C5C7C9CBC9CECCC1C2AD9D9483737A767E948A92A0
9F8A8E847B72828F8D868E938A99B5B3ABAEAC9B9EA5B0ADACA7AC959B9BA6A1A1A09475
7275636799A5B8BABEA98573787059605E514D59
C4B8ADA29D939CA0AAA792889397A8D0D6BCB4AD898692948B9B8F8A869096A897979898
8BA7A89996998E94A0B3B9BDB3AB9B968A7F7A7673798586959BA1BCCDBDC1B597989C90
A0ABA9AFB6B5B3ABAEB1AA9A9181756C6A717C85919897918F857778726E6E7C898594B2
B0B3D0D3A6978772697EA0A4ABA1A09CA7B3BCC7
889AA0A7B2BFB7AFA59B93919AAEB7ACB6B8A79DB0B5B4B2B3A59790908C88848E989093
9D948897939794948A83808990A0A89E9EA0A2A5B4AFACA3A0999A8A868B827C8C93979D
978A806D61544D4C526282A9CAD9DDD6C1A7937C6D66646D7A8F979EA2A29A9F97989188
92826869898FA9C0C3AF938B85888F9086888E83
827C7E867D727E858085918E7E6D5C594A4758616B636E79837D9BA3A3A9BABBC0C7C8AC
A09F908A9489827E8281898387797E848B838485828082837B7A757C7D7D88A1A3A2A1A1
A7A0B1C8D4E3FFFFEDD8A6775E524A608597AAC1B7A3A19A8F8C8F918B878D858697A8A1
A9CFF5F9FFFFE7C6BDB9D4DDD8D5DACBBBAC9990
A6A8A79CA0ADA5A4BBBBA6A4A0858592969EB0B7C8E4DACBBCA48B878380726057575A7C
878690978B8F9F9C9CA39F9891897D81868C908F87899196A7B7BEBBBBB0A797A4A6A6A7
8E99988A7B8B666274829FBBBBBAC5A68888867CA2C3CECBCEBDB3B1BEBAC9D1CCB7A79A
815739310F0A20242428161844566A7989838F99
8D806E706F69666C525F7B99B4ECF1E0D2C29B8F796F717D87A29992958B90ABBCB6B9A8
A19DA09AAAA8A6B0B7A8A8A09CA2B0A59896999CABC7C4BAAAA1918D95A6A8AB9F958E8B
9D9B9492977F8D928C8C8478787D7695A59F8C86684F51646A788C877B7D64535B6B7D93
B6C1BBC0D2C3BBD3CDD2E4D288664933467E9292
A09FA9A7AAB4C6C6D2C0A38166484B53646B86857A6D767072819FA9ACB8B9A497999CA3
B7C3C4C7C2B5ABAC9FA29FB0B8C0B9C1C7B7A899876461666D7285867E706B696A6C8391
8B8B8C85818A9399A6A9AFB7C0BDC1BAB8C3DCE4F1FFFCDECCBC9B979EA6A5AC9C8D7A77
6B88938F8FA091909F9F8FA3C3E2F8FFFED9B6A7
8BA0B8C0C7B8A09A9B9EA6B1B29E848579868C9CA0A58B8988867E82858883868985797A
6D66655E5667757B87898E837F7B7B75798B9CB6C0C5B8A998908E9AA7B0B8B3ADAA9F89
908A87979C8E8781717076716A5F55585B5E5C69625651636D788F9B99908F8792938C96
977F7081725F5E746A67818E8C9091838370737D
BCA18579736D7A747378858C9BBBD4D5D3C8B59FAAAFC4BFB9A39D968F87868A8889929A
9E9BA0A5A0978F89878A8182796C626968646D7A7E8E9FA7ACB6A7938277747D8A98A2AB
ACB9BBACACBAB1A9AE9C8D9197A3AA948E81736E797E8D92929B95989AA3ACB5B1C0CDCC
CCD3D7C7C4D2CCA7A9B093878C8A777F8FADB4BB
7C98ACB7B4BBACAC9C9A978B787975717E8A85887471708492A8A4A7A6A8AEB0ABB4BCBA
BCC5BDB5B6AFABA89D979A9A999EA0A49C9A8E7D6C635A6A77737E918F939A9A96928A8F
8D8593A4A3A8BABAB6BCC0B8B2B6BECBCCD5CEC4BEB8AAA8A9A1A7A3A7A2A39E9D908F84
81817C6E81879BB4D4BFBBB4AD94ABA899898B7C
967E68615B6A8296AFAD9E9A9B7D7982857E929C9B8C8773685D6664635C57535A5A595E
615C616D7584909898969DA1A6B0C6BEC9D6D8CFD0C8BFBBAFABABA5B5B7B9B0B5A3A297
908A807A7D7B757A7E8183827B685E5E5E617684898F959891928B857D7D7976797D8286
8E90A6B6A99B948065838C8B87A08BA1AAB0A3AC
A3ADB1B7B19E8F7866738892ABC5CCC5B9AFA5A1B0CAD3DDDEE6DBD2CFD2D2D5DAD6C1A5
8F8173706C6A68696E7B7A7D838E7F85897A727D7C7C8B8B95A29F9E8E8D868C8C9F9EA9
A9A4968C7A77767C7882848D9BB0B2B9BCB2A29A8E8A897D7F858684848B87878B938B92
8376839098ADB19C917B767A7E686A5A5F6F858F
767583808791A0B2BEB3ADADA09F9E918888838683838279706D6F7A8689827B6A5F788F
A3BFD4D5E4E4DFD9D1C7BDAFA89B988D858E93919C99918E7D695B5A5A5764797A7C8877
7E8798A7C2C4C7BBBCB7B7AFAB9E9D928B8B8E8A89817B838787929B9386857E7976888F
A3B28E6A625A629BBBCCD6D5D8DFD8BA9F796C66
9B9D989BA69F918E8C8E88846F5E5A5F74929F9FA79C9399A8A5A3A5A19FB0C0C9CCB39F
8C6E625F4D4E5357637077878387898E908D86756B6C6A6C76859CAEB2CAC1A794908083
83857F7B75717E8D928E877D6F757F919CA8A4A3B0C7C9C8C8B3A0A5B1B6C8D4CEC8B4A2
9793BEE4ECE8D49E7D6F5856565D6694ACB9BBB0
A18B7D66696F7E7C837B7C91B7C2C0CBB291837A6F6D6C6B666B7679838D837D8392AABB
CDE1DCCCD3D0C8C2C6BCB3ABA8AAB2B4B1BAC0CBD3DEEBEFF5F4E1D5D5C0C2CBD6CCC4C4
CFC7C0BFB3A1827976767E8D938C7F6D6D67737A7E727D8285909E97979E9F9C9C9C9C8F
838462515A676E91A1A9C7D0C4AE9A6A626C8397
BFE3F8FFFFFFEEEDE2DACBA48A83858CA6A2A6B4AEB9CCD2DCDCD1CCB1927E6E63605B69
685E63787D899A9D948E8E8E999D9AA4A49D937C6E6B676572716F61565D585A57676A70
606C767D86A3AAA7ACADADC6D0D9DCDDC5C0B7B1A6A99E989A9F9B958F7A6E6A727C8BA5
B3A0918B6E6275767C847A809BACC0CFC6B9ADA9
4E454C50544E564035455D798FADB7A9979F99888B857B6C666E75809DB1CBE5E6DED7BB
A19A959591898685838B9594968D897476777A879688776D5B5A708390999F9B9EAEBFBD
CBC7B8BFC0ACC3C3A8A4A3837A7D868C9FACB4B6B2919893898DA39D9CB3ACB1AAA39093
8B96AAACA79D9385766E7A77627081918C95816B
C0B09B89878FA3C4CCBDB5996B4E46485D768F9DB0ADACAEAB99988B8A9293828C8689A0
B8BCC4BBACA79D9B9B999DA7A3AAAFA89E97A3B0BFDDF5FFFFFEE6DDD9BCB8B1A48C7B73
6D695F5A5F6B57627C7A7584837D7F8687847C79768E818B8F8973807161686F727D907E
8593999FD6E1D4D4E1C5ACA6AE918379878AA7B6
969B9BA59BA28B7D8AA1A7C6ECEDF0F6F1DBCFC8AD988D89858D94A0948E8F9791988F75
6B66676E7A767471777D7B808C8383999E9F97927A5F4F4D434B5E564D6D7482939D9899
999EA0938B767B858287968F9199928D88857A827E8D8C999AA7A3A7BAC6D0CED5CAC1C1
BAADAFAD767483765571816E668B9597A5B3A1A1
6663666A6F7180867D7572706F7A787467675B5962757D919799958F8386766B646D7889
98A6A69FA3A4AAABAAA49D89767A72707B878B939CB2BBB5B4B19DA8AFA3999484758389
888CAFC0CAEAE1C6BCB79BA09D90908A8385938CA0A0AB948F7E857E7F7C70655E666E7A
7C7E6F6C879494B0CAC3C2C0BDAC9FA09783776E
C8CDCDD0D0CDC1BDB2A69A8F8B8A918C88817677767A79807B828A878B8B8C888F8C838D
8F9295AEB4BDBCC1B5A8A8B2BABCC0B6A8998F8B938B89929898A7A7A3A699909FABAAB5
C4B89C8E806572838E9EB8ADB6B1A59CA48F929384626E757D879C9D9FA1A9AAA9998A7F
84828E937A61564149636F82948D959FA3AEBBC0
8787877F7B777C8395A2AEAE99887D808A9FB8C3D2DCE7D9DFD2C1BEC8BBBFCAC9BAB8A7
947E857A7170736D78878D92867B777580939B9B9890908F928E82828B8EA7C0B4AAA690
767E847B85929191A190878B898A9EB0B6BAC4C8D0E5DBC6BFB0989CA0A09FA4ACB6BBBE
BAB1A097BAD3DEF6F0CCB5A6989E8774736D6D7E
858D969DA2A7A3918689888FB2C9CDCAC6B4A9A0988977716B707C7C7A7E767676828B99
9DADA49F9B9B949393938D8F99A2A5AFA1928782737F7E76717984837E7C72616A72747A
88888E9599988D8F7F7E797A6973736F778A7D6967686A88A2B0B5AEA49D97968C898D8D
8C9FB3B7A4998F7A768B8DA1ACADC1CDB8AAA188
A4978C80716E7784878C969582817D7D8592979A9992979F9F978C8B848CA2ADB7ADA792
8A80838791979B9C9B90907F88818E8CA7ACADAFB9A4A7B8B8B4B8BCBDC0BBB9B1ABA2A5
A09A95A39C99A1948D95A1ADCED3DFD8C4B9BDB5ACB9AA9B7F877979676F797D8190827E
7A6D64727078818F9A918A87776B68747E93A4B4
A8B1B7BCCFD0C7BEC3B2A08E8870636366626674757E8486848B989D9F9D8D81798B9AB4
BBCACEC3B6B0A7A2A0ADB0C1BDC5B5B9A4A2ABABA0A396817B75736B6A69767C888E9B97
98A3A9A7A7ACAEB3ACACA19079775D6D7C80718B83767F8D8A81848895948B8E8D8BA6B5
C2D9E3D9E3D7C0B4A7A3B0A4ABB3A994A39D9793
83726B7272767E8881807F847989A7A9A3ADA68780898F8B8F998D8B969BA1A39C8E7657
4E3F29333F3E516A747B928C867F7C68707A7F8997A3B0BCD0DDD8DAC7AF9B8672756C74
798280878A8E7F7A837E818796918A85787D8EA4AFC1BAB3B8BABFB7BCAEA39DA596888C
856A6D7465627A71727F8891928F998F898B8B83
ACB9C2B1A6988F86919CB4D4FDF5E4CCB89BA1B9D2C9B8B2AA9CA2ADA59C939294A5BBD7
E7FEFFFFFCF8E3CDBCA7807982848FA6A2938D8B8C8B888675665F657B93A6C1D3D7DBDA
DFCCBCB0A5949DA9B1B6B4B0A39E9F9AA49B94858878857D7B7777768696A0A39D949283
84948D91A7BEB1C4C1AC91989EA3A4B7AB9AA2AC
92918D989E9D9C9C90837054414C537597B0A6A18C868296938A78675D667A8B938F8984
7D7A787C7A7579818795AFBAB4B2ADA19AA2A19F9A99978C8E9B9FA3ABA5968E83777472
605E666D6E7A80796D737A84909DAAAA9F9B9D959793929393959BA1978C969D9DABAFA8
9D979B9B806D73676B90AFAFB2B5ACA7A9B0A298
6F6F70757C858D98A7B0AEB3A9A0A38D696C7262728F9892A1BCD2D4D2BE9B7D7270706B
6F69687080838C8C8C83807C7D7783868C8C8F85827D808C918282766B6C7E83929B9FA1
ACB7C1BCC2C0B6A7AC9F9B8A77696D68728F97989BA99A9A98948E95909F91878A9591A4
AFA18A6D6E65585B674F474E58607989918D8276
ACAFABACA3A5A2A091848D878B909293C0B4ADBDB88D918A8176767993B5D0DBE1DCC4B4
ACA9ABA1A0A6A3A0AEB5ACB0A8A093948E8C8F9AA3ADB3AEADBEBCBDC3BFAAA3998C868A
8484888B8F95A1AEAFAAACB8C7CEC3C4C1A69C9F9A858F8F979AA59F9792908773727058
6285A4CCF1FCFFFFF2F3DFBE9B825C51536C86A3
AAA3A2999893918793968B97A4AFB8DBCED0C8BFA1A79E9F9F9D969A8D736A7167708EA9
B6C0BCB7A99B9B99908A8D8792A9B2B0B3B1A59B8F80797372717F8687878D8883868F93
9B957B6F6055576D7A95999A9DA0989F9C9999939099979C9FA29FB0B5BBC2CDD8CFD0E8
DAB4A486686F6F6A776D697AA0C1CCCED5BEA8A3
76838991959594A197BFCCC6B4A6724C3D3D4D5270858E979A9A9B9A9DB4C0BFCBBBA68C
7E706E67777C6A6B716D6E7A6D5E565D68788991999C9DA4AAA8A49D96979B97A5B5B5B1
B3B9CBD3DEE3D6A998847C757575828F95A6ACB2AAA9ACACA19991796C6662616E75766F
768888A2A593888D7D8BA9B7A691A3A184879784
AA9E9893919293929670655F5F5D868F989EA4A39F9B96919094948E7B665E595A6A7A86
8C8D93938993ADB7C1D1CDBAC6CBD1D5CFB7A99D939E9BA09B9B939C999C9FACA68D837A
60565A5A5D6A7698A0A1ABABA4A4A17E756661516C76736E81837F83968B867F6D565658
52585D575E768AA5C3C2AFA2918C868599A29BA0
80838988888C90928F97969EA4A7A7AB9B938D8787888A8F8E8A88929D9D9BA093818384
848B95A1AAAA9D8B7261667279787A6C717784979F979B948D8483828C878E8B8A8F9398
A3A7AFB4B8BCBBA29E9686868B8799ABB0B3BCB8B9B2BFB8B3AAB2B2B7C6D9E9F6FFFDE9
E2CDBFADA2938E7D6F7B878394A29F9D9F929390
B6AFACAFB3B3AFABABA6AEB8BBBDAFB0B6B2AEBBB8AEB4AAA79992878E9692949FB2ACAF
B4B4A49F9E9DA5B8C4CAC6C0ABA9A8AEA3AEA2938B8D878E97A7AEACA2A6969293A2A8B3
C1C2AE9E8A70697A89939EA39B93858D88908D9C8C897C7C7F87888B837B766E6C737C89
92B0CCD2D1D4B8AEACA49CA4998A7E7E828B94A5
889AA1A09B8E8A8787827E6A64627C7A889BAAA3ACB0A8A9ACBDCCD3CBC8D0D0C9BFB9A8
968E948C86817C73777877797C6F6B6C6D687A86979BAAA6A5928B858581898A806C6258
4D5463748A9CA19C8B8282828D968C93919697A59EA2948F8884848C8F8A8C868283837C
83745E6170758C94937B6A575E63747A7E7E7F80
8D7F7871636C7771738C9298B1C0AEA896806B5E4E55514F5658505760686F76767B7D86
949798A4A8ABB1B1A7A7A4A7B3D3D6DCD9C1A08F7C726F5F5F657588A4ABAFB4B9CDD4DA
E2DDCCC7BCADA8A4A1A195857A757B747B73676077829CB1B5B0AEA7ADB8B3BCC0B2A5A9
9F9DB0B49E908B8080A3CED9CAD2CDA8A0ACA092
7C8D9594BBC0B6B9CCA288785A3A3B4A616B7C93A5A0B8C0B7B2B6B2A997846B6A67787F
8F928B83857E7375797F8D8E8F82796F789AB9CDDCE1D4DDD8DACDB493887773726A6A6C
656C7A7A77838B9197A7B8C7D1DDD9A79394918D9C8D796D5F6E736F6769666A687C8289
857F5D5351585C656D6B5A6F99A2ACE3D0ABA499
C5AB9999777479796788A8CCDDF5F8E5CCC9BBAA9E9C8B8D8E877A7A7E8A94A7ACABA1AB
A4A3A3A8A3A1A0A29E948888847776786F6262524C58626C83877F8A90919FA8B5BABAB4
B49B97989B98938886817B7D807C7CA5B7B0B4BAA2AEB7B4B8ABA4ADB8B7BCAEAC9A9F95
9DAAC9C9E4E7DFDEDFC2B2A5826E66455B7C8AA2
899EA5B7BCBDBDC3BAB0A3898A82868B9793A1B0B0ADA99C9BACB8B3B4ACA59D9B99957B
6D6E787F8D9A9D989399A09C9BAFAFB2BFC3B7C7AC8E6C5839485D737F8B908E8F898B8D
96AAA8A19F968E9FA7A4A3A29994A0B8B8BABCB08B7E7C8B8E9FA1A18D88868C8F9C9198
907C61776D7C8C8A6E72716A7A8B909F9CA2A197
9C93979193989A9BA7A6A6AAA39D989F92897967637C909AA193807E8999A9B6BCB8B4C1
C3BCB7B2A59E9D9EA0958E918B7C7F7F7A7A80899BC8E0E8EAE5C1B4B4ACA69A9094918B
87837C83828C969991909489888B8D8185909A9FB3B0ABA29A99B4B4BACAC3B5B8ABB8BC
CBDCFEF0F1E2DBE1F0FFFFFFE6D4C1AD9B97959B
99958D8084807B76767F75757470575C7B9CB7D6D9B096898896ACB3A69C8A8080909191
99948D898B888E9097A2A19FAAB5BBC5C2B3A5919F809AB4C3A6BA9E857C7A878F898B8F
8A8B999B9C9C92838284818E9693908B85766D676A78898B979E81788B7770817A7E7F81
7175574D3E342C2A4252646E999BA3B4BFA9A89D
8D8F9FA5A09CA3A29D9EA99F9FB2C3C1B4A99A8E8CA3B0B09A8983746F737A716E66757D
8797A4ABABABA9ADA9A99F94837363555D768A969F977D66627086A0AEB4ACA1969B999F
A6A29EA1A5A2A19FA4A3A0A4A0979391939CA7AAAEACA39E9B8F8C947D7E89807E847F77
7E74797987979D9B83654E453548565B63747A83
78888B8A919A938F999B9BABB6B2C4BCB4B0A69096918997ADC0C0CDD2CBC3CFCDC9C4BC
A9A29C918B8F887E77748BA9C2DAF5F6E1C7B0997F878F938F8F7E7F8F9BA1A6A3908F8C
82888B85829093A5A6AAB0ACA9B3AFA0A1938987837B7E7A777B7D74829199A3A29C978B
8893A0AFC2BCB6ACA79FADAEB2A7B0A9A39A9485
8F7C76756D5F677F807B6E69534545575B59696E6C6F7C7B796D66676A6E757A787B6F6F
7576737C837F84909FA18E725845353D5468778D9AAAA0A29F9C9193888691969AA4A49A
A7A39F9FA28D8B837C6A66645D5968707386948C939B9DA4B5B5B5B6A59B93929FAAADC5
D2D5D4C7B3A9A3ACBECCC4B5AFA683838B797387
F5FEE4DFD2D3C6A0878AA0B7E5FEECC5A69B89989A938786817E8A8C908C9B9D9FA0B8B2
AEACAFA4A5A8AAA09499A3B8C6D8DCD6C8C5BCAFACA2A9A6A9ABAEA39B9B938F8E969493
8C8F97938C99A9A5B1D1D1C6D1DCCAC5B9AE99A1A4A0A0A7A3A2B4B4B0A9A89988868C7D
746C5C5A67748086868F94A59E9FA29391C5D3DB
635C717C8F94A3C4D3C8B88D584E5A78A1B3AD9C9CA7B7BDC0BEB9A699A28F7677776271
80827C86838B87949FA2A2ABA99B948F80757A7871767F808F9BA5A4A998938E908F96A1
A49A8B8E887E85877F6C6D6968638897B0BCD0C3BDA29E89766F69626A707B8E96989199
93929099828B9295949794929EA4A5B0A68A807C
7D8489877E777264636B85A7BFB6B4A087799098979593878A9291A4B1AFB5CAC5C5CCBB
A0958776787D84837D716751565C666F7E898F9CA9B0A6A695867F7B7B90989CAAB0AAA9
AFBABCBAC8C1B2B1B4A9B0B0AA9C79695B4C49616D939BACB6B9A8B7B4B09E9896969995
9998A6B2C2B8AFA79F9797999896A6B1ADA0968A
9590858699ACA7A8A7A7958D95999BA4A7B2ABAFACB1A3A09595969494939089847B6E79
8C9CC7EAEFDED4B6B0B1C6C8CEC9C1BBC3B9AD9A8574727484929AA2A79A95938370736B
595F656A6E898687879B98B0B9C9C3C5BABBADA7998C8B817D7E8D8B90999F9B9899A0B7
BBBCC2A5877E736E7686979B898876606E87948E
9AA6B4AFA79B98918F8777736D7A828C9D9B9593A0979A909084807B716D6C6C7690A3A7
A89F7F634843425C676E5F48393246516B7683949BA1A5A4979598979A999E9BA3ABAAAA
AB9F9A978E878B8E8B8B887D767681878F989F9B9B9E93A0A8B2B7C7BFBDC4BFAD9B835D
57534C638B9FBBCBC8A68F7F9896A7B0A185858D
AD9B939791878E9596A3B2B4AA958B86766E756D5A5F6C7D8CA1AAAFB3AFB0B6B6A69D97
8E8C9AABC3D7E9E1E6DDE3FFFFFFFFEFB8ADA09BA19D948B89838385868F89918A929397
9CA8A3A6AFA69E9587797573777F838386837B7A89979C948F7B654F54595A7392A7B8C7
C0C3CFBFB4AA9587909D9FA79291868F9FB0AFB0
6A737E858D9CA4A8AAA19F98949B9893959B9199A9A297978B75777A83939D9E9E9D9CA1
A5A6A3A49A8E80846E746F6B5A6264718791979599A2B0BFCAC7B9B0A39396959D9F9FA4
A491959285858A8692989AA1A69B9390898E94A0A79F9291908F92989C917D746F747F91
A39F8987766971776D797F8597A0AAA2917D7169
B0B3A293958F849195939491888483838E93A2A9A3AFBAB5B8C6B9ADA08F7D756C6A615E
595E5657606E7278898782706F6263686D75838681868474676B736A6C767B807F85908B
8D9A969398948C9B9DA3AAB6ACACAAA9A5A493867E7A7D8B9A9EACA1A4ACBCBAB9A58B6E
5D71818D9EA79B939B9691918F8A898E92A1ABAD
7C7B898C75888B7F84808BA7BFC6D2D4C4BBB3ACA693827F7B7487969BAEBFBDBEC0BFC4
C7CAD5D3C5BDB9ACA7ADAFBCC4C7BEB9AB997E7879778398ABAFB1BEC5B9B0A79B8F8D8F
949A9B989FA1B4B0B4ADA58B91A0A8A9A9A09FA4A693A39E8F868C8A827F9399A2AABABF
C7B1A49D949EB2BDACA5968F8B979BA79F9690A1
E9DFDAD9D7B8AB9C928E856D67666E7389999B948F96999CA5AB9B90897771717B7C877F
8A7C7D7C8887888B9384827E7C7A9297A9B9CAD3D3C6A8938384868F939B96959B8F8383
82798F97979A979793928E968978817F877B978B858898929CB6B7CDBBB39792747E7A80
7D919BA2A3957C76848EA4A49981725F7C97AFBC
4A5656607286939EA0A5A7AFAEABA39C877A747A8A9B9DA7A29F969A9C9D909997989FAB
A2ADACAEADAFAAA99FAFB6C8D2D8C3BAAC9A968F8F8E979A9E9A9F9FA2A6ABA5A6ADB1B2
B2B09A8B85877A777E8381858A8681838EA7ACB6ADC199968D90718C9D9FA4AAA5919599
9F93918F908EA4ADA89D999A9EAFCCE9D0C0A478
9D938E89969499999DA19C939D9A909096888C8E8D83908F9194A2A3A5ACB8B7B2ACA396
8C83776D625E62686A7273655E64667280877F8083838D969A9B948A84827B878A838788
8A8C9FA3A7A3A8A49F9B9D96A09E9B9E9995878679858D8C867D7850697A8A7E96928479
7E7A767C83847E74747E8C929EA19674787C8182
9CA7AAAEA49C8986828587898A8182808F9AA8A3A598877E7E7C80858B96908A8C908C8D
9BA3A9B4C9C3C2C0BDB0B4B7B1ACA89B8F8F918F8B9187858184878F8E9399918E9B9A99
9A9C8F8D91948E959F9B99A9A2A9B2B8B6B0B4ADC5A2ACA0AA9FC2B8A99E938F9FA7B7B4
B0A7AD9A989DA1A0A398726E74706F7C7E70707B
A7A098918B93A3A7A39D99928DA5B4BCAFAE938F8293A0A9A7A79F9A9781858A8786999B
9C9A978F8383847C7C80747074767C89929B9BA1A2A2A8B0AEA49184777780929A938A86
86838E94918D868D8A8F97998A7F7A71727C857F8D94929B9F969194928C7D7B83888B97
A4A297ABAEA4A0A4939DC0AFA39E988896A8B9BF
6D6675848F90919598A1A8A4978C776D777A858E998F8A82888789898C9FA1A2A09C8B88
878B8B89868D8C99A29797997B6C747270899B9D9495948B92A7BDCAD5D4C4B1A4A1A3A2
98948D9F96A1B0AA97A49B98A9A7A1A79B8F85937B8A869393A397A79BABC6D7BEC0A28D
747E84838A918D8C8F8E829291A8ACCDC7BD9B87
C3D0D0BEA8978C858C8B8FABB1ABAFB29A9B9FA2989A969E97A2ADA9988A817E848E9B9A
8B858A8B95A3ABA5A2A6A8AFDEF3F0E7D8A589869AA3AAB4A9907F736F777C8B979EA3AC
AFB0AA9E9C95928F9291988C8896918F97A59CA1A5A5A8A29C9DA5A099846F675C6B8194
8B8F8C93898D909598989DB3B0958D7A5E5C7DA0
89796F6E818E97A69C97948789939BA4BAB4B6ACB5B8C1BCBBA38F8E96A4B0B4AFADA4AC
C3C9C5C6BCA5999EA29E9E9F878282848FA4A6A6978C8B83879296999A949C9A93918F87
8B91957E86847E83927F7B888E9BA3ABA59795989991938A7B6A676F7D8E91928D8C99B8
D4E0D8CAB4B3B2B3B6AE977C7A77747693949A96
939DA5B2B0B4AC949398887E7C6F6261616E757D7E7A746F79859298A08C847B79757D76
6D68686C717A78736872736E747A78868D97A4A69C9B897E7A727A7D8387867D7E838699
9C9D8E96A5ABB8C1C6B6B3A1977E827C8E9DA7A0988F858694B9B8B7B7B0A4A5B5AA9F8B
80728283939BA1929599A59B9F9F988F969D908B
837A78767673869A978A97A19395938472788195A4B2B0ACA29D938E8F9BA0ACAEADA6A4
9E9C9A9C979DABB2B8BEC0B9BEB6AFA49D83797E8C97ACBEBFBFB4B4B7BAC8B8C2B2AA88
9B93A9B4A09A87705C767E919BA49B9074655B667D98A6C1BA948F8B8A8BACA8A092966D
6A6D60556A615E6F778795ABBDCFD6DBC5AFA393
C3D1D4CFBDB69681899B9FABC9E0FEFFFFFFD7AB89767C888A8F9A9187867F77808C8D96
A3ADABACAE9F9797938F9591948B867D8F909EABAB998E8783817E75625D4C807E8D889F
677069747A8B93A3A9AFB4ACA89E9C9DA8A5B3A28B7A866D77899D8C8F8A7E8397A0A5C2
B6ACBBD1C0C6C5B6A19388776B6F717C94A3A5BB
837E787A8487A1B0ABA098827D78625F6A7287A2A7A6A39A99A39CA6B8B6BBBEB29E9F94
897A807C7E87918A857F7A7A6A767A787C8D8682858A9398A2AEB2C0B8B5B4948997978E
B5B2A7A29E8983857D6E63696A7C888F919A89939B978395908F87919EAEA69A8B755F69
7D938D7A726C596C847B7D8B86748784817C8984
8F908E84878D837E888889938A7A7C7062676F6A868F9398A28F94918786898991989797
9B9E9D9A9CA19FA3ACB1B0C1D1CDD7DFC1BBB9AA98A29589837E7F84A0A4B6C0B7A9B0A9
92989D928A999E96ABBDCBC4C6B7AAA5ACADBBABABAAA896A19E9FA99B8F8E9999BCC8BD
A7908394A2A6B5AEA0A8AFB5ABAF9C8983918F8B
9790929C938B8E92888F999CA1A7A8ACACAAB0B49FA49A9389938A9191938C8E8E93999B
999F9A9799877E7D797A897D6E6B685F7178807B87726F7182838D8B7A6F5F5A697C7F97
B0B2ACC0C0B4B4BE9F86817A728B999B9B93909A90949F9F9DA59A918782837A79727B83
9DB4C0B4AAADA4A3A7A89C9BA19CA5AFAAA09F9C
878C8A8F9EA8A2A7A9AC9E9E948C8B8F8E8F8A7877737C7F8788949193979F9A99978E8F
9993979B959A9A9592857187969DA5B49276787F7FABD0D6D2CEBCB4BCBCBDB9B69D937E
786F736D787C83748B9493869183807C81918C978FA096978B9B8C8F969B969AA09D9798
958C949599999A999E979B9C9EA2A6A7A39F968B
A2A69F9C968C898B827E938E929FA1929CA49BA7ADAC9FAFACAEACACA0968F8D8A838B86
848B918E8C929C9FA6B8B38F84827670A3C8C1C2CEAF84818079818385827F7B81858F97
979A9B99958F8D9692979BB4B1B4A49B8372667690878E94998AA6B0B2AEC6C1B5B4A793
8E949BA39A8E9387858882797977727C7F89909F
7E808A8D99A0A7A3AAA4929693898B9E948F928F8E95A0978E8272666F7B7F818D92939D
978E8C91929B999D97929BBDC4C0CDD0A39B9985707F7C82869AA7B0ADB3AC9F91979A94
939590919DA0ACB4B1B2AC9F8F8AA2C5D8ECF6D9CFBCC6C3B9A39B8F969D807A76707696
A29A8B858F938A938E86A0B1B8C2C9B3AC9E9687
B1A3A79B8C8B8E879296918F92909AA2A39C9B9893838481848A9DAFB7B4B9BEB1AFAFA3
A7AEA9A8AAA096978A8381766E726E647479839CAEA7B0A191888274888B898D9F939295
9992969B9A9B8F877F847A868C836E69595567737A8C837E84927E8E897C85A0A1A7B8A0
97948E878B85908C8F97926F766E656486939BA4
8B9BA1ADB9B9B8AE968B959197A093818184858F909B9B9F9FAAA498968F8B8B97989D9F
9F9C9EA29FA0A6A7B9C2C6B8B4A8A1A6ACA19A9084808A9298939CA7A2AAB4B7B0A9A8A6
ADACB3A19B8C8B8D9496ADA9A7A7AA9994907F706D6C677D8B82958F8B8B9B8C9D99948E
878280898390959B969A8FAA9FA7B0C59BA09895
A19B86807A777687A0A8A39E988D8E9BA6A7AAA9A7A5A4A4A69FA0A7999B989283837C78
7275766E777C78757269677F85939EAA9DA3A5A39FA6A19FA3A3948B7C797474737D7C82
7C80828B8B9495969D998D8E8F8D8D97ADBEC9CEC6B3B19E979EA38F8B928F939A9BABB0
B8B9C2AAAE989A98A7A8A39B9D8C898B93969998
89838F827E7C817E7F879297A2A5A49A958C898380868A8A878B837C84868182848D94A6
AEB1AAA89D9BA1A1A6A79E8A918B837B887D767C837E878E8D97999DA4A5A5B3B2ABABB0
ABA8A39F94968E89878F979BA5A69C8C826A677C87A0ABA190908891A0B0ADABA4AF9994
7E7F7C8B92A0A79F948F9F8C8B8B7F70857C8188
9A9F9DA4ACB2B2B0A79E9897979B9D9E98A0A4A6A19F9F9EA7AFB7B4B8B5C5CACDBAAC91
877E8B96A09B9D9791909BA1A4989B9FA3ACBBBCBDB8ABACA3999396848B8C918E989B92
908F98929B9FA8A0978C817079879A9BA6A5A2867E75727083878D878B827A7A736D6F88
97A9A5B1A6A7A1AD9CA29AA09EADB6BFB4B4B4A7
AAAEB0AEA09B968E878C7E6F6F73737E918E8D6A726A605E766B6A71707B6E6A696E7795
A4B0AFA7989798A1A09F9B918790989B9D988C80777882838E9097898C8B90859290888E
969498A09B9FA19E9F9D8C83888E93A9BEBEB4B3ACA39BA9B0B9B4BAA7918989979DA59C
987D77756B696A8496A49FA8948E7A7576797491
79707C8090979FAFB0ACB2C3B0AA9F93808D90C2D6D9D8D4AFA2A7A7ACACABAAAAAEAC9F
978F8B818D8F8B868F9191A2A7A4969186898E9DA49F9F9F9597939695938F9C8C8F9191
8C998C8B8E8D8B9299939FC3B9B3AD94676A707E9499A7A7A290989E9FABB6A7938C766E
75818C97A4A59F7A7469737D9EA6B4B2AB9B9982
8B9287878A7C7B7A878C9DA9B7B8C0C2BFBBB3B2A0A09B9D8C938887888A969B9C969485
858785898F8B878E9491938C83848B828A8C86838686837E878E9DA1A69C9A8B93908E8C
8D878B8F8F8E909898A5A4938B8D80899B908C8A86807F786E62626A748B9FAFB4AEA7A6
A3A8AFB4B7B0B0BDBDA7A29E99909CA89D9A9A94
B7ADA19E8E968F8D888C8277767C797C88837A5A575E6D7AA9AFB2B2A398918A869796A0
A9B1B4B8B4B3AB9D9EA19BA1A399949E9B9CA7ABA5A8B3ABA8A3978F938B8F979D9FA7A2
9B8E89899194959481746E7171879DAFB7BFC0B19B9D9BA2B7D9D9D5CAAE8A80777D8D9A
9CA0968B7D888B89849486786F787571899CA0B0
8D92A6ACAEB4C4BFB3A29A83746D717172759AB8BFBBB8946E6A5E5E70878B9DA0938D8F
7E73726F68798C9599A29B8F979D999AA09B978D94918B8B968F8F9097A0A19B8F8A7D80
8CA4A2A5A19B959CB1C1D0D0BCA3907E6F7779888AA19B997D6E5B6062718B8E969A9890
90979BA0A9AB9D969B97A2AAB2A9A4A19E939497
8F8F87808A8B838793A1A4BFCECDD4D9D0CAB59D938A859EADA9ACAA967E807579878B8E
9FA7A5B1B99E968F84778F918D8D8B837C7E818F939F9C9F9CA3A6BBB5ABA5A7AEC1C7D5
CBA7A3A191899C918578797C8B988F9B989588A3988F868FA2B7C3C0C9B3998B8C7D7E86
988E9A909391A1AFB4A9A19E8589988B8C939383
878B9B9C726234362D415672535C4A1D1C4D4479979F977D505573719DB9AB8B6761719C
8EA19A8979B8BFB89E9E8795A0BEC4C6B3A38B8884958E95625B51494071695060434A40
4C69A3627084755099898C7B8A4C7862727EB7B3CA94897F4A4B71595E858FB3CCC5C1A7
8A7562676169655A596F5564838B80A8A68D7B94
8F8E8A8FAEC4F2E9F4D8BD97B6B5D0FBFBC7C68C7478859ED2DACEDFC2A7AFC8E1DDD49F
9E8387939E6E69799499A39A93767E838E8FA7968D7F9388B8C4CFC3CDB1BCD4CEE8D1C9
C4B779C3C3B4A8CF95B2B2C7C2F1CED8D1C3948380AABEBCDCBE9CAB997C8372668294AD
B2BECCC8C8B8BEBBBCBCE7D8C8B0A4857C8A9E8E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`003@3oool0
1020P800SXj>08j>SP20P8020:^[Z`05061PH02WYjL0oooo0?ooo`0k>c/00P29RHT01@2NWYh0T92@
092@T01fMWH0PX:20080oooo00D0GemO0:>SX`2SXj<0VIVI0:6QX@020:FUY@0404=3@`3oool0oooo
05=CD`80PX:200D0VIVI09^KV`20P800P82006m_K`020?ooo`0505EEE@2ATI40T92@092@T02;Rh/0
0P2ZZZX01@0o?cl0oooo08R8R028R8P0PX:20080TI6A00D0VYZJ09BDU02DU9@0O7al0?ooo`02061P
H00508V9R@2?Shl0Shn?0:2PX02TY:@00P2GUiL0102=SHd0?Shn03hn?P3oool206ATI00509:BTP2?
Shl0Vi^K09^KV`1HF5P00P2EUID01@3oool0;bl_08j>SP2>SXh0[:b/0080WIfM00D0Cdm?09JFUP2F
UYH0oooo03Ti>@0209fMW@0509bLW02JVYX0VYZJ05QHF02GUiL00P3oool01@1<C4`0^KVi0;Vi^@2V
YZH0UIFE0080KFe]00@0gMgM0<30`030`<00@D510P2OWil01@2IVIT0V9RH03De=@0e=CD0oooo0080
Ogmo00D0Lg=c09fMW@2BTY80TY:B08j>SP0204i>CP050?ooo`15ADD0ADE508b<S02OWil00P2<S8`0
1@0n?Sh0oooo0?ooo`2VYZH0GUiN0080X:2P00D0VIVI07AdM01dM7@0/k>c0<g=c@0206UYJ@0409NG
U`2JVYX0VYZJ09NGU`80;2`/00D0oooo07emO@1gMgL0MgMg09ZJVP0209NGU`05065QH@36a/H0f][J
0=[JfP1RHV800P2=SHd01@2VYZH0UYJF09JFUP0Y:BT0oooo0080DU9B00<0UIFE05IFEP1FEUH02`3o
ool0101EEED0DE5A055AD@1=CDd204a<C00504i>CP1@D500De=C05=CD`1HF5P00P1IFET01@1NGUh0
HF5Q065QH@1SHf<0I6AT0080IFEU00D0HV9R061PH01PH600H61P065QH@0205aLG00405UIF@1GEeL0
EeMG05IFEP80DU9B00@0DE5A05EEE@1CDe<0De=C0`1BDU801@1EEED0DU9B05=CD`1CDe<0EeMG0080
EUIF00D0EEEE051@D01BDU80DU9B051@D00205IFEP0505YJFP1QHF40HF5Q069RHP1TI6@00P1RHV80
101PH600GemO05mOG`1MGEd305]KF`0405YJFP1LG5`0G5aL05eMG@@0GUiN0P1OGel00`1UIFD0IVIV
06IVIP0206IVIP80IFEU00@0GUiN05eMG@1MGEd0Fe]K0P1JFUX0101IFET0F5QH05QHF01HF5P305YJ
FP0505eMG@1PH600HV9R069RHP1TI6@00P1WIfL01@1UIFD0H61P05iNGP1NGUh0GEeM0080G5aL00<0
Fe]K05iNGP1NGUh00P1MGEd205mOG`05065QH@1RHV80HV9R065QH@1RHV800P1PH600101NGUh0GEeM
05eMG@1MGEd205]KF`0505eMG@1LG5`0FUYJ05YJFP1KFe/00`1LG5`0101NGUh0Fe]K05]KF`1GEeL2
05ADE00405=CD`1ADE40E5AD05ADE0<0EeMG00D0FUYJ05mOG`1OGel0HF5Q06ATI00206IVIP04065Q
H@1LG5`0G5aL05]KF`@0FEUI0P1GEeL305EEE@0505IFEP1GEeL0FUYJ05YJFP1LG5`00P1KFe/00`1G
EeL0oooo0?ooo`0=0?ooo`003@3oool01028R8P0SXj>08j>SP1VIVH20=gMg@0505iNGP2IVIT0oooo
0?ooo`1IFET00P26QXH01@2QXJ40T92@092@T023Ph<0RHV90080f=SH00D0NGUi09nOW`2OWil0Q8B4
0;Bd]0020;^k^`0403hn?P3oool0oooo06e]K@80Q8B400D0V9RH09bLW027QhL0QhN708V9R@020?Sh
n00506QXJ02CTi<0TI6A096AT@1bLW800P3@d=001@1DE5@0jNWY09:BTP2BTY80Q8B40080UYJF00D0
UIFE09>CT`2CTi<0RHV90>WYj@0206m_K`0508n?S`2BTY80TY:B08F5Q@39bLT00P2EUID01020P800
F5QH05QHF03oool206e]K@050:2PX02?Shl0Shn?08n?S`1bLW800P2<S8`01@3oool0@41008f=S@2=
SHd0alO70080QXJ600D0HV9R0:NWY`2WYjL0o_kn051@D00208n?S`0509fMW@2XZ:P0Z:RX07=cL`2=
SHd00P3Ti>@01@1FEUH0WinO09nOW`30`<00WYjN0080Kfm_00@0bLW90;>c/`2c/k<0FEUI0P2MWId0
1@2IVIT0UiNG04i>CP1>CTh0oooo0080Rh^;00D0M7Ad09:BTP2`/;00/;2`08R8R00205iNGP050?oo
o`1GEeL0EeMG08f=S@2RXZ800P29RHT01@1DE5@0oooo0?ooo`2WYjL0Jf][0080VIVI00D0V9RH09:B
TP2BTY80VYZJ0<;2`P0207AdM00409NGU`2MWId0WIfM09FEU@80?clo00@0oooo08F5Q@1mOGd0OGem
0`2HV9P01@1VIVH0c/k>0;Zj^P2j^[X0M7Ad0080TI6A00D0YjNW09ZJVP2JVYX0@D510?ooo`0206QX
J00409FEU@22PX80PX:20<o?c`X0oooo00@0:RXZ028R8P0R8R80:2PX0P0e=CD01@0f=SH0<S8b02d]
;@0];Bd08R8R0080410@00D02@T900h>3P0>3Ph05QHF020P800202XZ:P<0<c<c00D0;Rh^03De=@0i
>CT0>CTi03Xj>P0203Ti>@0303Ph>00];Bd0;Bd]0080;Bd]0P0b<S8303Lg=`0502l_;`0[:b/0;Bd]
02d];@0e=CD00P0o?cl01@14A4@0Bd];04U9B@19BDT0ATI60080ADE500D0Bd];04I6AP16ATH0@410
03Ph>002034a<@<0:2PX00D0;2`/030`<00e=CD0=CDe03Lg=`0203Ph>00503Ti>@0j>SX0>SXj03Lg
=`0i>CT00P0o?cl01@0k>c/0?3`l03`l?00o?cl0?Cdm0080>CTi00<0@T9204E5A@15ADD00`14A4@0
1@13@d<0@41003hn?P0n?Sh0?clo0080@T920P0j>SX203Ti>@0503@d=00a<C40<C4a03lo?`17AdL0
0P1<C4`0101CDe<0FUYJ05YJFP1FEUH204m?C`05055AD@1=CDd0C4a<04a<C01>CTh00P1BDU801@1E
EED0F5QH05aLG01LG5`0GUiN0080GEeM00D0G5aL05eMG@1MGEd0Fe]K05QHF00205ADE005055AD@1>
CTh0CTi>04e=C@1?Cdl00P1BDU801@1DE5@0FEUI05UIF@1KFe/0GEeM0080H61P0`1QHF401@1MGEd0
FUYJ05YJFP1HF5P0EEEE0080De=C00@0EUIF05QHF01HF5P0FEUI0`1KFe/0101LG5`0GEeM05eMG@1K
Fe/205QHF00505]KF`1NGUh0FUYJ05YJFP1@D5000P15ADD00`0h>3P0oooo0?ooo`0=0?ooo`003@3o
ool01028R8P0SXj>08j>SP1VIVH20=gMg@0505iNGP2IVIT0oooo0?ooo`1IFET00P26QXH01@2QXJ40
T92@092@T023Ph<0RHV90080f=SH00D0NGUi09nOW`2OWil0Q8B40;Bd]0020;^k^`0403hn?P3oool0
oooo06e]K@80Q8B400D0V9RH09bLW027QhL0QhN708V9R@020?Shn00506QXJ02CTi<0TI6A096AT@1b
LW800P3@d=001@1DE5@0jNWY09:BTP2BTY80Q8B40080UYJF00D0UIFE09>CT`2CTi<0RHV90>WYj@02
06m_K`0508n?S`2BTY80TY:B08F5Q@39bLT00P2EUID01020P800F5QH05QHF03oool206e]K@050:2P
X02?Shl0Shn?08n?S`1bLW800P2<S8`01@3oool0@41008f=S@2=SHd0alO70080QXJ600D0HV9R0:NW
Y`2WYjL0o_kn051@D00208n?S`0509fMW@2XZ:P0Z:RX07=cL`2=SHd00P3Ti>@01@1FEUH0WinO09nO
W`30`<00WYjN0080Kfm_00@0bLW90;>c/`2c/k<0FEUI0P2MWId01@2IVIT0UiNG04i>CP1>CTh0oooo
0080Rh^;00D0M7Ad09:BTP2`/;00/;2`08R8R00205iNGP050?ooo`1GEeL0EeMG08f=S@2RXZ800P29
RHT01@1DE5@0oooo0?ooo`2WYjL0Jf][0080VIVI00D0V9RH09:BTP2BTY80VYZJ0<;2`P0207AdM004
09NGU`2MWId0WIfM09FEU@80?clo00@0oooo08F5Q@1mOGd0OGem0`2HV9P01@1VIVH0c/k>0;Zj^P2j
^[X0M7Ad0080TI6A00D0YjNW09ZJVP2JVYX0@D510?ooo`0206QXJ00409FEU@22PX80PX:20<o?c`X0
oooo00@0:RXZ028R8P0R8R80:2PX0P0e=CD01@0f=SH0<S8b02d];@0];Bd08R8R0080410@00D02@T9
00h>3P0>3Ph05QHF020P800202XZ:P<0<c<c00D0;Rh^03De=@0i>CT0>CTi03Xj>P0203Ti>@0303Ph
>00];Bd0;Bd]0080;Bd]0P0b<S8303Lg=`0502l_;`0[:b/0;Bd]02d];@0e=CD00P0o?cl01@14A4@0
Bd];04U9B@19BDT0ATI60080ADE500D0Bd];04I6AP16ATH0@41003Ph>002034a<@<0:2PX00D0;2`/
030`<00e=CD0=CDe03Lg=`0203Ph>00503Ti>@0j>SX0>SXj03Lg=`0i>CT00P0o?cl01@0k>c/0?3`l
03`l?00o?cl0?Cdm0080>CTi00<0@T9204E5A@15ADD00`14A4@01@13@d<0@41003hn?P0n?Sh0?clo
0080@T920P0j>SX203Ti>@0503@d=00a<C40<C4a03lo?`17AdL00P1<C4`0101CDe<0FUYJ05YJFP1F
EUH204m?C`05055AD@1=CDd0C4a<04a<C01>CTh00P1BDU801@1EEED0F5QH05aLG01LG5`0GUiN0080
GEeM00D0G5aL05eMG@1MGEd0Fe]K05QHF00205ADE005055AD@1>CTh0CTi>04e=C@1?Cdl00P1BDU80
1@1DE5@0FEUI05UIF@1KFe/0GEeM0080H61P0`1QHF401@1MGEd0FUYJ05YJFP1HF5P0EEEE0080De=C
00@0EUIF05QHF01HF5P0FEUI0`1KFe/0101LG5`0GEeM05eMG@1KFe/205QHF00505]KF`1NGUh0FUYJ
05YJFP1@D5000P15ADD00`0h>3P0oooo0?ooo`0=0?ooo`003@3oool0102DU9@0SHf=08f=S@1?Cdl2
0?ooo`0505EEE@2LW9`0hN7Q0>7Qh@1aLG400P29RHT01@2OWil0Ti>C09>CT`2ATI40S8b<0080][Jf
00D0RXZ:09fMW@2MWId0Kfm_0<C4a0020=3@d00404=3@`3?cll0clo?08R8R080QXJ600D0V9RH09bL
W02?Shl0Shn?09nOW`020<30`00507moO`2EUID0TY:B09:BTP1GEeL00P3oool01@1FEUH0^;Rh0:>S
X`2SXj<0QXJ60080WIfM00D0T92@09BDU02DU9@0SXj>0<O7a`020861P@0509ZJVP2@T900T92@06UY
J@3clo<00P2>SXh0101lO7`0L71`071`L03EeMD207alO0050:NWY`2ATI40Q8B408B4Q02<S8`00P2A
TI401@3lo?`0Cdm?08R8R028R8P0gmoO0080Ng]k00D0M7Ad0:f][@2][Jd0b/[:06i^KP0208J6QP05
09^KV`2^[Zh0[Zj^09JFUP1oOgl00P37alL01@1/K6`0NWYj07YjNP3Kfm/0ZZZZ0080KVi^00@0/K6a
0:j^[P2^[Zh0KVi^0P2JVYX01@2IVIT0VYZJ06ATI01TI6@0j^[Z0080U9BD00D0Ng]k07moO`3=cLd0
cLg=08b<S00206ATI0050?Gem@1/K6`0K6a/08j>SP2UYJD00P23Ph<01@1ZJVX0inOW0>OWi`2XZ:P0
MGEe0080UiNG00D0QHF50<71`@31`L40Q8B40;Jf]P0207emO@0409>CT`2TY:@0Y:BT08^;R`80E5AD
00D0oooo0:JVYP1_Kfl0Kfm_09JFUP0208Z:RP050820P03@d=00WinO09nOW`20P8000P2FUYH01@2T
Y:@0VYZJ09ZJVP1HF5P0kNg]0080OGem00@0TY:B09>CT`2CTi<0[Zj^2P3oool01039bLT0c/k>0<k>
cP3;bl/20<30`0050<71`@3=cLd0fMWI0=WIf@3WinL00P3jn_X01@3no_h0m_Kf0?KfmP3[jn/0h>3P
0080dm?C00@0aLG50<30`030`<00`l?30`2l_;`0102n_[h0alO70<O7a`38b<P20=GEe@050=SHf03F
e]H0c/k>0<k>cP37alL00P31`L401@2o_kl0_Kfm0;Jf]P2f][H0ZZZZ0080WYjN00D0UYJF09FEU@2I
VIT0VIVI09jNWP020:6QX@0309nOW`2PX:00X:2P0080XJ6Q0P2MWId01@2GUiL0TI6A096AT@2:RXX0
QhN70080RHV900@0Shn?08Z:RP2:RXX0QXJ60P20P8001@1gMgL0LG5a07=cL`1cLg<0KVi^0080JVYZ
00D0IfMW06=SH`1KFe/0Fe]K05UIF@0305mOG`80GEeM00D0GUiN05]KF`1ADE40DE5A059BDP0205EE
E@0505eMG@1TI6@0K6a/06a/K01cLg<00P1hN7P01@1aLG40JVYZ05eMG@1MGEd0CDe=0080?clo00D0
>SXj03Ph>00h>3P0?Cdm0451@@0203dm?@0503<c<`0/;2`0;2`/01dM7@0B4Q800P0F5QH0100B4Q80
4A4A014A4@0A4A42010@400500P8200C4a<07alO01lO7`0U9BD00P0Y:BT01@0];Bd09RHV024Q8@0Q
8B40820P008071`L0P0J6QX201HF5P0401DE5@0N7Qh07QhN02<S8`8092@T00<09bLW02TY:@0X:2P0
0P0X:2P202/[:`0502h^;P0b<S80>CTi03Ti>@0m?Cd00P0n?Sh01@13@d<0@D510451@@0i>CT0<C4a
0080BDU900@0Hf=S08F5Q@25QHD0ZZZZ3`3oool000d0oooo00@0XJ6Q092@T02@T900=cLg0P3oool0
1@19BDT0WinO0;Rh^02h^;P0Q8B40080TI6A00D0W9bL09RHV02HV9P0U9BD09^KV`0209ZJVP0509NG
U`2IVIT0VIVI05MGE`3Fe]H00P3Shn<0101<C4`0XZ:R0::RXP2EUID208^;R`0509VIV@2QXJ40VIVI
09VIV@2KVi/00P2TY:@01@2>SXh0UiNG09>CT`2CTi<0?Cdm0080oooo00D0Bd];09FEU@2XZ:P0Z:RX
09>CT`0209ZJVP0509:BTP2CTi<0Ti>C09BDU02RXZ800P2EUID01@2UYJD0Shn?08n?S`1@D500oooo
0080RHV900@0MgMg08J6QP26QXH0Z:RX0P28R8P01@2YZJT0U9BD08J6QP26QXH0VIVI0080Vi^K00D0
`l?306e]K@20P800P8200?Gem@0206i^KP0508J6QP2`/;00/;2`09^KV`2<S8`00P1iNGT01@2MWId0
]kNg0;Ng]`2^[Zh0Lg=c0080Xj>S00D0UIFE04Y:BP1:BTX0n_[j0;Bd]00206e]K@0409fMW@2PX:00
X:2P08V9R@<0UYJF00@0Vi^K0820P020P800_;bl0P2NWYh01@23Ph<0K6a/0>o_k`3_knl0QhN70080
L71`00D0bLW90820P020P800U9BD0:6QX@0208>3P`0507alO03?cll0clo?0:JVYP1mOGd00P2HV9P0
1@1VIVH0o?cl0?clo01bLW80XZ:R0080QHF500@0Shn?0:VYZ@2YZJT0NWYj0P1`L7001@3Ogml0eMGE
05mOG`1OGel0SXj>0080OWin00D0VIVI0=KFeP23Ph<0Ph>308V9R@0209bLW0050:6QX@2IVIT0VIVI
06i^KP39bLT00P2ATI40102?Shl0XJ6Q0:6QX@2@T90:0?ooo`0402/[:`0a<C40<C4a02h^;P80;Bd]
00@0:RXZ028R8P0I6AT06ATI100G5aL201HF5P0501TI6@0O7al092@T02@T900[:b/00P0c<c<00`0b
<S80<30`02`/;00202`/;080:2PX00<0:b/[02d];@0];Bd00P0];Bd2038b<P0503Lg=`0m?Cd0?Cdm
04E5A@1<C4`00P1@D5001@1=CDd0CTi>04i>CP1>CTh0BTY:0080BDU900<0CDe=04a<C01<C4`01017
AdL0101>CTh0GUiN05iNGP1]KFd207MgM`0508>3P`27QhL0OGem07emO@1lO7`00P23Ph<01@25QHD0
Rh^;08^;R`2EUID0V9RH0080SHf=00D0TY:B09>CT`2CTi<0U9BD09jNWP020:n_[`040:b/[02WYjL0
YjNW0;2`/080/[:b00D0];Bd0;^k^`35aLD0aLG50<C4a0020<71`@050<30`02n_[h0];Bd0;Bd]02Z
ZZX00P2YZJT01@2UYJD0Z:RX0;Jf]P2f][H0`l?30080c<c<00D0dm?C0=[JfP3Jf]X0e]KF0=WIf@02
0>7Qh@050>OWi`3Ph>00h>3P0>SXj03/k>`00P3Vi^H0103YjNT0m?Cd0?Cdm03gmoL20?KfmP050?gm
o@3fm_H0l?3`0?3`l03[jn/00P3WinL01@3Ng]h0fm_K0=cLg03Lg=`0gMgM0080fm_K00D0emOG0=GE
e@3>c/h0c/k>0<G5a@020;bl_0050;Zj^P2g]kL0]kNg0;Bd]02b/[800P2^[Zh01@2YZJT0Z:RX0:RX
Z02SXj<0VYZJ0080TI6A00@0R8R807alO01lO7`0Ng]k0P25QHD01@2@T900VYZJ08Z:RP2:RXX0MGEe
0080FUYJ00<0?clo0?ooo`3oool03@3oool000d0oooo00@0XJ6Q092@T02@T900=cLg0P3oool01@19
BDT0WinO0;Rh^02h^;P0Q8B40080TI6A00D0W9bL09RHV02HV9P0U9BD09^KV`0209ZJVP0509NGU`2I
VIT0VIVI05MGE`3Fe]H00P3Shn<0101<C4`0XZ:R0::RXP2EUID208^;R`0509VIV@2QXJ40VIVI09VI
V@2KVi/00P2TY:@01@2>SXh0UiNG09>CT`2CTi<0?Cdm0080oooo00D0Bd];09FEU@2XZ:P0Z:RX09>C
T`0209ZJVP0509:BTP2CTi<0Ti>C09BDU02RXZ800P2EUID01@2UYJD0Shn?08n?S`1@D500oooo0080
RHV900@0MgMg08J6QP26QXH0Z:RX0P28R8P01@2YZJT0U9BD08J6QP26QXH0VIVI0080Vi^K00D0`l?3
06e]K@20P800P8200?Gem@0206i^KP0508J6QP2`/;00/;2`09^KV`2<S8`00P1iNGT01@2MWId0]kNg
0;Ng]`2^[Zh0Lg=c0080Xj>S00D0UIFE04Y:BP1:BTX0n_[j0;Bd]00206e]K@0409fMW@2PX:00X:2P
08V9R@<0UYJF00@0Vi^K0820P020P800_;bl0P2NWYh01@23Ph<0K6a/0>o_k`3_knl0QhN70080L71`
00D0bLW90820P020P800U9BD0:6QX@0208>3P`0507alO03?cll0clo?0:JVYP1mOGd00P2HV9P01@1V
IVH0o?cl0?clo01bLW80XZ:R0080QHF500@0Shn?0:VYZ@2YZJT0NWYj0P1`L7001@3Ogml0eMGE05mO
G`1OGel0SXj>0080OWin00D0VIVI0=KFeP23Ph<0Ph>308V9R@0209bLW0050:6QX@2IVIT0VIVI06i^
KP39bLT00P2ATI40102?Shl0XJ6Q0:6QX@2@T90:0?ooo`0402/[:`0a<C40<C4a02h^;P80;Bd]00@0
:RXZ028R8P0I6AT06ATI100G5aL201HF5P0501TI6@0O7al092@T02@T900[:b/00P0c<c<00`0b<S80
<30`02`/;00202`/;080:2PX00<0:b/[02d];@0];Bd00P0];Bd2038b<P0503Lg=`0m?Cd0?Cdm04E5
A@1<C4`00P1@D5001@1=CDd0CTi>04i>CP1>CTh0BTY:0080BDU900<0CDe=04a<C01<C4`01017AdL0
101>CTh0GUiN05iNGP1]KFd207MgM`0508>3P`27QhL0OGem07emO@1lO7`00P23Ph<01@25QHD0Rh^;
08^;R`2EUID0V9RH0080SHf=00D0TY:B09>CT`2CTi<0U9BD09jNWP020:n_[`040:b/[02WYjL0YjNW
0;2`/080/[:b00D0];Bd0;^k^`35aLD0aLG50<C4a0020<71`@050<30`02n_[h0];Bd0;Bd]02ZZZX0
0P2YZJT01@2UYJD0Z:RX0;Jf]P2f][H0`l?30080c<c<00D0dm?C0=[JfP3Jf]X0e]KF0=WIf@020>7Q
h@050>OWi`3Ph>00h>3P0>SXj03/k>`00P3Vi^H0103YjNT0m?Cd0?Cdm03gmoL20?KfmP050?gmo@3f
m_H0l?3`0?3`l03[jn/00P3WinL01@3Ng]h0fm_K0=cLg03Lg=`0gMgM0080fm_K00D0emOG0=GEe@3>
c/h0c/k>0<G5a@020;bl_0050;Zj^P2g]kL0]kNg0;Bd]02b/[800P2^[Zh01@2YZJT0Z:RX0:RXZ02S
Xj<0VYZJ0080TI6A00@0R8R807alO01lO7`0Ng]k0P25QHD01@2@T900VYZJ08Z:RP2:RXX0MGEe0080
FUYJ00<0?clo0?ooo`3oool03@3oool000d0oooo00@0WIfM09>CT`2CTi<09bLW0P3oool01@12@T80
W9bL0;>c/`2c/k<0R8R800<0UIFE0P2LW9`01@2ATI40Vi^K09^KV`2KVi/0VIVI0080UYJF00D0BDU9
0>7Qh@3dm?@0m?Cd04A4A00209nOW`0509:BTP2ATI40TI6A09bLW02MWId00P2KVi/01@2BTY80XJ6Q
0:6QX@2EUID0W9bL0080Shn?00D09bLW0?ooo`3oool0>c/k08Z:RP020:j^[P0309>CT`2KVi/0Vi^K
00<0TY:B00D0V9RH09>CT`2NWYh0WYjN0:ZZZP0208j>SP0503De=@3oool0QXJ608J6QP1]KFd00P2D
U9@01@2HV9P0QHF508F5Q@2][Jd0UYJF0080QXJ600D0YjNW09ZJVP2JVYX0X:2P07emO@0207]kN`04
0?ooo`1PH600H61P092@T080^[Zj00D0M7Ad0::RXP1aLG40LG5a09RHV0020<C4a0050<O7a`1SHf<0
Ti>C09>CT`2NWYh00P0a<C401@3oool0][Jf065QH@1QHF40TY:B0080W9bL00D0VYZJ09NGU`2GUiL0
VIVI09BDU00209NGU`0509nOW`2GUiL0UiNG092@T01KFe/00P3oool01024Q8@0O7al07alO02NWYh2
09FEU@0509ZJVP2OWil0QXJ608J6QP2<S8`00P2e]KD01@2NWYh0RHV909VIV@2IVIT0B4Q80080oooo
00D0GEeM08^;R`2@T900T92@096AT@020:RXZ00506YZJP2?Shl0Shn?0<S8b03^k^h00P1FEUH01@26
QXH0KFe]06e]K@2m_Kd0d];B0080JFUY00<0TY:B0:FUY@2UYJD00`2HV9P01@27QhL0Xj>S0:2PX02P
X:00Shn?0080^[Zj00<0MgMg0?ooo`3oool0203oool305MGE`0505]KF`1OGel0GemO069RHP1PH600
0P1OGel0101KFe/0E5AD05ADE01@D50204m?C`0504i>CP1=CDd0C4a<04a<C01?Cdl00`1BDU80101E
EED0F5QH05QHF01GEeL205IFEP0505EEE@1BDU80DU9B051@D01<C4`00P19BDT01@16ATH0ADE504E5
A@12@T80A4A40080C4a<00D0De=C05MGE`1GEeL0GEeM061PH00205YJFP0405ADE01BDU80DU9B055A
D@80D51@0P1ADE4204Y:BP0504Q8B014A4@0A4A403dm?@0j>SX00P0n?Sh0100i>CT0=SHf03Hf=P0h
>3P203De=@0503<c<`0b<S80=cLg03Lg=`0j>SX00P11@D401@15ADD0@T9203dm?@0m?Cd0?Shn0080
=3@d00@0:BTY02LW9`0W9bL08b<S0`0O7al01@0L71`06a/K01/K6`0G5aL03`l?00804a<C00<06ATI
01XJ6P0J6QX00P0J6QX201DE5@<04A4A0`0B4Q801@0?3`l03@d=00/;2`0;2`/03`l?00806a/K00D0
8B4Q02DU9@0W9bL09bLW02@T900201dM7@0301hN7P0Q8B408B4Q00808b<S0P0T92@01@0W9bL0:BTY
02TY:@0a<C40=cLg0080>SXj00D0?3`l0492@P12@T80B4Q8051@D00205]KF`04069RHP1NGUh0GUiN
05EEE@80EeMG00D0FEUI05eMG@1WIfL0IfMW07AdM00207=cL`0507QhN01nOWh0R8R808R8R02ATI40
0P2NWYh01@2JVYX0TY:B09:BTP29RHT0PX:20080LG5a00@0JVYZ06EUI@1UIFD0GUiN3`3oool000d0
oooo00@0Vi^K09FEU@2EUID0>c/k0P3oool01@15ADD0Y:BT0:b/[02/[:`0RHV90080S8b<00D0/;2`
09>CT`2CTi<0TI6A09^KV`0209VIV@0509ZJVP2EUID0UIFE055AD@3Bd]800P3]kNd00`1BDU80V9RH
09RHV003096AT@050:^[Z`2MWId0TY:B09:BTP2CTi<00P2MWId209VIV@80TY:B00D0=CDe0?ooo`3o
ool0?3`l09:BTP020:^[Z`0408n?S`2ZZZX0ZZZZ09>CT`80R8R800D0V9RH09JFUP2LW9`0W9bL0;2`
/00208Z:RP0503De=@3oool0R8R808R8R01/K6`00P2HV9P01@2KVi/0RHV908V9R@2SXj<0WIfM0080
QXJ600D0YjNW09RHV02HV9P0Xj>S07UiN@0207alO0040?ooo`1RHV80HV9R08f=S@80_Kfm00D0LW9b
09nOW`1bLW80LW9b09fMW@020<;2`P050<c<c01RHV80SXj>08j>SP2OWil00P0Z:RX01@3oool0_kno
05MGE`1GEeL0SXj>0080WinO0`2LW9`01@2DU9@0VIVI09NGU`2GUiL0U9BD0080W9bL00D0TI6A04Q8
B03oool0oooo07UiN@0207QhN00509:BTP2QXJ40XJ6Q09jNWP2IVIT00P2=SHd01@2<S8`0YjNW0:NW
Y`2SXj<0Shn?0080UYJF00D0:RXZ0?ooo`3oool0D51@07IfMP0208n?S`0409bLW02UYJD0YJFU06=S
H`80YJFU00D0`<300>KViP1PH600H61P08:2PP02065QH@050=WIf@39bLT0FUYJ05YJFP2CTi<00P2/
[:`309JFUP0509RHV02BTY80XJ6Q0:6QX@2>SXh00P2NWYh00`2FUYH0oooo0?ooo`080?ooo`<0HV9R
00<0HF5Q05iNGP1NGUh00P1NGUh205mOG`04065QH@1UIFD0IFEU06EUI@80IVIV00D0I6AT069RHP1P
H600H61P05iNGP0205aLG0@0GEeM0`1NGUh0101MGEd0GUiN05iNGP1NGUh405mOG`80GEeM0P1LG5`2
05QHF00505IFEP1EEED0EEEE059BDP1?Cdl00P1BDU8305=CD`0405IFEP1JFUX0FUYJ05eMG@<0GUiN
00<0H61P05mOG`1OGel00P1NGUh205eMG@0405aLG01OGel0GemO05iNGP80H61P00D0J6QX06a/K01]
KFd0KFe]06i^KP0206YZJP05065QH@1MGEd0FEUI05UIF@1FEUH00P1HF5P01@1IFET0FUYJ05YJFP1J
FUX0Fe]K0080HF5Q00<0HV9R065QH@1QHF400P1QHF4505aLG00505eMG@1NGUh0GemO05mOG`1PH600
0P1RHV8406=SH`04069RHP1PH600H61P05eMG@80FUYJ00<0FEUI05MGE`1EEED0101EEED0101ADE40
Cdm?04m?C`1?Cdl304e=C@0304i>CP1?Cdl0Cdm?0080C4a<0P17AdL01@13@d<0?clo03lo?`0m?Cd0
>CTi0080=cLg00@0=3@d038b<P0b<S80=3@d0`0c<c<00`0e=CD0>CTi03Ti>@0403@d=004038b<P0/
;2`0;2`/02XZ:P809bLW00D09RHV02TY:@0Y:BT0;2`/02d];@0203Xj>P0404E5A@1>CTh0CTi>05QH
F0l0oooo000=0?ooo`0409bLW02EUID0UIFE05ADE080oooo00D0EeMG0:>SX`2QXJ40XJ6Q08j>SP02
07IfMP050=kNgP1oOgl0Ogmo096AT@2KVi/00`2JVYX209>CT`0506EUI@30`<00fMWI0=WIf@1TI6@0
0P2EUID01@2@T900Ph>308>3P`3>c/h0SHf=0080SXj>00D0Ti>C0:2PX02PX:00UYJF09bLW00209:B
TP0504a<C03oool0oooo0492@P2EUID00P2XZ:P0101iNGT0d];B0=;BdP24Q8@208R8R00509^KV`2F
UYH0VYZJ09ZJVP2_[jl00P28R8P01@1@D500oooo08R8R028R8P0NGUi0080UiNG00D0R8R80:f][@2]
[Jd0VYZJ09>CT`02092@T0050:2PX02TY:@0Y:BT09JFUP1lO7`00P22PX80103clo<0MGEe07EeM@2?
Shl20:RXZ00507=cL`2h^;P0MGEe07EeM@2LW9`00P2a/K401@34a<@0Kfm_08n?S`2?Shl0WYjN0080
@d=300D0oooo0;Fe]@1OGel0GemO08j>SP0209^KV`050:j^[P2GUiL0UiNG08n?S`2LW9`00P2GUiL0
1@2FUYH0Vi^K09^KV`2FUYH0EEEE0080oooo00@0PH6107moO`1oOgl0RXZ:0P2`/;001@2RXZ80TI6A
08j>SP2>SXh0RXZ:0080ZJVY00D0XZ:R08n?S`2IVIT0VIVI030`<0020?ooo`05065QH@1bLW80QXJ6
08J6QP2^[Zh00P2KVi/01@1QHF40ZZZZ0:ZZZP2k^k/0h^;R0080I6AT00D0Ph>306=SH`1SHf<0fm_K
0;Jf]P0206e]K@04096AT@2[Zj/0Zj^[09JFUP80VIVI00D0Shn?09VIV@2NWYh0WYjN096AT@020:JV
YP0308Z:RP3oool0oooo00P0oooo00@0EEEE051@D01@D500CDe=0P1>CTh0101=CDd0BTY:04i>CP1>
CTh304m?C`04059BDP1ADE40DE5A05ADE0<0EEEE00@0F5QH05YJFP1JFUX0EUIF0`1DE5@00`1ADE40
Cdm?04m?C`04055AD@04051@D01ADE40DE5A059BDP<0E5AD00@0F5QH05YJFP1JFUX0G5aL0P1MGEd0
101PH600GUiN05iNGP1NGUh305eMG@0505]KF`1JFUX0FUYJ05UIF@1GEeL01@1HF5P205]KF`H0F5QH
0P1KFe/205YJFP80F5QH00<0E5AD051@D01@D5000P1DE5@205UIF@0405aLG01NGUh0GUiN05mOG`80
H61P00<0HF5Q069RHP1NGUh01@1NGUh0101MGEd0HF5Q065QH@1RHV8406=SH`80HF5Q00<0GemO05aL
G01LG5`00`1JFUX01@1IFET0FUYJ05]KF`1KFe/0G5aL0080GemO0P1QHF42069RHP04065QH@1MGEd0
GEeM05]KF`@0FUYJ0P1HF5P01@1GEeL0EUIF05IFEP1EEED0F5QH0080G5aL00D0GEeM05iNGP1NGUh0
G5aL05QHF00205EEE@0405IFEP1JFUX0FUYJ069RHP<0IFEU00<0HV9R05aLG01LG5`0101HF5P00`1J
FUX0GEeM05eMG@0305aLG00305eMG@1LG5`0G5aL0080Fe]K0P1IFET0101HF5P0EeMG05MGE`1EEED?
0?ooo`003@3oool0102LW9`0UIFE09FEU@1DE5@20?ooo`0505MGE`2SXj<0XJ6Q0:6QX@2>SXh00P1f
MWH01@3Ng]h0Ogmo07moO`2ATI40Vi^K00<0VYZJ0P2CTi<01@1UIFD0`<300=WIf@3IfMT0I6AT0080
UIFE00D0T92@08>3P`23Ph<0c/k>08f=S@0208j>SP0509>CT`2PX:00X:2P09JFUP2LW9`00P2BTY80
1@1<C4`0oooo0?ooo`12@T80UIFE0080Z:RX00@0NGUi0=;BdP3Bd]80Q8B40P28R8P01@2KVi/0UYJF
09ZJVP2JVYX0[jn_0080R8R800D0D51@0?ooo`28R8P0R8R807UiN@0209NGU`0508R8R02][Jd0[Jf]
09ZJVP2CTi<00P2@T9001@2PX:00Y:BT0:BTY02FUYH0O7al0080PX:200@0lo?c07EeM@1eMGD0Shn?
0P2XZ:P01@1cLg<0^;Rh07EeM@1eMGD0W9bL0080/K6a00D0a<C406m_K`2?Shl0Shn?09jNWP0204=3
@`050?ooo`2e]KD0GemO05mOG`2>SXh00P2KVi/01@2^[Zh0UiNG09NGU`2?Shl0W9bL0080UiNG00D0
UYJF09^KV`2KVi/0UYJF05EEE@020?ooo`040861P@1oOgl0Ogmo08Z:RP80/;2`00D0XZ:R096AT@2>
SXh0SXj>08Z:RP020:VYZ@050::RXP2?Shl0VIVI09VIV@0`<3000P3oool01@1QHF40LW9b08J6QP26
QXH0[Zj^0080Vi^K00D0HF5Q0:ZZZP2ZZZX0^k^k0>;RhP0206ATI00508>3P`1SHf<0Hf=S0=_Kf`2f
][H00P1]KFd0102ATI40Zj^[0:^[Z`2FUYH209VIV@0508n?S`2IVIT0WYjN09jNWP2ATI400P2VYZH0
0`2:RXX0oooo0?ooo`080?ooo`0405EEE@1@D500D51@04e=C@80CTi>00@0CDe=04Y:BP1>CTh0CTi>
0`1?Cdl0101BDU80DE5A055AD@1DE5@305EEE@0405QHF01JFUX0FUYJ05IFEP<0E5AD00<0DE5A04m?
C`1?Cdl0101ADE40101@D500DE5A055AD@1BDU8305ADE00405QHF01JFUX0FUYJ05aLG080GEeM00@0
H61P05iNGP1NGUh0GUiN0`1MGEd01@1KFe/0FUYJ05YJFP1IFET0EeMG00D0F5QH0P1KFe/605QHF080
Fe]K0P1JFUX205QHF00305ADE01@D500D51@0080E5AD0P1IFET0101LG5`0GUiN05iNGP1OGel2061P
H003065QH@1RHV80GUiN00D0GUiN00@0GEeM065QH@1QHF40HV9R101SHf<2065QH@0305mOG`1LG5`0
G5aL00<0FUYJ00D0FEUI05YJFP1KFe/0Fe]K05aLG00205mOG`80HF5Q0P1RHV80101QHF40GEeM05eM
G@1KFe/405YJFP80F5QH00D0EeMG05IFEP1FEUH0EEEE05QHF00205aLG00505eMG@1NGUh0GUiN05aL
G01HF5P00P1EEED0101FEUH0FUYJ05YJFP1RHV8306EUI@03069RHP1LG5`0G5aL00@0F5QH00<0FUYJ
05eMG@1MGEd00`1LG5`00`1MGEd0G5aL05aLG00205]KF`80FEUI00@0F5QH05MGE`1GEeL0EEEE3`3o
ool000d0oooo00@0W9bL09>CT`2CTi<0L71`0P3WinL01@1`L700WinO09fMW@2MWId0TY:B0080GEeM
00@0oooo06MWI`1WIfL0TI6A0`2IVIT01@2KVi/0V9RH09RHV01gMgL0[Jf]0080alO700@0M7Ad09BD
U02DU9@0TI6A0P1_Kfl01@3gmoL0NGUi08f=S@2=SHd0TY:B0080X:2P00D0UIFE09^KV`2DU9@0U9BD
06QXJ0020?ooo`0505aLG02DU9@0XZ:R0::RXP1XJ6P00P3clo<01@1hN7P0QHF508F5Q@2MWId0Vi^K
0080V9RH00D0YZJV08j>SP2>SXh0Jf][0>GUi@0208n?S`0407moO`2HV9P0V9RH07moO`80`/;200D0
V9RH08V9R@2KVi/0Vi^K09JFUP020:JVYP0509>CT`20P800SHf=08f=S@3IfMT00P22PX801@2@T900
X:2P0:2PX01cLg<0c/k>0080LG5a00D0WYjN0:RXZ02XZ:P0/K6a0820P00209:BTP0509ZJVP1MGEd0
GEeM0>?Sh`2_[jl00P1ZJVX0102?Shl0TI6A096AT@36a/H208^;R`0508j>SP2KVi/0VIVI09VIV@2G
UiL00P2KVi/01@2FUYH0J6QX0>c/k03/k>`0Q8B40080QXJ600D0MGEe0=;BdP3Bd]80XZ:R08F5Q@02
096AT@0508Z:RP2VYZH0YZJV0:2PX02CTi<00P2HV9P01@12@T80oooo0?ooo`1dM7@0LW9b0080LG5a
00@0fMWI08B4Q024Q8@0J6QX0P2/[:`01@2l_;`0alO707=cL`1cLg<0R8R80080KFe]00D0b/[:0:n_
[`1kNg/0Ng]k08^;R`0209nOW`050;Fe]@2<S8`0S8b<08j>SP2JVYX00P2GUiL0102FUYH0/K6a0;6a
/@20P80:0?ooo`0306ATI01[Jf/0Jf][00@0KVi^00@0IFEU05MGE`1GEeL0De=C0P1?Cdl00`1<C4`0
CTi>04i>CP0205ADE080EEEE00@0F5QH05YJFP1JFUX0GemO0`1TI6@0101KFe/0De=C05=CD`1;Bd/2
04U9B@0504Y:BP1ADE40EeMG05MGE`1LG5`00`1IFET0101MGEd0EeMG05MGE`1>CTh204U9B@050451
@@0b<S80<C4a034a<@0g=cL00P0l?3`01@12@T80Bd];04];B`1BDU80E5AD0080De=C00D0GEeM061P
H01PH600G5aL05MGE`0205EEE@0404=3@`0e=CD0=CDe02d];@809BDU00D07alO01dM7@0N7Qh07QhN
024Q8@0202PX:00503<c<`0j>SX0?Cdm03dm?@0n?Sh00P0m?Cd01@0d=3@0<30`030`<00];Bd0;Rh^
00<0<C4a0P0d=3@203Hf=P80>3Ph00D0>c/k03`l?00l?3`0?Shn03lo?`0203/k>`0403`l?011@D40
@D5104=3@`80ATI600D0BDU904M7A`15ADD0ADE504I6AP0204A4A0030492@P17AdL0B4Q80080B4Q8
0P1<C4`01@1@D500DE5A055AD@1CDe<0F5QH00D0FEUI00D0Fe]K05YJFP1JFUX0FUYJ05UIF@0205MG
E`0505ADE01@D500Cdm?04m?C`1CDe<00P1LG5`306ATI00506=SH`1PH600GEeM05eMG@1IFET00P1K
Fe/00`1NGUh0GemO05aLG00705aLG00405eMG@1LG5`0G5aL05aLG0<0FUYJ00<0G5aL0?ooo`3oool0
3@3oool000d0oooo00@0VYZJ09>CT`2CTi<0Rh^;0P2f][H01@2;Rh/0WIfM09JFUP2FUYH0V9RH0080
ADE500D0oooo05IFEP1FEUH0Vi^K09>CT`0209^KV`0509JFUP2JVYX0VYZJ092@T02FUYH00P2e]KD0
1026QXH0U9BD09BDU02CTi<2061PH0050?ooo`1TI6@0TI6A096AT@2BTY800P2PX:001@2EUID0V9RH
09RHV02HV9P0PX:20080cLg=00D0NWYj09BDU02LW9`0W9bL05EEE@020?ooo`0506QXJ023Ph<0Ph>3
0:2PX02LW9`00P2MWId01@2IVIT0UYJF09JFUP1mOGd0`L710080UYJF00@0Q8B409ZJVP2JVYX0L71`
0P3Fe]H01@2NWYh0OWin09ZJVP2JVYX0W9bL0080X:2P00D0TY:B08R8R02EUID0UIFE0;^k^`0208j>
SP05092@T02IVIT0VIVI07MgM`3Lg=`00P1aLG4309bLW0050:RXZ02<S8`0UYJF09JFUP2GUiL00P1d
M7@01@36a/H0ZZZZ07EeM@1eMGD0SHf=0080Q8B400D0iNGU07emO@1mOGd0SXj>09ZJVP0209NGU`05
09^KV`2HV9P0V9RH09VIV@1jNWX00P39bLT0102<S8`0SXj>08j>SP1OGel20?7al@050:NWY`1gMgL0
TY:B09:BTP2<S8`00P2OWil01@2QXJ40UYJF09NGU`2GUiL0H61P0080oOgm00D0QHF507UiN@1KFe/0
Fe]K0?ooo`0207MgM`05071`L02ZZZX0ZZZZ0;Rh^02UYJD00P28R8P01@2>SXh0NWYj07YjNP2k^k/0
Y:BT0080R8R800@0QHF509FEU@2EUID0e]KF0P1lO7`01@2;Rh/0VYZJ09>CT`2CTi<0W9bL0080/[:b
00<0OGem0?ooo`3oool0203oool0101dM7@0Lg=c07=cL`1dM7@207IfMP0507MgM`26QXH0Shn?08n?
S`2CTi<00P2HV9P01@2IVIT0TY:B09:BTP2>SXh0S8b<0080Rh^;00D0QXJ608N7Q`27QhL0QhN708F5
Q@0208J6QP0409>CT`2IVIT0VIVI0:6QX@80Xj>S00D0XJ6Q09ZJVP2HV9P0V9RH096AT@0209BDU005
09NGU`2ATI40UiNG09NGU`2PX:000P2WYjL01@2_[jl0^[Zj0;bl_02l_;`0/[:b0080YjNW00@0Vi^K
096AT@2ATI40QHF50`22PX801@1jNWX0NGUi07UiN@1oOgl0RXZ:0080U9BD00@0XJ6Q0:n_[`2_[jl0
^k^k0P32`/801@33`l<0b/[:0<c<c03<c<`0bLW90080aLG500D0_kno0;jn_P2i^KT0^KVi0;Jf]P02
0;:b/P030:f][@2YZJT0ZJVY0080[:b/0P2ZZZX01@2_[jl0ZZZZ0:ZZZP2RXZ80WIfM0080Vi^K00D0
W9bL09jNWP2NWYh0W9bL09ZJVP0209BDU00408f=S@26QXH0QXJ60820P080NGUi0P1dM7@207IfMP05
07EeM@1nOWh0OWin0820P01fMWH00P1_Kfl0101ZJVX0Fe]K05]KF`1EEED205=CD`0504m?C`19BDT0
BDU904U9B@18B4P00P15ADD00`13@d<0DE5A059BDP02059BDP80EUIF00D0Fe]K05MGE`1LG5`0G5aL
06=SH`0206EUI@<0H61P00D0G5aL05EEE@1ADE40DE5A04i>CP020410@00403<c<`0Z:RX07alO01lO
7`<061PH00D06ATI01XJ6P0J6QX06QXJ01hN7P02030`<00404A4A01GEeL0EeMG06][J`l0oooo000=
0?ooo`0409ZJVP2CTi<0Ti>C08^;R`80][Jf00D0Rh^;09fMW@2FUYH0UYJF09RHV00204E5A@050?oo
o`1FEUH0EUIF09^KV`2CTi<00P2KVi/01@2FUYH0VYZJ09ZJVP2@T900UYJF0080]KFe00@0QXJ609BD
U02DU9@0Ti>C0P1PH6001@3oool0I6AT096AT@2ATI40TY:B0080X:2P00D0UIFE09RHV02HV9P0V9RH
08:2PP020<g=c@0507YjNP2DU9@0W9bL09bLW01EEED00P3oool01@1XJ6P0Ph>308>3P`2PX:00W9bL
0080WIfM00D0VIVI09JFUP2FUYH0OGem0<71`@0209JFUP0408B4Q02JVYX0VYZJ071`L080e]KF00D0
WYjN07inOP2JVYX0VYZJ09bLW0020:2PX00509:BTP28R8P0UIFE09FEU@2k^k/00P2>SXh01@2@T900
VIVI09VIV@1gMgL0g=cL0080LG5a0`2LW9`01@2XZ:P0S8b<09JFUP2FUYH0UiNG0080M7Ad00D0a/K6
0:ZZZP1eMGD0MGEe08f=S@0208B4Q0050>GUi@1mOGd0OGem08j>SP2JVYX00P2GUiL01@2KVi/0V9RH
09RHV02IVIT0NWYj0080bLW900@0S8b<08j>SP2>SXh0GemO0P3alO401@2WYjL0MgMg09:BTP2BTY80
S8b<0080WinO00D0XJ6Q09JFUP2GUiL0UiNG061PH0020?gmo@0508F5Q@1iNGT0Fe]K05]KF`3oool0
0P1gMgL01@1`L700ZZZZ0:ZZZP2h^;P0YJFU0080R8R800D0SXj>07YjNP1jNWX0^k^k0:BTY00208R8
R00408F5Q@2EUID0UIFE0=KFeP80O7al00D0Rh^;09ZJVP2CTi<0Ti>C09bLW0020;:b/P0307emO@3o
ool0oooo00P0oooo00@0M7Ad07=cL`1cLg<0M7Ad0P1fMWH01@1gMgL0QXJ608n?S`2?Shl0Ti>C0080
V9RH00D0VIVI09:BTP2BTY80SXj>08b<S00208^;R`0508J6QP27QhL0QhN708N7Q`25QHD00P26QXH0
102CTi<0VIVI09VIV@2QXJ420:>SX`050:6QX@2JVYX0V9RH09RHV02ATI400P2DU9@01@2GUiL0TI6A
09NGU`2GUiL0X:2P0080YjNW00D0[jn_0;Zj^P2l_;`0_;bl0;:b/P020:NWY`0409^KV`2ATI40TI6A
08F5Q@<0PX:200D0NWYj07UiN@1iNGT0Ogmo08Z:RP0209BDU0040:6QX@2_[jl0[jn_0;^k^`80`/;2
00D0`l?30<[:bP3<c<`0c<c<0<W9b@020<G5a@050;no_`2n_[h0^KVi0;Vi^@2f][H00P2b/[800`2]
[Jd0ZJVY0:VYZ@020:b/[080ZZZZ00D0[jn_0:ZZZP2ZZZX0XZ:R09fMW@0209^KV`0509bLW02NWYh0
WYjN09bLW02JVYX00P2DU9@0102=SHd0QXJ608J6QP20P80207UiN@80M7Ad0P1fMWH01@1eMGD0OWin
07inOP20P800MWIf0080Kfm_00@0JVYZ05]KF`1KFe/0EEEE0P1CDe<01@1?Cdl0BDU904U9B@19BDT0
B4Q80080ADE500<0@d=3055AD@1BDU800P1BDU8205IFEP0505]KF`1GEeL0G5aL05aLG01SHf<00P1U
IFD3061PH00505aLG01EEED0DE5A055AD@1>CTh00P10@400100c<c<0:RXZ01lO7`0O7al301PH6005
01TI6@0J6QX06QXJ01XJ6P0N7Qh00P0`<3001014A4@0EeMG05MGE`1[Jf/?0?ooo`003@3oool0102N
WYh0UYJF09JFUP2GUiL209BDU00509^KV`2NWYh0V9RH09RHV02EUID00P0_;bl01@3oool0C4a<04a<
C02NWYh0TI6A0080Ti>C00D0V9RH09ZJVP2JVYX0XZ:R08^;R`020:>SX`0409>CT`2>SXh0SXj>09FE
U@80EEEE00D0oooo05]KF`2;Rh/0Rh^;09JFUP0209nOW`0509FEU@2CTi<0XJ6Q0:6QX@2BTY800P2P
X:001@2DU9@0VIVI09FEU@2EUID0AdM70080oooo00<0EeMG08F5Q@25QHD00P2NWYh209bLW00509:B
TP2OWil0WinO09JFUP2JVYX00P2IVIT0102?Shl0VIVI09VIV@1EEED20?Ogm`050:2PX01fMWH0W9bL
09bLW02KVi/00P2SXj<01@2<S8`0UYJF09ZJVP2JVYX0W9bL0080VIVI00D0T92@096AT@2ATI40Q8B4
0>KViP0206i^KP0509bLW02DU9@0U9BD09^KV`2IVIT00`2GUiL208Z:RP050:RXZ02VYZH0P8200820
P02<S8`00P1hN7P01@3oool0KVi^06i^KP2>SXh0VYZJ0080UYJF00D0VIVI09bLW02LW9`0UiNG08V9
R@020:f][@0409:BTP2DU9@0U9BD04a<C080oooo00D0XZ:R06a/K02CTi<0Ti>C096AT@0209VIV@05
09jNWP2KVi/0UiNG09NGU`1mOGd00P3:b/X01@2ATI40PX:204E5A@15ADD0oooo0080KFe]00D0MgMg
0:BTY02TY:@0Zj^[092@T00209VIV@0509BDU02;Rh/0Rh^;0:>SX`2PX:000P2EUID0101nOWh0TY:B
09:BTP3[jn/2075aL@0508V9R@2KVi/0T92@092@T02PX:000P2g]kL00`1eMGD0oooo0?ooo`080?oo
o`0404=3@`11@D40@D5103hn?P80?3`l00@0?Cdm03/k>`0o?cl0?clo0`11@D401@12@T80ADE504E5
A@11@D40?Shn0080?Cdm00@0>c/k03Hf=P0f=SH0=CDe0`0g=cL0100f=SH0>c/k03/k>`0j>SX203Ti
>@80>SXj0`0f=SH203@d=005030`<00/;2`0:b/[02/[:`0W9bL00`0S8b<302`/;004038b<P0i>CT0
>CTi03hn?P80>c/k1`11@D401@0o?cl0>SXj03De=@0e=CD0>SXj0080>3Ph00D0<S8b02l_;`0_;bl0
<30`02LW9`0202<S8`<092@T00D0820P01`L700N7Qh07QhN020P800202HV9P0503Ph>015ADD0ADE5
04Y:BP1?Cdl00P1ADE401@1=CDd0Cdm?04m?C`1EEED0G5aL0080Fe]K00D0EEEE055AD@1ADE40D51@
055AD@0205iNGP0406YZJP1bLW80LW9b07YjNP80PH6100D0Q8B408F5Q@25QHD0QHF508>3P`0207Qh
N00507EeM@1lO7`0Q8B408B4Q028R8P00P2IVIT01@2PX:00XZ:R0::RXP2UYJD0[Zj^00<0/K6a0P2c
/k<01@2f][H0YZJV0:FUY@2UYJD0YZJV0080Y:BT00D0WIfM0:JVYP2RXZ80XZ:R09VIV@0208n?S`05
08f=S@2>SXh0SXj>09:BTP2LW9`00P2UYJD01@2_[jl0_;bl0;bl_039bLT0clo?0080e=CD00<0g=cL
0=WIf@3IfMT00`3Hf=P01@3MgMd0fMWI0;^k^`2k^k/0W9bL0080OWin00<0GemO0?ooo`3oool03@3o
ool000d0oooo00@0Vi^K09RHV02HV9P0V9RH0P2IVIT01@2KVi/0W9bL09bLW02LW9`0U9BD0080>3Ph
00D0oooo05iNGP1NGUh0UYJF09>CT`0209JFUP0409VIV@2HV9P0V9RH09jNWP<0V9RH00@0UYJF09:B
TP2BTY80VIVI0P1?Cdl01@3oool0EUIF08n?S`2?Shl0V9RH00<0VIVI00@0UIFE0:6QX@2QXJ40Shn?
0P2WYjL209JFUP80Shn?00@0Cdm?0?ooo`3oool0D51@0P2>SXh01@2JVYX0XJ6Q09bLW02LW9`0T92@
0080XZ:R00@0UiNG09RHV02JVYX0VYZJ0`2CTi<01@16ATH0oooo0?ooo`2KVi/0Lg=c0080WIfM00D0
V9RH0:BTY02TY:@0Rh^;09fMW@0309NGU`80UIFE00D0Ti>C092@T02@T900PX:20?[jnP0206ATI005
09FEU@2@T900T92@09JFUP2MWId00P2QXJ401@2GUiL0TY:B09:BTP2NWYh0VYZJ0080RHV900@0QXJ6
07inOP1nOWh0oooo0P1HF5P01@2QXJ40SXj>09RHV02HV9P0WinO0080UYJF00D0Ti>C09fMW@2BTY80
TY:B09^KV`0209NGU`0503hn?P3oool0oooo0:2PX01QHF400P2EUID01@2ATI40WIfM09fMW@2FUYH0
WIfM0080V9RH00D0Vi^K09RHV02HV9P0WIfM08f=S@02034a<@040?ooo`1NGUh0GUiN07YjNP80WYjN
00D0WinO09FEU@2HV9P0V9RH09JFUP0209FEU@05096AT@2TY:@0W9bL09bLW01eMGD00P2CTi<01@3m
oOd0J6QX06QXJ02<S8`0UIFE0080T92@00@0YZJV0:FUY@2UYJD0P8202P3oool00`1OGel0H61P061P
H005061PH080HF5Q00<0GEeM05UIF@1IFET00`1GEeL0101HF5P0H61P06EUI@1UIFD306UYJ@0506MW
I`1RHV80HF5Q065QH@1PH6000P1RHV8306=SH`03069RHP1SHf<0H61P0080H61P0P1QHF401@1TI6@0
IVIV06IVIP1VIVH0IFEU0080I6AT00<0H61P05eMG@1NGUh00P1NGUh205eMG@0305mOG`1QHF40HF5Q
0080H61P0P1QHF401@1NGUh0GEeM05eMG@1LG5`0Fe]K0080G5aL0`1KFe/01@1JFUX0F5QH05QHF01F
EUH0F5QH0080FUYJ00@0Fe]K05aLG01LG5`0GEeM101OGel205eMG@0505UIF@1CDe<0De=C04i>CP18
B4P00P16ATH304E5A@0504A4A015ADD0A4A404A4A016ATH00P19BDT01@1;Bd/0BDU904I6AP16ATH0
@T920080?Shn00D0>SXj03Ph>00h>3P0>3Ph03Ti>@0203Xj>P0503/k>`0n?Sh0?Shn03dm?@0i>CT0
0P0f=SH0100g=cL0<c<c03<c<`0a<C43038b<P0302/[:`0Y:BT0:BTY00<0:RXZ00@0:BTY02/[:`0[
:b/0:b/[0`0Z:RX01@0`<300;Bd]02h^;P0^;Rh0;bl_0080<30`00D0;2`/02d];@0];Bd0;Bd]02/[
:`0202PX:00302HV9P0T92@092@T00808B4Q0`0X:2P302XZ:P80:b/[00D09RHV02PX:00c<c<0<c<c
0451@@0204a<C00305MGE`3oool0oooo00d0oooo000=0?ooo`0409JFUP2<S8`0S8b<0:ZZZP80YJFU
00D0SHf=09fMW@2LW9`0W9bL09:BTP02059BDP050?ooo`1^KVh0KVi^09RHV02ATI400`2HV9P209FE
U@05092@T034a<@0OWin07inOP2FUYH00P2BTY801@2KVi/0G5aL05aLG03oool0Hf=S0080Ti>C00@0
V9RH09VIV@2IVIT0W9bL0`2ATI401@2j^[X0TY:B09:BTP2BTY80U9BD0080Ti>C00@0IFEU0?ooo`3o
ool0Hf=S0P2?Shl01@2IVIT0X:2P09bLW02LW9`0S8b<0080VIVI00@0/k>c08f=S@2IVIT0VIVI0`2C
Ti<01@1HF5P0kno_0>o_k`2MWId0OWin0080XJ6Q00D0UYJF0::RXP2RXZ80RHV9092@T0020:f][@04
09FEU@2ATI40TI6A09FEU@80Ti>C00D0TI6A0=gMg@1YJFT0JFUY09RHV002096AT@0509VIV@2JVYX0
W9bL09bLW02JVYX00P2KVi/01@2FUYH0WYjN08^;R`2;Rh/0RHV90080P82000D0moOg06UYJ@1YJFT0
WinO08j>SP0209JFUP0509bLW02NWYh0WYjN092@T02HV9P00P2KVi/0102FUYH0V9RH09RHV01:BTX2
0?ooo`0509JFUP1ZJVX0VIVI09VIV@2@T9000P2HV9P01@2IVIT0XJ6Q09NGU`2GUiL0VYZJ00<0VIVI
00@0RHV903hn?P0n?Sh0oooo0P1RHV801@1iNGT0WYjN09jNWP2OWil0V9RH0080U9BD00D0V9RH09FE
U@2EUID0Ti>C0:BTY00209JFUP04071`L02ATI40TI6A0?ooo`80H61P00D0TY:B08f=S@2DU9@0U9BD
0:^[Z`0209>CT`0308j>SP3oool0oooo00P0oooo00@0Hf=S069RHP1RHV80HF5Q0P1OGel01@1MGEd0
FUYJ05QHF01HF5P0FEUI0080GemO00D0Hf=S06MWI`1WIfL0Jf][06UYJ@0206EUI@05065QH@1OGel0
GemO05mOG`1QHF400`1RHV8205mOG`0505YJFP1HF5P0F5QH05MGE`1HF5P00P1KFe/00`1OGel0H61P
061PH002061PH0L0HF5Q0`1OGel2069RHP0506=SH`1WIfL0IfMW06IVIP1UIFD00`1RHV82065QH@05
06=SH`1UIFD0IVIV06IVIP1RHV800P1PH60505mOG`80GUiN00D0GEeM05aLG01LG5`0Fe]K05YJFP03
05]KF`80FEUI101HF5P0101IFET0Fe]K05]KF`1MGEd3061PH0<0GUiN00D0GEeM05YJFP1JFUX0F5QH
05UIF@0305eMG@80GUiN0`1PH6001@1NGUh0G5aL05aLG01LG5`0Fe]K00<0FUYJ00@0G5aL05eMG@1M
GEd0GUiN0P1RHV800`1QHF40H61P061PH002061PH0<0G5aL0`1MGEd00`1KFe/0G5aL05aLG00305eM
G@0305]KF`1NGUh0GUiN00@0GUiN00@0GemO05eMG@1MGEd0GEeM1P1NGUh205eMG@80GemO0`1NGUh0
1@1OGel0GUiN05iNGP1KFe/0FUYJ00<0Fe]K0P1LG5`00`1PH600oooo0?ooo`0=0?ooo`003@3oool0
102FUYH0S8b<08b<S02ZZZX20:FUY@0508f=S@2MWId0W9bL09bLW02BTY800P1BDU801@3oool0KVi^
06i^KP2HV9P0TI6A00<0V9RH0P2EUID01@2@T900a<C407inOP1nOWh0UYJF0080TY:B00D0Vi^K05aL
G01LG5`0oooo06=SH`0209>CT`0409RHV02IVIT0VIVI09bLW0<0TI6A00D0^[Zj09:BTP2BTY80TY:B
09BDU00209>CT`0406EUI@3oool0oooo06=SH`80Shn?00D0VIVI0:2PX02LW9`0W9bL08b<S00209VI
V@040;>c/`2=SHd0VIVI09VIV@<0Ti>C00D0F5QH0>o_k`3_knl0WIfM07inOP020:6QX@0509JFUP2R
XZ80XZ:R08V9R@2@T9000P2][Jd0102EUID0TI6A096AT@2EUID209>CT`05096AT@3MgMd0JFUY06UY
J@2HV9P00P2ATI401@2IVIT0VYZJ09bLW02LW9`0VYZJ0080Vi^K00D0UYJF09jNWP2;Rh/0Rh^;08V9
R@020820P0050?Ogm`1YJFT0JFUY09nOW`2>SXh00P2FUYH01@2LW9`0WYjN09jNWP2@T900V9RH0080
Vi^K00@0UYJF09RHV02HV9P0BTY:0P3oool01@2FUYH0JVYZ09VIV@2IVIT0T92@0080V9RH00D0VIVI
0:6QX@2GUiL0UiNG09ZJVP0309VIV@0408V9R@0n?Sh0?Shn0?ooo`80HV9R00D0NGUi09jNWP2NWYh0
WinO09RHV00209BDU00509RHV02EUID0UIFE09>CT`2TY:@00P2FUYH0101`L700TI6A096AT@3oool2
061PH00509:BTP2=SHd0U9BD09BDU02[Zj/00P2CTi<00`2>SXh0oooo0?ooo`080?ooo`0406=SH`1R
HV80HV9R065QH@80GemO00D0GEeM05YJFP1HF5P0F5QH05UIF@0205mOG`0506=SH`1WIfL0IfMW06][
J`1YJFT00P1UIFD01@1QHF40GemO05mOG`1OGel0HF5Q00<0HV9R0P1OGel01@1JFUX0F5QH05QHF01G
EeL0F5QH0080Fe]K00<0GemO061PH01PH6000P1PH607065QH@<0GemO0P1RHV801@1SHf<0IfMW06MW
I`1VIVH0IFEU00<0HV9R0P1QHF401@1SHf<0IFEU06IVIP1VIVH0HV9R0080H61P1@1OGel205iNGP05
05eMG@1LG5`0G5aL05]KF`1JFUX00`1KFe/205UIF@@0F5QH00@0FEUI05]KF`1KFe/0GEeM0`1PH603
05iNGP0505eMG@1JFUX0FUYJ05QHF01IFET00`1MGEd205iNGP<0H61P00D0GUiN05aLG01LG5`0G5aL
05]KF`0305YJFP0405aLG01MGEd0GEeM05iNGP80HV9R00<0HF5Q061PH01PH6000P1PH60305aLG0<0
GEeM00<0Fe]K05aLG01LG5`00`1MGEd00`1KFe/0GUiN05iNGP0405iNGP0405mOG`1MGEd0GEeM05eM
G@H0GUiN0P1MGEd205mOG`<0GUiN00D0GemO05iNGP1NGUh0Fe]K05YJFP0305]KF`80G5aL00<0H61P
0?ooo`3oool03@3oool000d0oooo00@0TI6A08>3P`23Ph<0_Kfm0P2ZZZX01@24Q8@0Vi^K09bLW02L
W9`0TY:B0080Jf][00D0hN7Q08F5Q@25QHD0UYJF096AT@0209VIV@0509bLW02>SXh0SXj>07YjNP3d
m?@00P1WIfL0102IVIT0SXj>08j>SP2PX:0206i^KP050>GUi@1dM7@0UIFE09FEU@2FUYH00P2MWId0
1@2NWYh0T92@07alO01lO7`0i^KV0080MgMg00D0TI6A09NGU`2DU9@0U9BD07UiN@020>GUi@0506a/
K02BTY80TY:B09VIV@2MWId00P2LW9`01@2>SXh0R8R808R8R03De=@0PH610080UYJF00@0TI6A09FE
U@2EUID0IFEU0P3MgMd01@2JVYX0QXJ609nOW`2OWil0V9RH0080WinO00D0RXZ:07YjNP3Hf=P0f=SH
0861P@02092@T0@0UYJF00@0alO707AdM01dM7@0VIVI0P2CTi<01@2FUYH0VIVI09BDU02DU9@0Ti>C
0080`l?300D0MgMg0:^[Z`29RHT0RHV908R8R00208Z:RP050=kNgP1fMWH0MWIf09nOW`2>SXh00P22
PX801@2][Jd0^;Rh0;Rh^01lO7`0UiNG0080VIVI00@0UIFE09^KV`2KVi/0HF5Q0P3jn_X01@2CTi<0
NGUi09RHV02HV9P0Shn?0080QHF500D0/k>c0:FUY@2<S8`0S8b<09VIV@0209fMW@0509RHV028R8P0
E5AD05ADE03oool00P1dM7@01@1iNGT0XJ6Q0:6QX@2KVi/0RHV90080/;2`00D0Ti>C092@T02@T900
V9RH09nOW`0209:BTP0407YjNP2LW9`0W9bL0>g]k@80J6QX00D0VYZJ08n?S`2EUID0UIFE09nOW`02
0:^[Z`030861P@3oool0oooo00P0oooo00<07AdM01/K6`0K6a/00`0I6AT01@0M7Ad08B4Q02TY:@0Y
:BT0;2`/0080;Bd]00D0:RXZ02HV9P0V9RH06ATI01<C4`03014A4@804a<C00<051@D018B4P0@4100
0P0@410201HF5P0501/K6`0Q8B408B4Q02HV9P0Z:RX00P0V9RH01@0R8R807QhN01hN7P0I6AT04a<C
00804A4A00D0410@014A4@0A4A404A4A01XJ6P0201dM7@04020P800S8b<08b<S02DU9@808R8R00D0
9bLW02d];@0a<C40<C4a03@d=00203Hf=P0503@d=00a<C40;bl_02l_;`0e=CD00P0j>SX01@0o?cl0
@d=304=3@`19BDT0B4Q80080ATI60`15ADD404A4A00404=3@`18B4P0B4Q804Q8B080AdM70P18B4P2
0410@00303`l?00h>3P0>3Ph0080=3@d0P0e=CD0100j>SX0@4100410@015ADD30492@P0404=3@`12
@T80@T9204A4A080BTY:00D0C4a<04m?C`1CDe<0De=C05ADE00205EEE@0305IFEP1GEeL0EeMG00@0
EeMG00<0FEUI05YJFP1JFUX00P1KFe/305iNGP<0GEeM0`1NGUh305eMG@0505iNGP1OGel0H61P061P
H01QHF400`1SHf<4065QH@80H61P00D0GUiN05eMG@1MGEd0GUiN05eMG@0305]KF`80FEUI00D0EeMG
05IFEP1FEUH0FEUI05YJFP0205=CD`0404U9B@0n?Sh0?Shn02d];@l0oooo000=0?ooo`0408n?S`1f
MWH0MWIf0<o?c`80[jn_00D0Ng]k09ZJVP2MWId0WIfM08n?S`0208:2PP050;jn_P2CTi<0Ti>C092@
T02CTi<00P2FUYH01@2VYZH0QXJ608J6QP1XJ6P0oooo0080De=C00@0V9RH08Z:RP2:RXX0Y:BT0P1m
OGd01@33`l<0RHV9092@T02@T900V9RH0080WYjN00D0W9bL09:BTP1RHV80HV9R0?ooo`0205]KF`05
08j>SP2FUYH0UiNG09NGU`2@T9000P31`L401@1kNg/0UIFE09FEU@2FUYH0WIfM0080UIFE00D0UYJF
07IfMP1fMWH0n?Sh06i^KP0309>CT`80UIFE00D0M7Ad0<W9b@39bLT0UiNG08j>SP0209jNWP0509NG
U`2OWil0WinO08f=S@1PH6000P3oool0101XJ6P0Ti>C09>CT`2GUiL209ZJVP0509VIV@2f][H0OGem
07emO@2IVIT00P2DU9@01@2GUiL0VYZJ08b<S02<S8`0SXj>0080hN7Q00D0GUiN0;Bd]02>SXh0SXj>
08F5Q@0209JFUP050;jn_P27QhL0QhN709jNWP2=SHd00P1]KFd01@30`<00d=3@0=3@d01UIFD0VYZJ
0080VIVI00@0TY:B09^KV`2KVi/0N7Qh0P3Hf=P01@2@T900QXJ609VIV@2IVIT0SHf=0080N7Qh00D0
a/K60:ZZZP23Ph<0Ph>309RHV0020::RXP0509JFUP28R8P0K6a/06a/K03gmoL00`20P8020:6QX@05
09RHV01cLg<0gmoO0=oOg`26QXH00P28R8P01@2JVYX0W9bL09>CT`2CTi<0PX:20080XJ6Q00D0c/k>
07UiN@1iNGT0WIfM08j>SP0209JFUP0409:BTP2o_kl0_kno07YjNPX0oooo00@0bl_;0=?Cd`3Cdm<0
f][J0P3Ogml01@3Shn<0inOW0>3Ph03Ph>00g]kN0080f][J00D0fm_K0=cLg03Lg=`0i>CT0>?Sh`02
0>7Qh@050=WIf@3Kfm/0fm_K0=_Kf`3Ogml00P3UiND0103_knl0j^[Z0>[ZjP3Vi^H20=gMg@030=CD
e039bLT0alO70080alO70P3:b/X01@38b<P0e=CD0=WIf@3IfMT0g=cL0080gMgM00D0j>SX0=oOg`3G
emL0emOG0=3@d0020<O7a`050;jn_P2i^KT0^KVi0;6a/@2YZJT00P2NWYh01@2HV9P0Ti>C09>CT`2?
Shl0SXj>0080Ti>C00@0U9BD09:BTP2BTY80T92@0P2=SHd00`28R8P0PH6108:2PP0208:2PP80Ng]k
00D0NGUi07MgM`1aLG40LG5a06m_K`02079bLP<0NWYj00D0NGUi07IfMP1gMgL0MgMg07=cL`0307If
MP04075aL@1]KFd0KFe]06=SH`80FEUI00D0DU9B05]KF`1LG5`0G5aL05MGE`0205QHF005059BDP13
@d<0@d=303Ti>@0f=SH00P0_;bl01@0b<S80=3@d03@d=00i>CT0>c/k0080?3`l00@0A4A404E5A@15
ADD0?Shn0P0j>SX0100c<c<08b<S01PH600H61P401DE5@0401HF5P0I6AT06ATI01dM7@807QhN00D0
:BTY02XZ:P0[:b/0:b/[02XZ:P0202/[:`05024Q8@0S8b<08b<S02DU9@0W9bL00P0[:b/01@0b<S80
=CDe03De=@0f=SH0>CTi0080>SXj00<0=SHf03Lg=`0g=cL00`0h>3P01@0g=cL0>3Ph059BDP1BDU80
KVi^0080SXj>00<0[:b/0?ooo`3oool03@3oool000d0oooo00@0Shn?07IfMP1fMWH0clo?0P2_[jl0
1@1kNg/0VYZJ09fMW@2MWId0Shn?0080PX:200D0_[jn09>CT`2CTi<0T92@09>CT`0209JFUP050:JV
YP26QXH0QXJ606QXJ03oool00P1CDe<0102HV9P0RXZ:08Z:RP2TY:@207emO@050<?3``29RHT0T92@
092@T02HV9P00P2NWYh01@2LW9`0TY:B069RHP1RHV80oooo0080Fe]K00D0SXj>09JFUP2GUiL0UiNG
092@T0020<71`@0507]kN`2EUID0UIFE09JFUP2MWId00P2EUID01@2FUYH0MWIf07IfMP3hn?P0KVi^
00<0Ti>C0P2EUID01@1dM7@0bLW90<W9b@2GUiL0SXj>0080WYjN00D0UiNG09nOW`2OWil0SHf=061P
H0020?ooo`0406QXJ02CTi<0Ti>C09NGU`80VYZJ00D0VIVI0;Jf]P1mOGd0OGem09VIV@0209BDU005
09NGU`2JVYX0S8b<08b<S02>SXh00P3QhN401@1NGUh0];Bd08j>SP2>SXh0QHF50080UYJF00D0_[jn
08N7Q`27QhL0WYjN08f=S@0206e]K@050<30`03@d=00d=3@06EUI@2JVYX00P2IVIT0102BTY80Vi^K
09^KV`1hN7P20=SHf005092@T026QXH0VIVI09VIV@2=SHd00P1hN7P01@36a/H0ZZZZ08>3P`23Ph<0
V9RH0080XZ:R00D0UYJF08R8R01/K6`0K6a/0?Ogm`030820P080XJ6Q00D0V9RH07=cL`3Ogml0gmoO
08J6QP0208R8R00509ZJVP2LW9`0Ti>C09>CT`22PX800P2QXJ401@3>c/h0NGUi07UiN@2MWId0SXj>
0080UYJF00@0TY:B0;no_`2o_kl0NWYj2P3oool0103;bl/0dm?C0=?Cd`3Jf]X20=oOg`050>?Sh`3W
inL0h>3P0>3Ph03Ng]h00P3Jf]X01@3Kfm/0g=cL0=cLg03Ti>@0hn?S0080hN7Q00D0fMWI0=_Kf`3K
fm/0fm_K0=oOg`020>GUi@040>o_k`3Zj^X0j^[Z0>KViP80gMgM00<0e=CD0<W9b@37alL00P37alL2
0<[:bP050<S8b03De=@0fMWI0=WIf@3Lg=`00P3MgMd01@3Xj>P0gmoO0=OGe`3GemL0d=3@0080alO7
00D0_[jn0;Vi^@2i^KT0/K6a0:VYZ@0209jNWP0509RHV02CTi<0Ti>C08n?S`2>SXh00P2CTi<0102D
U9@0TY:B09:BTP2@T90208f=S@0308R8R021PH40PX:20080PX:20P1kNg/01@1iNGT0MgMg075aL@1a
LG40Kfm_0080LW9b0`1jNWX01@1iNGT0MWIf07MgM`1gMgL0Lg=c00<0MWIf00@0LG5a06e]K@1]KFd0
Hf=S0P1IFET01@1BDU80Fe]K05aLG01LG5`0EeMG0080F5QH00D0DU9B04=3@`13@d<0>CTi03Hf=P02
02l_;`05038b<P0d=3@0=3@d03Ti>@0k>c/00P0l?3`01014A4@0ADE504E5A@0n?Sh203Xj>P0403<c
<`0S8b<061PH01PH60@05ADE00@05QHF01TI6@0I6AT07AdM0P0N7Qh01@0Y:BT0:RXZ02/[:`0[:b/0
:RXZ0080:b/[00D08B4Q02<S8`0S8b<09BDU02LW9`0202/[:`05038b<P0e=CD0=CDe03Hf=P0i>CT0
0P0j>SX00`0f=SH0=cLg03Lg=`0303Ph>00503Lg=`0h>3P0DU9B059BDP1^KVh00P2>SXh00`2/[:`0
oooo0?ooo`0=0?ooo`003@3oool0102=SHd0IFEU06EUI@3[jn/20;Ng]`0506QXJ02MWId0WIfM09fM
W@2;Rh/00P2MWId01@2IVIT0WYjN09jNWP2@T900U9BD0080Ti>C00D0[jn_08:2PP22PX80EEEE0?oo
o`0203dm?@0409NGU`2;Rh/0Rh^;0:FUY@80SXj>00D0YJFU09FEU@2@T900T92@09NGU`0209nOW`05
09^KV`2GUiL0@T920492@P3oool00P15ADD01026QXH0VIVI09VIV@2IVIT30:6QX@0508R8R02FUYH0
UYJF09FEU@2MWId00P2EUID01@2FUYH0HF5Q065QH@3oool0Fe]K0080TY:B0`2EUID01@29RHT0[Jf]
0:f][@2IVIT0TY:B0080Vi^K00D0UiNG09jNWP2NWYh0Shn?04i>CP020?ooo`04059BDP2?Shl0Shn?
0::RXP80XJ6Q00D0SXj>0:VYZ@27QhL0QhN709ZJVP0209FEU@0509JFUP2KVi/0QHF508F5Q@2<S8`0
0P3moOd01@1:BTX0][Jf092@T02@T900R8R80080WIfM00D0YZJV09BDU02DU9@0Vi^K08f=S@0205eM
G@050<o?c`3YjNT0jNWY055AD@2KVi/00P2GUiL0102DU9@0Vi^K09^KV`2=SHd20;Fe]@80TY:B0P2G
UiL01@2=SHd0IfMW06MWI`3Ph>00Zj^[0080NWYj00D0U9BD0:ZZZP2ZZZX0U9BD08R8R00208:2PP04
0<c<c02;Rh/0Rh^;08V9R@80X:2P00D0TY:B05YJFP3oool0oooo06i^KP0208>3P`80VIVI0P2EUID0
1029RHT0XZ:R0::RXP2i^KT208>3P`050::RXP2;Rh/0UiNG09NGU`24Q8@00P3Cdm<00`1cLg<0oooo
0?ooo`080?ooo`0402l_;`0[:b/0:b/[02LW9`8092@T00D07AdM01HF5P0F5QH05QHF01@D500601HF
5P0401/K6`0Q8B408B4Q02/[:`80:BTY00@0:2PX02DU9@0M7Ad07AdM0`0A4A401@0E5AD06a/K01/K
6`0S8b<0:RXZ0080<30`00D0<c<c03@d=00d=3@0>SXj03Hf=P02038b<P0302h^;P0[:b/0:b/[0080
8B4Q0P0W9bL0100];Bd0<S8b038b<P0g=cL203hn?P050492@P18B4P0De=C05=CD`1KFe/00P1TI6@0
1@1]KFd0Lg=c07AdM01dM7@0LW9b0080M7Ad00@0MgMg07YjNP1jNWX0OGem1026QXH208V9R@0508n?
S`2BTY80V9RH09RHV02JVYX00P2GUiL01@2=SHd0Rh^;08^;R`2;Rh/0Shn?0080UIFE00D0WIfM0:2P
X02PX:00Y:BT0:FUY@020:VYZ@040:j^[P2e]KD0]KFe0;Zj^P<0_Kfm00@0b<S80<[:bP3:b/X0clo?
0P3IfMT01@3GemL0cLg=0<k>cP3>c/h0b<S80080`/;200D0a<C40<S8b037alL0alO70;jn_P020;^k
^`050<?3``39bLT0bLW90<o?c`3QhN400P3WinL01@3UiND0hn?S0>?Sh`3Shn<0g]kN0080gmoO00<0
h>3P0>;RhP3Rh^800P3Kfm/20=WIf@040=CDe03:b/X0b/[:0<O7a`80^;Rh00D0[Zj^0:JVYP2NWYh0
WYjN09BDU00209JFUP0509>CT`2?Shl0U9BD09BDU02IVIT00`2JVYX209bLW00509VIV@2?Shl0NWYj
07YjNP1UIFD00P1=CDd00`0j>SX0oooo0?ooo`0=0?ooo`003@3oool0102>SXh0GemO05mOG`3inOT2
0;Fe]@05065QH@2PX:00UiNG09NGU`2=SHd00P2NWYh00`2JVYX0V9RH09RHV00209FEU@80TI6A00D0
[Jf]08N7Q`27QhL0DE5A0?ooo`0202XZ:P0409ZJVP29RHT0RHV909nOW`80W9bL0P2IVIT209>CT`05
096AT@2ZZZX0ZZZZ09>CT`2MWId00P0`<3001@3oool0?clo03lo?`22PX80VIVI0080WYjN00@0XJ6Q
09>CT`2CTi<0SHf=0P2DU9@01@2QXJ40Ti>C09^KV`2KVi/0U9BD0080D51@00D0oooo04M7A`2ATI40
TI6A09FEU@0208n?S`050:6QX@2HV9P0V9RH0:2PX02;Rh/00P2KVi/01@2UYJD0UIFE09FEU@2;Rh/0
@D510080oooo00@0?3`l08^;R`2;Rh/0/[:b0P2NWYh209>CT`80TY:B00D0W9bL09BDU02DU9@0W9bL
09JFUP0207QhN00508J6QP3oool0oooo03hn?P2b/[800P2ATI4309>CT`0509NGU`2VYZH0YZJV08b<
S02FUYH00P1>CTh01@3QhN40n?Sh0?Shn00o?cl0Vi^K0080UiNG00@0U9BD09jNWP2NWYh0WYjN0P2C
Ti<01@2EUID0WYjN09FEU@2EUID0Shn?0080De=C00D0o_kn0:RXZ01bLW80LW9b092@T0020;:b/P05
09>CT`28R8P0VYZJ09ZJVP2HV9P00P2PX:001@2?Shl0X:2P0:2PX02>SXh0@4100080oooo00D0F5QH
0820P020P800Vi^K09:BTP0209NGU`0409:BTP2UYJD0YJFU0:JVYP80SXj>00D0WIfM09:BTP2?Shl0
Shn?07alO0020?KfmP0305eMG@3oool0oooo00P0oooo0`1MGEd00`1LG5`0Fe]K05]KF`0205]KF`80
FUYJ00@0FEUI05MGE`1GEeL0EUIF0P1GEeL01@1HF5P0FEUI05MGE`1GEeL0F5QH0080FEUI0P1JFUX2
061PH003065QH@1OGel0GemO00<0GEeM00D0Fe]K05eMG@1OGel0GemO061PH00205iNGP0405eMG@1I
FET0EeMG05MGE`<0F5QH00@0EeMG05QHF01HF5P0F5QH0`1EEED305MGE`0505IFEP1CDe<0DE5A055A
D@1>CTh00P18B4P01@13@d<0@41003/k>`0k>c/0>3Ph0080=CDe00@0<c<c034a<@0a<C40<30`0`0_
;bl01@0`<300<c<c03<c<`0a<C40<30`00<0;Rh^0P0Z:RX01@0];Bd0;bl_02l_;`0`<300;Rh^0080
;2`/00@0:BTY02HV9P0V9RH09RHV0`0`<3001@0c<c<0<C4a034a<@0^;Rh08B4Q00807AdM00@05ADE
01@D500D51@04Q8B0P0A4A401@0K6a/09bLW02TY:@0Y:BT0:b/[0080;Bd]00@09bLW020P800O7al0
7alO0`0P82001@0N7Qh06a/K01/K6`0I6AT05ADE00807AdM00D092@T02PX:00X:2P0:BTY02h^;P02
02LW9`05024Q8@0M7Ad07AdM01TI6@0H61P00P0K6a/0100R8R80;Rh^02h^;P0l?3`204Y:BP0505MG
E`1OGel0JFUY06UYJ@1`L7000P1cLg<01@1gMgL0NWYj07IfMP1fMWH0M7Ad00<0MWIf0P1dM7@01@1f
MWH0Ng]k07EeM@1eMGD0KVi^0080JVYZ00<0IfMW0?ooo`3oool03@3oool000d0oooo00@0T92@071`
L01`L700i^KV0P2VYZH01@1aLG40X:2P09RHV02HV9P0PH610080[Jf]0`2HV9P209JFUP80Shn?00D0
ZZZZ08n?S`2?Shl0H61P0?ooo`0204M7A`0409^KV`27QhL0QhN709JFUP80XZ:R00D0YjNW09>CT`2A
TI40TI6A09>CT`020:FUY@0509>CT`2PX:00?Shn03hn?P3oool00P1GEeL01@20P800V9RH09fMW@2M
WId0UiNG0080ZZZZ00D0Q8B409FEU@2EUID0XJ6Q09:BTP0209jNWP0509BDU01NGUh0GUiN0?ooo`1G
EeL00P2ATI40102DU9@0RHV908V9R@2RXZ820:RXZ00509RHV027QhL0Vi^K09^KV`2UYJD00P2DU9@0
1@2CTi<0BDU90?ooo`3oool0>c/k0080UiNG00D0/;2`09:BTP2BTY80W9bL09RHV00208^;R`050:BT
Y02@T900T92@09FEU@2PX:000`1jNWX20?ooo`0504A4A02a/K40T92@092@T02>SXh00P2IVIT01@2H
V9P0W9bL09bLW02FUYH0UIFE0080@d=300D0inOW0?Shn03hn?P0?clo09nOW`0209BDU00409VIV@2G
UiL0UiNG09fMW@80UYJF00D0VYZJ09VIV@2BTY80TY:B09JFUP0204A4A0050?ooo`2c/k<0JFUY06UY
J@2>SXh00P2a/K401@2CTi<0Shn?09FEU@2EUID0Shn?0080YJFU00D0SXj>0:BTY02TY:@0RHV9034a
<@020?ooo`0505=CD`1fMWH0MWIf09RHV02FUYH00P2EUID0102GUiL0YjNW0:NWY`2GUiL409RHV080
Ogmo00@0OWin0?ooo`3oool0FUYJ2P3oool405YJFP80Fe]K0P1LG5`305]KF`<0G5aL0P1MGEd0101N
GUh0GEeM05mOG`1OGel4061PH0H0HF5Q00D0HV9R065QH@1QHF40H61P05iNGP0205aLG00305YJFP1K
Fe/0Fe]K0080FUYJ0`1LG5`205eMG@03061PH01QHF40H61P0080H61P0P1NGUh0101KFe/0FUYJ05YJ
FP1LG5`405eMG@80GUiN00D0GEeM05aLG01LG5`0G5aL05eMG@0205aLG00305]KF`1LG5`0G5aL0080
G5aL0P1KFe/01@1IFET0F5QH05QHF01IFET0FUYJ0080FEUI00<0Fe]K05eMG@1MGEd00`1NGUh00`1Q
HF40HV9R069RHP04069RHP04061PH01JFUX0F5QH05QHF0@0FEUI0`1MGEd00`1KFe/0FEUI05UIF@03
05YJFP0505aLG01KFe/0Fe]K05]KF`1MGEd00P1OGel205eMG@80GUiN1P1MGEd01@1NGUh0GemO05UI
F@1IFET0F5QH0080EUIF00D0EEEE05=CD`1FEUH0EUIF05QHF00205YJFP0505UIF@1JFUX0EeMG05MG
E`1CDe<00P1?Cdl01@1=CDd0C4a<04a<C01:BTX0BDU90080ADE500D0@T9203dm?@0m?Cd0>3Ph03De
=@0203<c<`04038b<P0`<300<30`030`<080<S8b00D0=3@d03Hf=P0o?cl0?clo04Q8B00204m?C`03
05ADE03oool0oooo00d0oooo000=0?ooo`04092@T01`L700L71`0>KViP80YZJV00D0LG5a0:2PX02H
V9P0V9RH0861P@020:f][@<0V9RH0P2FUYH208n?S`050:ZZZP2?Shl0Shn?061PH03oool00P17AdL0
102KVi/0QhN708N7Q`2FUYH20::RXP050:NWY`2CTi<0TI6A096AT@2CTi<00P2UYJD01@2CTi<0X:2P
03hn?P0n?Sh0oooo0080EeMG00D0P82009RHV02MWId0WIfM09NGU`020:ZZZP0508B4Q02EUID0UIFE
0:6QX@2BTY800P2NWYh01@2DU9@0GUiN05iNGP3oool0EeMG0080TI6A00@0U9BD08V9R@29RHT0XZ:R
0P2XZ:P01@2HV9P0QhN709^KV`2KVi/0YJFU0080U9BD00D0Ti>C04U9B@3oool0oooo03/k>`0209NG
U`050;2`/02BTY80TY:B09bLW02HV9P00P2;Rh/01@2TY:@0T92@092@T02EUID0X:2P00<0NWYj0P3o
ool01@14A4@0/K6a092@T02@T900SXj>0080VIVI00D0V9RH09bLW02LW9`0UYJF09FEU@0204=3@`05
0>OWi`3hn?P0n?Sh03lo?`2OWil00P2DU9@0102IVIT0UiNG09NGU`2MWId209JFUP0509ZJVP2IVIT0
TY:B09:BTP2FUYH00P14A4@01@3oool0/k>c06UYJ@1YJFT0SXj>0080/K6a00D0Ti>C08n?S`2EUID0
UIFE08n?S`020:FUY@0508j>SP2TY:@0Y:BT08V9R@0a<C400P3oool01@1CDe<0MWIf07IfMP2HV9P0
UYJF0080UIFE00@0UiNG0:NWY`2WYjL0UiNG102HV9P207moO`0407inOP3oool0oooo05YJFPX0oooo
101JFUX205]KF`80G5aL0`1KFe/305aLG080GEeM00@0GUiN05eMG@1OGel0GemO101PH606065QH@05
069RHP1QHF40HF5Q061PH01NGUh00P1LG5`00`1JFUX0Fe]K05]KF`0205YJFP<0G5aL0P1MGEd00`1P
H600HF5Q061PH002061PH080GUiN00@0Fe]K05YJFP1JFUX0G5aL101MGEd205iNGP0505eMG@1LG5`0
G5aL05aLG01MGEd00P1LG5`00`1KFe/0G5aL05aLG00205aLG080Fe]K00D0FEUI05QHF01HF5P0FEUI
05YJFP0205UIF@0305]KF`1MGEd0GEeM00<0GUiN00<0HF5Q069RHP1RHV80101RHV80101PH600FUYJ
05QHF01HF5P405UIF@<0GEeM00<0Fe]K05UIF@1IFET00`1JFUX01@1LG5`0Fe]K05]KF`1KFe/0GEeM
0080GemO0P1MGEd205iNGPH0GEeM00D0GUiN05mOG`1IFET0FEUI05QHF00205IFEP0505EEE@1CDe<0
EUIF05IFEP1HF5P00P1JFUX01@1IFET0FUYJ05MGE`1GEeL0De=C0080Cdm?00D0CDe=04a<C01<C4`0
BTY:04U9B@0204E5A@050492@P0m?Cd0?Cdm03Ph>00e=CD00P0c<c<0100b<S80<30`030`<00`<302
038b<P0503@d=00f=SH0?clo03lo?`18B4P00P1?Cdl00`1DE5@0oooo0?ooo`0=0?ooo`003@3oool0
102DU9@0Ng]k07]kN`3Cdm<20:6QX@0507UiN@2PX:00VIVI09VIV@1]KFd00P3;bl/01@2GUiL0Rh^;
08^;R`2OWil0UIFE0080SHf=00D0YZJV08n?S`2?Shl0NGUi0?[jnP0205eMG@0409ZJVP2<S8`0S8b<
07moO`80/K6a00D0_Kfm0820P02BTY80TY:B09RHV00209jNWP0509BDU02NWYh0E5AD05ADE03oool0
0P1`L7001@21PH40UiNG09JFUP2FUYH0QhN70080fm_K00D0KVi^092@T02@T900XJ6Q09>CT`0209fM
W@0509BDU01cLg<0Lg=c0?ooo`1TI6@00P2DU9@0102EUID0R8R808R8R02:RXX20=CDe00508J6QP24
Q8@0WIfM09fMW@2RXZ800`2CTi<0101TI6@0oooo0?ooo`1>CTh209RHV0050;6a/@2>SXh0SXj>08b<
S02l_;`00P1kNg/01@2QXJ40Ti>C09>CT`2FUYH0WinO0080P82000D0QHF50?Gem@3emOD0IFEU0::R
XP0209FEU@0408N7Q`2NWYh0WYjN0:VYZ@80Shn?0P2GUiL205IFEP050=7Ad@3Shn<0hn?S05=CD`2M
WId00P2GUiL0102HV9P0Ti>C09>CT`2?Shl20:j^[P0509bLW02?Shl0U9BD09BDU02IVIT00P1JFUX0
1@3/k>`0Zj^[07AdM01dM7@0SXj>0080[:b/00D0Ti>C09FEU@2<S8`0S8b<0:BTY00209bLW005096A
T@2OWil0WinO08Z:RP0o?cl00P3oool01@1GEeL0OGem07emO@2GUiL0V9RH0080TY:B00@0UIFE0:RX
Z02XZ:P0XJ6Q0P2EUID01@2CTi<0UiNG07moO`1oOgl0QXJ60080oooo00<0EEEE0?ooo`3oool0203o
ool01017AdL0ADE504E5A@15ADD204M7A`80A4A40P16ATH304M7A`0504E5A@12@T80@T920492@P0o
?cl00P0m?Cd0100o?cl0@4100410@00o?cl30451@@0403`l?00j>SX0>SXj03Ph>080=SHf00<0=CDe
03Hf=P0f=SH00P0f=SH203@d=00503Ph>00g=cL0=CDe03De=@0h>3P00P0l?3`0100i>CT0@41004E5
A@15ADD304M7A`0304Q8B016ATH0ATI60080ADE50P18B4P01@19BDT0C4a<04a<C01@D500De=C00<0
DU9B0`1CDe<2051@D005055AD@1EEED0FEUI05UIF@1LG5`00P1QHF401@1UIFD0I6AT06=SH`1SHf<0
H61P0080GUiN00<0G5aL05YJFP1JFUX0101IFET01@1KFe/0GEeM05eMG@1NGUh0G5aL0080FUYJ0`1H
F5P00`1KFe/0GEeM061PH002061PH080GemO00D0GEeM05aLG01LG5`0FEUI05eMG@0205iNGP<0GEeM
00<0GUiN05aLG01KFe/00P1KFe/205aLG00505eMG@1LG5`0G5aL05aLG01KFe/01@1MGEd00`1NGUh0
HF5Q061PH004061PH003065QH@1OGel0H61P00@0H61P00D0GUiN061PH01PH600GEeM05]KF`0305YJ
FP80F5QH0P1JFUX205aLG0<0GEeM0`1LG5`01@1KFe/0FUYJ05EEE@1EEED0D51@0080BTY:00<0BDU9
0?ooo`3oool03@3oool000d0oooo00@0UYJF08R8R028R8P0_kno0P2LW9`01@22PX80X:2P09RHV02H
V9P0GEeM0080inOW00D0UYJF07inOP1nOWh0Z:RX09BDU00208j>SP0509jNWP2HV9P0V9RH08R8R03C
dm<00P1`L700102JVYX0T92@092@T01aLG420;Ng]`050=CDe01`L700U9BD09BDU02GUiL00P2NWYh0
1@2DU9@0W9bL06i^KP1^KVh0h>3P0080S8b<00D0PH6109ZJVP2@T900T92@06i^KP020?ooo`0505MG
E`2=SHd0SHf=09nOW`2GUiL00P2NWYh01@2ATI40PX:208:2PP3Rh^80MgMg0080V9RH00@0Ti>C08B4
Q024Q8@0L71`0P3oool01@1bLW80Ph>309fMW@2MWId0Xj>S0080T92@00D0UIFE07moO`3Ogml0gmoO
06=SH`0209VIV@050;:b/P2:RXX0RXZ:07alO03Kfm/00P1]KFd01@2QXJ40Ti>C09>CT`2FUYH0WYjN
0080QHF500D0RXZ:0=gMg@3MgMd0Ng]k09NGU`0209BDU00408:2PP2XZ:P0Z:RX0;Jf]P80P82000D0
V9RH09^KV`1[Jf/0Jf][0;Rh^0020<o?c`0506][J`2JVYX0UIFE09FEU@2KVi/00P2BTY801@1lO7`0
cLg=0<g=c@2IVIT0RXZ:0080U9BD00D0V9RH06MWI`1WIfL0f][J0:NWY`0207alO00508n?S`2ZZZX0
ZZZZ09FEU@2DU9@00P1iNGT0103=cLd0R8R808R8R02ATI4209nOW`0508b<S01FEUH0oooo0?ooo`1T
I6@00P24Q8@01@2FUYH0Vi^K08^;R`2;Rh/0UIFE0080YjNW00D0]KFe08^;R`2;Rh/0Ti>C09RHV002
07inOP0408n?S`3^k^h0k^k^05aLG0X0oooo0`2ATI401@2?Shl0RHV908V9R@22PX80N7Qh0080M7Ad
00@0LG5a079bLP1bLW80MGEe0P1lO7`01@20P800Q8B408J6QP26QXH0QhN70080Ph>300@0P82007al
O01hN7P0N7Qh0`1fMWH01@1jNWX0OGem07emO@1oOgl0PX:20080R8R800D0SHf=09:BTP2BTY80UiNG
09fMW@0209nOW`0509VIV@2@T900T92@08F5Q@1/K6`00P1MGEd0101EEED0E5AD05ADE01CDe<205aL
G00505mOG`1PH600IVIV06IVIP1RHV800P1LG5`01@1DE5@0C4a<03lo?`0o?cl0>3Ph0080=CDe00D0
<C4a038b<P0b<S80;bl_02XZ:P0202DU9@0502LW9`0Y:BT0:BTY02<S8`0T92@00P0/;2`0100^;Rh0
9RHV02HV9P0V9RH202LW9`05028R8P0O7al08b<S02<S8`0R8R800P0Q8B401@0W9bL0<30`038b<P0b
<S80<c<c0080=3@d00D0;Rh^02@T900Q8B408B4Q02<S8`0202@T900502DU9@0Z:RX0:RXZ038b<P0c
<c<00P0b<S800`0_;bl0;Bd]02d];@0202PX:080:RXZ0`0/;2`302/[:`0502`/;00^;Rh0<S8b038b
<P0a<C400P0b<S801@0d=3@0=cLg03Hf=P0f=SH0>CTi00@0>c/k0P0l?3`303/k>`0503Xj>P0n?Sh0
?Shn03`l?010@4000P13@d<304M7A`0404];B`1?Cdl0Cdm?04m?C`<0CTi>101@D500101BDU80GEeM
05eMG@1XJ6P207AdM00308F5Q@3oool0oooo00d0oooo000=0?ooo`0409JFUP28R8P0R8R80;no_`80
W9bL00D0PX:20:2PX02HV9P0V9RH05eMG@020>OWi`0509JFUP1nOWh0OWin0:RXZ02DU9@00P2>SXh0
1@2NWYh0V9RH09RHV028R8P0dm?C0080L71`00@0VYZJ092@T02@T900LG5a0P2g]kL01@3De=@0L71`
09BDU02DU9@0UiNG0080WYjN00D0U9BD09bLW01^KVh0KVi^0>3Ph00208b<S0050861P@2JVYX0T92@
092@T01^KVh00P3oool01@1GEeL0SHf=08f=S@2OWil0UiNG0080WYjN00D0TI6A08:2PP22PX80h^;R
07MgM`0209RHV00409>CT`24Q8@0Q8B4071`L080oooo00D0LW9b08>3P`2MWId0WIfM0:>SX`02092@
T00509FEU@1oOgl0gmoO0=oOg`1SHf<00P2IVIT01@2b/[80RXZ:08Z:RP1lO7`0fm_K0080KFe]00D0
XJ6Q09>CT`2CTi<0UYJF09jNWP0208F5Q@0508Z:RP3MgMd0gMgM07]kN`2GUiL00P2DU9@01022PX80
Z:RX0:RXZ02f][H20820P00509RHV02KVi/0Jf][06][J`2h^;P00P3?cll01@1[Jf/0VYZJ09FEU@2E
UID0Vi^K0080TY:B00D0O7al0<g=c@3=cLd0VIVI08Z:RP0209BDU00509RHV01WIfL0IfMW0=[JfP2W
YjL00P1lO7`01@2?Shl0ZZZZ0:ZZZP2EUID0U9BD0080NGUi00@0cLg=08R8R028R8P0TI6A0P2OWil0
1@2<S8`0EUIF0?ooo`3oool0I6AT0080Q8B400D0UYJF09^KV`2;Rh/0Rh^;09FEU@020:NWY`050;Fe
]@2;Rh/0Rh^;09>CT`2HV9P00P1nOWh0102?Shl0k^k^0>k^kP1LG5`:0?ooo`<0TI6A00D0Shn?08V9
R@29RHT0PX:207QhN00207AdM004075aL@1bLW80LW9b07EeM@80O7al00D0P82008B4Q026QXH0QXJ6
08N7Q`0208>3P`040820P01lO7`0N7Qh07QhN0<0MWIf00D0NWYj07emO@1mOGd0Ogmo08:2PP0208R8
R00508f=S@2BTY80TY:B09NGU`2MWId00P2OWil01@2IVIT0T92@092@T025QHD0K6a/0080GEeM00@0
EEEE05ADE01DE5@0De=C0P1LG5`01@1OGel0H61P06IVIP1VIVH0HV9R0080G5aL00D0E5AD04a<C00o
?cl0?clo03Ph>00203De=@05034a<@0b<S80<S8b02l_;`0Z:RX00P0U9BD01@0W9bL0:BTY02TY:@0S
8b<092@T0080;2`/00@0;Rh^02HV9P0V9RH09RHV0P0W9bL01@0R8R807alO02<S8`0S8b<08R8R0080
8B4Q00D09bLW030`<00b<S80<S8b03<c<`0203@d=00502h^;P0T92@08B4Q024Q8@0S8b<00P0T92@0
1@0U9BD0:RXZ02XZ:P0b<S80<c<c0080<S8b00<0;bl_02d];@0];Bd00P0X:2P202XZ:P<0;2`/0`0[
:b/01@0/;2`0;Rh^038b<P0b<S80<C4a0080<S8b00D0=3@d03Lg=`0f=SH0=SHf03Ti>@0403/k>`80
?3`l0`0k>c/01@0j>SX0?Shn03hn?P0l?3`0@4100080@d=30`17AdL0101;Bd/0Cdm?04m?C`1?Cdl3
04i>CP@0D51@00@0DU9B05eMG@1MGEd0J6QX0P1dM7@00`25QHD0oooo0?ooo`0=0?ooo`003@3oool0
102IVIT0UiNG09NGU`2UYJD209NGU`05092@T02NWYh0U9BD09BDU01BDU800P3oool01@2GUiL0KVi^
06i^KP2b/[80T92@0080U9BD00D0TY:B09nOW`2OWil0UiNG0:b/[00208J6QP0409ZJVP2@T900T92@
06EUI@80_Kfm00D0inOW05mOG`2KVi/0Vi^K09FEU@0209bLW00509FEU@2IVIT0Rh^;08^;R`2[Zj/0
0P2SXj<01@28R8P0UiNG08j>SP2>SXh0E5AD0080oooo00D0@d=308N7Q`27QhL0X:2P09^KV`0209RH
V00509NGU`2@T900T92@0;bl_02;Rh/00P2NWYh0102ATI40Ng]k07]kN`1NGUh20?ooo`0505eMG@22
PX80WinO09nOW`2RXZ800P2?Shl01@2HV9P0Ti>C0;:b/P2b/[80Ng]k0080W9bL00D0[Jf]08J6QP26
QXH0K6a/0?gmo@0205iNGP050:BTY02BTY80TY:B09VIV@2JVYX00`2=SHd20<?3``0508b<S02EUID0
UIFE09FEU@1gMgL00P2g]kL01@2k^k/0N7Qh07QhN02IVIT0VYZJ0080O7al00D0Zj^[0;Ng]`2g]kL0
Ogmo09^KV`0209FEU@0409bLW02?Shl0Shn?06ATI080lO7a00D0VIVI08:2PP2BTY80TY:B09ZJVP02
07QhN0050<30`02TY:@0QhN708N7Q`2ATI400P2TY:@01@2EUID0V9RH06=SH`1SHf<0m?Cd0080NGUi
00D0S8b<09nOW`2OWil0Shn?075aL@020?7al@0507alO026QXH0QXJ609JFUP2NWYh00P2:RXX0102B
TY80VIVI09VIV@3@d=0207inOP0509NGU`2FUYH0Ogmo07moO`2GUiL00P3MgMd00`1QHF40oooo0?oo
o`080?ooo`0405YJFP1PH600H61P06ATI080JFUY00D0LW9b07YjNP1mOGd0OGem0861P@0208:2PP04
08B4Q023Ph<0Ph>308:2PP<0PH6100D0NWYj07emO@1mOGd0P82007moO`020861P@0408J6QP25QHD0
QHF508F5Q@80Q8B400D0Ph>308:2PP1nOWh0OWin07YjNP0207UiN@05079bLP1aLG40Kfm_06m_K`1a
LG400P1fMWH01@21PH40Rh^;09RHV02HV9P0XZ:R0080YJFU00D0YjNW0:FUY@2UYJD0WinO09NGU`02
08^;R`0508j>SP2DU9@0U9BD09bLW02VYZH00P2l_;`0102o_kl0a<C40<C4a03:b/X30<g=c@040=GE
e@3Jf]X0f][J0=OGe`80dM7A00D0e=CD0=GEe@3?cll0clo?0<k>cP020=[JfP030=?Cd`3>c/h0c/k>
0080d];B0P38b<P30<o?c`80b<S80P3<c<`01@3;bl/0b/[:0<[:bP3=cLd0c<c<0080aLG500@0`l?3
0<C4a034a<@0a<C40P32`/801@33`l<0`<300<71`@31`L40a<C40080aLG500D0a/K60<;2`P2j^[X0
^[Zj0:ZZZP020:2PX00509VIV@2EUID0UIFE096AT@2CTi<00P2IVIT01@2QXJ40X:2P0:2PX02OWil0
Vi^K0080TY:B00D0Q8B407emO@1mOGd0Lg=c075aL@0206i^KP04071`L01aLG40LG5a07QhN080OGem
00D0PH6107UiN@1bLW80LW9b06YZJP0205iNGP0305=CD`1<C4`0AdM70080AdM70`15ADD204I6AP05
051@D01DE5@0F5QH05QHF01MGEd00P1UIFD00`1NGUh0oooo0?ooo`0=0?ooo`003@3oool309bLW005
09JFUP2GUiL0UiNG09VIV@2HV9P00P2FUYH01017AdL0oooo0?ooo`2ATI4206=SH`050<?3``26QXH0
V9RH09RHV02?Shl00P2NWYh01@2PX:00TY:B09ZJVP2JVYX0UIFE0080Ti>C00D0GemO0;Jf]P2f][H0
oooo04m?C`0209bLW00409^KV`2EUID0UIFE09VIV@<0UYJF0`2MWId01@2<S8`0VIVI08n?S`2?Shl0
=3@d0080oooo00D0:RXZ08R8R028R8P0Vi^K0::RXP02092@T00509fMW@2PX:00X:2P09FEU@2LW9`0
0P2PX:00102HV9P0OGem07emO@16ATH20?ooo`0404e=C@2:RXX0WinO09nOW`<0VIVI00D0UiNG0::R
XP2=SHd0SHf=096AT@020:2PX0050:6QX@26QXH0QXJ605eMG@3oool00P1BDU801@2RXZ80UIFE09FE
U@2FUYH0WYjN0080UiNG00D0Shn?0:FUY@2UYJD0Ti>C09bLW00209JFUP0406][J`34a<@0a<C40<K6
aP80Jf][00D0VYZJ09bLW029RHT0RHV909^KV`020:JVYP0509:BTP2IVIT0Ti>C09>CT`2MWId00P2>
SXh01@1BDU80oooo0?ooo`2IVIT0Ogmo0080SXj>00D0VIVI08Z:RP2:RXX0XZ:R0:NWY`0208j>SP05
096AT@2QXJ40XJ6Q09JFUP2LW9`00P1?Cdl0103oool0I6AT06ATI02<S8`209jNWP05096AT@2<S8`0
^k^k0;^k^`2CTi<00P2:RXX01@2ATI40YJFU08f=S@2=SHd0SXj>0080RXZ:00D0i^KV071`L01`L700
YZJV096AT@0208:2PP0409bLW038b<P0b<S806e]K@X0oooo00@0BDU904E5A@15ADD0@d=30P11@D40
1@10@400@T9204=3@`13@d<0@D510080?Shn00D0>c/k03De=@0e=CD0<C4a02l_;`0202h^;P05030`
<00a<C40<C4a03<c<`0f=SH00P0e=CD00`0j>SX0?Cdm03dm?@0303/k>`0303dm?@0g=cL0<c<c0080
<c<c0P0`<30202d];@80;bl_00D0<c<c03De=@0e=CD0>SXj04A4A0020492@P0403hn?P0l?3`0?3`l
03Ti>@80<c<c00D0=SHf03dm?@0o?cl0?clo03dm?@0203Ti>@0503@d=00_;bl0:2PX02PX:00[:b/0
0P0Z:RX01@0W9bL09BDU02DU9@0U9BD07alO00807AdM00D07QhN01dM7@0M7Ad07QhN01`L700201dM
7@0401hN7P0M7Ad07AdM02HV9P<0;2`/00@0;Bd]038b<P0b<S80:BTY0P0X:2P01@0Y:BT08b<S01lO
7`0O7al0820P00808B4Q00D08R8R02XZ:P0c<c<0<c<c03Hf=P0503Lg=`0502l_;`0];Bd0;Bd]02d]
;@0^;Rh00P0`<3001@0f=SH0?Shn04Q8B018B4P0F5QH0080Hf=S00D0KFe]07IfMP1fMWH0OGem07in
OP0207IfMP0506m_K`1]KFd0KFe]06UYJ@1WIfL00P1`L7001@1nOWh0QHF508F5Q@2=SHd0TY:B0080
UYJF0`2EUID01@2DU9@0S8b<08b<S02:RXX0T92@0080U9BD00D0V9RH0:>SX`2SXj<0ZJVY0:^[Z`02
0:ZZZPH0ZJVY00D0YZJV0:FUY@2CTi<0Ti>C0820P00206YZJP0305UIF@3oool0oooo00d0oooo000=
0?ooo`<0W9bL00D0UYJF09NGU`2GUiL0VIVI09RHV00209JFUP0404M7A`3oool0oooo096AT@80Hf=S
00D0`l?308J6QP2HV9P0V9RH08n?S`0209jNWP050:2PX02BTY80VYZJ09ZJVP2EUID00P2CTi<01@1O
Gel0][Jf0;Jf]P3oool0Cdm?0080W9bL00@0Vi^K09FEU@2EUID0VIVI0`2FUYH309fMW@0508b<S02I
VIT0Shn?08n?S`0d=3@00P3oool01@0Z:RX0R8R808R8R02KVi/0XZ:R0080T92@00D0WIfM0:2PX02P
X:00UIFE09bLW0020:2PX00409RHV01mOGd0OGem04I6AP80oooo00@0CDe=08Z:RP2OWil0WinO0`2I
VIT01@2GUiL0XZ:R08f=S@2=SHd0TI6A0080X:2P00D0XJ6Q08J6QP26QXH0GEeM0?ooo`02059BDP05
0::RXP2EUID0UIFE09JFUP2NWYh00P2GUiL01@2?Shl0YJFU0:FUY@2CTi<0W9bL0080UYJF00@0Jf][
0<C4a034a<@0a/K60P1[Jf/01@2JVYX0W9bL08V9R@29RHT0Vi^K0080YZJV00D0TY:B09VIV@2CTi<0
Ti>C09fMW@0208j>SP05059BDP3oool0oooo09VIV@1oOgl00P2>SXh01@2IVIT0RXZ:08Z:RP2RXZ80
YjNW0080SXj>00D0TI6A0:6QX@2QXJ40UYJF09bLW00204m?C`040?ooo`1TI6@0I6AT08b<S080WYjN
00D0TI6A08b<S02k^k/0^k^k09>CT`0208Z:RP05096AT@2UYJD0SHf=08f=S@2>SXh00P2:RXX01@3V
i^H0L71`071`L02VYZH0TI6A0080PX:200@0W9bL0<S8b038b<P0KFe]2P3oool01019BDT0ADE504E5
A@13@d<20451@@050410@012@T80@d=304=3@`11@D400P0n?Sh01@0k>c/0=CDe03De=@0a<C40;bl_
0080;Rh^00D0<30`034a<@0a<C40<c<c03Hf=P0203De=@0303Xj>P0m?Cd0?Cdm00<0>c/k00<0?Cdm
03Lg=`0c<c<00P0c<c<2030`<080;Bd]0P0_;bl01@0c<c<0=CDe03De=@0j>SX0A4A40080@T9200@0
?Shn03`l?00l?3`0>CTi0P0c<c<01@0f=SH0?Cdm03lo?`0o?cl0?Cdm0080>CTi00D0=3@d02l_;`0X
:2P0:2PX02/[:`0202XZ:P0502LW9`0U9BD09BDU02DU9@0O7al00P0M7Ad01@0N7Qh07AdM01dM7@0N
7Qh071`L00807AdM00@07QhN01dM7@0M7Ad09RHV0`0/;2`0100];Bd0<S8b038b<P0Y:BT202PX:005
02TY:@0S8b<07alO01lO7`0P82000P0Q8B401@0R8R80:RXZ03<c<`0c<c<0=SHf00D0=cLg00D0;bl_
02d];@0];Bd0;Bd]02h^;P02030`<00503Hf=P0n?Sh0B4Q804Q8B01HF5P00P1SHf<01@1]KFd0MWIf
07IfMP1mOGd0OWin0080MWIf00D0Kfm_06e]K@1]KFd0JFUY06MWI`02071`L00507inOP25QHD0QHF5
08f=S@2BTY800P2FUYH309FEU@0509BDU02<S8`0S8b<08Z:RP2@T9000P2DU9@01@2HV9P0Xj>S0:>S
X`2YZJT0Zj^[0080ZZZZ1P2YZJT01@2VYZH0YJFU09>CT`2CTi<0P8200080JVYZ00<0FEUI0?ooo`3o
ool03@3oool000d0oooo00@0Vi^K09>CT`2CTi<0Z:RX0P2BTY801@2EUID0V9RH09JFUP2FUYH0Fe]K
0080oooo00D0SHf=06UYJ@1YJFT0`L7108J6QP0209^KV`0508Z:RP2MWId0WIfM0:NWY`2CTi<00P2G
UiL0102ATI40V9RH09RHV01WIfL20:n_[`030?[jnP1CDe<0WYjN0080WYjN0P2ATI401@2JVYX0V9RH
09VIV@2IVIT0Xj>S0080U9BD00D0Shn?09ZJVP29RHT0RHV90410@0020?ooo`0502XZ:P23Ph<0Ph>3
09RHV02WYjL00P2CTi<01@2MWId0Vi^K09^KV`2QXJ40UYJF0080V9RH00@0XJ6Q08:2PP22PX80?Shn
0P3oool01@1FEUH0RHV909nOW`2OWil0WIfM0080UIFE00D0Ti>C0:JVYP2?Shl0Shn?09:BTP0209ZJ
VP0509jNWP2ATI40TI6A055AD@3oool00P1ADE401@2KVi/0V9RH09RHV02KVi/0UIFE0080Vi^K102H
V9P0102IVIT0V9RH09RHV01[Jf/20<O7a`050<o?c`1SHf<0Hf=S09:BTP2PX:000P2GUiL01@2CTi<0
WIfM09fMW@2GUiL0Ti>C0080W9bL00@0Vi^K092@T02@T900@T920P3oool01@2CTi<0Ph>308^;R`2;
Rh/0V9RH0080UIFE00<0Ti>C09bLW02HV9P00P2HV9P209jNWP0509FEU@2PX:00AdM704M7A`3oool0
0P1EEED00`2ATI40SXj>08j>SP0209nOW`D0UIFE00D0Shn?0::RXP2GUiL0UiNG0820P00208j>SP05
0?7al@1SHf<0Hf=S0;>c/`2>SXh00P2;Rh/0102DU9@0XZ:R0::RXP2=SHd:0?ooo`0405YJFP1IFET0
FEUI05UIF@<0FUYJ0`1KFe/0101LG5`0GEeM05eMG@1PH602065QH@0506=SH`1TI6@0Hf=S06=SH`1R
HV800P1PH6001@1NGUh0GEeM05mOG`1OGel0G5aL0080GEeM00D0GUiN05]KF`1KFe/0FEUI05eMG@02
05mOG`05065QH@1TI6@0I6AT06ATI01RHV800P1QHF401@1OGel0G5aL05aLG01LG5`0FUYJ00D0F5QH
00D0EeMG05QHF01HF5P0EeMG05EEE@0205MGE`<0FEUI00@0Fe]K05eMG@1KFe/0Fe]K0`1LG5`0101M
GEd0GUiN05iNGP1PH60305iNGP0405eMG@1NGUh0GUiN05aLG0<0GEeM00@0G5aL05]KF`1KFe/0F5QH
101GEeL205IFEP@0FUYJ0`1KFe/00`1JFUX0Fe]K05]KF`0205]KF`80G5aL00@0Fe]K05YJFP1JFUX0
FUYJ0P1HF5P01@1EEED0De=C05=CD`1CDe<0DE5A0080Cdm?0P1@D50204a<C00404U9B@17AdL0AdM7
04=3@`80?clo00@0>SXj03Lg=`0g=cL0=cLg0`0f=SH01@0j>SX0>c/k03/k>`0k>c/0=cLg0080=SHf
00D0>3Ph03Hf=P0d=3@0=3@d03De=@0203<c<`0302h^;P0];Bd0;Bd]0080;2`/0P0];Bd01@0^;Rh0
<C4a034a<@0e=CD0>c/k0080?clo0`11@D401@0m?Cd0=SHf03Hf=P0`<300:b/[0080=3@d00@0?Cdm
04M7A`17AdL0D51@3`3oool000d0oooo00@0V9RH08>3P`23Ph<0clo?0P1mOGd01@2EUID0VYZJ09>C
T`2CTi<0LG5a0080i>CT00D0Shn?07AdM01dM7@0^[Zj08V9R@0209ZJVP0508N7Q`2>SXh0SXj>0<;2
`P2?Shl00P2OWil01027QhL0UYJF09JFUP1iNGT209jNWP050>GUi@1VIVH0Vi^K09^KV`2PX:000P2A
TI401@2GUiL0PX:20<c<c03<c<`0SHf=0080T92@00D0Shn?09VIV@2@T900T92@04a<C0020?ooo`05
03lo?`29RHT0RHV909FEU@2WYjL00P2@T9000`2ATI40^[Zj0;Zj^P0209:BTP80VIVI00@0XZ:R08:2
PP22PX80E5AD0P3oool01@1XJ6P0RXZ:0:>SX`2SXj<0VYZJ00<0SXj>00@0`L7108F5Q@25QHD0SXj>
0P2NWYh01@2MWId0T92@092@T01QHF40oooo0080H61P00D0W9bL09RHV02HV9P0Vi^K09:BTP02096A
T@050:^[Z`2FUYH0UYJF09>CT`2KVi/00P2FUYH0101dM7@0`L710<71`@2n_[h2071`L005092@T02R
XZ80V9RH09RHV02;Rh/00P2YZJT01@2OWil0RHV909VIV@2IVIT0WinO0080Ti>C00D0CTi>0?ooo`3o
ool0Ti>C092@T00208J6QP<0U9BD00D0XZ:R09RHV02DU9@0U9BD09RHV00209nOW`0509VIV@2OWil0
Cdm?04m?C`3oool00P1LG5`01@2CTi<0SXj>08j>SP2JVYX0[Jf]0080Ti>C00D0Shn?09VIV@2IVIT0
SHf=0::RXP0209fMW@0408>3P`26QXH0QXJ60>WYj@80Jf][00D0]KFe08Z:RP28R8P0R8R809jNWP02
0:FUY@0308J6QP3oool0oooo00P0oooo0`10@4001@12@T80@d=304=3@`16ATH0BTY:0080CTi>00@0
D51@055AD@1ADE40DU9B0P1ADE401@1@D500DU9B05EEE@1EEED0EeMG0080F5QH101KFe/0101LG5`0
Fe]K05]KF`1JFUX405eMG@<0GUiN0P1LG5`0101KFe/0GEeM05iNGP1NGUh305mOG`@0GUiN00<0GEeM
05iNGP1NGUh00`1OGel00`1PH600HF5Q065QH@02065QH@80HV9R00D0GemO05aLG01MGEd0GEeM061P
H00205mOG`<0H61P00D0GEeM05YJFP1KFe/0Fe]K05aLG00205iNGP05065QH@1RHV80HF5Q065QH@1O
Gel00`1NGUh305aLG0<0Fe]K00<0FEUI05YJFP1JFUX00P1KFe/205eMG@<0GemO00<0GUiN05eMG@1J
FUX01@1JFUX205]KF`0505mOG`1PH600H61P061PH01QHF400P1OGel01@1MGEd0FUYJ05YJFP1JFUX0
GUiN0080H61P0`1QHF400`1SHf<0H61P05iNGP0205iNGP80GemO0P1MGEd205aLG00505iNGP1KFe/0
Fe]K05aLG01MGEd00`1NGUh3065QH@80H61P00D0HF5Q05mOG`1NGUh0GUiN05aLG00205YJFP0505MG
E`1DE5@0E5AD05ADE01EEED00P1DE5@01@1EEED0FUYJ05YJFP1JFUX0Fe]K0080EeMG00@0De=C04a<
C01<C4`0ADE53`3oool000d0oooo00@0UIFE07EeM@1eMGD0l_;b0P1]KFd209JFUP80U9BD00@0QHF5
0<G5a@35aLD0UIFE0P1oOgl01@2`/;00Rh^;09^KV`2KVi/0QhN70080M7Ad00D0k^k^07inOP2UYJD0
YJFU08>3P`0209NGU`0507moO`2JVYX0VYZJ0<o?c`1fMWH00P2LW9`01@2QXJ40SHf=08f=S@2GUiL0
Kfm_0080n?Sh00D0MWIf092@T02@T900T92@09JFUP0209VIV@0405eMG@3oool0oooo05QHF080Rh^;
00D0Vi^K0::RXP2ATI40TI6A07alO0020>?Sh`0507emO@2?Shl0V9RH09RHV02RXZ800P27QhL01@1]
KFd0k>c/0>c/k01iNGT0TY:B0080YjNW00D0UIFE08b<S02<S8`0NGUi0>WYj@0207AdM00408b<S02N
WYh0WYjN09jNWP80TI6A00D0Kfm_0>_[j`1^KVh0KVi^09bLW00209RHV00509VIV@2CTi<0Ogmo07mo
O`3>c/h00P24Q8@01@2BTY80Vi^K09JFUP2FUYH0OWin0080]kNg00D0/;2`07alO01lO7`0T92@0:6Q
X@0209bLW00506MWI`3Ogml0gmoO096AT@22PX800P2MWId0102LW9`0UIFE09FEU@1RHV820>OWi`05
09>CT`2EUID0QXJ608J6QP23Ph<00P2XZ:P01@2a/K40R8R809NGU`2GUiL0UYJF0080W9bL00D0UiNG
0::RXP1PH600H61P0?KfmP0206a/K00509JFUP2:RXX0RXZ:08Z:RP3Cdm<00P29RHT01@27QhL0Vi^K
09^KV`2?Shl0WYjN0080XZ:R00@0QhN708>3P`23Ph<0f=SH0P1cLg<01@2f][H0QXJ607emO@1mOGd0
`l?30080Ti>C00<0QHF50?ooo`3oool0203oool0101SHf<0H61P061PH01KFe/205IFEP05059BDP1A
DE40CTi>04i>CP1;Bd/00P1>CTh01@1=CDd0AdM704M7A`13@d<0?Shn0080<c<c00@0;bl_02`/;00/
;2`0:BTY0`0X:2P0100[:b/0<c<c03<c<`0d=3@203<c<`05038b<P0/;2`07alO01lO7`0J6QX00P0H
61P01@0I6AT06QXJ01hN7P0N7Qh08R8R0080:BTY00D0:2PX038b<P0e=CD0=CDe03Xj>P020410@003
04M7A`11@D40@D5100@0A4A400D0AdM704a<C01<C4`0CTi>04e=C@0204];B`0404Q8B010@400@410
03/k>`H0>SXj00@0>3Ph038b<P0b<S80;Rh^0`0Y:BT0100X:2P0:RXZ02XZ:P0a<C4203Lg=`0403`l
?014A4@0Bd];04];B`<0C4a<00D0Bd];04M7A`11@D40@D5103`l?00203/k>`0503Xj>P0m?Cd0@T92
0492@P14A4@00P16ATH01@17AdL0ADE504E5A@14A4@0ADE50080ATI600@0B4Q804U9B@19BDT0BDU9
101:BTX304];B`80BDU900D0ATI604A4A012@T80@T920451@@0203lo?`0503dm?@0l?3`0?Cdm03dm
?@0l?3`00P0n?Sh204I6AP80B4Q800@0BTY:04Q8B018B4P0A4A40P16ATH01@17AdL0B4Q804];B`1;
Bd/0D51@00<0DE5A00@0Cdm?051@D01@D500Cdm?0P1CDe<0101GEeL0G5aL05aLG01OGel3061PH004
065QH@1SHf<0Hf=S065QH@l0oooo000=0?ooo`0409FEU@1eMGD0MGEe0?;blP80KFe]0P2FUYH209BD
U00408F5Q@35aLD0aLG509FEU@80Ogmo00D0/;2`08^;R`2KVi/0Vi^K08N7Q`0207AdM0050>k^kP1n
OWh0YJFU0:FUY@23Ph<00P2GUiL01@1oOgl0VYZJ09ZJVP3?cll0MWIf0080W9bL00D0XJ6Q08f=S@2=
SHd0UiNG06m_K`020?Shn00507IfMP2@T900T92@092@T02FUYH00P2IVIT0101MGEd0oooo0?ooo`1H
F5P208^;R`0509^KV`2RXZ80TI6A096AT@1lO7`00P3Shn<01@1mOGd0Shn?09RHV02HV9P0XZ:R0080
QhN700D0KFe]0>c/k03/k>`0NGUi09:BTP020:NWY`0509FEU@2<S8`0S8b<07UiN@3YjNT00P1dM7@0
102<S8`0WYjN09jNWP2NWYh2096AT@0506m_K`3[jn/0KVi^06i^KP2LW9`00P2HV9P01@2IVIT0Ti>C
07moO`1oOgl0c/k>0080Q8B400D0TY:B09^KV`2FUYH0UYJF07inOP020;Ng]`050;2`/01lO7`0O7al
092@T02QXJ400P2LW9`01@1WIfL0gmoO0=oOg`2ATI40PX:20080WIfM00@0W9bL09FEU@2EUID0HV9R
0P3WinL01@2CTi<0UIFE08J6QP26QXH0Ph>30080Z:RX00D0/K6a08R8R02GUiL0UiNG09JFUP0209bL
W00509NGU`2RXZ80H61P061PH03fm_H00P1/K6`01@2FUYH0RXZ:08Z:RP2:RXX0dm?C0080RHV900D0
QhN709^KV`2KVi/0Shn?09jNWP020::RXP0408N7Q`23Ph<0Ph>30=SHf080Lg=c00D0][Jf08J6QP1m
OGd0OGem0<?3``0209>CT`0308F5Q@3oool0oooo00P0oooo00@0Hf=S061PH01PH600Fe]K0P1FEUH0
1@1BDU80DE5A04i>CP1>CTh0Bd];0080CTi>00D0CDe=04M7A`17AdL0@d=303hn?P0203<c<`0402l_
;`0/;2`0;2`/02TY:@<0:2PX00@0:b/[03<c<`0c<c<0=3@d0P0c<c<01@0b<S80;2`/01lO7`0O7al0
6QXJ008061PH00D06ATI01XJ6P0N7Qh07QhN028R8P0202TY:@0502PX:00b<S80=CDe03De=@0j>SX0
0P10@4000`17AdL0@D510451@@0404A4A00504M7A`1<C4`0C4a<04i>CP1=CDd00P1;Bd/01018B4P0
@4100410@00k>c/603Xj>P0403Ph>00b<S80<S8b02h^;P<0:BTY00@0:2PX02XZ:P0Z:RX0<C4a0P0g
=cL0100l?3`0A4A404];B`1;Bd/304a<C00504];B`17AdL0@D510451@@0l?3`00P0k>c/01@0j>SX0
?Cdm0492@P12@T80A4A40080ATI600D0AdM704E5A@15ADD0A4A404E5A@0204I6AP0404Q8B019BDT0
BDU904U9B@@0BTY:0`1;Bd/204U9B@0504I6AP14A4@0@T920492@P11@D400P0o?cl01@0m?Cd0?3`l
03dm?@0m?Cd0?3`l0080?Shn0P16ATH204Q8B00404Y:BP18B4P0B4Q804A4A080ATI600D0AdM704Q8
B01;Bd/0Bd];051@D003055AD@0404m?C`1@D500D51@04m?C`80De=C00@0EeMG05aLG01LG5`0GemO
0`1PH600101QHF40Hf=S06=SH`1QHF4?0?ooo`003@3oool0102BTY80JFUY06UYJ@3oool205YJFP03
09FEU@2DU9@0UiNG0080UiNG0P2XZ:P01@2HV9P0S8b<08b<S02UYJD0T92@0080VIVI00D0SHf=05]K
F`1KFe/0oooo06MWI`020:^[Z`0407moO`2IVIT0VIVI08b<S080TY:B00D0^KVi08R8R02HV9P0V9RH
0:BTY00208V9R@0509BDU01ZJVX0oooo0?ooo`1QHF400P2>SXh209:BTP80XJ6Q00@0MgMg0=oOg`3O
gml0Lg=c0P2?Shl01@2IVIT0X:2P09NGU`2GUiL0IFEU0080oooo00D0JFUY09>CT`2@T900T92@0::R
XP0208n?S`0508:2PP2n_[h0_[jn08n?S`2BTY800P2XZ:P01@2DU9@0Rh^;08^;R`1SHf<0oooo0080
Hf=S00@0R8R80:>SX`2SXj<0V9RH0P2IVIT01@1mOGd0bl_;0861P@21PH40UiNG0080Vi^K00D0UiNG
09JFUP1[Jf/0Jf][0?;blP02075aL@0509:BTP2KVi/0UYJF09JFUP28R8P00P2XZ:P01@2^[Zh0QHF5
08F5Q@2?Shl0Xj>S0080Vi^K00D0BTY:0?ooo`3oool0O7al0861P@0209jNWP0409^KV`2HV9P0V9RH
07QhN080a<C400D0TY:B09fMW@29RHT0RHV906e]K@020<30`0050;jn_P1lO7`0UYJF09JFUP2HV9P0
0`2IVIT0102NWYh0N7Qh07QhN03>c/h207YjNP0509ZJVP21PH40PH610861P@3jn_X00P1hN7P01@23
Ph<0W9bL09bLW02@T900WIfM0080XZ:R0`2<S8`01@2o_kl0OWin07inOP2a/K40QhN70080Kfm_00@0
iNGU0820P020P800QXJ62P3oool0102^[Zh0/k>c0;>c/`2h^;P20;jn_P050<G5a@31`L40`<300<30
`032`/800P2n_[h01@2m_Kd0alO70<O7a`3<c<`0c/k>0080clo?00D0bl_;0<K6aP36a/H0alO70<W9
b@020=7Ad@040=KFeP3Hf=P0f=SH0=_Kf`80g=cL00D0g]kN0>?Sh`3]kNd0kNg]0?7al@030>WYj@04
0>CTi03Jf]X0f][J0<o?c`80cLg=00D0bLW90;jn_P2i^KT0^KVi0;>c/`020:b/[0050:>SX`2WYjL0
YjNW0::RXP2HV9P00P2IVIT01@2FUYH0SXj>08j>SP2BTY80X:2P0080Y:BT00@0Z:RX0;Bd]02d];@0
^KVi0P2j^[X01@2m_Kd0_[jn0;Ng]`2g]kL0Zj^[0080ZZZZ00D0YjNW0:JVYP2WYjL0YjNW0;6a/@02
0;>c/`050:n_[`2YZJT0ZJVY0:BTY02KVi/00P2@T9000`2>SXh0SHf=08f=S@0208N7Q`D0Rh^;00D0
T92@096AT@2;Rh/0Rh^;08F5Q@0207emO@0507IfMP1`L700L71`06QXJ01OGel00P1IFET01@1FEUH0
EeMG05MGE`1HF5P0GUiN0080Hf=S00@0IfMW06IVIP1VIVH0JFUY0P1/K6`01@1_Kfl0J6QX06IVIP1V
IVH0JFUY0080Kfm_00D0NGUi0820P026QXH0QXJ608N7Q`0208F5Q@0507inOP1jNWX0LW9b079bLP1W
IfL00P1RHV801@1IFET0DE5A055AD@1<C4`0BDU90080@T9200D0@41004A4A014A4@0A4A404];B`02
051@D0<0E5AD00D0EEEE04];B`1;Bd/0@D5103Xj>P0204Y:BP0405iNGP1gMgL0MgMg09:BTPl0oooo
000=0?ooo`0409>CT`1LG5`0G5aL0?ooo`80BDU900D0UIFE09BDU02EUID0UIFE0:VYZ@0209:BTP04
09jNWP2GUiL0UiNG09>CT`<0UiNG00D0Shn?04M7A`17AdL0oooo055AD@020:ZZZP0408:2PP2FUYH0
UYJF09^KV`80TY:B00D0VYZJ09bLW02GUiL0UiNG0:BTY00208^;R`0508f=S@1RHV80oooo0?ooo`11
@D400P2CTi<01@2DU9@0SHf=0:NWY`2WYjL0TI6A0080ZZZZ00D0T92@09FEU@2EUID0TY:B09bLW002
09nOW`0504];B`3oool0oooo059BDP2DU9@00P2@T900102LW9`0V9RH09RHV02?Shl20:6QX@0509bL
W02EUID0Y:BT0:BTY02EUID00P29RHT01@1:BTX0oooo055AD@1ADE40PX:20080ZJVY00D0UYJF0:2P
X02PX:00S8b<0:ZZZP0209:BTP0509>CT`2NWYh0WYjN09>CT`2DU9@00P1KFe/01@3oool0G5aL05aL
G02FUYH0V9RH0080UYJF00@0Ti>C09^KV`2KVi/0Y:BT0P2DU9@01@2;Rh/0YJFU09ZJVP2JVYX0;bl_
0080oooo00D0JFUY07moO`2RXZ80XZ:R09^KV`0209VIV@0508Z:RP2XZ:P0Z:RX09:BTP2OWil00P2;
Rh/01@1GEeL0hn?S0>?Sh`37alL0JFUY0080UYJF00D0Vi^K09JFUP2FUYH0Vi^K09VIV@0208^;R`04
0:VYZ@2;Rh/0Rh^;09jNWP80O7al00D0M7Ad0?ooo`1SHf<0Hf=S08>3P`0209bLW00509FEU@2CTi<0
YjNW0:NWY`2>SXh00P2FUYH01@2/[:`0S8b<08b<S02OWil0S8b<0080JVYZ00@0oooo07UiN@1iNGT0
Ogmo2P3oool0100W9bL09BDU02DU9@0U9BD202<S8`0501dM7@0N7Qh07AdM01dM7@0K6a/00P0L71`0
1@0K6a/061PH01PH600G5aL061PH00807QhN00D0:2PX034a<@0a<C40<C4a02h^;P0202HV9P0401XJ
6P0?3`l03`l?00`<30<02`/;0`0=3@d01@0<30`06ATI01TI6@0J6QX071`L00808R8R00D0:BTY02<S
8`0S8b<09BDU02PX:00202XZ:P0402d];@0^;Rh0;Rh^03<c<`80=SHf00<0?3`l04M7A`19BDT00P19
BDT204Y:BP0504E5A@0i>CT0>3Ph03Ph>00e=CD00P0a<C401@0];Bd0;2`/02`/;00Z:RX0;bl_0080
>CTi00D0AdM704i>CP1>CTh0EEEE05UIF@0205IFEP0404i>CP1<C4`0C4a<04];B`80C4a<00D0CDe=
051@D01DE5@0E5AD05IFEP0205MGE`0505mOG`1XJ6P0KFe]06e]K@1eMGD00`1jNWX0101hN7P0Ng]k
07]kN`22PX8208^;R`0309>CT`2LW9`0W9bL0080YJFU0P2ZZZX01@2YZJT0YjNW0:NWY`2TY:@0YZJV
0080XJ6Q00@0Vi^K09ZJVP2JVYX0VYZJ0P2IVIT01@2JVYX0WinO09nOW`2OWil0VYZJ0080U9BD00D0
Rh^;08b<S02=SHd0SHf=08n?S`0309>CT`0409FEU@2HV9P0V9RH0:2PX080YJFU00D0[Zj^0;Fe]@2e
]KD0^[Zj0;fm_@020<?3``050<_;b`3:b/X0b/[:0<c<c038b<P00P32`/80102o_kl0_;bl0;bl_02g
]kL30;Vi^@040;fm_@2QXJ40XJ6Q08B4Q080I6AT00<0C4a<0?ooo`3oool03@3oool000d0oooo00@0
Ti>C05aLG01LG5`0oooo0P19BDT01@2EUID0U9BD09FEU@2EUID0ZJVY0080TY:B00@0WYjN09NGU`2G
UiL0Ti>C0`2GUiL01@2?Shl0AdM704M7A`3oool0DE5A0080ZZZZ00@0PX:209JFUP2FUYH0Vi^K0P2B
TY801@2JVYX0W9bL09NGU`2GUiL0Y:BT0080Rh^;00D0SHf=069RHP3oool0oooo0451@@0209>CT`05
09BDU02=SHd0YjNW0:NWY`2ATI400P2ZZZX01@2@T900UIFE09FEU@2BTY80W9bL0080WinO00D0Bd];
0?ooo`3oool0DU9B09BDU002092@T00409bLW02HV9P0V9RH08n?S`80XJ6Q00D0W9bL09FEU@2TY:@0
Y:BT09FEU@0208V9R@0504Y:BP3oool0DE5A055AD@22PX800P2YZJT01@2FUYH0X:2P0:2PX02<S8`0
ZZZZ0080TY:B00D0Ti>C09jNWP2NWYh0Ti>C09BDU00205]KF`050?ooo`1LG5`0G5aL09JFUP2HV9P0
0P2FUYH0102CTi<0Vi^K09^KV`2TY:@209BDU00508^;R`2UYJD0VYZJ09ZJVP0_;bl00P3oool01@1Y
JFT0Ogmo0::RXP2RXZ80Vi^K0080VIVI00D0RXZ:0:RXZ02XZ:P0TY:B09nOW`0208^;R`0505MGE`3S
hn<0hn?S0<O7a`1YJFT00P2FUYH01@2KVi/0UYJF09JFUP2KVi/0VIVI0080Rh^;00@0ZJVY08^;R`2;
Rh/0WYjN0P1lO7`01@1dM7@0oooo06=SH`1SHf<0Ph>30080W9bL00D0UIFE09>CT`2WYjL0YjNW08j>
SP0209JFUP050:b/[02<S8`0S8b<09nOW`2<S8`00P1ZJVX0103oool0NGUi07UiN@1oOgl:0?ooo`04
02LW9`0U9BD09BDU02DU9@808b<S00D07AdM01hN7P0M7Ad07AdM01/K6`0201`L700501/K6`0H61P0
61PH01LG5`0H61P00P0N7Qh01@0X:2P0<C4a034a<@0a<C40;Rh^00809RHV00@06QXJ00l?3`0?3`l0
30`<0`0;2`/300d=3@0500`<300I6AT06ATI01XJ6P0L71`00P0R8R801@0Y:BT08b<S02<S8`0U9BD0
:2PX0080:RXZ00@0;Bd]02h^;P0^;Rh0<c<c0P0f=SH00`0l?3`0AdM704U9B@0204U9B@80BTY:00D0
ADE503Ti>@0h>3P0>3Ph03De=@02034a<@0502d];@0/;2`0;2`/02XZ:P0_;bl00P0i>CT01@17AdL0
CTi>04i>CP1EEED0FEUI0080EUIF00@0CTi>04a<C01<C4`0Bd];0P1<C4`01@1=CDd0D51@05ADE01D
E5@0EUIF0080EeMG00D0GemO06QXJ01]KFd0KFe]07EeM@0307YjNP0407QhN01kNg/0Ng]k08:2PP80
Rh^;00<0Ti>C09bLW02LW9`00P2UYJD20:ZZZP050:VYZ@2WYjL0YjNW0:BTY02VYZH00P2QXJ40102K
Vi/0VYZJ09ZJVP2JVYX209VIV@0509ZJVP2OWil0WinO09nOW`2JVYX00P2DU9@01@2;Rh/0S8b<08f=
S@2=SHd0Shn?00<0Ti>C00@0UIFE09RHV02HV9P0X:2P0P2UYJD01@2^[Zh0]KFe0;Fe]@2j^[X0_Kfm
0080`l?300D0bl_;0<[:bP3:b/X0c<c<0<S8b0020<;2`P040;no_`2l_;`0_;bl0;Ng]`<0^KVi00@0
_Kfm0:6QX@2QXJ40Q8B40P1TI6@00`1<C4`0oooo0?ooo`0=0?ooo`003@3oool0102ATI40I6AT06AT
I03oool204Y:BP0509>CT`2FUYH0UYJF09JFUP2MWId00P2OWil01@2PX:00TI6A096AT@2EUID0U9BD
0080UiNG00D0U9BD04M7A`17AdL0oooo05EEE@020:RXZ00408B4Q02EUID0UIFE09VIV@80UIFE00D0
VYZJ09fMW@2FUYH0UYJF09nOW`0208^;R`0508j>SP1HF5P0oooo0?ooo`0Z:RX00`2FUYH0102@T900
ZJVY0:VYZ@2ATI4309VIV@80WIfM00D0T92@09VIV@2LW9`0W9bL03lo?`020?ooo`050410@02DU9@0
V9RH09RHV02CTi<00P2KVi/309NGU`0509VIV@2MWId0XJ6Q0:6QX@2CTi<00P29RHT01@0k>c/0oooo
03Ph>00h>3P0R8R80080YZJV00D0V9RH0:NWY`2WYjL0Rh^;09bLW00209^KV`0509FEU@2MWId0WIfM
09>CT`2HV9P00P19BDT01@3oool0CTi>04i>CP2DU9@0UIFE00<0VIVI0P2CTi<01@2HV9P0Y:BT0:BT
Y02>SXh0XZ:R0080VYZJ00D04Q8B0?ooo`3oool0F5QH07YjNP0209bLW0040:>SX`2FUYH0UYJF09^K
V`<0UIFE00@0WIfM08V9R@29RHT0?Shn0P3oool01@3=cLd0FUYJ09RHV02HV9P0U9BD0080W9bL00<0
V9RH09NGU`2DU9@00P2DU9@209:BTP050:NWY`1nOWh0OWin061PH03oool00P1ADE401@29RHT0WYjN
09jNWP2GUiL0Shn?0080XJ6Q00@0Vi^K09BDU02DU9@0Y:BT0P2CTi<01@2FUYH0R8R806MWI`1WIfL0
oooo0080G5aL00<0S8b<0?ooo`3oool0203oool305iNGP0405eMG@1NGUh0GUiN05mOG`@0GUiN1`1M
GEd2061PH005069RHP1QHF40HF5Q069RHP1TI6@00P1OGel00`1NGUh0GEeM05eMG@0305]KF`0405eM
G@1NGUh0GemO05mOG`<0GUiN0P1MGEd205aLG00405eMG@1LG5`0G5aL05aLG0@0FEUI1@1JFUX205QH
F0<0EUIF0P1GEeL01@1HF5P0EEEE05=CD`1CDe<0DE5A0080CTi>00<0DU9B05EEE@1EEED00P1FEUH2
05EEE@05055AD@1=CDd0CDe=04];B`1:BTX00P1<C4`304U9B@0404Q8B019BDT0BDU904U9B@<0Bd];
00D0CDe=04a<C01<C4`0BTY:04E5A@020451@@0303`l?00i>CT0>CTi0080=CDe0P0a<C40100];Bd0
:BTY02TY:@0V9RH302DU9@04030`<00d=3@0=3@d03Lg=`80>3Ph00D0>SXj030`<00^;Rh0;Rh^02d]
;@0202/[:`0502PX:00W9bL09bLW02DU9@0Z:RX00P0_;bl01@0d=3@0>3Ph03Ph>00j>SX0<c<c0080
;Bd]00D0:RXZ02HV9P0V9RH09BDU02HV9P0302LW9`8092@T0`0Y:BT01@0X:2P09bLW02PX:00X:2P0
7alO00806a/K00@06QXJ01TI6@0G5aL05aLG0`0H61P01@0I6AT07AdM01dM7@0W9bL0:BTY0080=cLg
00@0A4A404e=C@1=CDd0DE5A3`3oool000d0oooo00@0[Zj^06IVIP1VIVH0oooo0P1PH600102?Shl0
QhN70;^k^`2k^k/309JFUP0509bLW02CTi<0Ti>C08n?S`2<S8`00P2d];@01@2EUID0C4a<04a<C03o
ool0EeMG0080XZ:R00@0OGem0;Jf]P2f][H0Rh^;0P2DU9@01@2IVIT0XZ:R09>CT`2CTi<0TI6A0080
WYjN00D0SHf=071`L03oool0oooo03Xj>P0208n?S`0509fMW@2SXj<0WinO09nOW`2=SHd00P2BTY80
1@2OWil0WIfM09fMW@22PX80[Zj^0080XZ:R00D0@d=30?ooo`3oool0DE5A09nOW`0208j>SP040:6Q
X@2BTY80TY:B09NGU`80UIFE00D0WIfM09bLW02IVIT0VIVI0:VYZ@0208:2PP050492@P3oool0@T92
0492@P2ATI400P2TY:@01@2KVi/0YjNW0:NWY`2@T900UIFE0080VIVI00D0UiNG0:>SX`2SXj<0TI6A
09VIV@0205=CD`050?ooo`1CDe<0De=C09RHV02IVIT00P2FUYH0102HV9P0U9BD09BDU02DU9@20:JV
YP0509JFUP2LW9`0VYZJ09ZJVP0J6QX00P3oool01@1DE5@0QHF509VIV@2IVIT0Xj>S0080U9BD00D0
VYZJ09VIV@2IVIT0UIFE09bLW00209:BTP0503Ph>03oool0oooo0<71`@1RHV800P2HV9P00`2FUYH0
Vi^K09^KV`0209NGU`80Ti>C00@0UiNG096AT@2ATI40Z:RX0P20P8001@1LG5`0oooo05YJFP1JFUX0
S8b<0080VYZJ00D0UiNG09:BTP2NWYh0WYjN09>CT`0209^KV`050:>SX`2BTY80TY:B09RHV025QHD0
0P1WIfL0103oool0@T920492@P2HV9P:0?ooo`@0GemO0P1MGEd01@1JFUX0F5QH05UIF@1IFET0FUYJ
0080Fe]K00D0GUiN05mOG`1OGel0GemO05iNGP0205]KF`0505QHF01GEeL0EeMG05MGE`1IFET00P1M
GEd0101PH600HV9R069RHP1RHV82065QH@0505iNGP1MGEd0GUiN05iNGP1QHF400P1OGel2061PH080
GemO00D0G5aL05iNGP1NGUh0GUiN05aLG00205]KF`<0FUYJ00D0Fe]K05eMG@1MGEd0GEeM05YJFP03
05UIF@80F5QH00D0FEUI05aLG01OGel0GemO061PH00306ATI080Hf=S00D0H61P05iNGP1LG5`0G5aL
05iNGP0205mOG`80H61P0P1MGEd00`1KFe/0FUYJ05YJFP0305UIF@0405]KF`1LG5`0GUiN05iNGP<0
GEeM00<0GUiN05mOG`1NGUh0101NGUh205aLG080GemO00<0H61P06=SH`1SHf<00`1TI6@01@1QHF40
GemO05YJFP1JFUX0F5QH0080E5AD0P1ADE4205ADE00405EEE@1IFET0FEUI05eMG@<0GemO00@0GEeM
05aLG01LG5`0FUYJ0P1IFET01@1HF5P0FUYJ05UIF@1IFET0F5QH0080FEUI00D0F5QH05UIF@1HF5P0
F5QH05UIF@0205aLG0<0GemO00D0H61P05iNGP1JFUX0FUYJ05UIF@0205MGE`0505IFEP1DE5@0De=C
05=CD`1ADE400`1CDe<205EEE@0505QHF01IFET0FEUI05UIF@1KFe/00P1MGEd00`1OGel0oooo0?oo
o`0=0?ooo`003@3oool0103]kNd0EUIF05IFEP3Jf]X2075aL@0508Z:RP1UIFD0n_[j0?[jnP2:RXX0
0P2;Rh/01@2GUiL0UIFE09FEU@29RHT0M7Ad0080l?3`00D0QHF505YJFP1JFUX0mOGe06=SH`0209bL
W00407AdM03Lg=`0g=cL07moO`80S8b<00D0WYjN0:>SX`2>SXh0SXj>08F5Q@020;6a/@0508^;R`27
QhL0oooo0?ooo`1>CTh00P28R8P01@2<S8`0dm?C08b<S02<S8`0PX:20080U9BD00D0Y:BT09ZJVP2J
VYX0J6QX0=GEe@020::RXP0504a<C03inOT0nOWi06EUI@2QXJ400P1aLG40103Bd]80N7Qh07QhN02B
TY8209nOW`050:2PX02HV9P0U9BD09BDU03<c<`00P1ZJVX01@1DE5@0oooo05EEE@1EEED0PX:20080
/[:b00D0/;2`09RHV02HV9P0SHf=09JFUP0209>CT`0507inOP3Bd]80d];B08Z:RP2<S8`00P1TI6@0
1@3oool0GemO05mOG`1oOgl0e]KF0080MgMg00@0VIVI09:BTP2BTY80QHF50P2d];@01@2XZ:P0Rh^;
09JFUP2FUYH0?clo0080oooo00D0F5QH0;:b/P25QHD0QHF50:2PX00209JFUP<0V9RH00D0PX:20<[:
bP1lO7`0O7al04a<C0020?Gem@050;6a/@1EEED0_;bl0;bl_02LW9`00P29RHT01@2LW9`0UiNG09JF
UP2FUYH0QhN70080Vi^K00D0_[jn07EeM@1eMGD0Kfm_0?ooo`0205mOG`0308J6QP2k^k/0^k^k0080
T92@0P2KVi/0102@T900Vi^K09^KV`2;Rh/20;Rh^00509VIV@20P800M7Ad07AdM03hn?P00P1EEED0
0`1oOgl0oooo0?ooo`080?ooo`04020P800M7Ad07AdM01TI6@<06QXJ0`0I6AT0100J6QX06ATI01TI
6@0G5aL201TI6@0401/K6`0L71`09BDU02DU9@<092@T00@09BDU02HV9P0P8200820P0`0S8b<01@0V
9RH0:BTY02TY:@0[:b/0;2`/0080:b/[00D0:RXZ02d];@0];Bd0;Bd]02h^;P0203@d=00503Hf=P0j
>SX0>SXj03lo?`14A4@00P19BDT0101<C4`0BDU904U9B@16ATH20492@P0503dm?@0n?Sh0?Shn03hn
?P0o?cl00P10@4000`12@T80@4100451@@020451@@80?clo00D0?Shn03dm?@0m?Cd0?clo0492@P02
0451@@0504I6AP18B4P0B4Q804Q8B01<C4`00P1EEED0101GEeL0Fe]K05]KF`1NGUh205eMG@0505QH
F01FEUH0DU9B059BDP1?Cdl00`1=CDd01019BDT0ATI604I6AP14A4@20451@@0303lo?`10@400@D51
0080@D510P12@T801@14A4@0ADE504E5A@1:BTX0CDe=0080De=C00D0FUYJ06=SH`1SHf<0IFEU06QX
J00206IVIP04061PH01IFET0FEUI05IFEP80EEEE00<0F5QH05iNGP1PH6000P1PH60205mOG`0505eM
G@1JFUX0Fe]K05]KF`1LG5`00P1MGEd00`1NGUh0GEeM05]KF`0205]KF`80FUYJ00<0Fe]K05aLG01L
G5`00P1MGEd205iNGP0505eMG@1OGel0GemO05mOG`1PH6000P1QHF40101PH600GEeM05eMG@1QHF42
069RHP05061PH01OGel0E5AD05ADE016ATH00P0f=SH00`0];Bd0oooo0?ooo`0=0?ooo`003@3oool0
103]kNd0EUIF05IFEP3Jf]X2075aL@0508Z:RP1UIFD0n_[j0?[jnP2:RXX00P2;Rh/01@2GUiL0UIFE
09FEU@29RHT0M7Ad0080l?3`00D0QHF505YJFP1JFUX0mOGe06=SH`0209bLW00407AdM03Lg=`0g=cL
07moO`80S8b<00D0WYjN0:>SX`2>SXh0SXj>08F5Q@020;6a/@0508^;R`27QhL0oooo0?ooo`1>CTh0
0P28R8P01@2<S8`0dm?C08b<S02<S8`0PX:20080U9BD00D0Y:BT09ZJVP2JVYX0J6QX0=GEe@020::R
XP0504a<C03inOT0nOWi06EUI@2QXJ400P1aLG40103Bd]80N7Qh07QhN02BTY8209nOW`050:2PX02H
V9P0U9BD09BDU03<c<`00P1ZJVX01@1DE5@0oooo05EEE@1EEED0PX:20080/[:b00D0/;2`09RHV02H
V9P0SHf=09JFUP0209>CT`0507inOP3Bd]80d];B08Z:RP2<S8`00P1TI6@01@3oool0GemO05mOG`1o
Ogl0e]KF0080MgMg00@0VIVI09:BTP2BTY80QHF50P2d];@01@2XZ:P0Rh^;09JFUP2FUYH0?clo0080
oooo00D0F5QH0;:b/P25QHD0QHF50:2PX00209JFUP<0V9RH00D0PX:20<[:bP1lO7`0O7al04a<C002
0?Gem@050;6a/@1EEED0_;bl0;bl_02LW9`00P29RHT01@2LW9`0UiNG09JFUP2FUYH0QhN70080Vi^K
00D0_[jn07EeM@1eMGD0Kfm_0?ooo`0205mOG`0308J6QP2k^k/0^k^k0080T92@0P2KVi/0102@T900
Vi^K09^KV`2;Rh/20;Rh^00509VIV@20P800M7Ad07AdM03hn?P00P1EEED00`1oOgl0oooo0?ooo`08
0?ooo`04020P800M7Ad07AdM01TI6@<06QXJ0`0I6AT0100J6QX06ATI01TI6@0G5aL201TI6@0401/K
6`0L71`09BDU02DU9@<092@T00@09BDU02HV9P0P8200820P0`0S8b<01@0V9RH0:BTY02TY:@0[:b/0
;2`/0080:b/[00D0:RXZ02d];@0];Bd0;Bd]02h^;P0203@d=00503Hf=P0j>SX0>SXj03lo?`14A4@0
0P19BDT0101<C4`0BDU904U9B@16ATH20492@P0503dm?@0n?Sh0?Shn03hn?P0o?cl00P10@4000`12
@T80@4100451@@020451@@80?clo00D0?Shn03dm?@0m?Cd0?clo0492@P020451@@0504I6AP18B4P0
B4Q804Q8B01<C4`00P1EEED0101GEeL0Fe]K05]KF`1NGUh205eMG@0505QHF01FEUH0DU9B059BDP1?
Cdl00`1=CDd01019BDT0ATI604I6AP14A4@20451@@0303lo?`10@400@D510080@D510P12@T801@14
A4@0ADE504E5A@1:BTX0CDe=0080De=C00D0FUYJ06=SH`1SHf<0IFEU06QXJ00206IVIP04061PH01I
FET0FEUI05IFEP80EEEE00<0F5QH05iNGP1PH6000P1PH60205mOG`0505eMG@1JFUX0Fe]K05]KF`1L
G5`00P1MGEd00`1NGUh0GEeM05]KF`0205]KF`80FUYJ00<0Fe]K05aLG01LG5`00P1MGEd205iNGP05
05eMG@1OGel0GemO05mOG`1PH6000P1QHF40101PH600GEeM05eMG@1QHF42069RHP05061PH01OGel0
E5AD05ADE016ATH00P0f=SH00`0];Bd0oooo0?ooo`0=0?ooo`003P3oool204=3@`050;Ng]`22PX80
PX:208F5Q@15ADD00P3oool0101kNg/0Ogmo07moO`2FUYH209FEU@0508N7Q`1DE5@0oooo0?ooo`1`
L7000P1TI6@01@3<c<`0MGEe09JFUP2FUYH0I6AT0080oooo00D0KFe]08B4Q024Q8@0WinO09jNWP02
092@T00506m_K`34a<@0a<C409FEU@2ATI400P3Vi^H01@1OGel0QHF508F5Q@1kNg/0nOWi0080Ogmo
00@0M7Ad09NGU`2GUiL0ZJVY0P2FUYH01@1>CTh0oooo09bLW02LW9`0DE5A0080emOG00D0N7Qh09bL
W01KFe/0Fe]K0?gmo@0206MWI`0508^;R`2MWId0WIfM0:6QX@2HV9P00P2KVi/01@3Ti>@0De=C05=C
D`1ZJVX0j>SX0080JVYZ00@0LG5a0<G5a@35aLD0`L710P24Q8@01@2ATI40UIFE08j>SP2>SXh0IFEU
0080oooo00D0P8200861P@1jNWX0NWYj0=gMg@02071`L00506QXJ03oool0HF5Q065QH@2IVIT00P2G
UiL01@1iNGT0YjNW0:NWY`3;bl/0NWYj0080U9BD00D0HV9R0??cl`3clo<0FUYJ0=SHf00207EeM@04
09bLW02FUYH0UYJF09RHV080UYJF00D0MgMg0?Gem@1RHV80HV9R061PH0020=gMg@050:JVYP1=CDd0
dm?C0=?Cd`2SXj<00P22PX801@2GUiL0VIVI09ZJVP2JVYX0MgMg0080]KFe00D0_[jn07=cL`1cLg<0
MWIf0>7Qh@02075aL@0506e]K@3dm?@0m?Cd07emO@28R8P00P2KVi/0102=SHd0WIfM09fMW@1]KFd2
0??cl`050820P022PX80PH610861P@3Fe]H00`1TI6@:0?ooo`040;jn_P35aLD0aLG50<o?c`80a<C4
00<0`L710<O7a`3:b/X00P3:b/X20=?Cd`050=;BdP31`L40`L710;Vi^@2j^[X00P2d];@01@2h^;P0
_[jn0;jn_P2m_Kd0/;2`0080[jn_0`2YZJT01@2UYJD0YZJV0:JVYP2RXZ80UIFE0080SXj>00D0S8b<
08j>SP2>SXh0SXj>09:BTP0208Z:RP050820P01fMWH0MWIf07=cL`1`L7000P1bLW80101gMgL0N7Qh
07QhN01_Kfl206a/K00506i^KP1bLW80LW9b079bLP1dM7@00P1cLg<00`1[Jf/0IFEU06=SH`0206=S
H`80HV9R00<0IFEU065QH@1QHF400P1JFUX205eMG@05065QH@1PH600H61P061PH01GEeL00P1=CDd0
1013@d<0?clo03lo?`0m?Cd203hn?P050410@00k>c/0>c/k03/k>`0n?Sh00P10@4001@17AdL0C4a<
04m?C`1?Cdl0CDe=0080Cdm?00D0C4a<04];B`18B4P0B4Q804M7A`0203lo?`0503Lg=`0b<S80<S8b
02XZ:P0^;Rh00P0[:b/302HV9P0402d];@0V9RH0;2`/02`/;0<0=3@d00D0;bl_02XZ:P0Z:RX09RHV
02d];@0203@d=00503Ph>00o?cl0?clo04=3@`0j>SX00P0c<c<01@0b<S80<30`030`<00`<300<S8b
0080>CTi00@0>c/k03dm?@0m?Cd0?clo0P0h>3P01@0c<c<0<S8b02h^;P0^;Rh0:RXZ0080<C4a00D0
=SHf03Ph>00l?3`0?3`l03lo?`0203hn?P0503Ph>00c<c<0<c<c034a<@0/;2`00P14A4@0101KFe/0
OGem07emO@2KVi/?0?ooo`003P3oool203Lg=`0509JFUP2DU9@0U9BD07alO00_;bl00P3oool00`1T
I6@0MgMg07MgM`0309JFUP0508>3P`0l?3`0oooo0?ooo`1LG5`00P1_Kfl01@2NWYh0RHV909FEU@2E
UID0FEUI0080oooo00D0Fe]K07UiN@1iNGT0YZJV09^KV`0208n?S`0505EEE@3Hf=P0f=SH09^KV`2Q
XJ400P32`/801@1oOgl0NWYj07YjNP1fMWH0oooo0080JFUY00@0IVIV09nOW`2OWil0/;2`0P2>SXh0
1@0i>CT0oooo09JFUP2FUYH0GEeM0080[Jf]00D0Shn?09^KV`10@400@4100?ooo`0205UIF@0508J6
QP2CTi<0Ti>C0:JVYP2IVIT00P2KVi/01@3oool0=3@d03@d=029RHT0^[Zj0080Ogmo00@0HF5Q0=cL
g03Lg=`0alO70P1dM7@01@2BTY80UYJF08N7Q`27QhL0Cdm?0080oooo00D0LG5a07UiN@2<S8`0S8b<
0;Vi^@020861P@0405=CD`3oool0BDU904U9B@<0VIVI00D0LG5a09VIV@2IVIT0k^k^06QXJ00209VI
V@0507YjNP33`l<0`l?3069RHP3inOT00P1TI6@0102EUID0UiNG09NGU`2EUID209bLW00506EUI@3o
ool0BDU904U9B@1eMGD00P2j^[X01@2OWil0B4Q80>SXj03Xj>P0[Zj^0080MGEe00D0UYJF09bLW02K
Vi/0Vi^K06][J`020=CDe0050;Fe]@1`L700L71`08B4Q02g]kL00P22PX801@1>CTh0oooo0?ooo`1T
I6@0RXZ:00<0TI6A0P2KVi/01@1?Cdl0oooo0?ooo`1]KFd0Ogmo0080R8R800@0_Kfm07QhN01hN7P0
B4Q82P3oool0101EEED0DU9B059BDP1EEED205UIF@0505eMG@1GEeL0DE5A055AD@1=CDd00P1<C4`0
1@1@D500F5QH05QHF01OGel0GUiN0080Fe]K00D0EUIF05MGE`1GEeL0EEEE05aLG002065QH@0406AT
I01SHf<0Hf=S06QXJ080IfMW00D0Jf][07AdM01iNGT0NGUi07IfMP02071`L00506e]K@1YJFT0Lg=c
07=cL`1jNWX00P24Q8@208J6QP80Ogmo00@0OGem07inOP1nOWh0Q8B40P2:RXX01@2>SXh0S8b<09:B
TP2BTY80VIVI0080WYjN00D0WinO0:NWY`2SXj<0Xj>S09VIV@0209:BTP0508j>SP2<S8`0S8b<08n?
S`2EUID00`2KVi/20:BTY0050:n_[`2b/[80/[:b0;:b/P30`<000P36a/H01@35aLD0cLg=0<g=c@3G
emL0d=3@0080b/[:00D0b<S80<C4a034a<@0^[Zj0<C4a0020<W9b@050<71`@33`l<0`l?30<c<c03>
c/h00P3Bd]80103MgMd0h^;R0>;RhP3YjNT20>c/k0050>g]k@3WinL0hn?S0>?Sh`3De=@00P3;bl/0
1@33`l<0a/K60<?3``33`l<0b/[:0080c/k>00D0b/[:0<o?c`3?cll0d=3@0<O7a`020;no_`050<C4
a02`/;00/;2`0:JVYP2][Jd00P2`/;001@2][Jd0][Jf0;Jf]P2j^[X0[jn_0080X:2P00@0WIfM09ZJ
VP2JVYX0Vi^K0P2^[Zh01@2l_;`0][Jf0;Rh^02h^;P0^[Zj0080[Zj^00D0ZJVY0;6a/@2b/[80/[:b
0:FUY@020::RXP050:>SX`2UYJD0YJFU0:ZZZP2k^k/00P2`/;00102PX:00RHV908V9R@1^KVh?0?oo
o`003P3oool203Lg=`0509JFUP2DU9@0U9BD07alO00_;bl00P3oool00`1TI6@0MgMg07MgM`0309JF
UP0508>3P`0l?3`0oooo0?ooo`1LG5`00P1_Kfl01@2NWYh0RHV909FEU@2EUID0FEUI0080oooo00D0
Fe]K07UiN@1iNGT0YZJV09^KV`0208n?S`0505EEE@3Hf=P0f=SH09^KV`2QXJ400P32`/801@1oOgl0
NWYj07YjNP1fMWH0oooo0080JFUY00@0IVIV09nOW`2OWil0/;2`0P2>SXh01@0i>CT0oooo09JFUP2F
UYH0GEeM0080[Jf]00D0Shn?09^KV`10@400@4100?ooo`0205UIF@0508J6QP2CTi<0Ti>C0:JVYP2I
VIT00P2KVi/01@3oool0=3@d03@d=029RHT0^[Zj0080Ogmo00@0HF5Q0=cLg03Lg=`0alO70P1dM7@0
1@2BTY80UYJF08N7Q`27QhL0Cdm?0080oooo00D0LG5a07UiN@2<S8`0S8b<0;Vi^@020861P@0405=C
D`3oool0BDU904U9B@<0VIVI00D0LG5a09VIV@2IVIT0k^k^06QXJ00209VIV@0507YjNP33`l<0`l?3
069RHP3inOT00P1TI6@0102EUID0UiNG09NGU`2EUID209bLW00506EUI@3oool0BDU904U9B@1eMGD0
0P2j^[X01@2OWil0B4Q80>SXj03Xj>P0[Zj^0080MGEe00D0UYJF09bLW02KVi/0Vi^K06][J`020=CD
e0050;Fe]@1`L700L71`08B4Q02g]kL00P22PX801@1>CTh0oooo0?ooo`1TI6@0RXZ:00<0TI6A0P2K
Vi/01@1?Cdl0oooo0?ooo`1]KFd0Ogmo0080R8R800@0_Kfm07QhN01hN7P0B4Q82P3oool0101EEED0
DU9B059BDP1EEED205UIF@0505eMG@1GEeL0DE5A055AD@1=CDd00P1<C4`01@1@D500F5QH05QHF01O
Gel0GUiN0080Fe]K00D0EUIF05MGE`1GEeL0EEEE05aLG002065QH@0406ATI01SHf<0Hf=S06QXJ080
IfMW00D0Jf][07AdM01iNGT0NGUi07IfMP02071`L00506e]K@1YJFT0Lg=c07=cL`1jNWX00P24Q8@2
08J6QP80Ogmo00@0OGem07inOP1nOWh0Q8B40P2:RXX01@2>SXh0S8b<09:BTP2BTY80VIVI0080WYjN
00D0WinO0:NWY`2SXj<0Xj>S09VIV@0209:BTP0508j>SP2<S8`0S8b<08n?S`2EUID00`2KVi/20:BT
Y0050:n_[`2b/[80/[:b0;:b/P30`<000P36a/H01@35aLD0cLg=0<g=c@3GemL0d=3@0080b/[:00D0
b<S80<C4a034a<@0^[Zj0<C4a0020<W9b@050<71`@33`l<0`l?30<c<c03>c/h00P3Bd]80103MgMd0
h^;R0>;RhP3YjNT20>c/k0050>g]k@3WinL0hn?S0>?Sh`3De=@00P3;bl/01@33`l<0a/K60<?3``33
`l<0b/[:0080c/k>00D0b/[:0<o?c`3?cll0d=3@0<O7a`020;no_`050<C4a02`/;00/;2`0:JVYP2]
[Jd00P2`/;001@2][Jd0][Jf0;Jf]P2j^[X0[jn_0080X:2P00@0WIfM09ZJVP2JVYX0Vi^K0P2^[Zh0
1@2l_;`0][Jf0;Rh^02h^;P0^[Zj0080[Zj^00D0ZJVY0;6a/@2b/[80/[:b0:FUY@020::RXP050:>S
X`2UYJD0YJFU0:ZZZP2k^k/00P2`/;00102PX:00RHV908V9R@1^KVh?0?ooo`003P3oool202<S8`05
08V9R@2MWId0WIfM07]kN`0P82000P3oool0101YJFT0Hf=S06=SH`2HV9P209jNWP0507]kN`0[:b/0
oooo0?ooo`1EEED00P1[Jf/01@2ATI40SHf=09fMW@2MWId0DE5A0080oooo00<0Fe]K07EeM@1eMGD0
0P2NWYh2096AT@0503lo?`3_knl0kno_09FEU@2c/k<00P2SXj<01@2?Shl0P8200820P01[Jf/0oooo
0080HF5Q00@0G5aL0:b/[02/[:`0[jn_0P2:RXX01@0c<c<0oooo09FEU@2EUID0HV9R0080Ti>C00D0
XJ6Q09VIV@0];Bd0;Bd]0?ooo`0203lo?`0507inOP2IVIT0VIVI0::RXP2VYZH00P2>SXh01@3oool0
7alO01lO7`2HV9P0VIVI0080UiNG00@0CTi>0?7al@3alO40bLW90P1VIVH01@2IVIT0UYJF07alO01l
O7`0@4100080oooo00D0GemO07IfMP2JVYX0VYZJ09jNWP0208b<S00503hn?P3oool0=cLg03Lg=`2N
WYh00P2DU9@01@1^KVh0RHV908V9R@3oool0EUIF0080UYJF00D0Vi^K08j>SP2>SXh0I6AT0?ooo`02
05EEE@0408Z:RP2LW9`0W9bL08n?S`80W9bL00D0G5aL0?ooo`0g=cL0=cLg08^;R`0209NGU`0509fM
W@0n?Sh0o?cl0?clo02o_kl00P1SHf<01@2GUiL0WIfM09ZJVP2JVYX0IVIV0080lo?c00D0Xj>S071`
L01`L700RXZ:09NGU`0209RHV00502PX:03oool0oooo04a<C029RHT00P2>SXh0102BTY80UYJF09JF
UP0];Bd20?ooo`05055AD@25QHD0TY:B09:BTP2NWYh00P2HV9P00`0U9BD0oooo0?ooo`080?ooo`04
04I6AP12@T80@T9203Lg=`80?3`l00D0@4100492@P14A4@0A4A404M7A`020410@00303hn?P14A4@0
A4A400@0ATI600D0ADE503dm?@0m?Cd0?Cdm03hn?P020451@@0404E5A@1<C4`0C4a<04m?C`80DU9B
0P1FEUH2051@D00504a<C019BDT0BDU904=3@`0n?Sh00P0l?3`40451@@0404A4A017AdL0AdM70410
@080@D510`13@d<01@11@D40?clo03`l?00l?3`0=3@d0080;Rh^0P0c<c<203Ti>@0404I6AP1@D500
D51@055AD@80EEEE00D0EeMG04Y:BP10@400@41003Hf=P0202d];@05020P800S8b<0:b/[02/[:`0Y
:BT00`0U9BD201dM7@0501<C4`0O7al09bLW02LW9`0X:2P00P0Z:RX0100Y:BT071`L01LG5`0G5aL3
02LW9`0502HV9P0U9BD08B4Q024Q8@0F5QH00P0E5AD3014A4@05018B4P0;2`/04Q8B018B4P0U9BD0
0P0/;2`01@0_;bl0<S8b02d];@0];Bd0820P00806a/K0`0S8b<01@0V9RH09bLW02PX:00X:2P08B4Q
0080<C4a00D0>SXj03`l?012@T80@T9204E5A@0203Ti>@0503<c<`0l?3`0CDe=04e=C@1CDe<00P1H
F5P01@1EEED0Bd];04];B`0m?Cd0@D510080A4A400D0C4a<05=CD`1CDe<0E5AD04a<C00204I6AP03
04e=C@1GEeL0EeMG00<0F5QH00@0DE5A04E5A@0l?3`0?3`l0`11@D400`16ATH0oooo0?ooo`0=0?oo
o`003P3oool202l_;`0508:2PP2a/K40/K6a07moO`0Z:RX00P3oool0101XJ6P0LG5a075aL@2LW9`2
09jNWP0507YjNP0g=cL0oooo0?ooo`1KFe/00P1fMWH01@29RHT0VYZJ0:6QX@2QXJ40FUYJ0080oooo
00D0IVIV07alO01lO7`0VIVI0:2PX00209BDU00504M7A`3MgMd0gMgM09VIV@2^[Zh00P2MWId01@2P
X:00SXj>08j>SP1PH600oooo0080IfMW00@0IVIV0:j^[P2^[Zh0[Jf]0P2:RXX01@14A4@0oooo08n?
S`2?Shl0KVi^0080Shn?00D0YJFU09bLW00b<S80<S8b0?ooo`0204a<C00507emO@2JVYX0VYZJ09jN
WP2ZZZX00P2?Shl01@3oool0<C4a034a<@2BTY80VYZJ0080XJ6Q00@0BDU90>o_k`3_knl0a<C40P1V
IVH01@2HV9P0WIfM07]kN`1kNg/0@d=30080oooo00<0GEeM07UiN@2JVYX00P2JVYX2092@T00503`l
?03oool0@4100410@02NWYh00P2ATI401@1`L700SHf=08f=S@3oool0DE5A0080W9bL00D0WIfM08j>
SP2>SXh0G5aL0?ooo`0205ADE00408R8R02LW9`0W9bL09FEU@80UiNG00D0G5aL0?ooo`0V9RH09RHV
09FEU@0209BDU00509fMW@0f=SH0oooo0?ooo`3<c<`00P1LG5`01@2@T900WinO09^KV`2KVi/0I6AT
0080oooo00<0WIfM06m_K`1_Kfl00P2?Shl209BDU00501/K6`3oool0oooo04A4A023Ph<00P2=SHd0
102KVi/0T92@092@T00P82020?ooo`0503hn?P2;Rh/0VYZJ09ZJVP2<S8`00P2HV9P00`0d=3@0oooo
0?ooo`080?ooo`0405]KF`1LG5`0G5aL05]KF`80GEeM00<0GUiN05mOG`1PH6000P1PH60205iNGP<0
FEUI0P1GEeL205UIF@<0G5aL00D0Fe]K05iNGP1NGUh0GUiN05aLG00205MGE`0505=CD`1>CTh0CTi>
04U9B@1:BTX00P1BDU801@1FEUH0EEEE05EEE@1CDe<0D51@0080AdM700<0ADE504Q8B018B4P00P1<
C4`204i>CP04051@D01?Cdl0Cdm?05ADE0<0EeMG00@0F5QH05MGE`1GEeL0DU9B0P1CDe<705EEE@05
05QHF01MGEd0GEeM05eMG@1OGel00P1NGUh00`1KFe/0EUIF05IFEP0205QHF0<0EeMG0`1JFUX205UI
F@0305MGE`1EEED0E5AD0080E5AD0P1GEeL01@1LG5`0GemO05iNGP1NGUh0F5QH0080EUIF0P1DE5@3
05IFEP80FEUI00D0G5aL05eMG@1MGEd0H61P06EUI@0205iNGP0505YJFP1HF5P0F5QH05ADE01CDe<0
0`1HF5P305aLG080Fe]K00D0FUYJ05]KF`1HF5P0F5QH05MGE`0205ADE005059BDP1CDe<0D51@051@
D01?Cdl00P1DE5@01@1EEED0De=C051@D01@D500CTi>0080BTY:00D0Bd];04Y:BP1:BTX0CDe=04m?
C`0204i>CP0504Y:BP18B4P0B4Q804U9B@17AdL00P18B4P0101<C4`0AdM704M7A`18B4P204U9B@05
04];B`19BDT0DE5A055AD@1EEED00P1FEUH00`1HF5P0oooo0?ooo`0=0?ooo`003P3oool204m?C`05
06i^KP3Ph>00h>3P07=cL`18B4P00P3oool0101_Kfl0Ph>308>3P`2JVYX209fMW@0507moO`1@D500
oooo0?ooo`1XJ6P00P28R8P01@1iNGT0/K6a0:b/[02/[:`0EeMG0080oooo00D0MGEe08V9R@29RHT0
TY:B09jNWP0209VIV@05051@D03?cll0clo?09bLW02YZJT00P28R8P01@2l_;`0V9RH09RHV01WIfL0
i>CT0080M7Ad00@0MWIf0:RXZ02XZ:P0Zj^[0P2?Shl01@1IFET0oOgm08b<S02<S8`0Ng]k0080Ph>3
00D0/;2`0;:b/P0k>c/0>c/k0?ooo`0206ATI00508J6QP2@T900T92@09jNWP2XZ:P00P2BTY801@3Z
j^X0DE5A055AD@2@T900QhN70080bLW900@0C4a<0=gMg@3MgMd0Zj^[0P1fMWH01@2IVIT0XJ6Q08:2
PP22PX80GEeM0080oooo00D0IFEU08V9R@2GUiL0UiNG07UiN@020;Bd]00506i^KP3oool0HV9R069R
HP2KVi/00P2ATI401@1oOgl0P8200820P03gmoL0GemO0080WIfM00D0T92@0;jn_P2n_[h0CDe=0?oo
o`02069RHP0409VIV@2BTY80TY:B09bLW080UiNG00@0Kfm_0?ooo`0k>c/0>c/k0`2ATI401@2UYJD0
IFEU0<g=c@3=cLd0`/;20080M7Ad00D0S8b<09bLW02ATI40TI6A08>3P`020?Cdm0<0P82000D0S8b<
08>3P`2h^;P0^;Rh02DU9@020?ooo`0504U9B@26QXH0SXj>08j>SP2SXj<00P2IVIT0100f=SH0oooo
0?ooo`14A4@309JFUP0409FEU@2a/K40/K6a038b<PX0oooo00@0?Shn03`l?00l?3`0?Cdm0P15ADD0
1@14A4@0AdM704U9B@19BDT0B4Q80080ADE500D0C4a<059BDP1BDU80DU9B04m?C`0204Y:BP050492
@P0j>SX0>SXj03dm?@15ADD00P16ATH01017AdL0BDU904U9B@17AdL20451@@0504A4A01:BTX0D51@
051@D01KFe/00P1[Jf/01@1mOGd0Q8B408^;R`2;Rh/0R8R80080NWYj00D0J6QX061PH01FEUH0EUIF
04m?C`0204e=C@05051@D01>CTh0CTi>04a<C019BDT00P18B4P01@13@d<0@4100410@011@D40B4Q8
0080Bd];0`19BDT01@14A4@0@D510451@@14A4@0BTY:0080CDe=00D0DE5A04i>CP1>CTh0BDU904];
B`0204Y:BP0304U9B@18B4P0B4Q800<0BDU900<0BTY:055AD@1EEED0101EEED01@1FEUH0De=C05AD
E01DE5@0EeMG0080EEEE00D0E5AD05EEE@1DE5@0E5AD05=CD`0205IFEP0505YJFP1LG5`0G5aL05aL
G01MGEd00P1QHF4305mOG`05061PH01QHF40GemO05mOG`1TI6@00P1RHV80101UIFD0I6AT06ATI01S
Hf<305mOG`<0GEeM00D0G5aL05eMG@1QHF40HF5Q06=SH`0206EUI@0406QXJ01YJFT0IVIV06IVIP<0
IFEU00<0Hf=S061PH01PH6000P1PH60305eMG@80GUiN00<0GemO061PH01SHf<00P1SHf<306EUI@80
Hf=S00D0HV9R06=SH`1KFe/0Fe]K05ADE00204i>CP0304M7A`3oool0oooo00d0oooo000>0?ooo`80
Cdm?00D0KVi^0>3Ph03Ph>00Lg=c04Q8B0020?ooo`0406m_K`23Ph<0Ph>309ZJVP80WIfM00D0Ogmo
051@D03oool0oooo06QXJ00208R8R00507UiN@2a/K40[:b/0:b/[01GEeL00P3oool01@1eMGD0RHV9
08V9R@2BTY80WYjN0080VIVI00D0D51@0<o?c`3?cll0W9bL0:VYZ@0208R8R0050;bl_02HV9P0V9RH
06MWI`3Ti>@00P1dM7@0101fMWH0Z:RX0:RXZ02[Zj/208n?S`0505UIF@3moOd0S8b<08b<S01kNg/0
0P23Ph<01@2`/;00/[:b03/k>`0k>c/0oooo0080I6AT00D0QXJ6092@T02@T900WYjN0:RXZ00209:B
TP050>[ZjP1ADE40DE5A092@T027QhL00P39bLT0101<C4`0gMgM0=gMg@2[Zj/207IfMP0509VIV@2Q
XJ40PX:208:2PP1MGEd00P3oool01@1UIFD0RHV909NGU`2GUiL0NGUi0080];Bd00D0KVi^0?ooo`1R
HV80HV9R09^KV`02096AT@0507moO`20P800P8200?Ogm`1OGel00P2MWId01@2@T900_[jn0;jn_P1=
CDd0oooo0080HV9R00@0VIVI09:BTP2BTY80W9bL0P2GUiL0101_Kfl0oooo03/k>`0k>c/3096AT@05
0:FUY@1UIFD0cLg=0<g=c@32`/800P1dM7@01@2<S8`0W9bL096AT@2ATI40Ph>30080m?Cd0`20P800
1@2<S8`0Ph>30;Rh^02h^;P09BDU0080oooo00D0BDU908J6QP2>SXh0SXj>0:>SX`0209VIV@0403Hf
=P3oool0oooo04A4A0<0UYJF00@0UIFE0;6a/@2a/K40<S8b2P3oool0100n?Sh0?3`l03`l?00m?Cd2
04E5A@0504A4A017AdL0BDU904U9B@18B4P00P15ADD01@1<C4`0DU9B059BDP1BDU80Cdm?0080BTY:
00D0@T9203Xj>P0j>SX0?Cdm04E5A@0204I6AP0404M7A`19BDT0BDU904M7A`80@D5100D0A4A404Y:
BP1@D500D51@05]KF`0206][J`0507emO@24Q8@0Rh^;08^;R`28R8P00P1jNWX01@1XJ6P0H61P05IF
EP1FEUH0Cdm?0080CDe=00D0D51@04i>CP1>CTh0C4a<04U9B@0204Q8B00504=3@`10@400@4100451
@@18B4P00P1;Bd/304U9B@0504A4A011@D40@D5104A4A01:BTX00P1=CDd01@1ADE40CTi>04i>CP19
BDT0Bd];0080BTY:00<0BDU904Q8B018B4P00`19BDT00`1:BTX0DE5A05EEE@0405EEE@0505IFEP1C
De<0E5AD05ADE01GEeL00P1EEED01@1DE5@0EEEE05ADE01DE5@0De=C0080EUIF00D0FUYJ05aLG01L
G5`0G5aL05eMG@02065QH@<0GemO00D0H61P065QH@1OGel0GemO06ATI002069RHP0406EUI@1TI6@0
I6AT06=SH`<0GemO0`1MGEd01@1LG5`0GEeM065QH@1QHF40Hf=S0080IFEU00@0J6QX06UYJ@1VIVH0
IVIV0`1UIFD00`1SHf<0H61P061PH002061PH0<0GEeM0P1NGUh00`1OGel0H61P06=SH`0206=SH`<0
IFEU0P1SHf<01@1RHV80Hf=S05]KF`1KFe/0E5AD0080CTi>00<0AdM70?ooo`3oool03@3oool000d0
oooo00@0nOWi06i^KP1^KVh0DE5A0P3oool01@1SHf<0I6AT0>_[j`3[jn/0OGem0080U9BD00D0UiNG
09^KV`2KVi/0Q8B4071`L0020?Gem@0507alO02BTY80TY:B06a/K03:b/X00P2c/k<0101NGUh0bl_;
0<_;b`1oOgl20::RXP0508R8R02SXj<0UiNG09NGU`1SHf<00P33`l<01@2HV9P0Xj>S07=cL`1cLg<0
eMGE0080XJ6Q00D0KFe]0<71`@1nOWh0OWin08:2PP020:NWY`050:JVYP2CTi<0Ti>C07AdM03?cll0
0P2@T9001@29RHT0Ogmo07moO`2f][H0^k^k0080Bd];00@0iNGU07IfMP1fMWH0SXj>0P2BTY801@2I
VIT0ZJVY08Z:RP2:RXX0eMGE0080JFUY00D0T92@06e]K@3jn_X0n_[j04m?C`020;no_`050:2PX024
Q8@0Q8B409FEU@2TY:@00P27QhL01@1mOGd0l?3`0?3`l01`L700U9BD0080T92@00D0GUiN0>7Qh@3Q
hN40Q8B40<_;b`0207QhN00409ZJVP2<S8`0S8b<08R8R080SHf=00D0eMGE06m_K`2GUiL0UiNG08F5
Q@020>k^kP050492@P3Jf]X0Lg=c07=cL`2LW9`00P2ATI401@2MWId0UYJF09JFUP1hN7P0oooo0080
DU9B00D0T92@08R8R028R8P0YZJV09:BTP020:NWY`050;Zj^P1oOgl0Ogmo096AT@2JVYX00P2:RXX0
102FUYH0f=SH0=SHf020P80208N7Q`0509>CT`1_Kfl0fm_K0=_Kf`0e=CD00P3oool01@1JFUX0TI6A
09>CT`2CTi<0WinO0080UiNG00D0E5AD0?ooo`3oool0H61P09NGU`0208B4Q0040:>SX`38b<P0b<S8
03Xj>PX0oooo00@0OGem07YjNP1jNWX0Lg=c0P1aLG401@1fMWH0NGUi07UiN@1iNGT0NWYj0080MgMg
00<0KFe]075aL@1aLG400P1aLG4207AdM00507UiN@1jNWX0NWYj07YjNP1iNGT00P1kNg/0101iNGT0
Lg=c07=cL`1/K6`206MWI`0505iNGP1MGEd0GemO05mOG`1TI6@00P1SHf<00`1RHV80GemO05eMG@02
05eMG@80Hf=S00@0KVi^07EeM@1jNWX0NWYj0`1mOGd01@1iNGT0M7Ad07AdM01`L700Kfm_0080KFe]
00D0J6QX06EUI@1UIFD0JFUY05aLG00205EEE@0405YJFP1LG5`0G5aL061PH080J6QX00D0L71`06YZ
JP1XJ6P0J6QX065QH@0206=SH`0505iNGP1SHf<0Hf=S06=SH`1RHV800P1PH6001@1LG5`0DU9B059B
DP1?Cdl0DU9B0080Cdm?00D0DU9B05ADE01DE5@0DE5A04A4A00303hn?P80?Cdm00D0?3`l03Xj>P0h
>3P0>3Ph030`<00203@d=0<0;bl_00D0<C4a030`<00[:b/0:b/[03De=@0203`l?00503lo?`14A4@0
ADE504E5A@11@D400P13@d<01@19BDT0BTY:04Y:BP1;Bd/0B4Q80080ATI600D0@41004E5A@15ADD0
CDe=04i>CP0204m?C`05059BDP1>CTh0CTi>04a<C01@D5000P1?Cdl0101:BTX0A4A404A4A00n?Sh2
03Hf=P0303De=@11@D40ADE50080ADE50P16ATH01@15ADD0>3Ph03De=@0e=CD0?3`l0080?Cdm00D0
@D5104A4A014A4@0AdM70410@00204e=C@0405mOG`1ZJVX0JVYZ07EeM@l0oooo000=0?ooo`040<O7
a`23Ph<0Ph>303Xj>P80oooo00D0EEEE07]kN`2_[jl0[jn_092@T00209fMW@0309NGU`2LW9`0W9bL
0080R8R80P2h^;P01@2BTY80VYZJ09ZJVP1PH600h^;R0080^;Rh00@0HF5Q09jNWP2NWYh0RXZ:0P2h
^;P01@1oOgl0YJFU09ZJVP2JVYX0N7Qh0080/[:b00D0WIfM09JFUP1WIfL0IfMW0=GEe@020;Zj^P05
06ATI02VYZH0SHf=08f=S@2ATI400P2NWYh01@2PX:00VYZJ09ZJVP2:RXX0Zj^[0080TY:B00D0UIFE
071`L01`L700`<300<o?c`0205IFEP040;bl_020P800P82009BDU080VYZJ00D0UIFE0:RXZ02:RXX0
RXZ:0;Bd]00208N7Q`0508j>SP1BDU80oooo0?ooo`1DE5@00P2QXJ401@2HV9P0TY:B09:BTP2CTi<0
YZJV0080Rh^;00D0W9bL0;Ng]`2g]kL0PH6109^KV`0208F5Q@0504];B`3oool0oooo09>CT`2@T900
0P2?Shl0102LW9`0R8R808R8R02@T90209^KV`050;Bd]01lO7`0U9BD09BDU01kNg/00P3oool01@0`
<300_[jn07]kN`1kNg/0Y:BT0080SXj>00D0X:2P08b<S02<S8`0RXZ:0>?Sh`0206YZJP0508j>SP1n
OWh0OWin0:ZZZP2j^[X00P24Q8@01@2_[jl0S8b<08b<S02?Shl0VYZJ0080RHV900@0YJFU0;Rh^02h
^;P0QHF50P2@T9001@2GUiL0Fe]K0?ooo`3oool0ATI60080hn?S00D0L71`09bLW02MWId0WIfM09RH
V00209JFUP05071`L03QhN40hN7Q07UiN@2HV9P00P1eMGD0102c/k<0dm?C0=?Cd`17AdL:0?ooo`04
07EeM@1lO7`0O7al08J6QP80Ogmo00D0NGUi07YjNP1hN7P0N7Qh07UiN@0208>3P`0508b<S024Q8@0
Q8B408B4Q026QXH00P28R8P01@27QhL0SXj>08j>SP2<S8`0Q8B40080Ogmo00@0PX:208R8R028R8P0
TY:B0P2PX:001@2YZJT0YJFU09fMW@2MWId0Shn?0080QhN70P1nOWh307moO`80OWin00D0P8200861
P@21PH40PH6108J6QP0208V9R@0508F5Q@27QhL0QhN708f=S@2@T9000P2ATI401@2KVi/0Y:BT0:BT
Y02PX:00ZJVY0080/;2`00@0[jn_0:RXZ02XZ:P0YJFU0P2JVYX0102?Shl0TY:B09>CT`2CTi<309VI
V@050::RXP2LW9`0Vi^K09^KV`2OWil00P2YZJT01@2][Jd0^;Rh0;Rh^02o_kl0^;Rh0080];Bd00D0
/;2`0:b/[02/[:`0[:b/0:j^[P030:ZZZP80/;2`00D0];Bd0<71`@3?cll0clo?0=WIf@020<o?c`05
0<[:bP34a<@0a<C40;Zj^P2ZZZX00P2[Zj/01@2UYJD0WinO09nOW`2JVYX0WYjN0080VYZJ0`2HV9P0
1@2EUID0Ti>C09>CT`2ATI40TY:B0080S8b<1@2:RXX208n?S`0509FEU@2GUiL0UiNG096AT@2@T900
0P2ATI40102@T900SXj>08j>SP2@T90208^;R`0308N7Q`24Q8@0Q8B40080Q8B40P25QHD00`21PH40
O7al07YjNP0207YjNP80N7Qh00D0MgMg07EeM@1eMGD0KFe]06EUI@0206IVIP04069RHP1VIVH0IVIV
06i^KPl0oooo000=0?ooo`040<O7a`23Ph<0Ph>303Xj>P80oooo00D0EEEE07]kN`2_[jl0[jn_092@
T00209fMW@0309NGU`2LW9`0W9bL0080R8R80P2h^;P01@2BTY80VYZJ09ZJVP1PH600h^;R0080^;Rh
00@0HF5Q09jNWP2NWYh0RXZ:0P2h^;P01@1oOgl0YJFU09ZJVP2JVYX0N7Qh0080/[:b00D0WIfM09JF
UP1WIfL0IfMW0=GEe@020;Zj^P0506ATI02VYZH0SHf=08f=S@2ATI400P2NWYh01@2PX:00VYZJ09ZJ
VP2:RXX0Zj^[0080TY:B00D0UIFE071`L01`L700`<300<o?c`0205IFEP040;bl_020P800P82009BD
U080VYZJ00D0UIFE0:RXZ02:RXX0RXZ:0;Bd]00208N7Q`0508j>SP1BDU80oooo0?ooo`1DE5@00P2Q
XJ401@2HV9P0TY:B09:BTP2CTi<0YZJV0080Rh^;00D0W9bL0;Ng]`2g]kL0PH6109^KV`0208F5Q@05
04];B`3oool0oooo09>CT`2@T9000P2?Shl0102LW9`0R8R808R8R02@T90209^KV`050;Bd]01lO7`0
U9BD09BDU01kNg/00P3oool01@0`<300_[jn07]kN`1kNg/0Y:BT0080SXj>00D0X:2P08b<S02<S8`0
RXZ:0>?Sh`0206YZJP0508j>SP1nOWh0OWin0:ZZZP2j^[X00P24Q8@01@2_[jl0S8b<08b<S02?Shl0
VYZJ0080RHV900@0YJFU0;Rh^02h^;P0QHF50P2@T9001@2GUiL0Fe]K0?ooo`3oool0ATI60080hn?S
00D0L71`09bLW02MWId0WIfM09RHV00209JFUP05071`L03QhN40hN7Q07UiN@2HV9P00P1eMGD0102c
/k<0dm?C0=?Cd`17AdL:0?ooo`0407EeM@1lO7`0O7al08J6QP80Ogmo00D0NGUi07YjNP1hN7P0N7Qh
07UiN@0208>3P`0508b<S024Q8@0Q8B408B4Q026QXH00P28R8P01@27QhL0SXj>08j>SP2<S8`0Q8B4
0080Ogmo00@0PX:208R8R028R8P0TY:B0P2PX:001@2YZJT0YJFU09fMW@2MWId0Shn?0080QhN70P1n
OWh307moO`80OWin00D0P8200861P@21PH40PH6108J6QP0208V9R@0508F5Q@27QhL0QhN708f=S@2@
T9000P2ATI401@2KVi/0Y:BT0:BTY02PX:00ZJVY0080/;2`00@0[jn_0:RXZ02XZ:P0YJFU0P2JVYX0
102?Shl0TY:B09>CT`2CTi<309VIV@050::RXP2LW9`0Vi^K09^KV`2OWil00P2YZJT01@2][Jd0^;Rh
0;Rh^02o_kl0^;Rh0080];Bd00D0/;2`0:b/[02/[:`0[:b/0:j^[P030:ZZZP80/;2`00D0];Bd0<71
`@3?cll0clo?0=WIf@020<o?c`050<[:bP34a<@0a<C40;Zj^P2ZZZX00P2[Zj/01@2UYJD0WinO09nO
W`2JVYX0WYjN0080VYZJ0`2HV9P01@2EUID0Ti>C09>CT`2ATI40TY:B0080S8b<1@2:RXX208n?S`05
09FEU@2GUiL0UiNG096AT@2@T9000P2ATI40102@T900SXj>08j>SP2@T90208^;R`0308N7Q`24Q8@0
Q8B40080Q8B40P25QHD00`21PH40O7al07YjNP0207YjNP80N7Qh00D0MgMg07EeM@1eMGD0KFe]06EU
I@0206IVIP04069RHP1VIVH0IVIV06i^KPl0oooo000=0?ooo`0409^KV`2FUYH0UYJF02DU9@80oooo
00D0ADE508R8R02FUYH0UYJF08^;R`020:j^[P0509BDU02KVi/0Vi^K08f=S@2HV9P00P2DU9@01@2O
Wil0Vi^K09^KV`1GEeL0moOg0080][Jf00@0HF5Q08j>SP2>SXh0QXJ60P36a/H01@1jNWX0ZJVY09VI
V@2IVIT0Rh^;0080XJ6Q00D0Xj>S08n?S`1JFUX0FUYJ0>7Qh@020<C4a005065QH@2HV9P0U9BD09BD
U02HV9P00P2CTi<01@2PX:00WinO09nOW`2CTi<0Vi^K0080TI6A00D0WIfM05eMG@1MGEd0clo?0>CT
i00205QHF00409:BTP2FUYH0UYJF09fMW@80UIFE1@2IVIT209jNWP0508n?S`0k>c/0oooo0?ooo`1G
EeL00P2?Shl01@2FUYH0UiNG09NGU`2@T900Z:RX0080UIFE00D0[:b/08^;R`2;Rh/0TY:B09^KV`02
08F5Q@05034a<@3oool0oooo0:RXZ01NGUh00P2QXJ40102BTY80T92@092@T02EUID20:>SX`05096A
T@2@T900UIFE09FEU@1`L7000P3oool01@0Y:BT0Vi^K08R8R028R8P0Zj^[0080Rh^;00D0YJFU08>3
P`23Ph<0Vi^K0<;2`P020820P00508f=S@1eMGD0MGEe0:b/[03Ti>@00P1SHf<01@2OWil0Vi^K09^K
V`2BTY80UiNG0080Rh^;00@0[:b/09jNWP2NWYh0Rh^;0P2GUiL01@2OWil0@T920?ooo`3oool0Fe]K
0080UiNG00D0PX:20:RXZ02^[Zh0[Zj^08n?S`0209JFUP0508b<S02WYjL0YjNW09>CT`2IVIT00P1V
IVH01030`<00k^k^0>k^kP15ADD:0?ooo`0404M7A`16ATH0ATI604E5A@80@d=300D0@D5103/k>`0g
=cL0=cLg03Hf=P0203@d=005034a<@0`<300<30`030`<00c<c<00P0d=3@01@0h>3P0>SXj03Xj>P0j
>SX0>CTi0080>SXj00@0=CDe034a<@0a<C40;Bd]0P0Y:BT0100V9RH09BDU02DU9@0U9BD302TY:@05
02h^;P0a<C40<c<c03<c<`0e=CD00P0h>3P00`0f=SH0<c<c03<c<`0203<c<`D0<S8b00D0<C4a02l_
;`0d=3@0=3@d03Xj>P0203Hf=P05038b<P0_;bl09bLW02LW9`0N7Qh00P0P82001@0S8b<09bLW02LW
9`0X:2P0:RXZ0080;2`/00D0;Bd]030`<00`<300;bl_02h^;P0202`/;00402XZ:P0R8R808R8R028R
8P808B4Q00D07alO01hN7P0Q8B408B4Q02@T900202DU9@0502@T900_;bl0?3`l03`l?00i>CT00P0h
>3P01@0i>CT0<30`01lO7`0O7al07QhN0080820P00D09BDU02`/;00/;2`0=3@d04A4A00204Q8B005
04I6AP17AdL0AdM704m?C`1;Bd/00P1ADE40101HF5P0EUIF05IFEP19BDT204Q8B00504M7A`1;Bd/0
F5QH05QHF01WIfL00P1UIFD01@1NGUh0Fe]K055AD@1ADE40ATI60080AdM700D0DE5A04i>CP1>CTh0
CTi>05=CD`0305QHF080I6AT00<0K6a/06=SH`1RHV80101RHV801@1^KVh0QhN7092@T02@T900Rh^;
0080S8b<00D0R8R808J6QP26QXH0RHV909JFUP0208N7Q`0407AdM01QHF40HF5Q055AD@l0oooo000=
0?ooo`0409RHV02KVi/0Vi^K02XZ:P80oooo00D0ADE508Z:RP2FUYH0UYJF08j>SP020:ZZZP05096A
T@2XZ:P0Z:RX096AT@2<S8`00P2FUYH01@2NWYh0VIVI09VIV@1QHF40l_;b0080[Zj^00@0K6a/08V9
R@29RHT0QXJ60P33`l<01@1oOgl0YJFU09ZJVP2JVYX0RXZ:0080YJFU00D0Xj>S08n?S`1LG5`0G5aL
0=gMg@020<71`@0506=SH`2LW9`0U9BD09BDU02CTi<00P2@T9001@2SXj<0YjNW0:NWY`2<S8`0W9bL
0080T92@00D0W9bL06=SH`1SHf<0bl_;0>WYj@02051@D00409JFUP2>SXh0SXj>0:JVYP80TI6A00D0
VIVI09nOW`2CTi<0Ti>C0:2PX00309FEU@0403Ti>@3oool0oooo04e=C@80SXj>00D0VYZJ09^KV`2K
Vi/0S8b<0:FUY@0209FEU@050:ZZZP25QHD0QHF509^KV`2HV9P00P22PX801@0`<300oooo0?ooo`2Z
ZZX0E5AD0080W9bL00@0UiNG08j>SP2>SXh0UiNG0P2KVi/01@2IVIT0U9BD08f=S@2=SHd0IfMW0080
oooo00D09bLW09:BTP2;Rh/0Rh^;0:j^[P0208R8R0050:BTY023Ph<0Ph>30:6QX@2e]KD00P2<S8`0
1@2:RXX0KFe]06e]K@2^[Zh0nOWi0080EEEE00D0U9BD09nOW`2OWil0UiNG09>CT`0208j>SP040:^[
Z`2FUYH0UYJF08b<S080UiNG00D0YJFU03Ph>03oool0oooo05eMG@0207IfMP0508f=S@2^[Zh0]kNg
0;Ng]`2<S8`00`2FUYH208b<S0050::RXP2FUYH0FUYJ05YJFP3<c<`00P3/k>`00`17AdL0oooo0?oo
o`080?ooo`0405UIF@1KFe/0Fe]K05aLG080GEeM00D0H61P065QH@1QHF40HF5Q069RHP0306=SH`80
HV9R00@0HF5Q05mOG`1NGUh0GUiN0`1MGEd01@1OGel0H61P065QH@1QHF40I6AT00<0IFEU0P1VIVH0
1@1UIFD0Hf=S06=SH`1SHf<0I6AT00<0Hf=S00<0GemO05eMG@1MGEd00`1LG5`00`1JFUX0Fe]K05]K
F`0205]KF`80G5aL0`1NGUh01@1OGel0HF5Q05aLG01LG5`0E5AD0080De=C00D0E5AD05=CD`1IFET0
FEUI065QH@02061PH00505mOG`1MGEd0GEeM05eMG@1KFe/00`1LG5`2061PH0D0HF5Q0`1NGUh2061P
H005065QH@1PH600GUiN05iNGP1LG5`00`1KFe/0101MGEd0FUYJ05YJFP1KFe/205YJFP0505MGE`1E
EED0FUYJ05YJFP1IFET00P1JFUX01@1KFe/0F5QH05QHF01GEeL0F5QH0080EUIF00D0EEEE05QHF01H
F5P0DU9B04m?C`0204e=C@<0BTY:00D0DE5A05ADE01DE5@0EUIF05EEE@02059BDP0504m?C`1<C4`0
C4a<04];B`1=CDd00P1@D5001@1?Cdl0CTi>04i>CP19BDT0B4Q800<0AdM70P19BDT304a<C00504Y:
BP1<C4`0Bd];04];B`1:BTX00P18B4P00`11@D40>3Ph03<c<`0403<c<`0503Hf=P0h>3P0>3Ph03Xj
>P0m?Cd00P12@T80101:BTX0De=C05=CD`1FEUH?0?ooo`003@3oool0102PX:00Z:RX0:RXZ00k>c/2
0?ooo`0505ADE02;Rh/0UYJF09JFUP2BTY800P2RXZ801@1nOWh0i>CT0>CTi01`L700RXZ:0080UiNG
00D0WinO09BDU02DU9@0LG5a0=gMg@020:RXZ00407]kN`23Ph<0Ph>308b<S080_Kfm00D0LG5a0<K6
aP2<S8`0S8b<08Z:RP020:FUY@050:2PX02?Shl0KFe]06e]K@36a/H00P2m_Kd01@1[Jf/0WYjN09BD
U02DU9@0RHV90080Shn?00D0`l?3092@T02@T900T92@09RHV002092@T00509jNWP1`L700L71`0;jn
_P3GemL00P1TI6@0102FUYH0Shn?08n?S`2?Shl209^KV`050;bl_02;Rh/0T92@092@T02QXJ400P2B
TY801@2GUiL0BTY:0?ooo`3oool0Hf=S0080Ti>C0`2HV9P01@24Q8@0ZJVY0:VYZ@2YZJT0W9bL0080
R8R800D0WYjN09:BTP24Q8@0Q8B4051@D0020?ooo`05096AT@1cLg<0UiNG09NGU`2FUYH00P1lO7`0
1@2_[jl0Y:BT0:BTY02?Shl0UIFE0080SXj>00D0MGEe0?ooo`3oool0?clo09RHV002092@T0040:6Q
X@2?Shl0Shn?09VIV@80NGUi00<0_[jn0:j^[P2;Rh/00P2;Rh/207EeM@050:RXZ03Shn<0HV9R069R
HP2HV9P00P2NWYh01@2EUID0TI6A0:VYZ@2YZJT0Ti>C0080UiNG00D0TI6A09BDU02DU9@0YjNW04U9
B@020?ooo`0506YZJP22PX80PX:208V9R@2c/k<00P2a/K401022PX80WinO09nOW`2<S8`209^KV`05
09bLW02FUYH0GUiN05iNGP37alL00P3Vi^H00`14A4@0oooo0?ooo`080?ooo`0406a/K01ZJVX0JVYZ
06QXJ080IVIV00D0Hf=S05eMG@1MGEd0GEeM05aLG00305]KF`80GUiN101OGel01@1MGEd0Fe]K05]K
F`1IFET0EeMG0080EEEE00@0EUIF05QHF01HF5P0Fe]K0P1NGUh205mOG`80GEeM00@0FEUI05MGE`1G
EeL0E5AD0`1EEED305QHF080G5aL0P1OGel3061PH0<0GemO00D0GUiN05]KF`1JFUX0FUYJ05aLG003
05]KF`0405eMG@1NGUh0GUiN05]KF`80G5aL00@0Fe]K05aLG01LG5`0Fe]K0`1LG5`305eMG@80GUiN
0P1MGEd0101NGUh0GEeM05eMG@1MGEd205iNGP0305mOG`1PH600H61P0080H61P0P1OGel00`1RHV80
I6AT069RHP04069RHP04061PH01MGEd0H61P061PH0<0HV9R0`1NGUh205eMG@80G5aL00D0GUiN05]K
F`1KFe/0FUYJ05MGE`0305IFEP80FUYJ00<0GUiN061PH01PH6000P1QHF42061PH0D0G5aL0P1KFe/0
0`1LG5`0GEeM05eMG@0405iNGP0405eMG@1LG5`0G5aL05]KF`@0G5aL0`1MGEd205]KF`0505QHF01G
EeL0EEEE05EEE@1DE5@00P1EEED01@1FEUH0EeMG05MGE`1JFUX0G5aL0080GemO00@0I6AT06MWI`1W
IfL0JFUY3`3oool000d0oooo00@0X:2P0:RXZ02XZ:P0>c/k0P3oool01@1DE5@0Rh^;09JFUP2FUYH0
TY:B0080XZ:R00D0OWin0>CTi03Ti>@0L71`08Z:RP0209NGU`0509nOW`2DU9@0U9BD075aL@3MgMd0
0P2XZ:P0101kNg/0Ph>308>3P`2<S8`20;fm_@05075aL@36a/H0S8b<08b<S02:RXX00P2UYJD01@2P
X:00Shn?06e]K@1]KFd0a/K60080_Kfm00D0Jf][09jNWP2DU9@0U9BD08V9R@0208n?S`050<?3``2@
T900T92@092@T02HV9P00P2@T9001@2NWYh0L71`071`L02n_[h0emOG0080I6AT00@0UYJF08n?S`2?
Shl0Shn?0P2KVi/01@2l_;`0Rh^;092@T02@T900XJ6Q0080TY:B00D0UiNG04Y:BP3oool0oooo06=S
H`0209>CT`<0V9RH00D0Q8B40:VYZ@2YZJT0ZJVY09bLW00208R8R00509jNWP2BTY80Q8B408B4Q01@
D5000P3oool01@2ATI40Lg=c09NGU`2GUiL0UYJF0080O7al00D0[jn_0:BTY02TY:@0Shn?09FEU@02
08j>SP0507EeM@3oool0oooo03lo?`2HV9P00P2@T900102QXJ40Shn?08n?S`2IVIT207UiN@030;jn
_P2^[Zh0Rh^;0080Rh^;0P1eMGD01@2XZ:P0hn?S069RHP1RHV80V9RH0080WYjN00D0UIFE096AT@2Y
ZJT0ZJVY09>CT`0209NGU`05096AT@2DU9@0U9BD0:NWY`19BDT00P3oool01@1ZJVX0PX:208:2PP29
RHT0/k>c0080/K6a00@0PX:209nOW`2OWil0S8b<0P2KVi/01@2LW9`0UYJF05iNGP1NGUh0alO70080
i^KV00<0A4A40?ooo`3oool0203oool0101/K6`0JVYZ06YZJP1XJ6P206IVIP0506=SH`1MGEd0GEeM
05eMG@1LG5`00`1KFe/205iNGP@0GemO00D0GEeM05]KF`1KFe/0FEUI05MGE`0205EEE@0405IFEP1H
F5P0F5QH05]KF`80GUiN0P1OGel205eMG@0405UIF@1GEeL0EeMG05ADE0<0EEEE0`1HF5P205aLG080
GemO0`1PH60305mOG`0505iNGP1KFe/0FUYJ05YJFP1LG5`00`1KFe/0101MGEd0GUiN05iNGP1KFe/2
05aLG00405]KF`1LG5`0G5aL05]KF`<0G5aL0`1MGEd205iNGP80GEeM00@0GUiN05eMG@1MGEd0GEeM
0P1NGUh00`1OGel0H61P061PH002061PH080GemO00<0HV9R06ATI01RHV80101RHV80101PH600GEeM
061PH01PH603069RHP<0GUiN0P1MGEd205aLG00505iNGP1KFe/0Fe]K05YJFP1GEeL00`1FEUH205YJ
FP0305iNGP1PH600H61P0080HF5Q0P1PH60505aLG080Fe]K00<0G5aL05eMG@1MGEd0101NGUh0101M
GEd0G5aL05aLG01KFe/405aLG0<0GEeM0P1KFe/01@1HF5P0EeMG05EEE@1EEED0E5AD0080EEEE00D0
EUIF05MGE`1GEeL0FUYJ05aLG00205mOG`0406ATI01WIfL0IfMW06UYJ@l0oooo000=0?ooo`0409nO
W`2^[Zh0[Zj^05]KF`80oooo00<0Jf][08J6QP2LW9`00P2LW9`209FEU@0506=SH`3oool0oooo05=C
D`23Ph<00P2JVYX01@2PX:00U9BD09BDU01nOWh0cLg=0080WinO00@0QXJ607moO`1oOgl0Y:BT0P2U
YJD01@1OGel0l?3`07]kN`1kNg/0S8b<0080YJFU00D0VYZJ092@T020P800P8200;6a/@020;Ng]`04
07IfMP2MWId0Ti>C09>CT`<0RHV900D0fMWI0861P@21PH40TI6A09RHV002096AT@0509jNWP1cLg<0
Lg=c0;Bd]03GemL00P1/K6`0102FUYH0Shn?08n?S`1mOGd20:6QX@050=gMg@1dM7@0TY:B09:BTP2P
X:000P2BTY801@2FUYH0I6AT0?;blP3bl_80NWYj0080UiNG00D0V9RH09JFUP2FUYH0MGEe0;Vi^@02
0;:b/P0508Z:RP2>SXh0SXj>0:2PX02?Shl00P27QhL01@1/K6`0no_k0?_kn`2BTY80Ogmo00<0V9RH
0P1[Jf/01@34a<@0/;2`0;2`/01oOgl0Ti>C0080UiNG00D0PH610?Shn03hn?P0G5aL09NGU`0209JF
UP0409nOW`2?Shl0Shn?09>CT`80GemO00D0l_;b09bLW026QXH0QXJ608V9R@0207emO@050:NWY`3=
cLd0Kfm_06m_K`2TY:@00P2IVIT01@2CTi<0N7Qh0<k>cP3>c/h0Shn?0080S8b<0`2EUID01@2SXj<0
FUYJ0?Cdm03dm?@0RHV90080PX:200D0QXJ60;6a/@2OWil0WinO09:BTP020;6a/@0507emO@2KVi/0
Vi^K09ZJVP2BTY800P1cLg<0102i^KT0clo?0<o?c`1EEED:0?ooo`04028R8P0O7al07alO028R8P80
9BDU00D0:b/[02`/;00^;Rh0;Rh^02d];@0202/[:`0402`/;00Y:BT0:BTY02TY:@<0:RXZ00D0<30`
03@d=00d=3@0=CDe03Ti>@0203/k>`0403De=@0^;Rh0;Rh^02XZ:P808b<S00D07alO01XJ6P0M7Ad0
7AdM024Q8@02028R8P0502TY:@0a<C40<c<c03<c<`0b<S800P0e=CD01@0b<S80;2`/02PX:00X:2P0
9BDU008092@T0`0R8R801@0S8b<09RHV030`<00`<300>3Ph0080>c/k0P0m?Cd2038b<P0402XZ:P0V
9RH09RHV02@T90<08b<S100T92@202LW9`0502/[:`0_;bl0=3@d03@d=00h>3P00`0j>SX203Ph>080
=cLg0P0d=3@01@0c<c<0<C4a034a<@0];Bd0;Rh^0080=3@d00D0=CDe03Lg=`0g=cL0>SXj03Ph>002
03<c<`04030`<00];Bd0;Bd]03<c<`80>3Ph00D0?Shn0492@P14A4@0A4A403lo?`0203/k>`80=cLg
1@0i>CT00`0h>3P0=cLg03Lg=`0203Lg=`80>3Ph00D0>c/k03`l?00l?3`0?Cdm03hn?P0203dm?@04
03`l?00k>c/0>c/k03`l?0<0?Cdm00@0?Shn03lo?`0o?cl0?clo0P14A4@01@16ATH0ADE50492@P12
@T80ADE50080ATI600D0A4A404E5A@18B4P0B4Q804M7A`020451@@0304=3@`14A4@0A4A40080A4A4
0P0o?cl0100f=SH0;Rh^02h^;P0U9BD?0?ooo`003@3oool0102JVYX0];Bd0;Bd]01mOGd20<W9b@80
PX:20P2QXJ40102TY:@0Rh^;08^;R`18B4P20?ooo`0503De=@23Ph<0V9RH09RHV02PX:000P2DU9@0
1@2ATI40^;Rh09NGU`2GUiL0Ti>C0080O7al00D0]KFe09>CT`2CTi<0CTi>0?ooo`0206YZJP0508R8
R02ZZZX0ZZZZ09NGU`2@T9000P2;Rh/01@2YZJT0YZJV0:JVYP23Ph<0WIfM0080U9BD00@0PH6108j>
SP2>SXh0inOW0P1hN7P01@2>SXh0Vi^K096AT@2ATI40Vi^K0080QHF500D0Y:BT0<S8b01mOGd0OGem
09BDU002096AT@0506e]K@2YZJT0ZJVY0?Shn01PH6000P2@T9001@2QXJ40T92@092@T02HV9P0NWYj
0080alO700@0SXj>09VIV@2IVIT0VIVI0P2CTi<01@1YJFT0a<C40<K6aP36a/H0MWIf0080TI6A00D0
XJ6Q08n?S`2=SHd0SHf=08>3P`020<c<c00509NGU`2:RXX0VYZJ09ZJVP2GUiL00P1HF5P01@3Ph>00
]KFe0;Fe]@1`L700U9BD0080Vi^K00D0T92@0<O7a`37alL0N7Qh09FEU@0209nOW`0409^KV`2@T900
T92@09:BTP80ATI600D0oooo08F5Q@1oOgl0Ogmo08b<S00208F5Q@050:FUY@2n_[h0NWYj07YjNP2S
Xj<00P2IVIT01@2FUYH0HF5Q0?7al@3alO40R8R80080QXJ600D0UIFE09RHV02HV9P0X:2P06e]K@02
0<g=c@0509bLW026QXH0QXJ608V9R@2/[:`00P26QXH0102[Zj/0`L710<71`@1_Kfl209bLW00509BD
U02@T900S8b<08b<S02VYZH00P2m_Kd00`1UIFD0oooo0?ooo`080?ooo`040;bl_032`/80`/;20<O7
a`80b<S800D0`/;20<71`@2l_;`0_;bl0;>c/`020;Jf]P050;Fe]@2f][H0][Jf0;Ng]`2o_kl00P30
`<001@2n_[h0_;bl0;bl_02k^k/0];Bd0080[:b/00@0[Jf]0;>c/`2c/k<0/;2`0P2j^[X01@34a<@0
clo?0=CDe03De=@0g=cL0080gmoO00D0g=cL0=CDe03@d=00d=3@0<c<c0020<C4a0050;jn_P2l_;`0
][Jf0;Jf]P2k^k/00P2m_Kd01@31`L40a/K60<K6aP3>c/h0c<c<0080bLW900D0a/K60<;2`P32`/80
_[jn0;bl_0020<G5a@030<;2`P2n_[h0_[jn00<0`L7100D0`<300<G5a@3?cll0clo?0<k>cP020<c<
c0050<;2`P2i^KT0/[:b0;:b/P2/[:`00P2WYjL01@2RXZ80Vi^K09^KV`2IVIT0UYJF0080VYZJ00D0
Xj>S0;2`/02`/;00^;Rh0;fm_@020;bl_0050;Vi^@2g]kL0]kNg0;Jf]P2d];@00P2^[Zh0102][Jd0
[jn_0:n_[`2XZ:P30:6QX@040:BTY02QXJ40XJ6Q0:>SX`80YJFU00D0Z:RX0:>SX`2NWYh0WYjN09RH
V00208f=S@0508B4Q01oOgl0Ogmo07QhN01dM7@00P1jNWX307moO`0507emO@1iNGT0MGEe07EeM@1]
KFd00P1UIFD01@1TI6@0J6QX06UYJ@1YJFT0Jf][0080LG5a00<0Lg=c07EeM@1eMGD00P1bLW8207Mg
M`0507]kN`1lO7`0O7al08>3P`22PX800P1mOGd0101iNGT0M7Ad07AdM01]KFd306a/K00406][J`1j
NWX0NWYj08^;R`80W9bL00<0[Zj^0?ooo`3oool03@3oool000d0oooo00@0VYZJ0;Bd]02d];@0OGem
0P39bLT208:2PP80XJ6Q00@0Y:BT08^;R`2;Rh/0B4Q80P3oool01@0e=CD0Ph>309RHV02HV9P0X:2P
0080U9BD00D0TI6A0;Rh^02GUiL0UiNG09>CT`0207alO0050;Fe]@2CTi<0Ti>C04i>CP3oool00P1Z
JVX01@28R8P0ZZZZ0:ZZZP2GUiL0T92@0080Rh^;00D0ZJVY0:JVYP2VYZH0Ph>309fMW@0209BDU004
0861P@2>SXh0SXj>0>OWi`80N7Qh00D0SXj>09^KV`2ATI40TI6A09^KV`0208F5Q@050:BTY038b<P0
OGem07emO@2DU9@00P2ATI401@1]KFd0ZJVY0:VYZ@3hn?P0H61P0080T92@00D0XJ6Q092@T02@T900
V9RH07YjNP020<O7a`0408j>SP2IVIT0VIVI09VIV@80Ti>C00D0JFUY0<C4a036a/H0a/K607IfMP02
096AT@050:6QX@2?Shl0SHf=08f=S@23Ph<00P3<c<`01@2GUiL0RXZ:09ZJVP2JVYX0UiNG0080F5QH
00D0h>3P0;Fe]@2e]KD0L71`09BDU00209^KV`05092@T037alL0alO707QhN02EUID00P2OWil0102K
Vi/0T92@092@T02BTY8204I6AP050?ooo`25QHD0Ogmo07moO`2<S8`00P25QHD01@2UYJD0_[jn07Yj
NP1jNWX0Xj>S0080VIVI00D0UYJF065QH@3alO40lO7a08R8R00208J6QP0509FEU@2HV9P0V9RH0:2P
X01]KFd00P3=cLd01@2LW9`0QXJ608J6QP29RHT0[:b/0080QXJ600@0Zj^[0<71`@31`L40Kfm_0P2L
W9`01@2DU9@0T92@08b<S02<S8`0YZJV0080_Kfm00<0IFEU0?ooo`3oool0203oool0102l_;`0`/;2
0<;2`P37alL20<S8b0050<;2`P31`L40_;bl0;bl_02c/k<00P2f][H01@2e]KD0][Jf0;Jf]P2g]kL0
_kno0080`<3000D0_[jn0;bl_02l_;`0^k^k0;Bd]0020:b/[0040:f][@2c/k<0/k>c0;2`/080^[Zj
00D0a<C40<o?c`3De=@0e=CD0=cLg0020=oOg`050=cLg03De=@0d=3@0=3@d03<c<`00P34a<@01@2n
_[h0_;bl0;Jf]P2f][H0^k^k0080_Kfm00D0`L710<K6aP36a/H0c/k>0<c<c0020<W9b@050<K6aP32
`/80`/;20;jn_P2l_;`00P35aLD00`32`/80_[jn0;jn_P030<71`@050<30`035aLD0clo?0<o?c`3>
c/h00P3<c<`01@32`/80^KVi0;:b/P2b/[80[:b/0080YjNW00D0XZ:R09^KV`2KVi/0VIVI09JFUP02
09ZJVP050:>SX`2`/;00/;2`0;Rh^02m_Kd00P2l_;`01@2i^KT0]kNg0;Ng]`2f][H0];Bd0080[Zj^
00@0[Jf]0:n_[`2_[jl0Z:RX0`2QXJ40102TY:@0XJ6Q0:6QX@2SXj<20:FUY@050:RXZ02SXj<0WYjN
09jNWP2HV9P00P2=SHd01@24Q8@0Ogmo07moO`1hN7P0M7Ad0080NWYj0`1oOgl01@1mOGd0NGUi07Ee
M@1eMGD0KFe]0080IFEU00D0I6AT06QXJ01YJFT0JFUY06][J`02075aL@0307=cL`1eMGD0MGEe0080
LW9b0P1gMgL01@1kNg/0O7al07alO023Ph<0PX:20080OGem00@0NGUi07AdM01dM7@0KFe]0`1/K6`0
101[Jf/0NWYj07YjNP2;Rh/209bLW0030:j^[P3oool0oooo00d0oooo000=0?ooo`0409fMW@2`/;00
/;2`09VIV@80VYZJ00<0UYJF07inOP2UYJD00P2UYJD208F5Q@0503/k>`3oool0oooo01dM7@27QhL0
0P2FUYH01@2LW9`0TY:B09:BTP2XZ:P0W9bL0080V9RH00@0W9bL07inOP1nOWh0][Jf0P2:RXX01@0m
?Cd0oooo05UIF@1IFET0RXZ:0080[Jf]00D0TI6A08b<S02LW9`0W9bL09jNWP0209bLW00508b<S02K
Vi/0UYJF09JFUP1eMGD00P2EUID01@3bl_80MgMg07MgM`2<S8`0UIFE00D0UiNG00D0RXZ:0;jn_P2>
SXh0SXj>09>CT`02096AT@0506IVIP2WYjL0YjNW0?ooo`1BDU800P2>SXh01@2PX:00TI6A096AT@2I
VIT0S8b<0080Y:BT00@0WinO09^KV`2KVi/0UiNG0P2BTY801@1RHV80aLG50=WIf@3IfMT0JFUY0080
Ti>C00D0XJ6Q08b<S02ATI40TI6A09jNWP020:FUY@0309:BTP2IVIT0V9RH0080V9RH0P16ATH01@3m
oOd0]KFe0;Fe]@1[Jf/0Rh^;0080YJFU00D0V9RH0::RXP2RXZ80SHf=09FEU@020:JVYP0409JFUP2B
TY80TY:B08n?S`80;2`/00@0oooo075aL@1iNGT0NGUi0`2<S8`01@2XZ:P0Zj^[08F5Q@25QHD0XZ:R
0080VYZJ00D0VIVI04Q8B03oool0oooo07inOP0207moO`0509NGU`2HV9P0V9RH09^KV`24Q8@00P2W
YjL01@2ZZZX0Shn?08n?S`2?Shl0YjNW0080IfMW00@0`l?30=;BdP3Bd]80Hf=S0P2JVYX01@2CTi<0
SHf=09nOW`2OWil0W9bL0080Z:RX00<0M7Ad0?ooo`3oool0203oool0100g=cL0<c<c03<c<`0[:b/2
02@T900502HV9P0^;Rh0=SHf03Hf=P12@T800P10@4001@0o?cl0>c/k03/k>`0c<c<09bLW00809BDU
0`0P82001@0Q8B408b<S02LW9`0W9bL0;Rh^0080<30`00D0=SHf03<c<`0c<c<0;Rh^02DU9@0201hN
7P0501DE5@0A4A404A4A00h>3P0@41000P0C4a<01@0G5aL07AdM01dM7@0T92@0;Rh^0080>SXj00@0
>3Ph03Ti>@0i>CT0=cLg0P0`<3001@0U9BD09RHV028R8P0R8R807alO00808R8R00D092@T02DU9@0U
9BD09BDU034a<@0203dm?@0503lo?`11@D40@D5104A4A00l?3`00P0^;Rh01@0[:b/09bLW02LW9`0]
;Bd0<c<c0080=SHf00@0>3Ph03lo?`0o?cl0@D510P19BDT01@1;Bd/0CTi>04e=C@1=CDd0B4Q80080
?3`l00@0=SHf02h^;P0[:b/0:b/[0`0`<3001@0a<C40=SHf03lo?`0o?cl0@4100080@T9200D0BDU9
04i>CP1>CTh0Bd];04A4A00204I6AP0504M7A`18B4P0B4Q804Y:BP1DE5@00P1HF5P0101PH600IVIV
06IVIP1[Jf/2075aL@0507UiN@1mOGd0OGem07emO@1jNWX00P1iNGT01@1hN7P0OGem08N7Q`27QhL0
V9RH0080XJ6Q00D0Y:BT0::RXP2OWil0WinO09RHV00309FEU@80S8b<0P29RHT208F5Q@030820P021
PH40PH610080OGem0P21PH401028R8P0TY:B09:BTP2LW9`209jNWP0509fMW@2JVYX0QHF508F5Q@1b
LW800P1RHV800`1>CTh0oooo0?ooo`0=0?ooo`003@3oool0102QXJ40ZJVY0:VYZ@2JVYX209VIV@05
09FEU@1oOgl0ZJVY0:VYZ@2SXj<00P2;Rh/01@0m?Cd0oooo0?ooo`0L71`0Rh^;0080V9RH00D0UIFE
09VIV@2IVIT0XJ6Q09jNWP0209NGU`0409^KV`1oOgl0Ogmo0;Vi^@80RHV900D0@T920?ooo`1@D500
D51@096AT@020:b/[00508j>SP29RHT0WinO09nOW`2KVi/00P2OWil01@2@T900Ti>C09nOW`2OWil0
L71`0080VYZJ00D0k^k^07=cL`1cLg<0SHf=09VIV@0209ZJVP0509RHV02BTY80TY:B08Z:RP2d];@0
0P2HV9P0102CTi<0U9BD09BDU01MGEd20:f][@040?ooo`0n?Sh0V9RH09RHV0<0UiNG00D0V9RH09:B
TP2EUID0UIFE0:BTY0020:2PX00509VIV@2<S8`0S8b<06=SH`36a/H00P3MgMd01@1ZJVX0VIVI09VI
V@2HV9P0SXj>0080UIFE00D0XJ6Q09FEU@2EUID0UYJF09nOW`0209VIV@0409:BTP0n?Sh0?Shn0?oo
o`80];Bd00D0FUYJ08f=S@2][Jd0[Jf]09nOW`0208Z:RP0509RHV02BTY80Zj^[0:^[Z`2ATI400P2I
VIT01@29RHT08R8R028R8P3oool0IFEU0080M7Ad00D0SHf=08b<S02<S8`0][Jf09RHV00208f=S@05
0:6QX@2LW9`0W9bL09NGU`0k>c/00P3oool00`20P800MgMg07MgM`0309RHV00509VIV@2@T900TY:B
09:BTP2d];@00P2FUYH01@29RHT0YJFU05]KF`1KFe/0bLW90080i>CT00D0F5QH09FEU@2EUID0TY:B
08V9R@020;Jf]P0408n?S`2KVi/0Vi^K07moO`X0oooo00@0EeMG05QHF01HF5P0FEUI0P1KFe/01@1L
G5`0FUYJ05EEE@1EEED0EeMG00<0F5QH0P1MGEd01@1SHf<0I6AT06=SH`1SHf<0IfMW00<0IVIV00@0
JVYZ06m_K`1_Kfl0K6a/0`1YJFT206IVIP03069RHP1TI6@0IFEU0080IFEU0P1WIfL01@1VIVH0IFEU
06MWI`1WIfL0IVIV00<0I6AT00@0GemO05YJFP1JFUX0F5QH0P1GEeL01@1EEED0FEUI05UIF@1KFe/0
G5aL0080GEeM0`1PH602065QH@80H61P00@0Fe]K05UIF@1IFET0EUIF0`1EEED00`1FEUH0F5QH05QH
F00705]KF`0405YJFP1HF5P0F5QH05UIF@80EEEE0P1CDe<205EEE@0505ADE01IFET0FEUI05]KF`1J
FUX00P1IFET0101GEeL0EUIF05IFEP1FEUH305MGE`0405YJFP1HF5P0F5QH05ADE080DE5A00D0Cdm?
04a<C01<C4`0C4a<04e=C@0204i>CP0504e=C@1<C4`0Bd];04];B`19BDT00P1>CTh01@1BDU80De=C
05=CD`1ADE40CTi>0080ADE50`10@40204M7A`80@d=300D0>c/k03Ti>@0i>CT0=3@d034a<@0203<c
<`0403Lg=`0d=3@0=3@d034a<@80=SHf00D0?Cdm03lo?`0o?cl0?clo0410@00203hn?P80>CTi0P0g
=cL0100d=3@0<S8b038b<P0];Bd202XZ:P0502TY:@0Z:RX0<S8b038b<P0k>c/00P13@d<00`1=CDd0
oooo0?ooo`0=0?ooo`003@3oool0102NWYh0UiNG09NGU`2ATI420;bl_00508b<S020P800YZJV0:JV
YP2NWYh00P2BTY801@1BDU80oooo0?ooo`0l?3`0SXj>0080UIFE00D0UiNG09:BTP2BTY80Ti>C0;Fe
]@020:NWY`0408J6QP20P800P8200<;2`P80PX:200D0De=C0?ooo`1NGUh0GUiN09>CT`020:ZZZP05
092@T02;Rh/0TI6A096AT@2SXj<00P2`/;001@25QHD0SHf=0:>SX`2SXj<0OGem0080V9RH00D0d];B
08V9R@29RHT0RHV909VIV@020:2PX00509:BTP27QhL0QhN70:6QX@2d];@00P2ATI40102?Shl0TI6A
096AT@1eMGD20:FUY@030?_kn`1ADE40V9RH0080V9RH0P2NWYh01@2DU9@0P8200:n_[`2_[jl0WYjN
0080UiNG00D0V9RH09>CT`2CTi<0Kfm_0;Zj^P020<g=c@0407=cL`2MWId0WIfM09>CT`<0TY:B00D0
UYJF0;Jf]P2f][H0QHF509RHV00209bLW00409FEU@1?Cdl0Cdm?0?[jnP80[:b/00D0JFUY08j>SP2/
[:`0[:b/096AT@020:RXZ00509BDU029RHT0Z:RX0:RXZ02BTY800P2FUYH01@2@T900;Rh^02h^;P3o
ool0KVi^0080NGUi00D0SHf=08V9R@29RHT0Z:RX0;Fe]@0208Z:RP0509bLW02EUID0UIFE09bLW012
@T800P3oool0102:RXX0N7Qh07QhN02KVi/209NGU`0509VIV@24Q8@0ZJVY0:VYZ@2_[jl00P2@T900
1@29RHT0Z:RX065QH@1QHF40b<S80080e]KF00D0H61P09JFUP2FUYH0TY:B08J6QP020;Vi^@0408J6
QP2^[Zh0[Zj^07alO0X0oooo00<0HV9R061PH01PH6000`1QHF401@1OGel0G5aL05]KF`1KFe/0GEeM
00<0Fe]K0P1OGel01@1TI6@0IVIV06YZJP1ZJVX0JFUY0080IfMW00<0I6AT05mOG`1MGEd00P1MGEd2
061PH004065QH@1RHV80HV9R05iNGP<0GemO00D0G5aL05YJFP1JFUX0Fe]K05QHF00205EEE@0505IF
EP1IFET0FEUI05]KF`1NGUh00P1MGEd0101IFET0EUIF05IFEP1GEeL205EEE@0505MGE`1KFe/0GEeM
05eMG@1JFUX00`1KFe/305YJFP04061PH01QHF40HF5Q065QH@80H61P00<0HF5Q05mOG`1MGEd0101M
GEd0101KFe/0FEUI05IFEP1FEUH305EEE@0505UIF@1NGUh0GUiN05iNGP1OGel00P1NGUh00`1KFe/0
EUIF05IFEP0405IFEP0505MGE`1IFET0FEUI05YJFP1KFe/00P1NGUh4061PH080GemO00<0GUiN05eM
G@1MGEd01@1MGEd0101LG5`0GEeM05eMG@1LG5`205YJFP0505QHF01GEeL0EeMG05QHF01JFUX00P1M
GEd01@1PH600HV9R069RHP1MGEd0G5aL0080Fe]K0`1IFET00`1MGEd0GUiN05eMG@0505eMG@80Fe]K
00D0F5QH05MGE`1GEeL0EeMG05QHF00205YJFP0505mOG`1RHV80HV9R069RHP1SHf<00P1QHF4305mO
G`0405iNGP1MGEd0GemO05mOG`<0GUiN00<0HF5Q0?ooo`3oool03@3oool000d0oooo00@0WYjN09NG
U`2GUiL0TI6A0P2l_;`01@2<S8`0P8200:JVYP2VYZH0WYjN0080TY:B00D0DU9B0?ooo`3oool0?3`l
08j>SP0209FEU@0509NGU`2BTY80TY:B09>CT`2e]KD00P2WYjL01026QXH0P8200820P032`/8208:2
PP0505=CD`3oool0GUiN05iNGP2CTi<00P2ZZZX01@2@T900Rh^;096AT@2ATI40Xj>S0080/;2`00D0
QHF508f=S@2SXj<0Xj>S07emO@0209RHV0050=;BdP29RHT0RHV908V9R@2IVIT00P2PX:001@2BTY80
QhN708N7Q`2QXJ40];Bd0080TI6A00@0Shn?096AT@2ATI40MGEe0P2UYJD00`3kno/0DE5A09RHV002
09RHV080WYjN00D0U9BD0820P02_[jl0[jn_09jNWP0209NGU`0509RHV02CTi<0Ti>C06m_K`2j^[X0
0P3=cLd0101cLg<0WIfM09fMW@2CTi<309:BTP0509JFUP2f][H0][Jf08F5Q@2HV9P00P2LW9`0102E
UID0Cdm?04m?C`3jn_X20:b/[00506UYJ@2>SXh0[:b/0:b/[02ATI400P2XZ:P01@2DU9@0RHV90:RX
Z02XZ:P0TY:B0080UYJF00D0T92@02h^;P0^;Rh0oooo06i^KP0207UiN@0508f=S@29RHT0RHV90:RX
Z02e]KD00P2:RXX01@2LW9`0UIFE09FEU@2LW9`0@T920080oooo00@0RXZ:07QhN01hN7P0Vi^K0P2G
UiL01@2IVIT0Q8B40:VYZ@2YZJT0[jn_0080T92@00D0RHV90:RXZ01QHF40HF5Q0<S8b0020=KFeP05
061PH02FUYH0UYJF09:BTP26QXH00P2i^KT01026QXH0[Zj^0:j^[P1lO7`:0?ooo`03069RHP1PH600
H61P00<0HF5Q00D0GemO05aLG01KFe/0Fe]K05eMG@0305]KF`80GemO00D0I6AT06IVIP1ZJVX0JVYZ
06UYJ@0206MWI`0306ATI01OGel0GEeM0080GEeM0P1PH600101QHF40HV9R069RHP1NGUh305mOG`05
05aLG01JFUX0FUYJ05]KF`1HF5P00P1EEED01@1FEUH0FEUI05UIF@1KFe/0GUiN0080GEeM00@0FEUI
05IFEP1FEUH0EeMG0P1EEED01@1GEeL0Fe]K05eMG@1MGEd0FUYJ00<0Fe]K0`1JFUX0101PH600HF5Q
065QH@1QHF42061PH003065QH@1OGel0GEeM00@0GEeM00@0Fe]K05UIF@1FEUH0EUIF0`1EEED01@1I
FET0GUiN05iNGP1NGUh0GemO0080GUiN00<0Fe]K05IFEP1FEUH0101FEUH01@1GEeL0FEUI05UIF@1J
FUX0Fe]K0080GUiN101PH60205mOG`0305iNGP1MGEd0GEeM00D0GEeM00@0G5aL05eMG@1MGEd0G5aL
0P1JFUX01@1HF5P0EeMG05MGE`1HF5P0FUYJ0080GEeM00D0H61P069RHP1RHV80GEeM05aLG00205]K
F`<0FEUI00<0GEeM05iNGP1MGEd01@1MGEd205]KF`0505QHF01GEeL0EeMG05MGE`1HF5P00P1JFUX0
1@1OGel0HV9R069RHP1RHV80Hf=S0080HF5Q0`1OGel0101NGUh0GEeM05mOG`1OGel305iNGP03065Q
H@3oool0oooo00d0oooo000=0?ooo`0409jNWP2BTY80TY:B07AdM080jNWY00D0Q8B408>3P`2OWil0
WinO09JFUP0209ZJVP0506m_K`3oool0oooo05UIF@2@T9000P2FUYH01@2IVIT0Rh^;08^;R`26QXH0
`l?30080_;bl00@0LW9b08B4Q024Q8@0^;Rh0P23Ph<01@1^KVh0l_;b07=cL`1cLg<0UIFE0080YZJV
00D0Ti>C08b<S022PX80PX:20:VYZ@020<K6aP0507=cL`2>SXh0YJFU0:FUY@1lO7`00P2RXZ801@2h
^;P0UiNG09NGU`2;Rh/0V9RH0080WYjN00D0TI6A07inOP1nOWh0^k^k0;6a/@0208>3P`0408n?S`2;
Rh/0Rh^;08n?S`80W9bL00D0f][J06MWI`2HV9P0V9RH09NGU`020:2PX00509FEU@1`L700c/k>0<k>
cP2>SXh00P2EUID01@2HV9P0UIFE09FEU@23Ph<0YJFU0080`L7100D0PH6109bLW02LW9`0TY:B09FE
U@0208n?S`0507inOP3YjNT0jNWY06UYJ@2JVYX00P2OWil0102CTi<0IFEU06EUI@3Ogml209nOW`05
07MgM`2@T900/K6a0;6a/@1/K6`00P3Rh^801028R8P0OGem0:FUY@2UYJD309JFUP0509>CT`18B4P0
B4Q80?ooo`1eMGD00P21PH401@2BTY80Ph>308>3P`2?Shl0kno_0080LW9b00D0SXj>09NGU`2GUiL0
WYjN05]KF`020>c/k004092@T024Q8@0Q8B409VIV@80UIFE00D0V9RH07IfMP38b<P0b<S80:NWY`02
08F5Q@0508b<S02VYZH0K6a/06a/K02k^k/00P38b<P01@1bLW80U9BD09BDU02CTi<0R8R80080][Jf
00@0LG5a0=_Kf`3Kfm/0J6QX2P3oool0100d=3@0;bl_02l_;`0/;2`202/[:`0402XZ:P0];Bd0;bl_
02l_;`<0=CDe00D0=SHf03<c<`0c<c<0;Bd]02<S8`0202HV9P0502DU9@0/;2`0;2`/034a<@0h>3P0
0P0d=3@0100c<c<0;2`/02`/;00b<S8203@d=00403/k>`10@400ATI604I6AP<0@T920P11@D4203lo
?`0503/k>`0f=SH0=SHf03De=@0i>CT00P12@T80101<C4`0De=C05=CD`1ADE4204e=C@0404=3@`0k
>c/0=SHf03Hf=P@0>SXj0`0i>CT00`0d=3@0=CDe03De=@0303Xj>P0503/k>`0n?Sh0?Shn03hn?P0k
>c/00P0m?Cd01@11@D40ADE504Q8B018B4P0C4a<0080Cdm?00D0C4a<04e=C@1=CDd0C4a<04U9B@03
04Q8B080AdM700D0B4Q804M7A`13@d<0@d=30451@@0203`l?00503Ph>00f=SH0=SHf03Hf=P0e=CD0
0P0g=cL0100i>CT0?clo03lo?`11@D4304A4A00504I6AP14A4@0A4A40492@P10@4000P0n?Sh0100k
>c/0@4100410@011@D430492@P0304=3@`0l?3`0?3`l00<0>SXj00D0?3`l03hn?P12@T80@T9204E5
A@0404];B`<0BTY:0P14A4@01@13@d<0@T920492@P10@400@T920080A4A400@0ADE504I6AP16ATH0
B4Q80`17AdL01019BDT0Bd];04];B`1;Bd/204Y:BP0504a<C01;Bd/0BDU904U9B@16ATH00P13@d<0
0`0l?3`0oooo0?ooo`0=0?ooo`003@3oool0102RXZ80Shn?08n?S`1?Cdl20?ooo`0507]kN`20P800
V9RH09RHV02ATI400P2SXj<01@2:RXX0c<c<0<c<c01gMgL0SHf=0080W9bL00D0V9RH08b<S02<S8`0
L71`0<o?c`020=_Kf`0405QHF029RHT0RHV90;2`/080QhN700D0QXJ60<K6aP26QXH0QXJ60::RXP02
09nOW`0508n?S`2>SXh0Ng]k07]kN`2[Zj/00P3Jf]X01@1WIfL0SXj>0:6QX@2QXJ40Q8B40080Z:RX
00D0Y:BT09VIV@2IVIT0UiNG09:BTP0209VIV@0509:BTP1cLg<0Lg=c0=[JfP2a/K400P1aLG40102A
TI40QHF508F5Q@2[Zj/208j>SP030;fm_@1mOGd0VIVI0080VIVI0P2NWYh01@2EUID0Hf=S0>[ZjP3Z
j^X0QHF50080TI6A00D0UYJF09RHV02HV9P0Ti>C09JFUP020:f][@0509>CT`2KVi/0Vi^K096AT@2D
U9@00P2<S8`01@1]KFd0oooo0?ooo`1CDe<0VYZJ0080WinO00@0U9BD07]kN`1kNg/0`L710P2FUYH0
1@26QXH0Ti>C0:ZZZP2ZZZX0DU9B0080oooo00@0QHF5071`L02PX:00X:2P0`2HV9P01@2CTi<0IfMW
06MWI`3alO40Ph>30080S8b<00D0TI6A07emO@1mOGd0MgMg0?ooo`0205IFEP05092@T02DU9@0U9BD
09nOW`1_Kfl00P3=cLd0102DU9@0SHf=08f=S@2IVIT209:BTP0509^KV`1VIVH0g=cL0=cLg02`/;00
0P1gMgL01@2?Shl0Y:BT07UiN@1iNGT0ZJVY0080`<3000D0PX:209:BTP2BTY80UIFE08^;R`020:j^
[P04065QH@3oool0oooo059BDPX0oooo00@0Y:BT0:RXZ02XZ:P0[Zj^0P2e]KD0102k^k/0a/K60<c<
c03<c<`30<K6aP050<C4a030`<00`<300;fm_@35aLD00P30`<001@2h^;P0[:b/0:b/[02YZJT0X:2P
0080WinO00<0ZJVY0;Zj^P2j^[X00`2e]KD01@2f][H0/;2`0:FUY@2UYJD0YZJV0080ZZZZ00D0YjNW
0:BTY02YZJT0ZJVY0:f][@020:b/[080ZZZZ0P2PX:00102LW9`0VYZJ09ZJVP2QXJ420:FUY@050:n_
[`2`/;00ZZZZ0:ZZZP2SXj<00P2RXZ801@2QXJ40YZJV0:f][@2][Jd0/K6a0080[Zj^00D0YJFU09nO
W`2OWil0VIVI09BDU00209FEU@0509^KV`2EUID0UIFE092@T02>SXh00P2;Rh/01024Q8@0QhN708N7
Q`2=SHd208b<S005092@T02EUID0UIFE09FEU@2CTi<00P2ATI401@29RHT0P82008B4Q024Q8@0QHF5
0080R8R800D0SHf=09JFUP2IVIT0VIVI09NGU`02092@T00408V9R@1nOWh0OWin06m_K`<0HV9R00D0
I6AT06YZJP1ZJVX0Lg=c08>3P`0208V9R@0408j>SP2ATI40TI6A08n?S`80RXZ:00D0QhN708:2PP21
PH40PH6107UiN@0207IfMP0507AdM01`L700IVIV06IVIP1XJ6P0101YJFT206YZJP@0Jf][0P1XJ6P0
101UIFD0HV9R05eMG@1MGEd305QHF00505aLG01PH600GEeM05eMG@1JFUX00P1EEED01@1@D500Cdm?
04m?C`1ADE40CTi>0080H61P00@0LW9b07inOP1nOWh0Shn?3`3oool000d0oooo00@0XZ:R08n?S`2?
Shl0Cdm?0P3oool01@1kNg/0P82009RHV02HV9P0TI6A0080Xj>S00D0RXZ:0<c<c03<c<`0MgMg08f=
S@0209bLW00509RHV02<S8`0S8b<071`L03?cll00P3Kfm/0101HF5P0RHV908V9R@2`/;0208N7Q`05
08J6QP36a/H0QXJ608J6QP2RXZ800P2OWil01@2?Shl0SXj>07]kN`1kNg/0Zj^[0080f][J00D0IfMW
08j>SP2QXJ40XJ6Q08B4Q0020:RXZ0050:BTY02IVIT0VIVI09NGU`2BTY800P2IVIT01@2BTY80Lg=c
07=cL`3Jf]X0/K6a0080LG5a00@0TI6A08F5Q@25QHD0Zj^[0P2>SXh00`2m_Kd0OGem09VIV@0209VI
V@80WYjN00D0UIFE06=SH`3Zj^X0j^[Z08F5Q@02096AT@0509JFUP2HV9P0V9RH09>CT`2FUYH00P2]
[Jd01@2CTi<0Vi^K09^KV`2ATI40U9BD0080S8b<00D0KFe]0?ooo`3oool0De=C09ZJVP0209nOW`04
09BDU01kNg/0Ng]k0<71`@80UYJF00D0QXJ609>CT`2ZZZX0ZZZZ059BDP020?ooo`0408F5Q@1`L700
X:2P0:2PX0<0V9RH00D0Ti>C06MWI`1WIfL0lO7a08>3P`0208b<S005096AT@1mOGd0OGem07MgM`3o
ool00P1FEUH01@2@T900U9BD09BDU02OWil0Kfm_0080cLg=00@0U9BD08f=S@2=SHd0VIVI0P2BTY80
1@2KVi/0IVIV0=cLg03Lg=`0/;2`0080MgMg00D0Shn?0:BTY01iNGT0NGUi0:VYZ@020<30`00508:2
PP2BTY80TY:B09FEU@2;Rh/00P2^[Zh0101QHF40oooo0?ooo`1BDU8:0?ooo`040:BTY02XZ:P0Z:RX
0:j^[P80]KFe00@0^k^k0<K6aP3<c<`0c<c<0`36a/H01@34a<@0`<300<30`02m_Kd0aLG50080`<30
00D0^;Rh0:b/[02/[:`0ZJVY0:2PX00209nOW`030:VYZ@2j^[X0^[Zj00<0]KFe00D0][Jf0;2`/02U
YJD0YJFU0:JVYP020:ZZZP050:NWY`2TY:@0ZJVY0:VYZ@2][Jd00P2/[:`20:ZZZP80X:2P00@0W9bL
09ZJVP2JVYX0XJ6Q0P2UYJD01@2_[jl0/;2`0:ZZZP2ZZZX0Xj>S0080XZ:R00D0XJ6Q0:JVYP2][Jd0
[Jf]0;6a/@020:j^[P050:FUY@2OWil0WinO09VIV@2DU9@00P2EUID01@2KVi/0UIFE09FEU@2@T900
SXj>0080Rh^;00@0Q8B408N7Q`27QhL0SHf=0P2<S8`01@2@T900UIFE09FEU@2EUID0Ti>C0080TI6A
00D0RHV90820P024Q8@0Q8B408F5Q@0208R8R00508f=S@2FUYH0VIVI09VIV@2GUiL00P2@T9001029
RHT0OWin07inOP1_Kfl3069RHP0506ATI01ZJVX0JVYZ07=cL`23Ph<00P29RHT0102>SXh0TI6A096A
T@2?Shl208Z:RP0508N7Q`22PX80PH610861P@1iNGT00P1fMWH01@1dM7@0L71`06IVIP1VIVH0J6QX
00@0JFUY0P1ZJVX406][J`80J6QX00@0IFEU069RHP1MGEd0GEeM0`1HF5P01@1LG5`0H61P05eMG@1M
GEd0FUYJ0080EEEE00D0D51@04m?C`1?Cdl0DE5A04i>CP02061PH004079bLP1nOWh0OWin08n?S`l0
oooo000=0?ooo`040:6QX@2CTi<0Ti>C03@d=080oooo00D0Ogmo07IfMP2BTY80TY:B09FEU@020:BT
Y00509^KV`2NWYh0WYjN08n?S`2=SHd00P2OWil01@2IVIT0Ti>C09>CT`1GEeL0g=cL0080l_;b00@0
@41008Z:RP2:RXX0][Jf0P20P8001@2QXJ40WYjN09JFUP2FUYH0Y:BT0080WIfM00D0TI6A09:BTP1`
L700L71`0;2`/0020>CTi00505mOG`2=SHd0WYjN09jNWP2ATI400P2XZ:P01@2GUiL0TY:B09:BTP2M
WId0V9RH0080Shn?00D0UYJF06IVIP1VIVH0o_kn0:FUY@0206IVIP0409BDU023Ph<0Ph>30;Vi^@80
RXZ:00D0YjNW08J6QP2OWil0WinO09bLW00209ZJVP0509FEU@1DE5@0oooo0?ooo`22PX800P23Ph<0
1@2GUiL0VYZJ09ZJVP2IVIT0Ti>C0080YjNW00D0U9BD09bLW02LW9`0TI6A09NGU`0208:2PP0506=S
H`3oool0oooo03dm?@2IVIT00P2LW9`0102HV9P0TI6A096AT@2SXj<209JFUP05092@T02BTY80YJFU
0:FUY@15ADD00P3oool01@2;Rh/0H61P09ZJVP2JVYX0Vi^K0080VYZJ00D0TI6A08V9R@29RHT0]kNg
09:BTP0209FEU@0509BDU01oOgl0Ogmo055AD@3oool00P0j>SX01@2?Shl0UiNG09NGU`2JVYX0QXJ6
0080[:b/00@0VYZJ09JFUP2FUYH0UiNG0P2?Shl01@2OWil0EeMG0>SXj03Xj>P0`L710080IfMW00D0
TI6A0:6QX@27QhL0QhN709^KV`020;>c/`0509:BTP2CTi<0Ti>C09JFUP2=SHd00P2UYJD0101?Cdl0
oooo0?ooo`0i>CT:0?ooo`<0ADE500D0A4A40492@P12@T80?Shn03Ph>00203De=@<0<c<c00@0=3@d
034a<@0a<C40;bl_0`0/;2`01@0c<c<0?3`l03`l?00l?3`0@4100080A4A400@0>3Ph02/[:`0[:b/0
9bLW0P0T92@01@0N7Qh0820P02LW9`0W9bL0;Rh^0080<30`00D0=SHf03dm?@0n?Sh0?Shn03lo?`02
04A4A00504Q8B014A4@0AdM704M7A`16ATH00P14A4@00`0l?3`0?Cdm03dm?@0203Ph>080?Shn00<0
@d=304A4A014A4@00P15ADD20451@@<0?clo00D0ATI604];B`1;Bd/0DE5A05EEE@0205ADE00504m?
C`1CDe<0De=C05UIF@1JFUX00P1PH600101ZJVX0J6QX06QXJ01QHF42061PH00505eMG@1JFUX0Fe]K
05]KF`1RHV800P1XJ6P01@1aLG40N7Qh07MgM`1gMgL0MWIf0080M7Ad00D0L71`06YZJP1TI6@0I6AT
06IVIP0206m_K`0507QhN021PH40PH61096AT@2GUiL00P2BTY801@2;Rh/0PX:208:2PP1gMgL0K6a/
0080IfMW00@0IVIV05iNGP1NGUh0GemO0P1VIVH01@1YJFT0KVi^07MgM`1gMgL0Ng]k0080Ogmo00D0
P82008:2PP2:RXX0RXZ:08n?S`0208V9R@0308R8R02:RXX0Rh^;0080Rh^;0P2BTY801@2EUID0UiNG
09NGU`2IVIT0WYjN0080Xj>S00D0[:b/0;2`/02`/;00[Zj^0:RXZ0050:NWY`050:b/[02_[jl0[jn_
0:n_[`2][Jd00P2EUID0101oOgl0JVYZ06YZJP1FEUH?0?ooo`003@3oool0102LW9`0UYJF09JFUP0^
;Rh20?ooo`0507]kN`1`L700Ti>C09>CT`2IVIT00P2OWil01@2GUiL0W9bL09bLW02@T900TI6A0080
W9bL00D0X:2P08j>SP2>SXh0E5AD0=oOg`020?ooo`04034a<@2>SXh0SXj>0;Fe]@80OWin00D0Vi^K
09fMW@2OWil0WinO09fMW@0209jNWP0509>CT`2JVYX0GemO05mOG`2o_kl00P3WinL01@1BDU80U9BD
09FEU@2EUID0WYjN0080YJFU00D0V9RH08N7Q`27QhL0YjNW09FEU@0208^;R`0509BDU01XJ6P0J6QX
0?ooo`2RXZ800P1OGel0102BTY80QHF508F5Q@2l_;`208Z:RP0509JFUP2BTY80W9bL09bLW02QXJ40
0P2GUiL01@2EUID0CTi>0?ooo`3oool0QHF50080PX:200D0TY:B09ZJVP2JVYX0WIfM08j>SP020:n_
[`0508^;R`2IVIT0VIVI09:BTP2HV9P00P1dM7@01@1bLW80oooo0?ooo`0S8b<0XJ6Q0080UIFE00@0
WinO09ZJVP2JVYX0Rh^;0P2KVi/01@2DU9@0T92@0:NWY`2WYjL0>SXj0080oooo00D0S8b<05YJFP2D
U9@0U9BD0:6QX@0209>CT`05096AT@2IVIT0VIVI09jNWP2GUiL00P2NWYh01@2ATI40Ph>308>3P`0c
<c<0oooo0080;bl_00D0Ph>309bLW02LW9`0VYZJ09FEU@0209VIV@0409^KV`2JVYX0VYZJ09VIV@80
Shn?00D0WYjN04];B`3Vi^H0i^KV0=[JfP0205aLG00509>CT`2LW9`0TI6A096AT@2BTY800P2QXJ40
0`2SXj<0UIFE09FEU@0209NGU`80U9BD00@0@D510?ooo`3oool0;Bd]2P3oool405EEE@80De=C00D0
DU9B04m?C`1<C4`0C4a<04Y:BP0204];B`0504e=C@1BDU80DU9B05IFEP1IFET00P1LG5`0101OGel0
GUiN05iNGP1PH604069RHPD0I6AT0P1SHf<2069RHP05061PH01MGEd0GEeM05eMG@1LG5`00P1HF5P0
1@1GEeL0EUIF05IFEP1CDe<0D51@00D0Cdm?00@0DU9B05=CD`1CDe<0EUIF101GEeL205IFEP0505AD
E01BDU80DE5A055AD@1?Cdl00P1@D50304m?C`0504i>CP1?Cdl0DU9B059BDP1EEED00P1DE5@01@1@
D500C4a<04Q8B018B4P0@d=30080@41000@0A4A404=3@`13@d<0@d=30`14A4@30492@P0503hn?P11
@D40?clo03lo?`10@4000P12@T801@14A4@0@D510492@P12@T80@4100080>SXj00D0>3Ph03Lg=`0g
=cL0<c<c03Xj>P0203dm?@050451@@14A4@0A4A404];B`17AdL00P1:BTX01019BDT0BTY:04Y:BP18
B4P304I6AP0404=3@`10@400@41004E5A@80@T9200D0@4100451@@0o?cl0?clo03Hf=P0603@d=0<0
=CDe00D0=3@d03Ph>00h>3P0>3Ph03De=@02038b<P0502d];@0T92@092@T020P800Q8B400P0T92@0
100W9bL0:RXZ02XZ:P0/;2`302d];@0403@d=00k>c/0>c/k04=3@`80C4a<00<0E5AD0?ooo`3oool0
3@3oool000d0oooo00@0V9RH09ZJVP2JVYX0@D510P3oool01@23Ph<0MWIf09ZJVP2JVYX0VIVI0080
V9RH00D0Q8B40;6a/@2a/K40VIVI08F5Q@0209^KV`050:>SX`2EUID0UIFE06=SH`37alL00P3^k^h0
1017AdL0TY:B09:BTP2XZ:P208F5Q@0509:BTP2RXZ80/;2`0;2`/02BTY800P2NWYh01@2DU9@0UYJF
06a/K01/K6`0^[Zj0080fMWI00D0Fe]K09ZJVP2ATI40TI6A09NGU`020:BTY0050:>SX`23Ph<0Ph>3
0:RXZ02CTi<00P2;Rh/01@2GUiL0MWIf07IfMP3clo<0XZ:R0080I6AT00@0U9BD08j>SP2>SXh0/k>c
0P26QXH01@2XZ:P0RHV909^KV`2KVi/0XZ:R0080T92@00D0W9bL06=SH`3hn?P0n?Sh08:2PP0208j>
SP0509:BTP2EUID0UIFE092@T02JVYX00P2l_;`01@25QHD0UIFE09FEU@2CTi<0VIVI0080N7Qh00D0
OGem0?ooo`3oool0>CTi09nOW`0209:BTP0409jNWP2IVIT0VIVI09bLW080Ti>C00D0Shn?09BDU02V
YZH0YZJV04E5A@020?ooo`05092@T01TI6@0UYJF09JFUP2NWYh00P2FUYH01@27QhL0WIfM09fMW@2Z
ZZX0UIFE0080VYZJ00D0UYJF0820P020P800A4A40?ooo`0203Hf=P0508F5Q@2RXZ80XZ:R09FEU@2C
Ti<00P2LW9`0102UYJD0TY:B09:BTP2FUYH2096AT@0509bLW01JFUX0eMGE0=GEe@3Cdm<00P1VIVH0
1@2DU9@0UYJF09:BTP2BTY80SHf=0080Zj^[00D0Z:RX08^;R`2;Rh/0VIVI09JFUP0209FEU@0404U9
B@3oool0oooo0410@0X0oooo00<0HV9R061PH01PH6000`1NGUh00`1MGEd0F5QH05UIF@0405UIF@05
05MGE`1HF5P0F5QH05UIF@1JFUX01@1IFET0101HF5P0EUIF05MGE`1GEeL305UIF@0505YJFP1MGEd0
GEeM065QH@1NGUh00P1KFe/01@1HF5P0EeMG05MGE`1DE5@0EUIF0080FUYJ00D0GEeM05aLG01LG5`0
GUiN069RHP0306=SH`80IVIV00@0IFEU065QH@1QHF40HF5Q0`1RHV8306ATI00406=SH`1PH600GemO
05mOG`<0G5aL00<0GEeM05aLG01LG5`00P1KFe/205UIF@<0F5QH00@0FEUI05]KF`1LG5`0G5aL0`1M
GEd00`1KFe/0EeMG05MGE`0405QHF00505UIF@1LG5`0G5aL05aLG01KFe/00P1LG5`01@1MGEd0GUiN
05iNGP1MGEd0GUiN00<0G5aL0P1KFe/0101LG5`0FEUI05UIF@1JFUX305aLG00405]KF`1OGel0GemO
05iNGPH0GEeM00D0GUiN05eMG@1MGEd0Fe]K05YJFP0205eMG@0405iNGP1OGel0GemO06=SH`<0I6AT
00<0IFEU06MWI`1WIfL00P1VIVH306EUI@H0I6AT00<0Hf=S069RHP1RHV800`1QHF400`1SHf<0IVIV
06IVIP0206IVIP80IFEU00D0I6AT065QH@1QHF40GemO05eMG@0205iNGP0405eMG@1LG5`0G5aL05aL
G0l0oooo000=0?ooo`0409RHV02JVYX0VYZJ0451@@80oooo00D0Ph>307IfMP2JVYX0VYZJ09VIV@02
09RHV00508B4Q02a/K40/K6a09VIV@25QHD00P2KVi/01@2SXj<0UIFE09FEU@1SHf<0alO70080k^k^
00@0AdM709:BTP2BTY80Z:RX0P25QHD01@2BTY80XZ:R0;2`/02`/;00TY:B0080WYjN00D0U9BD09JF
UP1/K6`0K6a/0;Zj^P020=WIf@0505]KF`2JVYX0TI6A096AT@2GUiL00P2TY:@01@2SXj<0Ph>308>3
P`2XZ:P0Ti>C0080Rh^;00D0UiNG07IfMP1fMWH0lo?c0::RXP0206ATI00409BDU02>SXh0SXj>0;>c
/`80QXJ600D0Z:RX08V9R@2KVi/0Vi^K0::RXP02092@T00509bLW01SHf<0n?Sh0?Shn022PX800P2>
SXh01@2BTY80UIFE09FEU@2@T900VYZJ0080_;bl00D0QHF509FEU@2EUID0Ti>C09VIV@0207QhN005
07emO@3oool0oooo03Ti>@2OWil00P2BTY80102NWYh0VIVI09VIV@2LW9`209>CT`0508n?S`2DU9@0
YZJV0:JVYP15ADD00P3oool01@2@T900I6AT09JFUP2FUYH0WYjN0080UYJF00D0QhN709fMW@2MWId0
ZZZZ09FEU@0209ZJVP0509JFUP20P800P82004A4A03oool00P0f=SH01@25QHD0XZ:R0::RXP2EUID0
Ti>C0080W9bL00@0YJFU09:BTP2BTY80UYJF0P2ATI401@2LW9`0FUYJ0=GEe@3EeMD0dm?C0080IVIV
00D0U9BD09JFUP2BTY80TY:B08f=S@020:^[Z`050:RXZ02;Rh/0Rh^;09VIV@2FUYH00P2EUID01019
BDT0oooo0?ooo`10@40:0?ooo`03069RHP1PH600H61P00<0GUiN00<0GEeM05QHF01IFET0101IFET0
1@1GEeL0F5QH05QHF01IFET0FUYJ00D0FEUI00@0F5QH05IFEP1GEeL0EeMG0`1IFET01@1JFUX0GEeM
05eMG@1QHF40GUiN0080Fe]K00D0F5QH05MGE`1GEeL0E5AD05IFEP0205YJFP0505eMG@1LG5`0G5aL
05iNGP1RHV800`1SHf<206IVIP0406EUI@1QHF40HF5Q065QH@<0HV9R0`1TI6@0101SHf<0H61P05mO
G`1OGel305aLG00305eMG@1LG5`0G5aL0080Fe]K0P1IFET305QHF00405UIF@1KFe/0G5aL05aLG0<0
GEeM00<0Fe]K05MGE`1GEeL0101HF5P01@1IFET0G5aL05aLG01LG5`0Fe]K0080G5aL00D0GEeM05iN
GP1NGUh0GEeM05iNGP0305aLG080Fe]K00@0G5aL05UIF@1IFET0FUYJ0`1LG5`0101KFe/0GemO05mO
G`1NGUh605eMG@0505iNGP1MGEd0GEeM05]KF`1JFUX00P1MGEd0101NGUh0GemO05mOG`1SHf<306AT
I00306EUI@1WIfL0IfMW0080IVIV0`1UIFD606ATI00306=SH`1RHV80HV9R00<0HF5Q00<0Hf=S06IV
IP1VIVH00P1VIVH206EUI@0506ATI01QHF40HF5Q05mOG`1MGEd00P1NGUh0101MGEd0G5aL05aLG01L
G5`?0?ooo`003@3oool0102HV9P0Vi^K09^KV`1JFUX20?ooo`0408^;R`1mOGd0WIfM09fMW@<0VIVI
00D0Jf][0=3@d03@d=00WYjN07]kN`0209RHV00509nOW`2QXJ40XJ6Q06e]K@2g]kL00P3IfMT0101L
G5`0UYJF09JFUP2OWil208Z:RP050861P@2_[jl0`L710<71`@21PH400P2RXZ801@2CTi<0UYJF07Yj
NP1jNWX0/K6a0080`l?300D0K6a/09^KV`2>SXh0SXj>09fMW@0208V9R@050<C4a025QHD0QHF509fM
W@2BTY800P2;Rh/01@2JVYX0PH610861P@3Lg=`0W9bL0080LW9b00@0UYJF09:BTP2BTY80YjNW0P1l
O7`01@3:b/X0MWIf09RHV02HV9P0Y:BT0080Shn?00D0XJ6Q071`L03Jf]X0f][J08j>SP02096AT@05
08n?S`2FUYH0UYJF0861P@2SXj<00P3Fe]H01@1aLG40U9BD09BDU02BTY80VIVI0080OGem00D0T92@
0?knoP3no_h0E5AD09nOW`0208b<S00409nOW`2?Shl0Shn?0;>c/`80S8b<00D0T92@09:BTP2QXJ40
XJ6Q06IVIP020??cl`050:2PX01aLG40U9BD09BDU02JVYX00P2HV9P01@1eMGD0/;2`0;2`/02a/K40
SHf=0080XZ:R00D0SXj>08>3P`23Ph<0FEUI0?ooo`02065QH@0508>3P`2OWil0WinO09BDU02;Rh/0
0P2TY:@00`2o_kl0O7al07alO00309BDU00509bLW01ZJVX0^[Zj0;Zj^P3?cll00P1cLg<01@2EUID0
TY:B09FEU@2EUID0Kfm_0080gmoO00D0UIFE08R8R028R8P0VYZJ09JFUP0209>CT`0405iNGP3oool0
oooo05=CD`X0oooo00<0>c/k0451@@11@D400`11@D401014A4@0ADE50410@010@40403hn?P80>c/k
0P0h>3P303Hf=P80>CTi00@0?3`l0451@@16ATH0ATI60`17AdL01@19BDT0B4Q804Q8B01:BTX0C4a<
0080CTi>00D0Cdm?051@D01@D500CDe=04Y:BP0204M7A`050492@P10@400@41003lo?`0l?3`00P0i
>CT00`0h>3P0=SHf03Hf=P0503De=@<0>SXj0P0l?3`00`0n?Sh0@41003hn?P0203hn?P80?clo0`0n
?Sh01@0m?Cd0>c/k03Ph>00h>3P0=SHf0080=cLg00D0>3Ph03Hf=P0f=SH0=SHf03Ph>00303De=@80
>c/k100l?3`01@0k>c/0>3Ph03Ph>00h>3P0?Cdm0080?Shn00D0?clo0451@@11@D40AdM704Q8B002
04Y:BP0304a<C01>CTh0CTi>00<0C4a<00@0D51@05ADE01HF5P0F5QH0`1KFe/01@1HF5P0EeMG05=C
D`1CDe<0DE5A0080C4a<00@0BTY:04Q8B018B4P0BDU90`1;Bd/01@1=CDd0Bd];04];B`1:BTX0BDU9
0080Bd];00D0BDU904a<C01<C4`0Bd];04a<C00204e=C@@0CTi>0P1?Cdl01@1@D500DE5A05=CD`1C
De<0EEEE0080E5AD1@1EEED205ADE0<0DU9B00D0De=C05ADE01@D500D51@04e=C@0204Q8B0030451
@@3oool0oooo00d0oooo000=0?ooo`0409JFUP2NWYh0WYjN07UiN@80b/[:00D0UiNG08J6QP2PX:00
X:2P09JFUP0209^KV`0505EEE@3/k>`0k>c/0::RXP1bLW800P2EUID01@2MWId0YZJV0:JVYP1kNg/0
[Zj^0080_Kfm00@0Lg=c09NGU`2GUiL0W9bL0P29RHT01@1dM7@0^[Zj0=CDe03De=@0KFe]0080XJ6Q
00D0VYZJ09>CT`27QhL0QhN70:^[Z`020;6a/@0507QhN02JVYX0TY:B09:BTP2QXJ400P1]KFd01@3M
gMd0SXj>08j>SP2<S8`0UIFE0080S8b<00D0WYjN08n?S`2?Shl0_Kfm09VIV@020861P@0409NGU`2H
V9P0V9RH09NGU`80M7Ad00D0lo?c05iNGP2FUYH0UYJF0:2PX00209RHV0050:FUY@1jNWX0_;bl0;bl
_02HV9P00P2DU9@01@2ATI40U9BD09BDU01aLG40/k>c0080j^[Z00D0H61P09BDU02DU9@0T92@09bL
W00208>3P`0509fMW@3De=@0e=CD06i^KP2NWYh00P29RHT0102KVi/0Rh^;08^;R`36a/H208V9R@05
08j>SP2?Shl0Y:BT0:BTY01mOGd00P33`l<01@2XZ:P0P82009BDU02DU9@0VIVI0080UIFE00D0Hf=S
0=3@d03@d=00[Jf]07emO@020:j^[P0508R8R02?Shl0Shn?06QXJ03alO400P2NWYh01@1eMGD0WYjN
09jNWP2ATI40Ogmo0080Z:RX00@0g=cL06ATI01TI6@0V9RH0P2GUiL01@2IVIT0NGUi0:2PX02PX:00
c/k>0080QXJ600D0SXj>08n?S`2LW9`0W9bL05MGE`020?ooo`0508^;R`23Ph<0Ph>309^KV`2FUYH0
0P2CTi<0101`L700m?Cd0?Cdm01SHf<:0?ooo`0409jNWP2LW9`0W9bL09ZJVP80V9RH00D0UYJF09BD
U02HV9P0V9RH09JFUP0209>CT`<0U9BD00D0UIFE09fMW@2VYZH0YZJV0:b/[0020:j^[P050:ZZZP2R
XZ80UiNG09NGU`2<S8`00P25QHD01@1mOGd0MgMg07MgM`1dM7@0Lg=c0080LW9b00D0MGEe07YjNP1j
NWX0PH6108:2PP030820P080PH6100D0OGem07inOP1mOGd0OGem07alO00207inOP050820P021PH40
PH6108R8R02?Shl00P2CTi<309BDU005092@T02:RXX0Ph>308>3P`1nOWh00P1fMWH01@1eMGD0MWIf
07IfMP1jNWX0OWin0080RXZ:00D0TY:B09RHV02HV9P0WIfM0:2PX00209nOW`0409ZJVP2FUYH0UYJF
08f=S@80Ph>300D0OWin07YjNP1cLg<0Lg=c079bLP0207=cL`0307]kN`21PH40P8200080P8200P1m
OGd0101aLG40IVIV06=SH`1SHf<3069RHP0506=SH`1YJFT0JFUY06a/K01_Kfl00P1aLG401@1]KFd0
IFEU06EUI@1OGel0E5AD0080C4a<00<0ATI604A4A014A4@00`0o?cl01@0l?3`0?Cdm0410@010@400
CDe=0080DU9B0P1DE5@2055AD@0504M7A`10@400@41003dm?@0l?3`00P0k>c/0100j>SX0>c/k03/k
>`0l?3`203lo?`0504M7A`18B4P0BDU904U9B@18B4P00P14A4@01@0h>3P0<30`02d];@0];Bd0;bl_
0080<30`00D0=CDe03Xj>P0j>SX0?3`l0492@P0205=CD`0406ATI01iNGT0NGUi08j>SPl0oooo000=
0?ooo`0409JFUP2NWYh0WYjN07UiN@80b/[:00D0UiNG08J6QP2PX:00X:2P09JFUP0209^KV`0505EE
E@3/k>`0k>c/0::RXP1bLW800P2EUID01@2MWId0YZJV0:JVYP1kNg/0[Zj^0080_Kfm00@0Lg=c09NG
U`2GUiL0W9bL0P29RHT01@1dM7@0^[Zj0=CDe03De=@0KFe]0080XJ6Q00D0VYZJ09>CT`27QhL0QhN7
0:^[Z`020;6a/@0507QhN02JVYX0TY:B09:BTP2QXJ400P1]KFd01@3MgMd0SXj>08j>SP2<S8`0UIFE
0080S8b<00D0WYjN08n?S`2?Shl0_Kfm09VIV@020861P@0409NGU`2HV9P0V9RH09NGU`80M7Ad00D0
lo?c05iNGP2FUYH0UYJF0:2PX00209RHV0050:FUY@1jNWX0_;bl0;bl_02HV9P00P2DU9@01@2ATI40
U9BD09BDU01aLG40/k>c0080j^[Z00D0H61P09BDU02DU9@0T92@09bLW00208>3P`0509fMW@3De=@0
e=CD06i^KP2NWYh00P29RHT0102KVi/0Rh^;08^;R`36a/H208V9R@0508j>SP2?Shl0Y:BT0:BTY01m
OGd00P33`l<01@2XZ:P0P82009BDU02DU9@0VIVI0080UIFE00D0Hf=S0=3@d03@d=00[Jf]07emO@02
0:j^[P0508R8R02?Shl0Shn?06QXJ03alO400P2NWYh01@1eMGD0WYjN09jNWP2ATI40Ogmo0080Z:RX
00@0g=cL06ATI01TI6@0V9RH0P2GUiL01@2IVIT0NGUi0:2PX02PX:00c/k>0080QXJ600D0SXj>08n?
S`2LW9`0W9bL05MGE`020?ooo`0508^;R`23Ph<0Ph>309^KV`2FUYH00P2CTi<0101`L700m?Cd0?Cd
m01SHf<:0?ooo`0409jNWP2LW9`0W9bL09ZJVP80V9RH00D0UYJF09BDU02HV9P0V9RH09JFUP0209>C
T`<0U9BD00D0UIFE09fMW@2VYZH0YZJV0:b/[0020:j^[P050:ZZZP2RXZ80UiNG09NGU`2<S8`00P25
QHD01@1mOGd0MgMg07MgM`1dM7@0Lg=c0080LW9b00D0MGEe07YjNP1jNWX0PH6108:2PP030820P080
PH6100D0OGem07inOP1mOGd0OGem07alO00207inOP050820P021PH40PH6108R8R02?Shl00P2CTi<3
09BDU005092@T02:RXX0Ph>308>3P`1nOWh00P1fMWH01@1eMGD0MWIf07IfMP1jNWX0OWin0080RXZ:
00D0TY:B09RHV02HV9P0WIfM0:2PX00209nOW`0409ZJVP2FUYH0UYJF08f=S@80Ph>300D0OWin07Yj
NP1cLg<0Lg=c079bLP0207=cL`0307]kN`21PH40P8200080P8200P1mOGd0101aLG40IVIV06=SH`1S
Hf<3069RHP0506=SH`1YJFT0JFUY06a/K01_Kfl00P1aLG401@1]KFd0IFEU06EUI@1OGel0E5AD0080
C4a<00<0ATI604A4A014A4@00`0o?cl01@0l?3`0?Cdm0410@010@400CDe=0080DU9B0P1DE5@2055A
D@0504M7A`10@400@41003dm?@0l?3`00P0k>c/0100j>SX0>c/k03/k>`0l?3`203lo?`0504M7A`18
B4P0BDU904U9B@18B4P00P14A4@01@0h>3P0<30`02d];@0];Bd0;bl_0080<30`00D0=CDe03Xj>P0j
>SX0?3`l0492@P0205=CD`0406ATI01iNGT0NGUi08j>SPl0oooo000=0?ooo`0409FEU@2LW9`0W9bL
09>CT`80Z:RX00D0Ti>C09BDU02RXZ80XZ:R09BDU00209VIV@0504M7A`3no_h0o_kn0:ZZZP1UIFD0
0P2>SXh30:NWY`0508n?S`2PX:00W9bL09bLW02BTY800P2CTi<01@2JVYX0Rh^;08^;R`1VIVH0aLG5
0080i>CT00D0GemO0:6QX@2QXJ40V9RH08j>SP0209FEU@050:>SX`2ZZZX0ZZZZ07moO`2JVYX00P2F
UYH0102PX:00EeMG05MGE`3gmoL2092@T00508V9R@2BTY80Rh^;08^;R`2NWYh00P2MWId01@2SXj<0
V9RH08j>SP2>SXh0UYJF0080Vi^K00D0S8b<06e]K@1]KFd0oooo04];B`0209RHV00509ZJVP2OWil0
WinO0:b/[025QHD00P2NWYh0102IVIT0WYjN09jNWP2CTi<2096AT@0506ATI036a/H0i^KV0>KViP1N
GUh00P2CTi<01@2?Shl0WinO08Z:RP2:RXX0ZJVY0080YjNW00D0R8R809bLW02;Rh/0Rh^;09JFUP02
08:2PP050=KFeP2<S8`0S8b<08N7Q`2FUYH00P2OWil01@2:RXX0YJFU0:FUY@2WYjL0Shn?0080UIFE
00@0VIVI096AT@2ATI40De=C0P3^k^h01@2WYjL0M7Ad0;Jf]P2f][H0Ogmo0080UIFE00D0Q8B40:NW
Y`3Jf]X0f][J06QXJ00209^KV`05096AT@1cLg<0ZZZZ0:ZZZP3moOd00P18B4P01@2QXJ40UIFE09FE
U@2KVi/0QXJ60080Shn?00D0alO7092@T02@T900S8b<08n?S`0209jNWP040492@P3oool0oooo0861
P@80P82000D0Vi^K09JFUP2FUYH0UYJF08:2PP020<o?c`0307EeM@3oool0oooo00P0oooo00@0E5AD
055AD@1ADE40EEEE0P1GEeL00`1FEUH0FUYJ05QHF00205QHF0<0FEUI0P1JFUX01@1LG5`0EUIF04m?
C`1?Cdl0AdM700<0@41000@0A4A404];B`1;Bd/0EUIF0P1QHF401@1UIFD0Jf][06][J`1_Kfl0L71`
0080M7Ad00D0MGEe07AdM01dM7@0M7Ad07MgM`0207alO0050820P021PH40PH6108>3P`24Q8@00P22
PX801020P800PH610861P@22PX8208B4Q0050861P@1mOGd0LG5a075aL@1/K6`00P1YJFT01@1ZJVX0
LG5a07alO01lO7`0Ph>30080R8R800D0RHV908J6QP26QXH0Ph>307emO@0207IfMP05075aL@1YJFT0
JFUY06ATI01UIFD00P1VIVH0101XJ6P0KVi^06i^KP1fMWH207]kN`0508:2PP27QhL0T92@092@T02E
UID00P2GUiL0102ATI40R8R808R8R028R8P308J6QP0508b<S02GUiL0UYJF09JFUP2DU9@00P2CTi<0
1@2EUID0Shn?08n?S`2:RXX0PX:200<0Ng]k0P23Ph<01@2<S8`0WIfM0:ZZZP2ZZZX0/;2`0080]KFe
0`2k^k/01@30`<00`l?30;no_`2o_kl0Zj^[0080WinO00D0UIFE096AT@2@T900T92@09nOW`020:NW
Y`050:RXZ02YZJT0[:b/0:b/[02][Jd00P2a/K40102h^;P0]KFe0;Fe]@2/[:`30:f][@050:j^[P2g
]kL0]kNg0<K6aP32`/800P33`l<0102n_[h0^[Zj0;Zj^P2d];@20;Zj^P050;Rh^02c/k<0XZ:R0::R
XP2@T9000P1jNWX00`1WIfL0oooo0?ooo`0=0?ooo`003@3oool0102HV9P0WYjN09jNWP2LW9`209:B
TP0509RHV02JVYX0XZ:R0::RXP2CTi<00P2JVYX01@0l?3`0oooo0?ooo`2ZZZX0GemO0080SXj>00D0
VIVI0;Rh^02h^;P0TY:B09^KV`0208Z:RP0409bLW02IVIT0VIVI09bLW080R8R800D0F5QH0=WIf@3T
i>@0i>CT05YJFP0209jNWP0509NGU`2;Rh/0XZ:R0::RXP2BTY800P2/[:`01@2<S8`0TY:B09ZJVP2J
VYX0W9bL0080C4a<00D0oooo08n?S`2?Shl0QhN708V9R@0208j>SP0509^KV`2UYJD0YJFU09jNWP2B
TY800P2CTi<0102HV9P0WIfM09fMW@2;Rh/205iNGP050?ooo`13@d<0Vi^K09^KV`2BTY800P2PX:00
1@2_[jl0QhN709>CT`2CTi<0WinO0080Vi^K00D0U9BD09:BTP2BTY80HF5Q0=;BdP020=KFeP0506AT
I02GUiL0UiNG08n?S`2KVi/00P2RXZ801@2FUYH0T92@092@T02OWil0TY:B0080U9BD00@0TY:B07mo
O`1oOgl0emOG0P2GUiL01@22PX80V9RH09RHV02HV9P0UYJF0080TY:B00D0YJFU09>CT`2KVi/0Vi^K
09RHV00208n?S`0504i>CP3oool0oooo09:BTP1kNg/00P2b/[801@1oOgl0WinO09nOW`2=SHd0NWYj
0080o_kn00D0JVYZ09:BTP2BTY80UYJF061PH0020;Jf]P040?ooo`12@T80@T920:VYZ@80S8b<00D0
Vi^K08n?S`28R8P0R8R80<C4a00308b<S00409:BTP2JVYX0VYZJ04=3@`80oooo00D0QhN707QhN01h
N7P0U9BD09JFUP0209ZJVP0409BDU02ZZZX0ZZZZ08:2PPX0oooo0`17AdL304E5A@0504M7A`19BDT0
BTY:04Y:BP1@D5000P1DE5@01@1EEED0E5AD05ADE01CDe<0D51@00D0Cdm?0P1@D50204m?C`0304e=
C@1;Bd/0Bd];00<0Bd];00D0BDU904Y:BP19BDT0BDU904I6AP0204=3@`0503hn?P0h>3P0=SHf03Hf
=P0d=3@00P0b<S801@0d=3@0<c<c03Ti>@0i>CT0?3`l0080>c/k0`0i>CT01@0b<S80;Rh^034a<@0a
<C40=CDe0080>CTi00@0>c/k03Xj>P0i>CT0>CTi0`0g=cL01@0f=SH0>CTi03Ti>@0k>c/0?Cdm0080
?clo0`11@D420410@080?Shn0`0o?cl01@11@D40A4A404A4A012@T80?clo0080?3`l00<0>3Ph03<c
<`0c<c<00P0a<C42030`<005034a<@0b<S80<S8b03@d=00c<c<00`0h>3P203Lg=`0303De=@0f=SH0
=SHf0080<c<c0P0d=3@01@0f=SH0=CDe03De=@0b<S80<30`00<0;Bd]0P0d=3@01@0j>SX0?Shn03hn
?P0m?Cd0>CTi0080=3@d00D0=CDe03Xj>P0j>SX0ADE504i>CP0305ADE0<0EEEE00@0D51@04U9B@19
BDT0@D510P0g=cL0100/;2`0:2PX02PX:00V9RH4028R8P80820P00D07alO02h^;P0`<300<30`03@d
=00203Ph>00503/k>`0_;bl0;bl_02d];@0[:b/00P0_;bl0100d=3@0>c/k03/k>`11@D4?0?ooo`00
3@3oool0102HV9P0WYjN09jNWP2LW9`209:BTP0509RHV02JVYX0XZ:R0::RXP2CTi<00P2JVYX01@0l
?3`0oooo0?ooo`2ZZZX0GemO0080SXj>00D0VIVI0;Rh^02h^;P0TY:B09^KV`0208Z:RP0409bLW02I
VIT0VIVI09bLW080R8R800D0F5QH0=WIf@3Ti>@0i>CT05YJFP0209jNWP0509NGU`2;Rh/0XZ:R0::R
XP2BTY800P2/[:`01@2<S8`0TY:B09ZJVP2JVYX0W9bL0080C4a<00D0oooo08n?S`2?Shl0QhN708V9
R@0208j>SP0509^KV`2UYJD0YJFU09jNWP2BTY800P2CTi<0102HV9P0WIfM09fMW@2;Rh/205iNGP05
0?ooo`13@d<0Vi^K09^KV`2BTY800P2PX:001@2_[jl0QhN709>CT`2CTi<0WinO0080Vi^K00D0U9BD
09:BTP2BTY80HF5Q0=;BdP020=KFeP0506ATI02GUiL0UiNG08n?S`2KVi/00P2RXZ801@2FUYH0T92@
092@T02OWil0TY:B0080U9BD00@0TY:B07moO`1oOgl0emOG0P2GUiL01@22PX80V9RH09RHV02HV9P0
UYJF0080TY:B00D0YJFU09>CT`2KVi/0Vi^K09RHV00208n?S`0504i>CP3oool0oooo09:BTP1kNg/0
0P2b/[801@1oOgl0WinO09nOW`2=SHd0NWYj0080o_kn00D0JVYZ09:BTP2BTY80UYJF061PH0020;Jf
]P040?ooo`12@T80@T920:VYZ@80S8b<00D0Vi^K08n?S`28R8P0R8R80<C4a00308b<S00409:BTP2J
VYX0VYZJ04=3@`80oooo00D0QhN707QhN01hN7P0U9BD09JFUP0209ZJVP0409BDU02ZZZX0ZZZZ08:2
PPX0oooo0`17AdL304E5A@0504M7A`19BDT0BTY:04Y:BP1@D5000P1DE5@01@1EEED0E5AD05ADE01C
De<0D51@00D0Cdm?0P1@D50204m?C`0304e=C@1;Bd/0Bd];00<0Bd];00D0BDU904Y:BP19BDT0BDU9
04I6AP0204=3@`0503hn?P0h>3P0=SHf03Hf=P0d=3@00P0b<S801@0d=3@0<c<c03Ti>@0i>CT0?3`l
0080>c/k0`0i>CT01@0b<S80;Rh^034a<@0a<C40=CDe0080>CTi00@0>c/k03Xj>P0i>CT0>CTi0`0g
=cL01@0f=SH0>CTi03Ti>@0k>c/0?Cdm0080?clo0`11@D420410@080?Shn0`0o?cl01@11@D40A4A4
04A4A012@T80?clo0080?3`l00<0>3Ph03<c<`0c<c<00P0a<C42030`<005034a<@0b<S80<S8b03@d
=00c<c<00`0h>3P203Lg=`0303De=@0f=SH0=SHf0080<c<c0P0d=3@01@0f=SH0=CDe03De=@0b<S80
<30`00<0;Bd]0P0d=3@01@0j>SX0?Shn03hn?P0m?Cd0>CTi0080=3@d00D0=CDe03Xj>P0j>SX0ADE5
04i>CP0305ADE0<0EEEE00@0D51@04U9B@19BDT0@D510P0g=cL0100/;2`0:2PX02PX:00V9RH4028R
8P80820P00D07alO02h^;P0`<300<30`03@d=00203Ph>00503/k>`0_;bl0;bl_02d];@0[:b/00P0_
;bl0100d=3@0>c/k03/k>`11@D4?0?ooo`003@3oool309ZJVP0509^KV`2/[:`0[:b/08V9R@2FUYH0
0P2OWil0102GUiL0Vi^K09^KV`1?Cdl20?Shn0050::RXP1/K6`0UYJF09JFUP2BTY800P2^[Zh01@2A
TI40];Bd08:2PP22PX80VIVI0080V9RH00D0VIVI08^;R`2;Rh/0HV9R0=KFeP020=;BdP0506=SH`2O
Wil0WinO09JFUP26QXH00P2WYjL01@2TY:@0XJ6Q0:6QX@27QhL0TY:B0080VYZJ00@0WYjN05EEE@1E
EED0n_[j0P2BTY801@2<S8`0RHV908^;R`2;Rh/0UiNG0080Xj>S00D0]KFe08F5Q@2CTi<0Ti>C09bL
W00209JFUP05096AT@1QHF40HF5Q0?ooo`1ADE400P2KVi/01@2?Shl0XZ:R0::RXP2WYjL0Rh^;0080
WYjN00@0WinO09:BTP2BTY80V9RH0P2IVIT01@1WIfL0bLW90<K6aP36a/H0KVi^0080Vi^K00D0SXj>
09FEU@2LW9`0W9bL0:6QX@0209VIV@0509JFUP2?Shl0UIFE09FEU@2KVi/00P1lO7`01@3;bl/0XJ6Q
0:6QX@21PH40UYJF0080VYZJ00D0U9BD08F5Q@25QHD0_Kfm092@T00209NGU`0409BDU02GUiL0UiNG
05=CD`80oooo00D0QhN707emO@2`/;00/;2`07emO@020:2PX00508j>SP20P800n_[j0?[jnP1dM7@0
0P2;Rh/01@2KVi/0G5aL0;Jf]P2f][H0n?Sh0080C4a<00D0YjNW08Z:RP2:RXX0VYZJ08^;R`0208b<
S0030=KFeP1jNWX0NWYj0080TY:B0P2KVi/0101;Bd/0oooo0?ooo`26QXH207inOP0508n?S`2KVi/0
TY:B09:BTP2DU9@00P2UYJD00`27QhL0oooo0?ooo`080?ooo`0305YJFP1KFe/0Fe]K00@0G5aL00@0
GUiN05eMG@1MGEd0GUiN0P1LG5`01@1KFe/0FEUI05UIF@1EEED0DE5A0080Cdm?00D0DE5A05ADE01D
E5@0EeMG05]KF`0205eMG@0305aLG01KFe/0Fe]K00<0Fe]K00<0FUYJ05QHF01HF5P00P1HF5P405MG
E`<0EUIF0P1GEeL00`1JFUX0GEeM05eMG@0205eMG@80Fe]K00<0FUYJ05UIF@1IFET00P1MGEd205iN
GP0505eMG@1LG5`0G5aL05YJFP1KFe/00P1MGEd0101NGUh0HV9R069RHP1QHF4305iNGP04061PH01K
Fe/0Fe]K05]KF`80G5aL00D0GemO05iNGP1NGUh0GUiN05mOG`02061PH00305mOG`1QHF40HF5Q0080
H61P0P1OGel01@1MGEd0FUYJ05YJFP1JFUX0Fe]K0080G5aL00@0Fe]K05YJFP1JFUX0FEUI0`1JFUX0
101KFe/0GUiN05iNGP1OGel205iNGP80GemO1@1NGUh01@1MGEd0G5aL05]KF`1KFe/0G5aL0080EEEE
00<0Cdm?04i>CP1>CTh00P1>CTh2059BDP0505QHF01KFe/0Fe]K05QHF01BDU800P1@D5001@1<C4`0
B4Q804Q8B01:BTX0CTi>0080De=C00@0FEUI05aLG01LG5`0GemO0P1PH6001@1UIFD0JFUY06UYJ@1Y
JFT0J6QX0080JFUY00D0I6AT05iNGP1OGel0GemO05iNGP0505aLG00405]KF`1LG5`0G5aL05aLG0@0
Fe]K3`3oool000d0oooo00@0W9bL09jNWP2NWYh0S8b<0P3Jf]X01@1[Jf/0VIVI09ZJVP2JVYX0V9RH
0080VIVI00D0JVYZ0=OGe`3GemL0WYjN07IfMP0209^KV`0508n?S`2RXZ80XZ:R09:BTP3Cdm<00P1^
KVh409RHV080Shn?00D0Kfm_0<S8b02m_Kd0_Kfm07]kN`0209VIV@0509JFUP1hN7P0YJFU0:FUY@3D
e=@00P20P8001@29RHT0T92@09^KV`2KVi/0WYjN0080Jf][00D0g=cL096AT@2ATI40TY:B08R8R002
096AT@0509:BTP2DU9@0U9BD0=_Kf`1gMgL00P2?Shl0102IVIT0V9RH09RHV02ATI4206i^KP050?Sh
n01VIVH0VYZJ09ZJVP2;Rh/00P2WYjL01@2;Rh/0VYZJ0;Bd]02d];@0U9BD0080SXj>00D0VYZJ09nO
W`2OWil0L71`0;bl_0020:^[Z`0508V9R@2GUiL0UiNG08b<S02IVIT00P2<S8`01@31`L40T92@092@
T02ATI40SHf=0080UYJF00@0Vi^K08R8R028R8P0];Bd0P2XZ:P01@20P800V9RH09^KV`2KVi/0Ti>C
0080I6AT00D0moOg07alO02ATI40TI6A09RHV00208n?S`0506a/K03^k^h0k^k^0820P025QHD00P2W
YjL01@22PX80Xj>S0:>SX`1cLg<0Z:RX0080m_Kf00D0LW9b08F5Q@25QHD0W9bL06IVIP020:n_[`04
0=_Kf`1QHF40HF5Q0:ZZZP80RXZ:00D0V9RH08b<S026QXH0QXJ60>_[j`0206e]K@0508f=S@2HV9P0
WinO09nOW`1VIVH00P3]kNd01@2FUYH0QHF508F5Q@2=SHd0WYjN0080T92@00@0OGem0<G5a@35aLD0
MgMg2P3oool01013@d<0@4100410@00o?cl203dm?@0503/k>`0g=cL0=cLg03Lg=`0e=CD00P0i>CT0
1@0m?Cd0ADE504E5A@1BDU80Fe]K0080GemO00D0G5aL05IFEP1FEUH0CTi>04Q8B00204=3@`0404M7
A`1;Bd/0Bd];04a<C080De=C00D0FEUI05aLG01KFe/0Fe]K05YJFP0205MGE`0505ADE01@D500CDe=
04e=C@1;Bd/00P19BDT01@17AdL0ADE504M7A`17AdL0BTY:0080CTi>00D0DE5A059BDP1BDU80Cdm?
04];B`0204E5A@030492@P13@d<0@d=300@0@d=300@0ATI604M7A`17AdL0AdM70P1;Bd/504a<C080
AdM700D0@D5103dm?@0i>CT0>CTi03Ph>00203Lg=`0503/k>`0l?3`0?3`l03/k>`0l?3`00P10@403
0451@@0304M7A`1:BTX0Bd];0080Bd];0P1<C4`204Q8B080BDU90`17AdL01@19BDT0BTY:04Y:BP19
BDT0CDe=0080DE5A00<0E5AD05EEE@1EEED00P1FEUH305ADE0<0EeMG0P1HF5P01@1GEeL0EEEE05AD
E01DE5@0DE5A0080D51@00@0DE5A05=CD`1BDU80DU9B0`1FEUH01@1JFUX0EEEE05ADE01DE5@0De=C
0080E5AD00D0D51@05ADE01DE5@0DU9B051@D00204m?C`0504a<C018B4P0B4Q804E5A@13@d<00P0n
?Sh01011@D40AdM704M7A`1>CTh205=CD`0505YJFP1MGEd0FEUI05UIF@1DE5@00P1>CTh00`19BDT0
oooo0?ooo`0=0?ooo`003@3oool0102IVIT0Zj^[0:^[Z`20P8020?gmo@03051@D02IVIT0VIVI00@0
VIVI00D0OGem0<30`030`<00Shn?08^;R`020:BTY00508N7Q`2LW9`0W9bL08R8R03emOD00P1IFET3
09RHV00509VIV@2CTi<0Ti>C07UiN@2n_[h00P2VYZH01@2?Shl0Vi^K09^KV`2ATI40LW9b0080VYZJ
00D0oooo069RHP1RHV80RHV9092@T00209bLW00409^KV`1mOGd0OGem0<O7a`80Rh^;00D0WYjN08N7
Q`2EUID0UIFE08J6QP0208V9R@050?ooo`1PH600Shn?08n?S`2GUiL00P2HV9P01@2CTi<0PH610861
P@3<c<`0OWin0080VYZJ00D0SHf=0:>SX`2SXj<0MGEe0:VYZ@020<K6aP0408F5Q@2ATI40TI6A09ZJ
VP80YJFU00D0N7Qh0:n_[`2HV9P0V9RH0:6QX@0209NGU`0508V9R@2IVIT0Ogmo07moO`3Kfm/00P2>
SXh01@25QHD0SHf=09>CT`2CTi<0XZ:R0080Ti>C00D0WinO0:^[Z`2[Zj/0PH6109^KV`0209ZJVP05
09:BTP19BDT0BDU90?ooo`1YJFT00P2:RXX0102KVi/0Shn?08n?S`22PX820<_;b`0508F5Q@2DU9@0
VYZJ09ZJVP2:RXX00P2NWYh01@1MGEd0fm_K0=[JfP3Jf]X0KFe]0080QXJ600D0Y:BT07MgM`2UYJD0
YJFU0;bl_00207UiN@050:FUY@2:RXX0RXZ:09NGU`2?Shl00P1oOgl01@3oool0EUIF05IFEP2CTi<0
Vi^K0080WinO00@0OGem0<K6aP36a/H0WinO0P28R8P01@2@T900WYjN08n?S`2?Shl0J6QX0080iNGU
00<0IVIV0?ooo`3oool0203oool0101]KFd0L71`071`L01bLW8207MgM`050820P02<S8`0TI6A096A
T@2JVYX00P2HV9P01@2CTi<0QhN708N7Q`1kNg/0Lg=c0080KFe]00@0Jf][06i^KP1^KVh0LG5a0`1]
KFd0101[Jf/0IVIV06IVIP1ZJVX206ATI00505iNGP1MGEd0G5aL05aLG01FEUH00`1EEED0101OGel0
JFUY06UYJ@1]KFd207=cL`0507MgM`1eMGD0M7Ad07AdM01bLW800P1_Kfl01@1ZJVX0IVIV06IVIP1R
HV80IFEU0080JFUY00<0Kfm_071`L01`L7000P1`L70206m_K`0306][J`1]KFd0KFe]00<0KFe]0P1[
Jf/206QXJ00406ATI01RHV80HV9R06EUI@<0IfMW00@0JFUY06m_K`1_Kfl0L71`0P1_Kfl01@1dM7@0
N7Qh07AdM01dM7@0L71`0080LW9b00D0IFEU05]KF`1HF5P0F5QH05MGE`0205IFEP0505mOG`1TI6@0
IfMW06MWI`1^KVh00P1]KFd01@1[Jf/0JVYZ06YZJP1XJ6P0H61P0080E5AD00D0Bd];04M7A`17AdL0
A4A40410@00204U9B@04055AD@1?Cdl0Cdm?051@D080De=C00D0DE5A04e=C@1:BTX0BTY:04M7A`02
04Q8B00504=3@`0m?Cd0?Shn03hn?P0l?3`00P0o?cl01@15ADD0DE5A05YJFP1JFUX0GEeM0080EeMG
00D0DU9B04M7A`17AdL0?Shn03Ph>00203@d=00503De=@0k>c/0>c/k04A4A01@D5000P1MGEd0101O
Gel0G5aL05aLG01EEED2051@D00504I6AP10@400Bd];04];B`1EEED00P1MGEd00`1SHf<0oooo0?oo
o`0=0?ooo`003@3oool0102IVIT0Zj^[0:^[Z`20P8020?gmo@03051@D02IVIT0VIVI00@0VIVI00D0
OGem0<30`030`<00Shn?08^;R`020:BTY00508N7Q`2LW9`0W9bL08R8R03emOD00P1IFET309RHV005
09VIV@2CTi<0Ti>C07UiN@2n_[h00P2VYZH01@2?Shl0Vi^K09^KV`2ATI40LW9b0080VYZJ00D0oooo
069RHP1RHV80RHV9092@T00209bLW00409^KV`1mOGd0OGem0<O7a`80Rh^;00D0WYjN08N7Q`2EUID0
UIFE08J6QP0208V9R@050?ooo`1PH600Shn?08n?S`2GUiL00P2HV9P01@2CTi<0PH610861P@3<c<`0
OWin0080VYZJ00D0SHf=0:>SX`2SXj<0MGEe0:VYZ@020<K6aP0408F5Q@2ATI40TI6A09ZJVP80YJFU
00D0N7Qh0:n_[`2HV9P0V9RH0:6QX@0209NGU`0508V9R@2IVIT0Ogmo07moO`3Kfm/00P2>SXh01@25
QHD0SHf=09>CT`2CTi<0XZ:R0080Ti>C00D0WinO0:^[Z`2[Zj/0PH6109^KV`0209ZJVP0509:BTP19
BDT0BDU90?ooo`1YJFT00P2:RXX0102KVi/0Shn?08n?S`22PX820<_;b`0508F5Q@2DU9@0VYZJ09ZJ
VP2:RXX00P2NWYh01@1MGEd0fm_K0=[JfP3Jf]X0KFe]0080QXJ600D0Y:BT07MgM`2UYJD0YJFU0;bl
_00207UiN@050:FUY@2:RXX0RXZ:09NGU`2?Shl00P1oOgl01@3oool0EUIF05IFEP2CTi<0Vi^K0080
WinO00@0OGem0<K6aP36a/H0WinO0P28R8P01@2@T900WYjN08n?S`2?Shl0J6QX0080iNGU00<0IVIV
0?ooo`3oool0203oool0101]KFd0L71`071`L01bLW8207MgM`050820P02<S8`0TI6A096AT@2JVYX0
0P2HV9P01@2CTi<0QhN708N7Q`1kNg/0Lg=c0080KFe]00@0Jf][06i^KP1^KVh0LG5a0`1]KFd0101[
Jf/0IVIV06IVIP1ZJVX206ATI00505iNGP1MGEd0G5aL05aLG01FEUH00`1EEED0101OGel0JFUY06UY
J@1]KFd207=cL`0507MgM`1eMGD0M7Ad07AdM01bLW800P1_Kfl01@1ZJVX0IVIV06IVIP1RHV80IFEU
0080JFUY00<0Kfm_071`L01`L7000P1`L70206m_K`0306][J`1]KFd0KFe]00<0KFe]0P1[Jf/206QX
J00406ATI01RHV80HV9R06EUI@<0IfMW00@0JFUY06m_K`1_Kfl0L71`0P1_Kfl01@1dM7@0N7Qh07Ad
M01dM7@0L71`0080LW9b00D0IFEU05]KF`1HF5P0F5QH05MGE`0205IFEP0505mOG`1TI6@0IfMW06MW
I`1^KVh00P1]KFd01@1[Jf/0JVYZ06YZJP1XJ6P0H61P0080E5AD00D0Bd];04M7A`17AdL0A4A40410
@00204U9B@04055AD@1?Cdl0Cdm?051@D080De=C00D0DE5A04e=C@1:BTX0BTY:04M7A`0204Q8B005
04=3@`0m?Cd0?Shn03hn?P0l?3`00P0o?cl01@15ADD0DE5A05YJFP1JFUX0GEeM0080EeMG00D0DU9B
04M7A`17AdL0?Shn03Ph>00203@d=00503De=@0k>c/0>c/k04A4A01@D5000P1MGEd0101OGel0G5aL
05aLG01EEED2051@D00504I6AP10@400Bd];04];B`1EEED00P1MGEd00`1SHf<0oooo0?ooo`0=0?oo
o`003@3oool0102CTi<0[jn_0:n_[`28R8P20?ooo`0403`l?02FUYH0W9bL09bLW0<0VIVI00D0RHV9
0:j^[P2^[Zh0NWYj0:j^[P020;:b/P05071`L02ATI40TI6A0861P@3oool00P1;Bd/0102@T900VYZJ
09ZJVP2KVi/209NGU`0507moO`2f][H0UYJF09JFUP2KVi/00P2EUID01@2FUYH0K6a/09BDU02DU9@0
oooo0080?Shn00D0Rh^;09JFUP2GUiL0UiNG09nOW`0208b<S0050;6a/@2;Rh/0Rh^;09bLW02=SHd0
0P2HV9P01@1oOgl0NGUi07UiN@3oool0A4A40080TI6A00@0VIVI09NGU`2GUiL0U9BD0P2?Shl01@2[
Zj/0Ti>C09BDU02DU9@0TI6A0080XZ:R00D0Fe]K0;Bd]03MgMd0gMgM07]kN`0209:BTP0509RHV02V
YZH0YZJV08J6QP2JVYX00P2CTi<01@2`/;00VIVI09VIV@25QHD0UiNG0080MWIf00D0lO7a08j>SP2>
SXh0N7Qh08f=S@0209:BTP040:FUY@2KVi/0Vi^K09RHV080Xj>S00D0QXJ609jNWP2JVYX0VYZJ096A
T@0202/[:`050?ooo`1IFET0Ph>308>3P`2KVi/00`2CTi<20:b/[00508V9R@2PX:00Shn?08n?S`2F
UYH00P2DU9@01@14A4@0oooo0;bl_02l_;`0KFe]0080Q8B400D0[Jf]08B4Q02QXJ40XJ6Q09ZJVP02
09>CT`0509fMW@2?Shl0Shn?09BDU02CTi<00P1`L7001@3oool0AdM704M7A`2EUID0W9bL0080X:2P
00@0T92@0:JVYP2VYZH0Z:RX0P29RHT01@2CTi<0WYjN08n?S`2?Shl0EUIF0080oooo00<0EEEE0?oo
o`3oool0203oool0101oOgl0P8200820P022PX8208B4Q00507emO@1eMGD0KVi^06i^KP1SHf<00P1N
GUh01@1PH600IVIV06IVIP1/K6`0LG5a0080MgMg00D0Ng]k07moO`1oOgl0Q8B408f=S@0209:BTP04
09JFUP2HV9P0V9RH09BDU0<0Ti>C0`2BTY801@2JVYX0WinO09nOW`2OWil0W9bL0080U9BD00D0T92@
08b<S02<S8`0RXZ:08V9R@0208N7Q`0408F5Q@28R8P0R8R808^;R`80S8b<00D0T92@096AT@2:RXX0
RXZ:08F5Q@0208J6QP0508V9R@2;Rh/0TY:B09:BTP2HV9P00P2FUYH01@2GUiL0V9RH09RHV02HV9P0
UiNG0080WIfM00D0W9bL09^KV`2KVi/0VIVI09NGU`0209FEU@0409BDU02BTY80TY:B08f=S@80RXZ:
00D0Q8B40820P021PH40PH6108>3P`0208F5Q@0508b<S02FUYH0Vi^K09^KV`2PX:000P2TY:@01@2U
YJD0WIfM09RHV02HV9P0Ti>C0080TI6A0`2>SXh01@2?Shl0TY:B09>CT`2CTi<0VIVI0080WYjN00D0
YJFU0;6a/@2f][H0][Jf0;:b/P020;>c/`050;Fe]@2_[jl0[jn_0;Bd]02m_Kd00P37alL01@31`L40
]kNg0;Ng]`2h^;P0^[Zj0080]KFe00D0_Kfm0<;2`P32`/80]kNg0:b/[0020:2PX00409^KV`2OWil0
WinO0:NWY`80/K6a00D0^k^k0<G5a@3>c/h0c/k>0=3@d0030<k>cP040<G5a@2j^[X0^[Zj0;Bd]080
[jn_00D0ZZZZ0:VYZ@2YZJT0[:b/0:RXZ00209fMW@0409:BTP27QhL0QhN70861P@l0oooo000=0?oo
o`0408^;R`2/[:`0[:b/09>CT`80oooo00D0:b/[09>CT`2PX:00X:2P09bLW002096AT@0509^KV`2G
UiL0UiNG075aL@31`L400P2i^KT307EeM@0408R8R03oool0?3`l03`l?0@0V9RH0P2LW9`01@2:RXX0
XJ6Q08f=S@2=SHd0[Zj^0080SHf=00D0W9bL06MWI`2IVIT0VIVI0?ooo`0202<S8`0508R8R02LW9`0
UIFE09FEU@2QXJ400P2FUYH309^KV`0508n?S`2IVIT0VIVI09VIV@1mOGd00P1]KFd01@3oool0<c<c
09:BTP2BTY80XJ6Q0080TI6A00D0UIFE09ZJVP2JVYX0U9BD09jNWP02092@T00509NGU`2SXj<0Xj>S
04i>CP2j^[X00P3Rh^80101gMgL0V9RH09RHV02FUYH20:b/[00508>3P`2BTY80VIVI09VIV@2b/[80
0P2ATI401@2>SXh0UIFE06e]K@1]KFd0oooo0080Q8B400D0L71`09FEU@2:RXX0RXZ:0:RXZ00209jN
WP0509fMW@2ATI40TI6A096AT@2NWYh00P2KVi/01@2<S8`06QXJ01XJ6P3oool0HF5Q0080MWIf00@0
VIVI09JFUP2FUYH0WIfM0`2EUID0102PX:00Rh^;08^;R`2NWYh208n?S`0503Ph>03oool0ZZZZ0:ZZ
ZP1ZJVX00P25QHD01@2YZJT0V9RH09BDU02DU9@0TI6A0080V9RH00D0U9BD09bLW02LW9`0SXj>092@
T00207MgM`050?ooo`19BDT0BDU909JFUP2KVi/00P2TY:@0102BTY80VIVI09VIV@2OWil209>CT`05
09VIV@2JVYX0RXZ:08Z:RP17AdL00P3oool00`0j>SX0oooo0?ooo`080?ooo`04059BDP1?Cdl0Cdm?
04];B`80AdM700D0ATI603lo?`11@D40@D510492@P0204E5A@050451@@0l?3`0?3`l03Ti>@0h>3P0
0P0j>SX303lo?`0403hn?P0m?Cd0=cLg03Lg=`<0<c<c0`0a<C400`0d=3@0<c<c03<c<`0203<c<`80
=3@d00D0=cLg03De=@0h>3P0>3Ph03Xj>P0203Ph>00503@d=00f=SH0=SHf03Hf=P0g=cL00`0e=CD2
03Xj>P0503hn?P0o?cl0AdM704M7A`1<C4`00P19BDT01@13@d<0@41003Hf=P0f=SH0;Bd]0080:BTY
00@0:2PX02HV9P0V9RH09RHV0`0X:2P01@0_;bl0>CTi03Ti>@0n?Sh0?clo0080@d=300@0?Shn03De
=@0e=CD0<30`0`0];Bd0100[:b/0;bl_02l_;`0e=CD203Ti>@0503dm?@0k>c/0>CTi03Ti>@0f=SH0
0P0c<c<402/[:`0402XZ:P0[:b/0:b/[02l_;`80<c<c00D0=SHf03Lg=`11@D40@D510492@P0203lo
?`0503Ti>@0a<C4092@T02@T900N7Qh00`0M7Ad201lO7`0501`L700I6AT05QHF01HF5P0R8R800P0b
<S801@0k>c/0?3`l03/k>`0k>c/0;Bd]00807AdM00D05aLG01/K6`0R8R808R8R02PX:00202/[:`<0
;Bd]00<0;2`/02TY:@0U9BD0100U9BD00`0Q8B407alO020P8004020P800502@T900V9RH09RHV02HV
9P0];Bd00P0d=3@0100n?Sh0ATI604I6AP1=CDd?0?ooo`003@3oool0102;Rh/0[:b/0:b/[02CTi<2
0?ooo`0502/[:`2CTi<0X:2P0:2PX02LW9`00P2ATI401@2KVi/0UiNG09NGU`1aLG40`L710080^KVi
0`1eMGD01028R8P0oooo03`l?00l?3`409RHV080W9bL00D0RXZ:0:6QX@2=SHd0SHf=0:j^[P0208f=
S@0509bLW01WIfL0VIVI09VIV@3oool00P0S8b<01@28R8P0W9bL09FEU@2EUID0XJ6Q0080UYJF0`2K
Vi/01@2?Shl0VIVI09VIV@2IVIT0OGem0080KFe]00D0oooo03<c<`2BTY80TY:B0:6QX@02096AT@05
09FEU@2JVYX0VYZJ09BDU02NWYh00P2@T9001@2GUiL0Xj>S0:>SX`1>CTh0^[Zj0080h^;R00@0MgMg
09RHV02HV9P0UYJF0P2/[:`01@23Ph<0TY:B09VIV@2IVIT0/[:b0080TI6A00D0SXj>09FEU@1]KFd0
KFe]0?ooo`0208B4Q005071`L02EUID0RXZ:08Z:RP2XZ:P00P2NWYh01@2MWId0TI6A096AT@2ATI40
WYjN0080Vi^K00D0S8b<01XJ6P0J6QX0oooo065QH@0207IfMP0409VIV@2FUYH0UYJF09fMW@<0UIFE
00@0X:2P08^;R`2;Rh/0WYjN0P2?Shl01@0h>3P0oooo0:ZZZP2ZZZX0JVYZ0080QHF500D0ZJVY09RH
V02DU9@0U9BD096AT@0209RHV00509BDU02LW9`0W9bL08j>SP2@T9000P1gMgL01@3oool0BDU904U9
B@2FUYH0Vi^K0080Y:BT00@0TY:B09VIV@2IVIT0WinO0P2CTi<01@2IVIT0VYZJ08Z:RP2:RXX0AdM7
0080oooo00<0>SXj0?ooo`3oool0203oool0101BDU80Cdm?04m?C`1;Bd/204M7A`0504I6AP0o?cl0
@D510451@@12@T800P15ADD01@11@D40?3`l03`l?00i>CT0>3Ph0080>SXj0`0o?cl0100n?Sh0?Cdm
03Lg=`0g=cL303<c<`<0<C4a00<0=3@d03<c<`0c<c<00P0c<c<203@d=00503Lg=`0e=CD0>3Ph03Ph
>00j>SX00P0h>3P01@0d=3@0=SHf03Hf=P0f=SH0=cLg00<0=CDe0P0j>SX01@0n?Sh0?clo04M7A`17
AdL0C4a<0080BDU900D0@d=30410@00f=SH0=SHf02d];@0202TY:@0402PX:00V9RH09RHV02HV9P<0
:2PX00D0;bl_03Ti>@0i>CT0?Shn03lo?`0204=3@`0403hn?P0e=CD0=CDe030`<0<0;Bd]00@0:b/[
02l_;`0_;bl0=CDe0P0i>CT01@0m?Cd0>c/k03Ti>@0i>CT0=SHf0080<c<c100[:b/0100Z:RX0:b/[
02/[:`0_;bl203<c<`0503Hf=P0g=cL0@D510451@@12@T800P0o?cl01@0i>CT0<C4a02@T900T92@0
7QhN00<07AdM0P0O7al01@0L71`06ATI01HF5P0F5QH08R8R0080<S8b00D0>c/k03`l?00k>c/0>c/k
02d];@0201dM7@0501LG5`0K6a/08R8R028R8P0X:2P00P0[:b/302d];@0302`/;00Y:BT09BDU00@0
9BDU00<08B4Q01lO7`0P8200100P82001@0T92@09RHV02HV9P0V9RH0;Bd]0080=3@d00@0?Shn04I6
AP16ATH0CDe=3`3oool000d0oooo00@0TY:B0:^[Z`2[Zj/0TI6A0P3oool01@0k>c/0Rh^;0:n_[`2_
[jl0VYZJ0080Rh^;00D0XJ6Q09RHV02HV9P0L71`0;Jf]P020<K6aP0507alO01cLg<0Lg=c08n?S`3o
ool00P15ADD0102DU9@0WinO09nOW`2HV9P20:6QX@0508V9R@2MWId0S8b<08b<S02VYZH00P2CTi<0
1@2TY:@0KFe]09JFUP2FUYH0oooo008092@T00D0UIFE0:FUY@2CTi<0Ti>C09jNWP0209FEU@0509bL
W02FUYH0UYJF08^;R`2UYJD00P2OWil01@1jNWX0K6a/06a/K03oool0@T920080QHF500@0Zj^[0:>S
X`2SXj<0RHV90P2IVIT01@2DU9@0WYjN08J6QP26QXH0Z:RX0080XZ:R00D0De=C0;Bd]03EeMD0eMGE
07UiN@0209BDU0050:FUY@2XZ:P0Z:RX07inOP2HV9P00P2IVIT01@2UYJD0U9BD09BDU02QXJ40T92@
0080KVi^00D0n_[j08:2PP22PX80MWIf08b<S0020:2PX00409VIV@2MWId0WIfM0:>SX`80SHf=00D0
TI6A09>CT`2`/;00/;2`08f=S@02028R8P050?ooo`1QHF40MWIf07IfMP2SXj<00P2EUID01@2KVi/0
Ti>C09>CT`2BTY80YJFU0080Ph>300D0[Zj^08b<S02<S8`0<30`0?ooo`020;>c/`0505mOG`28R8P0
R8R80:f][@2LW9`00P2?Shl0102FUYH0U9BD09BDU02CTi<20::RXP80TY:B0P1`L7001@3oool0DU9B
059BDP2>SXh0YJFU0080Y:BT00@0SXj>09^KV`2KVi/0UiNG0P2EUID01@2JVYX0Xj>S08R8R028R8P0
BDU90080oooo00<0B4Q80?ooo`3oool0203oool0101JFUX0Fe]K05]KF`1LG5`205YJFP0405eMG@1P
H600HV9R069RHP<0I6AT00<0IFEU06MWI`1WIfL00P1ZJVX206QXJ00506MWI`1SHf<0Hf=S05iNGP1K
Fe/00P1MGEd305aLG00305]KF`1JFUX0FUYJ0080FUYJ0`1HF5P205MGE`0505QHF01IFET0Fe]K05]K
F`1LG5`00`1PH6000`1QHF40Hf=S06=SH`0406ATI080H61P00@0G5aL05]KF`1GEeL0EeMG0`1EEED0
1@1FEUH0EEEE05QHF01HF5P0G5aL0080GUiN00D0GemO061PH01PH600H61P05mOG`02061PH00405eM
G@1HF5P0F5QH05EEE@<0EUIF00@0FUYJ065QH@1QHF40IfMW0`1YJFT0101XJ6P0IFEU06EUI@1OGel2
05]KF`0305UIF@1JFUX0Fe]K0080Fe]K0P1LG5`01@1PH600Hf=S069RHP1RHV80Hf=S0080I6AT00D0
HV9R05iNGP1NGUh0H61P065QH@02061PH00305iNGP1OGel0GemO0080H61P0P1RHV8306=SH`<0HV9R
0P1SHf<2065QH@0305mOG`1HF5P0F5QH0080DU9B0P1HF5P00`1NGUh0IFEU06EUI@0206a/K080IfMW
00@0Hf=S065QH@1QHF40H61P0`1MGEd00`1KFe/0FUYJ05YJFP0405QHF00405YJFP1KFe/0Fe]K05aL
G080GemO101PH600101RHV80H61P061PH01NGUh2061PH00305aLG03oool0oooo00d0oooo000=0?oo
o`040:b/[02BTY80TY:B0:6QX@80emOG00D0F5QH071`L03Bd]80d];B09NGU`0208B4Q0050:FUY@2I
VIT0VIVI06UYJ@2NWYh00P3Xj>P01@2:RXX0JFUY06UYJ@2=SHd0lo?c0080GUiN00@0N7Qh0;bl_02l
_;`0XJ6Q0P2CTi<01@2:RXX0WYjN08V9R@29RHT0TY:B0080YjNW00D0/K6a07IfMP28R8P0R8R80?oo
o`020451@@0507IfMP3>c/h0SHf=08f=S@2@T9000P2IVIT01@2LW9`0RXZ:08Z:RP21PH40b<S80080
Vi^K00D0MGEe07MgM`1gMgL0oooo05ADE002071`L0040=;BdP2XZ:P0Z:RX07EeM@80U9BD00D0Vi^K
0:BTY01[Jf/0Jf][0<[:bP020:>SX`0505MGE`2ZZZX0_Kfm0;fm_@27QhL00P1mOGd01@3@d=00UiNG
09NGU`1kNg/0WIfM0080Vi^K00D0UIFE07]kN`1kNg/0i>CT07UiN@0207=cL`050=cLg02:RXX0RXZ:
07inOP1WIfL00P3QhN401025QHD0T92@092@T02TY:@208f=S@0508n?S`1iNGT0iNGU0>GUi@1hN7P0
0P15ADD01@3oool0KVi^07UiN@1iNGT0Z:RX0080ZZZZ00D0QhN709NGU`2GUiL0TI6A0:FUY@0206UY
J@050=WIf@22PX80PX:204a<C03oool00P2TY:@01@1IFET0Rh^;08^;R`3Rh^80R8R80080Q8B400@0
UiNG09BDU02DU9@0Ogmo0P2`/;001@2i^KT0MWIf07MgM`1gMgL0m?Cd0080HF5Q00D0P8200;jn_P2R
XZ80XZ:R096AT@0209:BTP0509RHV02=SHd0SHf=08J6QP3IfMT00P1`L700101OGel0l_;b0?;blP1T
I6@:0?ooo`04059BDP1@D500D51@04a<C080B4Q800D0?clo03dm?@0j>SX0>SXj03Ph>00203Ti>@05
0492@P16ATH0ATI604M7A`19BDT00P1:BTX00`15ADD0@T920492@P0404A4A00404=3@`14A4@0A4A4
04Q8B080CDe=0P1<C4`204e=C@0504Y:BP19BDT0BDU904m?C`1>CTh00P1=CDd01@1?Cdl0CTi>04i>
CP1;Bd/0BDU90080AdM700<0@D510410@010@4000`0o?cl01@10@400A4A404Y:BP1:BTX0C4a<0080
D51@00D0DU9B05=CD`1<C4`0C4a<04e=C@0204];B`0504U9B@17AdL0AdM704A4A011@D400P0m?Cd0
1@0n?Sh0ADE504E5A@17AdL0B4Q80080BDU900@0AdM704A4A014A4@0A4A40P19BDT01@1@D500EeMG
05IFEP1FEUH0FEUI0080EeMG00@0F5QH05MGE`1GEeL0EeMG0`1FEUH01@1@D500CDe=04m?C`1?Cdl0
CTi>0080Bd];00D0C4a<04];B`1;Bd/0B4Q804M7A`0204a<C00504U9B@18B4P0B4Q804M7A`19BDT0
0`13@d<20410@00403hn?P0i>CT0>CTi03Hf=P<0<c<c00D0=CDe03Xj>P0j>SX0@D5104];B`0205=C
D`0305IFEP1JFUX0FUYJ0080FUYJ1@1IFET01@1HF5P0De=C05=CD`1CDe<0DU9B0080Cdm?00<0CTi>
055AD@1ADE40101>CTh0101?Cdl0D51@051@D01BDU8305ADE004059BDP1ADE40DE5A051@D080Cdm?
00<0De=C0?ooo`3oool03@3oool000d0oooo00@0alO707MgM`1gMgL0Zj^[0P2j^[X01@1^KVh0EeMG
0>SXj03Xj>P0[Zj^0080JFUY00D0[jn_09FEU@2EUID0M7Ad07QhN0020?gmo@0509nOW`1MGEd0GEeM
09FEU@3@d=000P1fMWH0101UIFD0d=3@0=3@d02^[Zh208:2PP0508V9R@2KVi/0SXj>08j>SP21PH40
0P2g]kL01@2m_Kd0OWin07emO@1mOGd0lo?c0080GEeM00D0I6AT0>[ZjP28R8P0R8R808V9R@0209JF
UP050::RXP20P800P82007AdM03UiND00P2NWYh01@1fMWH0NWYj07YjNP3Vi^H0KVi^0080Fe]K00@0
l_;b0:j^[P2^[Zh0IFEU0P2@T9001@2OWil0Xj>S05QHF01HF5P0j^[Z0080YjNW00D0F5QH0:6QX@2/
[:`0[:b/09FEU@0206ATI0050?gmo@27QhL0QhN707MgM`2MWId00P2LW9`01@2:RXX0Hf=S06=SH`3o
ool0JFUY0080NGUi00D0a<C408j>SP2>SXh0QXJ604I6AP020?ooo`0406][J`20P800P8200:VYZ@80
Shn?00D0Rh^;069RHP3oool0oooo06UYJ@0205iNGP050>o_k`1mOGd0NWYj07YjNP2`/;000P2m_Kd0
1@1cLg<0VIVI09VIV@2DU9@0XJ6Q0080CDe=00D0oooo07emO@1mOGd0Hf=S0=OGe`020:2PX00505mO
G`2:RXX0RXZ:0?ooo`1SHf<00P27QhL0102GUiL0UIFE09FEU@1ZJVX20<[:bP050<C4a01TI6@0RHV9
08V9R@3Cdm<00P1bLW801@1XJ6P0iNGU09ZJVP2JVYX0SXj>0080Shn?00D0V9RH08j>SP2>SXh0J6QX
0?ooo`0205UIF@0407=cL`2o_kl0_kno0820P0X0oooo00<0Fe]K069RHP1RHV800`1YJFT01@1VIVH0
H61P069RHP1RHV80I6AT0080IVIV00D0IFEU05mOG`1OGel0F5QH05ADE00205IFEP0505]KF`1RHV80
HV9R06UYJ@1[Jf/00P1VIVH0101LG5`0EeMG05MGE`1@D50204a<C005055AD@1CDe<0E5AD05ADE01H
F5P00P1OGel01@1NGUh0GemO05UIF@1IFET0CTi>0080@d=300D0?Cdm0410@018B4P0B4Q805MGE`02
05UIF@0505YJFP1KFe/0Fe]K05mOG`1QHF400P1/K6`306m_K`0506IVIP1IFET0D51@051@D01=CDd0
0P1;Bd/01@1?Cdl0FEUI05UIF@1IFET0G5aL0080HV9R00D0J6QX06i^KP1^KVh0Ng]k08J6QP0208N7
Q`0408R8R027QhL0QhN708>3P`80OGem00D0OWin07QhN01cLg<0Lg=c071`L002075aL@0506m_K`1/
K6`0IfMW06MWI`1RHV800P1BDU800`1=CDd0CTi>051@D002051@D080F5QH00D0EeMG051@D01@D500
C4a<04m?C`0205ADE00505mOG`1WIfL0IfMW06UYJ@1UIFD00P1SHf<0101NGUh0HF5Q065QH@1UIFD2
06e]K@0506a/K01^KVh0L71`071`L01eMGD00P1aLG401@1XJ6P0E5AD0410@010@400:b/[00807QhN
0P0H61P301/K6`806ATI00D07AdM02TY:@0Y:BT0<S8b03Ti>@020410@0050451@@0j>SX0>SXj03Lg
=`0f=SH00P0g=cL0100j>SX0>3Ph03Ph>00c<c<2038b<P0503<c<`0l?3`0@4100410@016ATH00P1=
CDd00`1GEeL0oooo0?ooo`0=0?ooo`003@3oool01037alL0MgMg07MgM`2[Zj/20;Zj^P0506i^KP1G
EeL0j>SX0>SXj02^[Zh00P1YJFT01@2_[jl0UIFE09FEU@1dM7@0N7Qh0080oOgm00D0WinO05eMG@1M
GEd0UIFE0=3@d00207IfMP0406EUI@3@d=00d=3@0:j^[P80PX:200D0RHV909^KV`2>SXh0SXj>0861
P@020;Ng]`050;fm_@1nOWh0OGem07emO@3clo<00P1MGEd01@1TI6@0j^[Z08R8R028R8P0RHV90080
UYJF00D0XZ:R0820P020P800M7Ad0>GUi@0209jNWP0507IfMP1jNWX0NWYj0>KViP1^KVh00P1KFe/0
103bl_80[Zj^0:j^[P1UIFD2092@T00509nOW`2SXj<0F5QH05QHF03Zj^X00P2WYjL01@1HF5P0XJ6Q
0:b/[02/[:`0UIFE0080I6AT00D0oOgm08N7Q`27QhL0MgMg09fMW@0209bLW00508Z:RP1SHf<0Hf=S
0?ooo`1YJFT00P1iNGT01@34a<@0SXj>08j>SP26QXH0ATI60080oooo00@0Jf][0820P020P800ZJVY
0P2?Shl01@2;Rh/0HV9R0?ooo`3oool0JFUY0080GUiN00D0kno_07emO@1jNWX0NWYj0;2`/0020;fm
_@0507=cL`2IVIT0VIVI09BDU02QXJ400P1=CDd01@3oool0OGem07emO@1SHf<0emOG0080X:2P00D0
GemO08Z:RP2:RXX0oooo06=SH`0208N7Q`0409NGU`2EUID0UIFE06YZJP80b/[:00D0a<C406ATI029
RHT0RHV90=?Cd`02079bLP0506QXJ03UiND0VYZJ09ZJVP2>SXh00P2?Shl01@2HV9P0SXj>08j>SP1X
J6P0oooo0080FEUI00@0Lg=c0;no_`2o_kl0P8202P3oool00`1KFe/0HV9R069RHP0306UYJ@0506IV
IP1PH600HV9R069RHP1TI6@00P1VIVH01@1UIFD0GemO05mOG`1HF5P0E5AD0080EUIF00D0Fe]K069R
HP1RHV80JFUY06][J`0206IVIP0405aLG01GEeL0EeMG051@D080C4a<00D0DE5A05=CD`1DE5@0E5AD
05QHF00205mOG`0505iNGP1OGel0FEUI05UIF@1>CTh00P13@d<01@0m?Cd0@41004Q8B018B4P0EeMG
0080FEUI00D0FUYJ05]KF`1KFe/0GemO065QH@0206a/K0<0Kfm_00D0IVIV05UIF@1@D500D51@04e=
C@0204];B`0504m?C`1IFET0FEUI05UIF@1LG5`00P1RHV801@1XJ6P0KVi^06i^KP1kNg/0QXJ60080
QhN700@0R8R808N7Q`27QhL0Ph>30P1mOGd01@1nOWh0N7Qh07=cL`1cLg<0L71`0080LG5a00D0Kfm_
06a/K01WIfL0IfMW069RHP02059BDP0304e=C@1>CTh0D51@0080D51@0P1HF5P01@1GEeL0D51@051@
D01<C4`0Cdm?0080E5AD00D0GemO06MWI`1WIfL0JFUY06EUI@0206=SH`0405iNGP1QHF40HF5Q06EU
I@80KFe]00D0K6a/06i^KP1`L700L71`07EeM@02075aL@0506QXJ01DE5@0@4100410@00[:b/00P0N
7Qh201PH60<06a/K0P0I6AT01@0M7Ad0:BTY02TY:@0b<S80>CTi0080@41000D0@D5103Xj>P0j>SX0
=cLg03Hf=P0203Lg=`0403Xj>P0h>3P0>3Ph03<c<`80<S8b00D0<c<c03`l?010@400@41004I6AP02
04e=C@0305MGE`3oool0oooo00d0oooo000=0?ooo`040>7Qh@1TI6@0I6AT0:FUY@80Z:RX00D0P820
03hn?P3oool0oooo0;Jf]P0205ADE0050;no_`2CTi<0Ti>C07moO`17AdL00P3oool01@2a/K40DU9B
059BDP2LW9`0/;2`0080T92@00@0Bd];0>_[j`3[jn/0];Bd0P1aLG401@2@T900VIVI08^;R`2;Rh/0
N7Qh0080alO700D0_kno08F5Q@1nOWh0OWin0<W9b@020820P00505=CD`3oool0Ph>308>3P`1mOGd0
0P2HV9P01@2OWil0OGem07emO@1TI6@0oooo0080W9bL00D0LW9b08N7Q`27QhL0/;2`09BDU00204=3
@`040?ooo`2c/k<0/k>c05QHF080SHf=00D0WinO0:RXZ011@D40@D510?ooo`020:RXZ00505iNGP2L
W9`0UiNG09NGU`2IVIT00P1?Cdl01@3oool0N7Qh07QhN01_Kfl0XJ6Q0080VYZJ00D0PX:204M7A`17
AdL0oooo05UIF@020820P0050:ZZZP2CTi<0Ti>C096AT@0S8b<00P3oool0101BDU80MgMg07MgM`2T
Y:@209JFUP0508N7Q`17AdL0oooo0?ooo`1IFET00P1iNGT01@2g]kL0U9BD07EeM@1eMGD0^k^k0080
b/[:00D0I6AT09NGU`2GUiL0V9RH09^KV`0203Lg=`050?ooo`1aLG40LG5a07QhN02`/;000P2NWYh0
1@1PH600TI6A096AT@3oool0AdM70080QhN700@0W9bL09:BTP2BTY80FEUI0P3Ng]h01@3Cdm<0DU9B
09^KV`2KVi/0/K6a0080PX:200D0Bd];0?ooo`2>SXh0SXj>08b<S00208^;R`0509FEU@23Ph<0Ph>3
06e]K@3oool00P0n?Sh01022PX80Ti>C09>CT`2IVIT:0?ooo`0408b<S029RHT0RHV908f=S@80Shn?
00D0UYJF09jNWP2LW9`0W9bL09RHV00209VIV@0509NGU`2DU9@0U9BD09FEU@2FUYH00P2CTi<01@2>
SXh0Shn?08n?S`2?Shl0RHV90080RXZ:00@0Vi^K0::RXP2RXZ80Y:BT0P2ZZZX01@2WYjL0W9bL09FE
U@2EUID0TI6A0080RXZ:00D0PH6108>3P`2@T900T92@09JFUP020:>SX`050;Ng]`2j^[X0/[:b0;:b
/P2_[jl00P2][Jd01@2TY:@0X:2P0:2PX02HV9P0Shn?0080OGem00D0OWin07alO01lO7`0PH61096A
T@020:BTY0040:ZZZP2][Jd0[Jf]0:j^[P80YZJV00D0XJ6Q09bLW02OWil0WinO09VIV@0208j>SP05
08F5Q@1nOWh0M7Ad07AdM01fMWH00P1lO7`01@23Ph<0QHF508F5Q@27QhL0S8b<0080R8R800D0QXJ6
08>3P`23Ph<0PX:20861P@0208j>SP0409RHV02NWYh0WYjN0:JVYP<0YjNW00@0YZJV0:VYZ@2YZJT0
Zj^[0P2ZZZX01@2YZJT0XZ:R09BDU02DU9@0RHV90080QXJ600D0Ph>308R8R02DU9@0U9BD09bLW002
09jNWP050:6QX@2RXZ80XZ:R0:2PX02OWil00P2NWYh309>CT`0509jNWP2WYjL0ZZZZ0:ZZZP2o_kl0
0P3>c/h01@3IfMT0h^;R0?3`l03`l?00j^[Z0080g]kN00D0f=SH0<g=c@3=cLd0`l?30<C4a0020<W9
b@050<71`@30`<00`<300<;2`P34a<@00P32`/801037alL0c<c<0<c<c038b<P20<O7a`050<S8b030
`<00^KVi0;Vi^@2e]KD00P2XZ:P00`2GUiL0oooo0?ooo`0=0?ooo`003P3oool205EEE@0509bLW02J
VYX0VYZJ08n?S`0_;bl00P3oool01039bLT0CDe=04e=C@2l_;`208b<S00508F5Q@0Q8B40oooo0?oo
o`2o_kl00P16ATH01@2NWYh0VYZJ0:FUY@2UYJD0;Bd]0080nOWi00D0e=CD05YJFP1JFUX0Rh^;09nO
W`0209:BTP05061PH03Ng]h0g]kN0;no_`23Ph<00P1eMGD01@2e]KD0WinO09nOW`0m?Cd0oooo0080
NWYj00@0O7al09FEU@2EUID0Vi^K0P1eMGD01@1HF5P0oooo0:RXZ02XZ:P0GemO00<0SXj>00@0/;2`
03De=@0e=CD0oooo0P2j^[X01@1=CDd0Rh^;08^;R`2QXJ40YjNW0080=cLg00D0oooo0:FUY@2UYJD0
EUIF09jNWP0209NGU`0409BDU00m?Cd0?Cdm0?ooo`80KFe]00D0KVi^0:2PX02GUiL0UiNG07UiN@02
03lo?`050?ooo`19BDT0Ogmo07moO`2JVYX00P2MWId01@2EUID010@40?ooo`3oool0>SXj0080M7Ad
0`2LW9`01@22PX80<c<c0?ooo`3oool0GEeM0080RHV900D0W9bL08^;R`1eMGD0MGEe0<G5a@020=kN
gP0505EEE@2BTY80TY:B09ZJVP2MWId00P0c<c<01@3oool0JFUY06UYJ@29RHT0Ti>C0080VIVI00D0
H61P09nOW`2OWil0oooo02l_;`0208N7Q`040:2PX02BTY80TY:B04E5A@80lo?c00D0h>3P04Y:BP2I
VIT0VIVI09nOW`0208^;R`05034a<@3oool0S8b<08b<S01lO7`00P2<S8`01@2CTi<0P8200820P01X
J6P0oooo00809bLW00@0TI6A06IVIP1VIVH0Zj^[2P3oool01010@400?3`l03`l?00c<c<203Ph>005
03De=@0h>3P0>c/k03/k>`0n?Sh00P0j>SX01@0o?cl0ATI604I6AP1:BTX0BDU90080B4Q800D0AdM7
03/k>`0k>c/0<c<c03/k>`020410@00403/k>`0j>SX0>SXj03`l?080<c<c00D0<C4a03Xj>P11@D40
@D5104A4A00204U9B@05051@D01<C4`0@d=304=3@`16ATH00P12@T80100d=3@0;bl_030`<00`<303
02LW9`0503<c<`0j>SX0>SXj0451@@18B4P00P1;Bd/01@16ATH0ADE504E5A@19BDT0ADE50080@410
00@0?Cdm03hn?P0n?Sh0>SXj0P0i>CT01@11@D40A4A403`l?00l?3`0>3Ph0080>CTi00<0=CDe030`
<00g=cL00P0g=cL203Hf=P0503<c<`0b<S80<S8b02/[:`0Y:BT00P0h>3P00`0m?Cd0?clo03lo?`02
0410@080<30`00D0:RXZ038b<P0b<S80=CDe03@d=00203<c<`0403Hf=P0];Bd0;Bd]02/[:`80=CDe
00D0>CTi03lo?`12@T80@T9204A4A00303dm?@0303Ti>@0f=SH0=SHf00<0=CDe00D0=3@d038b<P0b
<S80=SHf03De=@0203@d=00503<c<`0`<300<30`02TY:@0[:b/00`0f=SH2030`<00502XZ:P0Q8B40
4A4A014A4@0F5QH00P0/;2`01@0b<S80=SHf03Hf=P0g=cL0<C4a008092@T00D0:b/[03<c<`0c<c<0
=cLg03<c<`02030`<00402PX:00S8b<08b<S02`/;080;bl_00D0;Rh^02l_;`0c<c<0<c<c038b<P02
03De=@0303Xj>P3oool0oooo00d0oooo000>0?ooo`80EEEE00D0W9bL09ZJVP2JVYX0Shn?02l_;`02
0?ooo`040<W9b@1=CDd0CDe=0;bl_080S8b<00D0QHF5024Q8@3oool0oooo0;no_`0204I6AP0509jN
WP2JVYX0YJFU0:FUY@0];Bd00P3inOT01@3De=@0FUYJ05YJFP2;Rh/0WinO0080TY:B00D0H61P0=kN
gP3Ng]h0_kno08>3P`0207EeM@050;Fe]@2OWil0WinO03dm?@3oool00P1jNWX0101lO7`0UIFE09FE
U@2KVi/207EeM@0505QHF03oool0Z:RX0:RXZ01OGel00`2>SXh0102`/;00=CDe03De=@3oool20;Zj
^P0504e=C@2;Rh/0Rh^;0:6QX@2WYjL00P0g=cL01@3oool0YJFU0:FUY@1FEUH0WYjN0080UiNG00@0
U9BD03dm?@0m?Cd0oooo0P1]KFd01@1^KVh0X:2P09NGU`2GUiL0NGUi0080?clo00D0oooo04U9B@1o
Ogl0Ogmo09ZJVP0209fMW@0509FEU@0410@0oooo0?ooo`0j>SX00P1dM7@309bLW00508:2PP0c<c<0
oooo0?ooo`1MGEd00P29RHT01@2LW9`0Rh^;07EeM@1eMGD0aLG50080g]kN00D0EEEE09:BTP2BTY80
VYZJ09fMW@0203<c<`050?ooo`1YJFT0JFUY08V9R@2CTi<00P2IVIT01@1PH600WinO09nOW`3oool0
;bl_0080QhN700@0X:2P09:BTP2BTY80ADE50P3clo<01@3Ph>00BTY:09VIV@2IVIT0WinO0080Rh^;
00D0<C4a0?ooo`2<S8`0S8b<07alO00208b<S00509>CT`20P800P82006QXJ03oool00P0W9bL0102A
TI40IVIV06IVIP2[Zj/:0?ooo`040410@00l?3`0?3`l03<c<`80>3Ph00D0=CDe03Ph>00k>c/0>c/k
03hn?P0203Xj>P0503lo?`16ATH0ATI604Y:BP19BDT00P18B4P01@17AdL0>c/k03/k>`0c<c<0>c/k
0080@41000@0>c/k03Xj>P0j>SX0?3`l0P0c<c<01@0a<C40>SXj0451@@11@D40A4A40080BDU900D0
D51@04a<C013@d<0@d=304I6AP020492@P0403@d=00_;bl0<30`030`<0<09bLW00D0<c<c03Xj>P0j
>SX0@D5104Q8B00204];B`0504I6AP15ADD0ADE504U9B@15ADD00P10@400100m?Cd0?Shn03hn?P0j
>SX203Ti>@050451@@14A4@0?3`l03`l?00h>3P00P0i>CT00`0e=CD0<30`03Lg=`0203Lg=`80=SHf
00D0<c<c038b<P0b<S80:b/[02TY:@0203Ph>00303dm?@0o?cl0?clo0080@4100P0`<3001@0Z:RX0
<S8b038b<P0e=CD0=3@d0080<c<c00@0=SHf02d];@0];Bd0:b/[0P0e=CD01@0i>CT0?clo0492@P12
@T80A4A400<0?Cdm00<0>CTi03Hf=P0f=SH00`0e=CD01@0d=3@0<S8b038b<P0f=SH0=CDe0080=3@d
00D0<c<c030`<00`<300:BTY02/[:`0303Hf=P80<30`00D0:RXZ024Q8@0A4A404A4A01HF5P0202`/
;005038b<P0f=SH0=SHf03Lg=`0a<C400P0T92@01@0[:b/0<c<c03<c<`0g=cL0<c<c0080<30`00@0
:2PX02<S8`0S8b<0;2`/0P0_;bl01@0^;Rh0;bl_03<c<`0c<c<0<S8b0080=CDe00<0>SXj0?ooo`3o
ool03@3oool000d0oooo00@0oOgm05QHF01HF5P0WIfM0P2RXZ801@2?Shl0=SHf0?ooo`3oool0bl_;
0080DU9B00D0][Jf08j>SP2>SXh0QXJ602/[:`020?ooo`040;Vi^@1:BTX0BTY:09fMW@<0Y:BT00@0
=3@d0?3`l03`l?00f=SH0P1CDe<01@2>SXh0WYjN09>CT`2CTi<0J6QX0080f=SH00D0_Kfm07]kN`1o
Ogl0Ogmo0<30`00209ZJVP0503Ti>@3oool0NGUi07UiN@24Q8@00P2>SXh01@2LW9`0MgMg07MgM`1H
F5P0oooo0080W9bL00D0GEeM0:JVYP2VYZH0RXZ:0:>SX`0204a<C0040?ooo`2d];@0];Bd059BDP80
Rh^;00D0UIFE0;:b/P10@400@4100?ooo`020:FUY@0305MGE`2`/;00Ti>C0080Ti>C0P12@T801@3o
ool0KFe]06e]K@1dM7@0Vi^K0080Ti>C00D0QhN703`l?00l?3`0oooo04i>CP0207moO`050:ZZZP2H
V9P0V9RH09:BTP0:2PX00P3oool0100n?Sh0MgMg07MgM`2IVIT209fMW@0508>3P`0o?cl0oooo0?oo
o`1LG5`00P2BTY801@2SXj<0Rh^;071`L01`L700a/K60080f][J00D0FEUI08n?S`2?Shl0Xj>S09VI
V@0203lo?`050?ooo`1]KFd0KFe]08>3P`2YZJT00P2BTY801@1PH600XJ6Q0:6QX@3oool09bLW0080
RXZ:00@0W9bL09FEU@2EUID0?Shn0P3kno/01@3Kfm/0BDU90::RXP2RXZ80W9bL0080Rh^;00D0<C4a
0?ooo`27QhL0QhN707alO00208V9R@0509VIV@1mOGd0OGem06a/K03oool00P0[:b/0102ATI40Jf][
06][J`2OWil:0?ooo`0405iNGP1PH600H61P065QH@80GUiN00<0IFEU069RHP1PH6000P1PH60206=S
H`0505QHF01FEUH0EUIF05UIF@1KFe/00P1JFUX01@1MGEd0I6AT06ATI01UIFD0H61P0080HF5Q00@0
GemO05YJFP1JFUX0E5AD0P1FEUH01@1DE5@0EUIF05UIF@1IFET0Fe]K0080EEEE00D0E5AD059BDP1A
DE40DE5A04m?C`0205EEE@0405YJFP1NGUh0Hf=S06=SH`<0IfMW00D0HV9R065QH@1QHF40G5aL05QH
F00205IFEP0505EEE@1BDU80DU9B055AD@1DE5@00P1EEED0101HF5P0EeMG05MGE`1DE5@305EEE@04
05MGE`1IFET0FEUI05eMG@80G5aL00<0GUiN05eMG@1MGEd00P1MGEd205aLG00505YJFP1IFET0FEUI
05YJFP1HF5P00P1CDe<3055AD@04059BDP1EEED0FUYJ05YJFP<0G5aL0P1KFe/205aLG00405]KF`1L
G5`0G5aL05mOG`80H61P00D0HF5Q061PH01NGUh0GUiN05YJFP0205aLG00505iNGP1RHV80I6AT06AT
I01VIVH00P1SHf<01@1MGEd0FEUI05UIF@1JFUX0GemO0080HF5Q00D0I6AT06MWI`1WIfL0IfMW065Q
H@02061PH0<0G5aL00D0Fe]K05eMG@1KFe/0Fe]K05mOG`0205MGE`<0EUIF00<0EeMG05IFEP1KFe/0
0P1KFe/205UIF@0505QHF01JFUX0G5aL05aLG01KFe/00P1BDU801@1ADE40Cdm?04m?C`1>CTh0D51@
0080FEUI00@0Fe]K05eMG@1MGEd0GEeM3`3oool000d0oooo00@0g]kN069RHP1RHV80VYZJ0P37alL0
1@1mOGd0C4a<0>KViP3Vi^H0bl_;0080FUYJ00D0/K6a08n?S`2?Shl0Rh^;04E5A@020?ooo`050:f]
[@1?Cdl0Cdm?0:RXZ02a/K400P2EUID0101EEED0alO70<O7a`3Fe]H206IVIP0508^;R`2KVi/0UIFE
09FEU@1bLW800P3AdM401@2^[Zh0M7Ad09RHV02HV9P0`<300080S8b<00D0EUIF0?Shn01nOWh0OWin
09:BTP0208f=S@0509VIV@23Ph<0Ph>306=SH`3oool00P2NWYh01@18B4P0emOG0=OGe`20P800UiNG
0080IfMW00@0inOW0;Jf]P2f][H0Hf=S0P2?Shl01@2=SHd0Zj^[065QH@1QHF40k>c/0080XZ:R00D0
C4a<0>GUi@1kNg/0Ng]k092@T00205QHF0050?ooo`1hN7P0N7Qh07moO`2HV9P00P2CTi<01@2?Shl0
F5QH05QHF03oool0HV9R0080J6QX00D0h^;R0861P@21PH40TY:B02`/;0020?ooo`0405=CD`1mOGd0
OGem09^KV`80VIVI00D0QXJ605aLG03oool0oooo06a/K00208n?S`050;Ng]`23Ph<0LG5a075aL@30
`<000P3@d=001@1TI6@0Ti>C09>CT`2NWYh0Vi^K0080EUIF00D0mOGe07alO01lO7`0KFe]0=SHf002
07moO`0506i^KP2VYZH0YZJV0?ooo`0j>SX00P2FUYH0102LW9`0UYJF09JFUP1@D5020>g]k@050;^k
^`1BDU80/;2`0;2`/02/[:`00P24Q8@01@13@d<0oooo08>3P`23Ph<0O7al0080TY:B00D0V9RH08>3
P`23Ph<0PH610?ooo`0204A4A0040861P@2TY:@0Y:BT08:2PPX0oooo00@0DU9B04m?C`1?Cdl0CTi>
0P1ADE401@19BDT0AdM704e=C@1=CDd0DE5A0080D51@00D0EeMG05]KF`1KFe/0EEEE05ADE00205MG
E`0505UIF@1JFUX0FUYJ05aLG01MGEd00`1DE5@205UIF@0505mOG`1SHf<0Hf=S071`L01dM7@00P1c
Lg<01@1dM7@0NGUi07UiN@1eMGD0M7Ad0080Lg=c00D0L71`06UYJ@1YJFT0IVIV06ATI002061PH0@0
GEeM0P1IFET01@1JFUX0GEeM05iNGP1NGUh0GemO00<0Hf=S00@0GUiN05]KF`1KFe/0F5QH0P1GEeL0
1@1HF5P0EEEE05EEE@1FEUH0EeMG0080F5QH00D0EEEE05IFEP1FEUH0De=C05EEE@0205YJFP0405iN
GP1QHF40HF5Q06=SH`80HV9R00@0Fe]K05MGE`1HF5P0F5QH0`1IFET00`1KFe/0H61P069RHP02069R
HP80I6AT00D0Hf=S061PH01NGUh0GUiN05]KF`0205IFEP0505=CD`1BDU80DU9B04a<C01:BTX00P1=
CDd305EEE@80FEUI0P1EEED0101=CDd0BDU904U9B@17AdL204U9B@0505ADE01HF5P0G5aL05aLG01Q
HF400P1TI6@0101NGUh0HF5Q069RHP1RHV83065QH@05069RHP1QHF40HV9R069RHP1QHF400P1RHV80
0`1PH600GemO05mOG`0205iNGP80G5aL0`1OGel2069RHP80Hf=S00<0HF5Q06i^KP1^KVh0101/K6`0
101ZJVX0GEeM05eMG@1HF5P305EEE@l0oooo000=0?ooo`040<c<c01JFUX0FUYJ0:^[Z`80fMWI00D0
JFUY06=SH`3IfMT0fMWI0;>c/`02075aL@050:RXZ02ATI40TI6A08^;R`1QHF400P3`l?001@2NWYh0
EUIF05IFEP2ZZZX0a/K60080Q8B400@0Jf][0:b/[02/[:`0c/k>0P1hN7P01@2?Shl0UYJF09JFUP2F
UYH0Ogmo0080aLG500D0WinO06][J`2k^k/0^k^k0;Fe]@0208J6QP0506QXJ03MgMd0Ph>308>3P`2I
VIT00P2@T9001@2CTi<0Shn?08n?S`1_Kfl0iNGU0080W9bL00D0>c/k0?knoP3no_h0MgMg08j>SP02
07inOP040<O7a`2h^;P0^;Rh06m_K`80SXj>00D0S8b<0:JVYP1mOGd0OGem0<S8b00209fMW@0504U9
B@3oool0KFe]06e]K@2<S8`00P1^KVh0103Ti>@0S8b<08b<S028R8P309BDU00509:BTP1bLW80LW9b
0?Shn01`L7000P1ADE401@3oool0IFEU06EUI@2EUID0CTi>0080oooo00<0JVYZ08>3P`23Ph<00`2M
WId01@29RHT0LW9b0>SXj03Xj>P0MgMg0080TI6A00D0c<c<07]kN`1bLW80LW9b0;Rh^0020<C4a005
071`L02FUYH0UYJF09VIV@2RXZ800P1`L7001@39bLT0PX:208:2PP1NGUh0oooo0080KFe]00D0N7Qh
0:^[Z`2[Zj/0gMgM05eMG@0209JFUP0409bLW02BTY80TY:B06MWI`80e]KF00D0/k>c04m?C`2o_kl0
_kno0;Rh^00207]kN`0505YJFP3no_h0R8R808R8R01oOgl00P2FUYH01@2EUID0QXJ608J6QP2NWYh0
jNWY0080GUiN00@0KVi^0=OGe`3GemL0JFUY2P3oool0100m?Cd0=cLg03Lg=`0];Bd203<c<`050492
@P1:BTX0Bd];04];B`17AdL00P0n?Sh01@0a<C40>CTi03Ti>@14A4@0ATI60080AdM700D0A4A403Ph
>00h>3P0;bl_03/k>`02051@D0<0EEEE00<0FEUI051@D01@D500100k>c/0100c<c<0;Bd]02d];@0_
;bl303<c<`0503/k>`10@400@41003lo?`0g=cL00P0f=SH0100c<c<0<S8b038b<P0n?Sh204Y:BP05
04U9B@11@D40@d=304=3@`0m?Cd00P0c<c<00`0l?3`0AdM704Y:BP0204Y:BP80Cdm?00D0C4a<051@
D01@D500EeMG05EEE@0204a<C00504U9B@15ADD0ADE503`l?00j>SX00`0o?cl203Ti>@0503Lg=`0e
=CD0=CDe03@d=00i>CT00P14A4@01@13@d<0@D510451@@0k>c/0<30`00808R8R00D08B4Q02/[:`0[
:b/0=3@d03Xj>P0203hn?P0404=3@`0n?Sh0?Shn0410@080C4a<00D0Fe]K06=SH`1TI6@0I6AT061P
H00205IFEP80CDe=0P1?Cdl0101CDe<0E5AD05ADE01CDe<204i>CP0504M7A`12@T80?Cdm03dm?@0b
<S800P0Z:RX01@0[:b/0<30`03Hf=P0f=SH0?clo0080@d=300@0ADE50410@00j>SX0>SXj0`0m?Cd0
1@0j>SX0=cLg03Lg=`0e=CD0;bl_0080:b/[00D0=CDe03`l?00l?3`0>c/k03Xj>P0203`l?00403Hf
=P0`<300<30`03Ph>080=CDe00D0<c<c02h^;P0d=3@0=3@d03Ti>@0303hn?Pl0oooo000=0?ooo`04
0<c<c01JFUX0FUYJ0:^[Z`80fMWI00D0JFUY06=SH`3IfMT0fMWI0;>c/`02075aL@050:RXZ02ATI40
TI6A08^;R`1QHF400P3`l?001@2NWYh0EUIF05IFEP2ZZZX0a/K60080Q8B400@0Jf][0:b/[02/[:`0
c/k>0P1hN7P01@2?Shl0UYJF09JFUP2FUYH0Ogmo0080aLG500D0WinO06][J`2k^k/0^k^k0;Fe]@02
08J6QP0506QXJ03MgMd0Ph>308>3P`2IVIT00P2@T9001@2CTi<0Shn?08n?S`1_Kfl0iNGU0080W9bL
00D0>c/k0?knoP3no_h0MgMg08j>SP0207inOP040<O7a`2h^;P0^;Rh06m_K`80SXj>00D0S8b<0:JV
YP1mOGd0OGem0<S8b00209fMW@0504U9B@3oool0KFe]06e]K@2<S8`00P1^KVh0103Ti>@0S8b<08b<
S028R8P309BDU00509:BTP1bLW80LW9b0?Shn01`L7000P1ADE401@3oool0IFEU06EUI@2EUID0CTi>
0080oooo00<0JVYZ08>3P`23Ph<00`2MWId01@29RHT0LW9b0>SXj03Xj>P0MgMg0080TI6A00D0c<c<
07]kN`1bLW80LW9b0;Rh^0020<C4a005071`L02FUYH0UYJF09VIV@2RXZ800P1`L7001@39bLT0PX:2
08:2PP1NGUh0oooo0080KFe]00D0N7Qh0:^[Z`2[Zj/0gMgM05eMG@0209JFUP0409bLW02BTY80TY:B
06MWI`80e]KF00D0/k>c04m?C`2o_kl0_kno0;Rh^00207]kN`0505YJFP3no_h0R8R808R8R01oOgl0
0P2FUYH01@2EUID0QXJ608J6QP2NWYh0jNWY0080GUiN00@0KVi^0=OGe`3GemL0JFUY2P3oool0100m
?Cd0=cLg03Lg=`0];Bd203<c<`050492@P1:BTX0Bd];04];B`17AdL00P0n?Sh01@0a<C40>CTi03Ti
>@14A4@0ATI60080AdM700D0A4A403Ph>00h>3P0;bl_03/k>`02051@D0<0EEEE00<0FEUI051@D01@
D500100k>c/0100c<c<0;Bd]02d];@0_;bl303<c<`0503/k>`10@400@41003lo?`0g=cL00P0f=SH0
100c<c<0<S8b038b<P0n?Sh204Y:BP0504U9B@11@D40@d=304=3@`0m?Cd00P0c<c<00`0l?3`0AdM7
04Y:BP0204Y:BP80Cdm?00D0C4a<051@D01@D500EeMG05EEE@0204a<C00504U9B@15ADD0ADE503`l
?00j>SX00`0o?cl203Ti>@0503Lg=`0e=CD0=CDe03@d=00i>CT00P14A4@01@13@d<0@D510451@@0k
>c/0<30`00808R8R00D08B4Q02/[:`0[:b/0=3@d03Xj>P0203hn?P0404=3@`0n?Sh0?Shn0410@080
C4a<00D0Fe]K06=SH`1TI6@0I6AT061PH00205IFEP80CDe=0P1?Cdl0101CDe<0E5AD05ADE01CDe<2
04i>CP0504M7A`12@T80?Cdm03dm?@0b<S800P0Z:RX01@0[:b/0<30`03Hf=P0f=SH0?clo0080@d=3
00@0ADE50410@00j>SX0>SXj0`0m?Cd01@0j>SX0=cLg03Lg=`0e=CD0;bl_0080:b/[00D0=CDe03`l
?00l?3`0>c/k03Xj>P0203`l?00403Hf=P0`<300<30`03Ph>080=CDe00D0<c<c02h^;P0d=3@0=3@d
03Ti>@0303hn?Pl0oooo000=0?ooo`040;Zj^P1CDe<0De=C0;Ng]`80n?Sh00D0DE5A07alO02m_Kd0
_Kfm0:n_[`0208>3P`0509VIV@2CTi<0Ti>C092@T01lO7`00P3<c<`01@2GUiL0HV9R069RHP2TY:@0
h>3P0080Kfm_00@0QXJ608n?S`2?Shl0b<S80P25QHD01@2CTi<0UYJF08n?S`2?Shl0Rh^;0080_[jn
00D0V9RH06ATI03=cLd0cLg=0;Fe]@0207MgM`050820P02k^k/0RXZ:08Z:RP2LW9`00P2FUYH01@2H
V9P0TI6A096AT@1nOWh0aLG50080WinO00D0<c<c0?ooo`3oool0Kfm_08:2PP0209BDU0040:JVYP2o
_kl0_kno07UiN@80TI6A00D0S8b<09bLW02JVYX0VYZJ0:FUY@0209ZJVP0504I6AP3oool0F5QH05QH
F02ATI400P23Ph<01@2b/[80WinO09nOW`2?Shl0TY:B0080W9bL00D0T92@08^;R`2;Rh/0alO708:2
PP0203/k>`050?ooo`1<C4`0C4a<09JFUP1dM7@00P3Cdm<01023Ph<0QXJ608J6QP2NWYh20:2PX005
08b<S029RHT0]kNg0;Ng]`26QXH00P2ATI401@3Ph>00JVYZ07UiN@1iNGT0[Zj^0080^KVi00D0OGem
09ZJVP2JVYX0UIFE0:RXZ00208J6QP0509bLW02ATI40TI6A04m?C`3oool00P1KFe/01@28R8P0Y:BT
0:BTY02d];@0OGem0080UIFE00@0VYZJ092@T02@T900Ng]k0P37alL01@2UYJD0BDU90=CDe03De=@0
`<300080Lg=c00D0MgMg0<g=c@2BTY80TY:B0861P@0209bLW00509VIV@2ATI40TI6A09VIV@32`/80
0P1kNg/0101SHf<0oOgm0?gmo@1CDe<:0?ooo`040:JVYP2b/[80/[:b0<30`080_[jn00D0^[Zj0;no
_`2k^k/0^k^k0;Vi^@020;jn_P050<G5a@2k^k/0^k^k0;>c/`2_[jl00P2ZZZX01@2TY:@0[Jf]0:f]
[@2b/[80YjNW0080VIVI00@0UiNG09FEU@2EUID0T92@0P2EUID01@2QXJ40WYjN09jNWP2NWYh0Xj>S
0080YjNW00D0YZJV0:RXZ02/[:`0[:b/0:ZZZP020:^[Z`040;6a/@2d];@0/K6a0;6a/@<0/;2`00D0
YZJV0:2PX02PX:00Y:BT0:NWY`020:FUY@050:ZZZP2c/k<0/k>c0:^[Z`2XZ:P00P2WYjL0102UYJD0
W9bL09bLW02QXJ4209nOW`0509RHV02KVi/0Zj^[0:^[Z`2YZJT00P2][Jd01@2g]kL0^KVi0:^[Z`2[
Zj/0[Jf]00<0[:b/0P2][Jd01@2e]KD0]kNg0;:b/P2b/[80][Jf0080_Kfm00D0^[Zj0;jn_P37alL0
alO70<G5a@020;Jf]P050;Bd]02^[Zh0Zj^[0:^[Z`2XZ:P00`2`/;020:BTY00509fMW@2JVYX0VIVI
09VIV@2MWId00P2YZJT20:n_[`80/;2`00@0[Zj^0;:b/P2b/[80]KFe0P2g]kL01@2_[jl0ZZZZ0:JV
YP2VYZH0Xj>S0080YjNW0P2_[jl20:VYZ@050:JVYP2NWYh0WYjN09ZJVP2LW9`01@2QXJ430:NWY`05
0:FUY@2WYjL0Zj^[0:^[Z`2QXJ400P2OWil01@2VYZH0ZZZZ0:f][@2][Jd0][Jf0080_Kfm00D0_;bl
0<;2`P32`/80aLG50;no_`020;Ng]`040;2`/02ZZZX0ZZZZ0:BTY0l0oooo000=0?ooo`0409jNWP1?
Cdl0Cdm?0;fm_@80oooo00D0?Cdm08b<S02][Jd0[Jf]09RHV00209:BTP0509VIV@2HV9P0V9RH09JF
UP2CTi<00P2SXj<01@2?Shl0LW9b079bLP2OWil0moOg0080HV9R00@0WYjN07inOP1nOWh0Z:RX0P2N
WYh01@2IVIT0SXj>08f=S@2=SHd0UiNG0080]KFe00D0VIVI05IFEP3Xj>P0j>SX0;>c/`02065QH@80
Vi^K0`2FUYH209bLW00509fMW@2EUID0UIFE09:BTP2ZZZX00P29RHT01@0f=SH0oooo0?ooo`1JFUX0
MgMg0080[jn_00@0Rh^;0;jn_P2n_[h0Ogmo0P2FUYH01@2=SHd0Vi^K0:NWY`2WYjL0RHV90080Vi^K
00D0@T920?ooo`12@T80@T9209>CT`0209BDU00509FEU@2[Zj/0Zj^[09>CT`2DU9@00P2NWYh01@2E
UID0V9RH09RHV02IVIT0UiNG00808R8R00D0oooo03Hf=P0f=SH0VYZJ096AT@0209^KV`0309FEU@2;
Rh/0Rh^;00<0XJ6Q00D0TI6A09bLW02EUID0UIFE0820P00209VIV@050>o_k`1QHF40Ogmo07moO`2X
Z:P00P2_[jl01@25QHD0W9bL09bLW02BTY80Z:RX00<0SXj>0P2HV9P01@0o?cl0oooo04m?C`1?Cdl0
V9RH0080UYJF00D0VIVI09>CT`2CTi<0Ti>C09VIV@0208f=S@05092@T02e]KD0]KFe09jNWP0l?3`0
0P3/k>`01@3@d=00GemO05mOG`2EUID0XZ:R0080TI6A00@0Shn?09nOW`2OWil0VYZJ0P2ATI401@2R
XZ80WIfM096AT@2ATI40G5aL0080oooo00<0ATI60?ooo`3oool0203oool01012@T80@d=304=3@`11
@D4203Ti>@05034a<@0P82006a/K01/K6`0J6QX00P0N7Qh01@0P82007alO01lO7`0P82008R8R0080
:RXZ00D0<S8b03Lg=`0g=cL0?Cdm03lo?`0203hn?P0403dm?@0j>SX0>SXj03Ph>080=cLg0P0e=CD2
03Hf=P0503De=@0h>3P0>3Ph03dm?@0h>3P00P0f=SH01@0b<S80;Bd]02d];@0U9BD09bLW0080:BTY
0`0];Bd01@0[:b/0:BTY02TY:@0W9bL0<30`0080=3@d00D0>3Ph03Lg=`0g=cL0=cLg02`/;00202XZ
:P0402`/;00`<300<30`034a<@80<c<c00D0<C4a02h^;P0X:2P0:2PX03<c<`03038b<P04034a<@0d
=3@0=3@d02LW9`80:RXZ00D0:b/[02d];@0];Bd0;2`/02/[:`0202HV9P0502<S8`0O7al07alO02LW
9`0Z:RX00P0^;Rh01@0a<C40=3@d03@d=00_;bl0;Rh^0080;Bd]00@0;2`/02d];@0];Bd0;Bd]0`0_
;bl3030`<00302`/;00X:2P0:2PX00809RHV0P0U9BD302PX:00502XZ:P0/;2`0;2`/02l_;`0c<c<0
0P0g=cL01@10@400?clo03lo?`0l?3`0=cLg0080=SHf00D0<C4a03@d=00d=3@0=cLg03`l?00203hn
?P0403/k>`0i>CT0>CTi03Hf=P80>SXj00D0@D5104U9B@1<C4`0C4a<04];B`0204E5A@0503Xj>P0b
<S80:b/[02/[:`0X:2P00P0S8b<01@0M7Ad06QXJ01XJ6P0J6QX09RHV0080;Bd]00@0<S8b03Ti>@0i
>CT0?Cdm3`3oool000d0oooo00@0WYjN04m?C`1?Cdl0_Kfm0P3oool01@0m?Cd0S8b<0:f][@2][Jd0
V9RH0080TY:B00D0VIVI09RHV02HV9P0UYJF09>CT`020:>SX`0508n?S`1bLW80LW9b09nOW`3gmoL0
0P1RHV80102NWYh0OWin07inOP2XZ:P209jNWP0509VIV@2>SXh0SHf=08f=S@2GUiL00P2e]KD01@2I
VIT0EUIF0>SXj03Xj>P0/k>c0080HF5Q0P2KVi/309JFUP80W9bL00D0WIfM09FEU@2EUID0TY:B0:ZZ
ZP0208V9R@0503Hf=P3oool0oooo05YJFP1gMgL00P2_[jl0102;Rh/0_[jn0;jn_P1oOgl209JFUP05
08f=S@2KVi/0YjNW0:NWY`29RHT00P2KVi/01@12@T80oooo0492@P12@T80Ti>C0080U9BD00D0UIFE
0:^[Z`2[Zj/0Ti>C09BDU00209jNWP0509FEU@2HV9P0V9RH09VIV@2GUiL00P0R8R801@3oool0=SHf
03Hf=P2JVYX0TI6A0080Vi^K00<0UIFE08^;R`2;Rh/00`2QXJ401@2ATI40W9bL09FEU@2EUID0P820
0080VIVI00D0kno_065QH@1oOgl0Ogmo0:RXZ0020:n_[`0508F5Q@2LW9`0W9bL09:BTP2XZ:P00`2>
SXh209RHV00503lo?`3oool0Cdm?04m?C`2HV9P00P2FUYH01@2IVIT0Ti>C09>CT`2CTi<0VIVI0080
SHf=00D0T92@0;Fe]@2e]KD0WYjN03`l?0020>c/k0050=3@d01OGel0GemO09FEU@2RXZ800P2ATI40
102?Shl0WinO09nOW`2JVYX2096AT@050::RXP2MWId0TI6A096AT@1LG5`00P3oool00`16ATH0oooo
0?ooo`080?ooo`040492@P13@d<0@d=30451@@80>CTi00D0<C4a020P800K6a/06a/K01XJ6P0201hN
7P05020P800O7al07alO020P800R8R800P0Z:RX01@0b<S80=cLg03Lg=`0m?Cd0?clo0080?Shn00@0
?Cdm03Xj>P0j>SX0>3Ph0P0g=cL203De=@80=SHf00D0=CDe03Ph>00h>3P0?Cdm03Ph>00203Hf=P05
038b<P0];Bd0;Bd]02DU9@0W9bL00P0Y:BT302d];@0502/[:`0Y:BT0:BTY02LW9`0`<3000P0d=3@0
1@0h>3P0=cLg03Lg=`0g=cL0;2`/0080:RXZ00@0;2`/030`<00`<300<C4a0P0c<c<01@0a<C40;Rh^
02PX:00X:2P0<c<c00<0<S8b00@0<C4a03@d=00d=3@09bLW0P0Z:RX01@0[:b/0;Bd]02d];@0/;2`0
:b/[00809RHV00D08b<S01lO7`0O7al09bLW02XZ:P0202h^;P05034a<@0d=3@0=3@d02l_;`0^;Rh0
0P0];Bd0100/;2`0;Bd]02d];@0];Bd302l_;`<0<30`00<0;2`/02PX:00X:2P00P0V9RH202DU9@<0
:2PX00D0:RXZ02`/;00/;2`0;bl_03<c<`0203Lg=`050410@00o?cl0?clo03`l?00g=cL00P0f=SH0
1@0a<C40=3@d03@d=00g=cL0?3`l0080?Shn00@0>c/k03Ti>@0i>CT0=SHf0P0j>SX01@11@D40BDU9
04a<C01<C4`0Bd];0080ADE500D0>SXj038b<P0[:b/0:b/[02PX:00202<S8`0501dM7@0J6QX06QXJ
01XJ6P0V9RH00P0];Bd0100b<S80>CTi03Ti>@0m?Cd?0?ooo`003@3oool0102JVYX0Cdm?04m?C`2k
^k/20?ooo`0503dm?@28R8P0[Zj^0:j^[P2@T9000P2?Shl01@2QXJ40VIVI09VIV@2FUYH0Ti>C0080
UYJF00D0VYZJ07YjNP1jNWX0VYZJ0?;blP0206MWI`0409fMW@22PX80PX:209jNWP80W9bL00D0Vi^K
09NGU`2<S8`0S8b<0:6QX@020:VYZ@0509^KV`1DE5@0k^k^0>k^kP2YZJT00P1YJFT01@2HV9P0Ti>C
09ZJVP2JVYX0TI6A0080YjNW00D0WinO09RHV02HV9P0TY:B0::RXP0208N7Q`0504A4A03oool0oooo
05iNGP1mOGd00P2XZ:P0102>SXh0^;Rh0;Rh^01lO7`209ZJVP0509nOW`2;Rh/0ZZZZ0:ZZZP2=SHd0
0P2JVYX01@12@T80oooo04e=C@1=CDd0Shn?0080W9bL00D0Shn?0:ZZZP2ZZZX0Ti>C09^KV`020:2P
X00509NGU`2@T900T92@09^KV`2EUID00P0R8R801@3oool0<c<c03<c<`2MWId0UIFE0080Shn?00@0
WYjN08F5Q@25QHD0[:b/0P2MWId01@2HV9P0UIFE09JFUP2FUYH0QhN70080TI6A00D0inOW06IVIP25
QHD0QHF509nOW`020:n_[`0508R8R02RXZ80XZ:R09FEU@2LW9`00`2BTY8209ZJVP0504E5A@3oool0
E5AD05ADE02MWId00P2@T9001@2EUID0V9RH09^KV`2KVi/0TY:B0080Shn?00D0UiNG0;6a/@2a/K40
Vi^K03De=@020>_[j`050=cLg01MGEd0GEeM09JFUP2KVi/00P2EUID0102FUYH0WinO09nOW`2DU9@2
09bLW00509NGU`2HV9P0U9BD09BDU01KFe/00P3oool00`14A4@0oooo0?ooo`080?ooo`0405EEE@1A
DE40DE5A051@D080E5AD00D0EEEE05mOG`1UIFD0IFEU06QXJ00206MWI`@0IVIV00@0Hf=S061PH01P
H600GUiN0P1MGEd01@1KFe/0FUYJ05eMG@1MGEd0GemO00<0H61P0P1RHV801@1OGel0FEUI05ADE01D
E5@0EEEE0080DU9B00D0Cdm?05ADE01EEED0EEEE05IFEP0205MGE`0505]KF`1JFUX0Fe]K05]KF`1M
GEd00`1NGUh3061PH00305]KF`1JFUX0FUYJ00<0FUYJ00@0GEeM069RHP1SHf<0Hf=S0`1RHV800`1O
Gel0H61P061PH002061PH080GemO00<0Fe]K05YJFP1JFUX0101IFET0101PH600HF5Q065QH@1PH602
05mOG`05061PH01NGUh0GEeM05eMG@1NGUh00P1PH6001@1RHV80H61P05mOG`1OGel0GUiN0080GEeM
00D0FUYJ05aLG01NGUh0GUiN069RHP0306ATI080H61P00<0GUiN05]KF`1IFET00P1IFET205aLG080
GEeM0`1LG5`305]KF`80FUYJ0P1KFe/205aLG0<0GEeM00@0GUiN05mOG`1OGel0GemO0`1MGEd00`1L
G5`0FUYJ05UIF@0205UIF@<0FUYJ0P1IFET00`1FEUH0De=C051@D002051@D080De=C00D0EEEE05UI
F@1KFe/0Fe]K05aLG00205eMG@0405iNGP1OGel0GemO05mOG`@0H61P0`1OGel?0?ooo`003@3oool0
102MWId0F5QH05QHF02m_Kd20?knoP0504m?C`29RHT0[jn_0:n_[`2ATI400P20P8001@2d];@0[:b/
0:b/[020P800Ti>C0080VIVI00D0V9RH08R8R028R8P0TI6A0>3Ph00207IfMP0409JFUP2<S8`0S8b<
09JFUP80OWin00D0^[Zj0:VYZ@1mOGd0OGem0:>SX`020:6QX@0509jNWP1QHF40gmoO0=oOg`2DU9@0
0P1kNg/01@2JVYX0V9RH09BDU02DU9@0P8200080/k>c00D0_kno07alO01lO7`0Ti>C0:FUY@0208F5
Q@0505iNGP3oool0oooo06YZJP26QXH00P2WYjL0102>SXh0/K6a0;6a/@1aLG4209>CT`050<g=c@1f
MWH0YjNW0:NWY`2?Shl00P2HV9P01@1KFe/0oooo06MWI`1WIfL0TY:B0080Vi^K00D0Ti>C0:6QX@2Q
XJ40OGem0;jn_P0209NGU`0509RHV02>SXh0SXj>09fMW@2GUiL00P10@4001@3oool0AdM704M7A`2L
W9`0VYZJ0080UIFE00@0R8R8096AT@2ATI40c<c<0P24Q8@01@2GUiL0TI6A09ZJVP2JVYX0S8b<0080
TY:B00D0dm?C07=cL`25QHD0QHF509NGU`020:^[Z`0508Z:RP2d];@0];Bd0:6QX@23Ph<00P2FUYH0
1@2CTi<0VYZJ09ZJVP1MGEd0oooo0080JVYZ00D0WinO096AT@2ATI40S8b<09JFUP020;Zj^P040820
P02?Shl0Shn?09FEU@80/K6a00D0VIVI04Q8B03Kfm/0fm_K0<g=c@0206MWI`0509FEU@2?Shl0Shn?
08n?S`38b<P00P20P800102FUYH0XJ6Q0:6QX@2CTi<309JFUP0406i^KP3oool0oooo05UIF@X0oooo
00@0IVIV06EUI@1UIFD0I6AT0`1UIFD0101QHF40H61P061PH01NGUh205eMG@0505aLG01NGUh0GUiN
061PH01QHF400P1OGel00`1MGEd0FEUI05UIF@0405QHF00405MGE`1LG5`0G5aL065QH@80H61P00D0
I6AT06MWI`1UIFD0IFEU06=SH`0206ATI005069RHP1OGel0HF5Q065QH@1OGel00P1PH6001@1QHF40
IFEU06EUI@1UIFD0HV9R0080GemO00D0GEeM05UIF@1IFET0EUIF05ADE00205EEE@0505ADE01@D500
D51@04m?C`1DE5@00P1GEeL0101KFe/0GemO05mOG`1QHF4205mOG`0505eMG@1JFUX0FUYJ05YJFP1I
FET00P1FEUH01@1EEED0De=C051@D01@D500Cdm?0080DE5A00D0DU9B05QHF01HF5P0FUYJ05eMG@02
061PH003069RHP1NGUh0GUiN00@0G5aL0`1MGEd01@1PH600GemO05eMG@1MGEd0FUYJ0080EUIF00D0
De=C05ADE01DE5@0De=C055AD@0205=CD`0505EEE@1DE5@0E5AD05=CD`1FEUH00P1GEeL00`1HF5P0
FEUI05UIF@0405]KF`<0FUYJ00D0FEUI05QHF01HF5P0EUIF05EEE@0205ADE00305IFEP1HF5P0F5QH
0080FEUI0`1KFe/205YJFP0505]KF`1LG5`0G5aL05]KF`1NGUh00P1PH60305mOG`04061PH01NGUh0
H61P061PH0<0HF5Q0`1PH6001@1NGUh0GEeM05iNGP1NGUh0H61P0080GemO00<0Hf=S0?ooo`3oool0
3@3oool000d0oooo00@0Vi^K06][J`1[Jf/0[Zj^0P3[jn/01@1YJFT0QHF50:FUY@2UYJD0UIFE0080
MGEe00D0aLG50;Zj^P2j^[X0KVi^09:BTP0209ZJVP0509VIV@2@T900T92@09:BTP3<c<`00P23Ph<0
102FUYH0TY:B09:BTP2?Shl2071`L0050<30`033`l<0IFEU06EUI@2ZZZX00P2XZ:P01@2JVYX0JFUY
0<_;b`3;bl/0U9BD0080Ogmo00D0XJ6Q09JFUP2EUID0UIFE07IfMP020;6a/@050>GUi@1TI6@0I6AT
08n?S`2XZ:P00P24Q8@01@1bLW80l?3`0?3`l01]KFd0Vi^K0080XJ6Q00@0SXj>0:NWY`2WYjL0Jf][
0P2ATI401@3gmoL0GemO0:6QX@2QXJ40Ti>C0080UiNG00D0KVi^0>OWi`1gMgL0MgMg09BDU00209FE
U@050:JVYP2EUID0UIFE06IVIP3Jf]X00`2FUYH2092@T00509RHV02GUiL0Hf=S06=SH`3oool00P1N
GUh01@2IVIT0WYjN09:BTP2BTY80Ph>30080T92@00D0k^k^06YZJP1ZJVX0UIFE08f=S@020::RXP05
08n?S`2CTi<0Ti>C0;no_`21PH400P27QhL0102EUID0YjNW0:NWY`1lO7`20<k>cP050:JVYP1cLg<0
VYZJ09ZJVP2CTi<00P2JVYX01@1cLg<0gMgM0820P020P800WinO0080SXj>00D0P8200:FUY@3>c/h0
c/k>06e]K@0209:BTP0509FEU@2^[Zh0[Zj^09FEU@1NGUh00P38b<P01@30`<00M7Ad07AdM02HV9P0
RHV90080Ogmo00@0m?Cd06QXJ01XJ6P0V9RH0P2SXj<01@2>SXh0UYJF09NGU`2GUiL0Q8B40080eMGE
00<0Kfm_0?ooo`3oool0203oool00`0g=cL0>CTi03Ti>@0303`l?00503Ti>@0b<S80<30`030`<00]
;Bd00P0/;2`01@0X:2P08B4Q024Q8@0M7Ad06a/K00807AdM00@092@T02PX:00X:2P0:b/[0`0^;Rh0
100Y:BT09BDU02DU9@0R8R82024Q8@05020P800X:2P0<S8b038b<P0i>CT00P11@D400`17AdL0@d=3
0410@0020410@080>SXj00D0<c<c02h^;P0];Bd0;Bd]038b<P0203Lg=`0503lo?`11@D40@D510410
@014A4@00P0n?Sh01@0j>SX0?Shn03hn?P0n?Sh0<C4a0080;bl_00@0:BTY01lO7`0O7al07AdM0P0O
7al01@0P820092@T02LW9`0W9bL0<c<c0080>3Ph00D0?Cdm0492@P18B4P0B4Q80492@P020410@005
03`l?00f=SH0=SHf030`<00];Bd00P0Y:BT01@0X:2P0:BTY02TY:@0`<300;bl_00<0<C4a0P0c<c<2
02`/;080:b/[00@0;Bd]02l_;`0_;bl0=3@d0P0f=SH01@0l?3`0ATI604a<C01<C4`0BTY:0080BDU9
00D0AdM703`l?00_;bl0;bl_02LW9`0201lO7`0501XJ6P0G5aL05aLG01PH600L71`00P0Q8B401@0X
:2P0;2`/02`/;00a<C40=3@d0080=CDe00D0;bl_02d];@0];Bd0;2`/02d];@02030`<00403@d=00i
>CT0>CTi03Xj>P80@T9200D0ADE503hn?P0j>SX0>SXj03Hf=P0202/[:`0502@T900X:2P0:RXZ02XZ
:P0[:b/00P0a<C401@0d=3@0<c<c03<c<`0b<S80<C4a0080;2`/0`0Y:BT00`0/;2`0oooo0?ooo`0=
0?ooo`003@3oool0102KVi/0Jf][06][J`2^[Zh20>_[j`0506UYJ@25QHD0YJFU0:FUY@2EUID00P1e
MGD01@35aLD0^[Zj0;Zj^P1^KVh0TY:B0080VYZJ00D0VIVI092@T02@T900TY:B0<c<c00208>3P`04
09JFUP2BTY80TY:B08n?S`80L71`00D0`<300<?3``1UIFD0IFEU0:ZZZP020:RXZ00509ZJVP1YJFT0
bl_;0<_;b`2DU9@00P1oOgl01@2QXJ40UYJF09FEU@2EUID0MWIf0080/K6a00D0iNGU06ATI01TI6@0
Shn?0:RXZ00208B4Q005079bLP3`l?00l?3`06e]K@2KVi/00P2QXJ40102>SXh0YjNW0:NWY`1[Jf/2
096AT@050?Ogm`1OGel0XJ6Q0:6QX@2CTi<00P2GUiL01@1^KVh0inOW07MgM`1gMgL0U9BD0080UIFE
00D0YZJV09FEU@2EUID0IVIV0=[JfP0309JFUP80T92@00D0V9RH09NGU`1SHf<0Hf=S0?ooo`0205iN
GP0509VIV@2NWYh0TY:B09:BTP23Ph<00P2@T9001@3^k^h0JVYZ06YZJP2EUID0SHf=0080XZ:R00D0
Shn?09>CT`2CTi<0_kno0861P@0208N7Q`0409FEU@2WYjL0YjNW07alO080c/k>00D0YZJV07=cL`2J
VYX0VYZJ09>CT`0209ZJVP0507=cL`3MgMd0P8200820P02OWil00P2>SXh01@20P800YJFU0<k>cP3>
c/h0KFe]0080TY:B00D0UIFE0:j^[P2^[Zh0UIFE05iNGP020<S8b0050<30`01dM7@0M7Ad09RHV029
RHT00P1oOgl0103dm?@0J6QX06QXJ02HV9P20:>SX`0508j>SP2FUYH0UiNG09NGU`24Q8@00P3EeMD0
0`1_Kfl0oooo0?ooo`080?ooo`0303Lg=`0i>CT0>CTi00<0?3`l00D0>CTi038b<P0`<300<30`02d]
;@0202`/;00502PX:00Q8B408B4Q01dM7@0K6a/00P0M7Ad0100T92@0:2PX02PX:00[:b/302h^;P04
02TY:@0U9BD09BDU028R8P808B4Q00D0820P02PX:00b<S80<S8b03Ti>@020451@@0304M7A`13@d<0
@4100080@4100P0j>SX01@0c<c<0;Rh^02d];@0];Bd0<S8b0080=cLg00D0?clo0451@@11@D40@410
04A4A00203hn?P0503Xj>P0n?Sh0?Shn03hn?P0a<C400P0_;bl0100Y:BT07alO01lO7`0M7Ad201lO
7`05020P800T92@09bLW02LW9`0c<c<00P0h>3P01@0m?Cd0@T9204Q8B018B4P0@T920080@41000D0
?3`l03Hf=P0f=SH0<30`02d];@0202TY:@0502PX:00Y:BT0:BTY030`<00_;bl00`0a<C4203<c<`80
;2`/0P0[:b/0100];Bd0;bl_02l_;`0d=3@203Hf=P0503`l?016ATH0C4a<04a<C01:BTX00P19BDT0
1@17AdL0?3`l02l_;`0_;bl09bLW00807alO00D06QXJ01LG5`0G5aL061PH01`L7002024Q8@0502PX
:00/;2`0;2`/034a<@0d=3@00P0e=CD01@0_;bl0;Bd]02d];@0/;2`0;Bd]0080<30`00@0=3@d03Ti
>@0i>CT0>SXj0P12@T801@15ADD0?Shn03Xj>P0j>SX0=SHf0080:b/[00D092@T02PX:00Z:RX0:RXZ
02/[:`02034a<@0503@d=00c<c<0<c<c038b<P0a<C400P0/;2`302TY:@0302`/;03oool0oooo00d0
oooo000=0?ooo`0409VIV@1nOWh0OWin0::RXP80alO700D0SXj>08B4Q02LW9`0W9bL09:BTP02075a
L@050=3@d03<c<`0c<c<05aLG02>SXh00P2IVIT01@2MWId0UIFE09FEU@2JVYX0[Jf]00D0UIFE00D0
Rh^;06QXJ01XJ6P0`L710=7Ad@0205iNGP050:f][@2QXJ40XJ6Q09bLW01lO7`00P2a/K401@2EUID0
QhN708N7Q`2NWYh0UiNG0080Ti>C00@0LG5a0:NWY`2WYjL0oooo0P1>CTh01@2=SHd0YZJV08:2PP22
PX80QXJ60080d=3@00D0M7Ad0:VYZ@2LW9`0W9bL09:BTP0209ZJVP0506MWI`29RHT0RHV90?ooo`1;
Bd/00P2KVi/01@2BTY80VIVI09VIV@21PH40`L710080S8b<00@0TI6A08b<S02<S8`0^[Zj0P2;Rh/0
1@1@D500lo?c09>CT`2CTi<0UYJF0080SHf=00D0UYJF09RHV01oOgl0Ogmo0=CDe00207QhN00509JF
UP2NWYh0T92@092@T022PX800P2=SHd00`3oool0De=C05=CD`0209FEU@80[Jf]00D0R8R809FEU@2E
UID0YjNW092@T00208Z:RP0409>CT`2TY:@0Y:BT06UYJ@80kno_00D0Y:BT06IVIP2NWYh0WYjN092@
T00209jNWP0508F5Q@2g]kL0TI6A096AT@2MWId00P2?Shl01@1_Kfl0`L710=WIf@3IfMT0EeMG0080
UYJF00D0Ti>C0:f][@2][Jd0Ti>C07MgM`020;6a/@050;Bd]020P800P82009RHV027QhL00P1^KVh0
103oool0EEEE05EEE@2GUiL20:>SX`0508^;R`2GUiL0UiNG09NGU`2BTY800P2g]kL00`20P800oooo
0?ooo`080?ooo`040:ZZZP2[Zj/0Zj^[0:b/[080ZZZZ00<0Zj^[0:f][@2WYjL00P2WYjL20:j^[P05
0;Rh^02o_kl0_kno0=3@d03MgMd00P3Ng]h01@3Lg=`0gmoO0=oOg`3Jf]X0eMGE00<0d=3@0P35aLD0
1@2m_Kd0^k^k0;^k^`2l_;`0/K6a0080/[:b00D0/;2`0:^[Z`2[Zj/0YJFU0:VYZ@020:NWY`050:RX
Z02[Zj/0Zj^[0;>c/`2d];@00P2a/K40102c/k<0/;2`0;2`/02YZJT20:n_[`040;jn_P2o_kl0aLG5
0<G5a@<0bl_;00D0b/[:0=3@d03@d=00d=3@0<o?c`020<S8b0030<C4a030`<00`<300080_[jn0P37
alL01@31`L40`l?30<?3``31`L40`/;20080_kno0`38b<P01@34a<@0_kno0;no_`2k^k/0/;2`00<0
ZZZZ0`2/[:`0102d];@0][Jf0;Jf]P2f][H20;>c/`050;Rh^02`/;00[Jf]0:f][@2d];@00P2l_;`0
1@2k^k/0`<300<30`032`/80]kNg0080[:b/00D0[Zj^0;2`/02`/;00/k>c0;bl_0030<C4a080b/[:
00D0d];B0=WIf@3IfMT0gMgM0>;RhP020=oOg`050=GEe@3@d=00d=3@0<c<c038b<P00P37alL01@38
b<P0`<300<30`02n_[h0_Kfm00D0^KVi00D0]kNg0;:b/P2b/[80];Bd0;Vi^@020<71`@050<W9b@3=
cLd0cLg=0<?3``30`<000P2j^[X0102e]KD0/[:b0;:b/P2l_;`20;jn_P050<C4a037alL0b<S80<S8
b034a<@00P2o_kl00`2e]KD0oooo0?ooo`0=0?ooo`003@3oool0102HV9P0Ti>C09>CT`2IVIT20:>S
X`050:NWY`23Ph<0WinO09nOW`2DU9@00P1SHf<01@3GemL0i^KV0>KViP15ADD0T92@00<0Vi^K0P2L
W9`01@2MWId0UYJF0:6QX@2QXJ40UYJF0080V9RH00D0R8R805YJFP1JFUX0dm?C0=OGe`0205YJFP05
0:ZZZP2QXJ40XJ6Q09BDU02IVIT00P2EUID01@2DU9@0T92@092@T02JVYX0VIVI0080Shn?00@0JVYZ
0:>SX`2SXj<0oooo0P0d=3@01@29RHT0XZ:R08Z:RP2:RXX0VYZJ0080XZ:R00D0Rh^;0;>c/`2@T900
T92@09NGU`0209>CT`0506YZJP1eMGD0MGEe0?ooo`0a<C400P2JVYX01@2ATI40V9RH09RHV02DU9@0
XJ6Q0080Vi^K00@0TY:B08B4Q024Q8@0`/;20P2=SHd01@0l?3`0oooo09bLW02LW9`0S8b<0080RXZ:
00D0TI6A09fMW@2NWYh0WYjN0:BTY00209:BTP0508n?S`2JVYX0UYJF09JFUP1mOGd00P2ATI401@3o
ool0@D510451@@2DU9@0R8R80080`l?300D0S8b<09:BTP2BTY80TI6A09bLW002096AT@0408f=S@2O
Wil0WinO05YJFP80oooo00D0W9bL05]KF`2OWil0WinO09:BTP020:6QX@0309:BTP2JVYX0Vi^K0080
Vi^K0P2BTY801@1PH600e]KF0>[ZjP3Zj^X0@T920080VIVI00D0TI6A0:JVYP2VYZH0Ti>C092@T002
09bLW0050:>SX`2?Shl0Shn?09ZJVP26QXH00P1NGUh0103oool0@4100410@02IVIT20:BTY00508R8
R02CTi<0W9bL09bLW02JVYX00P2NWYh00`2?Shl0oooo0?ooo`080?ooo`0402`/;00W9bL09bLW02HV
9P809BDU00D0:2PX02l_;`0k>c/0>c/k0451@@0203hn?P0503Xj>P0g=cL0=cLg02TY:@0L71`00P0J
6QX01@0F5QH04Q8B018B4P0D51@05QHF00806a/K00@07QhN030`<00`<300?3`l0P0o?cl01@0l?3`0
?Cdm030`<00`<300:BTY00<092@T00<09bLW02TY:@0Y:BT0100Y:BT0100];Bd0<S8b038b<P0];Bd2
034a<@0503@d=00/;2`0;2`/024Q8@0N7Qh00P0L71`301LG5`0501PH600K6a/06a/K01/K6`0R8R80
0P0b<S801@0m?Cd0A4A404A4A019BDT0B4Q80080>SXj00D0=3@d02l_;`0_;bl0;Rh^02/[:`0202TY
:@<09BDU00D0;Rh^03De=@0e=CD0?Shn04Y:BP02059BDP0504i>CP19BDT0BDU903hn?P0c<c<00P0[
:b/01@0W9bL0:b/[02/[:`0];Bd0=SHf0080>c/k00@0=3@d02/[:`0[:b/0;Bd]0P0U9BD01@0O7al0
92@T02LW9`0W9bL09RHV008092@T00D08b<S02PX:00c<c<0<c<c03dm?@020492@P0503`l?00b<S80
<S8b02DU9@0K6a/00P0F5QH0100J6QX071`L01`L700N7Qh301lO7`03020P800Z:RX0:RXZ0080;2`/
0P0^;Rh0100`<300;2`/02`/;00/;2`202XZ:P0502HV9P0U9BD0820P020P800L71`00P0T92@01@0g
=cL0>3Ph03`l?00l?3`0@4100080>c/k00D0:b/[02XZ:P0Z:RX09BDU024Q8@0202<S8`0402LW9`0[
:b/0:b/[02`/;0l0oooo000=0?ooo`0409RHV02CTi<0Ti>C09VIV@80Xj>S00D0YjNW08>3P`2OWil0
WinO09BDU00206=SH`050=OGe`3Vi^H0i^KV04E5A@2@T9000`2KVi/209bLW00509fMW@2FUYH0XJ6Q
0:6QX@2FUYH00P2HV9P01@28R8P0FUYJ05YJFP3Cdm<0emOG0080FUYJ00D0ZZZZ0:6QX@2QXJ40U9BD
09VIV@0209FEU@0509BDU02@T900T92@09ZJVP2IVIT00P2?Shl0101ZJVX0Xj>S0:>SX`3oool203@d
=00508V9R@2RXZ80RXZ:08Z:RP2JVYX00P2RXZ801@2;Rh/0/k>c092@T02@T900UiNG0080Ti>C00D0
JVYZ07EeM@1eMGD0oooo034a<@0209ZJVP05096AT@2HV9P0V9RH09BDU02QXJ400P2KVi/0102BTY80
Q8B408B4Q032`/8208f=S@0503`l?03oool0W9bL09bLW02<S8`00P2:RXX01@2ATI40WIfM09jNWP2N
WYh0Y:BT0080TY:B00D0Shn?09ZJVP2FUYH0UYJF07emO@02096AT@050?ooo`11@D40@D5109BDU028
R8P00P33`l<01@2<S8`0TY:B09:BTP2ATI40W9bL0080TI6A00@0SHf=09nOW`2OWil0FUYJ0P3oool0
1@2LW9`0Fe]K09nOW`2OWil0TY:B0080XJ6Q00<0TY:B09ZJVP2KVi/00P2KVi/209:BTP05061PH03F
e]H0j^[Z0>[ZjP12@T800P2IVIT01@2ATI40YZJV0:JVYP2CTi<0T92@0080W9bL00D0Xj>S08n?S`2?
Shl0VYZJ08J6QP0205iNGP040?ooo`10@400@41009VIV@80Y:BT00D0R8R809>CT`2LW9`0W9bL09ZJ
VP0209jNWP0308n?S`3oool0oooo00P0oooo00@0;2`/02LW9`0W9bL09RHV0P0U9BD01@0X:2P0;bl_
03/k>`0k>c/0@D510080?Shn00D0>SXj03Lg=`0g=cL0:BTY01`L700201XJ6P0501HF5P0B4Q804Q8B
01@D500F5QH00P0K6a/0100N7Qh0<30`030`<00l?3`203lo?`0503`l?00m?Cd0<30`030`<00Y:BT0
0`0T92@00`0W9bL0:BTY02TY:@0402TY:@0402d];@0b<S80<S8b02d];@80<C4a00D0=3@d02`/;00/
;2`08B4Q01hN7P0201`L70<05aLG00D061PH01/K6`0K6a/06a/K028R8P02038b<P0503dm?@14A4@0
A4A404U9B@18B4P00P0j>SX01@0d=3@0;bl_02l_;`0^;Rh0:b/[0080:BTY0`0U9BD01@0^;Rh0=CDe
03De=@0n?Sh0BTY:0080DU9B00D0CTi>04U9B@19BDT0?Shn03<c<`0202/[:`0502LW9`0[:b/0:b/[
02d];@0f=SH00P0k>c/0100d=3@0:b/[02/[:`0];Bd202DU9@0501lO7`0T92@09bLW02LW9`0V9RH0
0P0T92@01@0S8b<0:2PX03<c<`0c<c<0?Cdm0080@T9200D0?3`l038b<P0b<S809BDU01/K6`0201HF
5P0401XJ6P0L71`071`L01hN7P<07alO00<0820P02XZ:P0Z:RX00P0/;2`202h^;P04030`<00/;2`0
;2`/02`/;080:RXZ00D09RHV02DU9@0P8200820P01`L700202@T900503Lg=`0h>3P0?3`l03`l?010
@4000P0k>c/01@0[:b/0:RXZ02XZ:P0U9BD08B4Q00808b<S00@09bLW02/[:`0[:b/0;2`/3`3oool0
00d0oooo00@0VIVI09NGU`2GUiL0WinO0P2JVYX01@2WYjL0QXJ609^KV`2KVi/0UYJF0080Hf=S00D0
fMWI0>o_k`3_knl0?Shn08j>SP020:2PX005096AT@2EUID0UIFE0:NWY`2EUID00P2LW9`0102IVIT0
U9BD09BDU02=SHd205]KF`050=[JfP3@d=00GEeM05eMG@2LW9`00P2^[Zh01@2=SHd0YjNW08N7Q`27
QhL0U9BD0080UiNG00D0WinO09FEU@27QhL0QhN706][J`020:RXZ0050?ooo`0`<300<30`08V9R@2L
W9`00P2EUID01@2BTY80WYjN09jNWP2>SXh0/k>c0080TY:B00@0Ti>C08b<S02<S8`0Ng]k0P1^KVh0
1@3oool0;bl_09RHV02HV9P0SXj>0080WYjN00D0Shn?0:BTY02HV9P0V9RH09^KV`0207alO0050<G5
a@2<S8`0S8b<03dm?@3no_h00P2OWil01@28R8P0TI6A096AT@2;Rh/0WinO0080ZZZZ00@0TY:B09ZJ
VP2JVYX0S8b<0`2LW9`0101cLg<0XJ6Q0:6QX@3oool20492@P0509FEU@2;Rh/0_kno0;no_`25QHD0
0`2JVYX0102CTi<0UIFE09FEU@2=SHd209^KV`0505]KF`3oool0oooo09FEU@1NGUh00P2MWId01@2G
UiL0W9bL09bLW02ATI40Xj>S0080UIFE0`2IVIT01@1NGUh0eMGE0>SXj03Xj>P0AdM70080UYJF00D0
Ti>C09VIV@2IVIT0WIfM09BDU0020:BTY00509FEU@2ATI40TI6A09fMW@29RHT00P1LG5`0103oool0
@4100410@02OWil209VIV@0508f=S@2EUID0Vi^K09^KV`2UYJD00P2;Rh/00`2DU9@0oooo0?ooo`08
0?ooo`0406MWI`1XJ6P0J6QX06IVIP80IFEU00D0I6AT065QH@1OGel0GemO05eMG@0205aLG0<0Fe]K
00@0G5aL05eMG@1MGEd0GEeM101NGUh305eMG@0305aLG01GEeL0EeMG00<0E5AD00D0F5QH05iNGP1Q
HF40HF5Q069RHP0206IVIP0506MWI`1VIVH0KVi^06i^KP1dM7@00`1gMgL0101dM7@0Kfm_06m_K`1]
KFd206MWI`0406EUI@1XJ6P0J6QX06QXJ0<0IfMW00D0JFUY06IVIP1VIVH0IFEU06ATI00206=SH`04
061PH01MGEd0GEeM05QHF080EUIF00D0EEEE05ADE01EEED0EEEE05QHF00205IFEP0505EEE@1CDe<0
EEEE05EEE@1FEUH00P1GEeL0101FEUH0EeMG05MGE`1HF5P305UIF@0305aLG01QHF40HF5Q0080I6AT
0P1XJ6P00`1[Jf/0J6QX06QXJ00406UYJ@0406EUI@1NGUh0GUiN05=CD`80C4a<00D0BDU904];B`1A
DE40DE5A05QHF00205iNGP0505mOG`1JFUX0DU9B059BDP1>CTh00P1;Bd/01@1=CDd0DE5A055AD@1I
FET0G5aL0080GUiN0`1MGEd205]KF`80GEeM00D0GemO065QH@1QHF40I6AT06MWI`0206QXJ00406EU
I@1RHV80HV9R061PH080GUiN0P1MGEd205mOG`05061PH01NGUh0GUiN05eMG@1LG5`00P1KFe/00`1I
FET0FUYJ05YJFP0305aLG00505eMG@1LG5`0GEeM05eMG@1NGUh00P1PH6000`1SHf<0oooo0?ooo`0=
0?ooo`003@3oool0102IVIT0QHF508F5Q@2k^k/209JFUP0509VIV@2CTi<0WYjN09jNWP2@T9000P1h
N7P01@32`/80eMGE0=GEe@1TI6@0QXJ60080Vi^K00D0UIFE07IfMP1fMWH0d];B096AT@0209VIV@04
09JFUP2BTY80TY:B08f=S@80Lg=c00D0_kno0<30`01]KFd0KFe]09jNWP020:^[Z`0509:BTP2>SXh0
Z:RX0:RXZ02KVi/00P29RHT01@2OWil0SXj>092@T02@T900MgMg0080WinO00D0oooo04Q8B018B4P0
SHf=09VIV@02092@T0050861P@30`<00`<3008R8R02`/;000`2ATI4208f=S@0508R8R01iNGT0NGUi
0?ooo`14A4@00P2FUYH01@2BTY80W9bL09bLW01oOgl0c/k>0080QhN700@0U9BD0861P@21PH40`L71
0P2>SXh01@1BDU80g]kN0:RXZ02XZ:P0QXJ60080UIFE00D0QhN709FEU@2WYjL0YjNW0;6a/@02096A
T@0508V9R@2MWId0UYJF09JFUP27QhL00P2HV9P01@3Vi^H0GEeM05eMG@2FUYH0S8b<0080_Kfm00D0
IVIV0<30`030`<00Zj^[07]kN`0209RHV004092@T02OWil0WinO05eMG@80oooo00D0Rh^;07EeM@2K
Vi/0Vi^K09NGU`0209JFUP0407QhN03Ti>@0L71`071`L0<0VIVI00D0IVIV0=KFeP3:b/X0b/[:05UI
F@0209RHV0<0UYJF00D0Vi^K08J6QP36a/H0a/K608Z:RP0208V9R@050:2PX02BTY80I6AT06ATI03o
ool00P1MGEd01@2LW9`0V9RH09RHV02?Shl0VIVI0080RXZ:00@0`<3008F5Q@25QHD0S8b<2P3oool0
0`1KFe/0GUiN05iNGP0405mOG`0406=SH`1QHF40HF5Q061PH080HV9R00@0H61P05eMG@1MGEd0GUiN
101PH602065QH@80H61P0P1OGel0101PH600G5aL05aLG01MGEd205]KF`0505aLG01IFET0G5aL05aL
G01MGEd00P1JFUX0101GEeL0F5QH05=CD`1CDe<304i>CP0504m?C`1ADE40EUIF05IFEP1JFUX00`1M
GEd205iNGP0505aLG01MGEd0GUiN05iNGP1OGel00`1PH600101NGUh0GEeM05eMG@1MGEd305]KF`80
F5QH00D0EEEE05=CD`1EEED0EEEE05=CD`0205IFEP0405UIF@1KFe/0GEeM05eMG@<0GUiN00D0H61P
065QH@1QHF40H61P069RHP0206ATI005069RHP1MGEd0GEeM05UIF@1JFUX00P1IFET01@1KFe/0GEeM
05eMG@1OGel0H61P0080Hf=S00@0JVYZ07EeM@1eMGD0PX:20P28R8P01@22PX80N7Qh06a/K01/K6`0
GUiN0080EUIF0P1GEeL205EEE@0405=CD`1BDU80DU9B059BDP<0De=C00@0E5AD05IFEP1FEUH0EeMG
0P1HF5P01@1KFe/0G5aL05aLG01LG5`0H61P0080GEeM00D0FEUI05IFEP1FEUH0EUIF05=CD`0205EE
E@<0F5QH00D0EeMG05IFEP1DE5@0E5AD059BDP03055AD@04059BDP1EEED0EEEE05QHF080Fe]K0`1N
GUh205eMG@80G5aL00@0Fe]K05YJFP1JFUX0Fe]K3`3oool000d0oooo00@0UiNG07IfMP1fMWH0dM7A
0P2GUiL01@1nOWh0/K6a09^KV`2KVi/0QXJ60080T92@00D0Zj^[0;Rh^02h^;P0TY:B07YjNP0209RH
V00509JFUP1GEeL0EeMG0?ooo`26QXH00P2EUID0102KVi/0S8b<08b<S02>SXh20820P0050;Rh^02[
Zj/0QHF508F5Q@2EUID00P2SXj<01@2MWId0NGUi0<G5a@35aLD0VIVI0080Ph>300D0VIVI096AT@2?
Shl0Shn?07moO`020:BTY0050?KfmP1OGel0GemO09BDU02EUID00P2?Shl0101]KFd0gMgM0=gMg@2?
Shl309VIV@04096AT@2>SXh0SXj>09:BTP80O7al00D0o?cl069RHP2DU9@0U9BD09FEU@0209VIV@05
06e]K@3moOd0LG5a075aL@2ATI400P26QXH01@2f][H0Shn?08n?S`1ZJVX0a/K60080YjNW00D0RXZ:
096AT@2ATI40Shn?08f=S@0209^KV`050<c<c027QhL0QhN708b<S02HV9P00P2GUiL0102>SXh0Vi^K
09^KV`31`L42079bLP0509ZJVP2BTY80]kNg0;Ng]`1=CDd00P3Zj^X01@2][Jd0KFe]09JFUP2FUYH0
SXj>0080XZ:R00D0Lg=c0>7Qh@3QhN40Rh^;0820P00209^KV`0509FEU@2DU9@0U9BD061PH03oool0
0P1?Cdl01@2LW9`0VYZJ09ZJVP1eMGD0`l?30080^[Zj00<0KFe]09ZJVP2JVYX00`2DU9@01@2JVYX0
Lg=c0?7al@3alO40N7Qh0080Q8B400D0XZ:R09JFUP1cLg<0Lg=c0>OWi`0206i^KP0509jNWP2IVIT0
VIVI096AT@2IVIT00P1jNWX0103Kfm/0Ng]k07]kN`2;Rh/:0?ooo`0402h^;P0[:b/0:b/[02/[:`80
;Rh^00D0<S8b030`<00a<C40<C4a03De=@02038b<P0503De=@0l?3`0?3`l03lo?`0m?Cd00P0l?3`0
1@0h>3P0<c<c03<c<`0^;Rh0:BTY0080:2PX00@09RHV02/[:`0[:b/0;bl_0P0b<S80100e=CD0?3`l
03/k>`0k>c/303`l?00503Xj>P0d=3@0<30`030`<00];Bd00P0/;2`01@0Y:BT0;2`/03De=@0e=CD0
=3@d0080<S8b00@0=3@d030`<00`<3009RHV0`0Q8B401@0O7al07QhN01hN7P0N7Qh07alO00<07QhN
0P0Z:RX01@0/;2`0<C4a034a<@0e=CD0=SHf0080:b/[00D0;2`/02TY:@0Y:BT09BDU02HV9P0202LW
9`0402TY:@0Z:RX0:RXZ030`<080<c<c00<0;Rh^02TY:@0X:2P00P0X:2P202/[:`0503<c<`0g=cL0
>3Ph03Ph>00b<S800P0_;bl01@0[:b/0:RXZ02/[:`0[:b/0:2PX0080820P00D06ATI01hN7P0N7Qh0
92@T02`/;00202l_;`0303De=@0`<300<30`0080:b/[0P0c<c<00`12@T80ATI604I6AP0304M7A`05
04E5A@0j>SX0=CDe03De=@0`<3000P0[:b/01@0X:2P092@T02HV9P0V9RH0;Rh^0080=CDe00D0<c<c
034a<@0];Bd0;Bd]02@T900301/K6`806QXJ0P0K6a/201lO7`05028R8P0W9bL09bLW03<c<`0h>3P0
0P0k>c/303dm?@05038b<P0`<300<30`02h^;P0];Bd00P0_;bl0100a<C40<S8b038b<P0_;bl?0?oo
o`003@3oool0102GUiL0MWIf07IfMP3AdM4209NGU`0507inOP2a/K40Vi^K09^KV`26QXH00P2@T900
1@2[Zj/0^;Rh0;Rh^02BTY80NWYj0080V9RH00D0UYJF05MGE`1GEeL0oooo08J6QP0209FEU@0409^K
V`2<S8`0S8b<08j>SP80P82000D0^;Rh0:^[Z`25QHD0QHF509FEU@020:>SX`0509fMW@1iNGT0aLG5
0<G5a@2IVIT00P23Ph<01@2IVIT0TI6A08n?S`2?Shl0Ogmo0080Y:BT00D0m_Kf05mOG`1OGel0U9BD
09FEU@0208n?S`0406e]K@3MgMd0gMgM08n?S`<0VIVI00@0TI6A08j>SP2>SXh0TY:B0P1lO7`01@3l
o?`0HV9R09BDU02DU9@0UIFE0080VIVI00D0KFe]0?gmo@1aLG40LG5a096AT@0208J6QP050;Jf]P2?
Shl0Shn?06YZJP36a/H00P2WYjL01@2:RXX0TI6A096AT@2?Shl0SHf=0080Vi^K00D0c<c<08N7Q`27
QhL0S8b<09RHV00209NGU`0408j>SP2KVi/0Vi^K0<71`@80LW9b00D0VYZJ09:BTP2g]kL0]kNg04e=
C@020>[ZjP050:f][@1]KFd0UYJF09JFUP2>SXh00P2RXZ801@1cLg<0hN7Q0>7Qh@2;Rh/0P8200080
Vi^K00D0UIFE09BDU02DU9@0H61P0?ooo`0204m?C`0509bLW02JVYX0VYZJ07EeM@33`l<00P2j^[X0
0`1]KFd0VYZJ09ZJVP0309BDU00509ZJVP1cLg<0lO7a0?7al@1hN7P00P24Q8@01@2RXZ80UYJF07=c
L`1cLg<0inOW0080KVi^00D0WYjN09VIV@2IVIT0TI6A09VIV@0207YjNP040=_Kf`1kNg/0Ng]k08^;
R`X0oooo00@0;Rh^02/[:`0[:b/0:b/[0P0^;Rh01@0b<S80<30`034a<@0a<C40=CDe0080<S8b00D0
=CDe03`l?00l?3`0?clo03dm?@0203`l?00503Ph>00c<c<0<c<c02h^;P0Y:BT00P0X:2P0100V9RH0
:b/[02/[:`0_;bl2038b<P0403De=@0l?3`0>c/k03/k>`<0?3`l00D0>SXj03@d=00`<300<30`02d]
;@0202`/;00502TY:@0/;2`0=CDe03De=@0d=3@00P0b<S80100d=3@0<30`030`<00V9RH3024Q8@05
01lO7`0N7Qh07QhN01hN7P0O7al00`0N7Qh202XZ:P0502`/;00a<C40<C4a03De=@0f=SH00P0[:b/0
1@0/;2`0:BTY02TY:@0U9BD09RHV00809bLW00@0:BTY02XZ:P0Z:RX0<30`0P0c<c<00`0^;Rh0:BTY
02PX:00202PX:080:b/[00D0<c<c03Lg=`0h>3P0>3Ph038b<P0202l_;`0502/[:`0Z:RX0:b/[02/[
:`0X:2P00P0P82001@0I6AT07QhN01hN7P0T92@0;2`/0080;bl_00<0=CDe030`<00`<3000P0[:b/2
03<c<`030492@P16ATH0ATI600<0AdM700D0ADE503Xj>P0e=CD0=CDe030`<00202/[:`0502PX:00T
92@09RHV02HV9P0^;Rh00P0e=CD01@0c<c<0<C4a02d];@0];Bd092@T00<06a/K0P0J6QX201/K6`80
7alO00D08R8R02LW9`0W9bL0<c<c03Ph>00203/k>`<0?Cdm00D0<S8b030`<00`<300;Rh^02d];@02
02l_;`04034a<@0b<S80<S8b02l_;`l0oooo000=0?ooo`0409RHV01VIVH0IVIV0>GUi@80W9bL00D0
H61P0=;BdP2ATI40TI6A07inOP020::RXP0509JFUP2UYJD0YJFU0;Zj^P1_Kfl00P2GUiL01@2FUYH0
>SXj03Xj>P3oool0QhN70080Rh^;00@0YJFU0820P020P800TI6A0P2:RXX01@2`/;00WinO09FEU@2E
UID0SHf=0080XZ:R00D0WYjN05iNGP3YjNT0jNWY09^KV`0207YjNP0509NGU`2CTi<0TY:B09:BTP25
QHD00P2][Jd01@36a/H0Ng]k07]kN`2LW9`0TI6A0080T92@00D0EUIF0?gmo@3moOd0UYJF08>3P`02
09jNWP0408n?S`2>SXh0SXj>09jNWP80Q8B400D0clo?07YjNP2JVYX0VYZJ09BDU00209RHV00405MG
E`3oool0G5aL05aLG0<0SXj>00D0YJFU09:BTP2BTY80PH610;2`/0020::RXP0508j>SP2EUID0UIFE
09:BTP28R8P00P2<S8`01@3Xj>P0NWYj07YjNP2@T900UYJF0080V9RH00@0Ti>C09jNWP2NWYh0Y:BT
0P25QHD01@2NWYh0SHf=0:^[Z`2[Zj/0?Cdm0080oooo00D0Zj^[05iNGP2EUID0UIFE08j>SP020::R
XP0508V9R@2n_[h0_[jn096AT@27QhL00`2IVIT208n?S`0504I6AP3oool0<c<c03<c<`2MWId00P2H
V9P01@28R8P0XZ:R0;2`/02`/;00Q8B40080W9bL00D0UYJF09:BTP2BTY80UiNG05iNGP020?ooo`05
06ATI020P800P8200:BTY02JVYX00P24Q8@01032`/80OGem07emO@2NWYh209^KV`05096AT@2IVIT0
JFUY06UYJ@3inOT00P1]KFd00`2<S8`0oooo0?ooo`080?ooo`040;Ng]`2i^KT0^KVi0;Fe]@80[Zj^
00@0/;2`0;:b/P2g]kL0]kNg0`2n_[h01@2j^[X0/K6a0;6a/@2UYJD0WYjN00<0V9RH0P2NWYh01@2X
Z:P0/K6a0<71`@31`L40cLg=0080d];B00D0d=3@0<k>cP3>c/h0b<S80<30`0030;^k^`80/[:b00D0
[jn_0;>c/`2f][H0][Jf0;Bd]0020;Zj^P050<C4a035aLD0`<300<30`033`l<00P36a/H30<30`005
0<G5a@2m_Kd0^[Zj0;Zj^P2i^KT00P2g]kL01@2h^;P0`/;20<g=c@3=cLd0dm?C0080c<c<00<0b/[:
0<O7a`37alL00P2o_kl20<O7a`050<71`@37alL0alO70<o?c`3@d=000P3AdM430=[JfP050=7Ad@3<
c<`0c<c<0<g=c@3:b/X00P37alL30<W9b@050;no_`30`<00`L710<71`@35aLD00P39bLT01@3Bd]80
e=CD0=7Ad@3AdM40d];B0080emOG00D0f][J0=?Cd`3Cdm<0d];B0<O7a`020<;2`P050<G5a@3?cll0
clo?0=CDe03MgMd00P3Ng]h0103Bd]80c/k>0<k>cP3<c<`20<g=c@050<k>cP3Fe]H0f=SH0=SHf03C
dm<00P3GemL00`3IfMT0gMgM0=kNgP020=kNgP<0e]KF0`3De=@0103MgMd0iNGU0>GUi@3Vi^H20>CT
i0030>KViP3YjNT0i^KV0080i^KV0P3Ti>@01@3EeMD0cLg=0<C4a034a<@0^;Rh0080/[:b00D0^k^k
0;bl_02l_;`0^k^k0;bl_0020;^k^`<0^;Rh00<0]kNg0?ooo`3oool03@3oool000d0oooo00@0W9bL
05EEE@1EEED0no_k0P2NWYh00`1=CDd0k>c/07moO`0207moO`80/K6a00D0PX:209FEU@2EUID0fm_K
06EUI@0209FEU@0509JFUP0V9RH09RHV0?ooo`2;Rh/00P22PX80102YZJT0OGem07emO@2BTY8209RH
V00509fMW@2KVi/0WIfM09fMW@2BTY800P2MWId01@2JVYX0AdM70?ooo`3oool0UIFE0080Kfm_00D0
VIVI096AT@2HV9P0V9RH08f=S@020:b/[00509fMW@2EUID0UIFE0:2PX02?Shl00P2BTY801@10@400
oooo0?ooo`2JVYX0NGUi0080WIfM00@0SHf=08n?S`2?Shl0WinO0P2JVYX01@2LW9`0UiNG09VIV@2I
VIT0UIFE0080U9BD00D0Cdm?0?ooo`1=CDd0CDe=08f=S@02092@T0040::RXP2;Rh/0Rh^;09FEU@<0
W9bL00D0VIVI09^KV`2KVi/0U9BD08>3P`0207MgM`050?ooo`1QHF40HF5Q09ZJVP2OWil00P2>SXh0
102JVYX0WIfM09fMW@2@T90209FEU@0509jNWP2LW9`0UIFE09FEU@0W9bL00P3oool01@2XZ:P0EUIF
09JFUP2FUYH0SXj>0080Xj>S00D0Vi^K09FEU@2EUID0XJ6Q08V9R@0209^KV`0509bLW024Q8@0Q8B4
03dm?@3oool00P0V9RH01@2OWil0VIVI09VIV@2BTY80RHV90080Xj>S0`2LW9`309NGU`0509BDU01=
CDd0oooo0?ooo`1@D5000P26QXH01@2OWil0W9bL096AT@2ATI40XJ6Q0080S8b<00D0XZ:R09RHV02H
V9P0T92@09bLW00205UIF@040?ooo`1SHf<0Hf=S08N7Q`X0oooo00@0=3@d03De=@0e=CD0=SHf0P0j
>SX01@0b<S80;Bd]02DU9@0U9BD071`L008061PH00D06QXJ020P800P8200:RXZ03<c<`0203hn?P05
04=3@`12@T80@T9203Xj>P0e=CD00P0V9RH00`0J6QX04A4A014A4@03010@400501<C4`0F5QH06a/K
01/K6`0O7al00P0];Bd01@0e=CD0>3Ph03/k>`0k>c/0?Cdm0080=CDe00D0:b/[02HV9P0Q8B408B4Q
01dM7@0201`L700501lO7`0S8b<08b<S02XZ:P0i>CT00P0n?Sh01@14A4@0B4Q804Q8B017AdL0>c/k
0080<S8b00@0:b/[02DU9@0U9BD08R8R0P0P82001@0R8R808B4Q02<S8`0S8b<0:b/[0080:RXZ0P0W
9bL202DU9@0401TI6@0H61P061PH01TI6@<061PH00@071`L01dM7@0M7Ad071`L0P0M7Ad01@0T92@0
8R8R020P800P82008B4Q00807alO00<05QHF01<C4`0B4Q800P0B4Q8300l?3`804a<C00<05ADE024Q
8@0];Bd00P0];Bd302`/;003028R8P0G5aL05aLG00<05aLG00D06ATI01PH600H61P061PH01XJ6P02
01`L700502HV9P0S8b<08b<S020P800M7Ad00P0J6QX01@0=3@d03Ph>00h>3P0?3`l04Q8B00805ADE
00@05QHF01PH600H61P06QXJ0`0N7Qh301dM7@0501XJ6P0G5aL05aLG01PH600L71`00P0Q8B40100Y
:BT0;bl_02l_;`0b<S8203<c<`80>3Ph0P0f=SH0100e=CD0=3@d03@d=00e=CD?0?ooo`003@3oool0
102LW9`0EEEE05EEE@3kno/209jNWP0304e=C@3/k>`0Ogmo0080Ogmo0P2a/K401@22PX80UIFE09FE
U@3Kfm/0IFEU0080UIFE00D0UYJF02HV9P0V9RH0oooo08^;R`0208:2PP040:VYZ@1mOGd0OGem09:B
TP80V9RH00D0WIfM09^KV`2MWId0WIfM09:BTP0209fMW@0509ZJVP17AdL0oooo0?ooo`2EUID00P1_
Kfl01@2IVIT0TI6A09RHV02HV9P0SHf=0080[:b/00D0WIfM09FEU@2EUID0X:2P08n?S`0209:BTP05
0410@03oool0oooo09ZJVP1iNGT00P2MWId0102=SHd0Shn?08n?S`2OWil209ZJVP0509bLW02GUiL0
VIVI09VIV@2EUID00P2DU9@01@1?Cdl0oooo04e=C@1=CDd0SHf=0080T92@00@0XZ:R08^;R`2;Rh/0
UIFE0`2LW9`01@2IVIT0Vi^K09^KV`2DU9@0Ph>30080MgMg00D0oooo065QH@1QHF40VYZJ09nOW`02
08j>SP0409ZJVP2MWId0WIfM092@T080UIFE00D0WYjN09bLW02EUID0UIFE02LW9`020?ooo`050:RX
Z01FEUH0UYJF09JFUP2>SXh00P2SXj<01@2KVi/0UIFE09FEU@2QXJ40RHV90080Vi^K00D0W9bL08B4
Q024Q8@0?Cdm0?ooo`0202HV9P0509nOW`2IVIT0VIVI09:BTP29RHT00P2SXj<309bLW0<0UiNG00D0
U9BD04e=C@3oool0oooo051@D00208J6QP0509nOW`2LW9`0TI6A096AT@2QXJ400P2<S8`01@2RXZ80
V9RH09RHV02@T900W9bL0080FEUI00@0oooo06=SH`1SHf<0QhN72P3oool0100d=3@0=CDe03De=@0f
=SH203Xj>P05038b<P0];Bd09BDU02DU9@0L71`00P0H61P01@0J6QX0820P020P800Z:RX0<c<c0080
?Shn00D0@d=30492@P12@T80>SXj03De=@0202HV9P0301XJ6P0A4A404A4A00<0410@00D04a<C01HF
5P0K6a/06a/K01lO7`0202d];@0503De=@0h>3P0>c/k03/k>`0m?Cd00P0e=CD01@0[:b/09RHV024Q
8@0Q8B407AdM008071`L00D07alO02<S8`0S8b<0:RXZ03Ti>@0203hn?P0504A4A018B4P0B4Q804M7
A`0k>c/00P0b<S80100[:b/09BDU02DU9@0R8R82020P8005028R8P0Q8B408b<S02<S8`0[:b/00P0Z
:RX202LW9`809BDU00@06ATI01PH600H61P06ATI0`0H61P0100L71`07AdM01dM7@0L71`201dM7@05
02@T900R8R80820P020P800Q8B400P0O7al00`0F5QH04a<C018B4P02018B4P<03`l?0P0C4a<00`0E
5AD08B4Q02d];@0202d];@<0;2`/00<08R8R01LG5`0G5aL00`0G5aL01@0I6AT061PH01PH600H61P0
6QXJ008071`L00D09RHV02<S8`0S8b<0820P01dM7@0201XJ6P0500d=3@0>3Ph03Ph>00l?3`0B4Q80
0P0E5AD0100F5QH061PH01PH600J6QX301hN7P<07AdM00D06QXJ01LG5`0G5aL061PH01`L7002024Q
8@0402TY:@0_;bl0;bl_038b<P80<c<c0P0h>3P203Hf=P0403De=@0d=3@0=3@d03De=@l0oooo000=
0?ooo`040:2PX01?Cdl0Cdm?0?clo080X:2P00D0ATI60?;blP1nOWh0OWin08>3P`020;>c/`0507Ad
M02ATI40TI6A0>;RhP1TI6@00P2JVYX01@2FUYH09RHV02HV9P3oool0SXj>0080OGem00@0YJFU0861
P@21PH40UYJF0P2DU9@01@2CTi<0Y:BT09jNWP2NWYh0TY:B0080Vi^K00D0TY:B04E5A@3oool0oooo
09BDU00206EUI@0509VIV@2ATI40XZ:R0::RXP2:RXX00P2TY:@01@2GUiL0Vi^K09^KV`2TY:@0TI6A
0080SXj>00D0>c/k0?ooo`3oool0Vi^K07MgM`0209VIV@0308n?S`2BTY80TY:B00<0VIVI0P2JVYX2
09bLW00509FEU@2ATI40TI6A04m?C`3oool00P19BDT01029RHT0TY:B09:BTP2ZZZX208J6QP0309:B
TP2NWYh0VIVI0080VIVI0P2QXJ401@2EUID0PH61079bLP1bLW80oooo0080D51@0P2OWil208b<S004
0:6QX@2FUYH0UYJF08b<S080Vi^K00D0VYZJ09bLW02FUYH0UYJF02d];@020?ooo`050:2PX01JFUX0
UiNG09NGU`2@T9000P2PX:001@2MWId0UiNG09NGU`2MWId0S8b<0080W9bL00D0V9RH08N7Q`27QhL0
?Shn0?ooo`0202TY:@0509^KV`2NWYh0WYjN096AT@27QhL00P2YZJT309^KV`0509JFUP2QXJ40XJ6Q
08b<S01>CTh00P3oool01@1BDU80R8R808R8R02RXZ80U9BD0080TI6A00@0YZJV08n?S`2?Shl0WinO
0P2JVYX01@2BTY80UYJF05]KF`1KFe/0oooo0080MGEe00<0NWYj0?ooo`3oool0203oool0101IFET0
F5QH05QHF01KFe/205iNGP0506=SH`1VIVH0JVYZ06YZJP1XJ6P00P1[Jf/01@1ZJVX0IfMW06MWI`1U
IFD0IVIV0080I6AT00@0HV9R06=SH`1SHf<0IVIV0`1WIfL306YZJP0506MWI`1VIVH0IVIV06ATI01S
Hf<00P1RHV801@1PH600Fe]K05]KF`1EEED0DU9B0080D51@00@0De=C05IFEP1FEUH0FUYJ1P1KFe/0
1@1JFUX0Fe]K05]KF`1IFET0EEEE0080De=C00D0DE5A051@D01@D500DU9B05EEE@0505ADE00505EE
E@1HF5P0F5QH05eMG@1QHF400P1SHf<01@1TI6@0HV9R069RHP1OGel0Fe]K0080FEUI00@0EeMG05UI
F@1IFET0FEUI0P1JFUX01@1KFe/0FUYJ05YJFP1JFUX0Fe]K00<0GEeM00@0GUiN05eMG@1MGEd0G5aL
1`1IFET205YJFP<0Fe]K0P1LG5`305YJFP80FEUI00D0F5QH05UIF@1LG5`0G5aL05]KF`0305eMG@80
Fe]K1@1IFET205]KF`0305iNGP1OGel0HF5Q0080HF5Q0`1SHf<0101RHV80GUiN05iNGP1LG5`205UI
F@<0EeMG00@0F5QH05UIF@1KFe/0Fe]K0`1LG5`00`1MGEd0G5aL05aLG00205aLG0D0Fe]K00<0FEUI
05QHF01HF5P01@1HF5P?0?ooo`003@3oool0102RXZ80HF5Q065QH@3Ogml20:BTY00505ADE03YjNT0
Ng]k07]kN`2;Rh/00P2^[Zh01@1NGUh0^;Rh0;Rh^03Fe]H0IfMW0080UIFE00D0VIVI04=3@`13@d<0
oooo09NGU`0207emO@040:VYZ@22PX80PX:209VIV@80Ti>C00D0Ph>30=3@d028R8P0R8R808f=S@02
09nOW`05092@T01LG5`0oooo0?ooo`2DU9@00P1aLG401@2FUYH0TY:B0:BTY02TY:@0RHV90080S8b<
00D0^[Zj09^KV`2KVi/0VYZJ08b<S00209>CT`05051@D03oool0oooo09jNWP1oOgl00P2HV9P0102A
TI40TY:B09:BTP2NWYh208:2PP050;jn_P2:RXX0Vi^K09^KV`2IVIT00P2@T9001@1TI6@0oooo05iN
GP1NGUh0S8b<0080TY:B00D0YZJV08Z:RP2:RXX0S8b<0:>SX`020:BTY00508b<S02UYJD0YJFU09JF
UP26QXH00P1hN7P01@3jn_X0GemO05mOG`2WYjL0VIVI0080Rh^;00@0Shn?0;:b/P2b/[80Rh^;0P2B
TY801@2KVi/0WYjN09FEU@2EUID0C4a<0080oooo00D0TI6A071`L02FUYH0UYJF09>CT`02096AT@05
0::RXP2[Zj/0Zj^[09>CT`2>SXh00P2JVYX01@2CTi<0TI6A096AT@1@D500oooo0080CTi>00D0UYJF
09bLW02LW9`0WIfM06][J`020<g=c@040820P02^[Zh0[Zj^09FEU@80WYjN00D0RHV905=CD`3oool0
oooo05]KF`0209:BTP050::RXP2?Shl0P8200820P030`<000P2ATI4309NGU`0509>CT`2DU9@0JFUY
06UYJ@3bl_800P26QXH00`1kNg/0oooo0?ooo`080?ooo`04069RHP1SHf<0Hf=S06IVIP80IfMW00D0
IFEU06MWI`1XJ6P0J6QX06IVIP0206MWI`0506UYJ@1WIfL0IfMW06MWI`1SHf<01@1PH6000`1QHF40
Hf=S06=SH`0206=SH`80I6AT00D0IFEU06QXJ01XJ6P0IfMW06IVIP0206EUI@05061PH01MGEd0GEeM
061PH01QHF400`1PH602065QH@0505iNGP1OGel0GemO05mOG`1PH6000P1RHV80101QHF40GemO05mO
G`1OGel3065QH@<0GemO00D0GEeM05]KF`1MGEd0GEeM065QH@02069RHP<0I6AT00<0H61P05iNGP1K
Fe/00P1KFe/405UIF@80FUYJ00@0FEUI05YJFP1JFUX0Fe]K0P1IFET505YJFP<0F5QH0`1KFe/0101J
FUX0GEeM05eMG@1OGel405]KF`80FUYJ00D0FEUI05YJFP1JFUX0FEUI05QHF00205IFEP0305ADE01A
DE40DE5A0080D51@0P1ADE40101CDe<0DU9B059BDP1@D50304m?C`04051@D01ADE40DE5A05ADE080
De=C00D0D51@04i>CP1@D500D51@04m?C`02055AD@0305=CD`1FEUH0F5QH00@0F5QH00D0FUYJ05aL
G01LG5`0Fe]K05YJFP0305]KF`80FEUI0P1HF5P205IFEP0405EEE@1CDe<0De=C059BDP@0DE5A0P1E
EED0101IFET0Fe]K05]KF`1PH60?0?ooo`003@3oool0102UYJD0LW9b079bLP37alL20:FUY@0506UY
J@3@d=00P8200820P02ATI400P2XZ:P01@17AdL0m_Kf0?KfmP2WYjL0MGEe0080Ti>C00D0UYJF065Q
H@1QHF40hn?S0:RXZ00207emO@040:6QX@26QXH0QXJ609bLW080TI6A00D0Kfm_0?ooo`1aLG40LG5a
08V9R@020:2PX00508^;R`1eMGD0iNGU0>GUi@2DU9@00P1kNg/01@2DU9@0TI6A0:NWY`2WYjL0RXZ:
0080N7Qh00D0h^;R08>3P`23Ph<0W9bL08^;R`0209FEU@0506ATI03QhN40hN7Q09jNWP25QHD00P2K
Vi/0102<S8`0VYZJ09ZJVP2SXj<2069RHP050?7al@1aLG40Vi^K09^KV`2HV9P00P2GUiL01@1eMGD0
j^[Z07MgM`1gMgL0SXj>0080VIVI00D0WinO08V9R@29RHT0R8R809nOW`020;fm_@0507emO@2WYjL0
YjNW09BDU02>SXh00P1nOWh01@3Ogml0Jf][06][J`2YZJT0UiNG0080SXj>00@0M7Ad0>3Ph03Ph>00
Ng]k0P2>SXh01@2OWil0Vi^K09RHV02HV9P0IFEU0080k^k^00D0TY:B07emO@2IVIT0VIVI09>CT`02
08J6QP0509nOW`3<c<`0c<c<07emO@2BTY800P2GUiL01@2?Shl0WYjN09jNWP1JFUX0oooo0080K6a/
00D0TI6A09fMW@2MWId0Y:BT05QHF0020>KViP0406ATI03@d=00d=3@08J6QP80WIfM00D0QhN705aL
G03oool0oooo06e]K@0209VIV@050:JVYP2;Rh/0K6a/06a/K03Bd]800P2GUiL01@2BTY80TI6A096A
T@2FUYH0Ti>C0080MgMg00@0e]KF09JFUP2FUYH0MGEe2P3oool403Hf=P80<S8b00D0;Bd]02LW9`0S
8b<08b<S02@T900202TY:@<0:RXZ00D0:b/[02XZ:P0];Bd0;Bd]030`<003038b<P0402l_;`0X:2P0
:2PX02<S8`807alO00D07AdM01hN7P0N7Qh092@T02TY:@0202h^;P0303Hf=P12@T80@T9200@0A4A4
00D0@d=303/k>`0k>c/0>3Ph03Hf=P0303Lg=`80=3@d00<0=SHf03Ph>00h>3P00P0f=SH203/k>`05
03dm?@0n?Sh0?Shn03lo?`0m?Cd00`0i>CT203/k>`0403dm?@0n?Sh0?Shn03lo?`<0?3`l00D0?Cdm
03/k>`0k>c/0=SHf038b<P0202/[:`0402DU9@0T92@092@T02@T90809bLW0P0Z:RX202PX:00502TY
:@0W9bL09bLW02`/;00];Bd00P0c<c<01@0g=cL0>3Ph03Ph>00c<c<0=3@d0080<C4a00@0;Rh^02l_
;`0_;bl0;Rh^0P0Z:RX01@0W9bL0;bl_02l_;`0_;bl0;Bd]0080;Rh^00D0;2`/01lO7`0J6QX06QXJ
01TI6@0201`L700501lO7`0T92@092@T02/[:`0^;Rh00P0a<C400`0i>CT0?Cdm03dm?@020410@080
>3Ph00D0;2`/02@T900T92@08B4Q028R8P0202HV9P0302`/;00^;Rh0;Rh^00<0:b/[00D09RHV024Q
8@0L71`071`L01XJ6P02018B4P804a<C0P0G5aL0100I6AT07QhN01hN7P0R8R8202DU9@0502/[:`0/
;2`0<30`030`<00a<C400P0c<c<00`0a<C40oooo0?ooo`0=0?ooo`003@3oool0102UYJD0LW9b079b
LP37alL20:FUY@0506UYJ@3@d=00P8200820P02ATI400P2XZ:P01@17AdL0m_Kf0?KfmP2WYjL0MGEe
0080Ti>C00D0UYJF065QH@1QHF40hn?S0:RXZ00207emO@040:6QX@26QXH0QXJ609bLW080TI6A00D0
Kfm_0?ooo`1aLG40LG5a08V9R@020:2PX00508^;R`1eMGD0iNGU0>GUi@2DU9@00P1kNg/01@2DU9@0
TI6A0:NWY`2WYjL0RXZ:0080N7Qh00D0h^;R08>3P`23Ph<0W9bL08^;R`0209FEU@0506ATI03QhN40
hN7Q09jNWP25QHD00P2KVi/0102<S8`0VYZJ09ZJVP2SXj<2069RHP050?7al@1aLG40Vi^K09^KV`2H
V9P00P2GUiL01@1eMGD0j^[Z07MgM`1gMgL0SXj>0080VIVI00D0WinO08V9R@29RHT0R8R809nOW`02
0;fm_@0507emO@2WYjL0YjNW09BDU02>SXh00P1nOWh01@3Ogml0Jf][06][J`2YZJT0UiNG0080SXj>
00@0M7Ad0>3Ph03Ph>00Ng]k0P2>SXh01@2OWil0Vi^K09RHV02HV9P0IFEU0080k^k^00D0TY:B07em
O@2IVIT0VIVI09>CT`0208J6QP0509nOW`3<c<`0c<c<07emO@2BTY800P2GUiL01@2?Shl0WYjN09jN
WP1JFUX0oooo0080K6a/00D0TI6A09fMW@2MWId0Y:BT05QHF0020>KViP0406ATI03@d=00d=3@08J6
QP80WIfM00D0QhN705aLG03oool0oooo06e]K@0209VIV@050:JVYP2;Rh/0K6a/06a/K03Bd]800P2G
UiL01@2BTY80TI6A096AT@2FUYH0Ti>C0080MgMg00@0e]KF09JFUP2FUYH0MGEe2P3oool403Hf=P80
<S8b00D0;Bd]02LW9`0S8b<08b<S02@T900202TY:@<0:RXZ00D0:b/[02XZ:P0];Bd0;Bd]030`<003
038b<P0402l_;`0X:2P0:2PX02<S8`807alO00D07AdM01hN7P0N7Qh092@T02TY:@0202h^;P0303Hf
=P12@T80@T9200@0A4A400D0@d=303/k>`0k>c/0>3Ph03Hf=P0303Lg=`80=3@d00<0=SHf03Ph>00h
>3P00P0f=SH203/k>`0503dm?@0n?Sh0?Shn03lo?`0m?Cd00`0i>CT203/k>`0403dm?@0n?Sh0?Shn
03lo?`<0?3`l00D0?Cdm03/k>`0k>c/0=SHf038b<P0202/[:`0402DU9@0T92@092@T02@T90809bLW
0P0Z:RX202PX:00502TY:@0W9bL09bLW02`/;00];Bd00P0c<c<01@0g=cL0>3Ph03Ph>00c<c<0=3@d
0080<C4a00@0;Rh^02l_;`0_;bl0;Rh^0P0Z:RX01@0W9bL0;bl_02l_;`0_;bl0;Bd]0080;Rh^00D0
;2`/01lO7`0J6QX06QXJ01TI6@0201`L700501lO7`0T92@092@T02/[:`0^;Rh00P0a<C400`0i>CT0
?Cdm03dm?@020410@080>3Ph00D0;2`/02@T900T92@08B4Q028R8P0202HV9P0302`/;00^;Rh0;Rh^
00<0:b/[00D09RHV024Q8@0L71`071`L01XJ6P02018B4P804a<C0P0G5aL0100I6AT07QhN01hN7P0R
8R8202DU9@0502/[:`0/;2`0<30`030`<00a<C400P0c<c<00`0a<C40oooo0?ooo`0=0?ooo`003@3o
ool0102VYZH0Q8B408B4Q02^[Zh20:FUY@0508:2PP2a/K40QhN708N7Q`2GUiL00P2SXj<01@0l?3`0
oooo0?ooo`2<S8`0P8200080TY:B00D0Shn?0820P020P800_Kfm0;2`/00208F5Q@04092@T02ATI40
TI6A09bLW080UIFE00D0GUiN0?ooo`1NGUh0GUiN08N7Q`020:2PX00508J6QP2;Rh/0cLg=0<g=c@2B
TY800P29RHT01@28R8P0U9BD0:j^[P2^[Zh0RHV90080J6QX00D0oooo071`L01`L700UIFE08j>SP02
09FEU@0507YjNP2n_[h0_[jn09VIV@2>SXh00P2UYJD01029RHT0Y:BT0:BTY02OWil20410@0050?oo
o`1DE5@0V9RH09RHV02GUiL00P2LW9`01@26QXH0^[Zj096AT@2ATI40T92@0080XZ:R00D0VIVI08J6
QP26QXH0PX:20:BTY0020=7Ad@0506a/K02[Zj/0Zj^[096AT@2<S8`00P2BTY801@2o_kl0O7al07al
O02UYJD0UiNG0080T92@00@0G5aL0?ooo`3oool0KFe]0P2>SXh01@2NWYh0VIVI09RHV02HV9P0P820
0080`L7100D0V9RH08Z:RP2JVYX0VYZJ09>CT`0207moO`0509NGU`3YjNT0jNWY06e]K@2GUiL00P2>
SXh01@2JVYX0UYJF09JFUP1`L700fm_K0080QXJ600D0SHf=09bLW02LW9`0Zj^[03dm?@020?ooo`04
065QH@3Lg=`0g=cL07EeM@80W9bL00D0Rh^;06=SH`3YjNT0jNWY07YjNP020:^[Z`050:JVYP23Ph<0
EeMG05MGE`3^k^h00P2ATI401@2FUYH0Rh^;08^;R`2HV9P0TY:B0080QHF500@0^[Zj0:VYZ@2YZJT0
KFe]2P3oool0102[Zj/0ZZZZ0:ZZZP2UYJD20:BTY080YZJV0P2YZJT0102TY:@0VIVI09VIV@2GUiL3
09VIV@030:BTY02_[jl0[jn_00<0/k>c00<0];Bd0;Fe]@2h^;P00P2h^;P20;Vi^@050;:b/P2`/;00
/;2`0:b/[02ZZZX00P2WYjL30;2`/080/K6a0P2c/k<01@2][Jd0Z:RX0:RXZ02XZ:P0ZJVY0080WIfM
00@0VYZJ09bLW02LW9`0Vi^K0P2LW9`01@2VYZH0[:b/0:RXZ02XZ:P0Xj>S0080WinO00<0Vi^K09NG
U`2FUYH00P2FUYH2092@T00508n?S`2@T900T92@096AT@2GUiL00P2RXZ801@2VYZH0[jn_0:n_[`2k
^k/0a<C40080d=3@00@0f=SH0=OGe`3GemL0dm?C0P3;bl/01@38b<P0bLW90<g=c@3=cLd0dm?C0080
fm_K00D0emOG0=3@d03:b/X0b/[:0<O7a`020<G5a@050<[:bP37alL0a/K60<K6aP38b<P00P37alL0
1@36a/H0d=3@0=3@d03Jf]X0e=CD0080e]KF00@0gMgM0>;RhP3Rh^80iNGU0`3`l?00103YjNT0hn?S
0>?Sh`3Ng]h20=[JfP050=SHf03GemL0e=CD0=CDe037alL00P33`l<01@31`L40a/K60<g=c@3=cLd0
g]kN0080hN7Q00D0i>CT0=WIf@3De=@0e=CD0=3@d0020=GEe@030=SHf03IfMT0fMWI0080h>3P0P3R
h^801@3UiND0lo?c0??cl`3alO40m?Cd0080l_;b00@0k^k^0>WYj@3YjNT0j^[Z0P3YjNT01@3Shn<0
hN7Q0=GEe@3EeMD0b/[:0080_kno00<0]kNg0?ooo`3oool03@3oool000d0oooo00@0YjNW096AT@2A
TI40W9bL0P2OWil01@2HV9P0VIVI092@T02@T900V9RH0080Y:BT00D0=3@d0?ooo`3oool0N7Qh08>3
P`0209JFUP0508n?S`2BTY80TY:B0:6QX@2/[:`00P2CTi<01025QHD0SXj>08j>SP2UYJD209bLW005
04U9B@3oool0BTY:04Y:BP25QHD00P2HV9P01@2=SHd0WinO0:FUY@2UYJD0W9bL0080V9RH00D0NGUi
09>CT`2c/k<0/k>c08^;R`02069RHP050?ooo`1HF5P0F5QH09RHV02<S8`00P2DU9@01@2>SXh0YZJV
0:JVYP2ATI40V9RH0080ZZZZ00@0SHf=0::RXP2RXZ80W9bL0P0/;2`01@3oool0?Cdm09>CT`2CTi<0
UiNG0080YZJV00D0SXj>09VIV@2SXj<0Xj>S08b<S0020:ZZZP0509>CT`29RHT0RHV907YjNP2XZ:P0
0P3Kfm/01@1VIVH0ZJVY0:VYZ@2EUID0Rh^;0080XZ:R00D0W9bL09>CT`2CTi<0Xj>S08n?S`0208b<
S00405QHF03oool0oooo06YZJP80QXJ600<0XJ6Q09FEU@2JVYX00P2JVYX209:BTP0509jNWP2MWId0
SXj>08j>SP2KVi/00P1hN7P01@2FUYH0oooo0?ooo`1IFET0YZJV0080QHF500D0U9BD09bLW02LW9`0
QXJ60;2`/00209jNWP0508R8R02IVIT0VIVI0;>c/`0U9BD00P3oool0101MGEd0hn?S0>?Sh`1WIfL2
09ZJVP0508>3P`1hN7P0d];B0=;BdP26QXH00P2h^;P01@2NWYh0Ogmo04U9B@19BDT0oooo0080UYJF
00D0QXJ608V9R@29RHT0VYZJ09RHV00209:BTP0409VIV@2h^;P0^;Rh06e]K@X0oooo00@0BDU904a<
C01<C4`0D51@0P1DE5@01@1HF5P0FUYJ05MGE`1GEeL0FUYJ0080Hf=S0`1VIVH01@1YJFT0HV9R055A
D@1ADE40B4Q80080ADE50P12@T8204U9B@0404i>CP1@D500D51@05EEE@80DU9B00D0D51@04e=C@1:
BTX0BTY:03`l?002038b<P0502l_;`0];Bd0;2`/02`/;00b<S800P0m?Cd203lo?`80C4a<00@0EeMG
05QHF01HF5P0Fe]K0P1NGUh01@1GEeL0CDe=04i>CP1>CTh0EEEE00<0F5QH00@0G5aL05eMG@1MGEd0
FUYJ0P1LG5`01@1KFe/0FUYJ05YJFP1KFe/0EeMG0080DE5A00D0BTY:04A4A014A4@0>SXj03<c<`02
02/[:`<0:RXZ00D0;Bd]02l_;`0_;bl0;2`/02XZ:P0202LW9`05024Q8@0M7Ad07AdM01hN7P0R8R80
1P0U9BD0100V9RH0:RXZ02XZ:P0];Bd202l_;`0503@d=00a<C40<C4a02/[:`0Y:BT00P0V9RH01@0R
8R807AdM01dM7@0L71`06a/K00807alO00<08b<S02LW9`0W9bL00`0Y:BT01@0T92@07alO01`L700L
71`06ATI00806QXJ00D06a/K01TI6@0J6QX06QXJ01PH600301dM7@0402@T900X:2P0:2PX02XZ:P80
8R8R00<08B4Q01lO7`0O7al00P0I6AT201PH600301DE5@0A4A404A4A00805QHF0P0G5aL0100I6AT0
6QXJ01XJ6P0D51@201<C4`0501DE5@0K6a/09RHV02HV9P0a<C400P0l?3`00`15ADD0oooo0?ooo`0=
0?ooo`003@3oool0102WYjL0TI6A096AT@2LW9`209nOW`0509RHV02IVIT0T92@092@T02HV9P00P2T
Y:@01@0d=3@0oooo0?ooo`1hN7P0Ph>30080UYJF00D0Shn?09:BTP2BTY80XJ6Q0:b/[00209>CT`04
08F5Q@2>SXh0SXj>0:FUY@80W9bL00D0BDU90?ooo`1:BTX0BTY:08F5Q@0209RHV00508f=S@2OWil0
YJFU0:FUY@2LW9`00P2HV9P01@1iNGT0Ti>C0;>c/`2c/k<0Rh^;0080HV9R00D0oooo05QHF01HF5P0
V9RH08b<S00209BDU00508j>SP2VYZH0YZJV096AT@2HV9P00P2ZZZX0102=SHd0XZ:R0::RXP2LW9`2
02`/;0050?ooo`0m?Cd0Ti>C09>CT`2GUiL00P2VYZH01@2>SXh0VIVI0:>SX`2SXj<0S8b<0080ZZZZ
00D0Ti>C08V9R@29RHT0NWYj0:RXZ0020=_Kf`0506IVIP2YZJT0ZJVY09FEU@2;Rh/00P2RXZ801@2L
W9`0Ti>C09>CT`2SXj<0Shn?0080S8b<00@0F5QH0?ooo`3oool0JVYZ0P26QXH00`2QXJ40UIFE09ZJ
VP0209ZJVP80TY:B00D0WYjN09fMW@2>SXh0SXj>09^KV`0207QhN00509JFUP3oool0oooo05UIF@2V
YZH00P25QHD01@2DU9@0W9bL09bLW026QXH0/;2`0080WYjN00D0R8R809VIV@2IVIT0/k>c02DU9@02
0?ooo`0405eMG@3Shn<0hn?S06MWI`80VYZJ00D0Ph>307QhN03Bd]80d];B08J6QP020;Rh^00509jN
WP1oOgl0BDU904U9B@3oool00P2FUYH01@26QXH0RHV908V9R@2JVYX0V9RH0080TY:B00@0VIVI0;Rh
^02h^;P0KFe]2P3oool01019BDT0C4a<04a<C01@D50205ADE00505QHF01JFUX0EeMG05MGE`1JFUX0
0P1SHf<306IVIP0506UYJ@1RHV80DE5A055AD@18B4P00P15ADD20492@P80BDU900@0CTi>051@D01@
D500EEEE0P1BDU801@1@D500CDe=04Y:BP1:BTX0?3`l0080<S8b00D0;bl_02d];@0/;2`0;2`/038b
<P0203dm?@80?clo0P1<C4`0101GEeL0F5QH05QHF01KFe/205iNGP0505MGE`1=CDd0CTi>04i>CP1E
EED00`1HF5P0101LG5`0GEeM05eMG@1JFUX205aLG00505]KF`1JFUX0FUYJ05]KF`1GEeL00P1ADE40
1@1:BTX0A4A404A4A00j>SX0<c<c0080:b/[0`0Z:RX01@0];Bd0;bl_02l_;`0/;2`0:RXZ00809bLW
00D08B4Q01dM7@0M7Ad07QhN028R8P0602DU9@0402HV9P0Z:RX0:RXZ02d];@80;bl_00D0=3@d034a
<@0a<C40:b/[02TY:@0202HV9P05028R8P0M7Ad07AdM01`L700K6a/00P0O7al00`0S8b<09bLW02LW
9`0302TY:@0502@T900O7al071`L01`L700I6AT00P0J6QX01@0K6a/06ATI01XJ6P0J6QX061PH00<0
7AdM00@092@T02PX:00X:2P0:RXZ0P0R8R800`0Q8B407alO01lO7`0201TI6@8061PH00<05ADE014A
4@0A4A400P0F5QH201LG5`0401TI6@0J6QX06QXJ01@D50804a<C00D05ADE01/K6`0V9RH09RHV034a
<@0203`l?00304E5A@3oool0oooo00d0oooo000=0?ooo`040:NWY`2CTi<0Ti>C09JFUP80WIfM00D0
X:2P09FEU@2;Rh/0Rh^;09jNWP020:NWY`0502XZ:P3oool0oooo07YjNP22PX800P2EUID01@2@T900
VIVI09VIV@2DU9@0Z:RX0080WIfM00@0QHF508J6QP26QXH0ZZZZ0P2RXZ801@0n?Sh0oooo03hn?P0n
?Sh0R8R80080U9BD00D0UYJF0:2PX02BTY80TY:B0:BTY00209nOW`0507EeM@2DU9@0/[:b0;:b/P2<
S8`00P1RHV801@3oool0CDe=04e=C@2DU9@0TI6A0080TY:B00D0Ti>C09RHV02HV9P0UiNG09FEU@02
0;2`/00408j>SP2RXZ80XZ:R09NGU`809bLW00<0oooo02/[:`2EUID00P2EUID20:BTY080Ti>C0P2W
YjL01024Q8@0];Bd0;Bd]026QXH208R8R00508:2PP2WYjL0iNGU0>GUi@1OGel00P2SXj<01@2FUYH0
TY:B0:>SX`2SXj<0TI6A0080WinO00D0X:2P08j>SP20P800P820061PH0020?ooo`0507emO@1kNg/0
Ng]k09bLW02BTY800P2PX:001@2IVIT0S8b<08b<S02QXJ40Xj>S0080Q8B400@0W9bL07MgM`1gMgL0
W9bL0P3lo?`01@1DE5@0/[:b08:2PP22PX80T92@0080XJ6Q00D0P8200;Bd]02PX:00X:2P08^;R`02
09>CT`050;2`/00Y:BT0oooo0?ooo`1QHF400P3Shn<01@1WIfL0Ti>C09>CT`28R8P0Ng]k0080c/k>
00D0QXJ60;fm_@2m_Kd0V9RH08B4Q00204M7A`040?ooo`2DU9@0U9BD08V9R@80QHF500D0WYjN0:6Q
X@2;Rh/0Rh^;09RHV0020;Fe]@03075aL@3oool0oooo00P0oooo00@0C4a<04M7A`17AdL0@d=30P10
@4001@0n?Sh0?3`l03dm?@0m?Cd0@T920080?3`l100k>c/0100g=cL0?clo03lo?`12@T8204=3@`05
04E5A@14A4@0@T920492@P10@4000P11@D401@16ATH0BDU904U9B@1<C4`0Cdm?0080D51@00D0CDe=
04];B`1;Bd/0BDU904Q8B00204Y:BP0504U9B@1:BTX0BTY:04e=C@1>CTh00P1;Bd/00`15ADD0B4Q8
04Q8B00404U9B@0404a<C019BDT0BDU904A4A080@T9200D0A4A404U9B@1>CTh0CTi>055AD@0205IF
EP<0F5QH00D0EUIF05QHF01EEED0EEEE055AD@0304m?C`0404i>CP1@D500D51@05=CD`80EUIF00D0
EeMG05eMG@1MGEd0Hf=S06ATI00206IVIP0506QXJ01RHV80HV9R05eMG@1IFET00P1GEeL01@1FEUH0
EeMG05MGE`1IFET0HV9R0080HF5Q00@0H61P05mOG`1OGel0GUiN0`1GEeL0101FEUH0EEEE05EEE@1E
EED205ADE00505EEE@1GEeL0FEUI05UIF@1MGEd00P1LG5`01@1NGUh0GemO05mOG`1NGUh0HF5Q0080
Hf=S00D0IfMW06QXJ01XJ6P0Jf][06QXJ00206UYJ@0506MWI`1QHF40HF5Q05UIF@1KFe/00P1EEED0
101ADE40De=C05=CD`1GEeL2055AD@0505IFEP1IFET0GemO05mOG`1SHf<00P1TI6@01@1OGel0H61P
05aLG01LG5`0FEUI0080Fe]K00D0GUiN05eMG@1MGEd0G5aL05QHF00205EEE@04059BDP1?Cdl0Cdm?
04a<C0l0oooo000=0?ooo`040:BTY02GUiL0UiNG08n?S`80[Jf]00D0YJFU0820P02EUID0UIFE09^K
V`020:>SX`0504U9B@3oool0oooo07=cL`29RHT00P2KVi/01@2<S8`0VIVI09VIV@2EUID0Z:RX0080
ZZZZ00@0MgMg08R8R028R8P0ZZZZ0P2TY:@01@1@D500oooo05=CD`1CDe<0Shn?0080Rh^;00D0VIVI
09jNWP2>SXh0SXj>0;Jf]P0209NGU`0507=cL`2HV9P0[:b/0:b/[02CTi<00P1fMWH01@3oool0DE5A
055AD@2JVYX0Ti>C0080V9RH00D0SHf=09>CT`2CTi<0[:b/08J6QP020:n_[`0408Z:RP2XZ:P0Z:RX
09ZJVP80>SXj00D0oooo03hn?P2KVi/0Vi^K092@T0020:NWY`0508F5Q@2RXZ80/;2`0;2`/01mOGd0
0P2^[Zh01@2:RXX0R8R808R8R027QhL0Xj>S0080e]KF00D0Jf][0:>SX`2SXj<0UYJF09BDU002092@
T0050:j^[P2LW9`0W9bL09RHV02>SXh00P24Q8@0101cLg<0oooo0?ooo`1oOgl208F5Q@80UIFE0P2R
XZ801@2ATI40P8200820P038b<P0TI6A0080QhN700@0Ti>C08N7Q`27QhL0W9bL0P3QhN401@1SHf<0
[Jf]08J6QP26QXH0U9BD0080W9bL00D0KVi^0=WIf@2ATI40TI6A08j>SP0209FEU@050::RXP17AdL0
o?cl0?clo01jNWX00P3>c/h01@1YJFT0UYJF09JFUP2=SHd0NWYj0080d=3@00D0S8b<0;6a/@2a/K40
UIFE08b<S002051@D0040?Gem@2KVi/0Vi^K08^;R`80PH6100D0X:2P0:BTY029RHT0RHV909>CT`02
0;Ng]`03079bLP3oool0oooo00P0oooo00<0GemO069RHP1RHV80101SHf<0101UIFD0IVIV06IVIP1V
IVH206a/K00306m_K`1]KFd0KFe]0080J6QX0P1TI6@00`1RHV80HF5Q065QH@02069RHP80GemO00<0
GEeM05iNGP1NGUh00`1NGUh01@1RHV80I6AT06ATI01TI6@0IfMW0080Jf][00D0K6a/06e]K@1]KFd0
KFe]06m_K`0206e]K@0506YZJP1WIfL0IVIV06IVIP1QHF400P1JFUX01@1GEeL0EEEE05EEE@1CDe<0
DE5A0080E5AD00@0EEEE05YJFP1JFUX0G5aL0`1PH60305iNGP0305]KF`1FEUH0EUIF0080De=C0P1?
Cdl01@1BDU80F5QH05QHF01OGel0IFEU0080IVIV00@0IFEU065QH@1QHF40GUiN0P1HF5P0101ADE40
CDe=04I6AP16ATH30410@00504E5A@19BDT0CDe=04e=C@1@D5000P1?Cdl0101<C4`0B4Q804M7A`17
AdL304U9B@0504e=C@1ADE40DE5A05IFEP1HF5P00`1KFe/205aLG00405]KF`1JFUX0F5QH05QHF0<0
FEUI00@0F5QH05UIF@1IFET0HF5Q0`1NGUh01@1SHf<0HV9R069RHP1KFe/0GEeM0080G5aL00D0FEUI
05eMG@1MGEd0IFEU06QXJ00206][J`<0KVi^00D0IFEU06ATI01TI6@0H61P05mOG`0305aLG0<0F5QH
00@0E5AD05QHF01HF5P0GUiN0P1QHF401@1PH600Hf=S06=SH`1OGel0GEeM0080Fe]K0`1NGUh00`1M
GEd0oooo0?ooo`0=0?ooo`003@3oool0102TY:@0UiNG09NGU`2?Shl20:f][@050:FUY@20P800UIFE
09FEU@2KVi/00P2SXj<01@19BDT0oooo0?ooo`1cLg<0RHV90080Vi^K00D0S8b<09VIV@2IVIT0UIFE
0:RXZ0020:ZZZP0407MgM`28R8P0R8R80:ZZZP80Y:BT00D0D51@0?ooo`1CDe<0De=C08n?S`0208^;
R`0509VIV@2NWYh0SXj>08j>SP2f][H00P2GUiL01@1cLg<0V9RH0:b/[02/[:`0Ti>C0080MWIf00D0
oooo055AD@1ADE40VYZJ09>CT`0209RHV00508f=S@2CTi<0Ti>C0:b/[026QXH00P2_[jl0102:RXX0
Z:RX0:RXZ02JVYX203Xj>P050?ooo`0n?Sh0Vi^K09^KV`2@T9000P2WYjL01@25QHD0XZ:R0;2`/02`
/;00OGem0080[Zj^00D0RXZ:08R8R028R8P0QhN70:>SX`020=KFeP0506][J`2SXj<0Xj>S09JFUP2D
U9@00P2@T9001@2^[Zh0W9bL09bLW02HV9P0SXj>0080Q8B400@0Lg=c0?ooo`3oool0Ogmo0P25QHD2
09FEU@80XZ:R00D0TI6A0820P020P800b<S8096AT@0208N7Q`0409>CT`27QhL0QhN709bLW080hN7Q
00D0Hf=S0:f][@26QXH0QXJ609BDU00209bLW00506i^KP3IfMT0TI6A096AT@2>SXh00P2EUID01@2R
XZ80AdM70?clo03lo?`0NWYj0080c/k>00D0JFUY09JFUP2FUYH0SHf=07YjNP020=3@d00508b<S02a
/K40/K6a09FEU@2<S8`00P1@D500103emOD0Vi^K09^KV`2;Rh/20861P@050:2PX02TY:@0RHV908V9
R@2CTi<00P2g]kL00`1bLW80oooo0?ooo`080?ooo`0305mOG`1RHV80HV9R00@0Hf=S00@0IFEU06IV
IP1VIVH0IVIV0P1/K6`00`1_Kfl0KFe]06e]K@0206QXJ080I6AT00<0HV9R065QH@1QHF400P1RHV82
05mOG`0305eMG@1NGUh0GUiN00<0GUiN00D0HV9R06ATI01TI6@0I6AT06MWI`0206][J`0506a/K01]
KFd0KFe]06e]K@1_Kfl00P1]KFd01@1ZJVX0IfMW06IVIP1VIVH0HF5Q0080FUYJ00D0EeMG05EEE@1E
EED0De=C055AD@0205ADE00405EEE@1JFUX0FUYJ05aLG0<0H61P0`1NGUh00`1KFe/0EUIF05IFEP02
05=CD`80Cdm?00D0DU9B05QHF01HF5P0GemO06EUI@0206IVIP0406EUI@1QHF40HF5Q05iNGP80F5QH
00@0DE5A04e=C@16ATH0ATI60`10@4001@15ADD0BDU904e=C@1=CDd0D51@0080Cdm?00@0C4a<04Q8
B017AdL0AdM70`19BDT01@1=CDd0DE5A055AD@1FEUH0F5QH00<0Fe]K0P1LG5`0101KFe/0FUYJ05QH
F01HF5P305UIF@0405QHF01IFET0FEUI065QH@<0GUiN00D0Hf=S069RHP1RHV80Fe]K05eMG@0205aL
G00505UIF@1MGEd0GEeM06EUI@1XJ6P00P1[Jf/306i^KP0506EUI@1TI6@0I6AT061PH01OGel00`1L
G5`305QHF00405ADE01HF5P0F5QH05iNGP80HF5Q00D0H61P06=SH`1SHf<0GemO05eMG@0205]KF`<0
GUiN00<0GEeM0?ooo`3oool03@3oool000d0oooo00@0XJ6Q09>CT`2CTi<0MWIf0P3@d=001@2][Jd0
HF5Q0:NWY`2WYjL0Z:RX0080UYJF00D0IfMW0>KViP3Vi^H0R8R808N7Q`0209jNWP0508j>SP2IVIT0
VIVI08n?S`2g]kL00P2_[jl0101ZJVX0S8b<08b<S02UYJD20:NWY`0506ATI03oool0IfMW06MWI`2F
UYH00P27QhL01@2LW9`0VYZJ07YjNP1jNWX0eMGE0080T92@00D0L71`09VIV@2XZ:P0Z:RX09FEU@02
08J6QP050>[ZjP1[Jf/0Jf][09JFUP2CTi<00P2JVYX01@2>SXh0RXZ:08Z:RP35aLD0MWIf0080[:b/
00@0TY:B09nOW`2OWil0UIFE0P1KFe/01@3oool0EEEE09bLW02LW9`0TI6A0080Xj>S00D0MgMg0;:b
/P30`<00`<3006i^KP020:VYZ@0508j>SP2;Rh/0Rh^;08b<S02UYJD00P2m_Kd01@1jNWX0XJ6Q0:6Q
X@2EUID0UYJF0080Lg=c00D0g=cL09RHV02HV9P0RXZ:092@T00208B4Q00408^;R`3@d=00d=3@096A
T@<0S8b<00@0WIfM09nOW`2OWil0RXZ:0P1mOGd01@3Shn<0Ph>308>3P`23Ph<0UYJF0080TI6A00D0
W9bL0<?3``33`l<0MGEe0:ZZZP0208V9R@0509^KV`2<S8`0S8b<06ATI03oool00P1gMgL01@2CTi<0
UYJF09JFUP2FUYH0GUiN0080hN7Q00@0UIFE0:VYZ@2YZJT0N7Qh0P2HV9P01@2BTY80LW9b0>3Ph03P
h>00Rh^;0080Y:BT00D0RHV909NGU`1UIFD0IFEU0=oOg`0209>CT`0509BDU023Ph<0Ph>309nOW`2Y
ZJT00P20P800102ATI40bl_;0<_;b`1YJFT:0?ooo`0403Xj>P0k>c/0>c/k03`l?0<0?Shn0`10@400
1015ADD0@d=304=3@`11@D420492@P0504=3@`0o?cl0@D510451@@10@4000P0o?cl203`l?080?clo
0`15ADD01@1;Bd/0BTY:04Y:BP16ATH0@D5100<0@T920P16ATH0101;Bd/0CTi>04Y:BP1:BTX304E5
A@0404I6AP19BDT0De=C05=CD`<0EUIF00D0DU9B04i>CP1>CTh0B4Q804I6AP0204=3@`0504E5A@14
A4@0A4A40492@P0l?3`00P0i>CT303De=@0503Lg=`0l?3`0?3`l0492@P16ATH01@18B4P01@13@d<0
?3`l03/k>`0k>c/0?Cdm0080>c/k00D0?Shn04A4A014A4@0C4a<055AD@0205YJFP<0GUiN00D0FUYJ
05MGE`1FEUH0EUIF05ADE002059BDP05055AD@1?Cdl0B4Q804Q8B014A4@00P13@d<01@0o?cl0=SHf
03Hf=P0c<c<0<30`00<0:BTY0P0Z:RX202d];@<0;Rh^0P0/;2`01@0V9RH0820P020P800G5aL04A4A
00804Q8B00D03Ph>01<C4`0C4a<06ATI01XJ6P0201LG5`0501TI6@0P8200820P02HV9P0Y:BT00P0X
:2P0100[:b/08R8R028R8P0V9RH202h^;P0503Hf=P0m?Cd0@4100410@00k>c/00P0h>3P203lo?`80
>CTi00@0<c<c02`/;00/;2`08B4Q0P0L71`01@0P820092@T02/[:`0[:b/0;Rh^0080<S8b00<0=cLg
0?ooo`3oool03@3oool000d0oooo00@0WYjN09:BTP2BTY80GEeM0P3alO401@2_[jl0ADE50<30`030
`<00/;2`0080QXJ600D0Ogmo0<71`@31`L40Shn?08^;R`0209^KV`0509RHV02DU9@0U9BD08J6QP3;
bl/00P2/[:`0101UIFD0Rh^;08^;R`2UYJD20:JVYP0507IfMP3EeMD0OGem07emO@2JVYX00P24Q8@0
1@2WYjL0TY:B06IVIP1VIVH0jn_[0080SXj>00D0NGUi08f=S@2_[jl0[jn_09:BTP0209>CT`050<K6
aP1lO7`0O7al09fMW@2FUYH00P2HV9P01@2@T900QHF508F5Q@3Lg=`0K6a/0080W9bL00@0VYZJ09VI
V@2IVIT0UIFE0P1oOgl01@3Cdm<0LG5a0:2PX02PX:00U9BD0080X:2P00D0IfMW0<S8b03:b/X0b/[:
065QH@020::RXP0508n?S`2BTY80TY:B09BDU02NWYh00P2ZZZX01@2;Rh/0WIfM09fMW@2GUiL0VIVI
0080EEEE00D0oooo08f=S@2=SHd0RHV908^;R`0208J6QP0409^KV`2a/K40/K6a09nOW`80Rh^;00D0
Q8B40:b/[02KVi/0Vi^K07alO00208>3P`040?clo01`L700Q8B408B4Q0<0UiNG00D0WinO0:RXZ02X
Z:P0Ogmo0;6a/@0209:BTP0508R8R02;Rh/0Rh^;061PH03oool00P1PH6001@2DU9@0UYJF09JFUP2?
Shl0Ng]k0080`l?300@0UIFE09jNWP2NWYh0QhN70P2FUYH01@2ATI40M7Ad0>SXj03Xj>P0U9BD0080
SXj>00D0R8R809RHV01oOgl0Ogmo0<[:bP0208n?S`05096AT@2BTY80TY:B09nOW`2XZ:P00P1eMGD0
102ATI40hN7Q0>7Qh@1NGUh:0?ooo`0306YZJP1SHf<0Hf=S00<0I6AT00<0JFUY071`L01cLg<00P1c
Lg<207]kN`0507alO01nOWh0OWin08>3P`25QHD00P22PX801@21PH40PX:208:2PP29RHT0SHf=0080
Ti>C00@0UYJF09VIV@2IVIT0UYJF0P2CTi<01@2@T900Shn?08Z:RP2:RXX0Ph>30080OWin00D0MGEe
071`L01bLW80LW9b07=cL`0207AdM00507YjNP1oOgl0OGem07emO@1nOWh00P20P8001@22PX80P820
0820P021PH40QHF50080QXJ600D0QHF508R8R028R8P0Rh^;08V9R@0208Z:RP0408n?S`2DU9@0U9BD
08n?S`80SHf=00D0QhN707moO`1hN7P0N7Qh07MgM`0207AdM00507MgM`1oOgl0PH610861P@27QhL0
0P2CTi<01@2HV9P0VIVI09VIV@2IVIT0UiNG0080Ti>C00D0U9BD09FEU@2EUID0SXj>08Z:RP0208J6
QP0508>3P`21PH40PH61096AT@2OWil00P2`/;000`2e]KD0^;Rh0;Rh^0030;6a/@050:^[Z`2ZZZX0
YjNW0:NWY`2/[:`00P2ZZZX01@2[Zj/0/;2`0;no_`2o_kl0aLG50080d=3@00D0gMgM0>SXj03Xj>P0
k>c/0?;blP020?3`l0050>;RhP3Jf]X0f][J0=KFeP3Cdm<00P3EeMD01@3QhN40h>3P0>3Ph03Ph>00
gMgM0080g]kN00@0fm_K0>7Qh@3QhN40gmoO0P3Fe]H01@3=cLd0alO70<71`@31`L40`<300080aLG5
00D0_Kfm0;Vi^@2k^k/0^k^k0;jn_P020<C4a0050=CDe03IfMT0fMWI0=GEe@3:b/X00P2f][H0102R
XZ80SXj>08j>SP1kNg/?0?ooo`003@3oool0102MWId0T92@092@T01;Bd/20?ooo`050;Jf]P0Y:BT0
fMWI0=WIf@2e]KD00P1dM7@01@2FUYH0WinO09nOW`2DU9@0VIVI0080U9BD00D0VYZJ09BDU02DU9@0
N7Qh0>[ZjP020:BTY00405mOG`2>SXh0SXj>0::RXP80WinO00D0SHf=0:ZZZP2?Shl0Shn?0:6QX@02
08J6QP050:j^[P29RHT0Fe]K05]KF`3emOD00P2>SXh01@20P800RHV90:n_[`2_[jl0U9BD0080Vi^K
00D0Y:BT08n?S`2?Shl0Vi^K09BDU00209VIV@0509FEU@1mOGd0OGem0?Gem@1KFe/00P2FUYH309^K
V`0509VIV@2@T900T92@0:FUY@26QXH00P2UYJD01@2FUYH0WYjN09jNWP1EEED0g=cL0080dM7A00@0
F5QH09jNWP2NWYh0Shn?0P2BTY801@2PX:00UiNG09jNWP2NWYh0V9RH0080UYJF00D0UIFE09ZJVP0h
>3P0>3Ph0?ooo`0208b<S00508:2PP29RHT0Rh^;08^;R`2QXJ400P2LW9`01@2UYJD0Shn?08n?S`1c
Lg<0`/;20080U9BD00D0Ng]k08N7Q`27QhL0oooo05MGE`0208b<S00409>CT`2MWId0WIfM09nOW`80
Ti>C00D0QHF50;Jf]P2JVYX0VYZJ08>3P`02096AT@0504i>CP3oool0A4A404A4A02GUiL00P2DU9@0
1@2<S8`0VIVI0:2PX02PX:00UYJF0080V9RH00D0UIFE09NGU`2GUiL0Ti>C06ATI0020?gmo@0409>C
T`1jNWX0NWYj09>CT`<0U9BD00@0];Bd0861P@21PH40XZ:R0P2QXJ401@2DU9@0YJFU06][J`1[Jf/0
UIFE0080moOg00<0Cdm?0?ooo`3oool0203oool0102WYjL0ZJVY0:VYZ@2SXj<209RHV00508J6QP1n
OWh0O7al07alO01fMWH00P1`L7001@1cLg<0LG5a075aL@1/K6`0KFe]0080L71`00@0KVi^071`L01`
L700KVi^0`1`L700101bLW80L71`071`L01^KVh206m_K`80LG5a0P1cLg<01@1jNWX0Ng]k07]kN`1l
O7`0Ng]k0080N7Qh00D0MGEe06i^KP1^KVh0IfMW05mOG`0205MGE`0405=CD`1BDU80DU9B05=CD`80
FEUI00D0H61P069RHP1VIVH0IVIV06YZJP0206UYJ@0506][J`1dM7@0O7al07alO01mOGd00P1hN7P0
1@1nOWh0OGem07emO@1mOGd0P8200080RHV900D0RXZ:08R8R028R8P0Q8B407alO00207QhN004075a
L@1XJ6P0J6QX065QH@80GUiN00D0G5aL05iNGP1PH600H61P065QH@0206=SH`0506QXJ01YJFT0K6a/
06a/K01^KVh00P1aLG401@1WIfL0FEUI04a<C01<C4`0AdM70080@D5100D0ADE504Y:BP1:BTX0Cdm?
051@D00205YJFP<0EeMG00D0De=C04m?C`0m?Cd0?Cdm034a<@0202LW9`0401lO7`0H61P061PH01HF
5P<06ATI00D092@T02`/;00/;2`0<C4a03@d=00203Hf=P0502h^;P0U9BD09BDU01`L700F5QH00P0C
4a<0100@41004A4A014A4@0D51@201TI6@0501hN7P0P820092@T02@T900W9bL00P0Y:BT01@0b<S80
?3`l03/k>`0k>c/0>CTi0080=CDe00D0:BTY02<S8`0S8b<09RHV034a<@0204M7A`04065QH@1lO7`0
O7al09RHV0l0oooo000=0?ooo`0409fMW@2@T900T92@04];B`80oooo00D0][Jf02TY:@3IfMT0fMWI
0;Fe]@0207AdM00509JFUP2OWil0WinO09BDU02IVIT00P2DU9@01@2JVYX0U9BD09BDU01hN7P0j^[Z
0080Y:BT00@0GemO08j>SP2>SXh0XZ:R0P2OWil01@2=SHd0ZZZZ08n?S`2?Shl0XJ6Q0080QXJ600D0
[Zj^08V9R@1KFe/0Fe]K0?Gem@0208j>SP050820P029RHT0[jn_0:n_[`2DU9@00P2KVi/01@2TY:@0
Shn?08n?S`2KVi/0U9BD0080VIVI00D0UIFE07emO@1mOGd0mOGe05]KF`0209JFUP<0Vi^K00D0VIVI
092@T02@T900YJFU08J6QP020:FUY@0509JFUP2NWYh0WYjN05EEE@3Lg=`00P3AdM40101HF5P0WYjN
09jNWP2?Shl209:BTP050:2PX02GUiL0WYjN09jNWP2HV9P00P2FUYH01@2EUID0VYZJ03Ph>00h>3P0
oooo0080S8b<00D0PX:208V9R@2;Rh/0Rh^;0:6QX@0209bLW0050:FUY@2?Shl0Shn?07=cL`32`/80
0P2DU9@01@1kNg/0QhN708N7Q`3oool0EeMG0080S8b<00@0Ti>C09fMW@2MWId0WinO0P2CTi<01@25
QHD0][Jf09ZJVP2JVYX0Ph>30080TI6A00D0CTi>0?ooo`14A4@0A4A409NGU`0209BDU00508b<S02I
VIT0X:2P0:2PX02FUYH00P2HV9P01@2EUID0UiNG09NGU`2CTi<0I6AT0080oOgm00@0Ti>C07YjNP1j
NWX0Ti>C0`2DU9@0102d];@0PH610861P@2RXZ820:6QX@0509BDU02UYJD0Jf][06][J`2EUID00P3g
moL00`1?Cdl0oooo0?ooo`080?ooo`040:NWY`2YZJT0ZJVY0:>SX`80V9RH00D0QXJ607inOP1lO7`0
O7al07IfMP02071`L00507=cL`1aLG40LG5a06a/K01]KFd00P1`L700101^KVh0L71`071`L01^KVh3
071`L004079bLP1`L700L71`06i^KP80Kfm_0P1aLG4207=cL`0507YjNP1kNg/0Ng]k07alO01kNg/0
0P1hN7P01@1eMGD0KVi^06i^KP1WIfL0GemO0080EeMG00@0De=C059BDP1BDU80De=C0P1IFET01@1P
H600HV9R06IVIP1VIVH0JVYZ0080JFUY00D0Jf][07AdM01lO7`0O7al07emO@0207QhN00507inOP1m
OGd0OGem07emO@20P8000P29RHT01@2:RXX0R8R808R8R024Q8@0O7al0080N7Qh00@0LG5a06QXJ01X
J6P0HF5Q0P1NGUh01@1LG5`0GUiN061PH01PH600HF5Q0080Hf=S00D0J6QX06UYJ@1/K6`0K6a/06i^
KP02075aL@0506MWI`1IFET0C4a<04a<C017AdL00P11@D401@15ADD0BTY:04Y:BP1?Cdl0D51@0080
FUYJ0`1GEeL01@1CDe<0Cdm?03dm?@0m?Cd0<C4a00809bLW00@07alO01PH600H61P05QHF0`0I6AT0
1@0T92@0;2`/02`/;00a<C40=3@d0080=SHf00D0;Rh^02DU9@0U9BD071`L01HF5P0201<C4`04010@
400A4A404A4A01@D50806ATI00D07QhN020P800T92@092@T02LW9`0202TY:@05038b<P0l?3`0>c/k
03/k>`0i>CT00P0e=CD01@0Y:BT08b<S02<S8`0V9RH0<C4a0080AdM700@0HF5Q07alO01lO7`0V9RH
3`3oool000d0oooo00@0UYJF09jNWP2NWYh0@T920P3oool01@2f][H06a/K0>c/k03/k>`0YjNW0080
MgMg00D0YjNW08J6QP26QXH0UIFE0:NWY`0208n?S`0509NGU`2ATI40TI6A07MgM`3jn_X00P2ZZZX0
101=CDd0UIFE09FEU@2JVYX209jNWP0509NGU`2EUID0VYZJ09ZJVP2OWil00P2:RXX01@2YZJT0SHf=
05YJFP1JFUX0lo?c0080WinO00D0Lg=c08f=S@2a/K40/K6a09>CT`020:6QX@0508f=S@2LW9`0W9bL
09nOW`2;Rh/00P2OWil01@2IVIT0Kfm_06m_K`3oool0F5QH0080Shn?00@0XJ6Q09RHV02HV9P0UiNG
0P2NWYh01@28R8P0UIFE0:6QX@2QXJ40Vi^K0080Xj>S00D0BTY:0>?Sh`3Hf=P0f=SH05ADE00209BD
U00509RHV02FUYH0UYJF0:2PX02ATI400P2HV9P01@2UYJD0UYJF09JFUP2BTY80UYJF0080:2PX00D0
oooo09>CT`2CTi<0OGem08b<S00209>CT`0409BDU02NWYh0WYjN09JFUP80Ti>C00D0LW9b0=3@d028
R8P0R8R807emO@0209JFUP050?ooo`1=CDd0Ti>C09>CT`2GUiL00P2NWYh01@2GUiL0T92@092@T02@
T900ZJVY0080WinO00D0P82008f=S@2=SHd0CDe=0?ooo`0203`l?00509RHV02=SHd0SHf=09:BTP2N
WYh00P2GUiL0102CTi<0V9RH09RHV02HV9P209NGU`05092@T01TI6@0oooo0?ooo`2?Shl00P1bLW80
1@2MWId0Shn?09JFUP2FUYH0/[:b0080OGem00D0Y:BT0:VYZ@2YZJT0Shn?09nOW`0206YZJP0409fM
W@3moOd0oOgm04A4A0X0oooo00@0:RXZ02d];@0];Bd0<30`0P0k>c/00`17AdL0ATI604=3@`0204=3
@`80@D5100D0>SXj03/k>`0k>c/0?Cdm0410@0020492@P0504M7A`16ATH0ATI604A4A00o?cl00P0i
>CT0100`<300;2`/02`/;00Z:RX202TY:@0502XZ:P0/;2`0:b/[02/[:`0];Bd00P0_;bl01@0f=SH0
>SXj0451@@11@D40BDU90080CTi>00<0D51@05=CD`1FEUH00P1FEUH205QHF00505EEE@1BDU80DU9B
04m?C`19BDT00P18B4P304A4A00504=3@`0n?Sh0=cLg03Lg=`0e=CD00P0b<S800`0`<300<C4a034a
<@0203<c<`<0<C4a0P0f=SH0100h>3P0?3`l03hn?P0n?Sh70410@00403hn?P0l?3`0?3`l03dm?@80
>c/k00<0@D5104A4A012@T801012@T8203hn?P80@d=300@0ADE504Q8B018B4P0B4Q80P1:BTX01@1<
C4`0Bd];04Y:BP1:BTX0C4a<0080Bd];00D0CDe=051@D01CDe<0De=C05IFEP0205UIF@0505MGE`1F
EUH0EUIF05QHF01EEED00P1BDU800`1DE5@0D51@051@D00204e=C@80Cdm?00D0CTi>05ADE01DE5@0
F5QH05UIF@0205]KF`<0GEeM00D0FUYJ05]KF`1KFe/0FUYJ05MGE`0205EEE@0505YJFP1GEeL0EeMG
055AD@1?Cdl00P1ADE40101>CTh0DE5A055AD@1LG5`2065QH@05061PH01NGUh0EUIF05IFEP18B4P0
0P0j>SX00`0/;2`0oooo0?ooo`0=0?ooo`003@3oool0102QXJ40ZZZZ0:ZZZP0n?Sh20?ooo`050;2`
/00`<300fMWI0=WIf@2e]KD00P26QXH01@2CTi<0QXJ608J6QP2KVi/0XJ6Q0080SHf=00D0VYZJ0:ZZ
ZP2ZZZX0JFUY0?Ogm`0209VIV@0405iNGP29RHT0RHV909^KV`80[Jf]00D0TY:B09FEU@2IVIT0VIVI
09jNWP0208J6QP050:>SX`2UYJD0EeMG05MGE`3Ogml00P2UYJD01@1iNGT0Q8B40:n_[`2_[jl0YjNW
0080VYZJ00D0RXZ:09^KV`2KVi/0X:2P07]kN`020:>SX`050;>c/`1WIfL0IfMW0?Shn01QHF400P2=
SHd0102JVYX0Xj>S0:>SX`2JVYX209JFUP05096AT@2<S8`0WinO09nOW`29RHT00P2f][H01@1OGel0
clo?0=7Ad@3AdM40FEUI0080RXZ:00D0YjNW0:FUY@2UYJD0Ti>C08V9R@0209nOW`030:FUY@2:RXX0
RXZ:0080WIfM0P0a<C401@3oool0U9BD09BDU01iNGT0TY:B0080Xj>S00@0TY:B09VIV@2IVIT0VIVI
0P2ATI401@1RHV80inOW08Z:RP2:RXX0NWYj0080Xj>S00D0g]kN05iNGP27QhL0QhN70<30`00308j>
SP80V9RH00D0S8b<09ZJVP2][Jd0[Jf]08n?S`0208V9R@05069RHP3oool0?Cdm03dm?@2?Shl00P2`
/;001@2ATI40T92@09NGU`2GUiL0Y:BT0080RXZ:00D0S8b<0;fm_@2m_Kd0PH6106a/K0020?Gem@05
08J6QP1aLG40LG5a0:NWY`2SXj<00P2>SXh0102XZ:P0NGUi07UiN@2WYjL209^KV`050:VYZ@2JVYX0
JVYZ06YZJP2TY:@00P3Rh^800`1;Bd/0oooo0?ooo`080?ooo`<0F5QH00D0FEUI05YJFP1JFUX0GEeM
05mOG`0206=SH`0406ATI01VIVH0IVIV06IVIP80I6AT00D0Hf=S069RHP1QHF40HF5Q061PH00205mO
G`0305eMG@1LG5`0FEUI0080FEUI0`1JFUX205eMG@0505iNGP1MGEd0GUiN05iNGP1LG5`00P1IFET5
05]KF`80GUiN00D0GEeM05mOG`1TI6@0I6AT06a/K00207=cL`0507inOP22PX80PX:208:2PP1oOgl0
0P1gMgL01@1]KFd0I6AT06ATI01NGUh0FUYJ00<0F5QH0`1IFET205QHF00505IFEP1DE5@0EEEE05EE
E@1GEeL00P1HF5P01@1JFUX0Fe]K05]KF`1KFe/0FUYJ00H0FEUI00@0FUYJ05]KF`1KFe/0Fe]K0`1M
GEd305UIF@@0F5QH0`1LG5`305eMG@0505iNGP1JFUX0FUYJ05EEE@1FEUH00P1HF5P01@1JFUX0GemO
05mOG`1UIFD0Hf=S0080HF5Q00@0H61P05eMG@1MGEd0G5aL0P1IFET01@1FEUH0DU9B05QHF01HF5P0
GUiN0080HV9R00D0IFEU06QXJ01RHV80HV9R05aLG00205UIF@0305MGE`1HF5P0FUYJ0080FUYJ0P1M
GEd01@1OGel0GEeM05eMG@1MGEd0GUiN0080G5aL00D0EeMG05UIF@1IFET0F5QH05IFEP0205EEE@04
05]KF`1MGEd0GEeM05UIF@80FUYJ00@0Fe]K05UIF@1FEUH0EUIF0`1IFET00`1HF5P0oooo0?ooo`0=
0?ooo`003@3oool0102QXJ40ZZZZ0:ZZZP0n?Sh20?ooo`050;2`/00`<300fMWI0=WIf@2e]KD00P26
QXH01@2CTi<0QXJ608J6QP2KVi/0XJ6Q0080SHf=00D0VYZJ0:ZZZP2ZZZX0JFUY0?Ogm`0209VIV@04
05iNGP29RHT0RHV909^KV`80[Jf]00D0TY:B09FEU@2IVIT0VIVI09jNWP0208J6QP050:>SX`2UYJD0
EeMG05MGE`3Ogml00P2UYJD01@1iNGT0Q8B40:n_[`2_[jl0YjNW0080VYZJ00D0RXZ:09^KV`2KVi/0
X:2P07]kN`020:>SX`050;>c/`1WIfL0IfMW0?Shn01QHF400P2=SHd0102JVYX0Xj>S0:>SX`2JVYX2
09JFUP05096AT@2<S8`0WinO09nOW`29RHT00P2f][H01@1OGel0clo?0=7Ad@3AdM40FEUI0080RXZ:
00D0YjNW0:FUY@2UYJD0Ti>C08V9R@0209nOW`030:FUY@2:RXX0RXZ:0080WIfM0P0a<C401@3oool0
U9BD09BDU01iNGT0TY:B0080Xj>S00@0TY:B09VIV@2IVIT0VIVI0P2ATI401@1RHV80inOW08Z:RP2:
RXX0NWYj0080Xj>S00D0g]kN05iNGP27QhL0QhN70<30`00308j>SP80V9RH00D0S8b<09ZJVP2][Jd0
[Jf]08n?S`0208V9R@05069RHP3oool0?Cdm03dm?@2?Shl00P2`/;001@2ATI40T92@09NGU`2GUiL0
Y:BT0080RXZ:00D0S8b<0;fm_@2m_Kd0PH6106a/K0020?Gem@0508J6QP1aLG40LG5a0:NWY`2SXj<0
0P2>SXh0102XZ:P0NGUi07UiN@2WYjL209^KV`050:VYZ@2JVYX0JVYZ06YZJP2TY:@00P3Rh^800`1;
Bd/0oooo0?ooo`080?ooo`<0F5QH00D0FEUI05YJFP1JFUX0GEeM05mOG`0206=SH`0406ATI01VIVH0
IVIV06IVIP80I6AT00D0Hf=S069RHP1QHF40HF5Q061PH00205mOG`0305eMG@1LG5`0FEUI0080FEUI
0`1JFUX205eMG@0505iNGP1MGEd0GUiN05iNGP1LG5`00P1IFET505]KF`80GUiN00D0GEeM05mOG`1T
I6@0I6AT06a/K00207=cL`0507inOP22PX80PX:208:2PP1oOgl00P1gMgL01@1]KFd0I6AT06ATI01N
GUh0FUYJ00<0F5QH0`1IFET205QHF00505IFEP1DE5@0EEEE05EEE@1GEeL00P1HF5P01@1JFUX0Fe]K
05]KF`1KFe/0FUYJ00H0FEUI00@0FUYJ05]KF`1KFe/0Fe]K0`1MGEd305UIF@@0F5QH0`1LG5`305eM
G@0505iNGP1JFUX0FUYJ05EEE@1FEUH00P1HF5P01@1JFUX0GemO05mOG`1UIFD0Hf=S0080HF5Q00@0
H61P05eMG@1MGEd0G5aL0P1IFET01@1FEUH0DU9B05QHF01HF5P0GUiN0080HV9R00D0IFEU06QXJ01R
HV80HV9R05aLG00205UIF@0305MGE`1HF5P0FUYJ0080FUYJ0P1MGEd01@1OGel0GEeM05eMG@1MGEd0
GUiN0080G5aL00D0EeMG05UIF@1IFET0F5QH05IFEP0205EEE@0405]KF`1MGEd0GEeM05UIF@80FUYJ
00@0Fe]K05UIF@1FEUH0EUIF0`1IFET00`1HF5P0oooo0?ooo`0=0?ooo`003@3oool0102b/[80bl_;
0<_;b`0k>c/20=kNgP050:j^[P1ADE40[Jf]0:f][@37alL00P2PX:001@21PH40RXZ:08Z:RP2EUID0
WinO0080NGUi00D0Z:RX0=WIf@3IfMT0C4a<0>;RhP0209JFUP0406a/K01hN7P0N7Qh09:BTP80j>SX
00D0MGEe08n?S`2LW9`0W9bL09fMW@0207moO`0509VIV@3@d=00EUIF05IFEP2l_;`00P2c/k<01@1j
NWX0NGUi0;Jf]P2f][H0^[Zj0080Rh^;00D0RXZ:09FEU@2EUID0XZ:R06a/K0020:NWY`050=_Kf`1B
DU80DU9B0=kNgP1hN7P00P28R8P01022PX80_Kfm0;fm_@2[Zj/208>3P`0509BDU02;Rh/0V9RH09RH
V01hN7P00P3Lg=`01@1RHV80_[jn0<30`030`<00I6AT0080S8b<00D0WYjN0<O7a`37alL0NWYj08^;
R`0209jNWP0509^KV`2:RXX0RXZ:0:f][@2SXj<00P0o?cl01@3gmoL0XJ6Q0:6QX@21PH40MgMg0080
eMGE00@0NGUi09VIV@2IVIT0WYjN0P2<S8`01@1FEUH0oOgm08Z:RP2:RXX0NWYj0080YZJV00D0`<30
06UYJ@1gMgL0MgMg0>o_k`0207alO00508R8R02EUID0UIFE08n?S`26QXH00P39bLT01@2GUiL0Ogmo
07moO`1gMgL0oooo0080Bd];00D0O7al0>_[j`3[jn/0QHF508>3P`0209JFUP040:FUY@22PX80PX:2
07EeM@80nOWi00D0HV9R07alO03Ng]h0g]kN08N7Q`0206ATI0050;Jf]P30`<00MWIf07IfMP2[Zj/0
0P1mOGd01@2OWil0OWin07inOP3Lg=`0R8R80080L71`00@0Xj>S0<c<c03<c<`0@T922P3oool01014
A4@0C4a<04a<C01BDU8205eMG@05069RHP1MGEd0EeMG05MGE`1HF5P00P1CDe<01@1ADE40EEEE05EE
E@1GEeL0E5AD00<0De=C0P1ADE400`1@D500DE5A05MGE`0205MGE`80F5QH00D0EeMG05ADE01DE5@0
De=C059BDP0205=CD`05055AD@1>CTh0CTi>04M7A`11@D400`0l?3`203hn?P050451@@12@T80@410
0410@00j>SX00P0a<C401@0X:2P09BDU02DU9@0W9bL0;Bd]0080=3@d00D0>SXj03hn?P0n?Sh0?clo
03hn?P020410@00403lo?`10@400@41004=3@`80ADE500D0B4Q804Y:BP1;Bd/0Bd];04e=C@0204a<
C00504];B`1:BTX0BDU904U9B@16ATH00P14A4@01@13@d<0@D510451@@12@T80?Shn0080?Cdm0`0l
?3`01@11@D40BTY:04i>CP1>CTh0Cdm?0080D51@00<0CDe=04Q8B016ATH01016ATH00`19BDT0Bd];
04];B`0404e=C@0504=3@`0k>c/0>c/k03<c<`0`<3000P0^;Rh0100`<300=3@d03@d=00n?Sh204M7
A`0504e=C@1EEED0EeMG05MGE`1@D5000P18B4P01@11@D40>3Ph03@d=00d=3@0<S8b00<0<c<c0`0e
=CD0100f=SH0<c<c03<c<`0c<c<203/k>`0503hn?P10@400A4A404A4A015ADD00P10@4000`12@T80
@d=304I6AP0204I6AP80?Shn00D0>3Ph03<c<`0c<c<0;Bd]02l_;`0203Hf=P0403Xj>P0k>c/0>c/k
03lo?`l0oooo000=0?ooo`040<C4a03Zj^X0j^[Z03lo?`80^KVi00D0YZJV06e]K@29RHT0RHV90=_K
f`020;fm_@0506ATI02?Shl0Shn?09NGU`2JVYX00P1WIfL01@2^[Zh0oooo0?ooo`0b<S80a/K60080
UiNG00@0NWYj06IVIP1VIVH0Shn?0P3oool00`1DE5@0RHV909jNWP0209jNWP80NWYj00D0QhN70?oo
o`1ADE40DE5A0:BTY0020:n_[`0507]kN`1jNWX0/K6a0;6a/@3IfMT00P1oOgl01@25QHD0TI6A096A
T@2TY:@0EEEE0080/[:b00D0oooo03/k>`0k>c/0aLG508R8R00208j>SP0406][J`3GemL0emOG0;Ng
]`80LW9b00D0UiNG08V9R@2BTY80TY:B06MWI`020?ooo`0506MWI`2a/K40[:b/0:b/[01YJFT00P2<
S8`01@2^[Zh0dm?C0=?Cd`1ZJVX0SXj>0080W9bL00D0UiNG07AdM01dM7@0c<c<0:BTY00204];B`05
0=?Cd`2YZJT0ZJVY07moO`1`L7000P3kno/0101UIFD0Shn?08n?S`2QXJ4209BDU00504U9B@3oool0
TY:B09:BTP1jNWX00P2RXZ801@2QXJ40OGem06EUI@1UIFD0oooo0080IfMW00D0R8R809:BTP2BTY80
UIFE06YZJP020>7Qh@050:JVYP1nOWh0OWin07alO03?cll00P1JFUX01@1XJ6P0oooo0?ooo`1jNWX0
MWIf0080UYJF00@0YjNW07inOP1nOWh0DE5A0P3oool01@1>CTh0Q8B40<C4a034a<@0QHF50080EeMG
00D0b<S80>KViP1FEUH0EUIF0:BTY00208V9R@0509bLW01KFe/0Fe]K0?ooo`22PX800P1bLW80102T
Y:@0/k>c0;>c/`0k>c/:0?ooo`04079bLP1^KVh0KVi^06a/K080HV9R00D0DE5A04Y:BP1<C4`0C4a<
04];B`0204e=C@0505QHF01EEED0EEEE04a<C018B4P00P1<C4`01@1BDU80GUiN05iNGP1TI6@0JVYZ
0080GemO00@0Cdm?0492@P12@T80A4A40P16ATH01@1=CDd0FUYJ05iNGP1NGUh0HV9R0080Kfm_00D0
Ng]k08R8R02?Shl0Shn?09BDU00208^;R`0307moO`1eMGD0Lg=c0080Lg=c0P1iNGT01@22PX80Ogmo
07moO`1iNGT0MWIf0080NGUi00D0Ng]k0820P020P800RHV908:2PP0207IfMP<0MGEe00D0M7Ad07al
O01lO7`0Q8B407inOP0207IfMP0307=cL`1_Kfl0Kfm_0080IfMW0P1UIFD0101PH600I6AT06ATI01/
K6`2079bLP0507alO025QHD0P8200820P01kNg/00P1iNGT207MgM`80O7al00D0OGem07=cL`1cLg<0
Jf][06IVIP0206ATI00406EUI@1`L700L71`071`L080LG5a00D0O7al08Z:RP2>SXh0SXj>09bLW002
0:>SX`0509VIV@2@T900T92@092@T02?Shl00P2BTY801@2FUYH0SXj>08j>SP22PX80O7al0080NWYj
00D0Ph>309:BTP2BTY80Vi^K09:BTP0208b<S00508F5Q@1iNGT0NGUi07AdM01nOWh00P22PX80101j
NWX0PH610861P@2=SHd209:BTP0509RHV02SXj<0WinO09nOW`2DU9@00P2>SXh01@28R8P0QXJ608V9
R@29RHT0TY:B0080Ti>C00D0VIVI09nOW`2OWil0Z:RX0:b/[0020:BTY00409NGU`2=SHd0SHf=07mo
O`l0oooo000=0?ooo`040=CDe03oool0oooo03/k>`80X:2P00D0V9RH08J6QP1YJFT0JFUY0>c/k002
0=gMg@0504];B`2=SHd0SHf=0:2PX02ATI400P1FEUH01@2e]KD0oooo0?ooo`0N7Qh0YJFU0080VYZJ
00@0Rh^;05EEE@1EEED0QXJ60P3oool01@0c<c<0RHV90:2PX02PX:00VIVI0080MGEe00D0Ng]k0?oo
o`18B4P0B4Q808j>SP020;:b/P0508:2PP1aLG40[Jf]0:f][@3inOT00P1]KFd01@22PX80SXj>08j>
SP2WYjL0C4a<0080/[:b00D0oooo02XZ:P0Z:RX0[Zj^092@T00209RHV00405=CD`3]kNd0kNg]0<K6
aP80Hf=S00D0V9RH08J6QP2ATI40TI6A055AD@020?ooo`0506QXJ02DU9@0XZ:R0::RXP1bLW800P2;
Rh/01@2m_Kd0g]kN0=kNgP1MGEd0TI6A0080WIfM00D0RXZ:06e]K@1]KFd0j>SX09jNWP0205iNGP05
0;>c/`2WYjL0YjNW0861P@1RHV800P3oool0101DE5@0QXJ608J6QP2PX:0209nOW`0504=3@`3oool0
Y:BT0:BTY01/K6`00P2OWil01@2<S8`0Shn?04i>CP1>CTh0oooo0080Bd];00D0QHF509>CT`2CTi<0
Vi^K04Q8B0020?ooo`050:n_[`1`L700L71`08J6QP2XZ:P00P1WIfL01@1OGel0oooo0?ooo`1dM7@0
KFe]0080V9RH00@0YJFU07QhN01hN7P0=CDe0P3oool01@0n?Sh0T92@0:6QX@2QXJ40SXj>0080B4Q8
00D0f=SH0?ooo`0l?3`0?3`l09RHV00209FEU@0509VIV@0o?cl0?clo0?ooo`1`L7000P1hN7P0102O
Wil0WIfM09fMW@0e=CD:0?ooo`04096AT@29RHT0RHV908R8R080Rh^;00D0S8b<09FEU@2HV9P0V9RH
09VIV@0209fMW@050:2PX02XZ:P0Z:RX0:f][@2^[Zh00P2[Zj/00`2RXZ80UIFE09FEU@0209BDU080
VIVI00<0WYjN0:^[Z`2[Zj/00`2/[:`01@2XZ:P0YZJV09fMW@2MWId0TY:B0080QXJ600D0NWYj06a/
K01UIFD0IFEU061PH00205mOG`0306QXJ01`L700LG5a0080LG5a0P1`L7001@1WIfL0JFUY06UYJ@1/
K6`0LW9b0080M7Ad00D0N7Qh07UiN@1iNGT0NGUi07moO`0208V9R@0408^;R`2:RXX0RXZ:08F5Q@80
O7al0P1aLG4207alO0050861P@26QXH0QXJ6096AT@2CTi<00P2FUYH00`2JVYX0V9RH09RHV00309:B
TP0508F5Q@1oOgl0PH610861P@25QHD00P23Ph<01@1kNg/0MGEe075aL@1aLG40MgMg0080OWin00D0
Shn?09NGU`2JVYX0VYZJ09:BTP0208R8R00508:2PP21PH40PH6107IfMP1XJ6P00P1OGel01@1GEeL0
E5AD05ADE01MGEd0IfMW0080KFe]00@0Jf][06EUI@1UIFD0G5aL0P1MGEd01@1WIfL0KFe]06m_K`1_
Kfl0J6QX0080HF5Q00D0Fe]K069RHP1`L700L71`08:2PP0209BDU0050:6QX@2MWId0UiNG09NGU`2E
UID00P28R8P0101aLG40GemO05mOG`1ADE4304U9B@04055AD@1MGEd0GEeM06MWI`<0Jf][0`1WIfL0
1@1VIVH0H61P061PH01IFET0De=C0080GemO00@0Jf][07IfMP1fMWH0QhN73`3oool000d0oooo00@0
e=CD0?ooo`3oool0>c/k0P2PX:001@2HV9P0QXJ606UYJ@1YJFT0k>c/0080gMgM00D0Bd];08f=S@2=
SHd0X:2P096AT@0205IFEP050;Fe]@3oool0oooo01hN7P2UYJD00P2JVYX0102;Rh/0EEEE05EEE@26
QXH20?ooo`0503<c<`29RHT0X:2P0:2PX02IVIT00P1eMGD01@1kNg/0oooo04Q8B018B4P0SXj>0080
/[:b00D0PX:2075aL@2][Jd0[Jf]0?Win@0206e]K@0508:2PP2>SXh0SXj>0:NWY`1<C4`00P2b/[80
1@3oool0:RXZ02XZ:P2^[Zh0T92@0080V9RH00@0De=C0>g]k@3]kNd0a/K60P1SHf<01@2HV9P0QXJ6
096AT@2ATI40DE5A0080oooo00D0J6QX09BDU02RXZ80XZ:R079bLP0208^;R`050;fm_@3Ng]h0g]kN
05eMG@2ATI400P2MWId01@2:RXX0KFe]06e]K@3Xj>P0WYjN0080GUiN00D0/k>c0:NWY`2WYjL0PH61
069RHP020?ooo`0405ADE026QXH0QXJ60:2PX080WinO00D0@d=30?ooo`2TY:@0Y:BT06a/K00209nO
W`0508b<S02?Shl0CTi>04i>CP3oool00P1;Bd/01@25QHD0Ti>C09>CT`2KVi/0B4Q80080oooo00D0
[jn_071`L01`L700QXJ60:RXZ00206MWI`0505mOG`3oool0oooo07AdM01]KFd00P2HV9P0102UYJD0
N7Qh07QhN00e=CD20?ooo`0503hn?P2@T900XJ6Q0:6QX@2>SXh00P18B4P01@3Hf=P0oooo03`l?00l
?3`0V9RH0080UIFE00D0VIVI03lo?`0o?cl0oooo071`L00207QhN00409nOW`2MWId0WIfM03De=@X0
oooo00@0TI6A08V9R@29RHT0R8R80P2;Rh/01@2<S8`0UIFE09RHV02HV9P0VIVI0080WIfM00D0X:2P
0:RXZ02XZ:P0[Jf]0:j^[P020:^[Z`030::RXP2EUID0UIFE0080U9BD0P2IVIT00`2NWYh0Zj^[0:^[
Z`030:b/[0050:RXZ02VYZH0WIfM09fMW@2BTY800P26QXH01@1jNWX0K6a/06EUI@1UIFD0H61P0080
GemO00<0J6QX071`L01aLG400P1aLG42071`L00506MWI`1YJFT0JFUY06a/K01bLW800P1dM7@01@1h
N7P0NGUi07UiN@1iNGT0Ogmo0080RHV900@0Rh^;08Z:RP2:RXX0QHF50P1lO7`2075aL@80O7al00D0
PH6108J6QP26QXH0TI6A09>CT`0209JFUP0309ZJVP2HV9P0V9RH00<0TY:B00D0QHF507moO`21PH40
PH6108F5Q@0208>3P`0507]kN`1eMGD0LG5a075aL@1gMgL00P1nOWh01@2?Shl0UiNG09ZJVP2JVYX0
TY:B0080R8R800D0PX:20861P@21PH40MWIf06QXJ00205mOG`0505MGE`1DE5@0E5AD05eMG@1WIfL0
0P1]KFd0101[Jf/0IFEU06EUI@1LG5`205eMG@0506MWI`1]KFd0Kfm_06m_K`1XJ6P00P1QHF401@1K
Fe/0HV9R071`L01`L700PX:20080U9BD00D0XJ6Q09fMW@2GUiL0UiNG09FEU@0208R8R004075aL@1O
Gel0GemO055AD@<0BDU900@0DE5A05eMG@1MGEd0IfMW0`1[Jf/306MWI`0506IVIP1PH600H61P05UI
F@1CDe<00P1OGel0101[Jf/0MWIf07IfMP27QhL?0?ooo`003@3oool0103Xj>P0oooo0?ooo`0_;bl2
09bLW00509FEU@2@T900CDe=04e=C@3lo?`00P3/k>`01@1ADE40QHF508F5Q@2MWId0QhN70080Bd];
00D0_Kfm0?ooo`3oool092@T08n?S`0208V9R@0408f=S@1TI6@0I6AT07QhN080oooo00D061PH08J6
QP2OWil0WinO09^KV`0206IVIP0508Z:RP3oool0A4A404A4A02<S8`00P2RXZ801@2@T900GemO0;Bd
]02d];@0oooo0080GUiN00D0QhN708Z:RP2:RXX0XZ:R0492@P020;Vi^@050?ooo`0U9BD09BDU09BD
U02HV9P00P2RXZ80100h>3P0oooo0?ooo`3Bd]8205UIF@0509>CT`2<S8`0SHf=08f=S@12@T800P3o
ool01@1TI6@0OGem09^KV`2KVi/0PH610080TY:B00D0/K6a0?Gem@3emOD0CDe=09:BTP0209nOW`05
0861P@1QHF40HF5Q0?ooo`2NWYh00P1WIfL01@2NWYh0YjNW0:NWY`22PX80C4a<0080oooo00@0KFe]
07QhN01hN7P0WIfM0P2VYZH01@0g=cL0oooo0;fm_@2m_Kd0L71`0080QXJ600D0SHf=096AT@19BDT0
BDU90?ooo`0204A4A00508>3P`2BTY80TY:B09^KV`12@T800P3oool01@2[Zj/0L71`071`L02<S8`0
T92@0080Hf=S00D0I6AT0?ooo`3oool0IVIV06ATI00209ZJVP040:>SX`1iNGT0NGUi02LW9`80oooo
00D0>SXj092@T02ATI40TI6A09>CT`020410@0050=CDe03oool0:b/[02/[:`2CTi<00P2GUiL01@2K
Vi/0=cLg03Lg=`3oool0I6AT0080OGem0`2GUiL00`0e=CD0oooo0?ooo`080?ooo`0403De=@0m?Cd0
?Cdm03dm?@80=cLg0P0n?Sh203/k>`0403Ph>00f=SH0=SHf02`/;08092@T00D09BDU02`/;00^;Rh0
;Rh^038b<P0203Hf=P05034a<@0[:b/0;bl_02l_;`0j>SX00P0i>CT303Ph>00503De=@0[:b/0;Rh^
02h^;P0g=cL00P0l?3`01@13@d<0CTi>059BDP1BDU80DE5A0080De=C00D0DE5A04U9B@18B4P0B4Q8
04M7A`0204Q8B00504a<C01?Cdl0Cdm?051@D01:BTX00P16ATH01@11@D40?Cdm03dm?@0g=cL0>c/k
0080?Cdm00@0?3`l03dm?@0m?Cd0@D510P10@4001011@D40AdM70492@P12@T8303dm?@0503Xj>P0e
=CD0;bl_02l_;`0e=CD00P0c<c<01@0b<S80;bl_02l_;`0g=cL0>SXj0080?Shn00D0@D510492@P12
@T80@d=303lo?`0203`l?00503<c<`0h>3P0>3Ph03De=@0d=3@00P0e=CD0100j>SX0=cLg03Lg=`0l
?3`203dm?@050451@@17AdL0BDU904U9B@17AdL00P16ATH01@19BDT0Bd];04Y:BP1:BTX0CTi>0080
De=C00D0DE5A05=CD`1CDe<0DU9B04e=C@0204U9B@0504M7A`12@T80@T9204=3@`19BDT00P14A4@0
1@0m?Cd0=cLg03Lg=`0`<300:RXZ0080;Rh^00@0>3Ph03dm?@0m?Cd0B4Q80P1ADE401@1DE5@0Cdm?
059BDP1BDU80EEEE0080DU9B00D0CTi>04a<C018B4P0B4Q803hn?P020410@00503lo?`12@T80@T92
04E5A@18B4P00P0n?Sh0100l?3`0>c/k03/k>`0e=CD?0?ooo`003@3oool0103Lg=`0m?Cd0?Cdm012
@T820:VYZ@05092@T02FUYH0CTi>04i>CP3alO400P3Kfm/01@1QHF40S8b<08b<S02KVi/0S8b<0080
CDe=00D0^[Zj0?ooo`3oool0?clo09FEU@0208n?S`0408R8R01`L700L71`07EeM@80oooo00D06QXJ
08R8R02RXZ80XZ:R09JFUP02071`L00508^;R`3oool0De=C05=CD`2QXJ400P2FUYH01@2<S8`0IVIV
0;Fe]@2e]KD0o_kn0080I6AT0`2:RXX01@2QXJ40EEEE0:n_[`2_[jl0oooo0080<30`00D0Xj>S09JF
UP2PX:00X:2P04M7A`020>o_k`050<[:bP1MGEd0GEeM096AT@2DU9@00P2@T9001@1IFET0oooo0?oo
o`1CDe<0Rh^;0080YJFU00@0NGUi0:BTY02TY:@0Vi^K0P3[jn/01@1LG5`0V9RH09RHV02HV9P0Q8B4
0080K6a/00D0l_;b09JFUP1QHF40HF5Q0;Jf]P020:NWY`0508V9R@1;Bd/0oooo0?ooo`1]KFd00P1o
Ogl01@2HV9P0Z:RX0:RXZ01CDe<0h^;R0080^;Rh00D0KVi^08F5Q@25QHD0Zj^[08:2PP0205iNGP04
0?ooo`1?Cdl0Cdm?08R8R080TI6A00D0VIVI05iNGP3oool0oooo09ZJVP0206][J`0508Z:RP2/[:`0
LW9b079bLP1TI6@00P3oool01@1UIFD0MWIf09ZJVP2JVYX0TY:B0080QXJ600D0?3`l0?ooo`3oool0
A4A408b<S0020::RXP0509bLW014A4@0A4A40=3@d03oool00P0g=cL0102@T900TI6A096AT@2QXJ42
05IFEP050?ooo`1KFe/0KVi^06i^KP2d];@00P2UYJD00`0^;Rh0oooo0?ooo`080?ooo`0405mOG`1M
GEd0GEeM05]KF`80G5aL00D0GEeM061PH01PH600H61P065QH@02061PH00305iNGP1MGEd0GEeM0080
GUiN0P1MGEd00`1LG5`0Fe]K05]KF`0205]KF`H0G5aL0P1OGel01@1QHF40Hf=S06EUI@1UIFD0IfMW
0080IFEU00<0HV9R05UIF@1GEeL00P1GEeL205]KF`0505mOG`1YJFT0KVi^06i^KP1]KFd00P1ZJVX3
06MWI`80JFUY0`1WIfL2065QH@0505eMG@1NGUh0GEeM05eMG@1NGUh00P1OGel01@1PH600GemO05mO
G`1PH600GUiN0080HF5Q00@0IVIV06ATI01TI6@0HV9R0`1TI6@0101KFe/0FUYJ05YJFP1KFe/205MG
E`05051@D01;Bd/0CDe=04e=C@1?Cdl00P1BDU801@1HF5P0H61P065QH@1QHF40IVIV0080Hf=S00D0
GemO05iNGP1OGel0GemO05iNGP02065QH@0506ATI01SHf<0Hf=S05mOG`1KFe/00P1IFET00`1JFUX0
GEeM05eMG@0405eMG@0405]KF`1HF5P0F5QH05YJFP80EeMG00<0FEUI05]KF`1LG5`00P1LG5`205iN
GP0505aLG01QHF40IFEU06EUI@1WIfL00P1XJ6P01@1YJFT0Hf=S05aLG01LG5`0Fe]K0080GUiN00D0
GEeM05aLG01LG5`0GemO061PH002069RHP<0I6AT00@0Hf=S05eMG@1EEED0EEEE0`1@D5001@1BDU80
EEEE05EEE@1JFUX0G5aL0080GEeM00@0GUiN061PH01PH600HF5Q3`3oool000d0oooo00@0g=cL0?Cd
m03dm?@0@T920P2YZJT01@2@T900UYJF04i>CP1>CTh0lO7a0080fm_K00D0HF5Q08b<S02<S8`0Vi^K
08b<S00204e=C@050;Zj^P3oool0oooo03lo?`2EUID00P2?Shl01028R8P0L71`071`L01eMGD20?oo
o`0501XJ6P28R8P0XZ:R0::RXP2FUYH00P1`L7001@2;Rh/0oooo05=CD`1CDe<0XJ6Q0080UYJF00D0
S8b<06IVIP2e]KD0]KFe0?knoP0206ATI0<0RXZ:00D0XJ6Q05EEE@2_[jl0[jn_0?ooo`02030`<005
0:>SX`2FUYH0X:2P0:2PX017AdL00P3_knl01@3:b/X0GEeM05eMG@2ATI40U9BD0080T92@00D0FEUI
0?ooo`3oool0De=C08^;R`020:FUY@0407UiN@2TY:@0Y:BT09^KV`80jn_[00D0G5aL09RHV02HV9P0
V9RH08B4Q00206a/K0050?;blP2FUYH0HF5Q065QH@2f][H00P2WYjL01@29RHT0Bd];0?ooo`3oool0
KFe]0080Ogmo00D0V9RH0:RXZ02XZ:P0De=C0>;RhP020;Rh^00506i^KP25QHD0QHF50:^[Z`22PX80
0P1NGUh0103oool0Cdm?04m?C`28R8P2096AT@0509VIV@1NGUh0oooo0?ooo`2JVYX00P1[Jf/01@2:
RXX0[:b/079bLP1bLW80I6AT0080oooo00D0IFEU07IfMP2JVYX0VYZJ09:BTP0208J6QP0503`l?03o
ool0oooo04A4A02<S8`00P2RXZ801@2LW9`0A4A404A4A03@d=00oooo0080=cLg00@0T92@096AT@2A
TI40XJ6Q0P1FEUH01@3oool0Fe]K06i^KP1^KVh0];Bd0080YJFU00<0;Rh^0?ooo`3oool0203oool0
101OGel0GEeM05eMG@1KFe/205aLG00505eMG@1PH600H61P061PH01QHF400P1PH6000`1NGUh0GEeM
05eMG@0205iNGP80GEeM00<0G5aL05]KF`1KFe/00P1KFe/605aLG080GemO00D0HF5Q06=SH`1UIFD0
IFEU06MWI`0206EUI@03069RHP1IFET0EeMG0080EeMG0P1KFe/01@1OGel0JFUY06i^KP1^KVh0KFe]
0080JVYZ0`1WIfL206UYJ@<0IfMW0P1QHF401@1MGEd0GUiN05eMG@1MGEd0GUiN0080GemO00D0H61P
05mOG`1OGel0H61P05iNGP02065QH@0406IVIP1TI6@0I6AT069RHP<0I6AT00@0Fe]K05YJFP1JFUX0
Fe]K0P1GEeL01@1@D500Bd];04e=C@1=CDd0Cdm?0080DU9B00D0F5QH061PH01QHF40HF5Q06IVIP02
06=SH`0505mOG`1NGUh0GemO05mOG`1NGUh00P1QHF401@1TI6@0Hf=S06=SH`1OGel0Fe]K0080FEUI
00<0FUYJ05eMG@1MGEd0101MGEd0101KFe/0F5QH05QHF01JFUX205MGE`0305UIF@1KFe/0G5aL0080
G5aL0P1NGUh01@1LG5`0HF5Q06EUI@1UIFD0IfMW0080J6QX00D0JFUY06=SH`1LG5`0G5aL05]KF`02
05iNGP0505eMG@1LG5`0G5aL05mOG`1PH6000P1RHV8306ATI00406=SH`1MGEd0EEEE05EEE@<0D51@
00D0DU9B05EEE@1EEED0FUYJ05aLG00205eMG@0405iNGP1PH600H61P065QH@l0oooo000=0?ooo`04
0<g=c@31`L40`L71075aL@80];Bd00D0P8200:>SX`1LG5`0G5aL0=;BdP020<?3``0507EeM@2HV9P0
V9RH09ZJVP2HV9P00P1HF5P01@2ZZZX0j>SX0>SXj01aLG40bLW90080KFe]00@0QHF508:2PP22PX80
OGem0P3oool01@0f=SH0S8b<0::RXP2RXZ80WYjN0080Lg=c00D0UYJF0>3Ph01TI6@0I6AT0>;RhP02
06IVIP0508n?S`1^KVh0Zj^[0:^[Z`3dm?@00P1eMGD01@23Ph<0SXj>08j>SP2LW9`0IfMW0080ZJVY
00D0m?Cd03De=@0e=CD0i>CT07AdM00209fMW@0405eMG@3Hf=P0f=SH0<71`@80K6a/0P2?Shl20:6Q
X@0506i^KP3oool0oooo059BDP2=SHd00P3;bl/0101PH600YJFU0:FUY@2OWil20=;BdP0507AdM02C
Ti<0Vi^K09^KV`2<S8`00P1^KVh01@3QhN40SXj>05EEE@1EEED0fm_K0080XJ6Q00D0P82006a/K03^
k^h0k^k^08J6QP020861P@0509>CT`2ZZZX0ZZZZ06YZJP32`/800P2h^;P01@1fMWH0N7Qh07QhN038
b<P0LG5a0080Ng]k00@0oooo05MGE`1GEeL0T92@0P2=SHd01@2KVi/0Lg=c0?7al@3alO40Rh^;0080
MgMg00D0L71`0>?Sh`1SHf<0Hf=S07EeM@020?ooo`0507=cL`23Ph<0VIVI09VIV@2?Shl00P2@T900
1@1CDe<0oooo0?ooo`1VIVH0NGUi0080^KVi00D0VYZJ059BDP1BDU80a<C40>k^kP0204a<C00408b<
S02=SHd0SHf=0:2PX080SHf=00D0o_kn06ATI01BDU80DU9B0=kNgP020:ZZZP0303@d=03oool0oooo
00P0oooo00@0DE5A05ADE01DE5@0EUIF0P1GEeL01@1HF5P0EUIF04i>CP1>CTh0CDe=0080Bd];00D0
BDU904];B`1;Bd/0De=C05ADE00204Q8B00504=3@`14A4@0A4A404A4A00l?3`00P16ATH304e=C@05
04a<C01ADE40DE5A051@D01<C4`00`19BDT204A4A0050410@012@T80ATI604I6AP15ADD00P19BDT0
101BDU80CTi>04];B`1;Bd/304Y:BP0504I6AP12@T80@T920451@@0o?cl00P0n?Sh01@0m?Cd0ADE5
04E5A@19BDT0CDe=0080D51@00@0CTi>04U9B@19BDT0A4A40P11@D400`0o?cl0ATI604M7A`0504M7
A`0404E5A@1>CTh0CTi>05MGE`80GEeM00D0Hf=S06ATI01TI6@0GUiN05eMG@0205QHF004059BDP1?
Cdl0Cdm?04i>CP<0BTY:00D0BDU904Q8B018B4P0?3`l03@d=00302h^;P80;Bd]00<0>3Ph03`l?00l
?3`00P0i>CT203Ph>0<0=SHf00D0@d=303dm?@0h>3P0>3Ph038b<P0202d];@0501lO7`0V9RH09RHV
02XZ:P0Y:BT00P0/;2`01@0`<300;Bd]02d];@0/;2`0;Bd]0080<30`00D0<c<c03@d=00d=3@0=SHf
03Ti>@0203Xj>P040410@00n?Sh0?Shn03lo?`80@D5100D0@41003Ph>00k>c/0>c/k03Hf=P0203De
=@0503Hf=P0k>c/0@4100410@01:BTX00P1DE5@01@1EEED0DU9B059BDP1:BTX0@d=30080?Cdm00@0
?clo04E5A@15ADD0C4a<3`3oool000d0oooo00@0_[jn092@T02@T900WYjN0P2o_kl01@1]KFd0][Jf
069RHP1RHV80^;Rh0080[:b/00D0Rh^;0:BTY02TY:@0UIFE09jNWP0206MWI`050:6QX@2LW9`0W9bL
0:JVYP3^k^h00P1BDU801022PX80UYJF09JFUP21PH420?knoP0505QHF02@T900WIfM09fMW@2UYJD0
0P1fMWH01@2QXJ40YZJV07AdM01dM7@0oooo0080ATI600D0T92@07MgM`2MWId0WIfM0>GUi@0208N7
Q`0507moO`2DU9@0U9BD09NGU`1lO7`00P2RXZ801@36a/H0=SHf03Hf=P3oool0De=C0080W9bL00@0
KVi^0;bl_02l_;`0`<300P1hN7P208j>SP80YJFU00D0QhN70=cLg03Lg=`0DU9B08B4Q0020?Shn004
059BDP2LW9`0W9bL09NGU`80b<S800D0QXJ609>CT`2LW9`0W9bL08j>SP0208J6QP050<30`02<S8`0
BDU904U9B@3hn?P00P2MWId01@21PH40M7Ad0<O7a`37alL0WYjN0080R8R800D0SXj>0:>SX`2SXj<0
Ph>30:JVYP020;:b/P0508R8R01ZJVX0JVYZ0>KViP1LG5`00P2<S8`0103^k^h0IfMW06MWI`2GUiL2
08b<S00509VIV@2:RXX0gMgM0=gMg@1nOWh00P22PX801@1FEUH0oooo05iNGP1NGUh0RHV90080dm?C
00D0Ogmo08f=S@2NWYh0WYjN08j>SP02096AT@0507MgM`3/k>`0k>c/07]kN`1UIFD00P3Rh^801@2A
TI40GUiN05iNGP2a/K40f=SH0080I6AT00@0RXZ:08R8R028R8P0VYZJ0P31`L401@39bLT0JFUY03lo
?`0o?cl0oooo0080ZJVY00<0@4100?ooo`3oool0203oool01017AdL0>SXj03Xj>P0X:2P201lO7`04
02XZ:P0n?Sh0DU9B059BDP<0EUIF00D0DE5A04A4A014A4@0?Cdm04i>CP02061PH005069RHP1KFe/0
Fe]K04i>CP1:BTX00P0o?cl01016ATH0Bd];04];B`1@D50204I6AP0504A4A00n?Sh0C4a<04a<C01H
F5P00P1SHf<01@1WIfL0JVYZ061PH01PH600EEEE0080D51@00D0CDe=04U9B@17AdL0AdM704Q8B002
04=3@`050492@P1>CTh0CTi>05aLG01RHV800P1QHF401@1RHV80EeMG05MGE`16ATH0ADE50080CTi>
00@0EUIF05]KF`1KFe/0HV9R0P1PH600101LG5`0GUiN05eMG@1MGEd305IFEP0505]KF`1IFET0FEUI
05UIF@1TI6@00P1UIFD01@1NGUh0GEeM05eMG@1PH600GUiN0080Jf][00D0MWIf07QhN01hN7P0LG5a
06m_K`0206IVIP0506=SH`1`L700L71`09JFUP2ZZZX00P2g]kL0102k^k/0/;2`0;2`/02JVYX209bL
W0050:BTY02QXJ40W9bL09bLW02FUYH00P27QhL01@1hN7P0OWin08^;R`2;Rh/0U9BD0080WinO00D0
YZJV0:VYZ@2YZJT0YZJV0:NWY`020:2PX00409BDU02<S8`0S8b<09BDU0<0V9RH00D0Vi^K09VIV@2I
VIT0SHf=08>3P`020820P00408B4Q02;Rh/0Rh^;08f=S@80QHF500D0PH6107inOP1kNg/0Ng]k08J6
QP02092@T00509JFUP2IVIT0UiNG09NGU`2:RXX00`25QHD208N7Q`0508>3P`24Q8@0OWin07inOP1g
MgL00P1ZJVX00`1IFET0oooo0?ooo`0=0?ooo`003@3oool0102^[Zh0I6AT06ATI037alL20=;BdP05
055AD@3?cll0IFEU06EUI@2PX:000`2IVIT20;Rh^00508R8R02TY:@0NWYj07YjNP2GUiL00P1FEUH0
1@3Cdm<0oooo03De=@0e=CD0OWin0080Z:RX00D0QXJ60<K6aP36a/H0N7Qh092@T00209ZJVP050;2`
/01lO7`0O7al0:JVYP1iNGT00P1fMWH01@3oool06QXJ01XJ6P2BTY80QXJ60080TI6A00@0b/[:0:BT
Y02TY:@0O7al0P2FUYH01@2EUID0R8R80:6QX@2QXJ40WYjN0080=CDe00D0oooo03dm?@2EUID0UIFE
0820P0020::RXP050;fm_@24Q8@0Q8B408n?S`2<S8`00P2ZZZX01@2SXj<0YJFU0:FUY@1NGUh0QhN7
0080oooo00@0BDU909:BTP2BTY80SXj>0P2n_[h01@2FUYH0Ti>C09RHV02HV9P0U9BD0080TI6A00D0
YZJV092@T00k>c/0>c/k0?ooo`020:6QX@050820P025QHD0V9RH09RHV02`/;000`2@T9020:2PX005
09FEU@2@T900ZZZZ0:ZZZP2BTY800P1TI6@01@3oool0Bd];09bLW02LW9`0`l?30080OWin00D0W9bL
08N7Q`27QhL0VYZJ0:NWY`020;Vi^@0507]kN`2=SHd0SHf=03Xj>P3oool00P1@D5001@2?Shl0[jn_
0:n_[`25QHD0U9BD0080WYjN00@0TI6A09FEU@2EUID0TI6A0P2a/K401@2EUID0De=C0?ooo`3oool0
Ph>30080L71`00D0WYjN0<;2`P1kNg/0Ng]k08n?S`0207inOP0509>CT`3[jn/0jn_[09ZJVP1bLW80
0P0`<300103oool0YJFU0:FUY@1<C4`:0?ooo`040:NWY`2a/K40/K6a0<71`@80b/[:00D0`/;20;Fe
]@2/[:`0[:b/0:ZZZP020:^[Z`050;Bd]032`/80`/;20<?3``2c/k<00P2XZ:P01@2PX:00ZJVY0:VY
Z@2j^[X0bl_;0080e]KF00@0eMGE0<g=c@3=cLd0a/K60P34a<@01@30`<00a/K60;Rh^02h^;P0ZJVY
0080X:2P00D0VIVI09RHV02NWYh0WYjN0:VYZ@020:ZZZP050:f][@2^[Zh0/[:b0;:b/P2c/k<00P2j
^[X01@2o_kl0]kNg0;Ng]`2XZ:P0YJFU0080WYjN00D0X:2P0:ZZZP2ZZZX0^KVi0;>c/`020:j^[P04
0::RXP2MWId0WIfM09RHV080WIfM00D0Y:BT09nOW`2PX:00X:2P0:FUY@020:>SX`050::RXP2XZ:P0
XJ6Q0:6QX@2CTi<01@2ATI401@2EUID0Vi^K092@T02@T900R8R80080QXJ600D0QHF508:2PP28R8P0
R8R808J6QP0207IfMP0505eMG@1=CDd0@D510451@@0n?Sh00P19BDT01@1BDU80D51@051@D01=CDd0
E5AD0080GEeM00D0JFUY07UiN@1iNGT0Ogmo07alO00207=cL`0406m_K`1YJFT0JFUY071`L080IfMW
00D0I6AT069RHP1[Jf/0Jf][071`L0020820P00507alO01_Kfl0I6AT06ATI01PH6000P1JFUX01@1T
I6@0M7Ad07emO@1mOGd0LG5a0080J6QX00D0IfMW06a/K01/K6`0Kfm_07alO00207inOP0506i^KP1U
IFD0IFEU05]KF`1FEUH00P1HF5P0101TI6@0HF5Q065QH@1MGEd205]KF`0505iNGP1RHV80LW9b079b
LP1lO7`00P27QhL00`2GUiL0oooo0?ooo`0=0?ooo`003@3oool0102^[Zh0I6AT06ATI037alL20=;B
dP05055AD@3?cll0IFEU06EUI@2PX:000`2IVIT20;Rh^00508R8R02TY:@0NWYj07YjNP2GUiL00P1F
EUH01@3Cdm<0oooo03De=@0e=CD0OWin0080Z:RX00D0QXJ60<K6aP36a/H0N7Qh092@T00209ZJVP05
0;2`/01lO7`0O7al0:JVYP1iNGT00P1fMWH01@3oool06QXJ01XJ6P2BTY80QXJ60080TI6A00@0b/[:
0:BTY02TY:@0O7al0P2FUYH01@2EUID0R8R80:6QX@2QXJ40WYjN0080=CDe00D0oooo03dm?@2EUID0
UIFE0820P0020::RXP050;fm_@24Q8@0Q8B408n?S`2<S8`00P2ZZZX01@2SXj<0YJFU0:FUY@1NGUh0
QhN70080oooo00@0BDU909:BTP2BTY80SXj>0P2n_[h01@2FUYH0Ti>C09RHV02HV9P0U9BD0080TI6A
00D0YZJV092@T00k>c/0>c/k0?ooo`020:6QX@050820P025QHD0V9RH09RHV02`/;000`2@T9020:2P
X00509FEU@2@T900ZZZZ0:ZZZP2BTY800P1TI6@01@3oool0Bd];09bLW02LW9`0`l?30080OWin00D0
W9bL08N7Q`27QhL0VYZJ0:NWY`020;Vi^@0507]kN`2=SHd0SHf=03Xj>P3oool00P1@D5001@2?Shl0
[jn_0:n_[`25QHD0U9BD0080WYjN00@0TI6A09FEU@2EUID0TI6A0P2a/K401@2EUID0De=C0?ooo`3o
ool0Ph>30080L71`00D0WYjN0<;2`P1kNg/0Ng]k08n?S`0207inOP0509>CT`3[jn/0jn_[09ZJVP1b
LW800P0`<300103oool0YJFU0:FUY@1<C4`:0?ooo`040:NWY`2a/K40/K6a0<71`@80b/[:00D0`/;2
0;Fe]@2/[:`0[:b/0:ZZZP020:^[Z`050;Bd]032`/80`/;20<?3``2c/k<00P2XZ:P01@2PX:00ZJVY
0:VYZ@2j^[X0bl_;0080e]KF00@0eMGE0<g=c@3=cLd0a/K60P34a<@01@30`<00a/K60;Rh^02h^;P0
ZJVY0080X:2P00D0VIVI09RHV02NWYh0WYjN0:VYZ@020:ZZZP050:f][@2^[Zh0/[:b0;:b/P2c/k<0
0P2j^[X01@2o_kl0]kNg0;Ng]`2XZ:P0YJFU0080WYjN00D0X:2P0:ZZZP2ZZZX0^KVi0;>c/`020:j^
[P040::RXP2MWId0WIfM09RHV080WIfM00D0Y:BT09nOW`2PX:00X:2P0:FUY@020:>SX`050::RXP2X
Z:P0XJ6Q0:6QX@2CTi<01@2ATI401@2EUID0Vi^K092@T02@T900R8R80080QXJ600D0QHF508:2PP28
R8P0R8R808J6QP0207IfMP0505eMG@1=CDd0@D510451@@0n?Sh00P19BDT01@1BDU80D51@051@D01=
CDd0E5AD0080GEeM00D0JFUY07UiN@1iNGT0Ogmo07alO00207=cL`0406m_K`1YJFT0JFUY071`L080
IfMW00D0I6AT069RHP1[Jf/0Jf][071`L0020820P00507alO01_Kfl0I6AT06ATI01PH6000P1JFUX0
1@1TI6@0M7Ad07emO@1mOGd0LG5a0080J6QX00D0IfMW06a/K01/K6`0Kfm_07alO00207inOP0506i^
KP1UIFD0IFEU05]KF`1FEUH00P1HF5P0101TI6@0HF5Q065QH@1MGEd205]KF`0505iNGP1RHV80LW9b
079bLP1lO7`00P27QhL00`2GUiL0oooo0?ooo`0=0?ooo`003@3oool0102LW9`0@4100410@03oool2
0=;BdP0503Ti>@3Shn<0KFe]06e]K@2HV9P00P24Q8@01@25QHD0gMgM0=gMg@21PH40[:b/0080PX:2
00D0UYJF02LW9`0W9bL0eMGE0?ooo`0201hN7P0408^;R`2KVi/0Vi^K09BDU080VIVI00D0UIFE08n?
S`2JVYX0VYZJ0;6a/@02092@T00509FEU@1XJ6P0LG5a075aL@3oool00P010@401@2CTi<0UIFE08N7
Q`27QhL0];Bd0080^k^k00D0MGEe09RHV02HV9P0Ti>C09bLW00209FEU@0507inOP0n?Sh0?Shn0?oo
o`0d=3@00P2?Shl0102;Rh/0VIVI09VIV@2j^[X208>3P`0509>CT`28R8P0[Zj^0:j^[P2g]kL00P1o
Ogl01@1PH600X:2P0?ooo`3oool0>SXj0080S8b<00D0TY:B0:^[Z`2[Zj/0XJ6Q09bLW00209:BTP05
09BDU02OWil0WinO09BDU02@T9000P0d=3@01@3oool0Xj>S0:>SX`21PH40WIfM0080PX:200@0Ti>C
0:BTY02TY:@0Shn?0P2KVi/01@2VYZH0SXj>09RHV02HV9P0W9bL0080FEUI00D0oooo03lo?`2OWil0
WinO0;Jf]P020861P@050:6QX@23Ph<0Ph>309VIV@2g]kL00P2NWYh01@29RHT0S8b<08b<S00Y:BT0
oooo0080CTi>00D0QXJ609JFUP2FUYH0RXZ:0:JVYP0209bLW004092@T02GUiL0UiNG09NGU`80UYJF
00D0Xj>S05QHF03oool0oooo08>3P`0207inOP0509VIV@2RXZ80Shn?08n?S`2CTi<00P1jNWX01@2A
TI40m_Kf0?KfmP29RHT0MgMg0080;Bd]00@0oooo0;Bd]02d];@0AdM72P3oool0100f=SH0>SXj03Xj
>P0l?3`203/k>`0503<c<`0Z:RX09RHV02HV9P0T92@00P0U9BD01@0Y:BT09bLW02LW9`0S8b<08R8R
0080:BTY00D0>3Ph03Lg=`0g=cL0=3@d02l_;`0202@T900401<C4`0D51@051@D01LG5`8071`L00D0
8B4Q028R8P0T92@092@T02DU9@0202TY:@05038b<P0a<C40<30`030`<00a<C400P0^;Rh01@0U9BD0
9RHV02@T900T92@08b<S00808B4Q00D0820P024Q8@0Q8B408b<S02HV9P02038b<P05030`<00^;Rh0
;Rh^030`<00a<C400P0Y:BT0100^;Rh0<S8b038b<P0c<c<303Hf=P0303<c<`0`<300<30`00<0;bl_
00D0:RXZ02`/;00/;2`0;2`/02h^;P0202/[:`0502`/;00];Bd0;Bd]02d];@0/;2`00P0];Bd01@0`
<300<S8b038b<P0i>CT0@4100080@T9200<0AdM704];B`1;Bd/00P19BDT204];B`0404Q8B017AdL0
AdM704I6AP80ADE500<0A4A40492@P11@D400P11@D420492@P80A4A40P13@d<01011@D40@4100410
@00m?Cd40451@@80?3`l00D0@41003Hf=P0f=SH0=cLg03`l?0020492@P0503hn?P15ADD0ADE504E5
A@11@D400P0m?Cd0100o?cl0A4A404A4A013@d<20451@@050492@P0o?cl0>c/k03/k>`0n?Sh00P11
@D401@14A4@0ATI604U9B@19BDT0C4a<0080CDe=00D0Cdm?051@D01@D500E5AD05=CD`0204i>CP04
04I6AP10@400@41003Ti>@l0oooo000=0?ooo`040:6QX@18B4P0B4Q80?Win@80bLW900D0?clo0=SH
f01gMgL0MgMg092@T00208b<S00508N7Q`3Hf=P0f=SH08:2PP2ZZZX00P26QXH01@2HV9P0>3Ph03Ph
>036a/H0oooo00808R8R00@0Shn?09NGU`2GUiL0UiNG0P2>SXh01@2XZ:P0QXJ609JFUP2FUYH0];Bd
0080Shn?00D0UIFE07AdM01]KFd0KFe]0?ooo`02010@400509NGU`2DU9@0QhN708N7Q`2[Zj/00P36
a/H01@1aLG40UYJF09JFUP2JVYX0UiNG0080UIFE00D0RHV904=3@`13@d<0oooo03<c<`0209BDU004
08f=S@2ATI40TI6A0;no_`80Shn?00D0RXZ:08V9R@2][Jd0[Jf]0;Bd]00208B4Q00506UYJ@2JVYX0
oooo0?ooo`13@d<00P2=SHd01@2CTi<0ZJVY0:VYZ@2VYZH0W9bL0080TI6A00<0UiNG09ZJVP2JVYX0
0P2CTi<20451@@050?ooo`2NWYh0WYjN08V9R@2EUID00P21PH40102GUiL0];Bd0;Bd]025QHD209^K
V`050:2PX02EUID0UYJF09JFUP2UYJD00P1KFe/01@3oool0E5AD09bLW02LW9`0][Jf0080MgMg00D0
]KFe0861P@21PH40V9RH0:^[Z`0209fMW@<0TI6A00D0<S8b0?ooo`1<C4`0C4a<08n?S`0209^KV`05
0820P02g]kL0VIVI09VIV@2>SXh00P2GUiL01@2?Shl0VYZJ09ZJVP2[Zj/0F5QH0080moOg00D0Ogmo
08R8R028R8P0Vi^K09FEU@0209>CT`040:f][@1dM7@0M7Ad08^;R`80jn_[00D0RXZ:07moO`11@D40
@D510?ooo`0209fMW@0306=SH`3oool0oooo00P0oooo00<0Hf=S05iNGP1NGUh00`1KFe/01@1MGEd0
Hf=S06IVIP1VIVH0JFUY0080JVYZ00D0IfMW06IVIP1VIVH0IVIV06=SH`02061PH00405YJFP1HF5P0
F5QH05QHF0<0FEUI00<0GUiN05mOG`1OGel0101NGUh305mOG`0505iNGP1PH600H61P05mOG`1PH600
0`1OGel205iNGP80H61P0P1QHF40101SHf<0HV9R069RHP1QHF43061PH0<0GEeM00D0GUiN05mOG`1O
Gel0H61P06=SH`0206EUI@<0J6QX00D0JFUY06ATI01TI6@0HF5Q061PH00205iNGP0505eMG@1PH600
H61P05mOG`1LG5`00P1OGel3061PH00506EUI@1XJ6P0J6QX06MWI`1XJ6P00P1VIVH0101RHV80H61P
061PH01NGUh405UIF@80Fe]K00D0GUiN065QH@1QHF40HF5Q069RHP02065QH@03061PH01OGel0GemO
0080Hf=S0P1QHF401@1NGUh0G5aL05aLG01FEUH0EeMG0080FUYJ00@0GUiN05mOG`1OGel0H61P0P1O
Gel205iNGP80GemO00@0GUiN069RHP1RHV80HV9R0`1PH6001@1SHf<0HV9R069RHP1RHV80Hf=S0080
I6AT00@0Hf=S05iNGP1NGUh0Fe]K101MGEd2069RHP0506UYJ@1WIfL0IfMW06MWI`1YJFT00P1VIVH0
101RHV80HF5Q065QH@1PH60205mOG`05065QH@1OGel0HF5Q065QH@1TI6@00P1UIFD00`1VIVH0oooo
0?ooo`0=0?ooo`003@3oool0102QXJ40B4Q804Q8B03inOT20<W9b@0503lo?`3Hf=P0MgMg07MgM`2@
T9000P2<S8`01@27QhL0f=SH0=SHf022PX80ZZZZ0080QXJ600D0V9RH03Ph>00h>3P0a/K60?ooo`02
028R8P0408n?S`2GUiL0UiNG09NGU`80SXj>00D0Z:RX08J6QP2FUYH0UYJF0;Bd]00208n?S`0509FE
U@1dM7@0KFe]06e]K@3oool00P0@41001@2GUiL0U9BD08N7Q`27QhL0Zj^[0080a/K600D0LG5a09JF
UP2FUYH0VYZJ09NGU`0209FEU@0508V9R@13@d<0@d=30?ooo`0c<c<00P2DU9@0102=SHd0TI6A096A
T@2o_kl208n?S`0508Z:RP29RHT0[Jf]0:f][@2d];@00P24Q8@01@1YJFT0VYZJ0?ooo`3oool0@d=3
0080SHf=00D0Ti>C0:VYZ@2YZJT0YZJV09bLW002096AT@0309NGU`2JVYX0VYZJ0080Ti>C0P11@D40
1@3oool0WYjN09jNWP29RHT0UIFE0080PH6100@0UiNG0;Bd]02d];@0QHF50P2KVi/01@2PX:00UIFE
09JFUP2FUYH0YJFU0080Fe]K00D0oooo05ADE02LW9`0W9bL0;Jf]P0207MgM`050;Fe]@21PH40PH61
09RHV02[Zj/00P2MWId3096AT@05038b<P3oool0C4a<04a<C02?Shl00P2KVi/01@20P800]kNg09VI
V@2IVIT0SXj>0080UiNG00D0Shn?09ZJVP2JVYX0Zj^[05QHF0020?Ogm`0507moO`28R8P0R8R809^K
V`2EUID00P2CTi<0102][Jd0M7Ad07AdM02;Rh/20>_[j`0508Z:RP1oOgl0@D510451@@3oool00P2M
WId00`1SHf<0oooo0?ooo`080?ooo`0306=SH`1NGUh0GUiN00<0Fe]K00D0GEeM06=SH`1VIVH0IVIV
06UYJ@0206YZJP0506MWI`1VIVH0IVIV06IVIP1SHf<00P1PH600101JFUX0F5QH05QHF01HF5P305UI
F@0305iNGP1OGel0GemO00@0GUiN0`1OGel01@1NGUh0H61P061PH01OGel0H61P00<0GemO0P1NGUh2
061PH080HF5Q00@0Hf=S069RHP1RHV80HF5Q0`1PH60305eMG@0505iNGP1OGel0GemO061PH01SHf<0
0P1UIFD306QXJ00506UYJ@1TI6@0I6AT065QH@1PH6000P1NGUh01@1MGEd0H61P061PH01OGel0G5aL
0080GemO0`1PH6001@1UIFD0J6QX06QXJ01WIfL0J6QX0080IVIV00@0HV9R061PH01PH600GUiN101I
FET205]KF`0505iNGP1QHF40HF5Q065QH@1RHV800P1QHF400`1PH600GemO05mOG`0206=SH`80HF5Q
00D0GUiN05aLG01LG5`0EUIF05MGE`0205YJFP0405iNGP1OGel0GemO061PH080GemO0P1NGUh205mO
G`0405iNGP1RHV80HV9R069RHP<0H61P00D0Hf=S069RHP1RHV80HV9R06=SH`0206ATI00406=SH`1N
GUh0GUiN05]KF`@0GEeM0P1RHV801@1YJFT0IfMW06MWI`1WIfL0JFUY0080IVIV00@0HV9R065QH@1Q
HF40H61P0P1OGel01@1QHF40GemO065QH@1QHF40I6AT0080IFEU00<0IVIV0?ooo`3oool03@3oool0
00d0oooo00@0X:2P05YJFP1JFUX0j>SX0P2k^k/01@1=CDd0alO708:2PP22PX80P8200080U9BD00D0
]KFe0;>c/`2c/k<0Ph>30:BTY00209:BTP0509VIV@1=CDd0CDe=0;^k^`3oool00P15ADD0102@T900
VIVI09VIV@2EUID2075aL@050>GUi@1YJFT0UiNG09NGU`2XZ:P00`2GUiL01026QXH0M7Ad07AdM03o
ool203lo?`0509RHV02CTi<0PX:208:2PP2DU9@00P3fm_H01@1KFe/0V9RH09RHV02IVIT0U9BD0080
SXj>00D0X:2P05MGE`1GEeL0oooo055AD@0209JFUP04096AT@20P800P8200<C4a080YjNW00D0NWYj
08n?S`2QXJ40XJ6Q0;>c/`0208R8R00507UiN@2JVYX0jn_[0>_[j`1QHF400P2;Rh/01@2ATI40Ti>C
09>CT`34a<@0WYjN0080Q8B400D0VIVI09FEU@2EUID0Vi^K092@T00205UIF@050?7al@2GUiL0UiNG
09VIV@2?Shl00P1mOGd0102=SHd0f][J0=[JfP1^KVh209^KV`0509nOW`2GUiL0U9BD09BDU02XZ:P0
0P1XJ6P01@3Ti>@0K6a/09>CT`2CTi<0[Zj^0080JFUY00D0g]kN07YjNP1jNWX0Rh^;0:f][@0209FE
U@0509VIV@2ATI40TI6A04m?C`3oool00P1YJFT01@2FUYH0XJ6Q0:6QX@1QHF40fMWI0080VIVI00@0
Q8B409FEU@2EUID0Shn?0P2HV9P01@2][Jd0IVIV0>7Qh@3QhN40P8200080RHV900D0Zj^[07QhN02I
VIT0VIVI0=3@d002065QH@0509JFUP3@d=00d=3@092@T021PH400P1QHF40103Vi^H0TY:B09:BTP1n
OWh:0?ooo`<0C4a<00<0Cdm?051@D01@D500101CDe<00`1ADE40CTi>04i>CP0304a<C00504Y:BP1<
C4`0Cdm?04m?C`1ADE400`1@D500101<C4`0BDU904U9B@18B4P204I6AP0404E5A@17AdL0AdM704Y:
BP@0BDU90P15ADD204I6AP80AdM700D0B4Q804U9B@19BDT0AdM704U9B@0204Y:BP<0B4Q800D0A4A4
03lo?`0o?cl0?3`l03Ti>@0303`l?080?Cdm00@0?clo03hn?P0k>c/0>c/k0`0m?Cd01@0k>c/0@410
0410@011@D40?clo0080@41000D0?clo0410@010@400A4A404I6AP0204Q8B00404i>CP1?Cdl0Cdm?
04];B`80BDU900D0ADE503hn?P0g=cL0=cLg03De=@0203@d=00503Ti>@10@400ATI604I6AP17AdL0
0`19BDT00`18B4P0C4a<04a<C003059BDP0504e=C@17AdL0AdM703Ti>@0c<c<00P0`<3001@0^;Rh0
;Bd]02d];@0e=CD0=3@d0080=CDe00<0=SHf03Lg=`0g=cL00`0f=SH403De=@<0>SXj00D0?3`l03dm
?@0l?3`0?3`l03<c<`03034a<@04030`<00_;bl0;bl_038b<P80<c<c00<0<S8b03Ti>@0i>CT00P0j
>SX203/k>`0503Xj>P0c<c<0<c<c03@d=00b<S800P0c<c<0100h>3P0=SHf03Hf=P0d=3@203<c<`05
03@d=00_;bl0=CDe03De=@0k>c/00P12@T800`13@d<0oooo0?ooo`0=0?ooo`003@3oool0102WYjL0
KVi^06i^KP3>c/h20;>c/`05065QH@2e]KD0RHV908V9R@1kNg/00P21PH401@3`l?00SXj>08j>SP24
Q8@0WIfM0080UYJF00D0WIfM06EUI@1UIFD0Zj^[0?Cdm00205iNGP0409>CT`2EUID0UIFE09FEU@80
FUYJ00D0oooo05UIF@2ATI40TI6A09nOW`0209FEU@0509^KV`2IVIT0NWYj07YjNP3dm?@00P1SHf<2
09RHV080OWin00@0NGUi0?ooo`3oool0EeMG0P2GUiL01@2FUYH0W9bL08R8R028R8P0ZJVY0080KVi^
00D0k>c/06][J`2GUiL0UiNG09FEU@0207MgM`050;Jf]P36a/H0a/K6071`L02<S8`00P2SXj<01@2Z
ZZX0SXj>08j>SP26QXH0Vi^K0080`/;200@0O7al09:BTP2BTY80SXj>0P21PH401@3AdM40Z:RX07Yj
NP1jNWX0WIfM0080SHf=00D0WinO08n?S`1dM7@0M7Ad0=;BdP0209RHV00509bLW02EUID0MGEe07Ee
M@28R8P00P3emOD01@1NGUh0VIVI09VIV@2MWId0VIVI0080UiNG00D0XJ6Q07MgM`1gMgL0b<S808:2
PP02092@T0040:NWY`1JFUX0FUYJ0?ooo`80J6QX00D0RXZ:0:VYZ@2FUYH0UYJF09fMW@0208n?S`05
06a/K03Shn<0OWin07inOP2JVYX00P2RXZ801@1<C4`0n_[j09FEU@2EUID0NWYj0080UiNG00D0SHf=
09FEU@2EUID0/k>c07YjNP020;Zj^P0508f=S@2>SXh0SXj>0;Fe]@1KFe/00P2VYZH0103Vi^H0E5AD
05ADE02UYJD20;:b/P0509NGU`29RHT0O7al07alO02n_[h00P2=SHd00`29RHT0oooo0?ooo`080?oo
o`0404I6AP15ADD0ADE504U9B@80AdM700D0>CTi02h^;P0Y:BT0:BTY02LW9`0202DU9@0502@T900U
9BD09BDU02TY:@0U9BD00P0];Bd01@0n?Sh0@T920492@P14A4@0Bd];0080AdM70`0j>SX01@0n?Sh0
?clo03lo?`10@400ATI60080Bd];00D0Cdm?05EEE@1EEED0GEeM05YJFP0205UIF@0505EEE@1?Cdl0
Cdm?04=3@`11@D400P0o?cl01011@D40@4100410@017AdL204a<C00505=CD`1KFe/0I6AT06ATI01X
J6P00P1WIfL01@1RHV80GUiN05IFEP1FEUH0CDe=0080C4a<00D0Cdm?04];B`1;Bd/0CTi>05IFEP02
05UIF@0506ATI01ZJVX0JVYZ06IVIP1PH6000P1HF5P01018B4P0?Cdm03dm?@0m?Cd20451@@0504Q8
B01EEED0IFEU06EUI@1/K6`00P1`L7001@1aLG40L71`06][J`1[Jf/0K6a/0080IVIV00D0H61P05UI
F@1GEeL0EeMG05=CD`0205]KF`0506][J`1mOGd0OGem09:BTP2LW9`00P2WYjL01@2VYZH0W9bL09bL
W02>SXh0QhN70080MWIf00@0LG5a07EeM@1eMGD0NGUi0P1lO7`01@24Q8@0RHV908J6QP26QXH0QhN7
0080QXJ600D0PX:207inOP1lO7`0O7al07EeM@0207=cL`0507AdM01hN7P0O7al07alO024Q8@00P2C
Ti<01@2QXJ40X:2P0:2PX02SXj<0XJ6Q0080UYJF00<0SHf=08b<S02<S8`00P22PX8208J6QP0408N7
Q`2BTY80TY:B0::RXP80[Jf]00D0/[:b0;bl_02RXZ80XZ:R08J6QP0206YZJP0305eMG@3oool0oooo
00d0oooo000=0?ooo`040:j^[P22PX80PX:20;Rh^080YJFU00D0NGUi0::RXP2@T900T92@07YjNP02
079bLP050?ooo`1YJFT0JFUY08b<S02FUYH00P2CTi<01@2UYJD0MGEe07EeM@2PX:00f=SH0080MGEe
00@0Ti>C09:BTP2BTY80TI6A0P1>CTh01@3oool0AdM7096AT@2ATI40Ti>C0080UIFE00D0Vi^K0:^[
Z`27QhL0QhN70;Ng]`0208R8R00509FEU@2JVYX0OGem07emO@1WIfL00P3oool01015ADD0VIVI09VI
V@2BTY8309JFUP050:RXZ021PH40PH610;^k^`25QHD00P2IVIT0102EUID0Lg=c07=cL`2TY:@20>KV
iP0506=SH`2ATI40W9bL09bLW02WYjL00P2FUYH01@2=SHd0X:2P09jNWP2NWYh0T92@0080UiNG00D0
SHf=075aL@1aLG40h^;R0:VYZ@0207=cL`0509nOW`2@T900T92@09VIV@2>SXh00P2BTY801@2h^;P0
T92@092@T02MWId0W9bL0080Lg=c00@0OGem0?ooo`3oool0ATI60P2CTi<01@2QXJ40VIVI09FEU@2E
UID0YjNW0080OWin00D0/;2`09>CT`2DU9@0U9BD09VIV@0204M7A`050?ooo`1JFUX0FUYJ08:2PP2U
YJD00P2EUID01@2QXJ40S8b<08b<S02<S8`0ZZZZ0080TY:B0`2RXZ801@0e=CD0oooo09FEU@2EUID0
KVi^0080V9RH00D0Shn?09:BTP2BTY80]KFe08Z:RP0209NGU`0509^KV`2>SXh0SXj>0;fm_@18B4P0
0P2[Zj/0103emOD0DU9B059BDP2^[Zh209JFUP050:2PX02EUID0S8b<08b<S02KVi/00P2;Rh/00`2B
TY80oooo0?ooo`080?ooo`040<C4a037alL0alO70<C4a080`l?300D0bl_;0<o?c`36a/H0a/K60<S8
b0020<W9b@050<c<c03Cdm<0dm?C0=oOg`3Ti>@00P3GemL01@35aLD0`L710<71`@2n_[h0^[Zj0080
aLG500@0e=CD0<c<c03<c<`0bLW90P38b<P01@34a<@0`<300<;2`P32`/80_kno0080^k^k00D0/[:b
0;Fe]@2i^KT0^KVi0;bl_0020<?3``030<g=c@33`l<0a<C40080a<C40P38b<P01@39bLT0d];B0=;B
dP3>c/h0bLW90080^;Rh0`2c/k<0102g]kL0^KVi0<;2`P32`/840<C4a080alO70P39bLT20<O7a`05
0;fm_@2a/K40/K6a0;:b/P2h^;P00P2o_kl0103:b/X0clo?0<o?c`3<c<`20<O7a`050<71`@2h^;P0
/K6a0;6a/@2_[jl00P2[Zj/01@2TY:@0X:2P0:>SX`2SXj<0WinO0080Xj>S00D0[:b/0:j^[P2^[Zh0
[Zj^0:n_[`020:FUY@0509VIV@2ATI40TI6A08>3P`1lO7`00P1dM7@01@1hN7P0QHF508F5Q@2ATI40
VIVI00<0Y:BT0P2LW9`01@2FUYH0T92@092@T02=SHd0R8R80080RHV900<0Ph>30861P@21PH400P1o
Ogl20861P@0508b<S02ATI40TI6A09FEU@2DU9@00P2>SXh01024Q8@0M7Ad07AdM01TI6@205YJFP05
05ADE01GEeL0GEeM05eMG@1TI6@00P1/K6`207AdM080Kfm_00@0Jf][069RHP1RHV80E5AD0P18B4P0
1@10@400>SXj05ADE01DE5@0L71`0080Shn?00<0ZJVY0?ooo`3oool03@3oool000d0oooo00@0[Zj^
08:2PP22PX80^;Rh0P2UYJD01@1iNGT0XZ:R092@T02@T900NWYj0080LW9b00D0oooo06UYJ@1YJFT0
S8b<09JFUP0209>CT`050:FUY@1eMGD0MGEe0:2PX03Hf=P00P1eMGD0102CTi<0TY:B09:BTP2ATI42
04i>CP050?ooo`17AdL0TI6A096AT@2CTi<00P2EUID01@2KVi/0Zj^[08N7Q`27QhL0]kNg0080R8R8
00D0UIFE09ZJVP1mOGd0OGem06MWI`020?ooo`0404E5A@2IVIT0VIVI09:BTP<0UYJF00D0Z:RX0861
P@21PH40^k^k08F5Q@0209VIV@0409FEU@1cLg<0Lg=c0:BTY080i^KV00D0Hf=S096AT@2LW9`0W9bL
0:NWY`0209JFUP0508f=S@2PX:00WYjN09jNWP2@T9000P2GUiL01@2=SHd0LG5a075aL@3Rh^80ZJVY
0080Lg=c00D0WinO092@T02@T900VIVI08j>SP0209:BTP050;Rh^02@T900T92@09fMW@2LW9`00P1c
Lg<0101mOGd0oooo0?ooo`16ATH209>CT`050:6QX@2IVIT0UIFE09FEU@2WYjL00P1nOWh01@2`/;00
Ti>C09BDU02DU9@0VIVI0080AdM700D0oooo05YJFP1JFUX0PX:20:FUY@0209FEU@050:6QX@2<S8`0
S8b<08b<S02ZZZX00P2BTY830::RXP0503De=@3oool0UIFE09FEU@1^KVh00P2HV9P01@2?Shl0TY:B
09:BTP2e]KD0RXZ:0080UiNG00D0Vi^K08j>SP2>SXh0_Kfm04Q8B0020:^[Z`040?Gem@1BDU80DU9B
0:j^[P80UYJF00D0X:2P09FEU@2<S8`0S8b<09^KV`0208^;R`0309:BTP3oool0oooo00P0oooo00@0
a<C40<O7a`37alL0a<C40P33`l<01@3;bl/0clo?0<K6aP36a/H0b<S80080bLW900D0c<c<0=?Cd`3C
dm<0gmoO0>CTi0020=OGe`050<G5a@31`L40`L710;jn_P2j^[X00P35aLD0103De=@0c<c<0<c<c039
bLT20<S8b0050<C4a030`<00`/;20<;2`P2o_kl00P2k^k/01@2b/[80]KFe0;Vi^@2i^KT0_;bl0080
`l?300<0cLg=0<?3``34a<@00P34a<@20<S8b0050<W9b@3Bd]80d];B0<k>cP39bLT00P2h^;P30;>c
/`040;Ng]`2i^KT0`/;20<;2`P@0a<C40P37alL20<W9b@80alO700D0_Kfm0;6a/@2a/K40/[:b0;Rh
^0020;no_`040<[:bP3?cll0clo?0<c<c080alO700D0`L710;Rh^02a/K40/K6a0:n_[`020:^[Z`05
0:BTY02PX:00Xj>S0:>SX`2OWil00P2SXj<01@2/[:`0[Zj^0:j^[P2^[Zh0[jn_0080YJFU00D0VIVI
096AT@2ATI40Ph>307alO00207AdM00507QhN025QHD0QHF5096AT@2IVIT00`2TY:@209bLW00509JF
UP2@T900T92@08f=S@28R8P00P29RHT00`23Ph<0PH610861P@0207moO`80PH6100D0S8b<096AT@2A
TI40UIFE09BDU00208j>SP0408B4Q01dM7@0M7Ad06ATI080FUYJ00D0E5AD05MGE`1MGEd0GEeM06AT
I00206a/K080M7Ad0P1_Kfl0101[Jf/0HV9R069RHP1DE5@204Q8B0050410@00j>SX0E5AD05ADE01`
L7000P2?Shl00`2YZJT0oooo0?ooo`0=0?ooo`003@3oool0102f][H0UIFE09FEU@2?Shl20:6QX@05
09JFUP2?Shl0UIFE09FEU@1lO7`00P1PH6000`3oool0@d=304=3@`02092@T080Ti>C00D0YJFU08b<
S02<S8`0V9RH0:NWY`0209fMW@0409>CT`29RHT0RHV908n?S`80Cdm?00<0oooo038b<P2CTi<00P2C
Ti<208Z:RP050:6QX@2a/K40TI6A096AT@2>SXh00P2NWYh01@2CTi<0WYjN07MgM`1gMgL0GemO0080
oooo00D0>c/k09FEU@2EUID0UIFE08^;R`0209jNWP050;2`/022PX80PX:20:BTY02@T9000P2QXJ40
102FUYH0I6AT06ATI02VYZH20?gmo@0405QHF02CTi<0VYZJ09ZJVP<0W9bL00D0WIfM08n?S`2CTi<0
Ti>C0:6QX@0209>CT`0509BDU01PH600H61P0?KfmP2WYjL00P1`L7001@2OWil0T92@092@T02EUID0
Shn?0080V9RH00D0][Jf08F5Q@25QHD0XZ:R09FEU@02075aL@040820P03oool0oooo03De=@80Shn?
00D0XJ6Q09NGU`2IVIT0VIVI09RHV00209NGU`0509:BTP2RXZ80UiNG09NGU`2?Shl00P0i>CT01@3o
ool0F5QH05QHF01hN7P0XZ:R0080UIFE00D0XJ6Q08F5Q@25QHD0ZZZZ08J6QP0209VIV@050:VYZ@2P
X:00X:2P02h^;P3oool00P2KVi/0101WIfL0UIFE09FEU@2EUID209>CT`050:VYZ@2<S8`0W9bL09bL
W02FUYH00P2?Shl01@2k^k/0ADE50;Fe]@2e]KD0nOWi0080DE5A00D0[Zj^096AT@2ATI40XJ6Q09VI
V@0208j>SP04096AT@25QHD0QHF509ZJVPX0oooo00@05ADE00l?3`0?3`l03`l?0P0B4Q801@0D51@0
8b<S03@d=00d=3@0>3Ph0080?3`l00@0@41003Ph>00h>3P0:2PX0`0T92@01@0Q8B407QhN01hN7P0M
7Ad0820P00807AdM00@071`L02LW9`0W9bL09bLW0P0Y:BT01@0/;2`0<30`02PX:00X:2P0:b/[0080
:BTY00@09bLW02@T900R8R808R8R0`0O7al01@0T92@0;Bd]02LW9`0W9bL08b<S00806a/K00D03`l?
00000000000020P800/;2`02014A4@0301PH600J6QX06QXJ00805aLG0P0M7Ad0100N7Qh071`L01`L
700F5QH2014A4@0500P820020P8010@400@410071`L00P0=3@d200h>3P802`/;00@03@d=01LG5`0G
5aL06a/K0P0N7Qh00`0R8R809BDU020P8002020P80808R8R00@09BDU02@T900R8R808R8R0`0S8b<0
0`0P8200:2PX02LW9`0202LW9`80;2`/00D0;bl_02TY:@0Y:BT0;2`/02d];@0302`/;080:BTY00D0
9RHV02DU9@0[:b/0:b/[02h^;P02034a<@0503<c<`0d=3@0=3@d030`<00_;bl00P0b<S801@0d=3@0
>SXj03Xj>P12@T80B4Q80080ATI600D0BDU904M7A`17AdL0?Shn03Lg=`0203Xj>P0403Ti>@0l?3`0
?3`l0492@P80AdM700D0B4Q804M7A`19BDT0BDU904Q8B00204M7A`80Bd];0P1:BTX01019BDT0B4Q8
04Q8B013@d<304E5A@0404M7A`14A4@0A4A403/k>`80;bl_00<08R8R0?ooo`3oool03@3oool000d0
oooo00@0/[:b09ZJVP2JVYX0R8R80P2UYJD01@2FUYH0Shn?09FEU@2EUID0Ph>30080GUiN00D0oooo
0451@@11@D40SXj>09>CT`0208n?S`050::RXP2<S8`0S8b<09bLW02XZ:P00P2LW9`0102CTi<0RHV9
08V9R@2BTY8205eMG@050?ooo`0l?3`0UIFE09FEU@2CTi<00P2:RXX01@2QXJ40[Jf]09BDU02DU9@0
Ti>C0080VIVI00D0TY:B09nOW`1jNWX0NWYj05iNGP020?ooo`0503`l?02NWYh0WYjN08j>SP2?Shl0
0P2IVIT01@2e]KD0OWin07inOP2RXZ80VYZJ0080WinO00@0Ti>C06UYJ@1YJFT0XJ6Q0P3emOD01@1O
Gel0UIFE09JFUP2FUYH0VYZJ0080W9bL00D0YjNW08Z:RP2EUID0UIFE0:BTY00208^;R`0509NGU`1S
Hf<0Hf=S0?3`l02UYJD00P1aLG400`2LW9`0TY:B09:BTP0209BDU080W9bL00D0/K6a08R8R028R8P0
WYjN09bLW002071`L0040861P@3oool0oooo0410@080TI6A00D0XJ6Q09FEU@2DU9@0U9BD0::RXP02
09ZJVP0508n?S`2WYjL0R8R808R8R02JVYX00P11@D401@3oool0GEeM05eMG@1kNg/0Y:BT0080UiNG
00D0TI6A09^KV`2KVi/0Zj^[0861P@0209FEU@050:^[Z`2NWYh0WYjN03hn?P3oool00P2JVYX0101]
KFd0UiNG09NGU`2FUYH2092@T00509fMW@2[Zj/0TI6A096AT@2FUYH00P2<S8`01@2c/k<0EUIF0;Bd
]02d];@0h>3P0080GUiN00D0/K6a092@T02@T900WYjN08F5Q@020;Jf]P0408f=S@1iNGT0NGUi09^K
V`X0oooo00@0HV9R06ATI01TI6@0HF5Q0P1NGUh01@1MGEd0E5AD05ADE01DE5@0De=C0080DU9B00D0
D51@05EEE@1EEED0EUIF05UIF@0205aLG00405eMG@1PH600H61P065QH@@0H61P0`1OGel205aLG005
05YJFP1IFET0Fe]K05]KF`1JFUX00P1NGUh01@1QHF40Hf=S06ATI01TI6@0IVIV0080I6AT00D0GemO
05iNGP1WIfL0IfMW06i^KP0207QhN00508J6QP29RHT0RHV907moO`1eMGD00P1[Jf/0101NGUh0Fe]K
05]KF`1IFET305QHF00405eMG@1SHf<0Hf=S06QXJ080KFe]00D0Kfm_071`L01/K6`0K6a/06UYJ@03
06IVIP<0IFEU00@0HV9R05aLG01LG5`0GUiN0P1OGel01@1PH600HF5Q06QXJ01XJ6P0IfMW0080IVIV
00D0IfMW06YZJP1XJ6P0J6QX06EUI@0206=SH`05065QH@1KFe/0G5aL05aLG01KFe/00`1LG5`2065Q
H@03061PH01RHV80HV9R0080HV9R0`1PH600101OGel0Fe]K05]KF`1GEeL205QHF00505UIF@1LG5`0
G5aL065QH@1UIFD00P1TI6@01@1SHf<0H61P061PH01LG5`0F5QH0080FEUI00@0EeMG05EEE@1EEED0
F5QH0`1KFe/00`1MGEd0GUiN05iNGP0305iNGP05061PH01QHF40HF5Q065QH@1RHV800P1TI6@01@1R
HV80H61P05iNGP1NGUh0G5aL0080FEUI00<0FUYJ05aLG01LG5`00P1NGUh205eMG@0405mOG`1PH600
H61P061PH0l0oooo000=0?ooo`040;:b/P2JVYX0VYZJ08R8R080YJFU00D0UYJF08n?S`2EUID0UIFE
08>3P`0205iNGP050?ooo`11@D40@D5108j>SP2CTi<00P2?Shl01@2RXZ80S8b<08b<S02LW9`0Z:RX
0080W9bL00@0Ti>C08V9R@29RHT0TY:B0P1MGEd01@3oool0?3`l09FEU@2EUID0Ti>C0080RXZ:00D0
XJ6Q0:f][@2DU9@0U9BD09>CT`0209VIV@0509:BTP2OWil0NWYj07YjNP1NGUh00P3oool01@0l?3`0
WYjN09jNWP2>SXh0Shn?0080VIVI00D0]KFe07inOP1nOWh0XZ:R09ZJVP0209nOW`0409>CT`1YJFT0
JFUY0:6QX@80mOGe00D0GemO09FEU@2FUYH0UYJF09ZJVP0209bLW0050:NWY`2:RXX0UIFE09FEU@2T
Y:@00P2;Rh/01@2GUiL0Hf=S06=SH`3`l?00YJFU0080LG5a00<0W9bL09:BTP2BTY800P2DU9@209bL
W0050;6a/@28R8P0R8R809jNWP2LW9`00P1`L7001021PH40oooo0?ooo`10@402096AT@050:6QX@2E
UID0U9BD09BDU02RXZ800P2JVYX01@2?Shl0YjNW08R8R028R8P0VYZJ0080@D5100D0oooo05eMG@1M
GEd0Ng]k0:BTY00209NGU`05096AT@2KVi/0Vi^K0:^[Z`21PH400P2EUID01@2[Zj/0WYjN09jNWP0n
?Sh0oooo0080VYZJ00@0KFe]09NGU`2GUiL0UYJF0P2@T9001@2MWId0Zj^[096AT@2ATI40UYJF0080
S8b<00D0/k>c05IFEP2d];@0];Bd0>3Ph00205iNGP050;6a/@2@T900T92@09jNWP25QHD00P2f][H0
102=SHd0NGUi07UiN@2KVi/:0?ooo`04069RHP1TI6@0I6AT065QH@80GUiN00D0GEeM05ADE01DE5@0
E5AD05=CD`02059BDP05051@D01EEED0EEEE05IFEP1IFET00P1LG5`0101MGEd0H61P061PH01QHF44
061PH0<0GemO0P1LG5`01@1JFUX0FEUI05]KF`1KFe/0FUYJ0080GUiN00D0HF5Q06=SH`1TI6@0I6AT
06IVIP0206ATI00505mOG`1NGUh0IfMW06MWI`1^KVh00P1hN7P01@26QXH0RHV908V9R@1oOgl0MGEe
0080Jf][00@0GUiN05]KF`1KFe/0FEUI0`1HF5P0101MGEd0Hf=S06=SH`1XJ6P206e]K@0506m_K`1`
L700K6a/06a/K01YJFT00`1VIVH306EUI@04069RHP1LG5`0G5aL05iNGP80GemO00D0H61P065QH@1X
J6P0J6QX06MWI`0206IVIP0506MWI`1ZJVX0J6QX06QXJ01UIFD00P1SHf<01@1QHF40Fe]K05aLG01L
G5`0Fe]K00<0G5aL0P1QHF400`1PH600HV9R069RHP02069RHP<0H61P00@0GemO05]KF`1KFe/0EeMG
0P1HF5P01@1IFET0G5aL05aLG01QHF40IFEU0080I6AT00D0Hf=S061PH01PH600G5aL05QHF00205UI
F@0405MGE`1EEED0EEEE05QHF0<0Fe]K00<0GEeM05iNGP1NGUh00`1NGUh01@1PH600HF5Q065QH@1Q
HF40HV9R0080I6AT00D0HV9R061PH01NGUh0GUiN05aLG00205UIF@0305YJFP1LG5`0G5aL0080GUiN
0P1MGEd0101OGel0H61P061PH01PH60?0?ooo`003@3oool0102^[Zh0TY:B09:BTP2_[jl208^;R`05
08j>SP2KVi/0VIVI09VIV@2EUID00P1KFe/01@3oool0GEeM05eMG@2<S8`0VIVI0080QXJ600D0UIFE
096AT@2ATI40`<3009BDU00209RHV00409JFUP23Ph<0Ph>309RHV080MgMg00D0oooo05]KF`2EUID0
UIFE09ZJVP0208b<S00507inOP3@d=00VIVI09VIV@2<S8`00P2DU9@01@2;Rh/0Y:BT08>3P`23Ph<0
J6QX0080oooo00D0F5QH0:6QX@2QXJ40Rh^;08j>SP0208>3P`050=cLg01aLG40LG5a09bLW02NWYh0
0P2QXJ40102@T900NGUi07UiN@2DU9@20>7Qh@05071`L02DU9@0VIVI09VIV@29RHT00P2MWId01@3A
dM40KVi^09FEU@2EUID0XJ6Q0080RHV900D0Xj>S07=cL`1cLg<0c/k>0:NWY`0207]kN`0509^KV`2C
Ti<0Ti>C07YjNP2f][H00P2RXZ801@2NWYh0Rh^;08^;R`2NWYh0VYZJ0080NGUi00@0Rh^;0?knoP3n
o_h0EeMG0P2BTY801@2EUID0YZJV07]kN`1kNg/0c/k>00<0RXZ:00@0XZ:R08^;R`2;Rh/0W9bL0P1G
EeL01@3oool0JVYZ06YZJP22PX80XZ:R0080UiNG00D0KVi^0<W9b@39bLT0[Jf]07UiN@02096AT@05
0:FUY@2GUiL0UiNG05iNGP3_knl00P2GUiL0101fMWH0WinO09nOW`2HV9P208^;R`0508b<S03@d=00
OGem07emO@2HV9P00P2DU9@01@2PX:00Jf][0;Bd]02d];@0_[jn0080NWYj00D0YjNW09>CT`2CTi<0
Vi^K06a/K0020>g]k@0407QhN01dM7@0M7Ad09NGU`X0oooo00@0Hf=S069RHP1RHV80HF5Q0P1OGel0
101MGEd0GUiN05aLG01LG5`305YJFP0505UIF@1HF5P0F5QH05eMG@1OGel00P1SHf<01@1ZJVX0JFUY
06UYJ@1UIFD0HV9R0080Fe]K00@0DU9B05=CD`1CDe<0EUIF0P1HF5P00`1JFUX0Fe]K05]KF`0205]K
F`80F5QH00D0EeMG05IFEP1DE5@0E5AD051@D00204m?C`05055AD@1BDU80CTi>04i>CP1<C4`00P19
BDT01@15ADD0B4Q804Q8B01;Bd/0Cdm?0080E5AD00D0F5QH05EEE@1EEED0F5QH05IFEP02055AD@04
051@D01?Cdl0Cdm?04m?C`80DE5A0P1HF5P205UIF@0305YJFP1HF5P0F5QH0080EEEE0P1GEeL0101J
FUX0GemO05mOG`1MGEd205]KF`0505QHF01DE5@0CDe=04e=C@1<C4`00P1@D5001@1>CTh0C4a<04m?
C`1?Cdl0D51@0080CDe=0P1;Bd/204U9B@0404M7A`16ATH0ATI604I6AP80A4A400D0ADE504A4A012
@T80@T920451@@020410@080?clo0P14A4@604I6AP050451@@10@400?Shn03hn?P0k>c/00`0i>CT3
03Lg=`0503/k>`0l?3`0?3`l03/k>`0l?3`00P0m?Cd0100j>SX0>CTi03Ti>@0f=SH2038b<P0502l_
;`0/;2`0:2PX02PX:00T92@00P0P82001@0R8R809BDU02XZ:P0Z:RX0<C4a0080>SXj0`10@4001@0o
?cl0?Shn04=3@`13@d<0B4Q80080DE5A00<0Fe]K0?ooo`3oool03@3oool000d0oooo00@0YZJV07Qh
N01hN7P0iNGU0P1`L7001@2;Rh/0WYjN09fMW@2MWId0VYZJ0080LW9b00D0lo?c07AdM01dM7@0SHf=
09bLW00208V9R@0508R8R024Q8@0Q8B40>WYj@20P8000P2HV9P0102EUID0Ph>308>3P`2JVYX2092@
T0050=OGe`1_Kfl0UYJF09JFUP2LW9`00P2JVYX01@1MGEd0jn_[09bLW02LW9`0Q8B40080TY:B00D0
R8R80:2PX02?Shl0Shn?07YjNP020?[jnP0506UYJ@2TY:@0Y:BT08^;R`24Q8@00P1]KFd01@3oool0
HV9R069RHP2HV9P0Xj>S0080XJ6Q00@0T92@07alO01lO7`0WIfM0P33`l<01@22PX80UIFE09>CT`2C
Ti<0NWYj0080XJ6Q00D0n?Sh05EEE@2DU9@0U9BD0:6QX@0208Z:RP050:2PX023Ph<0Ph>30;no_`2L
W9`00P24Q8@01@2LW9`0Vi^K09^KV`1RHV80cLg=0080ZZZZ00D0Shn?08f=S@2=SHd0VIVI09fMW@02
08J6QP0408V9R@3QhN40hN7Q06UYJ@<0U9BD00@0XZ:R06i^KP1^KVh0oOgm0P1^KVh01@26QXH0X:2P
08j>SP2>SXh0WinO0080IVIV00D0lo?c0820P020P800Q8B40:BTY00209:BTP0505=CD`3]kNd0kNg]
0;2`/01cLg<00P2:RXX01@2UYJD0UiNG09NGU`1bLW80d];B0080V9RH00@0MWIf0:RXZ02XZ:P0W9bL
0P27QhL01@20P800k>c/06i^KP1^KVh0VIVI0080UIFE00D0VIVI07emO@2/[:`0[:b/0:^[Z`0208^;
R`050:BTY02GUiL0UiNG09RHV01?Cdl00P3oool0101RHV80MWIf07IfMP2HV9P:0?ooo`04018B4P0C
4a<04a<C01@D50805aLG00D07AdM01hN7P0Y:BT0:BTY02/[:`0202TY:@0502@T900O7al07alO014A
4@0;2`/00P0820P01@071`L030`<00`<300?3`l04Q8B00806QXJ00<09bLW030`<00`<3000`0`<300
1@0/;2`0820P01<C4`0C4a<04A4A0080410@00D03`l?014A4@0C4a<04a<C01HF5P0201XJ6P05020P
800];Bd0;Rh^02h^;P0[:b/00P0W9bL01@0P82005QHF01HF5P0G5aL07QhN00809bLW00D0<S8b03Ph
>00h>3P0>CTi03/k>`020492@P<0B4Q800D0BTY:04M7A`17AdL0>c/k03De=@0203<c<`0503@d=00k
>c/0>c/k0451@@13@d<00P14A4@01010@400@D510451@@13@d<204I6AP0504M7A`1:BTX0AdM704M7
A`0n?Sh00P0c<c<01@0b<S80<30`02l_;`0_;bl0=CDe0080?clo00D0Bd];05eMG@1QHF40HF5Q05mO
G`0205YJFP0504m?C`10@400@41003`l?00n?Sh00P11@D430492@P0504A4A017AdL0DU9B059BDP1J
FUX00P1NGUh01@1RHV80H61P061PH01HF5P0CTi>0080Cdm?00D0EEEE05]KF`1KFe/0HF5Q06e]K@02
07AdM00307]kN`25QHD0QHF50080R8R80P27QhL01023Ph<0Ogmo07moO`1oOgl208J6QP0508b<S02B
TY80VYZJ09ZJVP2WYjL00P2`/;001@2d];@0]KFe0;Fe]@2e]KD0/K6a0080ZJVY00D0Xj>S09FEU@2E
UID0T92@08n?S`0207=cL`0405YJFP18B4P0B4Q802h^;Pl0oooo000=0?ooo`040:>SX`1JFUX0FUYJ
0?ooo`80E5AD00D0Shn?09fMW@2MWId0WIfM09nOW`0207moO`050<S8b028R8P0R8R809:BTP2MWId0
0P2;Rh/01@1kNg/0OGem07emO@3oool0HV9R0080Vi^K00@0U9BD08J6QP26QXH0WYjN0P2OWil01@2]
[Jd0Ogmo09:BTP2BTY80YjNW0080WinO00D0ADE50?knoP2ZZZX0ZZZZ07EeM@0208n?S`0508N7Q`2N
WYh0VYZJ09ZJVP25QHD00P3<c<`01@21PH40Zj^[0:^[Z`2@T900PX:20080B4Q800D0oooo05YJFP1J
FUX0Ti>C09nOW`0209jNWP0409VIV@20P800P8200::RXP80Y:BT00D0TY:B09RHV02ATI40TI6A05QH
F0020<[:bP050?ooo`0i>CT0UiNG09NGU`2NWYh00P2>SXh01@2LW9`0TY:B09:BTP2XZ:P0WinO0080
Rh^;00D0VYZJ09bLW02LW9`0De=C0=oOg`020;:b/P0508F5Q@2ATI40TI6A09JFUP2JVYX00P2@T900
102>SXh0_Kfm0;fm_@21PH42096AT@0509>CT`2[Zj/0E5AD05ADE03oool00P1FEUH01@20P800XJ6Q
08n?S`2?Shl0XZ:R0080OGem00D0`L7109>CT`2CTi<0S8b<0:BTY002096AT@0503<c<`3oool0oooo
0:j^[P1[Jf/00P2:RXX01@2QXJ40VIVI09VIV@29RHT0/;2`0080VIVI00@0O7al0:^[Z`2[Zj/0WYjN
0P25QHD01@1jNWX0oooo05eMG@1MGEd0UYJF0080UIFE00D0Ti>C08j>SP2][Jd0[Jf]09RHV00209NG
U`050:2PX02MWId0WIfM09:BTP0Z:RX00P3oool0101<C4`0NWYj07YjNP2FUYH:0?ooo`030>OWi`3/
k>`0k>c/00<0kno_00D0moOg0?Cdm03YjNT0jNWY0>[ZjP020>g]k@050?7al@3dm?@0m?Cd0?ooo`3l
o?`00P3^k^h01@3YjNT0iNGU0>GUi@3UiND0k>c/0080n?Sh00@0m?Cd0>CTi03Ti>@0gMgM0P3Fe]H0
1@3Bd]80e]KF0>GUi@3UiND0gMgM0080f][J00D0g]kN0=oOg`3Ph>00h>3P0>[ZjP020>k^kP050>SX
j03Kfm/0f=SH0=SHf03Kfm/00P3Ph>001@3Xj>P0lO7a0?7al@3Xj>P0hN7Q0080e]KF00D0clo?0<[:
bP3:b/X0dm?C0=;BdP020<k>cP040<G5a@33`l<0`l?30<?3``80aLG500D0cLg=0=;BdP3<c<`0c<c<
0<_;b`020<K6aP050<71`@32`/80a/K60<K6aP35aLD00P30`<001@2j^[X0]kNg0;Ng]`2h^;P0]kNg
0080_Kfm00D0`<300<C4a034a<@0b<S80<[:bP020<S8b0050<W9b@34a<@0a<C40;^k^`2[Zj/00P2/
[:`0102b/[80^KVi0;Vi^@2o_kl20<g=c@80bLW90P3;bl/01@3De=@0fMWI0=WIf@3Ti>@0h^;R0080
d];B00@0alO70<;2`P32`/80^k^k0P2j^[X01@35aLD0a<C40;jn_P2n_[h0]kNg0080[jn_00D0YZJV
09nOW`2JVYX0VYZJ08j>SP0208>3P`0507moO`1jNWX0MWIf07IfMP1jNWX00P1kNg/01@1hN7P0Lg=c
07=cL`1/K6`0IFEU0080GUiN00<0E5AD04e=C@1=CDd01018B4P0101:BTX0Cdm?04m?C`1DE5@205mO
G`0506QXJ01YJFT0QXJ608J6QP2RXZ800P2e]KD00`35aLD0oooo0?ooo`0=0?ooo`003@3oool0102S
Xj<0FUYJ05YJFP3oool205ADE00508n?S`2MWId0WIfM09fMW@2OWil00P1oOgl01@38b<P0R8R808R8
R02BTY80WIfM0080Rh^;00D0Ng]k07emO@1mOGd0oooo069RHP0209^KV`0409BDU026QXH0QXJ609jN
WP80WinO00D0[Jf]07moO`2BTY80TY:B0:NWY`0209nOW`0504E5A@3no_h0ZZZZ0:ZZZP1eMGD00P2?
Shl01@27QhL0WYjN09ZJVP2JVYX0QHF50080c<c<00D0PH610:^[Z`2[Zj/0T92@08:2PP0204Q8B005
0?ooo`1JFUX0FUYJ09>CT`2OWil00P2NWYh0102IVIT0P8200820P02RXZ820:BTY00509:BTP2HV9P0
TI6A096AT@1HF5P00P3:b/X01@3oool0>CTi09NGU`2GUiL0WYjN0080SXj>00D0W9bL09:BTP2BTY80
Z:RX09nOW`0208^;R`0509ZJVP2LW9`0W9bL05=CD`3Ogml00P2b/[801@25QHD0TI6A096AT@2FUYH0
VYZJ0080T92@00@0SXj>0;fm_@2m_Kd0PH610P2ATI401@2CTi<0Zj^[05ADE01DE5@0oooo0080EUIF
00D0P8200:6QX@2?Shl0Shn?0::RXP0207emO@050<71`@2CTi<0Ti>C08b<S02TY:@00P2ATI401@0c
<c<0oooo0?ooo`2^[Zh0Jf][0080RXZ:00D0XJ6Q09VIV@2IVIT0RHV90;2`/00209VIV@0407alO02[
Zj/0Zj^[09jNWP80QHF500D0NWYj0?ooo`1MGEd0GEeM09JFUP0209FEU@0509>CT`2>SXh0[Jf]0:f]
[@2HV9P00P2GUiL01@2PX:00WIfM09fMW@2BTY80:RXZ0080oooo00@0C4a<07YjNP1jNWX0UYJF2P3o
ool00`3WinL0k>c/0>c/k0030>o_k`050?Ogm`3dm?@0jNWY0>WYj@3Zj^X00P3]kNd01@3alO40m?Cd
0?Cdm03oool0o?cl0080k^k^00D0jNWY0>GUi@3UiND0iNGU0>c/k0020?Shn0040?Cdm03Ti>@0i>CT
0=gMg@80e]KF00D0d];B0=KFeP3UiND0iNGU0=gMg@020=[JfP050=kNgP3Ogml0h>3P0>3Ph03Zj^X0
0P3^k^h01@3Xj>P0fm_K0=SHf03Hf=P0fm_K0080h>3P00D0j>SX0?7al@3alO40j>SX0>7Qh@020=KF
eP050<o?c`3:b/X0b/[:0=?Cd`3Bd]800P3>c/h01035aLD0`l?30<?3``33`l<20<G5a@050<g=c@3B
d]80c<c<0<c<c03;bl/00P36a/H01@31`L40`/;20<K6aP36a/H0aLG50080`<3000D0^[Zj0;Ng]`2g
]kL0^;Rh0;Ng]`020;fm_@050<30`034a<@0a<C40<S8b03:b/X00P38b<P01@39bLT0a<C40<C4a02k
^k/0Zj^[0080[:b/00@0/[:b0;Vi^@2i^KT0_kno0P3=cLd20<W9b@80bl_;00D0e=CD0=WIf@3IfMT0
i>CT0>;RhP020=;BdP040<O7a`32`/80`/;20;^k^`80^[Zj00D0aLG50<C4a02n_[h0_[jn0;Ng]`02
0:n_[`050:JVYP2OWil0VYZJ09ZJVP2>SXh00P23Ph<01@1oOgl0NWYj07IfMP1fMWH0NWYj0080Ng]k
00D0N7Qh07=cL`1cLg<0K6a/06EUI@0205iNGP0305ADE01=CDd0CDe=00@0B4Q800@0BTY:04m?C`1?
Cdl0E5AD0P1OGel01@1XJ6P0JFUY08J6QP26QXH0XZ:R0080]KFe00<0aLG50?ooo`3oool03@3oool0
00d0oooo00@0VYZJ04Y:BP1:BTX0oooo0P0c<c<01@2=SHd0XZ:R09bLW02LW9`0WinO0080SXj>00D0
Xj>S09>CT`2CTi<0XZ:R09NGU`0208b<S0<0MGEe00D0oooo05EEE@2@T900T92@09FEU@0208j>SP05
09nOW`2NWYh0WYjN08j>SP2DU9@00P2EUID01@2XZ:P0WYjN09jNWP0];Bd0oooo0080YJFU00D0Hf=S
09VIV@2IVIT0P82009VIV@020:NWY`0409BDU02MWId0WIfM09RHV080/K6a00D0Ti>C08>3P`0[:b/0
:b/[0?ooo`0204e=C@05092@T02OWil0TI6A096AT@2ZZZX00P28R8P00`2IVIT0TI6A096AT@0209jN
WP80S8b<00D0CDe=0=7Ad@3AdM40oooo02@T900209>CT`0409^KV`2ATI40TI6A09JFUP80Xj>S00D0
UYJF0:RXZ029RHT0RHV909^KV`0209bLW00504A4A03Vi^H0b/[:0<[:bP1eMGD00P2HV9P01@2@T900
Vi^K09BDU02DU9@0V9RH0080Ti>C0`2FUYH01@2?Shl0^[Zj03Lg=`0g=cL0oooo0080@D5100D0QXJ6
0:6QX@28R8P0R8R80:>SX`0209:BTP050:2PX02GUiL0UiNG09FEU@2OWil00P2LW9`01@0G5aL0oooo
0?ooo`2OWil0IFEU0080U9BD0`2KVi/01@2IVIT0UiNG09FEU@2EUID0PH610080/;2`00D0WIfM08F5
Q@25QHD0P8200?ooo`02059BDP0509RHV02ATI40TI6A09BDU02FUYH00P2UYJD0102EUID0VIVI09VI
V@2PX:0209^KV`0508b<S00S8b<0oooo0?ooo`0n?Sh00P1dM7@00`2KVi/0oooo0?ooo`080?ooo`04
02<S8`0L71`071`L01dM7@806a/K00D04a<C01HF5P0F5QH05QHF010@400200X:2P0500P820061PH0
1PH600D51@0>3Ph00P0M7Ad01@0O7al0820P020P800O7al04a<C00800`<300@0000000@4100410@0
2PX:0P0C4a<01@0K6a/07alO01hN7P0N7Qh0:RXZ0080;bl_0P0];Bd202`/;00501lO7`0F5QH05QHF
01HF5P0E5AD00`0F5QH201<C4`05014A4@0@4100410@01XJ6P0K6a/00P0J6QX301/K6`05018B4P0C
4a<05ADE01DE5@0G5aL00P0H61P01@0F5QH05ADE01DE5@0F5QH06ATI00<08b<S0`0R8R800`0P8200
6a/K01/K6`0301hN7P<07alO00D06QXJ01LG5`0I6AT06ATI02<S8`0302HV9P0402PX:00Z:RX0:RXZ
01lO7`806a/K00D071`L01/K6`0E5AD05ADE018B4P02010@400501HF5P0G5aL05aLG028R8P0W9bL0
0P0X:2P01@0L71`06ATI01TI6@0<30`02PX:00802`/;00@03Ph>010@400@41004Q8B0`0A4A40100N
7Qh09RHV02HV9P0Z:RX202h^;P05034a<@0Y:BT09BDU02DU9@0V9RH00P0X:2P01@0[:b/0;bl_030`
<00`<300<C4a0080=3@d00D0>SXj03hn?P0n?Sh0@d=304Y:BP0204a<C00504];B`1<C4`0C4a<04];
B`19BDT00P16ATH01013@d<0@D510451@@11@D4204=3@`050492@P13@d<0?Shn03hn?P0g=cL00`0`
<30?0?ooo`003@3oool0102MWId0ADE504E5A@3oool202d];@0508Z:RP2WYjL0V9RH09RHV02PX:00
0P2<S8`01@2MWId0Vi^K09^KV`2SXj<0Ti>C0080T92@00D0LW9b075aL@1aLG40oooo04];B`0208Z:
RP0409NGU`2@T900T92@09^KV`80W9bL00D0SXj>09BDU02GUiL0UiNG0:ZZZP0209BDU005034a<@3o
ool0Xj>S0:>SX`1MGEd00P2OWil01@1oOgl0Vi^K0:FUY@2UYJD0UYJF0080V9RH00D0WinO0:b/[02/
[:`0TI6A08B4Q002030`<0050?ooo`1BDU80DU9B09JFUP2GUiL00P2ATI40102[Zj/0R8R808R8R02F
UYH209VIV@0509fMW@2LW9`0Rh^;08^;R`1?Cdl00P3Bd]801@3oool0:b/[096AT@2ATI40UiNG0080
U9BD00D0UYJF09jNWP2NWYh0TY:B0;Bd]00208f=S@0509NGU`2JVYX0VYZJ04Y:BP3Ph>000P3=cLd0
1@1_Kfl0W9bL09bLW02ATI40UiNG0080T92@00@0UiNG09^KV`2KVi/0Vi^K0P2BTY801@2CTi<0][Jf
03Ti>@0i>CT0oooo0080@41000D0TI6A09NGU`2>SXh0SXj>09bLW00208f=S@050::RXP2TY:@0Y:BT
096AT@2OWil00P2KVi/01@0V9RH0oooo0?ooo`2KVi/0KVi^0080UIFE00D0WYjN09VIV@2IVIT0UiNG
08b<S0020:f][@040861P@2VYZH0YZJV09^KV`80S8b<00D0QHF50??cl`1TI6@0I6AT09RHV00208b<
S00509RHV02ATI40WYjN09jNWP2e]KD00P22PX801@2SXj<0Vi^K09^KV`2<S8`0?Cdm0080oooo00@0
AdM709NGU`2GUiL0PH612P3oool0101EEED0EeMG05MGE`1HF5P205YJFP0405QHF01GEeL0EUIF05IF
EP@0EeMG0P1IFET01@1KFe/0FEUI05YJFP1JFUX0G5aL0080Fe]K00D0GUiN06IVIP1[Jf/0Jf][06i^
KP03071`L080KFe]00D0JFUY06QXJ01UIFD0IFEU05mOG`0205aLG00505]KF`1GEeL0EeMG05MGE`1J
FUX00P1OGel01@1PH600HF5Q065QH@1QHF40GemO00<0Fe]K0P1LG5`01@1NGUh0HV9R06QXJ01XJ6P0
KFe]0080KVi^00D0K6a/06YZJP1ZJVX0JVYZ06QXJ00206MWI`0506IVIP1SHf<0Hf=S05eMG@1DE5@0
0P1BDU801@1DE5@0EeMG05MGE`1KFe/0HV9R0080H61P101NGUh2061PH00506MWI`1/K6`0Jf][06][
J`1XJ6P00P1UIFD01@1OGel0G5aL05]KF`1KFe/0HF5Q0080IfMW00D0JVYZ06i^KP1cLg<0Lg=c07Ad
M00207=cL`0506m_K`1aLG40LG5a06a/K01TI6@00P1PH600101RHV80GEeM05eMG@1NGUh305mOG`04
05iNGP1LG5`0G5aL05]KF`80G5aL00<0GUiN05aLG01MGEd01@1MGEd0101OGel0HF5Q065QH@1QHF42
069RHP05065QH@1UIFD0JFUY06UYJ@1[Jf/00P1/K6`01@1]KFd0K6a/06a/K01/K6`0JVYZ00<0Jf][
0P1XJ6P01@1VIVH0IFEU06IVIP1VIVH0IfMW0080JFUY00D0IfMW06EUI@1UIFD0H61P05aLG00205QH
F00405ADE01BDU80DU9B05ADE0l0oooo000=0?ooo`0409fMW@15ADD0ADE50?ooo`80;Bd]00D0RXZ:
0:NWY`2HV9P0V9RH0:2PX00208b<S00509fMW@2KVi/0Vi^K0:>SX`2CTi<00P2@T9001@1bLW80LG5a
075aL@3oool0Bd];0080RXZ:00@0UiNG092@T02@T900Vi^K0P2LW9`01@2>SXh0U9BD09NGU`2GUiL0
ZZZZ0080U9BD00D0<C4a0?ooo`2SXj<0Xj>S05eMG@0209nOW`0507moO`2KVi/0YJFU0:FUY@2FUYH0
0P2HV9P01@2OWil0[:b/0:b/[02ATI40Q8B40080<30`00D0oooo059BDP1BDU80UYJF09NGU`02096A
T@040:^[Z`28R8P0R8R809JFUP80VIVI00D0WIfM09bLW02;Rh/0Rh^;04m?C`020=;BdP050?ooo`0[
:b/0TI6A096AT@2GUiL00P2DU9@01@2FUYH0WYjN09jNWP2BTY80];Bd0080SHf=00D0UiNG09ZJVP2J
VYX0BTY:0>3Ph0020<g=c@0506m_K`2LW9`0W9bL096AT@2GUiL00P2@T900102GUiL0Vi^K09^KV`2K
Vi/209:BTP0509>CT`2f][H0>CTi03Ti>@3oool00P10@4001@2ATI40UiNG08j>SP2>SXh0W9bL0080
SHf=00D0XZ:R0:BTY02TY:@0TI6A09nOW`0209^KV`0502HV9P3oool0oooo09^KV`1^KVh00P2EUID0
1@2NWYh0VIVI09VIV@2GUiL0S8b<0080[Jf]00@0PH610:JVYP2VYZH0Vi^K0P2<S8`01@25QHD0lo?c
06ATI01TI6@0V9RH0080S8b<00D0V9RH096AT@2NWYh0WYjN0;Fe]@0208:2PP050:>SX`2KVi/0Vi^K
08b<S00m?Cd00P3oool01017AdL0UiNG09NGU`21PH4:0?ooo`0405EEE@1GEeL0EeMG05QHF080FUYJ
00@0F5QH05MGE`1FEUH0EUIF101GEeL205UIF@0505]KF`1IFET0FUYJ05YJFP1LG5`00P1KFe/01@1N
GUh0IVIV06][J`1[Jf/0KVi^00<0L71`0P1]KFd01@1YJFT0J6QX06EUI@1UIFD0GemO0080G5aL00D0
Fe]K05MGE`1GEeL0EeMG05YJFP0205mOG`05061PH01QHF40HF5Q065QH@1OGel00`1KFe/205aLG005
05iNGP1RHV80J6QX06QXJ01]KFd00P1^KVh01@1/K6`0JVYZ06YZJP1ZJVX0J6QX0080IfMW00D0IVIV
06=SH`1SHf<0GEeM05ADE002059BDP0505ADE01GEeL0EeMG05]KF`1RHV800P1PH60405iNGP80H61P
00D0IfMW06a/K01[Jf/0Jf][06QXJ00206EUI@0505mOG`1LG5`0Fe]K05]KF`1QHF400P1WIfL01@1Z
JVX0KVi^07=cL`1cLg<0M7Ad0080Lg=c00D0Kfm_075aL@1aLG40K6a/06ATI002061PH004069RHP1M
GEd0GEeM05iNGP<0GemO00@0GUiN05aLG01LG5`0Fe]K0P1LG5`00`1NGUh0G5aL05eMG@0505eMG@04
05mOG`1QHF40HF5Q065QH@80HV9R00D0HF5Q06EUI@1YJFT0JFUY06][J`0206a/K00506e]K@1/K6`0
K6a/06a/K01ZJVX00`1[Jf/206QXJ00506IVIP1UIFD0IVIV06IVIP1WIfL00P1YJFT01@1WIfL0IFEU
06EUI@1PH600G5aL0080F5QH00@0E5AD059BDP1BDU80E5AD3`3oool000d0oooo00@0X:2P055AD@1A
DE40oooo0P17AdL01@2?Shl0Xj>S09BDU02DU9@0WYjN0080S8b<00D0P8200<c<c03<c<`0WIfM08B4
Q00209ZJVP0507alO01`L700L71`0?ooo`1QHF400P2?Shl0102KVi/0TY:B09:BTP2IVIT209ZJVP05
07=cL`31`L40T92@092@T02OWil00P2ATI401@1HF5P0oooo09ZJVP2JVYX0LG5a0080VYZJ00D0QhN7
09VIV@2RXZ80XZ:R096AT@0208Z:RP050<W9b@2EUID0UIFE092@T027QhL00P1>CTh01@3oool0IfMW
06MWI`2JVYX0UIFE0080TY:B00@0ZJVY08V9R@29RHT0NGUi0P3<c<`01@28R8P0WinO08N7Q`27QhL0
Fe]K0080f=SH00D0o?cl04=3@`2>SXh0SXj>09VIV@0209:BTP0509FEU@2GUiL0UiNG08R8R03Hf=P0
0P1lO7`01@2HV9P0VIVI09VIV@1OGel0`<300080b<S800D0O7al0:6QX@2QXJ40R8R809bLW00208f=
S@0408>3P`2k^k/0^k^k09jNWP80QHF500D0WIfM0:JVYP1CDe<0De=C0?ooo`02055AD@0509VIV@2C
Ti<0QhN708N7Q`2VYZH00P2<S8`01@2IVIT0bLW90<W9b@1cLg<0WIfM0080X:2P00D0BTY:0?Gem@3e
mOD0UIFE07alO00209NGU`050:NWY`2CTi<0Ti>C09FEU@1fMWH00P3Jf]X0101^KVh0W9bL09bLW02K
Vi/309FEU@040<c<c01jNWX0NWYj09bLW080QXJ600D0V9RH08Z:RP2EUID0UIFE0>?Sh`0206=SH`05
0:BTY02KVi/0Vi^K092@T01?Cdl00P3oool0101KFe/0[jn_0:n_[`1bLW8:0?ooo`0405mOG`1NGUh0
GUiN05]KF`<0G5aL00@0Fe]K05QHF01HF5P0FUYJ0P1KFe/01@1IFET0EeMG05MGE`1FEUH0E5AD00<0
EEEE0P1HF5P205YJFP80FEUI0`1JFUX0101HF5P0EeMG05MGE`1KFe/305YJFP0405UIF@1MGEd0GEeM
05YJFP<0F5QH00D0Fe]K05EEE@1EEED0De=C05MGE`0205IFEP0305UIF@1OGel0GemO00@0HF5Q00<0
H61P05iNGP1NGUh00`1KFe/01@1LG5`0FEUI05IFEP1FEUH0EeMG0080EUIF00D0EEEE05MGE`1GEeL0
FUYJ06YZJP0306][J`<0JVYZ00@0GEeM05iNGP1NGUh0H61P0P1OGel0101KFe/0FEUI05UIF@1EEED3
059BDP0505EEE@1GEeL0EeMG05]KF`1NGUh00P1QHF401@1PH600GemO05mOG`1KFe/0FEUI0080EUIF
00@0DE5A051@D01@D500DE5A0P1>CTh00`1BDU80EEEE059BDP02059BDP80EUIF00@0EEEE05MGE`1J
FUX0FUYJ0`1KFe/01@1IFET0EEEE05EEE@1@D500CDe=0080BTY:00<0AdM704U9B@19BDT00P1<C4`2
04];B`0404e=C@1?Cdl0Cdm?04m?C`<0CDe=00@0Bd];04U9B@19BDT0AdM70P13@d<01@0n?Sh0>c/k
03Xj>P0j>SX0=cLg0080>c/k00<0?Cdm03hn?P0n?Sh00P0n?Sh203/k>`0503Ph>00n?Sh0?Shn0451
@@15ADD00P1?Cdl0101KFe/0FEUI05UIF@1KFe/?0?ooo`003@3oool0102PX:00K6a/06a/K03oool2
061PH005096AT@2TY:@0TY:B09:BTP2NWYh00P2<S8`01@1QHF40oooo0?ooo`2;Rh/0Ogmo0080V9RH
00D0Ogmo0820P020P800o_kn07EeM@0208N7Q`040:6QX@2IVIT0VIVI09:BTP80V9RH00D0FEUI0??c
l`21PH40PH6109FEU@0209:BTP0506m_K`3Ti>@0UIFE09FEU@1oOgl00P2KVi/01@2CTi<0UIFE09RH
V02HV9P0TI6A0080PH6100<0jNWY08F5Q@25QHD00P2=SHd206IVIP050?3`l01iNGT0NGUi09NGU`2I
VIT00P2CTi<0102YZJT0SHf=08f=S@1DE5@20?Win@0507emO@2LW9`0QhN708N7Q`1ZJVX00P3Fe]H0
1@3EeMD0H61P08f=S@2=SHd0V9RH0080TI6A0`2HV9P01@1dM7@0nOWi06e]K@1]KFd0U9BD0080Vi^K
00D0Lg=c0:ZZZP32`/80`/;208:2PP020:FUY@0508j>SP2EUID0S8b<08b<S01bLW800P3Hf=P01@2Q
XJ40N7Qh07QhN02GUiL0[jn_0080HF5Q00D0m?Cd06e]K@1]KFd0WinO08j>SP0208:2PP040:RXZ02<
S8`0S8b<09BDU080k>c/00D0F5QH09fMW@2PX:00X:2P06IVIP020=CDe00508n?S`28R8P0VIVI09VI
V@2UYJD00P2CTi<01@2DU9@0HF5Q0?ooo`3oool0G5aL0080UIFE00D0UYJF09^KV`2KVi/0XZ:R0:n_
[`0208V9R@050:6QX@26QXH0QXJ609NGU`1mOGd00P2<S8`0103oool0C4a<04a<C02OWil209bLW005
09FEU@1OGel0l?3`0?3`l01iNGT00P2m_Kd00`1TI6@0oooo0?ooo`080?ooo`0402/[:`0Y:BT0:BTY
02TY:@809bLW00D07alO02<S8`0X:2P0:2PX02LW9`0302XZ:P80:BTY00D0:2PX02d];@0`<300<30`
03<c<`0203De=@05034a<@0];Bd09RHV02HV9P0P82000P0O7al00`0Q8B408R8R028R8P02020P8080
7QhN00D0:RXZ02TY:@0Y:BT09bLW02PX:00202@T900501HF5P0K6a/06a/K02<S8`0W9bL00P0];Bd0
100b<S80;Rh^02h^;P0X:2P202<S8`0502PX:00T92@08B4Q024Q8@0T92@00P0S8b<01@0J6QX06a/K
01/K6`0K6a/061PH00806a/K00D07AdM01`L700L71`07AdM020P800202LW9`0502@T900U9BD09BDU
02@T900R8R800P0H61P00`0J6QX07AdM01dM7@03020P8005028R8P0S8b<08R8R028R8P0U9BD00P0`
<3001@0f=SH0>3Ph03Hf=P0f=SH0<S8b0080:RXZ00D09bLW02<S8`0R8R808R8R02<S8`0202@T9005
02HV9P0Z:RX0:RXZ03<c<`0d=3@00P0h>3P01@0c<c<0;bl_02l_;`0X:2P0:BTY00809bLW00@08b<S
02TY:@0Y:BT0;Rh^0P0c<c<01@0g=cL0B4Q804i>CP1>CTh0De=C0080EEEE00<0EeMG05=CD`1EEED0
0P1EEED204m?C`05051@D01FEUH0Fe]K05]KF`1TI6@00P1gMgL01@24Q8@0QhN708N7Q`2;Rh/0S8b<
0080RHV900D0S8b<08n?S`2?Shl0S8b<08j>SP02092@T00408j>SP2ATI40TI6A09jNWP80XZ:R00D0
WinO09ZJVP22PX80PX:206EUI@0204a<C00303lo?`3oool0oooo00d0oooo000=0?ooo`0409jNWP25
QHD0QHF50=CDe080MGEe00D0TI6A0:BTY02FUYH0UYJF09^KV`0208F5Q@0504a<C03oool0oooo07=c
L`1kNg/00P2HV9P01@1oOgl0Ti>C09>CT`3IfMT0Ph>30080QhN700@0Z:RX09ZJVP2JVYX0Ti>C0P2@
T9001@0m?Cd0oooo06UYJ@1YJFT0RXZ:0080V9RH00D0P8200<[:bP29RHT0RHV908j>SP0209bLW005
09^KV`2EUID0TI6A096AT@2BTY800P1`L7001@3oool0K6a/06a/K028R8P0U9BD0080Ng]k00D0bLW9
08J6QP26QXH0UYJF09bLW00209JFUP040:NWY`2?Shl0Shn?03De=@80oooo00D0LW9b09VIV@2:RXX0
RXZ:07moO`020;Jf]P050<C4a01jNWX0Shn?08n?S`2EUID00P2DU9@01@2GUiL0U9BD09BDU01YJFT0
oooo0080GemO00D0U9BD09jNWP2NWYh0QhN709NGU`020;Bd]00508b<S02QXJ40XJ6Q09VIV@2>SXh0
0P2BTY80101NGUh0j^[Z0>[ZjP2XZ:P2071`L00509BDU02XZ:P0OGem07emO@31`L400P26QXH01@2Y
ZJT0PX:208J6QP26QXH0ZZZZ0080QXJ600D0UYJF0?ooo`3oool0?clo09bLW00209jNWP0508N7Q`2^
[Zh0[Zj^08n?S`2CTi<00P2HV9P01@2WYjL0T92@092@T02BTY80B4Q80080oooo00@0@d=308N7Q`27
QhL0V9RH0P2RXZ801@2TY:@0W9bL09NGU`2GUiL0/;2`0080OWin00D0Ti>C07EeM@20P800P8200?oo
o`02038b<P0509nOW`2JVYX0VYZJ09^KV`1jNWX00P2h^;P0102BTY80`L710<71`@1RHV8:0?ooo`03
0<G5a@3=cLd0cLg=00<0clo?0P3EeMD20=CDe0030<c<c038b<P0b<S800<0b/[:00D0cLg=0=KFeP3F
e]H0e]KF0<g=c@020<C4a0050;no_`2k^k/0_Kfm0;fm_@33`l<00P34a<@01@2i^KT0][Jf0;Jf]P2f
][H0]KFe0080_[jn00D0c<c<0=SHf03Hf=P0h^;R0>k^kP020??cl`050?_kn`3gmoL0moOg0?3`l03U
iND00P3Cdm<30<_;b`050=3@d03GemL0emOG0=cLg03Rh^800P3Ti>@30>?Sh`050>g]k@3_knl0l?3`
0?3`l03WinL00P3QhN401@3Kfm/0emOG0=OGe`3AdM40c/k>0080a<C400D0b<S80<K6aP36a/H0a<C4
0<g=c@020=GEe@040=;BdP3?cll0clo?0<_;b`80c/k>00D0clo?0=3@d03De=@0e=CD0=GEe@020<_;
b`050<G5a@33`l<0`L710<71`@30`<000P34a<@20<W9b@80bl_;00@0eMGE0=_Kf`3Kfm/0f=SH0P3K
fm/0103AdM40cLg=0<_;b`3;bl/30<k>cP050<o?c`35aLD0_kno0;no_`2l_;`00P2o_kl01@36a/H0
bl_;0<_;b`3>c/h0aLG50080_[jn00D0^[Zj0;Jf]P2f][H0/[:b0;Jf]P020;Bd]0<0/[:b00D0/k>c
0:VYZ@2MWId0WIfM08f=S@0207MgM`05061PH01KFe/0Fe]K05MGE`1FEUH00`1JFUX205IFEP0405MG
E`1FEUH0EUIF05IFEP<0F5QH00D0De=C04M7A`17AdL0ATI604Q8B00205]KF`0407AdM02HV9P0V9RH
0:b/[0l0oooo000=0?ooo`0409jNWP25QHD0QHF50=CDe080MGEe00D0TI6A0:BTY02FUYH0UYJF09^K
V`0208F5Q@0504a<C03oool0oooo07=cL`1kNg/00P2HV9P01@1oOgl0Ti>C09>CT`3IfMT0Ph>30080
QhN700@0Z:RX09ZJVP2JVYX0Ti>C0P2@T9001@0m?Cd0oooo06UYJ@1YJFT0RXZ:0080V9RH00D0P820
0<[:bP29RHT0RHV908j>SP0209bLW00509^KV`2EUID0TI6A096AT@2BTY800P1`L7001@3oool0K6a/
06a/K028R8P0U9BD0080Ng]k00D0bLW908J6QP26QXH0UYJF09bLW00209JFUP040:NWY`2?Shl0Shn?
03De=@80oooo00D0LW9b09VIV@2:RXX0RXZ:07moO`020;Jf]P050<C4a01jNWX0Shn?08n?S`2EUID0
0P2DU9@01@2GUiL0U9BD09BDU01YJFT0oooo0080GemO00D0U9BD09jNWP2NWYh0QhN709NGU`020;Bd
]00508b<S02QXJ40XJ6Q09VIV@2>SXh00P2BTY80101NGUh0j^[Z0>[ZjP2XZ:P2071`L00509BDU02X
Z:P0OGem07emO@31`L400P26QXH01@2YZJT0PX:208J6QP26QXH0ZZZZ0080QXJ600D0UYJF0?ooo`3o
ool0?clo09bLW00209jNWP0508N7Q`2^[Zh0[Zj^08n?S`2CTi<00P2HV9P01@2WYjL0T92@092@T02B
TY80B4Q80080oooo00@0@d=308N7Q`27QhL0V9RH0P2RXZ801@2TY:@0W9bL09NGU`2GUiL0/;2`0080
OWin00D0Ti>C07EeM@20P800P8200?ooo`02038b<P0509nOW`2JVYX0VYZJ09^KV`1jNWX00P2h^;P0
102BTY80`L710<71`@1RHV8:0?ooo`030<G5a@3=cLd0cLg=00<0clo?0P3EeMD20=CDe0030<c<c038
b<P0b<S800<0b/[:00D0cLg=0=KFeP3Fe]H0e]KF0<g=c@020<C4a0050;no_`2k^k/0_Kfm0;fm_@33
`l<00P34a<@01@2i^KT0][Jf0;Jf]P2f][H0]KFe0080_[jn00D0c<c<0=SHf03Hf=P0h^;R0>k^kP02
0??cl`050?_kn`3gmoL0moOg0?3`l03UiND00P3Cdm<30<_;b`050=3@d03GemL0emOG0=cLg03Rh^80
0P3Ti>@30>?Sh`050>g]k@3_knl0l?3`0?3`l03WinL00P3QhN401@3Kfm/0emOG0=OGe`3AdM40c/k>
0080a<C400D0b<S80<K6aP36a/H0a<C40<g=c@020=GEe@040=;BdP3?cll0clo?0<_;b`80c/k>00D0
clo?0=3@d03De=@0e=CD0=GEe@020<_;b`050<G5a@33`l<0`L710<71`@30`<000P34a<@20<W9b@80
bl_;00@0eMGE0=_Kf`3Kfm/0f=SH0P3Kfm/0103AdM40cLg=0<_;b`3;bl/30<k>cP050<o?c`35aLD0
_kno0;no_`2l_;`00P2o_kl01@36a/H0bl_;0<_;b`3>c/h0aLG50080_[jn00D0^[Zj0;Jf]P2f][H0
/[:b0;Jf]P020;Bd]0<0/[:b00D0/k>c0:VYZ@2MWId0WIfM08f=S@0207MgM`05061PH01KFe/0Fe]K
05MGE`1FEUH00`1JFUX205IFEP0405MGE`1FEUH0EUIF05IFEP<0F5QH00D0De=C04M7A`17AdL0ATI6
04Q8B00205]KF`0407AdM02HV9P0V9RH0:b/[0l0oooo000=0?ooo`040::RXP2CTi<0Ti>C0:NWY`80
TY:B00D0Shn?0:BTY02FUYH0UYJF09ZJVP0208Z:RP0502`/;03oool0oooo059BDP20P8000P2JVYX0
1@21PH40WIfM09fMW@2j^[X0Shn?0080TY:B00@0YZJV09NGU`2GUiL0UIFE0P2=SHd01@0X:2P0oooo
04e=C@1=CDd0R8R80080Y:BT00D0TY:B09fMW@26QXH0QXJ60:RXZ00208b<S0050:j^[P2DU9@0RHV9
08V9R@2>SXh00P1YJFT01@3oool0EEEE05EEE@20P800WYjN0080UYJF00D0VIVI09JFUP2FUYH0UYJF
09ZJVP0209nOW`040:6QX@2>SXh0SXj>01lO7`80oooo00D0IfMW09RHV02:RXX0RXZ:096AT@020:6Q
X@050:n_[`2@T900Shn?08n?S`2EUID00P2LW9`01@2CTi<0UYJF09JFUP1LG5`0oooo0080H61P00D0
UYJF09nOW`2OWil0UIFE08j>SP020:FUY@0509>CT`2RXZ80XZ:R09bLW02?Shl00P2FUYH01018B4P0
oooo0?ooo`2TY:@206YZJP0509nOW`2KVi/0U9BD09BDU02NWYh00P2IVIT01@2OWil0PX:208j>SP2>
SXh0[Jf]0080P82000D0V9RH0?ooo`3oool0:BTY09jNWP0209JFUP050:BTY02<S8`0S8b<09>CT`2M
WId00P2BTY801@2][Jd0Shn?08n?S`28R8P0?clo0080oooo00@0=CDe07alO01lO7`0UiNG0`2TY:@0
102CTi<0W9bL09bLW02j^[X20820P005096AT@1/K6`0OGem07emO@3oool00P0c<c<01@2IVIT0UiNG
09NGU`2TY:@0QHF50080V9RH00@0WIfM0<[:bP3:b/X0GUiN2P3oool0100h>3P0<c<c03<c<`0a<C42
030`<00502l_;`0];Bd0:b/[02/[:`0d=3@00P0j>SX01@0n?Sh0@T920492@P11@D40<30`00808b<S
00D092@T02TY:@0Y:BT0;Rh^03<c<`0203/k>`0403Ph>00b<S80<S8b03`l?080ATI600D0B4Q804Y:
BP19BDT0BDU903<c<`02024Q8@0501LG5`0;2`/00@4100410@030`<00`071`L0100?3`l0820P020P
800T92@202DU9@0502HV9P0T92@092@T01HF5P0B4Q800P0?3`l01@0<30`020P800P820071`L020P8
00802PX:00@06ATI01dM7@0M7Ad08b<S0P0X:2P01@0];Bd09RHV02TY:@0Y:BT09BDU00808R8R00D0
820P01dM7@0M7Ad07AdM024Q8@0202LW9`05034a<@0b<S80<S8b034a<@0];Bd00P0V9RH01@0J6QX0
5ADE01DE5@0E5AD061PH00806ATI00D07alO02@T900T92@08b<S02XZ:P0202d];@0402LW9`0S8b<0
8b<S01lO7`804a<C0P0=3@d200`<300500l?3`0E5AD05ADE02<S8`0`<3000P0g=cL0100m?Cd0=cLg
03Lg=`0];Bd202LW9`0302<S8`0M7Ad07alO00@07alO00D08b<S02HV9P0W9bL09bLW02PX:00202XZ
:P0502DU9@0X:2P0;Rh^02h^;P0f=SH00P0m?Cd00`15ADD0Bd];04];B`0204m?C`80C4a<00D0Cdm?
055AD@1ADE40E5AD05=CD`02055AD@0404e=C@19BDT0BDU904I6AP80Bd];00D0CTi>05=CD`1DE5@0
E5AD059BDP0204Y:BP030451@@3oool0oooo00d0oooo000=0?ooo`040:JVYP2<S8`0S8b<0::RXP80
Ti>C00D0UiNG0:6QX@2FUYH0UYJF09VIV@0208^;R`0502`/;03oool0oooo0451@@22PX800P2EUID0
1029RHT0WinO09nOW`2ZZZX309FEU@040:VYZ@2GUiL0UiNG09>CT`80RHV900D0:2PX0?ooo`11@D40
@D510820P0020;2`/00508j>SP2HV9P0QXJ608J6QP2VYZH00P2:RXX01@2b/[80UIFE08V9R@29RHT0
SHf=0080KVi^00D0oooo059BDP1BDU80Ogmo09bLW00209VIV@0509NGU`2DU9@0U9BD09JFUP2HV9P0
0P2ZZZX0102IVIT0RHV908V9R@0/;2`20?ooo`0506a/K02IVIT0S8b<08b<S02=SHd00P2SXj<01@2_
[jl0SXj>08n?S`2?Shl0UYJF0080XJ6Q00D0Shn?09NGU`2GUiL0HF5Q0?ooo`0205aLG00509ZJVP2O
Wil0WinO09JFUP2>SXh00P2SXj<01@2QXJ40U9BD09BDU02FUYH0TI6A0080WYjN00@0CDe=0?_kn`3k
no/0X:2P0P1[Jf/01@2KVi/0W9bL09RHV02HV9P0UYJF0080YjNW00D0Vi^K07inOP2?Shl0Shn?0:ZZ
ZP0208^;R`0509JFUP3oool0oooo034a<@2NWYh00P2BTY801@2VYZH0R8R808R8R02JVYX0Xj>S0080
SXj>00D0ZZZZ08j>SP2>SXh0RXZ:04a<C0020?ooo`04038b<P29RHT0RHV909>CT`80YJFU00D0W9bL
0:f][@2:RXX0RXZ:0;fm_@0208:2PP0508b<S01fMWH0OGem07emO@3oool00P17AdL01@2MWId0Ti>C
09>CT`2OWil0MWIf0080a<C400@0S8b<0;bl_02l_;`0JFUY2P3oool0101?Cdl0D51@051@D01ADE42
059BDP0505EEE@1GEeL0EEEE05EEE@1CDe<00P1@D5001@1;Bd/0AdM704M7A`1:BTX0CTi>0080EEEE
00D0F5QH05IFEP1FEUH0EUIF05MGE`02059BDP0405ADE01KFe/0Fe]K05]KF`80EUIF00D0E5AD059B
DP1=CDd0CDe=04a<C002051@D00505EEE@1KFe/0Hf=S06=SH`1TI6@00`1SHf<0101QHF40G5aL05aL
G01MGEd205iNGP0505eMG@1KFe/0Fe]K05eMG@1LG5`00P1MGEd01@1QHF40IVIV06IVIP1VIVH0IFEU
0080I6AT0`1NGUh00`1LG5`0GEeM05eMG@02061PH080GEeM00D0HF5Q06=SH`1SHf<0IFEU06QXJ002
06][J`0406YZJP1VIVH0IVIV069RHP80GUiN0P1KFe/205eMG@05065QH@1TI6@0I6AT069RHP1PH600
0P1NGUh0101LG5`0FEUI05UIF@1JFUX405]KF`80G5aL00D0HV9R06MWI`1WIfL0KVi^07=cL`0207If
MP0507AdM01^KVh0KVi^06MWI`1SHf<00P1QHF40101RHV80I6AT06ATI01UIFD206ATI0L0Hf=S00D0
GemO05aLG01LG5`0G5aL05YJFP0205QHF00305]KF`1OGel0H61P0080H61P0P1SHf<01@1QHF40Fe]K
05]KF`1JFUX0G5aL00<0GUiN0P1OGel01@1SHf<0IFEU06MWI`1WIfL0KVi^0080LW9b0`1aLG401@1c
Lg<0L71`06QXJ01XJ6P0Hf=S0080G5aL00<0E5AD0?ooo`3oool03@3oool000d0oooo00@0YZJV08b<
S02<S8`0XZ:R0P2CTi<01@2GUiL0XJ6Q09JFUP2FUYH0VIVI0080Rh^;00D0;2`/0?ooo`3oool0@D51
08:2PP0209FEU@0408V9R@2OWil0WinO0:ZZZP<0UIFE00@0ZJVY09NGU`2GUiL0Ti>C0P29RHT01@0X
:2P0oooo0451@@11@D40P8200080/;2`00D0SXj>09RHV026QXH0QXJ60:JVYP0208Z:RP050;:b/P2E
UID0RHV908V9R@2=SHd00P1^KVh01@3oool0DU9B059BDP1oOgl0W9bL0080VIVI00D0UiNG09BDU02D
U9@0UYJF09RHV0020:ZZZP0409VIV@29RHT0RHV902`/;080oooo00D0K6a/09VIV@2<S8`0S8b<08f=
S@020:>SX`050:n_[`2>SXh0Shn?08n?S`2FUYH00P2QXJ401@2?Shl0UiNG09NGU`1QHF40oooo0080
G5aL00D0VYZJ09nOW`2OWil0UYJF08j>SP020:>SX`050:6QX@2DU9@0U9BD09JFUP2ATI400P2NWYh0
101=CDd0no_k0?_kn`2PX:0206][J`0509^KV`2LW9`0V9RH09RHV02FUYH00P2WYjL01@2KVi/0OWin
08n?S`2?Shl0ZZZZ0080Rh^;00D0UYJF0?ooo`3oool0<C4a09jNWP0209:BTP050:JVYP28R8P0R8R8
09ZJVP2SXj<00P2>SXh01@2ZZZX0SXj>08j>SP2:RXX0C4a<0080oooo00@0<S8b08V9R@29RHT0Ti>C
0P2UYJD01@2LW9`0[Jf]08Z:RP2:RXX0_Kfm0080PX:200D0S8b<07IfMP1mOGd0OGem0?ooo`0204M7
A`0509fMW@2CTi<0Ti>C09nOW`1fMWH00P34a<@0102<S8`0_;bl0;bl_01YJFT:0?ooo`0404m?C`1@
D500D51@055AD@80DU9B00D0EEEE05MGE`1EEED0EEEE05=CD`02051@D00504];B`17AdL0AdM704Y:
BP1>CTh00P1EEED01@1HF5P0EUIF05IFEP1FEUH0EeMG0080DU9B00@0E5AD05]KF`1KFe/0Fe]K0P1F
EUH01@1DE5@0DU9B04e=C@1=CDd0C4a<0080D51@00D0EEEE05]KF`1SHf<0Hf=S06ATI00306=SH`04
065QH@1LG5`0G5aL05eMG@80GUiN00D0GEeM05]KF`1KFe/0GEeM05aLG00205eMG@05065QH@1VIVH0
IVIV06IVIP1UIFD00P1TI6@305iNGP0305aLG01MGEd0GEeM0080H61P0P1MGEd01@1QHF40Hf=S06=S
H`1UIFD0J6QX0080Jf][00@0JVYZ06IVIP1VIVH0HV9R0P1NGUh205]KF`80GEeM00D0HF5Q06ATI01T
I6@0HV9R061PH00205iNGP0405aLG01IFET0FEUI05YJFP@0Fe]K0P1LG5`01@1RHV80IfMW06MWI`1^
KVh0Lg=c0080MWIf00D0M7Ad06i^KP1^KVh0IfMW06=SH`02065QH@04069RHP1TI6@0I6AT06EUI@80
I6AT1`1SHf<01@1OGel0G5aL05aLG01LG5`0FUYJ0080F5QH00<0Fe]K05mOG`1PH6000P1PH60206=S
H`05065QH@1KFe/0Fe]K05YJFP1LG5`00`1NGUh205mOG`0506=SH`1UIFD0IfMW06MWI`1^KVh00P1b
LW83075aL@0507=cL`1`L700J6QX06QXJ01SHf<00P1LG5`00`1DE5@0oooo0?ooo`0=0?ooo`003@3o
ool0102ZZZX0MGEe07EeM@2m_Kd209nOW`0508B4Q02OWil0TI6A096AT@2RXZ800P2=SHd01@1;Bd/0
oooo0?ooo`16ATH0Rh^;0080Ti>C00D0S8b<0820P020P800c/k>0::RXP020820P0040:RXZ02GUiL0
UiNG09BDU080S8b<00D0ADE50?ooo`12@T80@T9208j>SP020:n_[`0508B4Q02?Shl0VYZJ09ZJVP2V
YZH00P2FUYH01@2UYJD0Ti>C08Z:RP2:RXX0SXj>0080P82000D0oooo069RHP1RHV80Q8B409NGU`02
0:JVYP0507AdM02m_Kd0_Kfm09RHV023Ph<00P2^[Zh0102OWil0R8R808R8R019BDT20?ooo`0508B4
Q02FUYH0UIFE09FEU@2:RXX00P2LW9`01@2@T900c<c<07moO`1oOgl0RXZ:0080ZZZZ00D0Ph>30:FU
Y@2UYJD0JVYZ0>c/k00206=SH`050:FUY@2OWil0WinO09bLW01mOGd00P2VYZH01@2o_kl0Lg=c07=c
L`2[Zj/0RHV90080WinO00@0GemO0=_Kf`3Kfm/0WinO0P1gMgL01@2JVYX0WYjN09VIV@2IVIT0O7al
0080emOG00D0SHf=07UiN@2EUID0UIFE09nOW`0208j>SP0509nOW`3[jn/0jn_[04i>CP2OWil00P2;
Rh/01@2UYJD0MGEe07EeM@2l_;`0Y:BT0080Q8B400D0XZ:R09>CT`2CTi<0S8b<065QH@020?ooo`04
04M7A`2<S8`0S8b<09:BTP80Xj>S00D0OWin0>;RhP1jNWX0NWYj0;6a/@0208N7Q`0508f=S@1oOgl0
QhN708N7Q`3gmoL00P1RHV801@2NWYh0TY:B09:BTP2KVi/0K6a/0080j>SX00@0OGem0:JVYP2VYZH0
N7Qh2P3oool00`1MGEd0G5aL05aLG00305]KF`0505YJFP1HF5P0Fe]K05]KF`1QHF400P1TI6@01@1V
IVH0J6QX06QXJ01TI6@0HF5Q00<0GUiN0P1QHF4206EUI@<0IVIV0P1SHf<01@1PH600GUiN05iNGP1M
GEd0GUiN0080HF5Q00D0Hf=S06IVIP1VIVH0Hf=S069RHP0205mOG`0505aLG01JFUX0FUYJ05]KF`1I
FET00P1LG5`305]KF`@0FUYJ00<0G5aL05eMG@1MGEd0101NGUh0101MGEd0Fe]K05]KF`1PH605069R
HPL0H61P00D0HF5Q05YJFP1FEUH0EUIF059BDP02055AD@<0De=C00D0E5AD05QHF01IFET0FEUI05QH
F00205YJFP0505eMG@1NGUh0HV9R069RHP1TI6@00P1WIfL01@1SHf<0HF5Q05eMG@1MGEd0FEUI0080
DU9B0`1?Cdl01@1;Bd/0CDe=059BDP1BDU80De=C00<0E5AD00@0D51@04e=C@1=CDd0CDe=1@1;Bd/0
101:BTX0B4Q804M7A`17AdL304E5A@0504I6AP17AdL0AdM704M7A`18B4P00P1@D5001@1?Cdl0BTY:
04Y:BP1:BTX0Bd];0080@d=300D0B4Q804e=C@1=CDd0C4a<04I6AP0204=3@`0503dm?@0i>CT0>CTi
03Ph>00c<c<00P0_;bl0100Y:BT08B4Q024Q8@0I6AT301XJ6P0401dM7@0/;2`0;2`/03/k>`80B4Q8
00<0De=C0?ooo`3oool03@3oool000d0oooo00@0YZJV05UIF@1IFET0hN7Q0P2VYZH01@1fMWH0W9bL
096AT@2ATI40Xj>S0080T92@00D0KFe]0?ooo`3oool0De=C09JFUP0209:BTP0509>CT`1VIVH0IVIV
0=[JfP2a/K400P1eMGD0102WYjL0TI6A096AT@2IVIT208j>SP0505mOG`3oool0E5AD05ADE02BTY80
0P2/[:`01@2;Rh/0N7Qh0;Fe]@2e]KD0WinO0080Xj>S00D0V9RH08n?S`2ATI40TI6A08R8R00209RH
V0050>;RhP1`L700L71`08Z:RP2>SXh00P2h^;P01@1<C4`0j>SX0>SXj02GUiL0LG5a0080/;2`00@0
X:2P08^;R`2;Rh/0JFUY0P3Lg=`01@29RHT0WYjN09FEU@2EUID0SXj>0080Ti>C00D0MgMg0?ooo`1Y
JFT0JFUY08F5Q@020:ZZZP050820P02XZ:P0Z:RX07emO@37alL00P1YJFT01@2a/K40WYjN09jNWP2V
YZH0KVi^0080V9RH00D0hn?S061PH01PH600[Zj^08R8R00209jNWP0407IfMP2k^k/0^k^k0:2PX080
PX:200D0WIfM09jNWP2DU9@0U9BD06IVIP020?ooo`05071`L01jNWX0W9bL09bLW02JVYX00P2CTi<0
1@2QXJ40a/K60<K6aP1[Jf/0WIfM0080Shn?00D0XJ6Q05iNGP1NGUh0g]kN0:FUY@0207alO00509fM
W@2EUID0UIFE08f=S@1kNg/00P3moOd0101VIVH0Q8B408B4Q02FUYH20:2PX00506ATI03oool0IVIV
06IVIP2XZ:P00P2<S8`01@2;Rh/0Shn?08n?S`2?Shl0b/[:0080O7al00D0WinO092@T02@T900TY:B
06UYJ@020?ooo`0406a/K02IVIT0VIVI08J6QPX0oooo00@0:2PX02@T900T92@08b<S100P820201lO
7`04028R8P0S8b<08b<S02DU9@809bLW00D0;Bd]02h^;P0c<c<0<c<c03Ph>00203`l?00503Ph>00e
=CD0<C4a034a<@0[:b/00P0V9RH00`0^;Rh0;bl_02l_;`02030`<080;2`/00D08b<S020P800P8200
820P01hN7P0202<S8`0502@T900X:2P0:2PX02DU9@0V9RH00`0X:2P202LW9`0502TY:@0[:b/0:b/[
02DU9@0T92@00P0S8b<00`0P820071`L01`L700201dM7@8071`L00<08b<S02PX:00X:2P00`0[:b/0
1@0`<3009bLW02LW9`0W9bL09RHV0080:RXZ00@0;Bd]03Hf=P0g=cL0=cLg0`0j>SX01@0m?Cd0@D51
0451@@16ATH0BDU90080BTY:00<0AdM704=3@`13@d<00P0n?Sh303dm?@80>3Ph00D0=SHf03@d=00c
<c<0<c<c03De=@0203hn?P0504=3@`0n?Sh0?Shn03hn?P0e=CD00P0Z:RX01@0[:b/0<C4a034a<@0k
>c/0BTY:0080Fe]K00@0I6AT06EUI@1UIFD0HV9R0P1OGel01@1GEeL0D51@04a<C01<C4`0BTY:00<0
BDU900@0C4a<055AD@1ADE40FEUI0P1TI6@00`1ZJVX0K6a/06m_K`0206m_K`<0KVi^0P1gMgL01@23
Ph<0Shn?09JFUP2FUYH0XJ6Q0080ZJVY00D0[:b/0;:b/P2d];@0];Bd0;Rh^0020;fm_@050<71`@2b
/[80/[:b0:b/[02UYJD00P25QHD0101UIFD0EEEE05EEE@0o?cl?0?ooo`003@3oool0102VYZH0FEUI
05UIF@3QhN420:JVYP0507IfMP2LW9`0TI6A096AT@2SXj<00P2@T9001@1]KFd0oooo0?ooo`1CDe<0
UYJF0080TY:B00D0Ti>C06IVIP1VIVH0f][J0;6a/@0207EeM@040:NWY`2ATI40TI6A09VIV@80SXj>
00D0GemO0?ooo`1DE5@0E5AD09:BTP020:b/[00508^;R`1hN7P0]KFe0;Fe]@2OWil00P2SXj<01@2H
V9P0Shn?096AT@2ATI40R8R80080V9RH00D0h^;R071`L01`L700RXZ:08j>SP020;Rh^00504a<C03X
j>P0j>SX09NGU`1aLG400P2`/;00102PX:00Rh^;08^;R`1YJFT20=cLg00508V9R@2NWYh0UIFE09FE
U@2>SXh00P2CTi<01@1gMgL0oooo06UYJ@1YJFT0QHF50080ZZZZ00D0P8200:RXZ02XZ:P0OGem0<O7
a`0206UYJ@050;6a/@2NWYh0WYjN0:JVYP1^KVh00P2HV9P01@3Shn<0H61P061PH02^[Zh0R8R80080
WYjN00@0MWIf0;^k^`2k^k/0X:2P0P22PX801@2MWId0WYjN09BDU02DU9@0IVIV0080oooo00D0L71`
07YjNP2LW9`0W9bL09ZJVP0209>CT`050:6QX@36a/H0a/K606][J`2MWId00P2?Shl01@2QXJ40GUiN
05iNGP3Ng]h0YJFU0080O7al00D0WIfM09FEU@2EUID0SHf=07]kN`020?gmo@0406IVIP24Q8@0Q8B4
09JFUP80X:2P00D0I6AT0?ooo`1VIVH0IVIV0:RXZ00208b<S00508^;R`2?Shl0Shn?08n?S`3:b/X0
0P1lO7`01@2OWil0T92@092@T02BTY80JFUY0080oooo00@0K6a/09VIV@2IVIT0QXJ62P3oool0100X
:2P092@T02@T900S8b<4020P80807alO00@08R8R02<S8`0S8b<09BDU0P0W9bL01@0];Bd0;Rh^03<c
<`0c<c<0>3Ph0080?3`l00D0>3Ph03De=@0a<C40<C4a02/[:`0202HV9P0302h^;P0_;bl0;bl_0080
<30`0P0/;2`01@0S8b<0820P020P800P82007QhN00808b<S00D092@T02PX:00X:2P09BDU02HV9P03
02PX:0809bLW00D0:BTY02/[:`0[:b/09BDU02@T900202<S8`03020P800L71`071`L00807AdM0P0L
71`00`0S8b<0:2PX02PX:00302/[:`05030`<00W9bL09bLW02LW9`0V9RH00P0Z:RX0100];Bd0=SHf
03Lg=`0g=cL303Xj>P0503dm?@11@D40@D5104I6AP19BDT00P1:BTX00`17AdL0@d=304=3@`0203hn
?P<0?Cdm0P0h>3P01@0f=SH0=3@d03<c<`0c<c<0=CDe0080?Shn00D0@d=303hn?P0n?Sh0?Shn03De
=@0202XZ:P0502/[:`0a<C40<C4a03/k>`1:BTX00P1KFe/0101TI6@0IFEU06EUI@1RHV8205mOG`05
05MGE`1@D500C4a<04a<C01:BTX00`19BDT0101<C4`0DE5A055AD@1IFET206ATI00306YZJP1/K6`0
Kfm_0080Kfm_0`1^KVh207MgM`0508>3P`2?Shl0UYJF09JFUP2QXJ400P2YZJT01@2/[:`0/[:b0;Bd
]02d];@0^;Rh0080_Kfm00D0`L710;:b/P2b/[80[:b/0:FUY@0208F5Q@0406EUI@1EEED0EEEE03lo
?`l0oooo000=0?ooo`040::RXP10@400@4100?ooo`80[jn_00D0JFUY09VIV@2>SXh0SXj>0:BTY002
09ZJVP0508:2PP3Ph>00h>3P06ATI02PX:000P2CTi<01@2KVi/0B4Q804Q8B03Vi^H0alO70080Jf][
00@0WinO092@T02@T900V9RH0P2EUID01@1jNWX0j^[Z06][J`1[Jf/0T92@0080ZZZZ00D0UIFE065Q
H@3:b/X0b/[:09VIV@020;:b/P05092@T024Q8@0UiNG09NGU`20P8000P2h^;P01@2b/[80PX:208:2
PP2>SXh0QHF50080c/k>00D08R8R0?ooo`3oool0TI6A06YZJP020;2`/00409ZJVP2@T900T92@08Z:
RP80[jn_00D0TI6A0:6QX@2DU9@0U9BD09VIV@0208^;R`05065QH@3oool0CTi>04i>CP2:RXX00P2T
Y:@01@25QHD0ZZZZ0:ZZZP2:RXX0Z:RX0080LW9b00D0^;Rh09bLW02LW9`0Zj^[06EUI@0208^;R`05
0?ooo`1<C4`0C4a<0:VYZ@2=SHd00P2FUYH0102@T900Y:BT0:BTY02IVIT208Z:RP050:BTY02MWId0
TY:B09:BTP1?Cdl00P3oool00`1ADE40P82009RHV00209RHV080VIVI00D0X:2P0:ZZZP2ZZZX0Ph>3
09VIV@0209:BTP0509jNWP19BDT0BDU90?ooo`2TY:@00P1bLW801@2EUID0WYjN09jNWP2FUYH0TI6A
0080[Zj^00@0Y:BT07MgM`1gMgL0VYZJ0P2IVIT01@1GEeL0oooo05aLG01LG5`0V9RH0080U9BD00D0
SHf=09VIV@2EUID0UIFE0:BTY00209RHV00509VIV@2BTY80TY:B08J6QP1QHF400P3oool0101FEUH0
UIFE09FEU@2:RXX:0?ooo`040::RXP2][Jd0[Jf]0;>c/`80^k^k00D0a/K60<k>cP3>c/h0c/k>0<g=
c@020<_;b`050<[:bP37alL0alO70<C4a032`/800P2b/[801@2QXJ40VYZJ09ZJVP2FUYH0U9BD0080
XJ6Q00@0/K6a0;Rh^02h^;P0]kNg0P2j^[X01@2i^KT0^[Zj0;no_`2o_kl0alO70080`l?30P30`<02
0<;2`P050<O7a`3De=@0e=CD0>GUi@3^k^h00P3]kNd0103Zj^X0inOW0>OWi`3QhN420=[JfP050=cL
g03>c/h0alO70<O7a`38b<P00P3<c<`01@38b<P0d];B0=_Kf`3Kfm/0dM7A00<0bl_;0P3:b/X01@33
`l<0c<c<0<g=c@3=cLd0`<300080^k^k00D0_;bl0;^k^`2n_[h0_[jn0<_;b`020=3@d0050<[:bP36
a/H0a/K60;jn_P2j^[X00P2g]kL30;jn_P050;fm_@2k^k/0/[:b0;:b/P2[Zj/00P2_[jl01@2m_Kd0
`/;20<c<c03<c<`0d=3@0080bl_;00D0`/;20<G5a@35aLD0alO70<C4a0020<W9b@050<_;b`35aLD0
aLG50;bl_02g]kL00P2XZ:P309^KV`050:2PX02TY:@0Y:BT0;2`/02m_Kd00P2o_kl01@34a<@0b<S8
0<S8b038b<P0a/K60080alO700D0_kno0:j^[P2^[Zh0ZZZZ0:VYZ@020:JVYP040:FUY@2ZZZX0ZZZZ
09nOW`80SHf=00D0OWin06e]K@1NGUh0GUiN05ADE00204U9B@0503dm?@0i>CT0>CTi03Ti>@0h>3P0
0P0k>c/01@12@T80CTi>04i>CP1ADE40E5AD0080JVYZ00@0OGem08J6QP26QXH0TI6A3`3oool000d0
oooo00@0WYjN02/[:`0[:b/0oooo0P2j^[X01@1JFUX0UYJF08n?S`2?Shl0Y:BT0080W9bL00D0UYJF
0;2`/02`/;00MgMg0:^[Z`0209BDU00509jNWP0/;2`0;2`/0?7al@3Ti>@00P1BDU80102UYJD0SXj>
08j>SP2EUID209nOW`0508f=S@2g]kL0QXJ608J6QP2@T9000P2TY:@01@2NWYh0CTi>0=gMg@3MgMd0
Vi^K0080_kno00D0O7al08B4Q02KVi/0Vi^K07MgM`020<o?c`05096AT@2EUID0UIFE08f=S@1lO7`0
0P3Bd]801@0F5QH0oooo0?ooo`2IVIT0G5aL0080[Jf]00@0UYJF09NGU`2GUiL0Xj>S0P2<S8`209VI
V@80Vi^K00D0V9RH09>CT`2CTi<0CTi>0?ooo`0203hn?P0408R8R02OWil0WinO08^;R`80Zj^[00D0
UIFE09RHV01aLG40LG5a0;Vi^@0209ZJVP050:n_[`1IFET0QXJ608J6QP3oool00P0`<3001@2UYJD0
Shn?09ZJVP2JVYX0W9bL0080Shn?00D0WYjN096AT@2ATI40WinO09NGU`0209RHV00503`l?03oool0
oooo04I6AP1hN7P00P2LW9`0102EUID0Vi^K09^KV`2KVi/209bLW005096AT@2HV9P0U9BD09BDU02G
UiL00P11@D401@3oool0SXj>07IfMP1fMWH0U9BD0080Y:BT00D0WIfM09VIV@28R8P0R8R80;Ng]`02
07MgM`050:BTY02CTi<0Ti>C05ADE03oool00P1LG5`01@2ATI40T92@092@T02EUID0WIfM00<0UiNG
0P2IVIT01@2JVYX0UiNG09NGU`1lO7`0H61P0080oooo00@0Fe]K09VIV@2IVIT0PX:22P3oool0101U
IFD0FEUI05UIF@1@D50204I6AP0503`l?00b<S80<S8b038b<P0Z:RX00P0X:2P01@0T92@09BDU02DU
9@0T92@0:2PX0080>c/k00D0C4a<055AD@1ADE40EUIF05UIF@0204Y:BP0403/k>`0e=CD0=CDe02d]
;@<0:BTY00@09BDU028R8P0R8R809RHV0P0];Bd01@0d=3@0>3Ph03De=@0e=CD0<C4a008092@T00<0
4a<C00L71`0410@00P0410@200D51@0500X:2P0C4a<04a<C01TI6@0Z:RX00P0b<S801@0a<C40;Rh^
02h^;P0b<S809RHV00<07AdM0P0N7Qh01@0L71`07QhN01hN7P0R8R8092@T00809BDU00D0<c<c03De
=@0e=CD0<S8b030`<00202d];@0301hN7P0G5aL05aLG00<06ATI00D071`L01XJ6P0K6a/06a/K01PH
600201lO7`0502DU9@0W9bL0<C4a034a<@0f=SH00P0_;bl01@0S8b<07alO01DE5@0E5AD04Q8B0080
5ADE00D071`L01lO7`0O7al0820P02PX:00502`/;005030`<00Z:RX0:BTY02TY:@0/;2`00P0];Bd0
1@0[:b/0:2PX02PX:00R8R807AdM00807QhN00<06QXJ01PH600H61P00P0G5aL200l?3`0300d=3@0>
3Ph03Ph>008030`<0P0=3@d0100>3Ph04A4A014A4@0M7Ad202PX:00502l_;`0g=cL0@D510451@@12
@T800P16ATH01@1<C4`0Cdm?04m?C`1?Cdl0CTi>0080C4a<1@1:BTX204e=C@0405EEE@1IFET0FEUI
065QH@l0oooo000=0?ooo`0409>CT`0Z:RX0:RXZ0?ooo`80b<S800D0BTY:09BDU02@T900T92@0:NW
Y`0209fMW@0509RHV02LW9`0W9bL08B4Q02_[jl00P2BTY801@2OWil07QhN01hN7P3jn_X0k^k^0080
CTi>00@0WYjN09BDU02DU9@0T92@0P2SXj<01@2CTi<0Z:RX08V9R@29RHT0VIVI0080WYjN00D0XJ6Q
04Y:BP3Ogml0gmoO0:6QX@020;no_`0507YjNP1mOGd0W9bL09bLW01mOGd00P3;bl/01@2=SHd0WinO
09nOW`26QXH0O7al0080dM7A00D06ATI0?ooo`3oool0WYjN05UIF@020:FUY@040:2PX02DU9@0U9BD
09jNWP80TI6A00D0VIVI096AT@2PX:00X:2P09nOW`0208^;R`0504=3@`3oool0@T920492@P2:RXX0
0P2JVYX01@2:RXX0YjNW0:NWY`2KVi/0VIVI0080KVi^00D0]kNg09bLW02LW9`0ZZZZ061PH00208J6
QP050?ooo`0e=CD0=CDe0:FUY@2NWYh00P2IVIT0102BTY80TI6A096AT@2NWYh208B4Q0050:n_[`2J
VYX0TI6A096AT@12@T800P3oool01@15ADD0M7Ad0:VYZ@2YZJT0Vi^K0080TI6A00D0Vi^K09jNWP2N
WYh0Rh^;0:BTY00209FEU@0509NGU`1:BTX0BTY:0?ooo`1iNGT00P20P8001@2PX:00WYjN09jNWP2K
Vi/0V9RH0080RHV900@0ZJVY09^KV`2KVi/0U9BD0P2;Rh/01@1QHF40oooo05YJFP1JFUX0W9bL0080
XJ6Q00D0SHf=09ZJVP2KVi/0Vi^K09:BTP0208>3P`050<G5a@23Ph<0Ph>308:2PP1bLW800P3oool0
101LG5`0`L710<71`@1aLG4:0?ooo`0404M7A`1:BTX0BTY:04m?C`80EUIF00<0EeMG05]KF`1LG5`0
0P1LG5`205YJFP0305UIF@1EEED0EEEE0080EEEE0P1@D5001@1<C4`0BDU904U9B@1:BTX0CDe=0080
E5AD00@0Fe]K06=SH`1SHf<0IFEU0`1WIfL0101YJFT0IfMW06MWI`1SHf<2065QH@0505iNGP1JFUX0
FUYJ05YJFP1KFe/00P1HF5P01@1JFUX0GEeM05iNGP1NGUh0H61P0080HF5Q00D0H61P05eMG@1MGEd0
FUYJ05QHF00305IFEP80F5QH00@0FEUI05]KF`1NGUh0GUiN101OGel205iNGP0505eMG@1JFUX0FEUI
05UIF@1JFUX00P1IFET405MGE`0405IFEP1HF5P0F5QH05UIF@80G5aL00D0HF5Q06EUI@1WIfL0IfMW
06IVIP02069RHP0505aLG01KFe/0EeMG05MGE`1IFET00P1OGel00`1SHf<0HV9R06IVIP0206IVIP80
HV9R00<0HF5Q05mOG`1OGel00P1MGEd205YJFP0505UIF@1JFUX0FUYJ05UIF@1HF5P00P1JFUX0101I
FET0F5QH05QHF01FEUH205MGE`@0F5QH0`1JFUX01@1HF5P0EUIF05EEE@1EEED0EeMG0080FEUI00D0
EeMG05YJFP1KFe/0Fe]K05MGE`0205ADE00505QHF01FEUH0EUIF05QHF01KFe/00`1LG5`205iNGP05
05eMG@1KFe/0Fe]K05]KF`1LG5`00P1MGEd00`1LG5`0FUYJ05YJFP0205aLG080F5QH00@0DU9B04i>
CP1>CTh0BTY:3`3oool000d0oooo00@0Ti>C02XZ:P0Z:RX0oooo0P38b<P01@1:BTX0U9BD092@T02@
T900YjNW0080WIfM00D0V9RH09bLW02LW9`0Q8B40:n_[`0209:BTP0509nOW`0N7Qh07QhN0?[jnP3^
k^h00P1>CTh0102NWYh0U9BD09BDU02@T9020:>SX`0509>CT`2XZ:P0RHV908V9R@2IVIT00P2NWYh0
1@2QXJ40BTY:0=oOg`3Ogml0XJ6Q0080_kno00D0NWYj07emO@2LW9`0W9bL07emO@020<_;b`0508f=
S@2OWil0WinO08J6QP1lO7`00P3AdM401@0I6AT0oooo0?ooo`2NWYh0FEUI0080YJFU00@0X:2P09BD
U02DU9@0WYjN0P2ATI401@2IVIT0TI6A0:2PX02PX:00WinO0080Rh^;00D0@d=30?ooo`12@T80@T92
08Z:RP0209ZJVP0508Z:RP2WYjL0YjNW09^KV`2IVIT00P1^KVh01@2g]kL0W9bL09bLW02ZZZX0H61P
0080QXJ600D0oooo03De=@0e=CD0YJFU09jNWP0209VIV@0409:BTP2ATI40TI6A09jNWP80Q8B400D0
[jn_09ZJVP2ATI40TI6A0492@P020?ooo`0504E5A@1dM7@0ZJVY0:VYZ@2KVi/00P2ATI401@2KVi/0
WYjN09jNWP2;Rh/0Y:BT0080UIFE00D0UiNG04Y:BP1:BTX0oooo07UiN@020820P0050:2PX02NWYh0
WYjN09^KV`2HV9P00P29RHT0102YZJT0Vi^K09^KV`2DU9@208^;R`05065QH@3oool0FUYJ05YJFP2L
W9`00P2QXJ401@2=SHd0VYZJ09^KV`2KVi/0TY:B0080Ph>300D0aLG508>3P`23Ph<0PX:2079bLP02
0?ooo`0405aLG031`L40`L71075aL@X0oooo00@0AdM704Y:BP1:BTX0Cdm?0P1FEUH00`1GEeL0Fe]K
05aLG00205aLG080FUYJ00<0FEUI05EEE@1EEED00P1EEED2051@D00504a<C019BDT0BDU904Y:BP1=
CDd00P1DE5@0101KFe/0Hf=S06=SH`1UIFD306MWI`0406UYJ@1WIfL0IfMW06=SH`80HF5Q00D0GUiN
05YJFP1JFUX0FUYJ05]KF`0205QHF00505YJFP1MGEd0GUiN05iNGP1PH6000P1QHF401@1PH600GEeM
05eMG@1JFUX0F5QH00<0EUIF0P1HF5P0101IFET0Fe]K05iNGP1NGUh405mOG`80GUiN00D0GEeM05YJ
FP1IFET0FEUI05YJFP0205UIF@@0EeMG00@0EUIF05QHF01HF5P0FEUI0P1LG5`01@1QHF40IFEU06MW
I`1WIfL0IVIV0080HV9R00D0G5aL05]KF`1GEeL0EeMG05UIF@0205mOG`0306=SH`1RHV80IVIV0080
IVIV0P1RHV800`1QHF40GemO05mOG`0205eMG@80FUYJ00D0FEUI05YJFP1JFUX0FEUI05QHF00205YJ
FP0405UIF@1HF5P0F5QH05IFEP80EeMG101HF5P305YJFP0505QHF01FEUH0EEEE05EEE@1GEeL00P1I
FET01@1GEeL0FUYJ05]KF`1KFe/0EeMG0080E5AD00D0F5QH05IFEP1FEUH0F5QH05]KF`0305aLG080
GUiN00D0GEeM05]KF`1KFe/0Fe]K05aLG00205eMG@0305aLG01JFUX0FUYJ0080G5aL0P1HF5P0101B
DU80CTi>04i>CP1:BTX?0?ooo`003@3oool0102TY:@0=CDe03De=@3oool20<30`00505mOG`1jNWX0
Zj^[0:^[Z`2a/K400P2?Shl01@2BTY80XJ6Q0:6QX@25QHD0U9BD0080];Bd00<0Zj^[02TY:@0Y:BT0
0P3Lg=`205YJFP0408Z:RP2k^k/0^k^k08j>SP80V9RH00D0Ti>C0:>SX`29RHT0RHV908J6QP020=;B
dP0408b<S01FEUH0c<c<0<c<c0<0WYjN00D0T92@0:JVYP23Ph<0Ph>307inOP020<G5a@05092@T02=
SHd0SHf=092@T02CTi<00P31`L401@0i>CT0oooo0?ooo`2MWId0EEEE0080/[:b00@0Zj^[08F5Q@25
QHD0Y:BT0P2BTY801@2FUYH0PH610:^[Z`2[Zj/0/k>c0080PH6100D0EeMG0?ooo`1DE5@0E5AD08Z:
RP020;Fe]@0508R8R02EUID0UIFE0:BTY02JVYX00P1SHf<01@2XZ:P0dM7A0=7Ad@2>SXh0JVYZ0080
Ph>300D0oooo0492@P12@T80SXj>0=CDe00207alO00409>CT`2@T900T92@09fMW@80IfMW00D0iNGU
096AT@23Ph<0Ph>305aLG0020?ooo`0504a<C01LG5`0k^k^0>k^kP22PX800P28R8P01@2KVi/0W9bL
09bLW01cLg<0d=3@0080Rh^;00D0SXj>061PH01PH600lo?c06i^KP0209:BTP050;>c/`2BTY80TY:B
09RHV02GUiL00P25QHD0102?Shl0fMWI0=WIf@1hN7P208R8R00507YjNP3Zj^X0BDU904U9B@3;bl/0
0P2WYjL01@20P800UYJF09ZJVP2JVYX0SXj>0080IVIV00D0oooo06EUI@1UIFD0Ph>308b<S0020>OW
i`04061PH03Vi^H0i^KV05=CD`X0oooo00@0GUiN05mOG`1OGel0GUiN0P1OGel01@1PH600HV9R06AT
I01TI6@0J6QX0080Jf][00D0JVYZ06UYJ@1YJFT0IVIV069RHP0305iNGP80GemO00@0G5aL05UIF@1I
FET0FEUI0`1JFUX01@1PH600HV9R069RHP1RHV80I6AT0080IFEU0`1TI6@4069RHP0505iNGP1MGEd0
GEeM061PH01MGEd00P1GEeL305IFEP<0EEEE00D0De=C05ADE01BDU80DU9B05IFEP0205MGE`0305iN
GP1PH600IFEU00@0IFEU00D0IVIV06ATI01TI6@0HV9R05mOG`0205aLG00305]KF`1JFUX0FUYJ0080
GUiN0P1PH600101NGUh0GEeM05eMG@1IFET305YJFP<0GEeM00D0G5aL05IFEP1FEUH0DE5A04e=C@02
04a<C00504];B`1=CDd0CDe=04m?C`1@D5000`1>CTh2059BDP0505=CD`1EEED0EEEE05EEE@1HF5P0
0P1CDe<01@1@D500Bd];04];B`18B4P0@d=30080@T9200@0@4100492@P12@T80ADE50P17AdL01@1:
BTX0C4a<051@D01@D500E5AD0080DE5A00D0Cdm?059BDP1ADE40DE5A04];B`0204Q8B005055AD@19
BDT0@T920492@P11@D400P12@T801@0j>SX0>c/k03/k>`0j>SX0>3Ph0080=cLg00D0=3@d03<c<`0c
<c<0=CDe03Hf=P0203@d=004034a<@0];Bd0;Bd]02/[:`80<S8b0P0`<30203`l?00404I6AP17AdL0
AdM705ADE0l0oooo000=0?ooo`040<o?c`0i>CT0>CTi0>GUi@80_[jn00D0KFe]06ATI037alL0alO7
0;^k^`0207alO005092@T02RXZ80XZ:R08V9R@1[Jf/00P3WinL01@2a/K40;Rh^02h^;P37alL0b<S8
0080LG5a00@0IFEU0>_[j`3[jn/0S8b<0P2:RXX01@2BTY80X:2P07moO`1oOgl0NWYj0080oooo00D0
K6a/06e]K@2b/[80/[:b0:>SX`020820P00509nOW`3@d=00Jf][06][J`22PX800P2h^;P01@2CTi<0
MWIf07IfMP2OWil0[Jf]0080[:b/00D0Fe]K0=cLg03Lg=`0X:2P05=CD`020;bl_0040;^k^`1cLg<0
Lg=c0:FUY@80SXj>00D0V9RH075aL@2m_Kd0_Kfm0;bl_00207]kN`0506e]K@3/k>`0K6a/06a/K01n
OWh00P3IfMT01@1nOWh0R8R808R8R02UYJD0Y:BT0080FUYJ00D0Ti>C0?ooo`3oool0LW9b075aL@02
08f=S@050?7al@15ADD0ADE509NGU`3alO400P1SHf<0102@T900TY:B09:BTP2KVi/204m?C`050?oo
o`24Q8@0NGUi07UiN@1dM7@00P3inOT01@1SHf<0?clo0?ooo`3oool0HF5Q0080Ph>300D0WIfM09^K
V`2KVi/0FEUI0?ooo`0207inOP0508V9R@1fMWH0MWIf0=?Cd`1NGUh00P2SXj<01@3=cLd0P8200820
P02HV9P0TY:B0080QXJ600@0LW9b0?ooo`3oool0FUYJ0P27QhL01@2>SXh0`L710492@P12@T80nOWi
0080XJ6Q00D0Lg=c09NGU`2KVi/0Vi^K08N7Q`0204U9B@050?ooo`16ATH0ATI608N7Q`2VYZH00P30
`<00101IFET0oooo0?ooo`0`<30:0?ooo`040492@P13@d<0@d=304A4A080@d=300D0>SXj03@d=00`
<300<30`02`/;00202h^;P0503De=@0k>c/0>c/k0410@014A4@00P19BDT00`1>CTh0CDe=04e=C@02
04m?C`80BTY:00@0?Shn03De=@0e=CD0:b/[0P0X:2P01@0T92@08R8R028R8P0R8R8092@T00809bLW
00D0<30`03<c<`0c<c<0<c<c03De=@02034a<@809RHV0`0Z:RX202/[:`0502l_;`0a<C40<C4a03Hf
=P0o?cl00P17AdL01@18B4P0A4A404A4A00o?cl0?3`l0080=cLg00@0>CTi03/k>`0k>c/0?3`l0P0h
>3P00`0i>CT0?Shn04A4A00204A4A080@41000D0>CTi03<c<`0^;Rh0;Rh^02l_;`02030`<004034a
<@0];Bd0;Bd]02HV9P<07alO00@0820P02d];@0];Bd0A4A40`1;Bd/00`1<C4`0@d=304=3@`02038b
<P80=cLg00<0?Cdm03Ti>@0i>CT0100e=CD0100i>CT0?clo03lo?`13@d<30451@@0403hn?P12@T80
@T9204Y:BP<0D51@0P1ADE401@1?Cdl0DU9B05mOG`1OGel0JFUY0080MgMg00D0Ph>308f=S@2>SXh0
SXj>09FEU@0209^KV`0509VIV@2BTY80VIVI09VIV@2NWYh00P2OWil01@2RXZ80Z:RX0:RXZ02MWId0
T92@0080Rh^;00D0SHf=08n?S`2?Shl0VIVI0::RXP0209^KV`040:6QX@2UYJD0YJFU0:b/[080/K6a
00D0a<C40<71`@2TY:@0Y:BT08J6QP0206a/K003059BDP3oool0oooo00d0oooo000=0?ooo`040<o?
c`0i>CT0>CTi0>GUi@80_[jn00D0KFe]06ATI037alL0alO70;^k^`0207alO005092@T02RXZ80XZ:R
08V9R@1[Jf/00P3WinL01@2a/K40;Rh^02h^;P37alL0b<S80080LG5a00@0IFEU0>_[j`3[jn/0S8b<
0P2:RXX01@2BTY80X:2P07moO`1oOgl0NWYj0080oooo00D0K6a/06e]K@2b/[80/[:b0:>SX`020820
P00509nOW`3@d=00Jf][06][J`22PX800P2h^;P01@2CTi<0MWIf07IfMP2OWil0[Jf]0080[:b/00D0
Fe]K0=cLg03Lg=`0X:2P05=CD`020;bl_0040;^k^`1cLg<0Lg=c0:FUY@80SXj>00D0V9RH075aL@2m
_Kd0_Kfm0;bl_00207]kN`0506e]K@3/k>`0K6a/06a/K01nOWh00P3IfMT01@1nOWh0R8R808R8R02U
YJD0Y:BT0080FUYJ00D0Ti>C0?ooo`3oool0LW9b075aL@0208f=S@050?7al@15ADD0ADE509NGU`3a
lO400P1SHf<0102@T900TY:B09:BTP2KVi/204m?C`050?ooo`24Q8@0NGUi07UiN@1dM7@00P3inOT0
1@1SHf<0?clo0?ooo`3oool0HF5Q0080Ph>300D0WIfM09^KV`2KVi/0FEUI0?ooo`0207inOP0508V9
R@1fMWH0MWIf0=?Cd`1NGUh00P2SXj<01@3=cLd0P8200820P02HV9P0TY:B0080QXJ600@0LW9b0?oo
o`3oool0FUYJ0P27QhL01@2>SXh0`L710492@P12@T80nOWi0080XJ6Q00D0Lg=c09NGU`2KVi/0Vi^K
08N7Q`0204U9B@050?ooo`16ATH0ATI608N7Q`2VYZH00P30`<00101IFET0oooo0?ooo`0`<30:0?oo
o`040492@P13@d<0@d=304A4A080@d=300D0>SXj03@d=00`<300<30`02`/;00202h^;P0503De=@0k
>c/0>c/k0410@014A4@00P19BDT00`1>CTh0CDe=04e=C@0204m?C`80BTY:00@0?Shn03De=@0e=CD0
:b/[0P0X:2P01@0T92@08R8R028R8P0R8R8092@T00809bLW00D0<30`03<c<`0c<c<0<c<c03De=@02
034a<@809RHV0`0Z:RX202/[:`0502l_;`0a<C40<C4a03Hf=P0o?cl00P17AdL01@18B4P0A4A404A4
A00o?cl0?3`l0080=cLg00@0>CTi03/k>`0k>c/0?3`l0P0h>3P00`0i>CT0?Shn04A4A00204A4A080
@41000D0>CTi03<c<`0^;Rh0;Rh^02l_;`02030`<004034a<@0];Bd0;Bd]02HV9P<07alO00@0820P
02d];@0];Bd0A4A40`1;Bd/00`1<C4`0@d=304=3@`02038b<P80=cLg00<0?Cdm03Ti>@0i>CT0100e
=CD0100i>CT0?clo03lo?`13@d<30451@@0403hn?P12@T80@T9204Y:BP<0D51@0P1ADE401@1?Cdl0
DU9B05mOG`1OGel0JFUY0080MgMg00D0Ph>308f=S@2>SXh0SXj>09FEU@0209^KV`0509VIV@2BTY80
VIVI09VIV@2NWYh00P2OWil01@2RXZ80Z:RX0:RXZ02MWId0T92@0080Rh^;00D0SHf=08n?S`2?Shl0
VIVI0::RXP0209^KV`040:6QX@2UYJD0YJFU0:b/[080/K6a00D0a<C40<71`@2TY:@0Y:BT08J6QP02
06a/K003059BDP3oool0oooo00d0oooo000=0?ooo`040?Ogm`11@D40@D510<30`080][Jf00D0NWYj
05=CD`3YjNT0jNWY0;no_`0206YZJP05092@T02PX:00X:2P08^;R`19BDT00P3oool01@2j^[X0>SXj
03Xj>P2c/k<0];Bd0080Ng]k00@0BDU90?ooo`3oool0QHF50P1mOGd01@2ATI40WIfM07alO01lO7`0
JVYZ0080oooo00D0B4Q807moO`2QXJ40XJ6Q0:NWY`02061PH0050:VYZ@3oool0E5AD05ADE027QhL0
0P2VYZH01@2JVYX0GUiN05iNGP2^[Zh0bl_;0080Shn?00D0OWin0;>c/`2c/k<0[jn_04];B`020<K6
aP040<k>cP1MGEd0GEeM0:>SX`80SHf=00D0VYZJ069RHP3Cdm<0dm?C0<C4a002075aL@0508:2PP2m
_Kd0QHF508F5Q@1ZJVX00P3oool01@1/K6`0Ogmo07moO`2VYZH0[Jf]0080Cdm?00D0Ph>30?ooo`3o
ool0DU9B07=cL`0209RHV0050<c<c01<C4`0C4a<0:>SX`3oool00P1@D500102=SHd0UIFE09FEU@2I
VIT203@d=0050?ooo`1lO7`0Kfm_06m_K`2;Rh/00P33`l<01@1lO7`08B4Q0?ooo`3oool0?Shn0080
QXJ600D0VIVI09ZJVP2JVYX0?clo0?ooo`0207=cL`050820P02<S8`0S8b<0;:b/P1DE5@00P2d];@0
1@3Ti>@0K6a/06a/K02CTi<0TI6A0080UIFE00@0A4A40?ooo`3oool0=cLg0P27QhL01@2LW9`0X:2P
03Hf=P0f=SH0oooo0080W9bL00D0IVIV09NGU`2IVIT0VIVI08J6QP0202XZ:P050?ooo`0M7Ad07AdM
09RHV02f][H00P2>SXh0101OGel0oooo0?ooo`0@410:0?ooo`0408j>SP2?Shl0Shn?09BDU080Rh^;
00D0Q8B408:2PP23Ph<0Ph>308F5Q@0208n?S`0509FEU@29RHT0RHV908>3P`25QHD00P29RHT01@2=
SHd0XZ:R0::RXP2/[:`0YZJV0080Xj>S00@0ZJVY0:j^[P2^[Zh0]kNg0P33`l<01@39bLT0_Kfm0;jn
_P2n_[h0`<300080`/;200D0a<C40=?Cd`3=cLd0cLg=0;fm_@020<30`0050<W9b@3:b/X0e=CD0=CD
e03Shn<00P3Hf=P01@36a/H0^k^k0;^k^`2b/[80Xj>S0080YJFU00D0[Zj^0:b/[02/[:`0Xj>S09nO
W`0209VIV@03096AT@2BTY80TY:B00<0U9BD00D0T92@08f=S@2=SHd0SHf=09>CT`020::RXP030:n_
[`2`/;00/[:b0080/[:b0P2`/;00102b/[80_[jn0;jn_P2o_kl30;Fe]@040;^k^`2i^KT0^KVi0;:b
/P<0`L7100D0][Jf0;fm_@2m_Kd0c/k>0=3@d0020<o?c`040=3@d034a<@0a<C40<;2`P80`l?300D0
a/K60<G5a@3@d=00d=3@0=GEe@020<g=c@050<o?c`3De=@0cLg=0<g=c@35aLD00P39bLT01@2n_[h0
^KVi0;Vi^@2i^KT0/k>c0080WYjN00D0TI6A0861P@21PH40L71`06ATI00206MWI`0506YZJP1/K6`0
K6a/06e]K@1cLg<00P1aLG40101]KFd0Jf][06][J`1XJ6P206IVIP0506a/K01hN7P0OGem07emO@22
PX800P1oOgl01@1hN7P0Jf][06][J`1[Jf/0HF5Q0080FEUI00D0Bd];03Ph>00h>3P08b<S02@T9002
03De=@0404M7A`1UIFD0IFEU07inOPl0oooo000>0?ooo`80AdM700D0W9bL0:^[Z`2[Zj/0RXZ:03lo
?`020?ooo`040<?3``1HF5P0F5QH09>CT`80XZ:R00D0T92@024Q8@3oool0oooo0;^k^`02055AD@05
0:NWY`2DU9@0RXZ:08Z:RP0/;2`00P3oool01@1hN7P0KFe]06e]K@2CTi<0XJ6Q0080L71`00D0HF5Q
0?ooo`3oool0:RXZ096AT@0209BDU00509RHV01>CTh0CTi>0<;2`P3oool00P0o?cl0102ATI40VYZJ
09ZJVP2HV9P204Q8B0050<o?c`3;bl/0SHf=08f=S@22PX800`2XZ:P0101>CTh0e=CD0=CDe03IfMT2
04Q8B00509nOW`2@T900T92@09ZJVP1FEUH00P3Vi^H01@37alL0KFe]06e]K@29RHT0W9bL0080Vi^K
00@0HV9R0?ooo`3oool0DU9B0P1fMWH01@2YZJT0[Zj^0492@P12@T80Q8B40080oooo00D0<c<c07em
O@2GUiL0UiNG09bLW002061PH0050:b/[03oool0>c/k03/k>`2<S8`00P2EUID01@2IVIT05aLG01LG
5`3oool0NGUi0080JFUY00D0ZZZZ096AT@2ATI40R8R800P820020?ooo`0402DU9@2=SHd0SHf=09BD
U080Ti>C00D0=3@d0?ooo`1TI6@0I6AT0820P00209RHV005096AT@1OGel0`l?30<?3``3WinL00P1M
GEd01@2EUID0Ti>C09>CT`2CTi<0>CTi0080oooo00D092@T08V9R@29RHT0VIVI09FEU@0203Hf=P05
0?ooo`2MWId0WIfM061PH02FUYH00P2HV9P01023Ph<0;2`/02`/;03oool2010@40050:6QX@2b/[80
QXJ608J6QP1HF5P00P3oool00`000000oooo0?ooo`080?ooo`<0HV9R00D0HF5Q06UYJ@1YJFT0MWIf
07emO@0207inOP0407moO`1fMWH0MWIf06][J`<0KVi^00@0IVIV05aLG01LG5`0Cdm?0P0k>c/01@0c
<c<0>3Ph03lo?`0o?cl0@T920080A4A400D0?Shn03Lg=`0g=cL0<S8b03`l?00203Ti>@0503@d=00Z
:RX0:RXZ024Q8@0?3`l00P0G5aL01@0Z:RX0<S8b038b<P0f=SH0>c/k0080=CDe00@0:2PX034a<@0a
<C40@D510P1:BTX01@1>CTh0D51@04E5A@15ADD0=CDe0080<c<c00D0>CTi03hn?P17AdL0AdM7051@
D00204e=C@0504M7A`19BDT0BDU904e=C@1;Bd/00P18B4P01@11@D40=cLg03Lg=`0_;bl0<c<c0080
=SHf00@0>SXj03`l?00l?3`0>3Ph0P0^;Rh01@0b<S80@4100410@010@400?Cdm0080>c/k00D0=CDe
02<S8`0Q8B408B4Q02l_;`0202`/;00502LW9`0V9RH092@T02@T900F5QH00P0T92@01@0X:2P09bLW
02LW9`0U9BD08R8R00804a<C00D03Ph>01/K6`0K6a/07QhN020P800202@T900402LW9`0M7Ad07AdM
02HV9P<0:BTY00@0;2`/038b<P0b<S80<S8b0P0i>CT01@12@T80ATI604A4A014A4@0?Shn0080=cLg
00D0<S8b03Lg=`0h>3P0>3Ph03/k>`0203hn?P0403lo?`0h>3P0>3Ph03`l?0<0?Shn00D0?Cdm03hn
?P0n?Sh0>c/k03Xj>P020451@@0404U9B@1@D500D51@05]KF`80IfMW00<0KFe]075aL@1bLW800P1b
LW8206i^KP0306IVIP3oool0oooo00d0oooo000>0?ooo`80Cdm?00D0T92@09JFUP2FUYH0QHF5055A
D@020?ooo`040:6QX@1GEeL0EeMG09:BTP80XJ6Q00D0Q8B401PH603oool0oooo09jNWP0206=SH`05
09fMW@2=SHd0S8b<08b<S00O7al00P3oool01@1SHf<0IfMW06MWI`2GUiL0W9bL0080Kfm_00D0@T92
0?ooo`3oool05ADE08j>SP0209:BTP0509JFUP1:BTX0BTY:0:VYZ@3oool00P0e=CD0102;Rh/0VIVI
09VIV@2GUiL20492@P030<S8b03/k>`0P8200080P8200P2TY:@01@2SXj<0DU9B0=CDe03De=@0dm?C
0080=cLg00D0b<S808:2PP22PX80UIFE05aLG0020>7Qh@050;:b/P1fMWH0MWIf0;bl_01hN7P00P2I
VIT0101OGel0oooo0?ooo`13@d<207]kN`050<W9b@2EUID0CDe=04e=C@23Ph<00P3oool01@0R8R80
M7Ad0;2`/02`/;00UYJF0080J6QX00D0/;2`0?ooo`0];Bd0;Bd]0::RXP020:6QX@0508B4Q00T92@0
92@T0?ooo`1hN7P00P1EEED01@3GemL0Ph>308>3P`20P8004A4A0080oooo00@08R8R07inOP1nOWh0
`L710P1nOWh01@0k>c/0oooo06UYJ@1YJFT0HV9R0080_;bl00D0UIFE05mOG`32`/80`/;20=OGe`02
05UIF@050::RXP2NWYh0R8R808R8R019BDT00P3oool01@0f=SH0MgMg07MgM`2m_Kd0Shn?0080?Shn
00D0oooo08b<S02<S8`0HV9R09nOW`020:^[Z`0407MgM`0o?cl0?clo0?ooo`8092@T00D0Rh^;0=oO
g`1gMgL0MgMg06EUI@020?ooo`0302LW9`3oool0oooo00P0oooo00<0ATI60492@P12@T800`0j>SX0
100l?3`0>c/k03/k>`0k>c/403`l?080A4A400D0BDU904e=C@1ADE40DE5A05EEE@0205=CD`05051@
D01ADE40DU9B059BDP1@D5000P1>CTh01@1@D500CTi>04i>CP1ADE40FEUI0080GUiN00D0Hf=S06UY
J@1YJFT0JFUY06MWI`0206=SH`0505aLG01FEUH0EUIF059BDP1>CTh00`1<C4`504e=C@80Cdm?0P1>
CTh01@1CDe<0F5QH05QHF01MGEd0HV9R0080IVIV0`1TI6@506=SH`80HF5Q0`1NGUh01@1MGEd0GUiN
065QH@1QHF40IFEU0080IfMW0`1[Jf/01@1XJ6P0IFEU06IVIP1VIVH0I6AT00<0Hf=S0`1VIVH00`1Q
HF40H61P061PH002061PH080Hf=S00@0Jf][06e]K@1]KFd0KVi^0P1/K6`00`1YJFT0Hf=S065QH@02
065QH@80HV9R1@1OGel205eMG@0505iNGP1PH600H61P061PH01OGel00P1NGUh01@1MGEd0G5aL05aL
G01LG5`0FEUI0080F5QH00D0FEUI05MGE`1GEeL0E5AD05EEE@0305MGE`80F5QH00D0G5aL05iNGP1N
GUh0GUiN05]KF`0205UIF@@0F5QH00@0GEeM065QH@1QHF40I6AT0P1VIVH01@1ZJVX0JFUY06UYJ@1S
Hf<0GUiN0080FEUI00@0EUIF04m?C`1?Cdl0Bd];3`3oool000h0oooo0P1?Cdl01@2@T900UYJF09JF
UP25QHD0DE5A0080oooo00@0XJ6Q05MGE`1GEeL0TY:B0P2QXJ401@24Q8@061PH0?ooo`3oool0WYjN
0080Hf=S00D0WIfM08f=S@2<S8`0S8b<01lO7`020?ooo`0506=SH`1WIfL0IfMW09NGU`2LW9`00P1_
Kfl01@12@T80oooo0?ooo`0E5AD0SXj>0080TY:B00D0UYJF04Y:BP1:BTX0ZJVY0?ooo`0203De=@04
08^;R`2IVIT0VIVI09NGU`80@T9200<0b<S80>c/k020P8000P20P8020:BTY0050:>SX`1BDU80e=CD
0=CDe03Cdm<00P0g=cL01@38b<P0PX:208:2PP2EUID0G5aL0080hN7Q00D0/[:b07IfMP1fMWH0_;bl
07QhN00209VIV@0405mOG`3oool0oooo04=3@`80Ng]k00D0bLW909FEU@1=CDd0CDe=08>3P`020?oo
o`05028R8P1dM7@0/;2`0;2`/02FUYH00P1XJ6P01@2`/;00oooo02d];@0];Bd0XZ:R0080XJ6Q00D0
Q8B402@T900T92@0oooo07QhN00205EEE@050=OGe`23Ph<0Ph>30820P00A4A400P3oool0100R8R80
OWin07inOP31`L4207inOP0503/k>`3oool0JFUY06UYJ@1RHV800P2l_;`01@2EUID0GemO0<;2`P32
`/80emOG0080FEUI00D0XZ:R09jNWP28R8P0R8R804U9B@020?ooo`0503Hf=P1gMgL0MgMg0;fm_@2?
Shl00P0n?Sh01@3oool0S8b<08b<S01RHV80WinO0080Zj^[00@0MgMg03lo?`0o?cl0oooo0P0T92@0
1@2;Rh/0gmoO07MgM`1gMgL0IFEU0080oooo00<09bLW0?ooo`3oool0203oool00`16ATH0@T920492
@P0303Xj>P0403`l?00k>c/0>c/k03/k>`@0?3`l0P14A4@01@19BDT0CDe=055AD@1ADE40EEEE0080
De=C00D0D51@055AD@1BDU80DU9B051@D00204i>CP05051@D01>CTh0CTi>055AD@1IFET00P1NGUh0
1@1SHf<0JFUY06UYJ@1YJFT0IfMW0080Hf=S00D0G5aL05IFEP1FEUH0DU9B04i>CP0304a<C0D0CDe=
0P1?Cdl204i>CP0505=CD`1HF5P0F5QH05eMG@1RHV800P1VIVH306ATI0D0Hf=S0P1QHF4305iNGP05
05eMG@1NGUh0HF5Q065QH@1UIFD00P1WIfL306][J`0506QXJ01UIFD0IVIV06IVIP1TI6@00`1SHf<3
06IVIP03065QH@1PH600H61P0080H61P0P1SHf<0101[Jf/0KFe]06e]K@1^KVh206a/K00306UYJ@1S
Hf<0HF5Q0080HF5Q0P1RHV8505mOG`80GEeM00D0GUiN061PH01PH600H61P05mOG`0205iNGP0505eM
G@1LG5`0G5aL05aLG01IFET00P1HF5P01@1IFET0EeMG05MGE`1DE5@0EEEE00<0EeMG0P1HF5P01@1L
G5`0GUiN05iNGP1NGUh0Fe]K0080FEUI101HF5P0101MGEd0HF5Q065QH@1TI6@206IVIP0506YZJP1Y
JFT0JFUY06=SH`1NGUh00P1IFET0101FEUH0Cdm?04m?C`1;Bd/?0?ooo`003@3oool0103kno/0GEeM
05eMG@2<S8`2092@T00507IfMP1YJFT0oooo0?ooo`1eMGD00P1RHV801@2DU9@0Vi^K09^KV`1jNWX0
;bl_0080oooo00D0PX:207YjNP1jNWX0W9bL092@T00209:BTP0401XJ6P3oool0oooo04U9B@80Kfm_
00D0UiNG0:6QX@1ZJVX0JVYZ03/k>`020?ooo`0501HF5P2ATI40TY:B09:BTP2CTi<00P1OGel01@24
Q8@0oooo04=3@`13@d<0RHV90080TY:B00D0VYZJ055AD@1ADE40^;Rh0?Win@0207AdM00508:2PP2N
WYh0WYjN0:FUY@1YJFT00P34a<@01032`/80;2`/02`/;03bl_8207AdM00509>CT`1/K6`0dM7A0=7A
d@2ATI400P1nOWh01@3]kNd0IfMW09>CT`2CTi<0KFe]0080oooo00D0?3`l08N7Q`27QhL0k>c/07If
MP0206IVIP0508R8R03oool0oooo02XZ:P1jNWX00P3<c<`01@1lO7`0QHF508F5Q@2j^[X0h>3P0080
?clo00@0^[Zj0:VYZ@2YZJT0L71`0P16ATH01@3oool0OGem04a<C01<C4`0oooo0080MWIf00D0O7al
03Hf=P3oool0oooo03De=@0207MgM`050>KViP1/K6`0K6a/05EEE@3oool00P1gMgL01@1DE5@0gMgM
0=gMg@2EUID0GUiN0080_kno00<0`L71065QH@1QHF400P2XZ:P20861P@0406MWI`3oool0oooo05AD
E080I6AT00D0g]kN08Z:RP1GEeL0EeMG0?ooo`0208Z:RP0506ATI02YZJT0^KVi0;Vi^@1aLG400P1M
GEd01@3oool0@D510451@@1gMgL0oOgm0080JFUY00@0LG5a0=_Kf`3Kfm/0Hf=S2P3oool0101OGel0
HF5Q065QH@1SHf<206ATI005069RHP1QHF40GEeM05eMG@1IFET00P1GEeL305QHF00505UIF@1GEeL0
De=C05=CD`1@D5000P1>CTh01@1<C4`0CTi>05=CD`1CDe<0EeMG0080FEUI0`1MGEd01@1HF5P0EUIF
05=CD`1CDe<0D51@0080Cdm?0P1BDU8205EEE@0405eMG@1QHF40HF5Q06=SH`<0IFEU00@0H61P05mO
G`1OGel0IfMW0P1YJFT0101/K6`0KVi^07=cL`1cLg<306e]K@0506a/K01[Jf/0IFEU06EUI@1RHV80
0P1QHF40101NGUh0GemO05mOG`1NGUh305eMG@0305aLG01GEeL0EeMG0080E5AD0P1EEED0101FEUH0
FEUI05UIF@1LG5`205eMG@0505]KF`1MGEd0Fe]K05]KF`1GEeL00P1DE5@0101EEED0D51@05=CD`1C
De<505ADE080Cdm?00@0CTi>04m?C`1?Cdl0C4a<0P19BDT01@15ADD0BDU904U9B@19BDT0C4a<0080
DU9B00D0De=C04m?C`18B4P0B4Q80451@@0203Ti>@0503`l?00m?Cd0?Cdm03dm?@0n?Sh00P10@400
1@0l?3`0>3Ph03Ph>00k>c/0?Shn0080@41000D0A4A404U9B@19BDT0C4a<051@D00204];B`0404M7
A`12@T80@T9203Ti>@80;bl_00D0=CDe03Hf=P0e=CD0=CDe03<c<`02038b<P0502TY:@0Q8B409RHV
02HV9P0P82000P0O7al01@0M7Ad07alO01lO7`0I6AT09BDU0080<S8b00@0@41004m?C`1?Cdl0FUYJ
3`3oool000d0oooo00@0b<S806m_K`1_Kfl0SHf=0P2>SXh01@1VIVH0PX:20?ooo`3oool0Cdm?0080
KVi^00D0UYJF09RHV02HV9P0M7Ad04Q8B0020?ooo`0506m_K`2@T900T92@09jNWP2CTi<00P2@T900
100M7Ad0oooo0?ooo`0o?cl207MgM`0509JFUP2LW9`0K6a/06a/K01?Cdl00P3oool01@0V9RH0TY:B
08n?S`2?Shl0TI6A0080KVi^00D0JFUY0?ooo`1JFUX0FUYJ07moO`0209>CT`0509VIV@1WIfL0IfMW
0:JVYP3oool00P1WIfL01@1oOgl0VIVI09VIV@2[Zj/0MgMg0080/k>c00@0/;2`02@T900T92@0oooo
0P1[Jf/01@2=SHd0NWYj0;no_`2o_kl0M7Ad0080Q8B400D0oooo04A4A02ATI40TI6A08N7Q`020>KV
iP0503Hf=P2ATI40TI6A0?ooo`1CDe<00P1lO7`01@2@T900oooo0?ooo`0^;Rh0Q8B40080kno_00D0
EUIF0:FUY@2UYJD0/[:b0<71`@0204U9B@040=;BdP2h^;P0^;Rh05EEE@80HV9R00D0o?cl08>3P`0o
?cl0?clo0?ooo`0206e]K@0507MgM`1HF5P0oooo0?ooo`1EEED00P1WIfL01@3oool0FEUI05UIF@1/
K6`0j^[Z0080P82000D0AdM70?clo03lo?`0UYJF069RHP020;Jf]P050:b/[01/K6`0K6a/0:^[Z`2c
/k<00P1iNGT01021PH40hn?S0>?Sh`1`L70204m?C`050?ooo`1kNg/0K6a/06a/K03Fe]H00P2=SHd0
1@1XJ6P0[jn_0<O7a`37alL0KFe]0080MgMg00D0jNWY065QH@1QHF40HV9R0?ooo`0205YJFP0408F5
Q@2YZJT0ZJVY0:RXZ0X0oooo00@0FEUI05mOG`1OGel0D51@0P1?Cdl01@1GEeL0F5QH05eMG@1MGEd0
JFUY0080KVi^00<0H61P05QHF01HF5P00P1IFET205YJFP05061PH01UIFD0IFEU069RHP1TI6@00P1V
IVH0101WIfL0J6QX06QXJ01YJFT306EUI@04061PH01KFe/0Fe]K05QHF080EEEE00D0Cdm?05EEE@1Q
HF40HF5Q05UIF@02055AD@0504Y:BP10@400<30`030`<00b<S800P0n?Sh01@0i>CT0@T920492@P1<
C4`0GUiN0080HV9R00D0MGEe07YjNP1jNWX0Ng]k075aL@02065QH@0405iNGP1MGEd0GEeM065QH@80
LG5a00D0Rh^;096AT@2;Rh/0Rh^;096AT@0209>CT`0509BDU02OWil0XJ6Q0:6QX@2=SHd00P1_Kfl0
1@1KFe/0ATI604I6AP1=CDd0HF5Q0080L71`00D0KFe]061PH01PH600C4a<03Lg=`02034a<@0503/k
>`18B4P0B4Q804U9B@1;Bd/00P1CDe<0101BDU80HV9R069RHP1gMgL308Z:RP0408N7Q`1jNWX0NWYj
075aL@80Lg=c00D0O7al08V9R@2:RXX0RXZ:09JFUP0209NGU`<0WinO00D0ZZZZ09nOW`2FUYH0UYJF
09:BTP0209^KV`0509jNWP2ZZZX0[:b/0:b/[02VYZH00`2QXJ40102TY:@0[Jf]0:f][@2d];@20:ZZ
ZP050:VYZ@2^[Zh0[Zj^0:n_[`2b/[800P31`L401034a<@0`L710<71`@39bLT30=CDe0040=oOg`3U
iND0iNGU0=OGe`80dM7A00D0e=CD0<o?c`2_[jl0[jn_0:JVYP0208Z:RP0306m_K`3oool0oooo00d0
oooo000=0?ooo`040<S8b01_Kfl0Kfm_08f=S@80SXj>00D0IVIV08:2PP3oool0oooo04m?C`0206i^
KP0509JFUP2HV9P0V9RH07AdM018B4P00P3oool01@1_Kfl0T92@092@T02NWYh0Ti>C0080T92@00@0
7AdM0?ooo`3oool0?clo0P1gMgL01@2FUYH0W9bL06a/K01/K6`0Cdm?0080oooo00D09RHV09:BTP2?
Shl0Shn?096AT@0206i^KP0506UYJ@3oool0FUYJ05YJFP1oOgl00P2CTi<01@2IVIT0IfMW06MWI`2V
YZH0oooo0080IfMW00D0Ogmo09VIV@2IVIT0Zj^[07MgM`020;>c/`040;2`/00T92@092@T0?ooo`80
Jf][00D0SHf=07YjNP2o_kl0_kno07AdM00208B4Q0050?ooo`14A4@0TI6A096AT@27QhL00P3Vi^H0
1@0f=SH0TI6A096AT@3oool0De=C0080O7al00D0T92@0?ooo`3oool0;Rh^08B4Q0020>o_k`0505IF
EP2UYJD0YJFU0;:b/P31`L400P19BDT0103Bd]80^;Rh0;Rh^01EEED2069RHP050?clo023Ph<0?clo
03lo?`3oool00P1]KFd01@1gMgL0F5QH0?ooo`3oool0EEEE0080IfMW00D0oooo05UIF@1IFET0K6a/
0>[ZjP020820P00504M7A`3lo?`0o?cl09JFUP1RHV800P2f][H01@2/[:`0K6a/06a/K02[Zj/0/k>c
0080NGUi00@0PH610>?Sh`3Shn<0L71`0P1?Cdl01@3oool0Ng]k06a/K01/K6`0e]KF0080SHf=00D0
J6QX0:n_[`37alL0alO706e]K@0207MgM`050>WYj@1QHF40HF5Q069RHP3oool00P1JFUX01025QHD0
ZJVY0:VYZ@2XZ:P:0?ooo`0405UIF@1OGel0GemO051@D080Cdm?00D0EeMG05QHF01MGEd0GEeM06UY
J@0206i^KP03061PH01HF5P0F5QH0080FEUI0P1JFUX01@1PH600IFEU06EUI@1RHV80I6AT0080IVIV
00@0IfMW06QXJ01XJ6P0JFUY0`1UIFD0101PH600Fe]K05]KF`1HF5P205EEE@0504m?C`1EEED0HF5Q
065QH@1IFET00P1ADE401@1:BTX0@410030`<00`<300<S8b0080?Shn00D0>CTi0492@P12@T80C4a<
05iNGP02069RHP0507EeM@1jNWX0NWYj07]kN`1aLG400P1QHF40101NGUh0GEeM05eMG@1QHF42075a
L@0508^;R`2ATI40Rh^;08^;R`2ATI400P2CTi<01@2DU9@0WinO0:6QX@2QXJ40SHf=0080Kfm_00D0
Fe]K04I6AP16ATH0CDe=065QH@02071`L00506e]K@1PH600H61P04a<C00g=cL00P0a<C401@0k>c/0
B4Q804Q8B019BDT0Bd];0080De=C00@0DU9B069RHP1RHV80MgMg0`2:RXX01027QhL0NWYj07YjNP1a
LG4207=cL`0507alO029RHT0RXZ:08Z:RP2FUYH00P2GUiL309nOW`050:ZZZP2OWil0UYJF09JFUP2B
TY800P2KVi/01@2NWYh0ZZZZ0:b/[02/[:`0YZJV00<0XJ6Q00@0Y:BT0:f][@2][Jd0];Bd0P2ZZZX0
1@2YZJT0[Zj^0:j^[P2_[jl0/[:b0080`L7100@0a<C40<71`@31`L40bLW90`3De=@0103Ogml0iNGU
0>GUi@3GemL20=7Ad@050=CDe03?cll0[jn_0:n_[`2VYZH00P2:RXX00`1_Kfl0oooo0?ooo`0=0?oo
o`003@3oool00`2RXZ80OWin07inOP03092@T005069RHP2IVIT0oooo0?ooo`16ATH00P1jNWX01@2N
WYh0U9BD09BDU01dM7@0IVIV0080oooo00D0Hf=S09jNWP2NWYh0XJ6Q09FEU@02096AT@0403Xj>P3o
ool0oooo04M7A`80MgMg00D0W9bL09ZJVP1dM7@0M7Ad06QXJ0020?ooo`0503`l?02BTY80Shn?08n?
S`2DU9@00P25QHD01@1FEUH0oooo071`L01`L700P8200080U9BD00D0VIVI07inOP1nOWh0UYJF0?oo
o`0206QXJ00508:2PP2KVi/0Vi^K0::RXP29RHT00P2WYjL0102KVi/0;2`/02`/;03oool206][J`05
08J6QP28R8P0[Jf]0:f][@1OGel00P2>SXh01@3oool0;2`/096AT@2ATI40W9bL0080a<C400D0>3Ph
096AT@2ATI40oooo03Ph>00208j>SP0509fMW@36a/H0a/K603hn?P2ATI400P3no_h01@1;Bd/0][Jf
0;Jf]P2UYJD0[Zj^0080GEeM00@0g=cL0;jn_P2n_[h0A4A40P22PX801@33`l<0Ti>C038b<P0b<S80
oooo0080LG5a00D0KFe]07alO03@d=00d=3@07EeM@0205ADE0050?ooo`17AdL0AdM708:2PP2n_[h0
0P24Q8@01@0k>c/0oooo0?ooo`2OWil0GUiN0080[Zj^00D0Vi^K071`L01`L700/[:b0<;2`P0206i^
KP0408n?S`2c/k<0/k>c08b<S080>CTi00D0oooo07MgM`1lO7`0O7al0:^[Z`0209:BTP0506QXJ02h
^;P0eMGE0=GEe@1SHf<00P2@T9001@2c/k<0RXZ:08Z:RP0o?cl0oooo0080DU9B00@0TY:B06EUI@1U
IFD0k>c/2P3oool0101YJFT0IVIV06IVIP1gMgL207IfMP0506][J`1ZJVX0IFEU06EUI@1GEeL00P1C
De<01@1RHV80J6QX06QXJ01UIFD0IVIV0080J6QX00D0Hf=S065QH@1QHF40JFUY06EUI@0205iNGP04
05]KF`1HF5P0F5QH05ADE080F5QH00D0Fe]K061PH01XJ6P0J6QX06a/K002075aL@0507MgM`1bLW80
I6AT06ATI01UIFD00P1[Jf/01@1dM7@0Ogmo08j>SP2>SXh0T92@0080Ogmo00D0N7Qh06YZJP1ZJVX0
GUiN04i>CP0204a<C0050410@00j>SX0>SXj03Hf=P0m?Cd00P1<C4`0101@D500DU9B059BDP1ADE42
04=3@`0502`/;00Z:RX0<C4a034a<@0];Bd00P0^;Rh01@0_;bl08b<S01hN7P0N7Qh0;bl_0080BDU9
00D0G5aL07=cL`1cLg<0LG5a05iNGP02051@D00505EEE@1RHV80HV9R07MgM`2>SXh00P2CTi<01@28
R8P0NGUi07UiN@1dM7@0Lg=c00<0KVi^0P1KFe/01@19BDT0>SXj03Xj>P11@D40ADE50080DU9B00D0
F5QH04i>CP1>CTh0A4A403/k>`020492@P0303hn?P17AdL0AdM700<0?Cdm00D0<S8b03dm?@16ATH0
ATI604i>CP0204U9B@0504=3@`0e=CD0=3@d03@d=00k>c/00P0o?cl01@11@D40>c/k038b<P0b<S80
;2`/0080>3Ph00D0?3`l03lo?`0o?cl0=cLg030`<00202<S8`0502@T900[:b/0:b/[02/[:`0V9RH0
0P0L71`0100A4A402`/;00/;2`0K6a/201lO7`0502<S8`0P8200=3@d03@d=00a<C400P13@d<00`1G
EeL0oooo0?ooo`0=0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`003@3oool0102c/k<0Lg=c07=cL`2RXZ8208:2PP05
0:>SX`1QHF40^k^k0;^k^`1cLg<00P28R8P01@3:b/X0EEEE05EEE@2n_[h0Hf=S0080XZ:R00D0U9BD
09bLW02LW9`0Rh^;06a/K0020:VYZ@0409VIV@1jNWX0NWYj0<71`@80HF5Q00D0]KFe079bLP1/K6`0
K6a/0>3Ph00204U9B@050<;2`P1mOGd0TI6A096AT@34a<@00P0c<c<01@2RXZ80UIFE0;bl_02l_;`0
U9BD00<0Ng]k0P2OWil01@20P800WYjN08N7Q`27QhL0UIFE0080Ph>300D0U9BD09bLW02ATI40TI6A
0:NWY`0208N7Q`05055AD@3IfMT0fMWI071`L02MWId00P2FUYH01@1JFUX0f][J0=[JfP1UIFD0Shn?
0080[:b/00@0>CTi0>c/k03/k>`0HV9R0P2h^;P01@1gMgL0QhN709bLW02LW9`0/[:b0080MGEe00D0
JFUY0;>c/`22PX80PX:20:f][@0209VIV@0506a/K02@T900MGEe07EeM@2[Zj/00P3GemL01@0];Bd0
UYJF09JFUP2i^KT0Ogmo0080Shn?00D0];Bd07moO`1oOgl0LG5a07UiN@020<S8b00408f=S@1bLW80
LW9b0:>SX`80TI6A00D0[Zj^03lo?`2KVi/0Vi^K0;2`/00208^;R`050;6a/@25QHD0L71`071`L02N
WYh00P2HV9P01@2;Rh/0RHV90::RXP2RXZ80Jf][0080[:b/00<0PH610:b/[02/[:`00P25QHD20::R
XP0507AdM02VYZH0YZJV08j>SP1cLg<00P2e]KD01024Q8@0JVYZ06YZJP2MWId20:f][@0308Z:RP2G
UiL0QhN70080QhN70P2DU9@00`23Ph<0oooo0?ooo`080?ooo`040;Vi^@2XZ:P0Z:RX08J6QP80MGEe
00D0LG5a061PH01HF5P0F5QH06IVIP0206m_K`0508>3P`2BTY80TY:B0:FUY@2KVi/00P24Q8@01@1c
Lg<0MGEe07EeM@1eMGD0QhN70080Vi^K0`2UYJD01@2WYjL0ZJVY0:VYZ@2^[Zh0Zj^[0080Xj>S00D0
Ti>C07inOP1nOWh0Ng]k07YjNP0207EeM@0507emO@2?Shl0Shn?08^;R`24Q8@00P2;Rh/0102:RXX0
QXJ608J6QP29RHT209:BTP05096AT@2HV9P0Y:BT0:BTY02/[:`00P2][Jd01@2h^;P0_kno0;Rh^02h
^;P0Zj^[0080/K6a00D0WinO096AT@2ATI40Ti>C0:FUY@0209NGU`050:>SX`2/[:`0[:b/0:f][@2P
X:000P2TY:@0102QXJ40Ti>C09>CT`27QhL308B4Q00407MgM`1fMWH0MWIf07alO080LG5a00D0JFUY
07IfMP25QHD0QHF508J6QP0209NGU`0509fMW@2JVYX0Ti>C09>CT`2BTY800P2ATI401@2FUYH0Ti>C
09>CT`2DU9@0QHF50080PX:200D0OGem07moO`1oOgl0O7al08Z:RP0208F5Q@0407emO@1oOgl0Ogmo
07inOP80Ogmo00D0Ph>308b<S02<S8`0S8b<09BDU0020:RXZ0050:^[Z`2b/[80_Kfm0;fm_@3;bl/0
0P33`l<01@2`/;00UiNG08^;R`2;Rh/0OWin0080KFe]00D0NWYj07moO`1oOgl0LW9b06a/K00207Mg
M`0508F5Q@2?Shl0Shn?0:JVYP2SXj<00P2CTi<01023Ph<0RXZ:08Z:RP29RHT209RHV0050:BTY02S
Xj<0Z:RX0:RXZ02^[Zh00P2`/;000`2_[jl0oooo0?ooo`0=0?ooo`003@3oool0102f][H0LW9b079b
LP2SXj<20820P0050:RXZ01IFET0`l?30<?3``1bLW800P27QhL01@38b<P0F5QH05QHF02m_Kd0GemO
0080ZZZZ00D0Shn?09nOW`2OWil0Rh^;06][J`020:>SX`0409bLW01nOWh0OWin0;bl_080IVIV00D0
/k>c079bLP1[Jf/0Jf][0>3Ph00204e=C@050;jn_P1lO7`0UIFE09FEU@2n_[h00P0g=cL01@2RXZ80
U9BD0;fm_@2m_Kd0TY:B0080NWYj00D0PH6109RHV02HV9P0P82009nOW`0208V9R@0509JFUP21PH40
PH6109FEU@2GUiL00P2BTY80102WYjL0RHV908V9R@1BDU820=KFeP0506e]K@2YZJT0RXZ:08Z:RP1Q
HF400P3Lg=`01@1OGel0U9BD0:ZZZP2ZZZX0>c/k0080jNWY00D0IFEU0;Ng]`2g]kL0Ng]k0820P002
0::RXP050;:b/P1hN7P0N7Qh069RHP2f][H00P24Q8@01@2RXZ80YZJV0:JVYP1XJ6P0TI6A0080KVi^
00@0];Bd0<W9b@39bLT0=SHf0P2EUID01@31`L40NWYj08b<S02<S8`0/[:b0080QHF500D0L71`07Mg
M`35aLD0aLG5096AT@0206a/K0050:b/[02:RXX0RXZ:0;2`/012@T800P2GUiL01@2b/[80Rh^;08^;
R`2][Jd0S8b<0080Lg=c00<0UYJF09ZJVP2JVYX00P2:RXX20:6QX@0406YZJP2/[:`0[:b/08F5Q@80
YZJV00D0RHV908F5Q@2TY:@0Y:BT06YZJP020;6a/@80PX:20P2][Jd01026QXH0JVYZ06YZJP2LW9`2
0:f][@0508^;R`2DU9@0SHf=08f=S@23Ph<00P2HV9P00`1oOgl0oooo0?ooo`080?ooo`0407UiN@2?
Shl0Shn?0;Rh^080clo?00D0g=cL0>CTi03YjNT0jNWY0=WIf@020<K6aP050:JVYP2LW9`0W9bL092@
T02DU9@00P2[Zj/30:NWY`050:>SX`2ATI40NWYj07YjNP2;Rh/00`2<S8`208Z:RP0508V9R@21PH40
Q8B408B4Q02=SHd00P2FUYH209:BTP80W9bL00D0UiNG08V9R@29RHT0UYJF0:FUY@0209nOW`040:ZZ
ZP2n_[h0_[jn0;^k^`80ZZZZ00D0YjNW09bLW01oOgl0Ogmo06][J`02065QH@05051@D00n?Sh0ADE5
04E5A@1HF5P00P1NGUh01@1`L700Ph>308>3P`2=SHd0QXJ60080TI6A00D0S8b<08F5Q@25QHD0MgMg
07UiN@0207inOP0408N7Q`2HV9P0V9RH0:^[Z`80[Zj^0P2VYZH20:b/[0030:JVYP2^[Zh0[Zj^0080
^[Zj0P2TY:@0102MWId0TY:B09:BTP29RHT308b<S00409BDU02LW9`0W9bL09FEU@80RHV900D0QHF5
08V9R@2:RXX0RXZ:08j>SP0208^;R`0509VIV@2=SHd0NWYj07YjNP1mOGd00P1jNWX01@1XJ6P0JFUY
06UYJ@1cLg<0M7Ad0080P82000D0RXZ:0820P020P800PH6108>3P`0208j>SP0509^KV`2UYJD0YJFU
0;Bd]033`l<00P2c/k<0102OWil0YjNW0:NWY`2DU9@208b<S00509bLW02CTi<0OGem07emO@1KFe/0
0P0e=CD01@0000003Ph>02`/;00/;2`0EEEE0080GUiN00D0PH61096AT@2ATI40R8R808j>SP0209JF
UP04096AT@21PH40PH6108F5Q@l0oooo000=0?ooo`040;Jf]P1bLW80LW9b0:>SX`80P82000D0Z:RX
05UIF@33`l<0`l?3079bLP0208N7Q`050<S8b01HF5P0F5QH0;fm_@1OGel00P2ZZZX01@2?Shl0WinO
09nOW`2;Rh/0Jf][0080Xj>S00@0W9bL07inOP1nOWh0_;bl0P1VIVH01@2c/k<0LW9b06][J`1[Jf/0
h>3P0080CDe=00D0_[jn07alO02EUID0UIFE0;jn_P0203Lg=`050::RXP2DU9@0_Kfm0;fm_@2BTY80
0P1jNWX01@21PH40V9RH09RHV020P800WinO0080RHV900D0UYJF0861P@21PH40UIFE09NGU`0209:B
TP040:NWY`29RHT0RHV9059BDP80e]KF00D0KFe]0:VYZ@2:RXX0RXZ:065QH@020=cLg00505mOG`2D
U9@0ZZZZ0:ZZZP0k>c/00P3YjNT01@1UIFD0]kNg0;Ng]`1kNg/0P8200080XZ:R00D0/[:b07QhN01h
N7P0HV9R0;Jf]P0208B4Q0050::RXP2VYZH0YZJV06QXJ02ATI400P1^KVh0102d];@0bLW90<W9b@0f
=SH209FEU@050<71`@1jNWX0S8b<08b<S02b/[800P25QHD01@1`L700MgMg0<G5a@35aLD0TI6A0080
K6a/00D0[:b/08Z:RP2:RXX0/;2`0492@P0209NGU`050;:b/P2;Rh/0Rh^;0:f][@2<S8`00P1cLg<0
0`2FUYH0VYZJ09ZJVP0208Z:RP80XJ6Q00@0JVYZ0:b/[02/[:`0QHF50P2VYZH01@29RHT0QHF50:BT
Y02TY:@0JVYZ0080/K6a0P22PX820:f][@0408J6QP1ZJVX0JVYZ09bLW080[Jf]00D0Rh^;09BDU02=
SHd0SHf=08>3P`0209RHV00307moO`3oool0oooo00P0oooo00@0NGUi08n?S`2?Shl0^;Rh0P3?cll0
1@3Lg=`0i>CT0>WYj@3YjNT0fMWI0080a/K600D0YZJV09bLW02LW9`0T92@09BDU0020:^[Z`<0YjNW
00D0Xj>S096AT@1jNWX0NWYj08^;R`0308b<S080RXZ:00D0RHV90861P@24Q8@0Q8B408f=S@0209JF
UP80TY:B0P2LW9`01@2GUiL0RHV908V9R@2FUYH0YJFU0080WinO00@0ZZZZ0;jn_P2n_[h0^k^k0P2Z
ZZX01@2WYjL0W9bL07moO`1oOgl0Jf][0080HF5Q00D0D51@03hn?P15ADD0ADE505QHF00205iNGP05
071`L023Ph<0Ph>308f=S@26QXH00P2ATI401@2<S8`0QHF508F5Q@1gMgL0NGUi0080OWin00@0QhN7
09RHV02HV9P0Zj^[0P2^[Zh20:JVYP80[:b/00<0YZJV0:j^[P2^[Zh00P2j^[X20:BTY00409fMW@2B
TY80TY:B08V9R@<0S8b<00@0U9BD09bLW02LW9`0UIFE0P29RHT01@25QHD0RHV908Z:RP2:RXX0SXj>
0080Rh^;00D0VIVI08f=S@1jNWX0NWYj07emO@0207YjNP0506QXJ01YJFT0JFUY07=cL`1dM7@00P20
P8001@2:RXX0P8200820P021PH40Ph>30080SXj>00D0Vi^K0:FUY@2UYJD0];Bd0<?3``020;>c/`04
09nOW`2WYjL0YjNW09BDU080S8b<00D0W9bL09>CT`1mOGd0OGem05]KF`0203De=@050000000>3Ph0
;2`/02`/;01EEED00P1NGUh01@21PH40TI6A096AT@28R8P0SXj>0080UYJF00@0TI6A0861P@21PH40
QHF53`3oool000d0oooo00@0];Bd071`L01`L700YjNW0P1nOWh01@2/[:`0E5AD0<O7a`37alL0Lg=c
0080QHF500D0bLW905YJFP1JFUX0^KVi05]KF`020;Jf]P0508F5Q@2TY:@0Y:BT08b<S01/K6`00P2N
WYh0102LW9`0PH610861P@2l_;`206IVIP050;>c/`1cLg<0IfMW06MWI`3QhN400P1?Cdl01@2n_[h0
NGUi09VIV@2IVIT0^k^k0080=SHf00D0Xj>S09BDU02n_[h0_[jn096AT@0207YjNP0508B4Q02HV9P0
V9RH07moO`2OWil00P2:RXX01@2HV9P0OWin07inOP2GUiL0UIFE0080Ti>C00@0YjNW08N7Q`27QhL0
EUIF0P3Hf=P01@1SHf<0]KFe08B4Q024Q8@0HF5Q0080fm_K00D0H61P09FEU@2XZ:P0Z:RX03dm?@02
0>OWi`0506MWI`2c/k<0/k>c07moO`20P8000P2PX:001@2b/[80O7al07alO01OGel0]KFe0080RXZ:
00D0VYZJ0:VYZ@2YZJT0IfMW09FEU@0206UYJ@040;Vi^@2n_[h0_[jn0410@080Ti>C00D0aLG507Ee
M@2=SHd0SHf=0:n_[`0208b<S00506UYJ@1hN7P0cLg=0<g=c@26QXH00P1ZJVX01@2g]kL0QXJ608J6
QP2_[jl0A4A40080UYJF00D0/[:b08j>SP2>SXh0YZJV09BDU00207=cL`0509:BTP2MWId0WIfM08R8
R027QhL00P2RXZ80101[Jf/0[jn_0:n_[`24Q8@20::RXP0508b<S025QHD0YjNW0:NWY`1UIFD00P2i
^KT01@1iNGT0RXZ:0:ZZZP2ZZZX0QXJ60080JVYZ00D0VIVI0:j^[P2^[Zh0SHf=09>CT`0208N7Q`04
08^;R`2GUiL0UiNG07emO@X0oooo00@0bl_;0<O7a`37alL0Zj^[0P2KVi/01@2=SHd0Rh^;08B4Q024
Q8@0Ti>C0080WYjN00D0^k^k0;no_`2o_kl0alO70<W9b@020<G5a@050;no_`2d];@0];Bd0;:b/P2h
^;P00P31`L40102d];@0[Jf]0:f][@2QXJ4209^KV`0509FEU@2CTi<0UiNG09NGU`2IVIT00P2FUYH0
1@2HV9P0YZJV0:NWY`2WYjL0YZJV0080Zj^[00D0XZ:R09NGU`2OWil0WinO0:>SX`0209RHV00509^K
V`2OWil0WinO09VIV@2GUiL00P2[Zj/01@2k^k/0aLG50<G5a@39bLT0eMGE0080b<S800@0^;Rh0:VY
Z@2YZJT0Y:BT0`2PX:00102YZJT0[Zj^0:j^[P2c/k<20;Fe]@050<30`02h^;P0/;2`0;2`/02OWil0
0P2@T9001@25QHD0T92@092@T02RXZ80YjNW0080Xj>S00D0][Jf0:VYZ@2YZJT0T92@09VIV@020:6Q
X@0509>CT`2ATI40TI6A09jNWP29RHT00`2DU9@209JFUP0509jNWP2d];@0];Bd0;Fe]@2m_Kd00P2h
^;P01@2[Zj/0ZZZZ0:ZZZP2FUYH0TY:B0080YZJV0`2h^;P01@37alL0`/;20<;2`P2h^;P0YJFU0080
WIfM00D0VIVI09JFUP2FUYH0Ti>C08n?S`0208R8R00507QhN022PX80PX:208^;R`2EUID00P2XZ:P0
0`36a/H0aLG50<G5a@030;fm_@040:FUY@2f][H0d=3@0=3@d0L0oooo00@0oOgm0>GUi@3UiND0/K6a
0P2BTY801@2FUYH0SXj>096AT@2ATI40Xj>S0080]KFe00<0];Bd0?ooo`3oool03@3oool000d0oooo
00@0]KFe06m_K`1_Kfl0Z:RX0P21PH401@2][Jd0BTY:0<o?c`3?cll0KFe]0080RHV900D0b/[:05MG
E`1GEeL0_;bl05MGE`020;fm_@0508B4Q02PX:00X:2P08^;R`1fMWH00P2DU9@0102MWId0Ph>308>3
P`2i^KT206][J`050;6a/@1cLg<0IFEU06EUI@3QhN400P1CDe<01@2m_Kd0MGEe09bLW02LW9`0^k^k
0080=cLg00D0XJ6Q09BDU035aLD0aLG508j>SP0207QhN00508B4Q02HV9P0V9RH07emO@2NWYh00P2?
Shl01@2CTi<0OGem07emO@2KVi/0TI6A0080V9RH00@0Y:BT08N7Q`27QhL0F5QH0P3EeMD01@1WIfL0
/k>c08B4Q024Q8@0GemO0080f][J00D0I6AT09:BTP2WYjL0YjNW0451@@020>KViP0506MWI`2a/K40
/K6a0820P01mOGd00P2SXj<01@2_[jl0Ph>308>3P`1GEeL0]kNg0080S8b<00D0V9RH0:NWY`2WYjL0
JFUY09ZJVP0206=SH`040;jn_P2d];@0];Bd04Q8B080Ti>C00D0a<C4075aL@2ATI40TI6A0:f][@02
08n?S`0506ATI01jNWX0c/k>0<k>cP25QHD00P1VIVH01@30`<00P8200820P02^[Zh0AdM70080UIFE
00D0/;2`09:BTP2BTY80WIfM09^KV`0207UiN@0508Z:RP2OWil0WinO08Z:RP21PH400P2YZJT0101W
IfL0[Jf]0:f][@26QXH20:6QX@0508V9R@2<S8`0YjNW0:NWY`1KFe/00P35aLD01@1YJFT0VIVI0:FU
Y@2UYJD0RXZ:0080JFUY00D0UIFE0:j^[P2^[Zh0TI6A09BDU00208B4Q00408b<S02FUYH0UYJF07in
OPX0oooo00@0KFe]06=SH`1SHf<0NWYj0P27QhL01@2EUID0VIVI0::RXP2RXZ80T92@0080QXJ600D0
M7Ad06][J`1[Jf/0EUIF05MGE`0205IFEP0506YZJP1jNWX0NWYj09BDU02CTi<00P2JVYX0102DU9@0
V9RH09RHV02OWil20:b/[0050:JVYP2/[:`0Y:BT0:BTY02HV9P00P2?Shl01@2DU9@0QhN707UiN@1i
NGT0N7Qh0080NGUi0P1fMWH20820P00407YjNP1mOGd0OGem07]kN`80P82000D0R8R809NGU`2ATI40
TI6A08^;R`0208J6QP0508Z:RP26QXH0V9RH09RHV02VYZH00P2d];@01@2OWil0Xj>S0:>SX`2KVi/0
TY:B0080Ph>300D0Shn?08R8R028R8P0Ogmo0820P00208^;R`04096AT@2EUID0UIFE0:6QX@80TI6A
00D0Ogmo07]kN`1jNWX0NWYj05YJFP0206IVIP05071`L01ZJVX0Kfm_06m_K`2=SHd00P2SXj<01@2d
];@0aLG50<C4a034a<@0_;bl0080ZZZZ00D0WIfM08^;R`2;Rh/0P8200861P@0208>3P`0509BDU02G
UiL0UiNG0;Bd]02h^;P00P30`<00102d];@0`/;20<;2`P2g]kL20;fm_@050;Zj^P31`L40_[jn0;jn
_P2i^KT00P2l_;`00`2e]KD0/;2`0:FUY@020:FUY@80UiNG00<0RXZ:0820P01gMgL00P1gMgL207If
MP0509bLW02`/;00/;2`0<S8b02o_kl00P2d];@01@1nOWh0K6a/06a/K01<C4`0@D510080BDU900@0
GUiN06i^KP1^KVh0Q8B40P2EUID01@2ATI40UYJF08^;R`2;Rh/0P8200080Ng]k00<0MgMg0?ooo`3o
ool03@3oool000d0oooo00@0]KFe06m_K`1_Kfl0Z:RX0P21PH401@2][Jd0BTY:0<o?c`3?cll0KFe]
0080RHV900D0b/[:05MGE`1GEeL0_;bl05MGE`020;fm_@0508B4Q02PX:00X:2P08^;R`1fMWH00P2D
U9@0102MWId0Ph>308>3P`2i^KT206][J`050;6a/@1cLg<0IFEU06EUI@3QhN400P1CDe<01@2m_Kd0
MGEe09bLW02LW9`0^k^k0080=cLg00D0XJ6Q09BDU035aLD0aLG508j>SP0207QhN00508B4Q02HV9P0
V9RH07emO@2NWYh00P2?Shl01@2CTi<0OGem07emO@2KVi/0TI6A0080V9RH00@0Y:BT08N7Q`27QhL0
F5QH0P3EeMD01@1WIfL0/k>c08B4Q024Q8@0GemO0080f][J00D0I6AT09:BTP2WYjL0YjNW0451@@02
0>KViP0506MWI`2a/K40/K6a0820P01mOGd00P2SXj<01@2_[jl0Ph>308>3P`1GEeL0]kNg0080S8b<
00D0V9RH0:NWY`2WYjL0JFUY09ZJVP0206=SH`040;jn_P2d];@0];Bd04Q8B080Ti>C00D0a<C4075a
L@2ATI40TI6A0:f][@0208n?S`0506ATI01jNWX0c/k>0<k>cP25QHD00P1VIVH01@30`<00P8200820
P02^[Zh0AdM70080UIFE00D0/;2`09:BTP2BTY80WIfM09^KV`0207UiN@0508Z:RP2OWil0WinO08Z:
RP21PH400P2YZJT0101WIfL0[Jf]0:f][@26QXH20:6QX@0508V9R@2<S8`0YjNW0:NWY`1KFe/00P35
aLD01@1YJFT0VIVI0:FUY@2UYJD0RXZ:0080JFUY00D0UIFE0:j^[P2^[Zh0TI6A09BDU00208B4Q004
08b<S02FUYH0UYJF07inOPX0oooo00@0KFe]06=SH`1SHf<0NWYj0P27QhL01@2EUID0VIVI0::RXP2R
XZ80T92@0080QXJ600D0M7Ad06][J`1[Jf/0EUIF05MGE`0205IFEP0506YZJP1jNWX0NWYj09BDU02C
Ti<00P2JVYX0102DU9@0V9RH09RHV02OWil20:b/[0050:JVYP2/[:`0Y:BT0:BTY02HV9P00P2?Shl0
1@2DU9@0QhN707UiN@1iNGT0N7Qh0080NGUi0P1fMWH20820P00407YjNP1mOGd0OGem07]kN`80P820
00D0R8R809NGU`2ATI40TI6A08^;R`0208J6QP0508Z:RP26QXH0V9RH09RHV02VYZH00P2d];@01@2O
Wil0Xj>S0:>SX`2KVi/0TY:B0080Ph>300D0Shn?08R8R028R8P0Ogmo0820P00208^;R`04096AT@2E
UID0UIFE0:6QX@80TI6A00D0Ogmo07]kN`1jNWX0NWYj05YJFP0206IVIP05071`L01ZJVX0Kfm_06m_
K`2=SHd00P2SXj<01@2d];@0aLG50<C4a034a<@0_;bl0080ZZZZ00D0WIfM08^;R`2;Rh/0P8200861
P@0208>3P`0509BDU02GUiL0UiNG0;Bd]02h^;P00P30`<00102d];@0`/;20<;2`P2g]kL20;fm_@05
0;Zj^P31`L40_[jn0;jn_P2i^KT00P2l_;`00`2e]KD0/;2`0:FUY@020:FUY@80UiNG00<0RXZ:0820
P01gMgL00P1gMgL207IfMP0509bLW02`/;00/;2`0<S8b02o_kl00P2d];@01@1nOWh0K6a/06a/K01<
C4`0@D510080BDU900@0GUiN06i^KP1^KVh0Q8B40P2EUID01@2ATI40UYJF08^;R`2;Rh/0P8200080
Ng]k00<0MgMg0?ooo`3oool03@3oool000d0oooo00@0];Bd06a/K01/K6`0[:b/0P20P8001@2/[:`0
B4Q80<o?c`3?cll0LW9b0080QHF500D0bl_;05EEE@1EEED0`<3004m?C`020<71`@0508J6QP2KVi/0
Vi^K08^;R`1eMGD00P2DU9@0102KVi/0RHV908V9R@2`/;0207=cL`050:n_[`1eMGD0HF5Q065QH@3P
h>000P1FEUH01@2l_;`0M7Ad09nOW`2OWil0^[Zj0080=3@d00D0Xj>S09FEU@35aLD0aLG508n?S`02
07IfMP050861P@2HV9P0V9RH0820P02LW9`00P2CTi<01@2=SHd0Ph>308>3P`2KVi/0Shn?0080VYZJ
00@0X:2P08N7Q`27QhL0FEUI0P3De=@01@1[Jf/0/K6a08B4Q024Q8@0GUiN0080fMWI00D0JFUY08b<
S02WYjL0YjNW04=3@`020>WYj@0506EUI@2a/K40/K6a08:2PP1lO7`00P2SXj<01@2/[:`0RHV908V9
R@1GEeL0/[:b0080SXj>00D0Vi^K0:>SX`2SXj<0Kfm_09FEU@0206IVIP040;^k^`2c/k<0/k>c04e=
C@80TY:B00D0aLG506e]K@2DU9@0U9BD0:^[Z`0208n?S`0506QXJ01iNGT0bl_;0<_;b`28R8P00P1U
IFD01@32`/80Ogmo07moO`2^[Zh0B4Q80080UIFE00D0[Jf]09NGU`2GUiL0UYJF0:2PX00207alO005
08N7Q`2PX:00X:2P08R8R022PX800P2ZZZX0101VIVH0Zj^[0:^[Z`2;Rh/209nOW`0508Z:RP2<S8`0
YjNW0:NWY`1IFET00P3:b/X01@1MGEd0Xj>S0::RXP2RXZ80QhN70080K6a/00D0UIFE0:j^[P2^[Zh0
TI6A09NGU`020861P@0408N7Q`2NWYh0WYjN07YjNPX0oooo00@0VYZJ09bLW02LW9`0QhN70P1lO7`0
1@1[Jf/0J6QX05eMG@1MGEd0IVIV0080LW9b00D0O7al08B4Q024Q8@0VYZJ09FEU@0208^;R`0508R8
R023Ph<0Ph>307AdM01nOWh00P1jNWX01020P800Ph>308>3P`1nOWh207MgM`0508F5Q@28R8P0T92@
092@T02XZ:P00P2k^k/01@2e]KD0^;Rh0<;2`P32`/80][Jf0080YjNW00D0X:2P09>CT`1jNWX0NWYj
06YZJP0206ATI005079bLP24Q8@0Q8B408b<S02GUiL00P2OWil01@2IVIT0U9BD09BDU02>SXh0Shn?
0080PX:200@0N7Qh07AdM01dM7@0Rh^;0P1lO7`01@2<S8`0UIFE09VIV@2IVIT0RHV90080TY:B00<0
S8b<08n?S`24Q8@00P24Q8@208N7Q`0507YjNP2CTi<0Ti>C0:FUY@2][Jd00P2WYjL01@2o_kl0Zj^[
0:^[Z`2^[Zh0];Bd0080]kNg00D0Xj>S08R8R028R8P0Kfm_05UIF@0205EEE@0406][J`2:RXX0RXZ:
09:BTP80VYZJ00D0XJ6Q09:BTP29RHT0RHV907IfMP0206][J`0507AdM01mOGd0MWIf07IfMP1oOgl0
0P26QXH01@23Ph<0NWYj07YjNP1oOgl0QHF50080QXJ600D0OGem07YjNP1jNWX0NWYj07moO`0208:2
PP<0QXJ600D0S8b<08f=S@2KVi/0Vi^K08Z:RP0208b<S00506e]K@1DE5@0E5AD03De=@0i>CT00P0b
<S801@1DE5@0J6QX06QXJ021PH40Ti>C0080Xj>S00@0Y:BT0:JVYP2VYZH0YZJV0P2WYjL01@2IVIT0
XZ:R0:>SX`2SXj<0YjNW0080XZ:R00<0[Zj^0?ooo`3oool03@3oool000d0oooo00@0][Jf06MWI`1W
IfL0]KFe0P1oOgl01@2][Jd0A4A40<c<c03<c<`0MWIf0080QHF500D0c<c<05=CD`1CDe<0`/;204];
B`020<C4a00508f=S@2CTi<0Ti>C092@T01cLg<00P2DU9@0102HV9P0Shn?08n?S`2ZZZX207YjNP05
0:^[Z`1fMWH0GEeM05eMG@3Ti>@00P1DE5@01@2o_kl0MGEe09^KV`2KVi/0^KVi0080<S8b00D0YjNW
09BDU033`l<0`l?308n?S`0207UiN@050820P02JVYX0VYZJ07moO`2LW9`00P2CTi<01@2:RXX0QhN7
08N7Q`2GUiL0TY:B0080WIfM00@0VYZJ08R8R028R8P0G5aL0P3AdM401@1]KFd0/K6a08F5Q@25QHD0
Fe]K0080f=SH00D0L71`08J6QP2YZJT0ZJVY0410@0020>k^kP0506ATI02_[jl0[jn_08:2PP1jNWX0
0P2TY:@01@2_[jl0QXJ608J6QP1GEeL0[jn_0080TY:B00D0V9RH0:BTY02TY:@0LG5a09FEU@0206QX
J0040;Fe]@2_[jl0[jn_05MGE`80TI6A00D0_[jn06i^KP2HV9P0V9RH0:ZZZP02096AT@0506MWI`1e
MGD0dM7A0=7Ad@23Ph<00P1VIVH01@2n_[h0QhN708N7Q`2][Jd0@d=30080UiNG00D0Zj^[09RHV02H
V9P0Ti>C0::RXP0207]kN`0508^;R`2KVi/0Vi^K092@T01kNg/00P2_[jl0101TI6@0Zj^[0:^[Z`2>
SXh209ZJVP0508f=S@25QHD0[:b/0:b/[01IFET00P3>c/h01@1ADE40/k>c09NGU`2GUiL0QhN70080
Lg=c00D0T92@0;2`/02`/;00T92@09NGU`020861P@0408V9R@2KVi/0Vi^K07YjNPX0oooo00@0Q8B4
09FEU@2EUID0[jn_0P2o_kl01@3Jf]X0fMWI0=GEe@3EeMD0clo?0080_;bl00D0[Jf]0;Jf]P2f][H0
[jn_0;Vi^@020<71`@050;2`/02/[:`0[:b/0:VYZ@2IVIT00P2NWYh0102KVi/0UiNG09NGU`2SXj<2
09nOW`0509ZJVP2KVi/0UIFE09FEU@1mOGd00P1eMGD01@1fMWH0NGUi07YjNP1jNWX0Shn?0080Y:BT
00@0_Kfm0=kNgP3hn?P0n?Sh0`3oool01@3]kNd0aLG50<G5a@2[Zj/0RHV90080NGUi00D0P82008:2
PP22PX80QhN7096AT@020:>SX`040:6QX@2MWId0WIfM0:>SX`80YJFU00@0UIFE09JFUP2MWId0WIfM
0`2FUYH209fMW@<0YjNW0P2/[:`01@2d];@0WYjN09jNWP2GUiL0S8b<0080TI6A00D0QhN709fMW@2M
WId0UYJF09BDU00208^;R`0509FEU@2RXZ80XZ:R0:f][@2n_[h00P2m_Kd0102VYZH0T92@092@T02>
SXh20820P00507inOP29RHT0TI6A096AT@2OWil00P2k^k/01@2=SHd0Ph>307moO`1oOgl0KVi^0080
EEEE00D0MGEe07inOP1nOWh0OWin08N7Q`0208j>SP0509VIV@2LW9`0W9bL09nOW`2IVIT00P2<S8`0
1@24Q8@0PH610861P@1jNWX0NGUi0080MgMg00@0P82008Z:RP2:RXX0UIFE0P2WYjL01@3AdM40hN7Q
0??cl`3clo<0kNg]0080gmoO00<0a<C40;2`/02?Shl00P2?Shl208Z:RP0508V9R@2:RXX0RXZ:0;6a
/@2YZJT00P2VYZH0102GUiL0Ti>C09>CT`1eMGD?0?ooo`003@3oool0102e]KD0Hf=S06=SH`2j^[X2
07alO0050:ZZZP1ADE40`<300<30`01kNg/00P25QHD01@3<c<`0DU9B059BDP34a<@0AdM70080a/K6
00D0Ti>C08R8R028R8P0U9BD07=cL`0209BDU00409VIV@2ATI40TI6A0:JVYP80PX:200D0Y:BT07Ui
N@1LG5`0G5aL0>GUi@0205=CD`050;jn_P1hN7P0UYJF09JFUP2m_Kd00P0c<c<01@2TY:@0UIFE0<71
`@31`L40T92@0080NGUi00D0OWin09fMW@2MWId0Ogmo09bLW002096AT@0508V9R@2<S8`0S8b<096A
T@2GUiL00P2KVi/0102IVIT0RXZ:08Z:RP1JFUX20=3@d005079bLP2WYjL0Shn?08n?S`1FEUH00P3F
e]H01@1bLW80QXJ60:ZZZP2ZZZX0?3`l0080lO7a00D0IVIV0:j^[P2^[Zh0P82008:2PP0209jNWP05
0:j^[P24Q8@0Q8B405iNGP2TY:@00P2LW9`01@2EUID0XZ:R0::RXP1hN7P0SHf=0080Kfm_00@0/;2`
0:b/[02/[:`0IFEU0P2<S8`01@2b/[80MgMg09JFUP2FUYH0Zj^[0080TY:B00D0IVIV07EeM@3EeMD0
eMGE07alO00206a/K0050;>c/`2CTi<0Ti>C0:b/[013@d<00P2BTY801@2[Zj/0VYZJ09ZJVP2CTi<0
X:2P0080OWin00D0Rh^;09NGU`2GUiL0TI6A07YjNP020;2`/00406MWI`2VYZH0YZJV092@T080WYjN
00D0R8R808N7Q`2][Jd0[Jf]05YJFP020<o?c`0504I6AP2o_kl0TI6A096AT@25QHD00P1kNg/01@2?
Shl0[Zj^0:j^[P2@T900UYJF0080Ph>300@0S8b<09NGU`2GUiL0O7al2P3oool01038b<P0/[:b0;:b
/P2=SHd207IfMP0505ADE01FEUH0JFUY06UYJ@1kNg/00P2;Rh/01@2UYJD0WYjN09jNWP2HV9P0UIFE
0080XZ:R00D0/K6a0:>SX`2SXj<0XZ:R09nOW`02096AT@0408b<S02JVYX0VYZJ09RHV080XJ6Q00D0
WYjN09VIV@2IVIT0VIVI09bLW00209NGU`0509:BTP29RHT0PX:208:2PP1jNWX00P1dM7@01@1QHF40
Cdm?04M7A`17AdL0BDU90080Bd];00D0IfMW08B4Q024Q8@0Ti>C09^KV`020:>SX`0509fMW@2WYjL0
YjNW0;Fe]@2l_;`00P2m_Kd0103=cLd0c/k>0<k>cP2k^k/20;Fe]@050:j^[P2OWil0VIVI09VIV@2U
YJD00P2VYZH01@2XZ:P0ZZZZ0:NWY`2WYjL0YJFU0080X:2P00D0WYjN0:JVYP2VYZH0VYZJ09fMW@02
09RHV00509fMW@2?Shl0Shn?092@T022PX800`1mOGd207AdM00507YjNP1nOWh0Ph>308>3P`25QHD0
0P2ATI401@2;Rh/0WIfM09fMW@2QXJ40VIVI0080U9BD00D0VIVI08b<S02<S8`0YZJV0:NWY`020;:b
/P040;Fe]@2h^;P0^;Rh0:BTY080Z:RX00D0YZJV09nOW`2HV9P0V9RH09JFUP0209>CT`0508Z:RP2C
Ti<0[Zj^0:j^[P2c/k<00P2i^KT01@33`l<0`/;20:b/[02/[:`0YjNW0080XZ:R0`2c/k<01@2TY:@0
UIFE0861P@21PH40JVYZ0080HF5Q0P1RHV8206i^KP04075aL@1/K6`0K6a/07=cL`80Q8B400D0Ng]k
07UiN@2<S8`0S8b<0:BTY0020:n_[`030<?3``3oool0oooo00d0oooo000=0?ooo`040;Fe]@1SHf<0
Hf=S0;Zj^P80O7al00D0ZZZZ055AD@30`<00`<3007]kN`0208F5Q@050<c<c01BDU80DU9B0<C4a017
AdL00P36a/H01@2CTi<0R8R808R8R02DU9@0Lg=c0080U9BD00@0VIVI096AT@2ATI40YZJV0P22PX80
1@2TY:@0NGUi05aLG01LG5`0iNGU0080De=C00D0_[jn07QhN02FUYH0UYJF0;fm_@0203<c<`050:BT
Y02EUID0`L710<71`@2@T9000P1iNGT01@1nOWh0WIfM09fMW@1oOgl0W9bL0080TI6A00D0RHV908b<
S02<S8`0TI6A09NGU`0209^KV`0409VIV@2:RXX0RXZ:05YJFP80d=3@00D0LW9b0:NWY`2?Shl0Shn?
05IFEP020=KFeP05079bLP26QXH0ZZZZ0:ZZZP0l?3`00P3alO401@1VIVH0[Zj^0:j^[P20P800PX:2
0080WYjN00D0[Zj^08B4Q024Q8@0GUiN0:BTY00209bLW00509FEU@2RXZ80XZ:R07QhN02=SHd00P1_
Kfl0102`/;00[:b/0:b/[01UIFD208b<S0050;:b/P1gMgL0UYJF09JFUP2[Zj/00P2BTY801@1VIVH0
MGEe0=GEe@3EeMD0O7al0080K6a/00D0/k>c09>CT`2CTi<0[:b/04=3@`0209:BTP050:^[Z`2JVYX0
VYZJ09>CT`2PX:000P1nOWh01@2;Rh/0UiNG09NGU`2ATI40NWYj0080/;2`00@0IfMW0:JVYP2VYZH0
T92@0P2NWYh01@28R8P0QhN70:f][@2][Jd0FUYJ0080clo?00D0ATI60;no_`2ATI40TI6A08F5Q@02
07]kN`0508n?S`2^[Zh0[Zj^092@T02FUYH00P23Ph<0102<S8`0UiNG09NGU`1lO7`:0?ooo`040<S8
b02b/[80/[:b08f=S@80MWIf00D0E5AD05IFEP1YJFT0JFUY07]kN`0208^;R`050:FUY@2NWYh0WYjN
09RHV02EUID00P2RXZ801@2a/K40Xj>S0:>SX`2RXZ80WinO0080TI6A00@0S8b<09ZJVP2JVYX0V9RH
0P2QXJ401@2NWYh0VIVI09VIV@2IVIT0W9bL0080UiNG00D0TY:B08V9R@22PX80PX:207YjNP0207Ad
M005065QH@1?Cdl0AdM704M7A`19BDT00P1;Bd/01@1WIfL0Q8B408B4Q02CTi<0Vi^K0080Xj>S00D0
WIfM0:NWY`2WYjL0]KFe0;bl_0020;fm_@040<g=c@3>c/h0c/k>0;^k^`80]KFe00D0[Zj^09nOW`2I
VIT0VIVI0:FUY@020:JVYP050:RXZ02ZZZX0YjNW0:NWY`2UYJD00P2PX:001@2NWYh0YZJV0:JVYP2J
VYX0WIfM0080V9RH00D0WIfM08n?S`2?Shl0T92@08:2PP0307emO@80M7Ad00D0NWYj07inOP23Ph<0
Ph>308F5Q@02096AT@0508^;R`2MWId0WIfM0:6QX@2IVIT00P2DU9@01@2IVIT0S8b<08b<S02VYZH0
YjNW0080/[:b00@0]KFe0;Rh^02h^;P0Y:BT0P2XZ:P01@2VYZH0WinO09RHV02HV9P0UYJF0080Ti>C
00D0RXZ:09>CT`2^[Zh0[Zj^0;>c/`020;Vi^@050<?3``32`/80[:b/0:b/[02WYjL00P2RXZ830;>c
/`050:BTY02EUID0PH610861P@1ZJVX00P1QHF42069RHP80KVi^00@0LG5a06a/K01/K6`0Lg=c0P24
Q8@01@1kNg/0NGUi08b<S02<S8`0Y:BT0080[jn_00<0`l?30?ooo`3oool03@3oool000d0oooo00@0
];Bd061PH01PH600_kno0P1jNWX01@2WYjL0F5QH0;Zj^P2j^[X0O7al0080QXJ600D0bl_;059BDP1B
DU80b<S804=3@`020<C4a00509nOW`1hN7P0N7Qh09ZJVP1cLg<00P2DU9@0102JVYX0U9BD09BDU02N
WYh208^;R`0509jNWP1lO7`0FUYJ05YJFP3WinL00P1ADE401@2l_;`0Ogmo09:BTP2BTY80_Kfm0080
=CDe00D0Y:BT09BDU033`l<0`l?3096AT@0207IfMP050820P02KVi/0Vi^K07moO`2OWil00P2?Shl0
1@26QXH0Ti>C09>CT`2:RXX0W9bL0080VYZJ00@0UiNG08n?S`2?Shl0De=C0P3@d=001@1gMgL0XJ6Q
09:BTP2BTY80Fe]K0080cLg=00D0NWYj08:2PP2][Jd0[Jf]03Lg=`020?Ogm`0306ATI02][Jd0[Jf]
0080Ogmo0P2RXZ801@2b/[80OGem07emO@1RHV80WIfM0080XZ:R00D0UiNG0:2PX02PX:00Ogmo0820
P00207QhN0040:^[Z`2XZ:P0Z:RX075aL@80S8b<00D0XJ6Q0861P@2GUiL0UiNG0:RXZ00209RHV005
06EUI@1dM7@0c/k>0<k>cP24Q8@00P1/K6`01@2YZJT0WYjN09jNWP2/[:`0AdM70080RHV900D0[jn_
09NGU`2GUiL0V9RH09jNWP0207alO005092@T02ATI40TI6A09FEU@1mOGd00P2[Zj/00`1`L700Vi^K
09^KV`0309RHV00508^;R`2:RXX0YZJV0:JVYP1PH6000P3:b/X01@0n?Sh0clo?08^;R`2;Rh/0Ph>3
0080Ogmo00D0Shn?0:JVYP2VYZH0UYJF096AT@0208f=S@040861P@2IVIT0VIVI07inOPX0oooo00@0
DE5A06QXJ01XJ6P0Rh^;0P2[Zj/01@3>c/h0cLg=0<30`030`<00/k>c0080Y:BT00D0Shn?08^;R`2;
Rh/0SHf=08R8R00207IfMP0506i^KP1nOWh0OWin08J6QP2?Shl00P2JVYX0102RXZ80Ti>C09>CT`27
QhL207moO`0508:2PP21PH40OGem07emO@21PH400P2?Shl01@2LW9`0Zj^[0;bl_02l_;`0`l?30080
^k^k00D0^;Rh0:6QX@2;Rh/0Rh^;07]kN`0206i^KP0505eMG@1SHf<0Hf=S06a/K01kNg/00P2<S8`0
1@2FUYH0S8b<08b<S01lO7`0I6AT0080ADE500@0@41004I6AP16ATH0EUIF0P1ZJVX01@1mOGd0Ph>3
07moO`1oOgl0NGUi0080Lg=c00D0Ogmo07UiN@1cLg<0Lg=c07UiN@0207]kN`0507=cL`1oOgl0Ogmo
096AT@2PX:000P2TY:@30:ZZZP80/;2`0P2h^;P01@2WYjL0/;2`0;2`/02^[Zh0ZJVY0080X:2P00@0
[Jf]0;>c/`2c/k<0/K6a0P2/[:`01@2^[Zh0];Bd0;6a/@2a/K40YZJV0080V9RH00D0Ti>C09:BTP22
PX80PX:207alO00208:2PP0508B4Q01jNWX0NWYj07YjNP26QXH00P2=SHd01@2>SXh0SHf=08f=S@26
QXH0MWIf0080FUYJ00D0DE5A04i>CP1>CTh0G5aL06UYJ@02096AT@0409jNWP2KVi/0Vi^K07inOP80
J6QX00D0A4A403dm?@17AdL0AdM706QXJ00208f=S@050;Bd]035aLD0emOG0=OGe`3>c/h00P38b<P0
1@2i^KT0UiNG09NGU`1mOGd0QXJ60080M7Ad00@0H61P05eMG@1MGEd0EeMG3`3oool000d0oooo00@0
/[:b05aLG01LG5`0a<C40P1gMgL01@2VYZH0H61P0;>c/`2c/k<0Q8B40080PX:200D0alO705QHF01H
F5P0a<C404A4A0020<71`@050:VYZ@1_Kfl0Kfm_09fMW@1_Kfl00P2JVYX309NGU`0509RHV02DU9@0
U9BD09JFUP1nOWh00P1LG5`01@3Vi^H0D51@051@D02k^k/0Q8B40080TI6A00D0^[Zj03Ti>@0i>CT0
X:2P09JFUP020<30`00409BDU01cLg<0Lg=c08:2PP80Vi^K00D0OWin09jNWP2ATI40TI6A08J6QP02
09BDU00508F5Q@2UYJD0UYJF09JFUP2EUID00P2BTY801@1DE5@0cLg=0<g=c@1iNGT0Xj>S0080SHf=
00<0HV9R0<C4a034a<@00P20P8020:ZZZP0403Ph>03jn_X0n_[j06=SH`80ZZZZ00D0Ph>30861P@2I
VIT0VIVI0;bl_00207IfMP0406YZJP2@T900YZJV0:JVYP<0WIfM00D0Ph>307QhN020P800P8200:>S
X`020:VYZ@0507inOP25QHD0QHF509>CT`2BTY800P2?Shl01@2][Jd0UYJF09JFUP1TI6@0NGUi0080
b/[:00@0P82007IfMP1fMWH0VYZJ0P2WYjL01@2_[jl0BDU90820P020P800/;2`0080UiNG0P2KVi/2
07YjNP0509JFUP2:RXX0RXZ:09NGU`1oOgl00P2WYjL0101lO7`0SHf=08f=S@2NWYh209JFUP0508n?
S`27QhL0WIfM09fMW@1`L7000P30`<001@0m?Cd0fMWI08B4Q024Q8@0PH610080Q8B400D0TY:B09bL
W02LW9`0VIVI096AT@02092@T0040861P@2JVYX0VYZJ07inOPX0oooo00@0b/[:0;2`/02`/;00PX:2
0P1WIfL01@18B4P0@T9204e=C@1=CDd0Hf=S0080KVi^00D0N7Qh0861P@21PH40R8R809^KV`020:>S
X`050:FUY@2IVIT0VIVI08n?S`26QXH00`23Ph<209BDU0050:JVYP2YZJT0ZJVY0:ZZZP2`/;000P2h
^;P01@2d];@0Y:BT0:BTY02ATI40N7Qh0080HF5Q00D0EeMG069RHP1RHV80M7Ad09NGU`020;2`/004
0;jn_P3Bd]80d];B0=oOg`80emOG0P3?cll20;jn_P<0/k>c00D0[jn_0;6a/@3>c/h0c/k>0<[:bP02
0<C4a0050;jn_P2b/[80/[:b09bLW02PX:000P2QXJ4309jNWP05092@T02DU9@0U9BD09BDU02CTi<0
0P27QhL01@20P800KVi^06i^KP1[Jf/0H61P0080GemO00D0H61P05eMG@1MGEd0D51@069RHP0206][
J`0508B4Q02=SHd0SHf=08Z:RP23Ph<00P2=SHd0102:RXX0R8R808R8R02?Shl209BDU00508N7Q`1j
NWX0Kfm_06m_K`1eMGD00P1hN7P01@2:RXX0QhN70:>SX`2SXj<0];Bd0080^;Rh00D0YZJV0;Zj^P2j
^[X0/K6a0:BTY0020:6QX@<0/[:b00D0b/[:0=_Kf`3emOD0mOGe0>k^kP020>[ZjP050;jn_P2YZJT0
Ng]k07]kN`1bLW800P1dM7@0102BTY80/k>c0;>c/`3Shn<30?ooo`050?Cdm038b<P0b<S809fMW@1k
Ng/00P1PH600101XJ6P0Ogmo07moO`2<S8`209ZJVP050:BTY02BTY80Shn?08n?S`2KVi/00P2ZZZX0
0`30`<00oooo0?ooo`0=0?ooo`003@3oool0102b/[80G5aL05aLG034a<@207MgM`050:JVYP1PH600
/k>c0;>c/`24Q8@00P22PX801@37alL0F5QH05QHF034a<@0A4A40080`L7100D0ZJVY06m_K`1_Kfl0
WIfM06m_K`0209ZJVP<0UiNG00D0V9RH09BDU02DU9@0UYJF07inOP0205aLG0050>KViP1@D500D51@
0;^k^`24Q8@00P2ATI401@2j^[X0>CTi03Ti>@2PX:00UYJF0080`<3000@0U9BD07=cL`1cLg<0PX:2
0P2KVi/01@1nOWh0WYjN096AT@2ATI40QXJ60080U9BD00D0QHF50:FUY@2FUYH0UYJF09FEU@0209:B
TP0505ADE03=cLd0cLg=07UiN@2SXj<00P2=SHd00`1RHV80a<C40<C4a0020820P080ZZZZ00@0>3Ph
0?[jnP3jn_X0Hf=S0P2ZZZX01@23Ph<0PH6109VIV@2IVIT0_;bl0080MWIf00@0JVYZ092@T02VYZH0
YZJV0`2MWId01@23Ph<0N7Qh0820P020P800Xj>S0080ZJVY00D0OWin08F5Q@25QHD0Ti>C09:BTP02
08n?S`050:f][@2FUYH0UYJF06ATI01iNGT00P3:b/X01020P800MWIf07IfMP2JVYX20:NWY`050:n_
[`19BDT0P8200820P02`/;000P2GUiL209^KV`80NWYj00D0UYJF08Z:RP2:RXX0UiNG07moO`020:NW
Y`0407alO02=SHd0SHf=09jNWP80UYJF00D0Shn?08N7Q`2MWId0WIfM071`L0020<30`00503dm?@3I
fMT0Q8B408B4Q021PH400P24Q8@01@2BTY80W9bL09bLW02IVIT0TI6A0080T92@00@0PH6109ZJVP2J
VYX0OWin2P3oool0103:b/X0/;2`0;2`/022PX8206MWI`0504Q8B012@T80CDe=04e=C@1SHf<00P1^
KVh01@1hN7P0PH610861P@28R8P0Vi^K0080Xj>S00D0YJFU09VIV@2IVIT0Shn?08J6QP0308>3P`80
U9BD00D0YZJV0:VYZ@2YZJT0ZZZZ0;2`/0020;Rh^0050;Bd]02TY:@0Y:BT096AT@1hN7P00P1QHF40
1@1GEeL0HV9R069RHP1dM7@0UiNG0080/;2`00@0_[jn0=;BdP3Bd]80gmoO0P3GemL20<o?c`80_[jn
0`2c/k<01@2_[jl0/K6a0<k>cP3>c/h0b/[:0080a<C400D0_[jn0;:b/P2b/[80W9bL0:2PX0020:6Q
X@<0WYjN00D0T92@09BDU02DU9@0U9BD09>CT`0208N7Q`050820P01^KVh0KVi^06][J`1PH6000P1O
Gel01@1PH600GEeM05eMG@1@D500HV9R0080Jf][00D0Q8B408f=S@2=SHd0RXZ:08>3P`0208f=S@04
08Z:RP28R8P0R8R808n?S`80U9BD00D0QhN707YjNP1_Kfl0Kfm_07EeM@0207QhN00508Z:RP27QhL0
Xj>S0:>SX`2d];@00P2h^;P01@2VYZH0^[Zj0;Zj^P2a/K40Y:BT0080XJ6Q0`2b/[801@3:b/X0fm_K
0?Gem@3emOD0k^k^0080j^[Z00D0_[jn0:VYZ@1kNg/0Ng]k079bLP0207AdM00409:BTP2c/k<0/k>c
0>?Sh`<0oooo00D0m?Cd0<S8b038b<P0WIfM07]kN`02061PH00406QXJ01oOgl0Ogmo08b<S080VYZJ
00D0Y:BT09:BTP2?Shl0Shn?09^KV`020:ZZZP030<30`03oool0oooo00d0oooo000=0?ooo`040;2`
/01MGEd0GEeM0<K6aP80M7Ad00D0XZ:R06MWI`2`/;00/;2`08:2PP0208F5Q@050<;2`P1QHF40HF5Q
0;^k^`1:BTX00P2n_[h01@2`/;00Hf=S06=SH`2UYJD0KVi^0080VIVI00@0Ti>C09bLW02LW9`0Ti>C
0P2IVIT01@2ATI40P82005eMG@1MGEd0iNGU0080Cdm?00D0^k^k08F5Q@2CTi<0Ti>C0;Fe]@0203hn
?P0509bLW02FUYH0`<300<30`02EUID00P1bLW801@26QXH0VYZJ09ZJVP1nOWh0WIfM0080TI6A00D0
QhN7096AT@2ATI40Q8B40:ZZZP02096AT@0409NGU`2DU9@0U9BD055AD@80clo?00D0MgMg0:NWY`28
R8P0R8R806UYJ@020;Ng]`0508^;R`21PH40YZJV0:JVYP0f=SH00P3moOd01@1RHV80YJFU0:FUY@28
R8P0Q8B40080UIFE00D0^k^k07MgM`1gMgL0L71`08R8R0030:JVYP80UYJF00D0QhN707=cL`20P800
P8200:BTY0020:b/[00508F5Q@1mOGd0OGem08R8R02OWil00P2=SHd01@2_[jl0TY:B09:BTP1UIFD0
O7al0080cLg=00@0NGUi07emO@1mOGd0SHf=0`2_[jl0101BDU80LW9b079bLP2e]KD209RHV00509ZJ
VP2NWYh0MGEe07EeM@2HV9P00P28R8P01@2KVi/0P8200::RXP2RXZ80QhN70080QHF500D0W9bL09JF
UP2FUYH0TI6A08Z:RP0209JFUP0507moO`2_[jl0[jn_0451@@3Rh^800P1lO7`01022PX80R8R808R8
R02?Shl209^KV`0509ZJVP2;Rh/0VYZJ09ZJVP1oOgl00P2FUYH00`22PX80oooo0?ooo`080?ooo`04
08:2PP2?Shl0Shn?0;6a/@80/k>c00D0aLG50=;BdP3:b/X0b/[:0:ZZZP020:b/[0050:6QX@2JVYX0
VYZJ09>CT`29RHT00P27QhL01@2BTY80X:2P0:2PX02a/K40`<300080c<c<00@0bLW90;Fe]@2e]KD0
W9bL0P2@T9001@23Ph<0NGUi07IfMP1fMWH0OGem0080QHF500D0Vi^K0;Bd]03;bl/0bl_;0=_Kf`02
0=[JfP050=?Cd`3:b/X0`/;20<;2`P2h^;P00P2XZ:P01@2BTY80P8200820P01hN7P0JVYZ0080K6a/
00D0MGEe07YjNP1jNWX0P82008^;R`0208R8R00408J6QP27QhL0QhN708>3P`80PX:200D0R8R809JF
UP2MWId0WIfM0;:b/P020;Rh^0050<71`@2m_Kd0b/[:0<[:bP3>c/h00P3UiND00`3jn_X0o?cl0?cl
o0020>GUi@80fMWI00D0`/;20<_;b`3;bl/0dM7A0;jn_P020;Bd]0050;:b/P2SXj<0Xj>S0:RXZ02S
Xj<00P2GUiL0102;Rh/0Shn?08n?S`29RHT207]kN`0308>3P`26QXH0Rh^;0080Rh^;0P2RXZ801@2L
W9`0^KVi0:ZZZP2ZZZX0YjNW0080Xj>S00D0];Bd09nOW`2OWil0ZJVY0;2`/0020:b/[00509ZJVP2P
X:00X:2P09>CT`2>SXh00P1oOgl01@29RHT0R8R808R8R02PX:00/;2`0080dm?C00@0g]kN0<o?c`3?
cll0^[Zj0P2WYjL01@21PH40GemO04e=C@1=CDd0AdM70080BDU900D0IVIV08b<S02j^[X0^[Zj0<o?
c`020<S8b0050<C4a02i^KT0^KVi0;fm_@37alL00P3AdM40103=cLd0^k^k0;^k^`2JVYX?0?ooo`00
3@3oool0102VYZH0GemO05mOG`3:b/X2071`L0050:2PX01/K6`0/;2`0;2`/01oOgl00P29RHT01@2k
^k/0JVYZ06YZJP2_[jl0De=C0080^[Zj00D0/k>c05iNGP1NGUh0YZJV075aL@0209NGU`0409FEU@2L
W9`0W9bL08n?S`80X:2P00D0Rh^;0861P@1QHF40HF5Q0>3Ph002055AD@050;Zj^P22PX80W9bL09bL
W02][Jd00P14A4@01@2CTi<0Vi^K0<;2`P32`/80UIFE0080KVi^00D0RHV909VIV@2IVIT0OGem09fM
W@0209BDU00508J6QP2=SHd0SHf=08V9R@2XZ:P00P2?Shl0102JVYX0UIFE09FEU@1;Bd/20=OGe`05
075aL@2][Jd0Q8B408B4Q01^KVh00P2YZJT01@2FUYH0PX:209nOW`2OWil0?3`l0080o?cl00<0HV9R
0:6QX@2QXJ400P2:RXX208j>SP050;Vi^@20P800P82006YZJP2;Rh/00P2PX:001@2a/K40Rh^;08^;
R`2FUYH0I6AT0080PX:200@0YJFU0;:b/P2b/[80QhN70P1`L7001@2:RXX0YJFU08j>SP2>SXh0[Zj^
0080Rh^;00D0KFe]07inOP38b<P0b<S807EeM@0308F5Q@80/[:b00D0[Zj^05mOG`1UIFD0IFEU0;Jf
]P0209bLW00509NGU`2PX:00NGUi07UiN@2DU9@00P26QXH01@2IVIT0QXJ609fMW@2MWId0S8b<0080
Ph>300D0Vi^K09FEU@2EUID0U9BD08^;R`0308b<S080XJ6Q00D0AdM70>SXj01hN7P0N7Qh08>3P`02
08R8R005096AT@2EUID0UIFE09ZJVP2<S8`00P2JVYX01021PH40UYJF09JFUP27QhL:0?ooo`040:NW
Y`2YZJT0ZJVY0:>SX`80WIfM00D0SHf=07moO`1oOgl0Ogmo08^;R`0209NGU`050::RXP2VYZH0YZJV
0:>SX`2IVIT00P2?Shl01@21PH40MgMg07MgM`1/K6`0IVIV0080F5QH00@0E5AD06IVIP1VIVH0OWin
0P27QhL0102MWId0YZJV0:>SX`2SXj<309VIV@0508n?S`28R8P0OWin07inOP1]KFd00P1[Jf/01@1S
Hf<0H61P05]KF`1KFe/0Hf=S0080LW9b00D0SHf=09VIV@2IVIT0Xj>S0;:b/P020:VYZ@0509VIV@2D
U9@0U9BD096AT@22PX800P1`L700101]KFd0Jf][06][J`1bLW8208:2PP0509^KV`2GUiL0W9bL09bL
W02CTi<00P2?Shl01@1nOWh0PX:2079bLP1bLW80GUiN0080>SXj00D0<S8b03hn?P0n?Sh0Cdm?04a<
C00206QXJ00508b<S02>SXh0SXj>09FEU@2^[Zh00P2d];@01@2HV9P0TY:B09:BTP2=SHd0T92@0080
UYJF00@0[Zj^09fMW@2MWId0WinO0P2a/K401@2`/;00`L710=_Kf`3Kfm/0gMgM0080clo?00D0_[jn
096AT@2<S8`0S8b<092@T00208N7Q`0508^;R`2EUID0UIFE08f=S@1mOGd00P22PX801@1nOWh0NGUi
07UiN@1fMWH0N7Qh0080LG5a00D0Lg=c079bLP1bLW80Lg=c07AdM002075aL@0406EUI@1jNWX0NWYj
08N7Q`80PX:200D0RHV909^KV`2SXj<0Xj>S0:j^[P020<S8b0050<_;b`30`<00Xj>S0:>SX`2?Shl0
0P29RHT01@20P800Rh^;08^;R`24Q8@0Lg=c0080J6QX00@0JVYZ06i^KP1^KVh0S8b<3`3oool000d0
oooo00@0YZJV05mOG`1OGel0b/[:0P1`L7001@2PX:00K6a/0;2`/02`/;00Ogmo0080RHV900D0^k^k
06YZJP1ZJVX0[jn_05=CD`020;Zj^P050;>c/`1NGUh0GUiN0:JVYP1aLG400P2GUiL0102EUID0W9bL
09bLW02?Shl20:2PX00508^;R`21PH40HF5Q065QH@3Ph>000P1ADE401@2j^[X0PX:209bLW02LW9`0
[Jf]0080A4A400D0Ti>C09^KV`32`/80`/;209FEU@0206i^KP0508V9R@2IVIT0VIVI07emO@2MWId0
0P2DU9@01@26QXH0SHf=08f=S@29RHT0Z:RX0080Shn?00@0VYZJ09FEU@2EUID0Bd];0P3GemL01@1a
LG40[Jf]08B4Q024Q8@0KVi^0080ZJVY00D0UYJF08:2PP2OWil0WinO03`l?0020?clo003069RHP2Q
XJ40XJ6Q0080RXZ:0P2>SXh01@2i^KT0P8200820P01ZJVX0Rh^;0080X:2P00D0/K6a08^;R`2;Rh/0
UYJF06ATI00208:2PP040:FUY@2b/[80/[:b08N7Q`80L71`00D0RXZ:0:FUY@2>SXh0SXj>0:j^[P02
08^;R`0506e]K@1nOWh0b<S80<S8b01eMGD00`25QHD20;:b/P050:j^[P1OGel0IFEU06EUI@2f][H0
0P2LW9`01@2GUiL0X:2P07UiN@1iNGT0U9BD0080QXJ600D0VIVI08J6QP2MWId0WIfM08b<S00208>3
P`0509^KV`2EUID0UIFE09BDU02;Rh/00`2<S8`20:6QX@0504M7A`3Xj>P0N7Qh07QhN023Ph<00P28
R8P01@2ATI40UIFE09FEU@2JVYX0S8b<0080VYZJ00@0PH6109JFUP2FUYH0QhN72P3oool0102WYjL0
ZJVY0:VYZ@2SXj<209fMW@0508f=S@1oOgl0Ogmo07moO`2;Rh/00P2GUiL01@2RXZ80YZJV0:JVYP2S
Xj<0VIVI0080Shn?00D0PH6107MgM`1gMgL0K6a/06IVIP0205QHF00405ADE01VIVH0IVIV07inOP80
QhN700@0WIfM0:JVYP2SXj<0Xj>S0`2IVIT01@2?Shl0R8R807inOP1nOWh0KFe]0080Jf][00D0Hf=S
061PH01KFe/0Fe]K06=SH`02079bLP0508f=S@2IVIT0VIVI0:>SX`2b/[800P2YZJT01@2IVIT0U9BD
09BDU02ATI40PX:20080L71`00@0KFe]06][J`1[Jf/0LW9b0P22PX801@2KVi/0UiNG09bLW02LW9`0
Ti>C0080Shn?00D0OWin08:2PP1bLW80LW9b05iNGP0203Xj>P05038b<P0n?Sh0?Shn04m?C`1<C4`0
0P1XJ6P01@2<S8`0SXj>08j>SP2EUID0[Zj^0080];Bd00D0V9RH09:BTP2BTY80SHf=092@T00209JF
UP040:j^[P2MWId0WIfM09nOW`80/K6a00D0/;2`0<71`@3Kfm/0fm_K0=gMg@020<o?c`050;jn_P2A
TI40S8b<08b<S02@T9000P27QhL01@2;Rh/0UIFE09FEU@2=SHd0OGem0080PX:200D0OWin07UiN@1i
NGT0MWIf07QhN002075aL@0507=cL`1bLW80LW9b07=cL`1dM7@00P1aLG40101UIFD0NWYj07YjNP27
QhL208:2PP0508V9R@2KVi/0Xj>S0:>SX`2^[Zh00P38b<P01@3;bl/0`<300:>SX`2SXj<0Shn?0080
RHV900D0P82008^;R`2;Rh/0Q8B407=cL`0206QXJ00406YZJP1^KVh0KVi^08b<S0l0oooo000=0?oo
o`0409fMW@1SHf<0Hf=S0<o?c`80K6a/00D0WinO06UYJ@2g]kL0]kNg07emO@0208Z:RP050;Rh^01/
K6`0K6a/0:VYZ@1LG5`00P2e]KD01@2h^;P0FUYJ05YJFP2VYZH0NGUi0080SXj>00@0UYJF09bLW02L
W9`0TI6A0P2OWil01@2<S8`0PH61069RHP1RHV80g=cL0080De=C00D0^k^k0861P@2SXj<0Xj>S0:BT
Y00204Y:BP0508b<S02NWYh0aLG50<G5a@2CTi<00P1`L7001@28R8P0UiNG09NGU`1nOWh0WYjN0080
UIFE00D0QHF508R8R028R8P0SHf=0:b/[00208Z:RP0409ZJVP2CTi<0Ti>C04a<C080g=cL00D0KFe]
0;:b/P1oOgl0Ogmo07=cL`0209fMW@050:>SX`1nOWh0VYZJ09ZJVP12@T800P3kno/01@1SHf<0W9bL
09bLW02>SXh0Rh^;0080QhN700D0^[Zj08Z:RP2:RXX0H61P09>CT`0209JFUP050;fm_@20P800P820
09bLW01RHV800P25QHD0102RXZ80]KFe0;Fe]@2;Rh/206=SH`05096AT@2TY:@0TY:B09:BTP2[Zj/0
0P28R8P01@1bLW80PH610;jn_P2n_[h0O7al0080Q8B400D0QhN70;2`/02`/;00Z:RX06YZJP0205iN
GP050;Fe]@2QXJ40XJ6Q08n?S`2UYJD00P1hN7P01@2EUID0Ph>308>3P`2LW9`0QHF50080WIfM00@0
SXj>08>3P`23Ph<0UYJF0P2HV9P01@2EUID0SXj>08:2PP22PX80U9BD0080Vi^K00D0Cdm?0>OWi`1i
NGT0NGUi07inOP0208V9R@0509>CT`2=SHd0SHf=0:6QX@2;Rh/00P2GUiL01023Ph<0UYJF09JFUP2=
SHd:0?ooo`0407MgM`21PH40PH6108Z:RP80YJFU00D0^;Rh0;Ng]`2b/[80/[:b0:ZZZP0209FEU@05
08:2PP23Ph<0Ph>308^;R`2DU9@00P2HV9P00`2QXJ40Z:RX0:RXZ0020:n_[`80`L7100@0dM7A0<O7
a`37alL0^KVi0P2l_;`01@2][Jd0Xj>S0:NWY`2WYjL0/;2`0080Z:RX00D0ZJVY0:2PX02HV9P0V9RH
09JFUP0209:BTP0508n?S`2:RXX0S8b<08b<S02;Rh/00P26QXH01@21PH40Shn?08n?S`2DU9@0S8b<
0080T92@00D0Vi^K09fMW@2MWId0XJ6Q0;2`/0020<c<c0040=3@d03De=@0e=CD0<k>cP80_;bl00D0
Xj>S09ZJVP28R8P0R8R80820P00208B4Q00509JFUP2MWId0^;Rh0;Rh^03Hf=P00P3bl_801@3Zj^X0
g]kN0=kNgP3MgMd0bl_;0080[Zj^00D0Ti>C096AT@2ATI40O7al07EeM@02079bLP05092@T02JVYX0
VYZJ08j>SP2;Rh/00P2GUiL01026QXH0Q8B408B4Q02FUYH209BDU00309FEU@2?Shl0PH610080PH61
0P1nOWh01@27QhL0W9bL0:FUY@2UYJD0Vi^K0080Z:RX00D0TY:B08J6QP26QXH0PX:208J6QP0208N7
Q`0509>CT`2IVIT0VIVI0:FUY@2RXZ800P2/[:`01@2e]KD0^;Rh0;Rh^02e]KD0Zj^[0080WinO00@0
Ti>C0820P020P800KVi^0P1bLW801@1kNg/0QhN708j>SP2>SXh0V9RH0080UiNG00D0OWin06][J`1[
Jf/0Jf][05aLG00205QHF00506m_K`1fMWH0MWIf08B4Q02UYJD00P2^[Zh0102PX:00V9RH09RHV023
Ph<?0?ooo`003@3oool0102EUID0IfMW06MWI`3AdM4206YZJP0509fMW@1/K6`0^k^k0;^k^`1jNWX0
0P2=SHd01@2c/k<0L71`071`L02OWil0J6QX0080[Jf]00D0]KFe06=SH`1SHf<0XJ6Q0820P00208>3
P`0409fMW@2KVi/0Vi^K092@T080WinO00D0SXj>07inOP1WIfL0IfMW0=OGe`0205EEE@050;^k^`1l
O7`0[:b/0:b/[02NWYh00P1?Cdl01@25QHD0Xj>S0<?3``33`l<0TY:B0080LG5a00D0Rh^;09BDU02D
U9@0OWin09^KV`0209ZJVP0508>3P`25QHD0QHF509:BTP2][Jd00P28R8P0102IVIT0TI6A096AT@1A
DE420=kNgP0506EUI@2i^KT0O7al07alO01cLg<00P2HV9P01@2ZZZX0Ph>308f=S@2=SHd0C4a<0080
m?Cd00D0J6QX09JFUP2FUYH0TY:B09>CT`0207YjNP050;Bd]02QXJ40XJ6Q04m?C`2JVYX00P2?Shl0
1@34a<@0O7al07alO02MWId0IFEU0080PX:200@0YZJV0;6a/@2a/K40TI6A0P1ADE401@2VYZH0WinO
08j>SP2>SXh0[jn_0080PH6100D0MGEe08B4Q02d];@0];Bd08F5Q@0208:2PP0508J6QP2b/[80/[:b
0:2PX01cLg<00P1NGUh01@2a/K40Xj>S0:>SX`2:RXX0ZJVY0080Ng]k00D0T92@08F5Q@25QHD0Vi^K
08F5Q@0209fMW@0408^;R`25QHD0QHF509>CT`80WIfM0P2BTY8207emO@0509NGU`2JVYX0VYZJ05=C
D`3Shn<00P1kNg/0101oOgl0R8R808R8R02EUID208V9R@050:FUY@29RHT0TI6A096AT@2<S8`00P2F
UYH00`2?Shl0oooo0?ooo`080?ooo`040:>SX`2OWil0WinO08j>SP80Ng]k00D0NWYj07inOP2;Rh/0
Rh^;09NGU`020:BTY0050;2`/02][Jd0[Jf]0:RXZ02JVYX00P2OWil01@2GUiL0U9BD09BDU023Ph<0
R8R80080Jf][00@0GEeM05]KF`1KFe/0Hf=S0P1OGel01@1eMGD0Ph>308J6QP26QXH0RXZ:0080T92@
00<0SHf=09VIV@2[Zj/00P2[Zj/20:b/[0050;>c/`2][Jd0YZJV0:JVYP2^[Zh00P2b/[800`2VYZH0
Vi^K09^KV`0209JFUP80WYjN00D0];Bd0;Ng]`2g]kL0];Bd0:^[Z`0208f=S@0407QhN01iNGT0NGUi
07YjNP80PH6100D0T92@09NGU`2KVi/0Vi^K09bLW00209:BTP0508J6QP1jNWX0IVIV06IVIP1LG5`0
0P1TI6@01@1cLg<0QhN708N7Q`2;Rh/0WIfM0080[:b/00D0YjNW09>CT`2CTi<0WYjN08n?S`0206m_
K`<0Jf][00D0NWYj08>3P`2?Shl0Shn?09FEU@0209NGU`0408N7Q`1mOGd0OGem07MgM`<0L71`00D0
J6QX07EeM@1eMGD0LW9b075aL@0206][J`0406i^KP1PH600H61P06i^KP80MGEe00D0SXj>09VIV@2L
W9`0W9bL09^KV`0208^;R`0507inOP27QhL0Rh^;08^;R`20P8000P2>SXh01@2LW9`0S8b<08V9R@29
RHT0XJ6Q0080];Bd00D0_Kfm0=GEe@3EeMD0e=CD0;Vi^@020:VYZ@0509ZJVP2@T900T92@0:RXZ03:
b/X00P3Kfm/30>_[j`050<K6aP2c/k<0/k>c09>CT`1`L7000P1TI6@01022PX80R8R808R8R02GUiL?
0?ooo`003@3oool0102<S8`0Jf][06][J`3Fe]H206MWI`0509NGU`1bLW80^k^k0;^k^`1hN7P00P2A
TI401@2YZJT0NGUi07UiN@2GUiL0M7Ad0080Xj>S00D0][Jf06QXJ01XJ6P0WinO08:2PP020820P004
09nOW`2JVYX0VYZJ09FEU@80UiNG00D0Ti>C07]kN`1[Jf/0Jf][0=CDe00205IFEP050;bl_01gMgL0
/[:b0;:b/P2KVi/00P1ADE401@23Ph<0Xj>S0<?3``33`l<0SHf=0080NWYj00D0RHV908n?S`2?Shl0
PH6109jNWP0209NGU`0508:2PP27QhL0QhN709>CT`2/[:`00P27QhL0102JVYX0SXj>08j>SP1BDU82
0>;RhP0505iNGP2o_kl0Ng]k07]kN`1fMWH00P2?Shl01@2_[jl0RHV908B4Q024Q8@0DE5A0080l_;b
00D0Jf][08n?S`2?Shl0U9BD09RHV00207IfMP050:RXZ02g]kL0]kNg03lo?`2RXZ800P2:RXX01@36
a/H0NWYj07YjNP2PX:00IFEU0080Ogmo00@0ZZZZ0:f][@2][Jd0UYJF0P13@d<01@2j^[X0UIFE092@
T02@T900[:b/0080Ogmo00D0Ph>307]kN`2`/;00/;2`08Z:RP020861P@0508Z:RP2`/;00/;2`09JF
UP1kNg/00P1SHf<01@2ZZZX0Y:BT0:BTY02;Rh/0YjNW0080OGem00D0Shn?08Z:RP2:RXX0UiNG08J6
QP0209^KV`0408R8R02@T900T92@08Z:RP80X:2P00D0SXj>09^KV`1iNGT0NGUi09RHV00209VIV@05
05ADE03QhN40OGem07emO@1nOWh00P26QXH01@2FUYH0RXZ:08Z:RP2YZJT0PX:20080TY:B00@0SHf=
09JFUP2FUYH0Ti>C2P3oool0102HV9P0SXj>08j>SP2EUID20:6QX@0509^KV`2PX:00X:2P0:2PX02`
/;000`2WYjL209nOW`0509NGU`2EUID0UIFE09FEU@2DU9@00P2LW9`01@2a/K40Zj^[0;Rh^02h^;P0
b<S80080`<3000D0^[Zj0;no_`2o_kl0[jn_09bLW00209ZJVP0508^;R`28R8P0R8R808n?S`2;Rh/0
0P25QHD01@2HV9P0WYjN09jNWP2TY:@0Zj^[0080^;Rh00@0YjNW09VIV@2IVIT0UYJF0P2LW9`01@2E
UID0W9bL09fMW@2MWId0Ph>30080P82000D0PH6107moO`2;Rh/0Rh^;0:f][@020:NWY`050:BTY02O
Wil0WinO09FEU@28R8P00P2@T9001@2GUiL0W9bL09bLW02QXJ40YjNW0080XJ6Q00@0UYJF08J6QP26
QXH0OGem0P1[Jf/01@1/K6`0JVYZ06UYJ@1YJFT0MWIf0080SXj>00D0V9RH0;>c/`3MgMd0gMgM0<S8
b0020;fm_@050;Fe]@2/[:`0R8R808R8R02DU9@00P2KVi/01@2LW9`0XZ:R0::RXP2/[:`0[jn_0080
]KFe00D0^[Zj0:RXZ02XZ:P0XZ:R09fMW@0209JFUP040:2PX02l_;`0_;bl0<W9b@80cLg=00D0`<30
0:j^[P2IVIT0VIVI09FEU@020:FUY@050:NWY`2LW9`0UiNG09NGU`2OWil00P2GUiL01@2BTY80/K6a
0;Rh^02h^;P0Xj>S0080VYZJ00D0UiNG0861P@21PH40PH6108N7Q`0208f=S@0509NGU`28R8P0R8R8
0820P01eMGD00`1WIfL207YjNP0509:BTP2XZ:P0Z:RX0<?3``3@d=000P3IfMT0102g]kL0ZJVY0:VY
Z@2OWil?0?ooo`003@3oool0102<S8`0Jf][06][J`3Fe]H206MWI`0509NGU`1bLW80^k^k0;^k^`1h
N7P00P2ATI401@2YZJT0NGUi07UiN@2GUiL0M7Ad0080Xj>S00D0][Jf06QXJ01XJ6P0WinO08:2PP02
0820P00409nOW`2JVYX0VYZJ09FEU@80UiNG00D0Ti>C07]kN`1[Jf/0Jf][0=CDe00205IFEP050;bl
_01gMgL0/[:b0;:b/P2KVi/00P1ADE401@23Ph<0Xj>S0<?3``33`l<0SHf=0080NWYj00D0RHV908n?
S`2?Shl0PH6109jNWP0209NGU`0508:2PP27QhL0QhN709>CT`2/[:`00P27QhL0102JVYX0SXj>08j>
SP1BDU820>;RhP0505iNGP2o_kl0Ng]k07]kN`1fMWH00P2?Shl01@2_[jl0RHV908B4Q024Q8@0DE5A
0080l_;b00D0Jf][08n?S`2?Shl0U9BD09RHV00207IfMP050:RXZ02g]kL0]kNg03lo?`2RXZ800P2:
RXX01@36a/H0NWYj07YjNP2PX:00IFEU0080Ogmo00@0ZZZZ0:f][@2][Jd0UYJF0P13@d<01@2j^[X0
UIFE092@T02@T900[:b/0080Ogmo00D0Ph>307]kN`2`/;00/;2`08Z:RP020861P@0508Z:RP2`/;00
/;2`09JFUP1kNg/00P1SHf<01@2ZZZX0Y:BT0:BTY02;Rh/0YjNW0080OGem00D0Shn?08Z:RP2:RXX0
UiNG08J6QP0209^KV`0408R8R02@T900T92@08Z:RP80X:2P00D0SXj>09^KV`1iNGT0NGUi09RHV002
09VIV@0505ADE03QhN40OGem07emO@1nOWh00P26QXH01@2FUYH0RXZ:08Z:RP2YZJT0PX:20080TY:B
00@0SHf=09JFUP2FUYH0Ti>C2P3oool0102HV9P0SXj>08j>SP2EUID20:6QX@0509^KV`2PX:00X:2P
0:2PX02`/;000`2WYjL209nOW`0509NGU`2EUID0UIFE09FEU@2DU9@00P2LW9`01@2a/K40Zj^[0;Rh
^02h^;P0b<S80080`<3000D0^[Zj0;no_`2o_kl0[jn_09bLW00209ZJVP0508^;R`28R8P0R8R808n?
S`2;Rh/00P25QHD01@2HV9P0WYjN09jNWP2TY:@0Zj^[0080^;Rh00@0YjNW09VIV@2IVIT0UYJF0P2L
W9`01@2EUID0W9bL09fMW@2MWId0Ph>30080P82000D0PH6107moO`2;Rh/0Rh^;0:f][@020:NWY`05
0:BTY02OWil0WinO09FEU@28R8P00P2@T9001@2GUiL0W9bL09bLW02QXJ40YjNW0080XJ6Q00@0UYJF
08J6QP26QXH0OGem0P1[Jf/01@1/K6`0JVYZ06UYJ@1YJFT0MWIf0080SXj>00D0V9RH0;>c/`3MgMd0
gMgM0<S8b0020;fm_@050;Fe]@2/[:`0R8R808R8R02DU9@00P2KVi/01@2LW9`0XZ:R0::RXP2/[:`0
[jn_0080]KFe00D0^[Zj0:RXZ02XZ:P0XZ:R09fMW@0209JFUP040:2PX02l_;`0_;bl0<W9b@80cLg=
00D0`<300:j^[P2IVIT0VIVI09FEU@020:FUY@050:NWY`2LW9`0UiNG09NGU`2OWil00P2GUiL01@2B
TY80/K6a0;Rh^02h^;P0Xj>S0080VYZJ00D0UiNG0861P@21PH40PH6108N7Q`0208f=S@0509NGU`28
R8P0R8R80820P01eMGD00`1WIfL207YjNP0509:BTP2XZ:P0Z:RX0<?3``3@d=000P3IfMT0102g]kL0
ZJVY0:VYZ@2OWil?0?ooo`003@3oool01020P800Kfm_06m_K`3Jf]X206QXJ005096AT@1iNGT0_;bl
0;bl_01eMGD00P2FUYH01@2PX:00OWin07inOP2CTi<0Ng]k0080W9bL00D0]kNg06e]K@1]KFd0VYZJ
08>3P`0207inOP040:FUY@2DU9@0U9BD09ZJVP80T92@00D0VIVI07UiN@1[Jf/0Jf][0=SHf002055A
D@050<71`@1bLW80^;Rh0;Rh^02IVIT00P1ADE401@1nOWh0ZJVY0<30`030`<00SXj>0080Ng]k00D0
R8R808b<S02<S8`0PX:20:6QX@0209JFUP050861P@28R8P0R8R809:BTP2/[:`00P26QXH0102KVi/0
S8b<08b<S01EEED20>?Sh`0505YJFP32`/80N7Qh07QhN01lO7`00P26QXH01@2`/;00T92@07inOP1n
OWh0EeMG0080j^[Z00D0M7Ad08V9R@29RHT0UIFE09jNWP0206m_K`050::RXP3<c<`0c<c<02XZ:P2]
[Jd00P29RHT01@32`/80OWin07inOP2PX:00IFEU0080Q8B400@0YJFU0:VYZ@2YZJT0WIfM0P0g=cL0
1@39bLT0SXj>08n?S`2?Shl0Z:RX0080Q8B400D0RXZ:07AdM02YZJT0ZJVY09BDU00207YjNP0508n?
S`2`/;00/;2`096AT@1mOGd00P1/K6`01@2PX:00XZ:R0::RXP2CTi<0X:2P0080PX:200D0Ti>C08B4
Q024Q8@0Vi^K08>3P`0209bLW00408:2PP2GUiL0UiNG08V9R@80WinO00D0SHf=0::RXP1_Kfl0Kfm_
09bLW00209^KV`0505EEE@3Kfm/0Q8B408B4Q01lO7`00P23Ph<01@2GUiL0R8R808R8R02YZJT0QHF5
0080T92@00@0SXj>09ZJVP2JVYX0UIFE2P3oool0102[Zj/0YJFU0:FUY@2LW9`208R8R00508V9R@2@
T900TI6A096AT@1kNg/00P26QXH01@22PX80TY:B09:BTP2IVIT0SXj>0080P82000D0PH6106YZJP1Z
JVX0E5AD06i^KP0207inOP0407EeM@20P800P82008Z:RP80Ph>300D0OGem08n?S`2OWil0WinO0;Bd
]0020;bl_0050;>c/`2[Zj/0Vi^K09^KV`28R8P00P2;Rh/01@2ATI40VYZJ09BDU02DU9@0W9bL0080
WinO00D0X:2P08J6QP26QXH0P82006=SH`02055AD@0505IFEP1OGel0GemO06m_K`29RHT00P2JVYX0
102HV9P0[:b/0:b/[02[Zj/20:ZZZP050:^[Z`2XZ:P0Vi^K09^KV`2HV9P00P2SXj<01@2TY:@0[Zj^
0;Fe]@2e]KD0`<300080^k^k00D0];Bd0;6a/@2a/K40ZZZZ0:NWY`030:b/[080WYjN00D0UiNG08N7
Q`1nOWh0OWin09FEU@020:n_[`050;Vi^@3Bd]80f][J0=[JfP34a<@00P2/[:`01@2XZ:P0V9RH09RH
V02;Rh/0R8R80080T92@00D0Rh^;08Z:RP2:RXX0TY:B0:FUY@020:RXZ00409ZJVP28R8P0R8R80861
P@80K6a/00<0JVYZ08N7Q`2?Shl00P2?Shl209BDU00509NGU`2BTY80VYZJ09ZJVP2DU9@00P2GUiL0
1@2DU9@0SHf=08J6QP26QXH0TI6A0080PH6100D0Lg=c075aL@1aLG40MWIf07UiN@020861P@0508F5
Q@2<S8`0S8b<07]kN`1eMGD00P1cLg<0101WIfL0G5aL05aLG01ZJVX2069RHP0505mOG`1aLG40PH61
0861P@2GUiL00P2][Jd00`2h^;P0oooo0?ooo`0=0?ooo`003@3oool307MgM`050=GEe@1]KFd0KFe]
08Z:RP21PH400P2i^KT0101dM7@0VYZJ09ZJVP2HV9P208B4Q00508n?S`20P800UYJF09JFUP2j^[X0
0P1`L7001@2HV9P0P8200861P@21PH40Xj>S0080UYJF00D0Vi^K08V9R@29RHT0WinO07EeM@0206m_
K`050=KFeP1@D500D51@0<?3``1^KVh00P2l_;`01@2GUiL0D51@051@D026QXH0XZ:R0080`<3000@0
SXj>07YjNP1jNWX0QXJ60P2?Shl01@23Ph<0WYjN09VIV@2IVIT0P8200080RHV900D0T92@0:n_[`25
QHD0QHF509fMW@0208Z:RP0505EEE@3Rh^80h^;R05YJFP34a<@00P1gMgL01@21PH40OWin07inOP2`
/;00UiNG0080NWYj00@0GUiN0=_Kf`3Kfm/0P8200P21PH401@2KVi/0WinO06e]K@1]KFd0VYZJ0080
g=cL00D08B4Q0:j^[P2:RXX0RXZ:0;bl_00208B4Q00509NGU`1`L700PH610861P@2UYJD00P2NWYh0
1@2ZZZX0;2`/02`/;03EeMD0Rh^;0080RHV900D0YZJV08n?S`2?Shl0R8R806i^KP020:JVYP0409nO
W`1cLg<0Lg=c09>CT`80[Zj^00D0TI6A07emO@1aLG40LG5a09ZJVP020:2PX00509VIV@2NWYh0P820
0820P02FUYH00P21PH401@2QXJ40Ogmo09^KV`2KVi/0PX:20080V9RH00D0QXJ60:6QX@2QXJ40RHV9
0:VYZ@0206YZJP0509fMW@2KVi/0Vi^K05ADE03Jf]X00P27QhL0101lO7`0P8200820P02JVYX208Z:
RP050:JVYP26QXH0TY:B09:BTP2;Rh/00P2KVi/00`2GUiL0oooo0?ooo`080?ooo`0408>3P`2@T900
T92@09NGU`80XJ6Q00D0Vi^K08^;R`23Ph<0Ph>307moO`0207emO@0508^;R`2BTY80TY:B09JFUP2l
_;`00P3=cLd01@3Fe]H0e=CD0=CDe03Ph>00_;bl0080WinO00@0UIFE0:2PX02PX:00UiNG0P2CTi<0
1@2IVIT0Ph>306][J`1[Jf/0Fe]K0080GemO00D0K6a/07alO027QhL0QhN709>CT`02092@T00508Z:
RP1nOWh0QhN708N7Q`1nOWh00P1mOGd01@1oOgl0YJFU0:FUY@2a/K40b/[:0080hN7Q00D0j^[Z0=3@
d03@d=00^;Rh0:>SX`0208F5Q@0406m_K`1NGUh0GUiN06UYJ@80KFe]00D0L71`0820P02DU9@0U9BD
09:BTP0208Z:RP0508j>SP21PH40P8200820P01lO7`00P22PX801@2<S8`0Ti>C09>CT`2IVIT0UYJF
0080Shn?00D0TY:B09^KV`2KVi/0V9RH09FEU@0208f=S@0507=cL`1OGel0GemO05=CD`11@D400P1@
D500101VIVH0Ogmo07moO`2ATI420:RXZ0050;Jf]P2d];@0UiNG09NGU`2OWil00P2[Zj/01@2VYZH0
SXj>09RHV02HV9P0VYZJ0080UYJF00D0Ti>C0:ZZZP2ZZZX0/[:b09^KV`0209VIV@0509jNWP2MWId0
WIfM08n?S`2GUiL00P2DU9@01@2?Shl0QhN708N7Q`29RHT0PX:20080Ti>C00@0UYJF0:ZZZP2ZZZX0
^;Rh0P2l_;`01@2/[:`0];Bd0;bl_02l_;`0`l?30080f][J00D0lO7a0>[ZjP3GemL0emOG0=7Ad@02
0<?3``050:>SX`2GUiL0UiNG0:>SX`2KVi/00P2=SHd0102<S8`0RHV908V9R@1hN7P?0?ooo`003@3o
ool307MgM`050=GEe@1]KFd0KFe]08Z:RP21PH400P2i^KT0101dM7@0VYZJ09ZJVP2HV9P208B4Q005
08n?S`20P800UYJF09JFUP2j^[X00P1`L7001@2HV9P0P8200861P@21PH40Xj>S0080UYJF00D0Vi^K
08V9R@29RHT0WinO07EeM@0206m_K`050=KFeP1@D500D51@0<?3``1^KVh00P2l_;`01@2GUiL0D51@
051@D026QXH0XZ:R0080`<3000@0SXj>07YjNP1jNWX0QXJ60P2?Shl01@23Ph<0WYjN09VIV@2IVIT0
P8200080RHV900D0T92@0:n_[`25QHD0QHF509fMW@0208Z:RP0505EEE@3Rh^80h^;R05YJFP34a<@0
0P1gMgL01@21PH40OWin07inOP2`/;00UiNG0080NWYj00@0GUiN0=_Kf`3Kfm/0P8200P21PH401@2K
Vi/0WinO06e]K@1]KFd0VYZJ0080g=cL00D08B4Q0:j^[P2:RXX0RXZ:0;bl_00208B4Q00509NGU`1`
L700PH610861P@2UYJD00P2NWYh01@2ZZZX0;2`/02`/;03EeMD0Rh^;0080RHV900D0YZJV08n?S`2?
Shl0R8R806i^KP020:JVYP0409nOW`1cLg<0Lg=c09>CT`80[Zj^00D0TI6A07emO@1aLG40LG5a09ZJ
VP020:2PX00509VIV@2NWYh0P8200820P02FUYH00P21PH401@2QXJ40Ogmo09^KV`2KVi/0PX:20080
V9RH00D0QXJ60:6QX@2QXJ40RHV90:VYZ@0206YZJP0509fMW@2KVi/0Vi^K05ADE03Jf]X00P27QhL0
101lO7`0P8200820P02JVYX208Z:RP050:JVYP26QXH0TY:B09:BTP2;Rh/00P2KVi/00`2GUiL0oooo
0?ooo`080?ooo`0408>3P`2@T900T92@09NGU`80XJ6Q00D0Vi^K08^;R`23Ph<0Ph>307moO`0207em
O@0508^;R`2BTY80TY:B09JFUP2l_;`00P3=cLd01@3Fe]H0e=CD0=CDe03Ph>00_;bl0080WinO00@0
UIFE0:2PX02PX:00UiNG0P2CTi<01@2IVIT0Ph>306][J`1[Jf/0Fe]K0080GemO00D0K6a/07alO027
QhL0QhN709>CT`02092@T00508Z:RP1nOWh0QhN708N7Q`1nOWh00P1mOGd01@1oOgl0YJFU0:FUY@2a
/K40b/[:0080hN7Q00D0j^[Z0=3@d03@d=00^;Rh0:>SX`0208F5Q@0406m_K`1NGUh0GUiN06UYJ@80
KFe]00D0L71`0820P02DU9@0U9BD09:BTP0208Z:RP0508j>SP21PH40P8200820P01lO7`00P22PX80
1@2<S8`0Ti>C09>CT`2IVIT0UYJF0080Shn?00D0TY:B09^KV`2KVi/0V9RH09FEU@0208f=S@0507=c
L`1OGel0GemO05=CD`11@D400P1@D500101VIVH0Ogmo07moO`2ATI420:RXZ0050;Jf]P2d];@0UiNG
09NGU`2OWil00P2[Zj/01@2VYZH0SXj>09RHV02HV9P0VYZJ0080UYJF00D0Ti>C0:ZZZP2ZZZX0/[:b
09^KV`0209VIV@0509jNWP2MWId0WIfM08n?S`2GUiL00P2DU9@01@2?Shl0QhN708N7Q`29RHT0PX:2
0080Ti>C00@0UYJF0:ZZZP2ZZZX0^;Rh0P2l_;`01@2/[:`0];Bd0;bl_02l_;`0`l?30080f][J00D0
lO7a0>[ZjP3GemL0emOG0=7Ad@020<?3``050:>SX`2GUiL0UiNG0:>SX`2KVi/00P2=SHd0102<S8`0
RHV908V9R@1hN7P?0?ooo`003@3oool0101]KFd0O7al07alO03Bd]8207EeM@050861P@27QhL0^KVi
0;Vi^@1_Kfl00P2QXJ401@2>SXh0Shn?08n?S`28R8P0QXJ60080TY:B00D0^;Rh07IfMP1fMWH0V9RH
07QhN00208^;R`0409jNWP2GUiL0UiNG09ZJVP80RHV900D0Xj>S071`L01eMGD0MGEe0=7Ad@02055A
D@050<K6aP1WIfL0`/;20<;2`P2HV9P00P1<C4`01@2;Rh/0X:2P0;no_`2o_kl0TY:B0080MGEe00D0
QhN709:BTP2BTY80PX:209NGU`020::RXP0507alO02<S8`0S8b<08n?S`2/[:`00P28R8P0102KVi/0
SXj>08j>SP1ADE420>?Sh`0505YJFP32`/80N7Qh07QhN024Q8@00P1hN7P01@2a/K40WinO07=cL`1c
Lg<0IVIV0080cLg=00D0S8b<07QhN01hN7P0WinO0:6QX@0206UYJ@0509RHV03Ti>@0i>CT01TI6@2e
]KD00P29RHT01@2c/k<0SXj>08j>SP2EUID0MGEe0080NGUi00@0Zj^[09BDU02DU9@0]KFe0P0U9BD0
1@3Ph>00P82008f=S@2=SHd0XJ6Q0080UiNG00D0Rh^;06IVIP2RXZ80XZ:R0:RXZ002075aL@05092@
T02_[jl0[jn_09RHV01fMWH00P1cLg<00`2HV9P0W9bL09bLW00209nOW`80P82000D0TI6A08F5Q@25
QHD0X:2P08B4Q00209JFUP040861P@2LW9`0W9bL08F5Q@80XJ6Q00D0QhN70:^[Z`1/K6`0K6a/09bL
W00209RHV00505ADE03Ng]h0PH610861P@22PX800P1kNg/01@2IVIT0SXj>08j>SP2WYjL0PX:20080
UYJF00@0RHV909nOW`2OWil0V9RH2P3oool0102OWil0WIfM09fMW@2GUiL209nOW`050:b/[02c/k<0
];Bd0;Bd]02k^k/00P2^[Zh01@2IVIT0QhN708N7Q`23Ph<0NGUi0080P82000D0OWin09FEU@2EUID0
UiNG0:6QX@020;Bd]0040;bl_02`/;00/;2`0;:b/P80_;bl00D0[Zj^0;no_`33`l<0`l?30<C4a002
0;2`/0050:^[Z`2IVIT0W9bL09bLW02;Rh/00P24Q8@01@1bLW80NWYj06i^KP1^KVh0OWin0080RXZ:
00D0UYJF07YjNP1jNWX0NGUi07YjNP0206m_K`0506a/K023Ph<0Ph>308^;R`27QhL00P2KVi/0102T
Y:@0YJFU0:FUY@2VYZH20:f][@050:VYZ@2ZZZX0YjNW0:NWY`2QXJ400P2BTY801@28R8P0QXJ607mo
O`1oOgl0Q8B40080T92@00D0Rh^;08F5Q@25QHD0QhN708b<S00209>CT`0508n?S`2>SXh0SXj>09:B
TP2>SXh00P29RHT01@2RXZ80YjNW0:NWY`2c/k<0`L710080`l?300@0[Zj^0:VYZ@2YZJT0RXZ:0P1f
MWH01@1XJ6P0IfMW07YjNP1jNWX0PH610080OWin00D0QhN70:RXZ02QXJ40XJ6Q09bLW00209^KV`05
09NGU`24Q8@0Q8B407UiN@27QhL00P2ATI401@2=SHd0PX:208:2PP2;Rh/0V9RH0080UYJF00D0XJ6Q
0:JVYP2VYZH0Z:RX0:2PX00209>CT`0408f=S@2?Shl0Shn?09ZJVP80YjNW00D0_kno0;bl_02YZJT0
ZJVY092@T00206m_K`0505YJFP1NGUh0O7al07alO028R8P00P2IVIT01@2RXZ80YZJV0:JVYP2BTY80
Rh^;0080SHf=00@0V9RH09NGU`2GUiL0X:2P3`3oool000d0oooo00@0IVIV08>3P`23Ph<0clo?0P1g
MgL01@20P800RXZ:0;Fe]@2e]KD0L71`0080Xj>S00<0QHF509JFUP2FUYH00P26QXH209FEU@050;Vi
^@1cLg<0Lg=c09VIV@1_Kfl00P2GUiL0102IVIT0UIFE09FEU@2NWYh208R8R0050:>SX`1]KFd0Ng]k
07]kN`3=cLd00P1ADE401@37alL0I6AT0<;2`P32`/80VIVI0080Bd];00D0S8b<09nOW`2n_[h0_[jn
09>CT`0207IfMP0508R8R02DU9@0U9BD07moO`2HV9P00P2OWil01@1lO7`0Shn?08n?S`2=SHd0ZZZZ
0080Rh^;00@0VYZJ096AT@2ATI40C4a<0P3Vi^H01@1MGEd0^k^k07UiN@1iNGT0RHV90080Kfm_00D0
/k>c0:>SX`1cLg<0Lg=c06][J`020<;2`P0509>CT`1dM7@0M7Ad0::RXP2PX:000P1WIfL01@2JVYX0
i^KV0>KViP0G5aL0^KVi0080QXJ600D0ZZZZ09VIV@2IVIT0TI6A07]kN`0207AdM0040:VYZ@2ATI40
TI6A0;fm_@807alO00D0inOW07EeM@2CTi<0Ti>C09ZJVP0209nOW`05092@T01MGEd0WYjN09jNWP2`
/;000P1]KFd01@2ATI40[:b/0:b/[02NWYh0Lg=c0080LW9b00<0UiNG09jNWP2NWYh00P2OWil207mo
O`0508j>SP29RHT0RHV909nOW`26QXH00P2FUYH0101mOGd0WinO09nOW`22PX820:NWY`0508:2PP2[
Zj/0LW9b079bLP2EUID00P2LW9`01@1CDe<0g=cL08:2PP22PX80PH610080NWYj00D0VYZJ09>CT`2C
Ti<0WinO08N7Q`0209ZJVP040861P@2OWil0WinO09jNWPX0oooo00@0RHV908J6QP26QXH0Rh^;0P29
RHT01@1eMGD0Kfm_06i^KP1^KVh0J6QX0080KFe]00D0NGUi0820P020P800QhN707moO`0207YjNP05
07alO01mOGd0OGem08B4Q02<S8`00P26QXH01021PH40QHF508F5Q@1mOGd207MgM`0308n?S`27QhL0
Q8B40080Q8B40P2ATI401@20P800R8R807QhN01hN7P0RHV90080SXj>00D0Y:BT0:j^[P36a/H0a/K6
0;Ng]`020;Zj^P040;Ng]`2j^[X0^[Zj0;Rh^0<0_;bl00D0]KFe0;2`/02`/;00/[:b0;Vi^@020;>c
/`040;:b/P2f][H0][Jf0:f][@80W9bL00<0V9RH08R8R01jNWX00P1jNWX208>3P`0508R8R02JVYX0
X:2P0:2PX02QXJ400P2LW9`01@2SXj<0W9bL09bLW02FUYH0V9RH0080RXZ:00D0QhN708V9R@29RHT0
VIVI0:VYZ@020<30`0050;6a/@2d];@0];Bd09jNWP25QHD00P1^KVh0101jNWX0M7Ad07AdM02?Shl2
09nOW`050;>c/`2d];@0^;Rh0;Rh^02YZJT00P2PX:001@2@T900NGUi06e]K@1]KFd0M7Ad0080LW9b
00D0OGem09:BTP2BTY80VIVI09>CT`0209RHV00509>CT`2BTY80TY:B09^KV`2@T9000P2;Rh/01@26
QXH0P8200820P01gMgL0P8200080QhN700@0SHf=08R8R028R8P0Ng]k0P1YJFT01@1JFUX0GEeM06UY
J@1YJFT0MWIf0080Vi^K00D0Zj^[0;6a/@2TY:@0Y:BT0:FUY@0309jNWP80YjNW00D0]KFe0;bl_02^
[Zh0[Zj^0:6QX@02096AT@0309>CT`3oool0oooo00d0oooo000=0?ooo`0405eMG@2:RXX0RXZ:0<_;
b`80NGUi00D0OWin08f=S@2c/k<0/k>c06a/K0020:VYZ@0508>3P`2GUiL0UiNG08B4Q028R8P00P2I
VIT01@2b/[80MWIf07IfMP2HV9P0L71`0080VIVI00@0UIFE09NGU`2GUiL0W9bL0P2:RXX01@2RXZ80
K6a/07]kN`1kNg/0cLg=0080Cdm?00D0b/[:06=SH`32`/80`/;209RHV00204Y:BP0508j>SP2MWId0
`<300<30`02KVi/00P1[Jf/01@2;Rh/0UiNG09NGU`1lO7`0UiNG0080Xj>S00D0NWYj08n?S`2?Shl0
S8b<0:b/[00208Z:RP0409^KV`2EUID0UIFE04A4A080j^[Z00D0GUiN0;Rh^01kNg/0Ng]k08^;R`02
06UYJ@050;Fe]@2XZ:P0LW9b079bLP1`L7000P2j^[X00`2EUID0MWIf07IfMP020:6QX@80I6AT00D0
WinO0>7Qh@3QhN405aLG0;no_`0208N7Q`0509fMW@2RXZ80XZ:R08b<S022PX800P1bLW80102UYJD0
Shn?08n?S`38b<P201TI6@050>SXj01bLW80VIVI09VIV@2DU9@00P2UYJD01@2:RXX0G5aL09bLW02L
W9`0_;bl0080HV9R00D0UIFE0:^[Z`2[Zj/0XZ:R07EeM@0206YZJP0509ZJVP2QXJ40XJ6Q09^KV`2Q
XJ400P22PX801@27QhL0S8b<08b<S02NWYh0RHV90080UiNG00@0Ng]k09NGU`2GUiL0RXZ:0P2YZJT0
1@22PX80YJFU07QhN01hN7P0SXj>0080X:2P00D0F5QH0=3@d028R8P0R8R808B4Q00207IfMP0509VI
V@2DU9@0U9BD09jNWP2:RXX00P2JVYX0101lO7`0Xj>S0:>SX`2QXJ4:0?ooo`0408Z:RP2CTi<0Ti>C
09nOW`80Y:BT00D0_Kfm0<O7a`39bLT0bLW90<g=c@020<[:bP050;no_`2b/[80/[:b0:RXZ02WYjL0
0P2PX:001@2KVi/0VYZJ09ZJVP2HV9P0UYJF0080V9RH00@0UYJF08j>SP2>SXh0Ti>C0P2KVi/01@2M
WId0[jn_0<C4a034a<@0bLW90080a<C400D0a/K60<C4a03>c/h0c/k>0;jn_P020;Rh^0050:ZZZP2?
Shl0KVi^06i^KP1aLG400P1XJ6P01@1ZJVX0Lg=c07=cL`1hN7P0MWIf0080MgMg00D0N7Qh07UiN@1i
NGT0NGUi06m_K`0207=cL`0407MgM`1fMWH0MWIf07inOP80TY:B00D0UIFE09NGU`2KVi/0Vi^K09RH
V00209^KV`0509JFUP2;Rh/0SXj>08j>SP2:RXX00P23Ph<01@1nOWh0RXZ:08Z:RP2;Rh/0VIVI0080
Xj>S00D0WinO0:2PX02PX:00UYJF07inOP0206][J`0507MgM`1kNg/0Ng]k08B4Q02CTi<00P2QXJ40
102LW9`0XJ6Q0:6QX@2/[:`20:BTY0050::RXP2[Zj/0VIVI09VIV@2?Shl00P2KVi/01@2RXZ80VIVI
0:b/[02/[:`0ZJVY0080Zj^[00<0[:b/0:j^[P2^[Zh00P2PX:0209^KV`0509ZJVP2OWil0WinO0:^[
Z`2UYJD00P2^[Zh01@2XZ:P0[jn_0:n_[`2WYjL0[jn_0080WIfM00@0WYjN09^KV`2KVi/0X:2P0P2R
XZ801@2ZZZX0X:2P09FEU@2EUID0S8b<0080Ogmo00<0O7al0861P@2:RXX00P2:RXX208:2PP0508Z:
RP25QHD0QHF507IfMP1ZJVX00P1kNg/0101^KVh0MgMg07MgM`1fMWH?0?ooo`003@3oool0101MGEd0
RXZ:08Z:RP3;bl/207UiN@0507inOP2=SHd0/k>c0;>c/`1/K6`00P2YZJT01@23Ph<0UiNG09NGU`24
Q8@0R8R80080VIVI00D0/[:b07IfMP1fMWH0V9RH071`L00209VIV@0409FEU@2GUiL0UiNG09bLW080
RXZ:00D0XZ:R06a/K01kNg/0Ng]k0<g=c@0204m?C`050<[:bP1SHf<0`/;20<;2`P2HV9P00P1:BTX0
1@2>SXh0WIfM0<30`030`<00Vi^K0080Jf][00D0Rh^;09NGU`2GUiL0O7al09NGU`020:>SX`0507Yj
NP2?Shl0Shn?08b<S02/[:`00P2:RXX0102KVi/0UIFE09FEU@14A4@20>[ZjP0505iNGP2h^;P0Ng]k
07]kN`2;Rh/00P1YJFT01@2e]KD0Z:RX079bLP1bLW80L71`0080^[Zj00<0UIFE07IfMP1fMWH00P2Q
XJ4206ATI00509nOW`3QhN40hN7Q01LG5`2o_kl00P27QhL01@2MWId0XZ:R0::RXP2<S8`0PX:20080
LW9b00@0YJFU08n?S`2?Shl0b<S80P0I6AT01@3Xj>P0LW9b09VIV@2IVIT0U9BD0080YJFU00D0RXZ:
05aLG02LW9`0W9bL0;bl_002069RHP0509FEU@2[Zj/0Zj^[0::RXP1eMGD00P1ZJVX01@2JVYX0XJ6Q
0:6QX@2KVi/0XJ6Q0080PX:200D0QhN708b<S02<S8`0WYjN08V9R@0209NGU`0407]kN`2GUiL0UiNG
08Z:RP80ZJVY00D0PX:20:FUY@1hN7P0N7Qh08j>SP020:2PX00505QHF03@d=00R8R808R8R024Q8@0
0P1fMWH01@2IVIT0U9BD09BDU02NWYh0RXZ:0080VYZJ00@0O7al0:>SX`2SXj<0XJ6Q2P3oool0102:
RXX0Ti>C09>CT`2OWil20:BTY0050;fm_@37alL0bLW90<W9b@3=cLd00P3:b/X01@2o_kl0/[:b0;:b
/P2XZ:P0YjNW0080X:2P00D0Vi^K09ZJVP2JVYX0V9RH09JFUP0209RHV00409JFUP2>SXh0SXj>09>C
T`80Vi^K00D0WIfM0:n_[`34a<@0a<C40<W9b@020<C4a0050<K6aP34a<@0c/k>0<k>cP2n_[h00P2h
^;P01@2ZZZX0Shn?06i^KP1^KVh0LG5a0080J6QX00D0JVYZ07=cL`1cLg<0N7Qh07IfMP0207MgM`05
07QhN01iNGT0NGUi07UiN@1_Kfl00P1cLg<0101gMgL0MWIf07IfMP1nOWh209:BTP0509FEU@2GUiL0
Vi^K09^KV`2HV9P00P2KVi/01@2FUYH0Rh^;08j>SP2>SXh0RXZ:0080Ph>300D0OWin08Z:RP2:RXX0
Rh^;09VIV@020:>SX`0509nOW`2PX:00X:2P09JFUP1nOWh00P1[Jf/01@1gMgL0Ng]k07]kN`24Q8@0
Ti>C0080XJ6Q00@0W9bL0:6QX@2QXJ40[:b/0P2TY:@01@2RXZ80Zj^[09VIV@2IVIT0Shn?0080Vi^K
00D0XZ:R09VIV@2/[:`0[:b/0:VYZ@020:^[Z`030:b/[02^[Zh0[Zj^0080X:2P0P2KVi/01@2JVYX0
WinO09nOW`2[Zj/0YJFU0080[Zj^00D0Z:RX0:n_[`2_[jl0YjNW0:n_[`0209fMW@0409jNWP2KVi/0
Vi^K0:2PX080XZ:R00D0ZZZZ0:2PX02EUID0UIFE08b<S00207moO`0307alO021PH40RXZ:0080RXZ:
0P22PX801@2:RXX0QHF508F5Q@1fMWH0JVYZ0080Ng]k00@0KVi^07MgM`1gMgL0MWIf3`3oool000d0
oooo00@0F5QH092@T02@T900b<S80P1iNGT01@1oOgl0Shn?0;6a/@2a/K40JFUY0080[Zj^00D0OWin
09ZJVP2JVYX0P82008^;R`0209jNWP050:ZZZP1mOGd0OGem09>CT`1aLG400P2LW9`0102@T900UiNG
09NGU`2MWId208f=S@050:2PX01/K6`0Ogmo07moO`38b<P00P1?Cdl01@3;bl/0I6AT0;Zj^P2j^[X0
WinO0080AdM700D0Ti>C09jNWP2h^;P0^;Rh0:6QX@0206UYJ@0508f=S@2FUYH0UYJF07UiN@2KVi/0
0P2NWYh01@1mOGd0Shn?08n?S`2;Rh/0Zj^[0080SHf=0`2GUiL01@12@T80k>c/0>c/k01NGUh0][Jf
0080Ogmo00D0Rh^;06EUI@1UIFD0]kNg0:^[Z`0206e]K@0407MgM`2a/K40/K6a09BDU080OGem00D0
WYjN0::RXP1PH600H61P0:VYZ@020=OGe`0501dM7@30`<00RHV908V9R@2ATI400P2^[Zh01@20P800
TI6A06][J`1[Jf/0XJ6Q0080SXj>00D0dm?C018B4P0B4Q80k>c/06][J`0209fMW@0509:BTP2YZJT0
ZJVY08V9R@1KFe/00P2GUiL01036a/H0H61P061PH02EUID20:JVYP050:FUY@1kNg/0H61P061PH02M
WId00P2UYJD01@2FUYH0YJFU08N7Q`27QhL0N7Qh0080UiNG00D0Vi^K08j>SP2DU9@0U9BD0820P002
08j>SP05096AT@2[Zj/0Zj^[07inOP2SXj<00`22PX820:JVYP0505]KF`39bLT0RXZ:08Z:RP26QXH0
0P1cLg<01@2JVYX0V9RH09RHV02KVi/0SHf=0080VIVI00@0Ng]k09nOW`2OWil0Z:RX2P3oool0102?
Shl0OGem07emO@1iNGT206i^KP80F5QH0P1VIVH0101WIfL0Kfm_06m_K`23Ph<208^;R`0508n?S`2>
SXh0Ti>C09>CT`2@T9000P28R8P01@1iNGT0OGem07]kN`1kNg/0P8200080Rh^;00D0U9BD08V9R@29
RHT0N7Qh06e]K@02069RHP0506=SH`1eMGD0MGEe08:2PP1nOWh00P21PH401@29RHT0RXZ:08Z:RP2E
UID0WinO0080Y:BT00@0];Bd0;^k^`2k^k/0]kNg0P3>c/h01@3Cdm<0`/;20;Zj^P2j^[X0^k^k0080
YjNW00D0Xj>S0:n_[`2_[jl0[jn_0:j^[P020;2`/0050:ZZZP2IVIT0VIVI09FEU@2JVYX00P2KVi/3
0:>SX`050:NWY`2UYJD0YJFU0:FUY@2QXJ400P2ZZZX30;2`/0050:JVYP2NWYh0VIVI09VIV@2NWYh0
0P2MWId01@2PX:00[:b/0;Zj^P2j^[X0[:b/0080Xj>S00D0[Zj^0:b/[02SXj<0Xj>S0:6QX@0209VI
V@0507]kN`1hN7P0N7Qh06e]K@1^KVh00P26QXH01@2GUiL0Ti>C09>CT`2HV9P0Zj^[0080W9bL00@0
XZ:R0;:b/P2b/[80/[:b0P2SXj<01@2d];@0]KFe0:b/[02/[:`0/[:b0080/;2`00D0UIFE09:BTP25
QHD0QHF508>3P`0207alO00509:BTP2JVYX0ZJVY0:VYZ@2TY:@00P2XZ:P01@2OWil0Vi^K09^KV`2S
Xj<0Z:RX0080/;2`00D0`<300:b/[02/[:`0UIFE08F5Q@02075aL@0405iNGP1kNg/0Ng]k07emO@80
Rh^;00D0ZJVY0<71`@2a/K40/K6a0;Rh^0020;>c/`030:NWY`3oool0oooo00d0oooo000=0?ooo`04
05ADE02ATI40TI6A0<S8b080N7Qh00D0P82008j>SP2b/[80/[:b06UYJ@020:j^[P0507UiN@2LW9`0
W9bL08:2PP2:RXX00P2UYJD01@2OWil0Ph>308>3P`2ATI40M7Ad0080VIVI00@0T92@09FEU@2EUID0
XJ6Q0P2=SHd01@2NWYh0Kfm_0820P020P800a<C40080D51@00D0c<c<06YZJP2^[Zh0[Zj^0:VYZ@02
04=3@`0509BDU02UYJD0ZJVY0:VYZ@2[Zj/00P1XJ6P01@2?Shl0TI6A096AT@1kNg/0VYZJ0080WinO
00D0O7al092@T02@T900RXZ:0:f][@0208j>SP0409>CT`2NWYh0WYjN03`l?080k^k^00D0GemO0;>c
/`21PH40PH6108^;R`02069RHP050;Vi^@2][Jd0Jf][06][J`1gMgL00P2a/K401@2?Shl0QHF508F5
Q@2IVIT0Xj>S0080G5aL00D0/k>c0<g=c@3=cLd09BDU0;Zj^P0208f=S@0508N7Q`2l_;`0_;bl07Ad
M02KVi/00P1WIfL0102LW9`0TI6A096AT@3MgMd2010@40050>OWi`1YJFT0XZ:R0::RXP2?Shl00P2X
Z:P01@2;Rh/0FEUI09FEU@2EUID0bl_;0080GEeM00D0V9RH09jNWP2NWYh0Z:RX0861P@0205IFEP05
0:>SX`2VYZH0YZJV09:BTP2UYJD00P2=SHd01@1ZJVX0Y:BT0:BTY02DU9@0TY:B0080SHf=00@0S8b<
07emO@1mOGd0WinO0P2WYjL01@1lO7`0XZ:R08V9R@29RHT0MGEe0080/[:b00D0FUYJ0;fm_@2BTY80
TY:B08V9R@02071`L00509RHV02MWId0WIfM09bLW027QhL00P2OWil0101fMWH0X:2P0:2PX02/[:`:
0?ooo`040<O7a`3Jf]X0f][J0=;BdP80d=3@00<0f][J0<S8b02/[:`00P2/[:`20:f][@0309VIV@2X
Z:P0Z:RX0080^;Rh0P2[Zj/30:NWY`050:JVYP2FUYH0VYZJ09ZJVP2PX:000P2LW9`01@2EUID0YjNW
0:NWY`2WYjL0Xj>S0080V9RH00D0Shn?08>3P`23Ph<0S8b<09NGU`0309>CT`80Rh^;00@0Ng]k08b<
S02YZJT0ZJVY102PX:0207IfMP0506=SH`1^KVh0NWYj07YjNP1oOgl00P2DU9@01@2GUiL0VIVI09NG
U`2GUiL0U9BD0080SHf=00D0SXj>09:BTP2BTY80UiNG09^KV`020::RXP050:BTY02WYjL0YjNW0:NW
Y`2YZJT00P2_[jl0102[Zj/0XJ6Q0:6QX@2JVYX209VIV@0509ZJVP2OWil0WYjN09jNWP2PX:000P2K
Vi/01@2JVYX0UYJF08n?S`2?Shl0Rh^;0080RHV900D0MWIf06QXJ01]KFd0KFe]07emO@0209BDU005
09^KV`2TY:@0Y:BT0;2`/02b/[800P2WYjL01@2`/;00]KFe0;Fe]@2`/;00X:2P00<0WinO0P2GUiL0
1@28R8P0QXJ608J6QP1jNWX0KFe]0080JVYZ00D0L71`06m_K`1_Kfl0N7Qh08N7Q`0208n?S`0509BD
U02GUiL0UiNG08^;R`23Ph<00P1lO7`00`1nOWh0Ng]k07]kN`0308Z:RP030820P021PH40QXJ60080
QXJ60P2CTi<01@2][Jd0_[jn0<k>cP3>c/h0eMGE0080]kNg00D0Zj^[08n?S`2?Shl0LG5a059BDP02
06][J`0407inOP2BTY80TY:B0:NWY`l0oooo000=0?ooo`0405ADE02ATI40TI6A0<S8b080N7Qh00D0
P82008j>SP2b/[80/[:b06UYJ@020:j^[P0507UiN@2LW9`0W9bL08:2PP2:RXX00P2UYJD01@2OWil0
Ph>308>3P`2ATI40M7Ad0080VIVI00@0T92@09FEU@2EUID0XJ6Q0P2=SHd01@2NWYh0Kfm_0820P020
P800a<C40080D51@00D0c<c<06YZJP2^[Zh0[Zj^0:VYZ@0204=3@`0509BDU02UYJD0ZJVY0:VYZ@2[
Zj/00P1XJ6P01@2?Shl0TI6A096AT@1kNg/0VYZJ0080WinO00D0O7al092@T02@T900RXZ:0:f][@02
08j>SP0409>CT`2NWYh0WYjN03`l?080k^k^00D0GemO0;>c/`21PH40PH6108^;R`02069RHP050;Vi
^@2][Jd0Jf][06][J`1gMgL00P2a/K401@2?Shl0QHF508F5Q@2IVIT0Xj>S0080G5aL00D0/k>c0<g=
c@3=cLd09BDU0;Zj^P0208f=S@0508N7Q`2l_;`0_;bl07AdM02KVi/00P1WIfL0102LW9`0TI6A096A
T@3MgMd2010@40050>OWi`1YJFT0XZ:R0::RXP2?Shl00P2XZ:P01@2;Rh/0FEUI09FEU@2EUID0bl_;
0080GEeM00D0V9RH09jNWP2NWYh0Z:RX0861P@0205IFEP050:>SX`2VYZH0YZJV09:BTP2UYJD00P2=
SHd01@1ZJVX0Y:BT0:BTY02DU9@0TY:B0080SHf=00@0S8b<07emO@1mOGd0WinO0P2WYjL01@1lO7`0
XZ:R08V9R@29RHT0MGEe0080/[:b00D0FUYJ0;fm_@2BTY80TY:B08V9R@02071`L00509RHV02MWId0
WIfM09bLW027QhL00P2OWil0101fMWH0X:2P0:2PX02/[:`:0?ooo`040<O7a`3Jf]X0f][J0=;BdP80
d=3@00<0f][J0<S8b02/[:`00P2/[:`20:f][@0309VIV@2XZ:P0Z:RX0080^;Rh0P2[Zj/30:NWY`05
0:JVYP2FUYH0VYZJ09ZJVP2PX:000P2LW9`01@2EUID0YjNW0:NWY`2WYjL0Xj>S0080V9RH00D0Shn?
08>3P`23Ph<0S8b<09NGU`0309>CT`80Rh^;00@0Ng]k08b<S02YZJT0ZJVY102PX:0207IfMP0506=S
H`1^KVh0NWYj07YjNP1oOgl00P2DU9@01@2GUiL0VIVI09NGU`2GUiL0U9BD0080SHf=00D0SXj>09:B
TP2BTY80UiNG09^KV`020::RXP050:BTY02WYjL0YjNW0:NWY`2YZJT00P2_[jl0102[Zj/0XJ6Q0:6Q
X@2JVYX209VIV@0509ZJVP2OWil0WYjN09jNWP2PX:000P2KVi/01@2JVYX0UYJF08n?S`2?Shl0Rh^;
0080RHV900D0MWIf06QXJ01]KFd0KFe]07emO@0209BDU00509^KV`2TY:@0Y:BT0;2`/02b/[800P2W
YjL01@2`/;00]KFe0;Fe]@2`/;00X:2P00<0WinO0P2GUiL01@28R8P0QXJ608J6QP1jNWX0KFe]0080
JVYZ00D0L71`06m_K`1_Kfl0N7Qh08N7Q`0208n?S`0509BDU02GUiL0UiNG08^;R`23Ph<00P1lO7`0
0`1nOWh0Ng]k07]kN`0308Z:RP030820P021PH40QXJ60080QXJ60P2CTi<01@2][Jd0_[jn0<k>cP3>
c/h0eMGE0080]kNg00D0Zj^[08n?S`2?Shl0LG5a059BDP0206][J`0407inOP2BTY80TY:B0:NWY`l0
oooo000=0?ooo`0405=CD`2BTY80TY:B0<K6aP80N7Qh00D0PH6108f=S@2b/[80/[:b06i^KP020:^[
Z`0507QhN02MWId0WIfM0820P02;Rh/00P2ZZZX01@2HV9P0QhN708N7Q`2<S8`0NWYj0080UIFE00@0
UYJF09:BTP2BTY80Xj>S0P27QhL01@2PX:00L71`08>3P`23Ph<0`<300080Cdm?00D0cLg=06m_K`2U
YJD0YJFU0:b/[00204=3@`0509ZJVP2TY:@0XJ6Q0:6QX@2`/;000P1WIfL01@2BTY80S8b<08b<S020
P800Vi^K0080VYZJ00D0Ogmo092@T02@T900RXZ:0;2`/00208V9R@0409FEU@2NWYh0WYjN03Xj>P80
lO7a00D0GEeM0;Jf]P20P800P82008j>SP0205iNGP050;Zj^P2][Jd0K6a/06a/K01gMgL00P2`/;00
1@2;Rh/0T92@092@T02DU9@0XJ6Q0080GEeM00D0^;Rh0<K6aP36a/H0;bl_0:j^[P0209RHV00507al
O039bLT0bLW906IVIP2RXZ800P1YJFT0102BTY80V9RH09RHV03Rh^8200/;2`050>?Sh`1`L700WinO
09nOW`2@T9000P2UYJD01@2<S8`0FUYJ09>CT`2CTi<0d];B0080EUIF00D0WIfM09JFUP2FUYH0Z:RX
08f=S@0204Y:BP<0YjNW00D0TY:B0::RXP2CTi<0Ti>C06EUI@020:VYZ@05092@T02DU9@0Rh^;08^;
R`2DU9@00P1cLg<01@2WYjL0XJ6Q0:6QX@20P800Xj>S0080QhN700D0LW9b0;Ng]`2g]kL0GEeM0:n_
[`0209fMW@0408N7Q`1_Kfl0Kfm_09RHV080X:2P00D0UiNG08N7Q`2TY:@0Y:BT075aL@020:2PX003
0:j^[P3oool0oooo00P0oooo00@0EeMG04m?C`1?Cdl0Fe]K0P1YJFT01@1_Kfl0PH6109JFUP2FUYH0
Ti>C0080Rh^;00D0TY:B08:2PP22PX80KFe]07=cL`0208V9R@05092@T02KVi/0Vi^K0:f][@2n_[h0
0P2e]KD0102^[Zh0[:b/0:b/[02TY:@2096AT@0509>CT`2JVYX0X:2P0:2PX02YZJT00P2][Jd01@2H
V9P0RXZ:08b<S02<S8`0Q8B40080WYjN00D0[Zj^09fMW@2;Rh/0Rh^;09BDU00207alO00507EeM@2@
T900T92@09JFUP2BTY800P2=SHd01@2ATI40Ph>308>3P`27QhL0Ng]k0080L71`00@0Jf][06YZJP1Z
JVX0Hf=S0P1TI6@01@1/K6`0L71`07YjNP1jNWX0Ph>30080R8R800@0QhN708R8R01iNGT0NGUi0`1a
LG401@1^KVh0J6QX06QXJ01bLW80MgMg0080PH6100D0SXj>09RHV02HV9P0Vi^K09fMW@020:JVYP05
0:b/[02f][H0][Jf0<S8b03EeMD00P3@d=001033`l<0/;2`0;2`/02][Jd20:j^[P0509bLW02;Rh/0
OWin07inOP1[Jf/00P1NGUh01@1VIVH0Lg=c08^;R`2;Rh/0Shn?0080RXZ:00D0SXj>09NGU`2GUiL0
UiNG0::RXP030:j^[P80/;2`00D0^KVi0;Bd]02[Zj/0Zj^[0:ZZZP020:FUY@0508f=S@1lO7`0PX:2
08:2PP27QhL00P2BTY801@2IVIT0YZJV0:JVYP2`/;00[Zj^0080XJ6Q00@0UIFE09VIV@2IVIT0Shn?
0`23Ph<0102=SHd0WIfM09fMW@2UYJD20;jn_P050<c<c03WinL0c<c<0<c<c02b/[800P2DU9@00`1k
Ng/0oooo0?ooo`0=0?ooo`003@3oool0101=CDd0UIFE09FEU@36a/H207YjNP0507moO`2?Shl0/[:b
0;:b/P1[Jf/00P2][Jd01@1jNWX0VIVI09VIV@1lO7`0T92@0080[jn_0`2>SXh01@29RHT0OWin092@
T02@T900UiNG0080TY:B00D0YjNW07moO`1oOgl0YjNW075aL@020820P0050;jn_P1=CDd0CDe=0<k>
cP1cLg<00P2NWYh01@2b/[80@D510451@@2LW9`0YZJV0080W9bL00<0]KFe06ATI01TI6@00`2>SXh0
1@27QhL0UIFE09bLW02LW9`0OWin0080Shn?00D0Rh^;0;6a/@29RHT0RHV909FEU@0209bLW00503/k
>`3dm?@0m?Cd05YJFP2g]kL00P1nOWh01@2ATI40G5aL05aLG02i^KT0[Zj^0080KVi^00@0N7Qh0:b/
[02/[:`0RXZ:0P2GUiL01@2?Shl0XJ6Q05mOG`1OGel0^;Rh0080`<3000D0>CTi0::RXP2TY:@0Y:BT
079bLP020=CDe00505aLG02TY:@0LG5a075aL@26QXH00P2NWYh01@3Zj^X01PH600H61P3Ng]h0M7Ad
0080X:2P00D0SXj>0:JVYP2VYZH0SXj>05MGE`0209JFUP040=KFeP1BDU80DU9B09fMW@80SXj>00D0
ZZZZ09RHV011@D40@D510:VYZ@020:NWY`0509:BTP2QXJ40UYJF09JFUP1VIVH00P2VYZH2096AT@80
S8b<00@0V9RH06e]K@1]KFd0/;2`0P2EUID01@2<S8`0Vi^K08R8R028R8P0M7Ad0080]kNg00D0HF5Q
09nOW`2YZJT0ZJVY08V9R@0206e]K@0509RHV02MWId0WIfM09ZJVP26QXH00P2YZJT0101YJFT0YZJV
0:JVYP2_[jl:0?ooo`040=CDe03IfMT0fMWI0=?Cd`80`<3000D0/[:b0;Ng]`2f][H0][Jf0;Ng]`02
0;Jf]P050;Vi^@2][Jd0[Jf]0:f][@2NWYh00P2BTY801@28R8P0Ph>308>3P`1^KVh0Hf=S0080J6QX
00@0K6a/06][J`1[Jf/0M7Ad0P29RHT0102TY:@0Xj>S0:RXZ02XZ:P30:NWY`050:>SX`2b/[80/K6a
0;6a/@35aLD00P30`<020;^k^`80_;bl00@0YZJV0:RXZ02XZ:P0]KFe0P2LW9`01@2PX:00Xj>S0:FU
Y@2UYJD0Ti>C0080ZJVY00D0YjNW0;2`/034a<@0a<C40<k>cP020<o?c`050=;BdP3@d=00d=3@0;Rh
^02SXj<00P2@T9001@1oOgl0M7Ad07AdM01oOgl0QHF50080T92@00@0YjNW0;Bd]02d];@0^KVi0P36
a/H01@31`L40[jn_09nOW`2OWil0UIFE0080QXJ600D0P82008:2PP1oOgl0Ogmo07emO@0207YjNP05
06i^KP1TI6@0GemO05mOG`1HF5P00P1UIFD01@1cLg<0OGem07emO@2MWId0][Jf0080aLG500D0d];B
0=CDe03De=@0c<c<0<30`0020:NWY`<0YJFU00@0Xj>S09nOW`2OWil0WIfM0`2GUiL01@2?Shl0QXJ6
08J6QP1nOWh0MgMg0080QHF500D0Shn?09ZJVP2JVYX0/K6a0<C4a0020;Rh^0040:j^[P2JVYX0VYZJ
08b<S080OGem00D0Kfm_06IVIP1fMWH0MWIf08>3P`0208J6QP0508f=S@2KVi/0T92@092@T024Q8@0
0P1oOgl01@25QHD0Lg=c07=cL`1^KVh0HF5Q0080K6a/00@0Ng]k09bLW02LW9`0][Jf3`3oool000d0
oooo00@0CDe=09FEU@2EUID0a/K60P1jNWX01@1oOgl0Shn?0;:b/P2b/[80Jf][0080[Jf]00D0NWYj
09VIV@2IVIT0O7al092@T0020:n_[`<0SXj>00D0RHV907inOP2@T900T92@09NGU`0209:BTP050:NW
Y`1oOgl0Ogmo0:NWY`1aLG400P20P8001@2n_[h0CDe=04e=C@3>c/h0Lg=c0080WYjN00D0/[:b0451
@@11@D40W9bL0:JVYP0209bLW0030;Fe]@1TI6@0I6AT00<0SXj>00D0QhN709FEU@2LW9`0W9bL07in
OP0208n?S`0508^;R`2a/K40RHV908V9R@2EUID00P2LW9`01@0k>c/0m?Cd0?Cdm01JFUX0]kNg0080
OWin00D0TI6A05aLG01LG5`0^KVi0:j^[P0206i^KP0407QhN02/[:`0[:b/08Z:RP80UiNG00D0Shn?
0:6QX@1OGel0GemO0;Rh^0020<30`00503Ti>@2RXZ80Y:BT0:BTY01bLW800P3De=@01@1LG5`0Y:BT
075aL@1aLG40QXJ60080WYjN00D0j^[Z00H61P061PH0g]kN07AdM0020:2PX00508j>SP2VYZH0YZJV
08j>SP1GEeL00P2FUYH0103Fe]H0DU9B059BDP2MWId208j>SP050:ZZZP2HV9P0@D510451@@2YZJT0
0P2WYjL01@2BTY80XJ6Q09JFUP2FUYH0IVIV0080YZJV0P2ATI4208b<S00409RHV01]KFd0KFe]0;2`
/080UIFE00D0S8b<09^KV`28R8P0R8R807AdM0020;Ng]`05065QH@2OWil0ZJVY0:VYZ@29RHT00P1]
KFd01@2HV9P0WIfM09fMW@2JVYX0QXJ60080ZJVY00@0JFUY0:JVYP2VYZH0[jn_2P3oool0103De=@0
fMWI0=WIf@3Cdm<20<30`0050;:b/P2g]kL0][Jf0;Jf]P2g]kL00P2f][H01@2i^KT0[Jf]0:f][@2]
[Jd0WYjN0080TY:B00D0R8R808>3P`23Ph<0KVi^06=SH`0206QXJ00406a/K01[Jf/0Jf][07AdM080
RHV900@0Y:BT0:>SX`2XZ:P0Z:RX0`2WYjL01@2SXj<0/[:b0;6a/@2a/K40aLG50080`<300P2k^k/2
0;bl_0040:JVYP2XZ:P0Z:RX0;Fe]@80W9bL00D0X:2P0:>SX`2UYJD0YJFU09>CT`020:VYZ@050:NW
Y`2`/;00a<C40<C4a03>c/h00P3?cll01@3Bd]80d=3@0=3@d02h^;P0Xj>S0080T92@00D0Ogmo07Ad
M01dM7@0Ogmo08F5Q@02092@T0040:NWY`2d];@0];Bd0;Vi^@80a/K600D0`L710:n_[`2OWil0WinO
09FEU@0208J6QP050820P022PX80Ogmo07moO`1mOGd00P1jNWX01@1^KVh0I6AT05mOG`1OGel0F5QH
0080IFEU00D0Lg=c07emO@1mOGd0WIfM0;Jf]P020<G5a@050=;BdP3De=@0e=CD0<c<c030`<000P2W
YjL30:FUY@040:>SX`2OWil0WinO09fMW@<0UiNG00D0Shn?08J6QP26QXH0OWin07MgM`0208F5Q@05
08n?S`2JVYX0VYZJ0;6a/@34a<@00P2h^;P0102^[Zh0VYZJ09ZJVP2<S8`207emO@0506m_K`1VIVH0
MWIf07IfMP23Ph<00P26QXH01@2=SHd0Vi^K092@T02@T900Q8B40080Ogmo00D0QHF507=cL`1cLg<0
KVi^065QH@0206a/K00407]kN`2LW9`0W9bL0;Jf]Pl0oooo000=0?ooo`0404e=C@2EUID0UIFE0<G5
a@80NWYj00D0Ogmo08n?S`2`/;00/;2`071`L0020:ZZZP0507UiN@2HV9P0V9RH07emO@2@T9000P2d
];@01@25QHD0UIFE09FEU@25QHD0PH610080SHf=00@0VYZJ096AT@2ATI40YZJV0P1lO7`01@2/[:`0
M7Ad08:2PP22PX80]KFe0080D51@00D0c/k>07UiN@2GUiL0UiNG0;Vi^@0203dm?@0509jNWP2ZZZX0
U9BD09BDU02e]KD00P1YJFT01@2=SHd0RXZ:08Z:RP2<S8`0T92@0080Vi^K00D0Ph>308f=S@2=SHd0
S8b<0:n_[`0208N7Q`0409BDU02NWYh0WYjN03`l?080lo?c00D0FUYJ0;Fe]@1oOgl0Ogmo09:BTP02
05iNGP050;Jf]P2_[jl0L71`071`L01iNGT00P2RXZ801@2CTi<0UYJF09JFUP2@T900W9bL0080IVIV
00D0/k>c0;jn_P2n_[h0@41009BDU0020:n_[`0506m_K`3MgMd0gMgM059BDP2VYZH00P1dM7@0101o
Ogl0WYjN09jNWP3clo<200<30`050=[JfP1hN7P0WIfM09fMW@2=SHd00P2WYjL01@2@T900De=C09RH
V02HV9P0emOG0080E5AD00D0V9RH08Z:RP2:RXX0[Jf]0::RXP0203Xj>P050:ZZZP2VYZH0YZJV09>C
T`2OWil00P2JVYX01@1YJFT0WYjN09jNWP2GUiL0Rh^;0080SHf=00@0V9RH07AdM01dM7@0[jn_0P2>
SXh01@2BTY80VYZJ08J6QP26QXH0Lg=c0080^k^k00D0IFEU092@T02b/[80/[:b08V9R@0206i^KP05
09BDU02TY:@0Y:BT09>CT`27QhL00P2[Zj/0101YJFT0X:2P0:2PX02d];@:0?ooo`0406e]K@1QHF40
HF5Q061PH080Hf=S00D0GemO055AD@11@D40@D5104A4A002051@D00505UIF@1`L700L71`08>3P`2K
Vi/00P2OWil01@2VYZH0Xj>S0:>SX`2][Jd0[jn_0080^KVi00@0b<S80<_;b`3;bl/0dM7A0P2j^[X0
1@2CTi<0O7al07EeM@1eMGD0IVIV0080FEUI00D0I6AT05ADE01?Cdl0Cdm?04M7A`020451@@0504=3
@`1;Bd/0BDU904U9B@15ADD00P1BDU801@15ADD0G5aL05aLG01RHV80Lg=c0080PX:200D0UIFE08n?
S`2?Shl0T92@096AT@0208V9R@0408J6QP25QHD0QHF508f=S@80Ti>C00D0Xj>S0;6a/@2i^KT0^KVi
0<K6aP020<G5a@050;Fe]@2/[:`0WIfM09fMW@27QhL00`1mOGd206m_K`0507YjNP2:RXX0Shn?08n?
S`2:RXX00P2?Shl01@2:RXX0Ph>307moO`1oOgl0RHV90080S8b<00D0TY:B09NGU`2VYZH0YZJV0:b/
[0020:>SX`0509RHV02=SHd0SHf=06i^KP1PH6000P1IFET01@1CDe<0FEUI05UIF@1QHF40IfMW0080
Ogmo00@0QXJ608b<S02<S8`0TY:B0P2EUID01@2BTY80TI6A08J6QP26QXH0RXZ:0080SXj>00D0S8b<
09FEU@2IVIT0VIVI08f=S@0208V9R@0508n?S`1nOWh0RHV908V9R@2JVYX00P2RXZ801@2VYZH0a<C4
0<C4a031`L40dM7A0080clo?00D0a<C40;Bd]02d];@0_;bl0:JVYP020:VYZ@040;Jf]P2d];@0];Bd
0:6QX@80ZJVY00D0Z:RX0:2PX02QXJ40XJ6Q09RHV00208R8R00307YjNP3oool0oooo00d0oooo000=
0?ooo`04051@D02BTY80TY:B0<G5a@80Ng]k00D0PX:208f=S@2`/;00/;2`07EeM@020:FUY@0507Qh
N02IVIT0VIVI07moO`2@T9000P2i^KT01@1kNg/0Vi^K09^KV`24Q8@0PX:20080RXZ:00@0WIfM08n?
S`2?Shl0Zj^[0P1bLW801@2d];@0LW9b08B4Q024Q8@0[Jf]0080EUIF00D0bLW907inOP2DU9@0U9BD
0;^k^`0203Xj>P050:2PX02UYJD0VIVI09VIV@2`/;000P1/K6`01@2<S8`0RXZ:08Z:RP2DU9@0QHF5
0080X:2P00D0PX:208j>SP2>SXh0S8b<0:n_[`0208J6QP0409JFUP2OWil0WinO03Xj>P80l_;b00D0
GUiN0;:b/P1mOGd0OGem09>CT`02061PH0050;:b/P2a/K40LG5a075aL@1kNg/00P2JVYX01@2HV9P0
UYJF09JFUP2CTi<0TI6A0080LG5a00D0[jn_0;Jf]P2f][H0CDe=08J6QP020;Zj^P0506e]K@3QhN40
hN7Q04i>CP2OWil00`1kNg/209fMW@050?[jnP020P800P820=OGe`1gMgL00P2MWId01@2<S8`0ZZZZ
0:ZZZP2@T900DU9B0080W9bL00@0e]KF05EEE@1EEED0TI6A0P2;Rh/01@2`/;00YJFU03Ph>00h>3P0
YjNW0080YZJV00D0Ti>C09nOW`2LW9`0W9bL079bLP02092@T00509bLW027QhL0T92@092@T02DU9@0
0P1gMgL01@2a/K40Ph>308>3P`2OWil0UiNG0080P82000D0NGUi0;bl_02l_;`0J6QX08:2PP020;bl
_00408R8R01`L700L71`096AT@80YjNW00D0SHf=08b<S02YZJT0ZJVY06UYJ@0209nOW`030;Fe]@3o
ool0oooo00P0oooo00@0Y:BT0:NWY`2WYjL0Xj>S0P2a/K401@34a<@0b/[:0=WIf@3IfMT0iNGU0080
h^;R00D0d=3@0<S8b038b<P0^[Zj09>CT`0208>3P`0508Z:RP2@T900T92@09NGU`2SXj<00P2HV9P0
101oOgl0LW9b079bLP1WIfL207emO@0509FEU@2c/k<0a<C40<C4a03?cll00P3@d=001@3<c<`0dM7A
0>3Ph03Ph>00f=SH0080e=CD0P3MgMd20>7Qh@030?clo03oool0oooo00<0oooo00D0n?Sh0=gMg@33
`l<0`l?30:f][@0209BDU080RXZ:0`27QhL209NGU`0509JFUP2ATI40TI6A09>CT`2BTY800P2@T900
1@23Ph<0P8200820P023Ph<0RHV90080Shn?00@0WYjN0:>SX`2SXj<0Xj>S0P2WYjL01@2RXZ80Vi^K
09nOW`2OWil0X:2P0080WinO00D0Vi^K0:2PX02SXj<0Xj>S0:BTY00209fMW@050:ZZZP2b/[80[:b/
0:b/[02[Zj/00P2b/[801@2a/K40X:2P0:2PX02RXZ80UIFE0080TY:B00D0RXZ:08>3P`23Ph<0P820
096AT@0208b<S00408>3P`2=SHd0SHf=08j>SP80Ph>300D0RXZ:09>CT`2HV9P0V9RH09ZJVP020:NW
Y`050:6QX@2UYJD0WYjN09jNWP2][Jd00P2WYjL01@2d];@0^KVi0;Zj^P2j^[X0YjNW0080XZ:R00D0
VYZJ07YjNP1jNWX0O7al06m_K`0206][J`0506QXJ01PH600H61P03lo?`13@d<00P19BDT0101;Bd/0
I6AT06ATI024Q8@209>CT`050:>SX`2YZJT0Zj^[0:^[Z`2h^;P00P2b/[800`2WYjL0oooo0?ooo`0=
0?ooo`003@3oool0101HF5P0S8b<08b<S036a/H207]kN`0508:2PP2<S8`0[jn_0:n_[`1fMWH00P2T
Y:@01@1kNg/0V9RH09RHV01hN7P0VIVI0080]KFe00D0N7Qh0:6QX@2QXJ40PH6108:2PP0208^;R`04
09jNWP2=SHd0SHf=0:f][@80Jf][00D0_Kfm06e]K@28R8P0R8R80:^[Z`0205YJFP050<71`@22PX80
UYJF09JFUP2j^[X00P0m?Cd01@2LW9`0YJFU09nOW`2OWil0Z:RX0080LW9b00D0RHV908^;R`2;Rh/0
UIFE08B4Q00209jNWP0508:2PP2@T900T92@08^;R`2`/;000P23Ph<0102HV9P0WYjN09jNWP0l?3`2
0?3`l005061PH02c/k<0Ng]k07]kN`2CTi<00P1TI6@01@2`/;00[Jf]07EeM@1eMGD0OGem0080Ti>C
00D0WYjN09JFUP2FUYH0UIFE08V9R@0207moO`050:RXZ02_[jl0[jn_05EEE@20P8000P30`<001@1/
K6`0hn?S0>?Sh`1;Bd/0Vi^K0080QHF500@0MGEe09^KV`2KVi/0o_kn0P0000001@3IfMT0M7Ad09nO
W`2OWil0Rh^;0080ZZZZ00D0T92@055AD@2PX:00X:2P0=;BdP0205eMG@0508>3P`2CTi<0Ti>C0:f]
[@2YZJT00P0j>SX01@2PX:00YZJV0:JVYP2@T900YJFU0080WinO00D0M7Ad08>3P`23Ph<0YJFU08B4
Q00209FEU@0408^;R`21PH40PH610:^[Z`80Ogmo00D0[:b/096AT@1iNGT0NGUi08B4Q0020;2`/005
07=cL`1gMgL0aLG50<G5a@24Q8@00P1iNGT01@2:RXX0Zj^[0:^[Z`28R8P0TY:B0080Y:BT00@0JFUY
09nOW`2OWil0/k>c2P3oool0102KVi/0Y:BT0:BTY02b/[820:f][@050::RXP2QXJ40WIfM09fMW@25
QHD00P1fMWH30820P0050861P@2KVi/0YJFU0:FUY@2EUID00P25QHD01@1aLG40H61P06a/K01/K6`0
L71`0080NWYj00D0NGUi06][J`1[Jf/0GEeM05ADE00204];B`0505ADE01]KFd0KFe]07moO`2GUiL0
0P2CTi<309nOW`0508V9R@1aLG40IVIV06IVIP1GEeL00P1;Bd/01@15ADD0Cdm?04m?C`1HF5P0GemO
0080Jf][00D0Ph>309RHV02HV9P0XJ6Q09>CT`0208^;R`040861P@1]KFd0KFe]07MgM`80QHF500<0
S8b<08N7Q`2;Rh/00P2;Rh/209FEU@0509NGU`2NWYh0X:2P0:2PX02OWil00P2EUID01@2KVi/0VIVI
09VIV@2OWil0WIfM00<0Xj>S0P2QXJ401@2FUYH0T92@08N7Q`27QhL0P8200080U9BD00D0TY:B09JF
UP2KVi/0Vi^K0:2PX00209FEU@0509NGU`2VYZH0YZJV0;:b/P37alL00P3Bd]801@3QhN40i^KV0>KV
iP3Rh^80`/;20080/;2`00@0YjNW09:BTP2BTY80QXJ60P2?Shl01@2CTi<0UYJF09bLW02LW9`0XJ6Q
0080Ti>C00D0TI6A08n?S`29RHT0RHV908N7Q`0209VIV@05096AT@25QHD0SXj>08j>SP2<S8`00P2?
Shl01@2<S8`0Y:BT0:BTY02PX:00WinO0080VIVI00D0[Jf]0<?3``33`l<0hn?S0?Gem@020?Ogm`04
0>7Qh@34a<@0a<C40:^[Z`80WYjN00D0RXZ:09jNWP2GUiL0UiNG08V9R@0208b<S00309jNWP3oool0
oooo00d0oooo000=0?ooo`0405QHF02<S8`0S8b<0<K6aP80Ng]k00D0PX:208b<S02_[jl0[jn_07If
MP020:BTY00507]kN`2HV9P0V9RH07QhN02IVIT00P2e]KD01@1hN7P0XJ6Q0:6QX@21PH40PX:20080
Rh^;00@0WYjN08f=S@2=SHd0[Jf]0P1[Jf/01@2m_Kd0KFe]08R8R028R8P0Zj^[0080FUYJ00D0`L71
08:2PP2FUYH0UYJF0;Zj^P0203dm?@0509bLW02UYJD0WinO09nOW`2XZ:P00P1bLW801@29RHT0Rh^;
08^;R`2EUID0Q8B40080WYjN00D0PX:2092@T02@T900Rh^;0;2`/00208>3P`0409RHV02NWYh0WYjN
03`l?080l?3`00D0H61P0;>c/`1kNg/0Ng]k09>CT`0206ATI0050;2`/02][Jd0MGEe07EeM@1mOGd0
0P2CTi<01@2NWYh0UYJF09JFUP2EUID0RHV90080Ogmo00D0Z:RX0:n_[`2_[jl0EEEE0820P0020<30
`00506a/K03Shn<0hn?S04];B`2KVi/00P25QHD0101eMGD0Vi^K09^KV`3no_h2000000050=WIf@1d
M7@0WinO09nOW`2;Rh/00P2ZZZX01@2@T900DE5A0:2PX02PX:00d];B0080GEeM00D0Ph>309>CT`2C
Ti<0[Jf]0:VYZ@0203Xj>P050:2PX02VYZH0YZJV092@T02UYJD00P2OWil01@1dM7@0Ph>308>3P`2U
YJD0Q8B40080UIFE00@0Rh^;0861P@21PH40Zj^[0P1oOgl01@2/[:`0TI6A07UiN@1iNGT0Q8B40080
/;2`00D0Lg=c07MgM`35aLD0aLG508B4Q00207UiN@0508Z:RP2[Zj/0Zj^[08R8R02BTY800P2TY:@0
101YJFT0WinO09nOW`2c/k<:0?ooo`0409^KV`2TY:@0Y:BT0;:b/P80[Jf]00D0XZ:R0:6QX@2MWId0
WIfM08F5Q@0207IfMP<0P82000D0PH6109^KV`2UYJD0YJFU09FEU@0208F5Q@05075aL@1PH600K6a/
06a/K01`L7000P1jNWX01@1iNGT0Jf][06][J`1MGEd0E5AD0080Bd];00D0E5AD06e]K@1]KFd0Ogmo
09NGU`0209>CT`<0WinO00D0RHV9075aL@1VIVH0IVIV05MGE`0204];B`0504E5A@1?Cdl0Cdm?05QH
F01OGel00P1[Jf/01@23Ph<0V9RH09RHV02QXJ40Ti>C0080Rh^;00@0PH6106e]K@1]KFd0MgMg0P25
QHD00`2<S8`0QhN708^;R`0208^;R`80UIFE00D0UiNG09jNWP2PX:00X:2P09nOW`0209FEU@0509^K
V`2IVIT0VIVI09nOW`2MWId00`2SXj<20:6QX@0509JFUP2@T900QhN708N7Q`20P8000P2DU9@01@2B
TY80UYJF09^KV`2KVi/0X:2P0080UIFE00D0UiNG0:JVYP2VYZH0/[:b0<O7a`020=;BdP050>7Qh@3V
i^H0i^KV0>;RhP32`/800P2`/;00102WYjL0TY:B09:BTP26QXH208n?S`0509>CT`2FUYH0W9bL09bL
W02QXJ400P2CTi<01@2ATI40Shn?08V9R@29RHT0QhN70080VIVI00D0TI6A08F5Q@2>SXh0SXj>08b<
S00208n?S`0508b<S02TY:@0Y:BT0:2PX02OWil00P2IVIT01@2][Jd0`l?30<?3``3Shn<0mOGe0080
moOg00@0hN7Q0<C4a034a<@0Zj^[0P2NWYh01@2:RXX0WYjN09NGU`2GUiL0RHV90080S8b<00<0WYjN
0?ooo`3oool03@3oool000d0oooo00@0G5aL08V9R@29RHT0aLG50P1lO7`01@23Ph<0RHV90;2`/02`
/;00MGEe0080XZ:R00D0OWin09NGU`2GUiL0MgMg09nOW`020:n_[`0507IfMP2XZ:P0Z:RX08:2PP1j
NWX00P2ATI40102LW9`0Rh^;08^;R`2b/[8206MWI`050<71`@1]KFd0Ph>308>3P`2/[:`00P1OGel0
1@2j^[X0QhN709:BTP2BTY80_kno0080>SXj00D0VIVI0:^[Z`2KVi/0Vi^K0:FUY@0207YjNP0508F5
Q@2:RXX0RXZ:09>CT`25QHD00P2RXZ801@20P800TY:B09:BTP2:RXX0[jn_0080QXJ600@0V9RH09ZJ
VP2JVYX0@T920P3Zj^X01@1SHf<0/[:b07alO01lO7`0TI6A0080J6QX00D0Zj^[0;6a/@1eMGD0MGEe
07inOP0208n?S`050:2PX02FUYH0UYJF09NGU`22PX800P29RHT01@2SXj<0ZZZZ0:ZZZP1JFUX0OWin
0080`l?300D0KFe]0>?Sh`3Shn<0BDU909BDU00209:BTP04071`L02DU9@0U9BD0?ooo`80000000D0
eMGE07EeM@2QXJ40XJ6Q08Z:RP020:b/[00508n?S`1?Cdl0YJFU0:FUY@3<c<`00P1TI6@01@1fMWH0
Xj>S0:>SX`2RXZ80[Zj^0080@d=300D0U9BD0:JVYP2VYZH0TI6A0::RXP020:NWY`0507EeM@1jNWX0
NWYj0:n_[`1nOWh00P2IVIT308B4Q0050:b/[01iNGT0NGUi0;Bd]02?Shl00P1iNGT01@23Ph<0Zj^[
0:^[Z`24Q8@0I6AT0080bl_;00@0QhN707YjNP1jNWX0Ph>30P2b/[801@22PX80VIVI09nOW`2OWil0
JFUY0080V9RH00<0^;Rh0?ooo`3oool0203oool01027QhL0Ph>308>3P`21PH4207IfMP80MGEe0P1f
MWH0101bLW80M7Ad07AdM01^KVh206YZJP05075aL@25QHD0W9bL09bLW02b/[800P33`l<01@3Fe]H0
g]kN0<K6aP36a/H0bl_;0080c<c<00@0d];B0<o?c`3?cll0fMWI0`3AdM401@34a<@0[jn_0:n_[`2Q
XJ40QhN70080NWYj00D0KFe]06i^KP1^KVh0N7Qh08n?S`0209RHV0<0UiNG00D0VIVI08b<S02<S8`0
SHf=096AT@0209:BTP0508J6QP20P800P8200861P@2HV9P00P2][Jd0102m_Kd0_kno0;no_`2/[:`2
09NGU`0508B4Q022PX80RHV908V9R@2@T9000P2:RXX01@25QHD0O7al08F5Q@25QHD0Q8B40080Ti>C
00D0W9bL09nOW`2OWil0TY:B09jNWP0208j>SP0508N7Q`2:RXX0RXZ:09ZJVP2HV9P00P2UYJD01@2`
/;00WIfM09fMW@2<S8`0O7al0080MWIf00@0IVIV06i^KP1^KVh0O7al0P21PH40101aLG40HV9R05AD
E01DE5@303`l?00504a<C01/K6`0QhN708N7Q`2BTY800P2JVYX01@2WYjL0YZJV0:JVYP2YZJT0[jn_
0080[Zj^00D0W9bL0::RXP2RXZ80Z:RX0:b/[0020;>c/`050:n_[`2MWId0WIfM08j>SP2FUYH00P26
QXH0102EUID0V9RH09RHV02NWYh208^;R`05096AT@2GUiL0WinO09nOW`2<S8`00P26QXH01@23Ph<0
Lg=c079bLP1bLW80Shn?0080Vi^K00D0UiNG09^KV`2KVi/0WYjN08R8R0020820P00408F5Q@27QhL0
QhN708>3P`l0oooo000=0?ooo`0405iNGP28R8P0R8R80<K6aP80OWin00D0P82008J6QP2c/k<0/k>c
07UiN@0209nOW`0507YjNP2JVYX0VYZJ07UiN@2NWYh00P2/[:`01@1fMWH0YjNW0:NWY`21PH40Ng]k
0080V9RH00@0UYJF08b<S02<S8`0/K6a0P1XJ6P01@30`<00Kfm_08:2PP22PX80ZJVY0080IVIV00D0
/[:b08b<S02>SXh0SXj>0<71`@0203Lg=`0509fMW@2[Zj/0UIFE09FEU@2TY:@00P22PX801@24Q8@0
R8R808R8R02@T900QhN70080Y:BT00D0P82009:BTP2BTY80RHV90:n_[`0208B4Q00409VIV@2JVYX0
VYZJ04I6AP80hN7Q00D0Jf][0:f][@20P800P82008f=S@0206][J`050:JVYP2f][H0LW9b079bLP1o
Ogl00P2=SHd01@2OWil0VYZJ09ZJVP2IVIT0NWYj0080TY:B00D0WIfM0:JVYP2VYZH0H61P07UiN@02
0<K6aP0506m_K`3Rh^80h^;R04a<C02>SXh00P2CTi<0101dM7@0SXj>08j>SP3oool200<30`050<c<
c01mOGd0W9bL09bLW02=SHd00P2[Zj/01@2>SXh0D51@0:RXZ02XZ:P0`/;20080LW9b00D0IVIV0;6a
/@2a/K40V9RH0;Vi^@0204A4A00508Z:RP2ZZZX0ZZZZ08n?S`2QXJ400P2][Jd01@1cLg<0MgMg07Mg
M`2a/K40Q8B40080TI6A0`26QXH01@2YZJT0NGUi07UiN@2c/k<0Ti>C0080MgMg00D0QXJ60:BTY02T
Y:@0SXj>05iNGP020<k>cP040820P022PX80PX:207YjNP80^KVi00D0OWin09nOW`2KVi/0Vi^K06i^
KP02096AT@030;^k^`3oool0oooo00P0oooo00@0VYZJ09^KV`2KVi/0VIVI0P2NWYh01@2PX:00UiNG
08^;R`2;Rh/0X:2P0080]KFe00D0^KVi0<[:bP3:b/X0`l?309bLW00207YjNP0506e]K@1JFUX0FUYJ
05YJFP1PH6000P1eMGD0101jNWX0QXJ608J6QP2;Rh/209>CT`0508n?S`2CTi<0Ti>C09>CT`2DU9@0
0`2HV9P0102OWil0YJFU0:FUY@2ZZZX30;Bd]0040:b/[02YZJT0ZJVY0:f][@80[Zj^00D0/K6a0;jn
_P2n_[h0`l?30<O7a`020<C4a0050<K6aP3;bl/0bl_;0<C4a02`/;000P2OWil0102FUYH0UiNG09NG
U`2FUYH20:6QX@050:VYZ@2[Zj/0WinO09nOW`2^[Zh00P2c/k<01@34a<@0`<300;Fe]@2e]KD0ZZZZ
0080WinO00D0QXJ608Z:RP2:RXX0Ti>C08V9R@0209BDU0050:2PX02YZJT0ZJVY0:^[Z`2d];@00P2X
Z:P01@2KVi/0Ti>C09>CT`2EUID0WinO0080[:b/0`30`<001@2][Jd0VIVI09VIV@2PX:00/;2`0080
aLG500D0fm_K0=[JfP3Jf]X0`/;209JFUP0207IfMP0406i^KP1dM7@0M7Ad07EeM@<0Q8B400@0QHF5
08N7Q`27QhL0RHV90P23Ph<01@2@T900OWin07AdM01dM7@0NWYj0080QXJ600D0QhN709NGU`2UYJD0
YJFU09JFUP0208b<S00508f=S@2BTY80TY:B08b<S02LW9`00P2BTY801@23Ph<0Ng]k07]kN`1aLG40
HF5Q0080JFUY00@0IFEU06IVIP1VIVH0OWin0P2=SHd01@2JVYX0Xj>S0;2`/02`/;00Xj>S0080WinO
00<0UYJF0?ooo`3oool03@3oool000d0oooo00@0GUiN08R8R028R8P0a/K60P1nOWh01@20P800QXJ6
0;>c/`2c/k<0NGUi0080WinO00D0NWYj09ZJVP2JVYX0NGUi09jNWP020:b/[00507IfMP2WYjL0YjNW
0861P@1kNg/00P2HV9P0102FUYH0S8b<08b<S02a/K4206QXJ0050<30`01_Kfl0PX:208:2PP2YZJT0
0P1VIVH01@2b/[80S8b<08j>SP2>SXh0`L710080=cLg00D0WIfM0:^[Z`2EUID0UIFE0:BTY00208:2
PP0508B4Q028R8P0R8R8092@T027QhL00P2TY:@01@20P800TY:B09:BTP29RHT0[jn_0080Q8B400@0
VIVI09ZJVP2JVYX0ATI60P3QhN401@1[Jf/0[Jf]0820P020P800SHf=0080Jf][00D0YZJV0;Jf]P1b
LW80LW9b07moO`0208f=S@0509nOW`2JVYX0VYZJ09VIV@1jNWX00P2BTY801@2MWId0YZJV0:JVYP1P
H600NGUi0080a/K600D0Kfm_0>;RhP3Rh^80C4a<08j>SP0209>CT`0407AdM02>SXh0SXj>0?ooo`80
0`<300D0c<c<07emO@2LW9`0W9bL08f=S@020:^[Z`0508j>SP1@D500Z:RX0:RXZ032`/800P1bLW80
1@1VIVH0/K6a0;6a/@2HV9P0^KVi0080A4A400D0RXZ:0:ZZZP2ZZZX0Shn?0:6QX@020:f][@0507=c
L`1gMgL0MgMg0;6a/@24Q8@00P2ATI4308J6QP050:VYZ@1iNGT0NGUi0;>c/`2CTi<00P1gMgL01@26
QXH0Y:BT0:BTY02>SXh0GUiN0080c/k>00@0P82008:2PP22PX80NWYj0P2i^KT01@1nOWh0WinO09^K
V`2KVi/0KVi^0080TI6A00<0^k^k0?ooo`3oool0203oool0102JVYX0Vi^K09^KV`2IVIT209jNWP05
0:2PX02GUiL0Rh^;08^;R`2PX:000P2e]KD01@2i^KT0b/[:0<[:bP33`l<0W9bL0080NWYj00D0KFe]
05YJFP1JFUX0FUYJ061PH00207EeM@0407YjNP26QXH0QXJ608^;R`80Ti>C00D0Shn?09>CT`2CTi<0
Ti>C09BDU00309RHV00409nOW`2UYJD0YJFU0:ZZZP<0];Bd00@0[:b/0:VYZ@2YZJT0[Jf]0P2^[Zh0
1@2a/K40_[jn0;jn_P33`l<0alO70080a<C400D0a/K60<_;b`3;bl/0a<C40;2`/00209nOW`0409JF
UP2GUiL0UiNG09JFUP80XJ6Q00D0ZJVY0:^[Z`2OWil0WinO0:j^[P020;>c/`050<C4a030`<00]KFe
0;Fe]@2ZZZX00P2OWil01@26QXH0RXZ:08Z:RP2CTi<0RHV90080U9BD00D0X:2P0:VYZ@2YZJT0Zj^[
0;Bd]0020:RXZ00509^KV`2CTi<0Ti>C09FEU@2OWil00P2/[:`30<30`0050:f][@2IVIT0VIVI0:2P
X02`/;000P35aLD01@3Kfm/0f][J0=[JfP32`/80UYJF0080MWIf00@0KVi^07AdM01dM7@0MGEe0`24
Q8@01025QHD0QhN708N7Q`29RHT208>3P`05092@T01nOWh0M7Ad07AdM01jNWX00P26QXH01@27QhL0
UiNG0:FUY@2UYJD0UYJF0080S8b<00D0SHf=09:BTP2BTY80S8b<09bLW00209:BTP0508>3P`1kNg/0
Ng]k075aL@1QHF400P1YJFT0101UIFD0IVIV06IVIP1nOWh208f=S@0509ZJVP2SXj<0/;2`0;2`/02S
Xj<00P2OWil00`2FUYH0oooo0?ooo`0=0?ooo`003@3oool0101OGel0QhN708N7Q`35aLD207moO`05
07inOP26QXH0]kNg0;Ng]`1gMgL00P2NWYh01@1kNg/0VYZJ09ZJVP1kNg/0WinO0080YjNW00D0O7al
0:JVYP2VYZH0PX:2071`L0020:BTY00409BDU028R8P0R8R80;Ng]`80HF5Q00D0a/K606a/K023Ph<0
Ph>30:NWY`0206UYJ@050:f][@2?Shl0S8b<08b<S034a<@00P0f=SH01@2OWil0[Jf]08n?S`2?Shl0
Y:BT0080RXZ:00D0P82008Z:RP2:RXX0RXZ:08^;R`020:JVYP0507emO@2DU9@0U9BD08B4Q02c/k<0
0P27QhL0102DU9@0VYZJ09ZJVP1<C4`20=GEe@0507=cL`2[Zj/0QHF508F5Q@29RHT00P1_Kfl01@2Q
XJ40^[Zj07=cL`1cLg<0PH610080RHV900D0WYjN0:2PX02PX:00Ti>C07EeM@0209bLW00509VIV@2S
Xj<0Xj>S06EUI@1fMWH00P36a/H01@1fMWH0eMGE0=GEe@1GEeL0QhN70080V9RH00@0MgMg08^;R`2;
Rh/0oooo0P0820P01@38b<P0OGem09ZJVP2JVYX0T92@0080Zj^[00D0SHf=059BDP2/[:`0[:b/0;Rh
^00207UiN@0505mOG`2l_;`0_;bl08^;R`2n_[h00P1=CDd01@1mOGd0[Zj^0:j^[P2@T900X:2P0080
Zj^[00D0Lg=c07]kN`1kNg/0YjNW092@T00208^;R`0408f=S@1nOWh0OWin0:f][@80M7Ad00D0];Bd
09>CT`1mOGd0OGem08>3P`0209nOW`0509BDU01LG5`0d=3@0=3@d01jNWX00P2>SXh01@1_Kfl0_[jn
0;jn_P1jNWX0YZJV0080UIFE00@0Kfm_096AT@2ATI40_;bl2P3oool0102IVIT0WYjN09jNWP2OWil3
0:FUY@040;Bd]02i^KT0^KVi0:VYZ@80UiNG00D0VYZJ08V9R@29RHT0Rh^;0:6QX@020:n_[`050;2`
/02d];@0];Bd0;>c/`2_[jl00P2[Zj/0102OWil0VYZJ09ZJVP2EUID209VIV@0509JFUP2BTY80Rh^;
08^;R`2:RXX0101nOWh207QhN0<0MgMg00D0Ng]k07alO029RHT0RHV908n?S`0208R8R00507emO@1]
KFd0KFe]05iNGP1ADE400P1<C4`01@1@D500EUIF05IFEP1RHV80M7Ad0080OGem00@0RHV909:BTP2B
TY80Vi^K0P2BTY80102DU9@0Ti>C09JFUP2FUYH30861P@80LW9b0P1hN7P0102:RXX0Shn?08n?S`2N
WYh209^KV`0509>CT`2ATI40RHV908V9R@1nOWh00P1eMGD01@1cLg<0MGEe07]kN`1kNg/0T92@0080
V9RH00D0W9bL09ZJVP2BTY80TY:B08B4Q00208n?S`0509BDU02RXZ80XZ:R0::RXP2MWId00P2:RXX0
1@2=SHd0UiNG09NGU`2/[:`0bLW90080f=SH00@0dM7A0<W9b@39bLT0/k>c0P2BTY801@2<S8`0R8R8
07IfMP1fMWH0UYJF0080WinO00D0RHV907moO`26QXH0QXJ606QXJ002069RHP0506m_K`1eMGD0K6a/
06a/K01mOGd00P27QhL01@1eMGD0Jf][06][J`1cLg<0F5QH0080EUIF00D0QhN70:FUY@2UYJD0/;2`
0=KFeP020=WIf@040<G5a@2b/[80/[:b09ZJVP80O7al00D0MWIf07alO01kNg/0Ng]k08f=S@0209FE
U@030:2PX03oool0oooo00d0oooo000=0?ooo`0405aLG02;Rh/0Rh^;0<C4a080Q8B400D0MWIf08N7
Q`2h^;P0^;Rh07IfMP0209nOW`0507emO@2EUID0UIFE07alO02TY:@00P2NWYh01@22PX80YZJV0:JV
YP22PX80JVYZ0080[:b/00@0TI6A08N7Q`27QhL0^;Rh0P1OGel01@39bLT0JVYZ08B4Q024Q8@0Z:RX
0080JFUY00D0ZZZZ09:BTP28R8P0R8R80<W9b@0203De=@0509bLW02c/k<0QHF508F5Q@2XZ:P00P2?
Shl01@1lO7`0SXj>08j>SP20P800UIFE0080Y:BT00D0O7al09JFUP2FUYH0PH610;Ng]`0208B4Q004
09:BTP2HV9P0V9RH05QHF080alO700D0M7Ad0:ZZZP2?Shl0Shn?07inOP0207UiN@0509ZJVP2i^KT0
MGEe07EeM@20P8000P2<S8`01@2NWYh0XJ6Q0:6QX@2ATI40Lg=c0080XZ:R00D0TY:B0:JVYP2VYZH0
J6QX07AdM0020;jn_P0508F5Q@34a<@0a<C406=SH`20P8000P2JVYX0101jNWX0R8R808R8R03oool2
00/;2`050<;2`P23Ph<0UiNG09NGU`2BTY800P2[Zj/01@2:RXX0DU9B0;2`/02`/;00[jn_0080OWin
00D0I6AT0;Jf]P2f][H0Rh^;0<71`@02059BDP0507UiN@2][Jd0[Jf]09>CT`2NWYh00P2YZJT01@1a
LG40QXJ608J6QP2JVYX0Vi^K0080Q8B400@0TY:B07alO01lO7`0ZZZZ0P1fMWH01@2b/[80UiNG07em
O@1mOGd0Ph>30080V9RH00D0WIfM05]KF`3Bd]80d];B079bLP0209NGU`0506IVIP31`L40`L7107em
O@2SXj<00P2BTY80101aLG40TY:B09:BTP2k^k/:0?ooo`040:2PX02RXZ80XZ:R09BDU080Ti>C00D0
UYJF08b<S02ATI40TI6A09jNWP020:JVYP050:b/[02^[Zh0[Zj^0:RXZ02TY:@00P2SXj<308f=S@04
08V9R@1hN7P0M7Ad07AdM0<0PX:200D0N7Qh07MgM`1gMgL0OGem08^;R`0209NGU`0509nOW`2[Zj/0
Zj^[0:NWY`2PX:000P2SXj<01@2RXZ80TI6A096AT@25QHD0OWin0080K6a/00@0FUYJ069RHP1RHV80
LW9b0P27QhL00`2KVi/0[jn_0;Zj^P020;Zj^P80/k>c00D0[Zj^0:BTY02UYJD0YJFU09fMW@0209NG
U`0409ZJVP2KVi/0Vi^K09FEU@@0V9RH0P2QXJ401@2/[:`0/k>c0;Bd]02d];@0Z:RX0080Vi^K00D0
Ti>C08n?S`2?Shl0Ti>C09ZJVP020:JVYP050;>c/`2d];@0];Bd0:n_[`2][Jd00P2TY:@01@2CTi<0
XJ6Q0:6QX@2OWil0WIfM00<0XZ:R0P2<S8`0102BTY80U9BD09BDU02ATI4308j>SP0508>3P`1dM7@0
M7Ad075aL@1^KVh00P1_Kfl0101lO7`0OWin07inOP24Q8@20:2PX00509jNWP2@T900X:2P0:2PX02D
U9@00P2CTi<01@2NWYh0/k>c0;Bd]02d];@0_[jn0080^KVi00D0Zj^[09jNWP2QXJ40XJ6Q0:2PX002
0:>SX`050<30`039bLT0bLW90<?3``3EeMD00P3Ogml01@2f][H0XZ:R0::RXP2WYjL0SHf=0080OWin
00@0UIFE09^KV`2KVi/0Rh^;0P2:RXX01@1iNGT0IVIV07=cL`1cLg<0R8R80080TI6A00<0Ti>C0?oo
o`3oool03@3oool000d0oooo00@0FUYJ08j>SP2>SXh0`/;20P26QXH01@1iNGT0QhN70;>c/`2c/k<0
MWIf0080WinO00D0OGem09>CT`2CTi<0Ph>309jNWP020:2PX0050861P@2WYjL0YjNW08F5Q@1UIFD0
0P2b/[80102>SXh0R8R808R8R02f][H2069RHP050<W9b@1YJFT0Ph>308>3P`2YZJT00P1VIVH01@2Y
ZJT0V9RH08B4Q024Q8@0c<c<0080<S8b00D0XJ6Q0;>c/`1kNg/0Ng]k0:j^[P0209>CT`0507QhN02@
T900T92@07QhN02NWYh00P2MWId01@20P800UiNG09NGU`1mOGd0^k^k0080PX:200@0UYJF08j>SP2>
SXh0JVYZ0P2f][H01@1lO7`0XZ:R0:2PX02PX:00Kfm_0080QHF500D0SXj>0<71`@1aLG40LG5a08:2
PP0208^;R`0509bLW02RXZ80XZ:R096AT@1cLg<00P2UYJD01@2;Rh/0ZJVY0:VYZ@1[Jf/0LW9b0080
^;Rh00D0UiNG0:n_[`2_[jl0LG5a07emO@0209BDU00407moO`26QXH0QXJ60?ooo`803Ph>00D0_;bl
08N7Q`2BTY80TY:B09JFUP020:b/[00508V9R@1EEED0[jn_0:n_[`2XZ:P00P1mOGd01@1bLW80ZZZZ
0:ZZZP2:RXX0a<C40080Fe]K00D0L71`0:f][@2][Jd0VIVI09RHV00209nOW`0507]kN`2>SXh0SXj>
08b<S02VYZH00P1nOWh0102KVi/0LW9b079bLP2a/K4207IfMP80Y:BT0P22PX801@1jNWX0V9RH09RH
V02QXJ40FUYJ0080dm?C00@0JVYZ0:2PX02PX:00GUiN0P33`l<01@24Q8@0X:2P08n?S`2?Shl0N7Qh
0080Rh^;00<0_kno0?ooo`3oool0203oool0101hN7P0JVYZ06YZJP1^KVh206a/K00406i^KP1cLg<0
O7al07alO0<0PX:200<0Ng]k08J6QP26QXH00P2>SXh209NGU`050<30`032`/80`/;20;bl_03<c<`0
0P3;bl/0102_[jl0Y:BT0:BTY02c/k<20:JVYP050::RXP2FUYH0Shn?08n?S`2<S8`00P2ATI401@2H
V9P0Y:BT0;2`/02`/;00];Bd0080a<C400D0c/k>0=?Cd`3Jf]X0f][J0>;RhP020=kNgP050<_;b`30
`<00`<300;Bd]02[Zj/00P2WYjL01@2VYZH0WYjN09jNWP2SXj<0X:2P0080VIVI00@0Y:BT0:ZZZP2Z
ZZX0XJ6Q0P2XZ:P01@2][Jd0XJ6Q0:6QX@2QXJ40XZ:R0080T92@00D0P82008>3P`1kNg/0Ng]k08J6
QP020::RXP050;Bd]02_[jl0[jn_0;:b/P2OWil00P2>SXh01@26QXH0SHf=08f=S@2=SHd0WYjN0080
UIFE00D0RHV9079bLP1bLW80K6a/05]KF`0206EUI@0406i^KP1gMgL0MgMg0820P080PH6100D0OWin
07moO`27QhL0QhN707moO`0208B4Q00508>3P`2?Shl0Rh^;08^;R`2EUID00P2QXJ401@2][Jd0T92@
092@T02KVi/0XJ6Q0080UiNG00D0U9BD0:j^[P2^[Zh0[Jf]0:b/[0020;Jf]P050:n_[`2DU9@0U9BD
08j>SP29RHT00P1jNWX0101lO7`0R8R808R8R023Ph<207inOP0508b<S01lO7`0Ogmo07moO`2<S8`0
0P2@T9001@1hN7P0Ng]k07alO01lO7`0MWIf0080RXZ:00D0/k>c0=SHf03Hf=P0inOW0>[ZjP020<k>
cP040:BTY027QhL0QhN707moO`l0oooo000=0?ooo`0405YJFP2>SXh0SXj>0<;2`P80QXJ600D0NGUi
08N7Q`2c/k<0/k>c07IfMP0209nOW`0507emO@2CTi<0Ti>C08>3P`2NWYh00P2PX:001@21PH40YjNW
0:NWY`25QHD0IFEU0080/[:b00@0SXj>08R8R028R8P0][Jf0P1RHV801@39bLT0JFUY08>3P`23Ph<0
ZJVY0080IVIV00D0ZJVY09RHV024Q8@0Q8B40<c<c002038b<P050:6QX@2c/k<0Ng]k07]kN`2^[Zh0
0P2CTi<01@1hN7P0T92@092@T01hN7P0WYjN0080WIfM00D0P82009NGU`2GUiL0OGem0;^k^`0208:2
PP0409JFUP2>SXh0SXj>06YZJP80][Jf00D0O7al0::RXP2PX:00X:2P06m_K`0208F5Q@0508j>SP31
`L40LG5a075aL@22PX800P2;Rh/01@2LW9`0XZ:R0::RXP2ATI40Lg=c0080YJFU00D0Rh^;0:VYZ@2Y
ZJT0Jf][079bLP020;Rh^00509NGU`2_[jl0[jn_075aL@1mOGd00P2DU9@0101oOgl0QXJ608J6QP3o
ool200h>3P050;bl_027QhL0TY:B09:BTP2FUYH00P2/[:`01@29RHT0EEEE0:n_[`2_[jl0Z:RX0080
OGem00D0LW9b0:ZZZP2ZZZX0RXZ:0<C4a00205]KF`05071`L02][Jd0[Jf]09VIV@2HV9P00P2OWil0
1@1kNg/0SXj>08j>SP2<S8`0YZJV0080OWin00@0Vi^K079bLP1bLW80/K6a0P1fMWH20:BTY080PX:2
00D0NWYj09RHV02HV9P0XJ6Q05YJFP020=?Cd`0406YZJP2PX:00X:2P05iNGP80`l?300D0Q8B40:2P
X02?Shl0Shn?07QhN00208^;R`030;no_`3oool0oooo00P0oooo00@0N7Qh06YZJP1ZJVX0KVi^0P1/
K6`0101^KVh0Lg=c07alO01lO7`308:2PP0307]kN`26QXH0QXJ60080SXj>0P2GUiL01@30`<00`/;2
0<;2`P2l_;`0c<c<0080bl_;00@0[jn_0:BTY02TY:@0/k>c0P2VYZH01@2RXZ80UYJF08n?S`2?Shl0
S8b<0080TI6A00D0V9RH0:BTY02`/;00/;2`0;Bd]0020<C4a0050<k>cP3Cdm<0f][J0=[JfP3Rh^80
0P3Ng]h01@3;bl/0`<300<30`02d];@0Zj^[0080YjNW00D0YZJV09jNWP2NWYh0Xj>S0:2PX00209VI
V@040:BTY02ZZZX0ZZZZ0:6QX@80Z:RX00D0[Jf]0:6QX@2QXJ40XJ6Q0::RXP02092@T0050820P023
Ph<0Ng]k07]kN`26QXH00P2RXZ801@2d];@0[jn_0:n_[`2b/[80WinO0080SXj>00D0QXJ608f=S@2=
SHd0SHf=09jNWP0209FEU@0508V9R@1bLW80LW9b06a/K01KFe/00P1UIFD0101^KVh0MgMg07MgM`20
P8020861P@0507inOP1oOgl0QhN708N7Q`1oOgl00P24Q8@01@23Ph<0Shn?08^;R`2;Rh/0UIFE0080
XJ6Q00D0[Jf]092@T02@T900Vi^K0:6QX@0209NGU`0509BDU02^[Zh0[Zj^0:f][@2/[:`00P2f][H0
1@2_[jl0U9BD09BDU02>SXh0RHV90080NWYj00@0O7al08R8R028R8P0Ph>30P1nOWh01@2<S8`0O7al
07moO`1oOgl0S8b<0080T92@00D0N7Qh07]kN`1lO7`0O7al07IfMP0208Z:RP050;>c/`3Hf=P0f=SH
0>OWi`3Zj^X00P3>c/h0102TY:@0QhN708N7Q`1oOgl?0?ooo`003@3oool0101CDe<0TY:B09:BTP33
`l<208J6QP0507EeM@2:RXX0/k>c0;>c/`1bLW800P2UYJD01@1iNGT0U9BD09BDU023Ph<0WIfM0080
Y:BT00D0P8200:FUY@2UYJD0QHF506QXJ0020;>c/`0408V9R@2;Rh/0Rh^;0;Jf]P80HF5Q00D0b/[:
06EUI@2;Rh/0Rh^;0:FUY@0206=SH`050:ZZZP2HV9P0QHF508F5Q@3?cll00P0`<3001@2OWil0/k>c
07QhN01hN7P0/K6a0080UiNG00D0MGEe096AT@2ATI40MGEe0:JVYP0209FEU@0508B4Q02JVYX0VYZJ
07]kN`2k^k/00P20P800102IVIT0R8R808R8R01fMWH20:VYZ@0508F5Q@2EUID0]KFe0;Fe]@1MGEd0
0P2CTi<01@25QHD0aLG5071`L01`L700PX:20080Rh^;00D0WIfM0::RXP2RXZ80TI6A07=cL`020:^[
Z`0507inOP2`/;00/;2`075aL@1ZJVX00P2b/[800`2YZJT0VYZJ09ZJVP0207emO@80Rh^;00@0RHV9
08B4Q024Q8@0oooo0P0B4Q801@2g]kL0Rh^;08f=S@2=SHd0VIVI0080[Zj^00D0QHF505QHF02b/[80
/[:b0:6QX@0207alO00508F5Q@2BTY80TY:B09^KV`2h^;P00P1SHf<01@1/K6`0/;2`0;2`/02JVYX0
W9bL0080TI6A00D0PX:209FEU@2EUID0P8200:^[Z`0207YjNP040:NWY`1VIVH0IVIV0;Fe]@80OGem
00D0VIVI0:NWY`25QHD0QHF507alO00209>CT`0509^KV`1XJ6P0d=3@0=3@d01QHF400P2WYjL01@1M
GEd0_[jn0;jn_P2<S8`0W9bL0080Rh^;00@0OGem08j>SP2>SXh0_kno2P3oool0102YZJT0][Jf0;Jf
]P33`l<20=3@d0050=[JfP3Rh^80eMGE0=GEe@33`l<00P2a/K401@2OWil0TY:B09:BTP2:RXX0Ph>3
0080P82000D0KVi^07MgM`1gMgL0QHF508B4Q00208>3P`0409^KV`2LW9`0W9bL09BDU080UYJF00@0
TI6A09NGU`2FUYH0UYJF0`2BTY800`2FUYH0TI6A09>CT`0209>CT`80SXj>00D0SHf=09bLW02OWil0
WinO0:JVYP020:n_[`050;bl_02c/k<0/k>c0:JVYP2GUiL00P27QhL01@26QXH0Shn?08n?S`27QhL0
TY:B0080U9BD00@0RHV907moO`1oOgl0Q8B40P1mOGd01@28R8P0RHV908^;R`2;Rh/0X:2P0080[Jf]
00D0ZZZZ09^KV`2LW9`0W9bL08f=S@0207MgM`05071`L02;Rh/0Rh^;08f=S@2HV9P00P2UYJD30:j^
[P050:FUY@2ATI40XZ:R0::RXP2c/k<00P2h^;P01@36a/H0dm?C0<;2`P32`/80]KFe0080/;2`00<0
X:2P0:6QX@2QXJ400P2WYjL20:^[Z`050;Rh^02j^[X0^[Zj0;6a/@2NWYh00P2;Rh/01023Ph<0GUiN
05iNGP1NGUh207EeM@0507AdM01_Kfl0QhN708N7Q`1gMgL00P1MGEd01@1YJFT0I6AT06IVIP1VIVH0
PX:20080YjNW00D0];Bd0;^k^`38b<P0b<S80;Zj^P020:RXZ00509ZJVP2`/;00/;2`0:6QX@2c/k<0
0P2WYjL01@2NWYh0SXj>08j>SP2XZ:P0[Zj^0080^;Rh00@0_kno0:f][@2][Jd0UIFE0P1eMGD01@1]
KFd0Lg=c08V9R@29RHT0VYZJ0080[:b/00<0/;2`0?ooo`3oool03@3oool000d0oooo00@0De=C09>C
T`2CTi<0`/;20P26QXH01@1hN7P0R8R80;2`/02`/;00Lg=c0080XZ:R00D0P820096AT@2ATI40QHF5
09bLW0020::RXP050861P@2VYZH0YZJV08F5Q@1TI6@00P2g]kL01028R8P0RXZ:08Z:RP2h^;P2061P
H0050<K6aP1SHf<0U9BD09BDU02RXZ800P1QHF401@2[Zj/0UiNG08J6QP26QXH0d=3@0080<30`00D0
X:2P0;2`/01fMWH0MWIf0;Fe]@0209JFUP0507EeM@2?Shl0Shn?079bLP2`/;000P2;Rh/01@27QhL0
W9bL09bLW01hN7P0]kNg0080PX:200@0WIfM0820P020P800Q8B40P2FUYH01@2EUID0QXJ60<[:bP3:
b/X0BDU90080X:2P00D0PH610<30`01cLg<0Lg=c07inOP02092@T00509jNWP2QXJ40XJ6Q08j>SP1e
MGD00P2`/;001@1aLG40^;Rh0;Rh^01dM7@0JFUY0080ZJVY00D0^KVi08V9R@29RHT0QHF507alO002
08Z:RP0408^;R`27QhL0QhN70?ooo`804a<C00D0];Bd08f=S@2;Rh/0Rh^;09ZJVP020;2`/0050820
P01OGel0[jn_0:n_[`2OWil00P1eMGD01@2KVi/0NGUi07UiN@2[Zj/0YjNW0080L71`00<0JVYZ0:j^
[P2^[Zh00P2LW9`208Z:RP0508N7Q`2LW9`0W9bL07QhN02UYJD00P22PX80102/[:`0Fe]K05]KF`2h
^;P208J6QP0508Z:RP2_[jl0QXJ608J6QP1jNWX00P2DU9@01@2HV9P0Lg=c0<K6aP36a/H0HV9R0080
Z:RX00D0GEeM0;bl_02l_;`0U9BD092@T00208Z:RP0408F5Q@2;Rh/0Rh^;0;no_`X0oooo00@0U9BD
07inOP1nOWh0N7Qh0P1]KFd01@1PH600D51@05UIF@1IFET0GemO0080HV9R00<0MWIf07]kN`1kNg/0
0P2;Rh/20861P@0507=cL`1aLG40LG5a06QXJ01]KFd00P1kNg/0101bLW80NGUi07UiN@1hN7P207em
O@050861P@26QXH0Q8B408B4Q022PX800P1jNWX01@1fMWH0MgMg06IVIP1VIVH0LG5a0080Ng]k00D0
M7Ad06ATI01ZJVX0JVYZ05eMG@0204i>CP0505EEE@1]KFd0KFe]0820P02GUiL00P2[Zj/01@2VYZH0
VIVI09VIV@2ATI40RXZ:0080OGem0`1kNg/01@23Ph<0NWYj07YjNP1jNWX0R8R80080UIFE00D0QhN7
09BDU02DU9@0[:b/0;Zj^P020;Ng]`040;Zj^P2WYjL0YjNW08R8R080KVi^00D0JFUY06YZJP1bLW80
LW9b07IfMP0206i^KP0507]kN`2:RXX0RXZ:08Z:RP27QhL00P2JVYX01@2EUID0Ti>C09bLW02LW9`0
[Jf]0080Zj^[00D0[jn_0:BTY02TY:@0WinO09ZJVP0208n?S`0508>3P`27QhL0QhN708n?S`2HV9P0
0P2][Jd01030`<00i>CT0>CTi03Shn<20=[JfP050=_Kf`3Fe]H0_Kfm0;fm_@34a<@00P3>c/h01@2k
^k/0][Jf0:FUY@2UYJD0V9RH0080R8R800D0RHV909FEU@2?Shl0Shn?08j>SP0209^KV`0509RHV01b
LW80LW9b0861P@1kNg/00P1gMgL01@26QXH0Y:BT0:BTY02GUiL0TY:B0080S8b<00@0P82007emO@1m
OGd0QhN70P2GUiL0102QXJ40[Jf]0:VYZ@2YZJT309fMW@0309RHV03oool0oooo00d0oooo000=0?oo
o`0405=CD`2CTi<0Ti>C0<;2`P80QXJ600D0N7Qh08R8R02`/;00/;2`07=cL`020::RXP050820P02A
TI40TI6A08F5Q@2LW9`00P2RXZ801@21PH40YZJV0:JVYP25QHD0I6AT0080]kNg00@0R8R808Z:RP2:
RXX0^;Rh0P1PH6001@36a/H0Hf=S09BDU02DU9@0XZ:R0080HF5Q00D0Zj^[09NGU`26QXH0QXJ60=3@
d002030`<0050:2PX02`/;00MWIf07IfMP2e]KD00P2FUYH01@1eMGD0Shn?08n?S`1bLW80/;2`0080
Rh^;00D0QhN709bLW02LW9`0N7Qh0;Ng]`0208:2PP0409fMW@20P800P82008B4Q080UYJF00D0UIFE
08J6QP3:b/X0b/[:04U9B@020:2PX0050861P@30`<00Lg=c07=cL`1nOWh00P2@T9001@2NWYh0XJ6Q
0:6QX@2>SXh0MGEe0080/;2`00D0LG5a0;Rh^02h^;P0M7Ad06UYJ@020:VYZ@050;Vi^@29RHT0RHV9
08F5Q@1lO7`00P2:RXX0102;Rh/0QhN708N7Q`3oool201<C4`050;Bd]02=SHd0Rh^;08^;R`2JVYX0
0P2`/;001@20P800GemO0:n_[`2_[jl0WinO0080MGEe00D0Vi^K07UiN@1iNGT0Zj^[0:NWY`02071`
L00306YZJP2^[Zh0[Zj^0080W9bL0P2:RXX01@27QhL0W9bL09bLW01hN7P0YJFU0080PX:200@0[:b/
05]KF`1KFe/0^;Rh0P26QXH01@2:RXX0[jn_08J6QP26QXH0NWYj0080U9BD00D0V9RH07=cL`36a/H0
a/K6069RHP020:RXZ00505eMG@2l_;`0_;bl09BDU02@T9000P2:RXX01025QHD0Rh^;08^;R`2o_kl:
0?ooo`0409BDU01nOWh0OWin07QhN080KFe]00D0H61P051@D01IFET0FEUI05mOG`02069RHP0307If
MP1kNg/0Ng]k0080Rh^;0P21PH401@1cLg<0LG5a075aL@1XJ6P0KFe]0080Ng]k00@0LW9b07UiN@1i
NGT0N7Qh0P1mOGd01@21PH40QXJ608B4Q024Q8@0PX:20080NWYj00D0MWIf07MgM`1VIVH0IVIV075a
L@0207]kN`0507AdM01TI6@0JVYZ06YZJP1MGEd00P1>CTh01@1EEED0KFe]06e]K@20P800UiNG0080
Zj^[00D0YZJV09VIV@2IVIT0TI6A08Z:RP0207emO@<0Ng]k00D0Ph>307YjNP1jNWX0NWYj08R8R002
09FEU@0508N7Q`2DU9@0U9BD0:b/[02j^[X00P2g]kL0102j^[X0YjNW0:NWY`28R8P206i^KP0506UY
J@1ZJVX0LW9b079bLP1fMWH00P1^KVh01@1kNg/0RXZ:08Z:RP2:RXX0QhN70080VYZJ00D0UIFE09>C
T`2LW9`0W9bL0:f][@020:^[Z`050:n_[`2TY:@0Y:BT09nOW`2JVYX00P2?Shl01@23Ph<0QhN708N7
Q`2?Shl0V9RH0080[Jf]00@0`<300>CTi03Ti>@0hn?S0P3Jf]X01@3Kfm/0e]KF0;fm_@2m_Kd0a<C4
0080c/k>00D0^k^k0;Jf]P2UYJD0YJFU09RHV00208R8R00508V9R@2EUID0Shn?08n?S`2>SXh00P2K
Vi/01@2HV9P0LW9b079bLP21PH40Ng]k0080MgMg00D0QXJ60:BTY02TY:@0UiNG09:BTP0208b<S004
0820P01mOGd0OGem08N7Q`80UiNG00@0XJ6Q0:f][@2YZJT0ZJVY0`2MWId00`2HV9P0oooo0?ooo`0=
0?ooo`003@3oool0101BDU80Ti>C09>CT`33`l<208R8R00507QhN025QHD0ZJVY0:VYZ@1mOGd00P2I
VIT01@29RHT0SHf=08f=S@26QXH0V9RH0080YjNW00D0P8200:>SX`2SXj<0Ph>306e]K@020;Jf]P04
0820P02<S8`0S8b<0;Rh^080IFEU00D0`/;206ATI02GUiL0UiNG09fMW@0206ATI0050:RXZ02HV9P0
QhN708N7Q`3AdM400P0d=3@01@2OWil0ZZZZ07IfMP1fMWH0^KVi0080UYJF00D0MWIf08Z:RP2:RXX0
M7Ad0;:b/P0208R8R00508V9R@2NWYh0WYjN07YjNP2][Jd00P24Q8@0102VYZH0LW9b079bLP2BTY82
08b<S00509fMW@1kNg/0f=SH0=SHf00o?cl00P2XZ:P01@22PX80]KFe07YjNP1jNWX0MWIf0080VIVI
00D0Vi^K09nOW`2OWil0SHf=07]kN`020:j^[P0506a/K02n_[h0_[jn07IfMP1WIfL00P2SXj<01@31
`L40QHF508F5Q@25QHD0Ng]k0080SHf=00@0RHV908^;R`2;Rh/0oooo0P0?3`l01@2f][H0Shn?08^;
R`2;Rh/0VYZJ0080/[:b00D0NGUi06MWI`2WYjL0YjNW0:>SX`02079bLP050:VYZ@1SHf<0Hf=S0<71
`@2FUYH00P1eMGD01@1^KVh0[:b/0:b/[02JVYX0XJ6Q0080QhN700D0QXJ60:NWY`2WYjL0LG5a09nO
W`0208Z:RP040:NWY`1PH600H61P0:n_[`80UIFE00D0Ogmo0:j^[P28R8P0R8R807inOP0208f=S@05
09RHV020P800]kNg0;Ng]`1XJ6P00P2SXj<01@1PH600^[Zj0;Zj^P2JVYX0QhN70080TY:B00@0QhN7
08R8R028R8P0_kno2P3oool0102n_[h0g=cL0=cLg03AdM420<?3``050;fm_@2d];@0WYjN09jNWP2J
VYX00P2e]KD01@2][Jd0YjNW0:NWY`2GUiL0YJFU0080XZ:R00D0Z:RX0:^[Z`2[Zj/0]KFe0:JVYP02
09bLW0040;Fe]@2l_;`0_;bl0<71`@80a<C400D0bl_;0;Ng]`2_[jl0[jn_0;Bd]0020:b/[00509jN
WP2LW9`0[:b/0:b/[02JVYX00P2BTY801@2MWId0Vi^K08R8R028R8P0Shn?0080UYJF00D0RHV907em
O@1mOGd0OGem07AdM00207UiN@0508n?S`2UYJD0YJFU0;>c/`2e]KD00P34a<@0102f][H0/k>c0;>c
/`2^[Zh20;Rh^0050:VYZ@2SXj<0SXj>08j>SP24Q8@00P1dM7@01@1TI6@0H61P06YZJP1ZJVX0LW9b
0080S8b<00D0ZJVY0;Fe]@2e]KD0`/;20;bl_0020:b/[0050:>SX`2VYZH0YZJV0:2PX02FUYH00P2G
UiL01@2CTi<0NGUi07UiN@1SHf<0IFEU0080GemO00@0EUIF06a/K01/K6`0O7al0P2>SXh01@2GUiL0
ZJVY0;Ng]`2g]kL0b/[:0080a<C400D0`<300;Rh^02ZZZX0ZZZZ09BDU0020861P@0309>CT`2LW9`0
W9bL0080V9RH0P2QXJ401@29RHT0LW9b079bLP1gMgL0NWYj0080QhN700D0TI6A09bLW02LW9`0UYJF
096AT@0209BDU00408f=S@26QXH0QXJ609NGU`80[:b/00D0VYZJ0:6QX@2_[jl0[jn_09RHV00208b<
S00509bLW02TY:@0TY:B09:BTP2TY:@00P2VYZH01@2MWId0SHf=08f=S@2BTY80Lg=c0080LW9b00@0
RHV908b<S02<S8`0VYZJ3`3oool000d0oooo00@0EeMG09>CT`2CTi<0_[jn0P27QhL01@1mOGd0Q8B4
0::RXP2RXZ80R8R80080SHf=00D0UIFE08Z:RP2:RXX0QhN7096AT@020:^[Z`0508F5Q@2HV9P0V9RH
08B4Q01cLg<00P2i^KT0101kNg/0T92@092@T02f][H206=SH`050<71`@1YJFT0V9RH09RHV02FUYH0
0P1ZJVX01@2UYJD0V9RH08V9R@29RHT0clo?0080=CDe00D0YZJV09nOW`1jNWX0NWYj0;Rh^00209RH
V00507UiN@20P800P82007UiN@2f][H00P26QXH01@29RHT0XJ6Q0:6QX@1hN7P0YJFU0080RHV900@0
[Zj^06ATI01TI6@0Xj>S0P1oOgl01@2UYJD0K6a/0>SXj03Xj>P0=SHf0080Zj^[00D0QhN70:b/[023
Ph<0Ph>3071`L00209ZJVP0509fMW@2LW9`0W9bL08b<S021PH400P2ZZZX01@1[Jf/0`<300<30`01h
N7P0J6QX0080Y:BT00D0_;bl08N7Q`27QhL0Q8B407inOP0208j>SP0408J6QP2@T900T92@0?clo080
3`l?00D0/k>c09FEU@2:RXX0RXZ:09fMW@020;6a/@05075aL@1cLg<0WYjN09jNWP2VYZH00P1_Kfl0
1@2c/k<0EeMG05MGE`38b<P0S8b<0080OWin00D0KFe]0:RXZ02XZ:P0Vi^K0::RXP0208F5Q@0508N7
Q`2/[:`0[:b/07=cL`2DU9@00P2ATI40102SXj<0Hf=S06=SH`2ZZZX209jNWP0507]kN`2WYjL0TY:B
09:BTP1kNg/00P2<S8`01@2FUYH0S8b<0:ZZZP2ZZZX0L71`0080VYZJ00D0K6a/0;:b/P2b/[80WYjN
07moO`0209ZJVP0408F5Q@2:RXX0RXZ:0;^k^`X0oooo00@0@41003Ph>00h>3P0DE5A0P1/K6`00`1g
MgL0Ti>C09fMW@0209fMW@80PH6100D0Rh^;08j>SP2>SXh0WYjN09JFUP020:f][@050;Bd]02WYjL0
YjNW0:>SX`2_[jl00P2/[:`0102BTY80UiNG09NGU`2CTi<208f=S@0508J6QP2EUID0W9bL09bLW02Q
XJ400P2_[jl01@2i^KT0/k>c0::RXP2RXZ80Z:RX0080X:2P00<0WYjN0;Fe]@39bLT00P39bLT20=3@
d0050=CDe03;bl/0bl_;0<C4a02o_kl00P2a/K401@2PX:00Q8B408B4Q01dM7@0JVYZ0080I6AT00@0
KVi^071`L01`L700LW9b0P1`L7001@1cLg<0M7Ad08N7Q`27QhL0Vi^K0080XJ6Q00D0Z:RX09jNWP2I
VIT0VIVI08F5Q@0207inOP0307=cL`1dM7@0M7Ad0080IVIV0P1YJFT01@1RHV80I6AT06ATI01_Kfl0
MgMg0080OGem00D0Shn?0:6QX@2QXJ40_kno0<K6aP020<[:bP040<c<c02i^KT0^KVi09^KV`80S8b<
00D0P82006i^KP1SHf<0Hf=S05UIF@02069RHP0506QXJ01iNGT0SXj>08j>SP2LW9`00P2WYjL01@2G
UiL0Rh^;08^;R`1jNWX0NGUi0080L71`00D0QHF508j>SP2>SXh0UYJF09bLW00309VIV@80UIFE00D0
VYZJ092@T02DU9@0U9BD09FEU@020:BTY0050:2PX02XZ:P0Z:RX0;2`/02RXZ800P2EUID01@2QXJ40
WYjN09jNWP26QXH0RXZ:0080W9bL00@0Rh^;08V9R@29RHT0U9BD0P2<S8`01@1dM7@0Ph>307YjNP1j
NWX0HV9R0080Hf=S00<0GEeM0?ooo`3oool03@3oool000d0oooo00@0F5QH09FEU@2EUID0_;bl0P29
RHT01@1mOGd0Q8B409RHV02HV9P0UiNG0080PX:200D0WYjN08V9R@29RHT0QHF5096AT@020:^[Z`05
08j>SP2<S8`0S8b<08>3P`1eMGD00P33`l<0101eMGD0SXj>08j>SP2f][H2061PH0050<;2`P1[Jf/0
VYZJ09ZJVP2@T9000P1^KVh01@2TY:@0UYJF08R8R028R8P0d];B0080=CDe00D0YZJV09ZJVP1oOgl0
Ogmo0;Vi^@0209FEU@0507moO`1eMGD0MGEe07]kN`2i^KT00P2@T9001@21PH40Y:BT0:BTY01iNGT0
VYZJ0080TI6A00@0/;2`05iNGP1NGUh0[:b/0P1gMgL01@2YZJT0Hf=S0?Gem@3emOD0;Bd]0080[:b/
00D0TI6A09VIV@2DU9@0U9BD06MWI`0209nOW`0509jNWP2LW9`0W9bL08J6QP29RHT00P2SXj<01@1[
Jf/0`/;20<;2`P1kNg/0IFEU0080Z:RX00D0/;2`092@T02@T900PX:207moO`0208f=S@0408F5Q@2G
UiL0UiNG0?Cdm0804A4A00D0[Zj^09fMW@25QHD0QHF50::RXP020;>c/`0506QXJ01jNWX0UiNG09NG
U`2[Zj/00P1`L7001@2e]KD0Cdm?04m?C`3Bd]80QHF50080P82000D0L71`0::RXP2RXZ80WYjN0:6Q
X@0308J6QP80/k>c00<0Jf][09BDU02IVIT00P2IVIT206i^KP0509nOW`2RXZ80XZ:R0820P02RXZ80
0P2BTY801@1mOGd0Rh^;08^;R`2DU9@0Ti>C0080W9bL00@0P82008b<S02<S8`0Ng]k0P2YZJT01@2O
Wil0N7Qh0::RXP2RXZ80QHF50080SXj>00<0][Jf0?ooo`3oool0203oool0103Shn<0eMGE0=GEe@2m
_Kd20::RXP0508J6QP1_Kfl0JVYZ06YZJP1/K6`00P1jNWX01@2:RXX0Shn?08n?S`2=SHd0TY:B0080
OGem00D0Jf][07QhN01hN7P0NWYj07IfMP020820P00408B4Q01ZJVX0JVYZ06=SH`80JVYZ00D0LG5a
07EeM@24Q8@0Q8B408R8R00208:2PP0507inOP27QhL0TY:B09:BTP2CTi<00P2DU9@01@2?Shl0Ng]k
06][J`1[Jf/0J6QX0080Hf=S00D0IfMW06i^KP1^KVh0MGEe07UiN@0207inOP0508>3P`2KVi/0Vi^K
0:VYZ@2d];@00P2i^KT0102f][H0a/K60<K6aP33`l<20<c<c0050<C4a037alL0[:b/0:b/[02SXj<0
0P2=SHd01@2DU9@0Xj>S0:n_[`2_[jl0`L710080c/k>00D0dM7A0<G5a@35aLD0]KFe0:ZZZP020:j^
[P050;Vi^@2d];@0];Bd0;bl_02b/[800P2TY:@01@2ATI40Rh^;08^;R`22PX80QHF50080RHV900@0
Shn?08^;R`2;Rh/0UIFE0P2ATI4208f=S@80WinO00D0Vi^K09VIV@2IVIT0S8b<07inOP0207=cL`04
06MWI`1KFe/0Fe]K06EUI@80LW9b00<0Ng]k08n?S`2TY:@00P2TY:@20:NWY`050:>SX`2KVi/0WYjN
09jNWP2KVi/00P2OWil01@2[Zj/0ZJVY0:n_[`2_[jl0^k^k0080ZJVY00D0YjNW0:VYZ@2YZJT0WYjN
0:NWY`020;2`/0<0WinO00D0WYjN08f=S@27QhL0QhN708Z:RP0209:BTP0508N7Q`2?Shl0Shn?0:BT
Y02[Zj/00P2e]KD0103Cdm<0h^;R0>;RhP3Ogml?0?ooo`003@3oool0101HF5P0UIFE09FEU@2l_;`2
08V9R@0507emO@24Q8@0V9RH09RHV02GUiL00P22PX801@2NWYh0RHV908V9R@25QHD0TI6A0080Zj^[
00D0SXj>08b<S02<S8`0Ph>307EeM@020<?3``0407EeM@2>SXh0SXj>0;Jf]P80H61P00D0`/;206][
J`2JVYX0VYZJ092@T00206i^KP050:BTY02FUYH0R8R808R8R03Bd]800P0e=CD01@2VYZH0VYZJ07mo
O`1oOgl0^KVi0080UIFE00D0Ogmo07EeM@1eMGD0Ng]k0;Vi^@02092@T0050861P@2TY:@0Y:BT07Ui
N@2JVYX00P2ATI40102`/;00GUiN05iNGP2/[:`207MgM`050:VYZ@1SHf<0mOGe0?Gem@0];Bd00P2/
[:`01@2ATI40VIVI09BDU02DU9@0IfMW0080WinO00D0WYjN09bLW02LW9`0QXJ608V9R@020:>SX`05
06][J`32`/80`/;207]kN`1UIFD00P2XZ:P01@2`/;00T92@092@T022PX80Ogmo0080SHf=00@0QHF5
09NGU`2GUiL0m?Cd0P0A4A401@2^[Zh0WIfM08F5Q@25QHD0XZ:R0080/k>c00D0J6QX07YjNP2GUiL0
UiNG0:^[Z`02071`L0050;Fe]@1?Cdl0Cdm?0=;BdP25QHD00P20P8001@1`L700XZ:R0::RXP2NWYh0
XJ6Q00<0QXJ60P2c/k<00`1[Jf/0U9BD09VIV@0209VIV@80KVi^00D0WinO0::RXP2RXZ80P8200::R
XP0209:BTP0507emO@2;Rh/0Rh^;09BDU02CTi<00P2LW9`01020P800S8b<08b<S01kNg/20:VYZ@05
09nOW`1hN7P0XZ:R0::RXP25QHD00P2>SXh00`2f][H0oooo0?ooo`080?ooo`040>?Sh`3EeMD0eMGE
0;fm_@80XZ:R00D0QXJ606m_K`1ZJVX0JVYZ06a/K00207YjNP0508Z:RP2?Shl0Shn?08f=S@2BTY80
0P1mOGd01@1[Jf/0N7Qh07QhN01jNWX0MWIf0080P82000@0Q8B406YZJP1ZJVX0Hf=S0P1ZJVX01@1a
LG40MGEe08B4Q024Q8@0R8R80080PX:200D0OWin08N7Q`2BTY80TY:B09>CT`0209BDU00508n?S`1k
Ng/0Jf][06][J`1XJ6P00P1SHf<01@1WIfL0KVi^06i^KP1eMGD0NGUi0080OWin00D0Ph>309^KV`2K
Vi/0ZJVY0;Bd]0020;Vi^@040;Jf]P36a/H0a/K60<?3``80c<c<00D0a<C40<O7a`2/[:`0[:b/0:>S
X`0208f=S@0509BDU02SXj<0[jn_0:n_[`31`L400P3>c/h01@3AdM40aLG50<G5a@2e]KD0ZZZZ0080
[Zj^00D0^KVi0;Bd]02d];@0_;bl0;:b/P020:BTY005096AT@2;Rh/0Rh^;08:2PP25QHD00P29RHT0
102?Shl0Rh^;08^;R`2EUID2096AT@80SHf=0P2OWil01@2KVi/0VIVI09VIV@2<S8`0OWin0080Lg=c
00@0IfMW05]KF`1KFe/0IFEU0P1bLW800`1kNg/0Shn?0:BTY0020:BTY080YjNW00D0Xj>S09^KV`2N
WYh0WYjN09^KV`0209nOW`050:^[Z`2YZJT0[jn_0:n_[`2k^k/00P2YZJT01@2WYjL0ZJVY0:VYZ@2N
WYh0YjNW0080/;2`0`2OWil01@2NWYh0SHf=08N7Q`27QhL0RXZ:0080TY:B00D0QhN708n?S`2?Shl0
Y:BT0:^[Z`020;Fe]@040=?Cd`3Rh^80h^;R0=oOg`l0oooo000=0?ooo`0405iNGP2ATI40TI6A0;fm
_@80R8R800D0Ogmo08:2PP2CTi<0Ti>C0:2PX00207QhN0050:ZZZP23Ph<0Ph>308R8R02;Rh/00P2[
Zj/01@2FUYH0QhN708N7Q`21PH40M7Ad0080b/[:00@0MGEe08^;R`2;Rh/0/k>c0P1SHf<01@31`L40
Kfm_09ZJVP2JVYX0S8b<0080LW9b00D0WinO09VIV@25QHD0QHF50=KFeP0203Hf=P050:VYZ@2DU9@0
P8200820P02m_Kd00P2?Shl01@24Q8@0KFe]06e]K@22PX80/k>c0080VIVI00D0OGem0:FUY@2UYJD0
OGem08^;R`0209fMW@040;:b/P1GEeL0EeMG0;Bd]080LG5a00D0[:b/05aLG03lo?`0o?cl02`/;002
0:b/[00509VIV@27QhL0YJFU0:FUY@1OGel00P2RXZ801@2KVi/0WIfM09fMW@23Ph<0TI6A0080Vi^K
00D0Kfm_0<;2`P32`/80NGUi06UYJ@020:b/[0050:>SX`2GUiL0UiNG08>3P`24Q8@00P28R8P01022
PX80WIfM09fMW@3^k^h2010@40050:f][@2UYJD0Ogmo07moO`2VYZH00P2d];@01@1OGel0QHF508^;
R`2;Rh/0];Bd0080KVi^00D0^;Rh04a<C01<C4`0c/k>08Z:RP020820P005079bLP2IVIT0VIVI0:>S
X`2OWil00P28R8P01@25QHD0][Jf0;Jf]P1WIfL0Ti>C0080WYjN00@0Shn?07moO`1oOgl0UIFE0P2P
X:001@23Ph<0X:2P09NGU`2GUiL0M7Ad0080U9BD0P2ATI4209NGU`0408j>SP1oOgl0Ogmo08F5Q@80
Y:BT00D0WYjN07AdM02^[Zh0[Zj^07moO`0208f=S@030;:b/P3oool0oooo00P0oooo00@0N7Qh07Yj
NP1jNWX0QXJ60P2HV9P0102][Jd0`<300=;BdP3Bd]830=cLg0050<;2`P2o_kl0_kno0;Ng]`2n_[h0
0P37alL01@3@d=00^;Rh0;Rh^02UYJD0S8b<0080PX:200@0Ti>C0:JVYP2VYZH0][Jf0P2l_;`01@2e
]KD0XJ6Q09JFUP2FUYH0Ti>C0080UYJF00<0X:2P0:FUY@2SXj<00P2SXj<20:6QX@0509jNWP2QXJ40
[Jf]0:f][@2d];@00P2e]KD01@2UYJD0VYZJ09ZJVP2>SXh0Ph>30080Q8B400D0RHV90861P@21PH40
M7Ad06a/K00205eMG@0306e]K@1cLg<0Lg=c00<0Q8B400D0X:2P09FEU@2DU9@0U9BD08^;R`0209FE
U@050820P01mOGd0N7Qh07QhN01jNWX00P1iNGT01@28R8P0UiNG09NGU`2/[:`0_kno0080_;bl00D0
[jn_0;2`/02`/;00[jn_0:>SX`020:2PX00509nOW`2KVi/0Vi^K08Z:RP25QHD00P28R8P01027QhL0
UiNG09NGU`2HV9P20:ZZZP050;>c/`30`<00/;2`0;2`/02e]KD00P2^[Zh01@2h^;P0];Bd0:VYZ@2Y
ZJT0Zj^[0080/K6a00<0WinO09FEU@2EUID00P2SXj<2096AT@0509ZJVP2QXJ40XJ6Q09VIV@2CTi<0
0P20P8001@1gMgL0M7Ad07AdM01XJ6P0JVYZ0080L71`00@0LW9b06YZJP1ZJVX0IVIV0P1RHV801@1b
LW80Jf][079bLP1bLW80QHF50080P82000D0SHf=09bLW02GUiL0UiNG0:FUY@020:j^[P050;Ng]`2n
_[h0_[jn0<?3``2`/;000P2VYZH01024Q8@0JVYZ06YZJP1cLg<?0?ooo`003@3oool0101VIVH0S8b<
08b<S031`L4208B4Q0050820P025QHD0T92@092@T02OWil00P1iNGT01@2^[Zh0P8200820P026QXH0
Rh^;0080Zj^[00D0VYZJ08F5Q@25QHD0Ng]k07UiN@020<c<c00407EeM@2:RXX0RXZ:0:n_[`80Hf=S
00D0a/K6071`L02HV9P0V9RH08Z:RP0207EeM@0509^KV`2LW9`0Ph>308>3P`3IfMT00P0d=3@01@2Z
ZZX0UIFE07YjNP1jNWX0a<C40080SHf=00D0QXJ606IVIP1VIVH0R8R80:j^[P020:>SX`0507MgM`2T
Y:@0Y:BT0820P022PX800P2UYJD0102`/;00E5AD05ADE02j^[X2075aL@050:BTY01PH600no_k0?_k
n`0[:b/00P2/[:`01@2OWil0Ng]k0;:b/P2b/[80F5QH0080Xj>S00D0VYZJ09^KV`2KVi/0PX:209^K
V`0208^;R`0507UiN@34a<@0a<C407MgM`1VIVH00P2a/K401@2GUiL0WIfM09fMW@26QXH0QhN70080
PH6100@0QhN709jNWP2NWYh0jNWY0P0B4Q801@2/[:`0ZJVY07inOP1nOWh0YjNW0080]KFe00D0FUYJ
08b<S021PH40PH610;^k^`0206e]K@050;Rh^01>CTh0CTi>0<S8b02@T9000P22PX801@1`L700TY:B
09:BTP2XZ:P0XJ6Q0080QXJ600D0Q8B40;Rh^02h^;P0I6AT09FEU@0209nOW`0408N7Q`2>SXh0SXj>
08b<S080VIVI00D0SXj>0:2PX02DU9@0U9BD07EeM@02092@T00509JFUP2;Rh/0UiNG09NGU`2HV9P0
0P1bLW8309FEU@0509nOW`1fMWH0/k>c0;>c/`1kNg/00P2>SXh00`2^[Zh0oooo0?ooo`080?ooo`04
09bLW02EUID0UIFE08f=S@80S8b<00D0Rh^;07]kN`1fMWH0MWIf06e]K@02061PH00506QXJ01dM7@0
M7Ad07alO01iNGT00P26QXH01@2NWYh0]KFe0;Fe]@3;bl/0l_;b0080lo?c00@0c/k>0<?3``33`l<0
/K6a0P2BTY801@25QHD0UYJF09>CT`2CTi<0Rh^;0080SXj>00D0RHV908F5Q@27QhL0QhN708B4Q002
092@T00509ZJVP2RXZ80WIfM09fMW@2KVi/00P2BTY801@2CTi<0Ogmo07moO`21PH40QXJ60080O7al
00D0NGUi08f=S@2=SHd0WYjN0:b/[0020<_;b`040<K6aP2h^;P0^;Rh0:2PX080UIFE00D0OGem08V9
R@2LW9`0W9bL0;2`/0020;Bd]0050<?3``2k^k/0][Jf0;Jf]P2XZ:P00P2QXJ400`2<S8`0UIFE09FE
U@0209VIV@80WinO00D0/;2`0:JVYP2VYZH0Vi^K0:FUY@020:NWY`050:JVYP2g]kL0]kNg0;Rh^02`
/;000P2WYjL0102LW9`0Q8B408B4Q023Ph<207UiN@05079bLP1]KFd0N7Qh07QhN021PH400P28R8P0
102;Rh/0TI6A09nOW`2OWil309jNWP050:JVYP2e]KD0]KFe0:f][@2[Zj/00P2g]kL01@2k^k/0]kNg
0;Ng]`2m_Kd0a/K60080gMgM00D0c<c<0;jn_P2n_[h0][Jf0:n_[`0208j>SP04096AT@2BTY80TY:B
08>3P`80QHF500D0QXJ608n?S`2FUYH0UYJF0:j^[P020:f][@0509NGU`28R8P0RXZ:08Z:RP1`L700
0P1ZJVX01@1jNWX0QhN708N7Q`21PH40VIVI0080XJ6Q00@0/K6a0;Vi^@2i^KT0[:b/3`3oool000d0
oooo00@0IVIV08b<S02<S8`0`L710P24Q8@01@20P800QHF5092@T02@T900WinO0080NGUi00D0[Zj^
0820P020P800QXJ608^;R`020:^[Z`0509ZJVP25QHD0QHF507]kN`1iNGT00P3<c<`0101eMGD0RXZ:
08Z:RP2_[jl206=SH`050<K6aP1`L700V9RH09RHV02:RXX00P1eMGD01@2KVi/0W9bL08>3P`23Ph<0
fMWI0080=3@d00D0ZZZZ09FEU@1jNWX0NWYj0<C4a00208f=S@0508J6QP1VIVH0IVIV08R8R02^[Zh0
0P2SXj<01@1gMgL0Y:BT0:BTY020P800PX:20080YJFU00@0/;2`05ADE01DE5@0^[Zj0P1aLG401@2T
Y:@0H61P0?_kn`3kno/0:b/[0080[:b/00D0WinO07]kN`2b/[80/[:b05QHF0020:>SX`0509ZJVP2K
Vi/0Vi^K08:2PP2KVi/00P2;Rh/01@1iNGT0a<C40<C4a01gMgL0IVIV0080/K6a00D0UiNG09fMW@2M
WId0QXJ608N7Q`020861P@0408N7Q`2NWYh0WYjN0>WYj@804Q8B00D0[:b/0:VYZ@1nOWh0OWin0:NW
Y`020;Fe]@0505YJFP2<S8`0PH610861P@2k^k/00P1]KFd01@2h^;P0CTi>04i>CP38b<P0T92@0080
PX:200D0L71`09:BTP2BTY80Z:RX0:6QX@0208J6QP0508B4Q02h^;P0^;Rh06ATI02EUID00P2OWil0
1027QhL0SXj>08j>SP2<S8`209VIV@0508j>SP2PX:00U9BD09BDU01eMGD00P2@T9001@2FUYH0Rh^;
09NGU`2GUiL0V9RH0080LW9b0`2EUID01@2OWil0MWIf0;>c/`2c/k<0Ng]k0080SXj>00<0[Zj^0?oo
o`3oool0203oool0102LW9`0UIFE09FEU@2=SHd208b<S00508^;R`1kNg/0MWIf07IfMP1]KFd00P1P
H6001@1XJ6P0M7Ad07AdM01lO7`0NGUi0080QXJ600D0WYjN0;Fe]@2e]KD0bl_;0?;blP020??cl`04
0<k>cP33`l<0`l?30;6a/@80TY:B00D0QHF509JFUP2CTi<0Ti>C08^;R`0208j>SP0508V9R@25QHD0
QhN708N7Q`24Q8@00P2@T9001@2JVYX0XZ:R09fMW@2MWId0Vi^K0080TY:B00D0Ti>C07moO`1oOgl0
PH6108J6QP0207alO00507UiN@2=SHd0SHf=09jNWP2/[:`00P3;bl/01036a/H0^;Rh0;Rh^02PX:02
09FEU@0507emO@29RHT0W9bL09bLW02`/;000P2d];@01@33`l<0^k^k0;Jf]P2f][H0Z:RX0080XJ6Q
00<0S8b<09FEU@2EUID00P2IVIT209nOW`050;2`/02VYZH0YZJV09^KV`2UYJD00P2WYjL01@2VYZH0
]kNg0;Ng]`2h^;P0/;2`0080YjNW00@0W9bL08B4Q024Q8@0Ph>30P1iNGT01@1bLW80KFe]07QhN01h
N7P0PH610080R8R800@0Rh^;096AT@2OWil0WinO0`2NWYh01@2VYZH0]KFe0;Fe]@2][Jd0Zj^[0080
]kNg00D0^k^k0;Ng]`2g]kL0_Kfm0<K6aP020=gMg@050<c<c02n_[h0_[jn0;Jf]P2_[jl00P2>SXh0
102ATI40TY:B09:BTP23Ph<208F5Q@0508J6QP2?Shl0UYJF09JFUP2^[Zh00P2][Jd01@2GUiL0R8R8
08Z:RP2:RXX0L71`0080JVYZ00D0NWYj08N7Q`27QhL0PH6109VIV@020:6QX@040;6a/@2i^KT0^KVi
0:b/[0l0oooo000=0?ooo`0406][J`28R8P0R8R80<G5a@80OGem00D0Q8B408N7Q`2ATI40TI6A09NG
U`0207moO`050:f][@21PH40PH6108>3P`2?Shl00P2WYjL01@2MWId0QhN708N7Q`1fMWH0NGUi0080
clo?00@0NWYj08J6QP26QXH0Zj^[0P1TI6@01@37alL0LW9b09NGU`2GUiL0Rh^;0080MWIf00D0UiNG
09jNWP23Ph<0Ph>30=_Kf`0202l_;`050:j^[P2EUID0Lg=c07=cL`3>c/h00`26QXH206=SH`0508^;
R`2][Jd0ZJVY0:VYZ@1dM7@00P2RXZ801@24Q8@0Ng]k0:b/[02/[:`0[jn_0080EUIF00D0^;Rh07=c
L`1cLg<0Y:BT05mOG`020?knoP0502PX:02ZZZX0ZZZZ0:FUY@1aLG400P2j^[X0101CDe<0ZJVY0:VY
Z@2HV9P209^KV`050861P@2TY:@0OGem07emO@20P8000P35aLD01@1fMWH0IfMW0;Fe]@2e]KD0RXZ:
0080XJ6Q00D0SHf=08R8R01gMgL0MgMg092@T00209ZJVP050>WYj@0C4a<04a<C0:NWY`2_[jl00P1k
Ng/01@2ZZZX0/K6a0;6a/@1IFET0TI6A0080N7Qh00@0`l?306UYJ@1YJFT0^k^k0P1EEED01@2j^[X0
VIVI08N7Q`27QhL0JFUY0080Shn?00D0[Jf]0:2PX027QhL0QhN708:2PP020;>c/`0506a/K02EUID0
VYZJ09ZJVP28R8P00P2EUID01@2:RXX0TI6A096AT@2ATI40YZJV0080Ti>C00D0MGEe08j>SP2>SXh0
Vi^K07alO0020::RXP0409ZJVP1XJ6P0J6QX0:BTY080QhN700D0YZJV07IfMP2`/;00/;2`07]kN`02
08n?S`030:b/[03oool0oooo00P0oooo00@0Ng]k09>CT`2CTi<0W9bL0P2:RXX209^KV`80Rh^;00@0
Shn?0:ZZZP2ZZZX0WYjN0P2:RXX01@1gMgL0GUiN04E5A@15ADD0;bl_00<0=3@d00@0<30`03Ph>00h
>3P0Cdm?0P1HF5P01@1]KFd0SXj>08j>SP2XZ:P0/;2`0080^;Rh00D0`<300;Jf]P2f][H0ZZZZ09fM
W@0209>CT`0508j>SP2<S8`0S8b<08^;R`27QhL00P22PX8307alO00509^KV`31`L40`L710<S8b03E
eMD00P3QhN401@3EeMD0^;Rh0;Rh^02`/;00Xj>S0080V9RH0`23Ph<01@2?Shl0VYZJ09ZJVP2@T900
S8b<0080Q8B400D0JVYZ069RHP1RHV80HF5Q06UYJ@0206YZJP0406i^KP1UIFD0IFEU06YZJP80De=C
00D0Bd];04i>CP1HF5P0F5QH051@D00206=SH`0506UYJ@1^KVh0K6a/06a/K01gMgL00P1eMGD01@27
QhL0Vi^K0:ZZZP2ZZZX0^KVi00D0b<S800D0clo?0<k>cP35aLD0aLG50;Zj^P020:j^[P0309jNWP2J
VYX0Shn?0080Shn?0P2BTY801@2DU9@0QhN708N7Q`2;Rh/0QHF50080M7Ad00D0J6QX069RHP1RHV80
H61P069RHP0205eMG@0507YjNP2>SXh0SXj>08f=S@2<S8`00`2RXZ820;Bd]0050<g=c@39bLT0bLW9
0<71`@2WYjL00P2HV9P01@29RHT0UIFE09FEU@2c/k<0dm?C0080e=CD00@0gMgM0=KFeP3Fe]H0[Zj^
0P2:RXX01@27QhL0MGEe06m_K`1_Kfl0LG5a0080MGEe00<0JFUY0?ooo`3oool03@3oool000d0oooo
00@0LG5a0861P@21PH40clo?0P1dM7@01@25QHD0Rh^;096AT@2ATI40SXj>0080Rh^;00D0YZJV08B4
Q024Q8@0Ph>3092@T0020:JVYP0509VIV@2@T900T92@06m_K`1iNGT00P3@d=00101lO7`0Ph>308>3
P`2YZJT206UYJ@050<K6aP1_Kfl0VIVI09VIV@2:RXX00P1hN7P01@2ATI40XJ6Q0861P@21PH40gmoO
0080;bl_00D0ZJVY09ZJVP1_Kfl0Kfm_0=KFeP020820P00508R8R01OGel0GemO09:BTP2VYZH00P2b
/[801@1_Kfl0Vi^K09^KV`2@T900LG5a0080/[:b00@0[Jf]05YJFP1JFUX0[Jf]0P1jNWX01@2SXj<0
HF5Q0?[jnP3jn_X0;2`/0080ZJVY00D0YjNW06e]K@2l_;`0_;bl04i>CP020;6a/@0509>CT`2JVYX0
VYZJ07moO`2_[jl00P1dM7@01@23Ph<0a/K60<K6aP1eMGD0J6QX0080/k>c00D0QXJ60::RXP2RXZ80
Ti>C08Z:RP0206YZJP040:6QX@2?Shl0Shn?0>_[j`8051@D00D0YZJV0;2`/01jNWX0NWYj0:b/[002
0:j^[P0505]KF`2ATI40Lg=c07=cL`3;bl/00P1WIfL01@2f][H0G5aL05aLG02b/[80W9bL0080SXj>
00D0GUiN09>CT`2CTi<0[Jf]0:6QX@0208Z:RP050861P@2/[:`0[:b/075aL@2DU9@00P2IVIT01029
RHT0UiNG09NGU`2;Rh/208b<S00508j>SP2^[Zh0Shn?08n?S`1hN7P00P2;Rh/01@2SXj<0JFUY0:j^
[P2^[Zh0WinO0080HV9R00D0YjNW08>3P`23Ph<0YZJV07inOP020:RXZ00407moO`2ATI40TI6A0:JV
YPX0oooo00@0ZJVY09^KV`2KVi/0V9RH0`2/[:`0102_[jl0a<C40<C4a03=cLd20;fm_@050;Zj^P3;
bl/0bl_;0=SHf03Rh^800P3_knl01@3]kNd0fm_K0=_Kf`3<c<`0`l?30080_[jn00@0b<S80<O7a`37
alL0_;bl0P2b/[801@2JVYX0Q8B407IfMP1fMWH0KFe]0080L71`00D0Q8B409FEU@2OWil0WinO0:JV
YP020:FUY@0509NGU`2BTY80Vi^K09^KV`2SXj<00P2WYjL01@2FUYH0Shn?08n?S`2=SHd0RHV90080
Ph>300D0QhN708f=S@2=SHd0RHV90820P00207QhN00408Z:RP28R8P0R8R807alO080QXJ600D0WinO
0:^[Z`2d];@0];Bd0<k>cP020=WIf@050=GEe@3>c/h0dM7A0=7Ad@3IfMT00P3Lg=`01@3Kfm/0k>c/
0>c/k03Ng]h0`L7100<0/;2`0P2QXJ401@2RXZ80Z:RX0:b/[02/[:`0Xj>S0080T92@00D0Ph>307Mg
M`1/K6`0K6a/05mOG`0206MWI`0507YjNP1fMWH0MWIf07QhN01gMgL00P1^KVh01@1VIVH0Lg=c07=c
L`1nOWh0QhN70080UiNG00@0Ti>C09JFUP2FUYH0U9BD0P2HV9P01@2GUiL0XJ6Q0:VYZ@2YZJT0Zj^[
0080^KVi00D0a<C40<k>cP3>c/h0c/k>0<c<c0030<?3``040<G5a@2n_[h0_[jn0:b/[080TI6A00D0
Ng]k07moO`1oOgl0Ng]k09bLW0020:2PX00509fMW@20P800P82006m_K`18B4P00P1>CTh0101LG5`0
J6QX06QXJ023Ph<20:JVYP050:NWY`2YZJT0/;2`0;2`/02[Zj/00P2PX:000`2_[jl0oooo0?ooo`0=
0?ooo`003@3oool0101aLG40PH610861P@3?cll207AdM00508F5Q@2;Rh/0TI6A096AT@2>SXh00P2;
Rh/01@2VYZH0Q8B408B4Q023Ph<0T92@0080YZJV00D0VIVI092@T02@T900Kfm_07UiN@020=3@d004
07alO023Ph<0Ph>30:VYZ@80JFUY00D0a/K606m_K`2IVIT0VIVI08Z:RP0207QhN005096AT@2QXJ40
PH610861P@3Ogml00P0_;bl01@2YZJT0VYZJ06m_K`1_Kfl0e]KF0080P82000D0R8R805mOG`1OGel0
TY:B0:JVYP020;:b/P0506m_K`2KVi/0Vi^K092@T01aLG400P2b/[80102][Jd0FUYJ05YJFP2][Jd2
07YjNP050:>SX`1QHF40n_[j0?[jnP0/;2`00P2YZJT01@2WYjL0KFe]0;bl_02l_;`0CTi>0080/K6a
00D0Ti>C09ZJVP2JVYX0Ogmo0:n_[`0207AdM00508>3P`36a/H0a/K607EeM@1XJ6P00P2c/k<01@26
QXH0XZ:R0::RXP2CTi<0RXZ:0080JVYZ00@0XJ6Q08n?S`2?Shl0jn_[0P0D51@01@2VYZH0/;2`07Yj
NP1jNWX0[:b/0080[Zj^00D0Fe]K096AT@1cLg<0Lg=c0<_;b`0206MWI`050;Jf]P1LG5`0G5aL0;:b
/P2LW9`00P2>SXh01@1NGUh0Ti>C09>CT`2][Jd0XJ6Q0080RXZ:00D0PH610:b/[02/[:`0LG5a09BD
U00209VIV@0408V9R@2GUiL0UiNG08^;R`80S8b<00D0SXj>0:j^[P2?Shl0Shn?07QhN00208^;R`05
0:>SX`1YJFT0[Zj^0:j^[P2OWil00P1RHV801@2WYjL0Ph>308>3P`2VYZH0OWin0080Z:RX00@0Ogmo
096AT@2ATI40YZJV2P3oool0102YZJT0Vi^K09^KV`2HV9P30:b/[0040:n_[`34a<@0a<C40<g=c@80
_Kfm00D0^[Zj0<_;b`3;bl/0f=SH0>;RhP020>o_k`050>g]k@3Kfm/0fm_K0<c<c033`l<00P2n_[h0
1038b<P0alO70<O7a`2l_;`20;:b/P0509ZJVP24Q8@0MWIf07IfMP1]KFd00P1`L7001@24Q8@0UIFE
09nOW`2OWil0YZJV0080YJFU00D0UiNG09:BTP2KVi/0Vi^K0:>SX`020:NWY`0509JFUP2?Shl0Shn?
08f=S@29RHT00P23Ph<01@27QhL0SHf=08f=S@29RHT0P8200080N7Qh00@0RXZ:08R8R028R8P0O7al
0P26QXH01@2OWil0Zj^[0;Bd]02d];@0c/k>0080fMWI00D0eMGE0<k>cP3AdM40dM7A0=WIf@020=cL
g0050=_Kf`3/k>`0k>c/0=kNgP31`L400`2`/;020:6QX@050::RXP2XZ:P0[:b/0:b/[02SXj<00P2@
T9001@23Ph<0MgMg06a/K01/K6`0GemO0080IfMW00D0NWYj07IfMP1fMWH0N7Qh07MgM`0206i^KP05
06IVIP1cLg<0Lg=c07inOP27QhL00P2GUiL0102CTi<0UYJF09JFUP2DU9@209RHV00509NGU`2QXJ40
ZJVY0:VYZ@2[Zj/00P2i^KT01@34a<@0c/k>0<k>cP3>c/h0c<c<00<0`l?300@0aLG50;jn_P2n_[h0
[:b/0P2ATI401@1kNg/0Ogmo07moO`1kNg/0W9bL0080X:2P00D0WIfM0820P020P800Kfm_04Q8B002
04i>CP0405aLG01XJ6P0J6QX08>3P`80YZJV00D0YjNW0:VYZ@2`/;00/;2`0:^[Z`020:2PX0030:n_
[`3oool0oooo00d0oooo000=0?ooo`0407EeM@1mOGd0OGem0=CDe080Kfm_00D0P82009>CT`2HV9P0
V9RH0820P00209FEU@050:6QX@22PX80PX:208R8R02>SXh00P2TY:@01@2IVIT0U9BD09BDU01/K6`0
NGUi0080c/k>00@0O7al08N7Q`27QhL0ZJVY0P1YJFT01@36a/H0KVi^09VIV@2IVIT0RHV90080O7al
00D0S8b<0:BTY022PX80PX:20>3Ph00202l_;`050:BTY02KVi/0LG5a075aL@3Bd]800P21PH401@2=
SHd0GEeM05eMG@2GUiL0WIfM0080];Bd00D0LW9b09:BTP2BTY80WIfM06ATI0020;Rh^0040;6a/@1J
FUX0FUYJ0::RXP80PH6100D0Xj>S069RHP3clo<0lo?c038b<P020:NWY`050:BTY01dM7@0]KFe0;Fe
]@1ADE400P2e]KD01@2=SHd0WIfM09fMW@1kNg/0^[Zj0080JFUY00D0Rh^;0<K6aP36a/H0L71`06e]
K@020:b/[00508J6QP2RXZ80XZ:R09NGU`29RHT00P1RHV80102a/K40PX:208:2PP3^k^h201DE5@05
0:BTY02`/;00O7al07alO02YZJT00P2][Jd01@1NGUh0TY:B071`L01`L700b/[:0080Jf][00D0/k>c
06IVIP1VIVH0Z:RX09VIV@0209RHV005055AD@2LW9`0W9bL0:^[Z`2RXZ800P2;Rh/01@20P800XZ:R
0::RXP1nOWh0Shn?0080UIFE00@0S8b<09nOW`2OWil0QHF50P2?Shl01@26QXH0[Zj^09FEU@2EUID0
OGem0080QHF500D0ZZZZ05EEE@33`l<0`l?309RHV00206=SH`050:>SX`21PH40PH610:VYZ@27QhL0
0P2MWId01020P800UiNG09NGU`2PX:0:0?ooo`040:BTY02QXJ40XJ6Q09RHV080RXZ:00D0MgMg07Ui
N@1nOWh0OWin07MgM`0207alO00508R8R027QhL0QhN708B4Q02<S8`00P29RHT01@2DU9@0VIVI09VI
V@2FUYH0U9BD0080Ti>C00@0MgMg06m_K`1_Kfl0KFe]0P1ZJVX01@1eMGD0RXZ:09NGU`2GUiL0YZJV
0080[:b/00D0YjNW0:BTY02OWil0WinO09fMW@0209VIV@0509fMW@2QXJ40WinO09nOW`2EUID00P2H
V9P01@2GUiL0Ti>C09>CT`2EUID0VIVI0080UiNG00D0VIVI09RHV02HV9P0UiNG09ZJVP020:>SX`04
09ZJVP2EUID0UIFE0:2PX080Vi^K00D0R8R808j>SP2=SHd0SHf=0861P@0207QhN00507EeM@1WIfL0
GemO05mOG`1BDU800P1EEED305aLG00306i^KP26QXH0Shn?0080Shn?0P2FUYH01@2GUiL0Shn?08b<
S02<S8`0UiNG0080Xj>S00D0YZJV0:RXZ02TY:@0Y:BT0:JVYP0209RHV00508Z:RP28R8P0R8R808b<
S02CTi<00P2PX:001@2XZ:P0Xj>S0:>SX`2KVi/0UIFE0080T92@0`2>SXh01@2ATI40QhN708N7Q`24
Q8@0OWin0080Ng]k00D0OGem07AdM01dM7@0JVYZ06QXJ00205YJFP05055AD@1JFUX0FUYJ05eMG@1P
H6000P1eMGD01026QXH0WIfM09fMW@2_[jl209jNWP0509bLW02;Rh/0Ph>308>3P`24Q8@00P2PX:00
1@2_[jl0_kno0;Vi^@2i^KT0W9bL0080TY:B00D0Ph>308F5Q@25QHD0RXZ:09NGU`0209ZJVP<0Xj>S
00<0WinO0?ooo`3oool03@3oool000d0oooo00@0MgMg07YjNP1jNWX0emOG0P1/K6`01@1oOgl0Vi^K
09JFUP2FUYH0N7Qh0080WYjN00D0VYZJ0861P@21PH40Shn?08b<S0020:JVYP0509JFUP2CTi<0Ti>C
06UYJ@1mOGd00P3;bl/0101lO7`0SXj>08j>SP2RXZ8206YZJP050<W9b@1ZJVX0W9bL09bLW025QHD0
0P20P8001@27QhL0Z:RX08B4Q024Q8@0g]kN0080;Rh^00D0Xj>S09VIV@1hN7P0N7Qh0<[:bP0208B4
Q00508n?S`1JFUX0FUYJ09jNWP2HV9P00P2e]KD01@1cLg<0RXZ:08Z:RP2UYJD0HF5Q0080]kNg00@0
][Jf05YJFP1JFUX0VYZJ0P27QhL01@2RXZ80JFUY0>[ZjP3Zj^X0>3Ph0080XJ6Q00D0YJFU07UiN@2^
[Zh0[Zj^05EEE@020;Bd]00508f=S@2JVYX0VYZJ07QhN035aLD00P1LG5`01@2GUiL0`L710<71`@1`
L700K6a/0080[:b/00D0PX:20:NWY`2WYjL0V9RH08b<S00205ADE0040<?3``1hN7P0N7Qh0?3`l080
5ADE00D0YJFU0:f][@20P800P8200:BTY0020:j^[P0506ATI02=SHd0KVi^06i^KP3>c/h00P1]KFd0
1@2YZJT0L71`071`L02TY:@0U9BD0080Xj>S00D0@d=30:VYZ@2YZJT0Y:BT0:JVYP0208^;R`0508>3
P`2CTi<0Ti>C08j>SP2;Rh/00P2DU9@0102>SXh0WinO09nOW`21PH4209JFUP0507]kN`2c/k<0Ti>C
09>CT`23Ph<00P1hN7P01@2k^k/0@T920=GEe@3EeMD0Rh^;0080Jf][00D0WinO0820P020P800Zj^[
096AT@0208b<S00408R8R02KVi/0Vi^K09^KV`X0oooo00@0V9RH09FEU@2EUID0UiNG0`2LW9`0102C
Ti<0PX:208:2PP1fMWH206MWI`<0IVIV00D0JFUY07=cL`1mOGd0OGem07IfMP0207]kN`0508B4Q01l
O7`0MWIf07IfMP2:RXX00P2=SHd01@2EUID0XZ:R0::RXP2YZJT0VYZJ0080U9BD00<0QXJ608B4Q024
Q8@00P22PX82092@T00508j>SP21PH40PH6108F5Q@24Q8@00P1bLW80101mOGd0PX:208:2PP26QXH2
08^;R`0509RHV02GUiL0Vi^K09^KV`2OWil00`2[Zj/0102g]kL0aLG50<G5a@3Bd]830=cLg080clo?
00D0alO70:JVYP2HV9P0V9RH092@T00209^KV`050:BTY02j^[X0_;bl0;bl_035aLD00P2d];@00`2P
X:00QXJ608J6QP0207alO080Ph>300D0TY:B0:f][@2][Jd0Zj^[0:FUY@020:b/[0040:BTY02OWil0
WinO09nOW`<0XZ:R00@0X:2P0:FUY@2UYJD0[jn_0P2e]KD20;2`/080Zj^[00D0ZJVY09nOW`2OWil0
Xj>S09jNWP0209bLW00409jNWP2GUiL0UiNG09BDU080VIVI00D0Ti>C08V9R@2@T900T92@08N7Q`02
08J6QP0507inOP20P800QXJ608J6QP2<S8`00P27QhL01@2BTY80UIFE08R8R028R8P0RXZ:0080UIFE
00D0VYZJ0:n_[`2_[jl0`<300<71`@020;Ng]`050:f][@2FUYH0UYJF08J6QP23Ph<00P29RHT0102>
SXh0Shn?08n?S`27QhL2079bLP0505UIF@1?Cdl0EUIF05IFEP1RHV800P1eMGD00`2>SXh0oooo0?oo
o`0=0?ooo`003@3oool0101iNGT0N7Qh07QhN03Hf=P206e]K@0507alO02QXJ40U9BD09BDU01fMWH0
0P2QXJ401@2FUYH0P8200820P02GUiL0Rh^;0080X:2P00D0UYJF09BDU02DU9@0Jf][07inOP020<W9
b@0407inOP2>SXh0SXj>09nOW`80Kfm_00D0aLG506YZJP2OWil0WinO0861P@0208F5Q@0508:2PP2Y
ZJT0QXJ608J6QP3Kfm/00P0c<c<01@2OWil0VYZJ07]kN`1kNg/0aLG50080QhN700D0TI6A05EEE@1E
EED0Z:RX092@T0020;Rh^00507=cL`25QHD0QHF50:VYZ@1RHV800P2c/k<0102m_Kd0FUYJ05YJFP2B
TY8208b<S0050:>SX`1ZJVX0h^;R0>;RhP12@T800P2FUYH01@2XZ:P0Ogmo0:VYZ@2YZJT0Fe]K0080
/[:b00D0RHV909jNWP2NWYh0MGEe0<O7a`0205iNGP0509nOW`2b/[80/[:b07UiN@1WIfL00P2^[Zh0
1@1oOgl0Zj^[0:^[Z`2FUYH0Ti>C0080ADE500@0e=CD071`L01`L700l?3`0P0E5AD01@2WYjL0[:b/
0820P020P800YJFU0080[Jf]00D0IfMW08^;R`1]KFd0KFe]0=;BdP0206m_K`0509nOW`1hN7P0N7Qh
0:>SX`2?Shl00P2/[:`01@0f=SH0][Jf0;Jf]P2MWId0ZJVY0080SXj>00D0Ogmo08f=S@2=SHd0VIVI
08R8R002096AT@0408n?S`2TY:@0Y:BT07UiN@80X:2P00D0Kfm_0;:b/P2KVi/0Vi^K08>3P`0207Yj
NP050;fm_@0d=3@0i>CT0>CTi01oOgl00P1gMgL308j>SP050:JVYP2HV9P0OWin07inOP2=SHd00P2Q
XJ400`2FUYH0oooo0?ooo`080?ooo`0307EeM@1oOgl0Ogmo00<0NWYj00D0OWin08j>SP2EUID0UIFE
0;:b/P020;^k^`050;Zj^P2e]KD0]KFe0:f][@2PX:000P2QXJ401@2`/;00]KFe0;Fe]@31`L40`l?3
0080aLG500@0^;Rh0;Jf]P2f][H0Zj^[0P2UYJD01@2RXZ80YjNW0:NWY`2WYjL0Z:RX0080XJ6Q00D0
WIfM09bLW02FUYH0UYJF09nOW`020;2`/0050;fm_@2][Jd0Y:BT0:BTY02BTY800P2>SXh01@1oOgl0
Q8B408B4Q020P800Ph>30080O7al00D0MWIf075aL@1aLG40NWYj0820P00207EeM@0406][J`1VIVH0
IVIV06QXJ080IVIV00D0LW9b08Z:RP2KVi/0Vi^K09NGU`0208j>SP0508:2PP1lO7`0PH610861P@28
R8P00P2OWil01@2d];@0d=3@0=3@d03Cdm<0f=SH0080dM7A00D0a<C40:NWY`2WYjL0YZJV0:VYZ@02
0::RXP050:2PX02IVIT0VIVI092@T024Q8@00`26QXH208V9R@050861P@1lO7`0O7al07IfMP1UIFD0
0P1MGEd01@1JFUX0IVIV06IVIP1eMGD0O7al0080PH6100@0Rh^;09FEU@2EUID0Ti>C0P2TY:@00`2]
[Jd0[jn_0:NWY`020:NWY`80Z:RX00D0[jn_0:^[Z`2/[:`0[:b/09^KV`0209JFUP0508n?S`2<S8`0
UiNG09NGU`2KVi/00P2CTi<01@2ATI40QhN708N7Q`1aLG40NGUi0080R8R800@0Shn?09fMW@2MWId0
ZJVY0`2WYjL0102XZ:P0ZZZZ0:ZZZP2h^;P20<k>cP050=SHf03IfMT0clo?0<o?c`2i^KT00P2OWil0
0`27QhL0oooo0?ooo`0=0?ooo`003@3oool0101iNGT0N7Qh07QhN03Hf=P206e]K@0507alO02QXJ40
U9BD09BDU01fMWH00P2QXJ401@2FUYH0P8200820P02GUiL0Rh^;0080X:2P00D0UYJF09BDU02DU9@0
Jf][07inOP020<W9b@0407inOP2>SXh0SXj>09nOW`80Kfm_00D0aLG506YZJP2OWil0WinO0861P@02
08F5Q@0508:2PP2YZJT0QXJ608J6QP3Kfm/00P0c<c<01@2OWil0VYZJ07]kN`1kNg/0aLG50080QhN7
00D0TI6A05EEE@1EEED0Z:RX092@T0020;Rh^00507=cL`25QHD0QHF50:VYZ@1RHV800P2c/k<0102m
_Kd0FUYJ05YJFP2BTY8208b<S0050:>SX`1ZJVX0h^;R0>;RhP12@T800P2FUYH01@2XZ:P0Ogmo0:VY
Z@2YZJT0Fe]K0080/[:b00D0RHV909jNWP2NWYh0MGEe0<O7a`0205iNGP0509nOW`2b/[80/[:b07Ui
N@1WIfL00P2^[Zh01@1oOgl0Zj^[0:^[Z`2FUYH0Ti>C0080ADE500@0e=CD071`L01`L700l?3`0P0E
5AD01@2WYjL0[:b/0820P020P800YJFU0080[Jf]00D0IfMW08^;R`1]KFd0KFe]0=;BdP0206m_K`05
09nOW`1hN7P0N7Qh0:>SX`2?Shl00P2/[:`01@0f=SH0][Jf0;Jf]P2MWId0ZJVY0080SXj>00D0Ogmo
08f=S@2=SHd0VIVI08R8R002096AT@0408n?S`2TY:@0Y:BT07UiN@80X:2P00D0Kfm_0;:b/P2KVi/0
Vi^K08>3P`0207YjNP050;fm_@0d=3@0i>CT0>CTi01oOgl00P1gMgL308j>SP050:JVYP2HV9P0OWin
07inOP2=SHd00P2QXJ400`2FUYH0oooo0?ooo`080?ooo`0307EeM@1oOgl0Ogmo00<0NWYj00D0OWin
08j>SP2EUID0UIFE0;:b/P020;^k^`050;Zj^P2e]KD0]KFe0:f][@2PX:000P2QXJ401@2`/;00]KFe
0;Fe]@31`L40`l?30080aLG500@0^;Rh0;Jf]P2f][H0Zj^[0P2UYJD01@2RXZ80YjNW0:NWY`2WYjL0
Z:RX0080XJ6Q00D0WIfM09bLW02FUYH0UYJF09nOW`020;2`/0050;fm_@2][Jd0Y:BT0:BTY02BTY80
0P2>SXh01@1oOgl0Q8B408B4Q020P800Ph>30080O7al00D0MWIf075aL@1aLG40NWYj0820P00207Ee
M@0406][J`1VIVH0IVIV06QXJ080IVIV00D0LW9b08Z:RP2KVi/0Vi^K09NGU`0208j>SP0508:2PP1l
O7`0PH610861P@28R8P00P2OWil01@2d];@0d=3@0=3@d03Cdm<0f=SH0080dM7A00D0a<C40:NWY`2W
YjL0YZJV0:VYZ@020::RXP050:2PX02IVIT0VIVI092@T024Q8@00`26QXH208V9R@050861P@1lO7`0
O7al07IfMP1UIFD00P1MGEd01@1JFUX0IVIV06IVIP1eMGD0O7al0080PH6100@0Rh^;09FEU@2EUID0
Ti>C0P2TY:@00`2][Jd0[jn_0:NWY`020:NWY`80Z:RX00D0[jn_0:^[Z`2/[:`0[:b/09^KV`0209JF
UP0508n?S`2<S8`0UiNG09NGU`2KVi/00P2CTi<01@2ATI40QhN708N7Q`1aLG40NGUi0080R8R800@0
Shn?09fMW@2MWId0ZJVY0`2WYjL0102XZ:P0ZZZZ0:ZZZP2h^;P20<k>cP050=SHf03IfMT0clo?0<o?
c`2i^KT00P2OWil00`27QhL0oooo0?ooo`0=0?ooo`003@3oool0101kNg/0MgMg07MgM`3GemL206m_
K`0507QhN02UYJD0Ti>C09>CT`1cLg<00P2UYJD01@2DU9@0OGem07emO@2OWil0QhN70080WinO00D0
UIFE092@T02@T900L71`07moO`020<K6aP0407emO@2ATI40TI6A0:6QX@80JFUY00D0bl_;06IVIP2S
Xj<0Xj>S07emO@0208R8R00507inOP2/[:`0R8R808R8R03Hf=P00P0g=cL01@2JVYX0UiNG08>3P`23
Ph<0`<300080QhN700D0UIFE055AD@1ADE40/K6a08F5Q@020;jn_P05075aL@21PH40PH610:b/[01T
I6@00P2^[Zh01031`L40Fe]K05]KF`2=SHd208n?S`050::RXP1_Kfl0emOG0=OGe`1>CTh00P2=SHd0
1@2XZ:P0R8R80:6QX@2QXJ40Hf=S0080[:b/00D0QhN70:2PX02PX:00MGEe0<[:bP0205aLG0050:JV
YP2TY:@0Y:BT08:2PP1QHF400P2a/K401@1mOGd0/K6a0;6a/@2CTi<0VYZJ0080=3@d00@0hn?S06a/
K01/K6`0k>c/0P0I6AT01@2TY:@0[Jf]07emO@1mOGd0YJFU0080[jn_00D0J6QX08Z:RP1/K6`0K6a/
0=7Ad@0207MgM`0509NGU`1mOGd0OGem0:BTY02:RXX00P2a/K401@0];Bd0`<300<30`02FUYH0ZZZZ
0080TY:B00D0OGem08^;R`2;Rh/0WYjN08B4Q002096AT@04092@T02SXj<0Xj>S07UiN@80YZJV00D0
HF5Q0;fm_@2HV9P0V9RH08>3P`0207QhN0040<;2`P0b<S80i^KV0>KViP<0OGem00D0P82009bLW02L
W9`0XJ6Q09^KV`0207EeM@0409RHV02RXZ80XZ:R08j>SPX0oooo00@0_;bl0;Bd]02d];@0^[Zj0P2g
]kL20<30`080`/;200@0[:b/0:^[Z`2[Zj/0YZJV0P2IVIT01@2JVYX0X:2P09>CT`2CTi<0N7Qh0080
MGEe00D0FEUI04];B`1CDe<0De=C069RHP0206EUI@0407IfMP1jNWX0NWYj07MgM`<0NWYj00D0N7Qh
07UiN@1iNGT0MgMg07IfMP0206i^KP0506e]K@1`L700L71`06e]K@27QhL00P2d];@0103<c<`0b/[:
0<[:bP3Hf=P20=7Ad@050<71`@2g]kL0alO70<O7a`2m_Kd00P2g]kL01@2XZ:P0Shn?07QhN01hN7P0
LW9b0080IfMW00D0GEeM06i^KP1^KVh0LG5a07AdM00206][J`0507EeM@1^KVh0KVi^07IfMP1kNg/0
0P1mOGd01023Ph<0R8R808R8R02<S8`207moO`0508R8R025QHD0PX:208:2PP1jNWX00P1bLW801@1a
LG40HV9R069RHP1RHV80H61P0080PH6100D0Shn?09nOW`2XZ:P0Z:RX0;>c/`020:>SX`0509^KV`2P
X:00X:2P0:FUY@2/[:`00P2d];@01@2n_[h0]KFe0;Fe]@2HV9P0XJ6Q0080YjNW00@0WinO09RHV02H
V9P0YjNW0P2EUID01@26QXH0Ph>308f=S@2=SHd0UIFE0080UYJF00D0VYZJ0:JVYP2WYjL0YjNW0;Rh
^0020;Vi^@050;Rh^02i^KT0ZZZZ0:ZZZP2LW9`00P2MWId01@2?Shl0RHV908V9R@2IVIT0Rh^;0080
LG5a00D0Jf][06MWI`1WIfL0JFUY07=cL`0207moO`0309bLW02WYjL0YjNW00<0YZJV00D0^[Zj0;fm
_@2h^;P0^;Rh0;jn_P020<W9b@030<30`03oool0oooo00d0oooo000=0?ooo`0407QhN01gMgL0MgMg
0=OGe`80LW9b00D0M7Ad0:JVYP2EUID0UIFE075aL@020:BTY00509RHV01hN7P0N7Qh0:>SX`28R8P0
0P2KVi/01@2IVIT0S8b<08b<S01cLg<0OGem0080bLW900@0NWYj08n?S`2?Shl0Y:BT0P1TI6@01@3B
d]80HV9R0:FUY@2UYJD0O7al0080RXZ:00D0NWYj0:n_[`2:RXX0RXZ:0=?Cd`0203Xj>P0509^KV`2B
TY80R8R808R8R02l_;`00P2;Rh/01@2CTi<0DU9B059BDP2e]KD0OGem0080`L7100D0MGEe07]kN`1k
Ng/0ZZZZ06][J`020:^[Z`040<;2`P1MGEd0GEeM08R8R080U9BD00D0WinO07AdM03=cLd0cLg=05aL
G00207moO`050:ZZZP2BTY80VIVI09VIV@1_Kfl00P2PX:001@26QXH0Xj>S0:>SX`1eMGD0bl_;0080
EeMG00D0[Zj^09NGU`2GUiL0SHf=05]KF`020;Rh^00507IfMP2c/k<0/k>c09>CT`2OWil00P0X:2P0
103[jn/0Kfm_06m_K`3Shn<2020P80050:BTY02/[:`0OGem07emO@2TY:@00P2c/k<01@1XJ6P0QhN7
06][J`1[Jf/0cLg=0080OWin00D0Ti>C0820P020P800X:2P08^;R`020;:b/P0502XZ:P36a/H0a/K6
096AT@2[Zj/00P2CTi<01@1jNWX0SHf=08f=S@2OWil0PX:20080TY:B00@0SXj>0:BTY02TY:@0MWIf
0P2_[jl01@1FEUH0_[jn09fMW@2MWId0Q8B40080NWYj00D0`<3003@d=03QhN40hN7Q07emO@0208N7
Q`0506m_K`2ZZZX0ZZZZ09nOW`2GUiL00P1cLg<309jNWP0309:BTP3oool0oooo00P0oooo00@0HF5Q
06YZJP1ZJVX0M7Ad0P1mOGd00`1bLW80L71`06EUI@0206EUI@80IVIV00D0Lg=c09RHV02HV9P0YjNW
09^KV`0209NGU`0509VIV@1kNg/0Ng]k08V9R@2d];@00P2k^k/0102n_[h0c/k>0<k>cP2m_Kd20:NW
Y`050:>SX`2RXZ80WYjN09jNWP2a/K400P2l_;`01@36a/H0_Kfm0;fm_@2m_Kd0Zj^[0080ZJVY00D0
U9BD08j>SP1gMgL0MgMg075aL@0206ATI00506][J`1`L700L71`07YjNP1lO7`00P1jNWX01@1iNGT0
Ng]k07]kN`1nOWh0QXJ60080TY:B00@0YZJV0;Bd]02d];@0`L710P35aLD01@37alL0bLW90<_;b`3;
bl/0bLW90080c/k>00D0c<c<0<71`@32`/80`/;20:f][@0209fMW@0509BDU023Ph<0Ph>307=cL`1j
NWX00P1fMWH01@1nOWh0U9BD09BDU02:RXX0TY:B0080X:2P00D0WinO08Z:RP2:RXX0SXj>08B4Q002
07]kN`04079bLP22PX80PX:208n?S`80SHf=00D0QXJ608j>SP2CTi<0Ti>C08Z:RP0209VIV@050;Fe
]@2c/k<0Zj^[0:^[Z`2^[Zh00P2/[:`01@2KVi/0WYjN09jNWP2UYJD0/;2`0080[Jf]00D0[:b/0:NW
Y`2WYjL0[:b/09FEU@0309^KV`80YZJV0P2QXJ420:2PX00409BDU01eMGD0MGEe079bLP80MGEe00D0
Hf=S06MWI`2IVIT0VIVI0:FUY@020;Rh^0050;Zj^P2n_[h0ZJVY0:VYZ@25QHD00P1cLg<01@1hN7P0
L71`071`L01IFET0H61P0080GUiN00@0DE5A04e=C@1=CDd0FEUI3`3oool000d0oooo00@0N7Qh07Mg
M`1gMgL0emOG0P1bLW801@1dM7@0YZJV09FEU@2EUID0LG5a0080Y:BT00D0V9RH07QhN01hN7P0Xj>S
08R8R00209^KV`0509VIV@2<S8`0S8b<07=cL`1mOGd00P39bLT0101jNWX0Shn?08n?S`2TY:@206AT
I0050=;BdP1RHV80YJFU0:FUY@1lO7`00P2:RXX01@1jNWX0[jn_08Z:RP2:RXX0dm?C0080>SXj00D0
Vi^K09:BTP28R8P0R8R80;bl_00208^;R`0509>CT`1BDU80DU9B0;Fe]@1mOGd00P31`L401@1eMGD0
Ng]k07]kN`2ZZZX0Jf][0080Zj^[00@0`/;205eMG@1MGEd0R8R80P2DU9@01@2OWil0M7Ad0<g=c@3=
cLd0G5aL0080Ogmo00D0ZZZZ09:BTP2IVIT0VIVI06m_K`020:2PX00508J6QP2SXj<0Xj>S07EeM@3;
bl/00P1GEeL01@2^[Zh0UiNG09NGU`2=SHd0Fe]K0080^;Rh00D0MWIf0;>c/`2c/k<0Ti>C09nOW`02
02PX:0040>_[j`1_Kfl0Kfm_0>?Sh`80820P00D0Y:BT0:b/[01mOGd0OGem0:BTY0020;>c/`0506QX
J027QhL0Jf][06][J`3=cLd00P1nOWh01@2CTi<0P8200820P02PX:00Rh^;0080/[:b00D0:RXZ0<K6
aP36a/H0TI6A0:^[Z`0209>CT`0507YjNP2=SHd0SHf=09nOW`22PX800P2BTY80102>SXh0Y:BT0:BT
Y01fMWH20:n_[`0505IFEP2n_[h0WIfM09fMW@24Q8@00P1jNWX01@30`<00=3@d0>7Qh@3QhN40OGem
0080QhN700D0Kfm_0:ZZZP2ZZZX0WinO09NGU`0207=cL`<0WYjN00<0TY:B0?ooo`3oool0203oool0
101QHF40JVYZ06YZJP1dM7@207emO@03079bLP1`L700IFEU0080IFEU0P1VIVH01@1cLg<0V9RH09RH
V02WYjL0Vi^K0080UiNG00D0VIVI07]kN`1kNg/0RHV90;Bd]0020;^k^`040;jn_P3>c/h0c/k>0;fm
_@80YjNW00D0Xj>S0::RXP2NWYh0WYjN0;6a/@020;bl_0050<K6aP2m_Kd0_Kfm0;fm_@2[Zj/00P2Y
ZJT01@2DU9@0SXj>07MgM`1gMgL0LG5a0080I6AT00D0Jf][071`L01`L700NWYj07alO00207YjNP05
07UiN@1kNg/0Ng]k07inOP26QXH00P2BTY80102VYZH0];Bd0;Bd]031`L420<G5a@050<O7a`39bLT0
bl_;0<_;b`39bLT00P3>c/h01@3<c<`0`L710<;2`P32`/80[Jf]0080WIfM00D0U9BD08>3P`23Ph<0
Lg=c07YjNP0207IfMP0507inOP2DU9@0U9BD08Z:RP2BTY800P2PX:001@2OWil0RXZ:08Z:RP2>SXh0
Q8B40080Ng]k00@0LW9b08:2PP22PX80Shn?0P2=SHd01@26QXH0SXj>09>CT`2CTi<0RXZ:0080VIVI
00D0]KFe0;>c/`2[Zj/0Zj^[0:j^[P020:b/[00509^KV`2NWYh0WYjN0:FUY@2`/;000P2][Jd01@2/
[:`0YjNW0:NWY`2/[:`0UIFE00<0Vi^K0P2VYZH20:6QX@80X:2P00@0U9BD07EeM@1eMGD0LW9b0P1e
MGD01@1SHf<0IfMW09VIV@2IVIT0YJFU0080^;Rh00D0^[Zj0;jn_P2YZJT0ZJVY08F5Q@0207=cL`05
07QhN01`L700L71`05UIF@1PH6000P1NGUh0101ADE40CDe=04e=C@1IFET?0?ooo`003@3oool0101f
MWH0N7Qh07QhN03Hf=P2075aL@0507IfMP2SXj<0UIFE09FEU@1aLG400P2UYJD01@2GUiL0NWYj07Yj
NP2RXZ80SHf=0080UYJF00D0VYZJ08^;R`2;Rh/0M7Ad0861P@020<O7a`0407]kN`2=SHd0SHf=0:JV
YP80I6AT00D0c/k>06QXJ02TY:@0Y:BT07QhN00208b<S00507MgM`2a/K40SXj>08j>SP3<c<`00P10
@4001@2IVIT0Shn?08^;R`2;Rh/0_Kfm0080RHV900D0Ti>C05ADE01DE5@0]KFe07YjNP020<;2`P05
07EeM@1jNWX0NWYj0:FUY@1iNGT00P2RXZ80102o_kl0IFEU06EUI@22PX8209NGU`0509fMW@1hN7P0
a<C40<C4a01YJFT00P1aLG401@2a/K40UYJF096AT@2ATI40O7al0080TY:B00D0S8b<0::RXP2RXZ80
NGUi0<S8b00205MGE`050;>c/`29RHT0RHV909fMW@1=CDd00P34a<@00`1aLG40]kNg0;Ng]`0209NG
U`80:RXZ00@0k>c/079bLP1bLW80g]kN0P0P82001@2UYJD0[:b/07inOP1nOWh0Y:BT0080/k>c00D0
K6a/0861P@1[Jf/0Jf][0=KFeP0207UiN@0508j>SP26QXH0QXJ609bLW02=SHd00P2b/[801@0[:b/0
alO70<O7a`2>SXh0Zj^[0080UIFE00D0Ng]k08f=S@2=SHd0Xj>S07]kN`0209>CT`04092@T02OWil0
WinO07]kN`80[Jf]00D0E5AD0<G5a@2LW9`0W9bL07alO00208>3P`050;Rh^011@D40dM7A0=7Ad@22
PX800P2<S8`01@1XJ6P0/K6a0;6a/@2IVIT0Ti>C0080NGUi00@0XJ6Q09BDU02DU9@0VYZJ2P3oool0
1034a<@0^;Rh0;Rh^02][Jd20::RXP0509fMW@2CTi<0W9bL09bLW02PX:000P2ZZZX01@2WYjL0TY:B
09:BTP28R8P0Ti>C0080UiNG00D0Z:RX0=3@d03@d=00e]KF0;bl_0020;Bd]0040:f][@29RHT0RHV9
08J6QP80TY:B00D0U9BD08^;R`2KVi/0Vi^K08n?S`0208Z:RP0508J6QP2@T900UYJF09JFUP2XZ:P0
0`2GUiL309RHV00408^;R`2WYjL0YjNW0:RXZ080VIVI00D0UYJF09VIV@2>SXh0SXj>09BDU0020:2P
X0050;>c/`2i^KT0_Kfm0;fm_@2c/k<00P2[Zj/01@2KVi/0UYJF09JFUP2:RXX0Ogmo0080NWYj00D0
MWIf07=cL`1cLg<0NGUi08F5Q@0208J6QP0409FEU@2KVi/0Vi^K0:6QX@80_;bl00D0cLg=0;fm_@31
`L40`L710;Fe]@0209NGU`0509RHV02LW9`0T92@092@T02PX:000P2[Zj/01@2YZJT0[jn_0;Jf]P2f
][H0]KFe0080/k>c00D0Zj^[0:j^[P2^[Zh0/K6a0:ZZZP0209ZJVP05096AT@21PH40PH6107EeM@1/
K6`00P1ZJVX0101aLG40O7al07alO025QHD2096AT@0509RHV02GUiL0TI6A096AT@2?Shl00P25QHD0
101gMgL0N7Qh079bLP1bLW8306i^KP0507alO029RHT0QHF508F5Q@2DU9@00P2b/[801@2`/;00/k>c
0;>c/`3@d=00dm?C0080YZJV00D0UiNG08N7Q`27QhL0LW9b06UYJ@0207inOP040:2PX02TY:@0Y:BT
0:^[Z`80XJ6Q00D0X:2P09bLW02WYjL0YjNW0;>c/`020;bl_0030<O7a`3oool0oooo00d0oooo000=
0?ooo`0407AdM01jNWX0NWYj0=GEe@80LW9b00D0MWIf0:6QX@2EUID0UIFE07AdM0020:>SX`0309VI
V@1mOGd0OGem0080UiNG0P2>SXh01@2KVi/0Rh^;08^;R`1jNWX0Ogmo0080alO700@0Ng]k08V9R@29
RHT0Zj^[0P1XJ6P01@2o_kl0L71`0:FUY@2UYJD0N7Qh0080SXj>00D0N7Qh0:b/[02BTY80TY:B0<S8
b00204M7A`0509>CT`2>SXh0Shn?08n?S`2l_;`00P2:RXX01@2ATI40FEUI05UIF@2`/;00Ng]k0080
`L7100D0MGEe07]kN`1kNg/0WYjN08^;R`0209RHV0040;Vi^@1_Kfl0Kfm_07emO@80VYZJ00D0W9bL
07QhN02n_[h0_[jn079bLP0206UYJ@050;Fe]@2JVYX0R8R808R8R029RHT00P25QHD01@2BTY80WinO
09nOW`1mOGd0a<C40080FEUI00D0][Jf07inOP1nOWh0[:b/04A4A0020<?3``0507AdM02h^;P0^;Rh
09FEU@2GUiL00P0Y:BT0103Xj>P0N7Qh07QhN03Kfm/2020P80050:JVYP2YZJT0P8200820P02WYjL0
0P2a/K401@1ZJVX0P82006m_K`1_Kfl0d=3@0080Ogmo00D0RXZ:08b<S02<S8`0U9BD09:BTP020;2`
/00502h^;P33`l<0`l?3096AT@2UYJD00P2KVi/01@1iNGT0T92@092@T02RXZ80OWin0080SHf=00@0
Shn?09jNWP2NWYh0OWin0P2[Zj/01@1HF5P0a<C40:6QX@2QXJ40LG5a0080SHf=00D0/;2`04i>CP2h
^;P0^;Rh09JFUP0208^;R`05065QH@2k^k/0^k^k09JFUP23Ph<00P26QXH0102TY:@0RXZ:08Z:RP2R
XZ8:0?ooo`0408R8R02JVYX0VYZJ0:2PX080YjNW00D0/[:b0;no_`2g]kL0]kNg0:n_[`020:FUY@05
09^KV`2CTi<0Ti>C096AT@2JVYX00P2^[Zh01@2g]kL0[:b/0:b/[02f][H0^;Rh0080YjNW00@0WIfM
0;2`/02`/;00]KFe0P2d];@01@2b/[80/k>c0:FUY@2UYJD0UiNG00<0T92@00@0S8b<08R8R028R8P0
Q8B40P2>SXh01@2HV9P0T92@09>CT`2CTi<0WIfM0080U9BD00D0R8R809NGU`2GUiL0Ti>C09NGU`03
09BDU080RXZ:00D0Ph>30820P029RHT0RHV9092@T0020:2PX0050:RXZ02NWYh0WYjN09jNWP2PX:00
0P2RXZ801@2UYJD0];Bd0;Bd]02_[jl0[:b/0080Xj>S00@0X:2P09VIV@2IVIT0VYZJ0P2:RXX01@26
QXH0Rh^;08:2PP22PX80O7al0080S8b<00D0Ti>C09NGU`2MWId0WIfM09NGU`0208Z:RP050820P01]
KFd0HF5Q065QH@1DE5@00P1=CDd01@1<C4`0DU9B059BDP1RHV80PX:20080ZJVY00D0b/[:0=WIf@3I
fMT0gMgM0=KFeP020<71`@040:NWY`2CTi<0Ti>C07alO080KFe]00D0IVIV06ATI01]KFd0KFe]07Yj
NP0208n?S`0309NGU`2NWYh0XZ:R0080XZ:R0P2JVYX01@2OWil0UiNG09RHV02HV9P0TI6A0080R8R8
00D0TY:B08:2PP22PX80J6QX06UYJ@0208V9R@0508n?S`2YZJT0ZJVY0<30`033`l<00P2_[jl0102C
Ti<0Rh^;08^;R`25QHD208R8R00508n?S`2@T900QXJ608J6QP28R8P00P2>SXh00`23Ph<0oooo0?oo
o`0=0?ooo`003@3oool0101_Kfl0OGem07emO@3Cdm<207AdM00507MgM`2QXJ40TY:B09:BTP1gMgL0
0P2RXZ801@2MWId0Ogmo07moO`2ATI40VIVI0080TY:B00D0Vi^K08J6QP26QXH0OGem07alO0020<O7
a`0407YjNP28R8P0R8R80;2`/080IfMW00D0^;Rh075aL@2WYjL0YjNW07MgM`0208j>SP0507UiN@2/
[:`0UYJF09JFUP32`/800P1;Bd/01@2@T900RHV909VIV@2IVIT0]KFe0080RHV900D0TY:B069RHP1R
HV80YZJV07emO@020<71`@0507=cL`1oOgl0Ogmo09NGU`2LW9`00P2;Rh/0102e]KD0MGEe07EeM@1k
Ng/209jNWP0509ZJVP1dM7@0^[Zj0;Zj^P1nOWh00P1UIFD01@2c/k<0WYjN0861P@21PH40TY:B0080
N7Qh00D0WinO09JFUP2FUYH0PX:20<C4a00205MGE`050;Ng]`1fMWH0MWIf0;Vi^@0o?cl00P33`l<0
1@1cLg<0^[Zj0;Zj^P2HV9P0UIFE0080:RXZ00@0h>3P0861P@21PH40fMWI0P0P82001@2XZ:P0YZJV
08B4Q024Q8@0Y:BT0080/[:b00D0Jf][07alO01dM7@0M7Ad0<[:bP0208>3P`0508N7Q`2@T900T92@
092@T02GUiL00P2ZZZX01@0h>3P0^KVi0;Vi^@2EUID0WinO0080WYjN00D0OWin08f=S@2=SHd0Y:BT
0820P00208Z:RP04096AT@2EUID0UIFE08Z:RP80XJ6Q00D0HV9R0;bl_02ZZZX0ZZZZ06a/K00208Z:
RP050;2`/01LG5`0WYjN09jNWP2ZZZX00P28R8P01@1TI6@0/k>c0;>c/`2HV9P0O7al0080UIFE00@0
XZ:R0861P@21PH40ZJVY2P3oool01022PX80O7al07alO01nOWh208J6QP0507emO@1bLW80OWin07in
OP25QHD00P20P8001@25QHD0TI6A096AT@2>SXh0OWin0080KFe]00D0G5aL05UIF@1IFET0BTY:04M7
A`0205QHF004065QH@1[Jf/0Jf][06=SH`80KVi^00D0NGUi08>3P`1mOGd0OGem09^KV`030:>SX`04
0:VYZ@2j^[X0^[Zj0;^k^`80`<3000D0alO70<S8b02/[:`0[:b/0:2PX00209nOW`05092@T02:RXX0
RXZ:09BDU029RHT00P22PX801@1nOWh0PX:208:2PP21PH40RHV90080Ph>300@0QhN707UiN@1iNGT0
OWin0P24Q8@01@2;Rh/0Ph>308B4Q024Q8@0QHF50080PX:200D0P82008:2PP23Ph<0Ph>307]kN`02
07YjNP0307EeM@1lO7`0O7al0080OGem0P28R8P0102QXJ40Xj>S0:>SX`2RXZ830:6QX@050:NWY`2P
X:00X:2P0;6a/@38b<P00P3De=@0103Shn<0oooo0?ooo`3oool20>g]k@050=SHf02VYZH0MgMg07Mg
M`1NGUh00P1BDU801@1:BTX0H61P08F5Q@25QHD0UiNG0080ZZZZ00D0`L710;Ng]`2g]kL0Xj>S0:6Q
X@0209ZJVP0508n?S`2<S8`0S8b<08n?S`2ATI400P2;Rh/01@27QhL0SHf=08f=S@25QHD0QXJ60080
UiNG00@0Z:RX0:6QX@2QXJ40ZJVY0P3?cll00`3emOD0nOWi0?ooo`020?ooo`80inOW00D0a/K60;fm
_@2i^KT0^KVi0=CDe0020=gMg@050=SHf03EeMD0eMGE0=[JfP3;bl/00P2k^k/0102/[:`0VIVI09VI
V@2@T90?0?ooo`003@3oool0101_Kfl0OGem07emO@3Cdm<207AdM00507MgM`2QXJ40TY:B09:BTP1g
MgL00P2RXZ801@2MWId0Ogmo07moO`2ATI40VIVI0080TY:B00D0Vi^K08J6QP26QXH0OGem07alO002
0<O7a`0407YjNP28R8P0R8R80;2`/080IfMW00D0^;Rh075aL@2WYjL0YjNW07MgM`0208j>SP0507Ui
N@2/[:`0UYJF09JFUP32`/800P1;Bd/01@2@T900RHV909VIV@2IVIT0]KFe0080RHV900D0TY:B069R
HP1RHV80YZJV07emO@020<71`@0507=cL`1oOgl0Ogmo09NGU`2LW9`00P2;Rh/0102e]KD0MGEe07Ee
M@1kNg/209jNWP0509ZJVP1dM7@0^[Zj0;Zj^P1nOWh00P1UIFD01@2c/k<0WYjN0861P@21PH40TY:B
0080N7Qh00D0WinO09JFUP2FUYH0PX:20<C4a00205MGE`050;Ng]`1fMWH0MWIf0;Vi^@0o?cl00P33
`l<01@1cLg<0^[Zj0;Zj^P2HV9P0UIFE0080:RXZ00@0h>3P0861P@21PH40fMWI0P0P82001@2XZ:P0
YZJV08B4Q024Q8@0Y:BT0080/[:b00D0Jf][07alO01dM7@0M7Ad0<[:bP0208>3P`0508N7Q`2@T900
T92@092@T02GUiL00P2ZZZX01@0h>3P0^KVi0;Vi^@2EUID0WinO0080WYjN00D0OWin08f=S@2=SHd0
Y:BT0820P00208Z:RP04096AT@2EUID0UIFE08Z:RP80XJ6Q00D0HV9R0;bl_02ZZZX0ZZZZ06a/K002
08Z:RP050;2`/01LG5`0WYjN09jNWP2ZZZX00P28R8P01@1TI6@0/k>c0;>c/`2HV9P0O7al0080UIFE
00@0XZ:R0861P@21PH40ZJVY2P3oool01022PX80O7al07alO01nOWh208J6QP0507emO@1bLW80OWin
07inOP25QHD00P20P8001@25QHD0TI6A096AT@2>SXh0OWin0080KFe]00D0G5aL05UIF@1IFET0BTY:
04M7A`0205QHF004065QH@1[Jf/0Jf][06=SH`80KVi^00D0NGUi08>3P`1mOGd0OGem09^KV`030:>S
X`040:VYZ@2j^[X0^[Zj0;^k^`80`<3000D0alO70<S8b02/[:`0[:b/0:2PX00209nOW`05092@T02:
RXX0RXZ:09BDU029RHT00P22PX801@1nOWh0PX:208:2PP21PH40RHV90080Ph>300@0QhN707UiN@1i
NGT0OWin0P24Q8@01@2;Rh/0Ph>308B4Q024Q8@0QHF50080PX:200D0P82008:2PP23Ph<0Ph>307]k
N`0207YjNP0307EeM@1lO7`0O7al0080OGem0P28R8P0102QXJ40Xj>S0:>SX`2RXZ830:6QX@050:NW
Y`2PX:00X:2P0;6a/@38b<P00P3De=@0103Shn<0oooo0?ooo`3oool20>g]k@050=SHf02VYZH0MgMg
07MgM`1NGUh00P1BDU801@1:BTX0H61P08F5Q@25QHD0UiNG0080ZZZZ00D0`L710;Ng]`2g]kL0Xj>S
0:6QX@0209ZJVP0508n?S`2<S8`0S8b<08n?S`2ATI400P2;Rh/01@27QhL0SHf=08f=S@25QHD0QXJ6
0080UiNG00@0Z:RX0:6QX@2QXJ40ZJVY0P3?cll00`3emOD0nOWi0?ooo`020?ooo`80inOW00D0a/K6
0;fm_@2i^KT0^KVi0=CDe0020=gMg@050=SHf03EeMD0eMGE0=[JfP3;bl/00P2k^k/0102/[:`0VIVI
09VIV@2@T90?0?ooo`003@3oool0101XJ6P0P8200820P03AdM4207AdM00507YjNP2PX:00Shn?08n?
S`1mOGd00P2HV9P01@2SXj<0Ogmo07moO`2<S8`0WinO0080TI6A00D0WIfM08>3P`23Ph<0OWin07Yj
NP020<W9b@0407QhN02<S8`0S8b<0:n_[`80Kfm_00D0ZJVY07IfMP2YZJT0ZJVY07EeM@02092@T005
07]kN`2VYZH0WinO09nOW`2k^k/00P1BDU801@28R8P0RXZ:0:6QX@2QXJ40ZZZZ0080SXj>00D0UYJF
06ATI01TI6@0WYjN08>3P`020<30`00506e]K@26QXH0QXJ609:BTP2YZJT00P20P800102b/[80O7al
07alO01kNg/209fMW@0509VIV@1^KVh0_Kfm0;fm_@23Ph<00P1VIVH01@2][Jd0YJFU07YjNP1jNWX0
VYZJ0080Jf][00D0[:b/08n?S`2?Shl0QHF50;fm_@0205eMG@050;Bd]01_Kfl0Kfm_0<[:bP0d=3@0
0P32`/800`1jNWX0]kNg0;Ng]`0209JFUP80;Bd]00@0emOG08f=S@2=SHd0eMGE0P0O7al01@2XZ:P0
Y:BT08R8R028R8P0WYjN0080][Jf00D0JFUY07QhN01kNg/0Ng]k0<;2`P0208N7Q`0508B4Q02EUID0
UIFE08Z:RP2NWYh00P2VYZH01@0n?Sh0[jn_0:n_[`2MWId0Vi^K0080WinO00D0PX:208V9R@29RHT0
YJFU0820P00208Z:RP0408b<S02EUID0UIFE08j>SP80UIFE00D0N7Qh0:VYZ@2b/[80/[:b06][J`02
08^;R`050:f][@1RHV80SHf=08f=S@2h^;P00P28R8P01@1YJFT0Z:RX0:RXZ02JVYX0NWYj0080XZ:R
00@0Vi^K07MgM`1gMgL0][Jf2P3oool0102VYZH0Z:RX0:RXZ02WYjL209bLW0050:2PX02][Jd0YJFU
0:FUY@2TY:@00`2k^k/20:JVYP030:BTY02PX:00QHF50080QHF50P2BTY801@2FUYH0WYjN0;2`/02`
/;00]kNg0080b<S800D0i>CT0=[JfP3Jf]X0bl_;0;bl_0020:BTY00508^;R`27QhL0QhN708>3P`20
P8000P1bLW801@1PH600EeMG05MGE`1GEeL0FUYJ0080O7al00@0QhN708J6QP26QXH0T92@0P2GUiL0
102;Rh/0Shn?09nOW`2OWil309bLW0050:>SX`2OWil0V9RH09RHV02ATI400P29RHT01@1mOGd0PH61
0861P@26QXH0S8b<0080T92@00D0Shn?08N7Q`27QhL0RHV9096AT@0209JFUP040:NWY`2g]kL0]kNg
0;jn_P<0^k^k00@0/;2`0:NWY`2WYjL0UiNG0P2TY:@20:JVYP80YjNW00D0SXj>09VIV@2IVIT0V9RH
08Z:RP0207]kN`0408^;R`1VIVH0IVIV069RHP80M7Ad00<0PX:209nOW`2k^k/00P2k^k/20;Zj^P03
0<G5a@2VYZH0R8R80080R8R80P26QXH01@1lO7`0XZ:R0::RXP33`l<0c/k>0080bl_;00D0c/k>0;fm
_@2m_Kd0/k>c0;6a/@020;jn_P050;Zj^P39bLT0bLW90=7Ad@3<c<`00P2g]kL0102WYjL0VYZJ09ZJ
VP21PH4205MGE`0503Ti>@0a<C403`l?00l?3`0:2PX00P0P820202@T9080:2PX00@05QHF01PH600H
61P0A4A40P1FEUH01@1ZJVX0NGUi08V9R@29RHT0Ph>30080Shn?00<0VIVI0?ooo`3oool03@3oool0
00d0oooo00@0J6QX08:2PP22PX80clo?0P1eMGD01@1jNWX0X:2P08f=S@2=SHd0Ogmo0080U9BD00D0
ZJVY07emO@1mOGd0QhN70:2PX00209NGU`0509RHV01mOGd0OGem08J6QP1mOGd00P33`l<0101kNg/0
Rh^;08^;R`2][Jd207UiN@0509VIV@1kNg/0[Zj^0:j^[P1`L7000P2BTY801@1mOGd0WYjN0:ZZZP2Z
ZZX0];Bd0080EUIF00D0Ogmo08j>SP2XZ:P0Z:RX0:2PX00208n?S`0509ZJVP1WIfL0IfMW09NGU`26
QXH00P31`L401@1TI6@0Ti>C09>CT`2:RXX0];Bd0080Lg=c00@0/k>c0820P020P800Ogmo0P2GUiL0
1@2KVi/0JFUY0;jn_P2n_[h0QhN70080IfMW00D0ZJVY0:NWY`1hN7P0N7Qh09nOW`0205iNGP050;fm
_@28R8P0R8R808R8R02g]kL00P1RHV801@2`/;00Kfm_06m_K`3Fe]H0:BTY0080_Kfm00D0QHF50;>c
/`2c/k<0UYJF09>CT`02030`<0040=7Ad@2CTi<0Ti>C0=GEe@807AdM0P2VYZH208b<S00509RHV02i
^KT0^KVi06YZJP1eMGD00P22PX801031`L40Q8B408B4Q020P80209bLW00508J6QP2RXZ80XJ6Q0:6Q
X@14A4@00P2WYjL01@2UYJD0U9BD0::RXP2RXZ80Q8B40080R8R800D0Y:BT0820P02;Rh/0Rh^;08b<
S00209>CT`05096AT@2>SXh0SXj>08Z:RP2LW9`00P2b/[801@1aLG40Q8B408B4Q02^[Zh0JVYZ0080
QHF500@0^KVi08V9R@29RHT0MgMg0P2DU9@01@2NWYh0NWYj0:ZZZP2ZZZX0UYJF0080Kfm_00<0_Kfm
0?ooo`3oool0203oool0102=SHd0P8200820P01^KVh2071`L00506m_K`1YJFT0IVIV06IVIP1/K6`0
0P1BDU801@1OGel0Ng]k07]kN`2IVIT0];Bd0080k>c/00D0lO7a0>3Ph03Ph>00d];B0<;2`P0209^K
V`0408n?S`1iNGT0NGUi06m_K`80LG5a00D0OGem08N7Q`2RXZ80XZ:R09VIV@0209:BTP0509FEU@2;
Rh/0T92@092@T02[Zj/00P2l_;`01@2f][H0^KVi0:RXZ02XZ:P0XJ6Q0080WIfM00D0X:2P09ZJVP2J
VYX0ZZZZ0:RXZ0020:JVYP030;2`/02g]kL0]kNg0080Z:RX0P2PX:00102LW9`0XZ:R0::RXP2`/;02
0:FUY@0509RHV02FUYH0VIVI09VIV@2LW9`00P2[Zj/01@37alL0a<C40;Zj^P2j^[X0ZZZZ0080XJ6Q
00D0TI6A08f=S@2=SHd0UIFE0:JVYP020:RXZ0050:^[Z`2OWil0WinO09FEU@2>SXh00P2;Rh/01@2M
WId0Vi^K09^KV`2DU9@0TY:B0080UiNG00@0Ogmo08f=S@2=SHd0TY:B0`2<S8`01024Q8@0N7Qh07Qh
N01hN7P207emO@0507IfMP2EUID0YJFU0:FUY@2OWil00P2<S8`01@26QXH0J6QX06QXJ01?Cdl0DE5A
0080I6AT00D0JVYZ07QhN01hN7P0S8b<08N7Q`0207]kN`0507emO@1TI6@0I6AT05=CD`1KFe/00P1[
Jf/0101mOGd0Ti>C09>CT`2f][H20<71`@050;^k^`30`<00d];B0=;BdP33`l<00P2k^k/01@3Cdm<0
cLg=0=;BdP3Bd]80i>CT0080d];B00D0R8R806IVIP1VIVH0BDU903<c<`0204I6AP0407inOP2BTY80
TY:B09:BTPl0oooo000=0?ooo`0406QXJ022PX80PX:20<o?c`80MGEe00D0NWYj0:2PX02=SHd0SHf=
07moO`0209BDU0050:VYZ@1mOGd0OGem08N7Q`2PX:000P2GUiL01@2HV9P0OGem07emO@26QXH0OGem
0080`l?300@0Ng]k08^;R`2;Rh/0[Jf]0P1iNGT01@2IVIT0Ng]k0:j^[P2^[Zh0L71`0080TY:B00D0
OGem09jNWP2ZZZX0ZZZZ0;Bd]00205IFEP0507moO`2>SXh0Z:RX0:RXZ02PX:000P2?Shl01@2JVYX0
IfMW06MWI`2GUiL0QXJ60080`L7100D0I6AT09>CT`2CTi<0RXZ:0;Bd]00207=cL`040;>c/`20P800
P82007moO`80UiNG00D0Vi^K06UYJ@2n_[h0_[jn08N7Q`0206MWI`050:VYZ@2WYjL0N7Qh07QhN02O
Wil00P1NGUh01@2m_Kd0R8R808R8R028R8P0]kNg0080HV9R00D0/;2`06m_K`1_Kfl0e]KF02TY:@02
0;fm_@0508F5Q@2c/k<0/k>c09JFUP2CTi<00P0`<300103AdM40Ti>C09>CT`3EeMD201dM7@80YZJV
0P2<S8`01@2HV9P0^KVi0;Vi^@1ZJVX0MGEe0080PX:200@0`L7108B4Q024Q8@0P8200P2LW9`01@26
QXH0XZ:R0:6QX@2QXJ40A4A40080YjNW00D0YJFU09BDU02RXZ80XZ:R08B4Q00208R8R0050:BTY020
P800Rh^;08^;R`2<S8`00P2CTi<01@2ATI40SXj>08j>SP2:RXX0W9bL0080/[:b00D0LG5a08B4Q024
Q8@0[Zj^06YZJP0208F5Q@040;Vi^@29RHT0RHV907MgM`80U9BD00D0WYjN07YjNP2ZZZX0ZZZZ09JF
UP0206m_K`030;fm_@3oool0oooo00P0oooo00@0SHf=0820P020P800KVi^0P1`L7001@1_Kfl0JFUY
06IVIP1VIVH0K6a/0080DU9B00D0GemO07]kN`1kNg/0VIVI0;Bd]0020>c/k0050?7al@3Ph>00h>3P
0=;BdP32`/800P2KVi/0102?Shl0NGUi07UiN@1_Kfl2075aL@0507emO@27QhL0XZ:R0::RXP2IVIT0
0P2BTY801@2EUID0Rh^;092@T02@T900Zj^[0080_;bl00D0][Jf0;Vi^@2XZ:P0Z:RX0:6QX@0209fM
W@050:2PX02JVYX0VYZJ0:ZZZP2XZ:P00P2VYZH00`2`/;00]kNg0;Ng]`020:RXZ080X:2P00@0W9bL
0::RXP2RXZ80/;2`0P2UYJD01@2HV9P0UYJF09VIV@2IVIT0W9bL0080Zj^[00D0alO70<C4a02j^[X0
^[Zj0:ZZZP020:6QX@05096AT@2=SHd0SHf=09FEU@2VYZH00P2XZ:P01@2[Zj/0WinO09nOW`2EUID0
SXj>0080Rh^;00D0WIfM09^KV`2KVi/0U9BD09:BTP0209NGU`0407moO`2=SHd0SHf=09:BTP<0S8b<
00@0Q8B407QhN01hN7P0N7Qh0P1mOGd01@1fMWH0UIFE0:FUY@2UYJD0WinO0080S8b<00D0QXJ606QX
J01XJ6P0Cdm?055AD@0206ATI00506YZJP1hN7P0N7Qh08b<S027QhL00P1kNg/01@1mOGd0I6AT06AT
I01CDe<0Fe]K0080Jf][00@0OGem09>CT`2CTi<0][Jf0P31`L401@2k^k/0`<300=;BdP3Bd]80`l?3
0080^k^k00D0dm?C0<g=c@3Bd]80d];B0>CTi0020=;BdP0508R8R01VIVH0IVIV04U9B@0c<c<00P16
ATH0101nOWh0TY:B09:BTP2BTY8?0?ooo`003@3oool0101XJ6P0PX:208:2PP3@d=0207AdM00507em
O@2NWYh0Shn?08n?S`1lO7`00P2@T9001@2a/K40OWin07inOP20P800WIfM0080XZ:R00D0Ti>C07Ui
N@1iNGT0Rh^;07emO@020;no_`0408:2PP2:RXX0RXZ:0:RXZ080Q8B400D0S8b<07]kN`2d];@0];Bd
06i^KP0209>CT`050820P02GUiL0];Bd0;Bd]02^[Zh00P1HF5P01@1lO7`0TY:B0:ZZZP2ZZZX0W9bL
0080TY:B00D0UiNG06UYJ@1YJFT0UiNG08>3P`020<K6aP0505YJFP2OWil0WinO08F5Q@2j^[X00P1Y
JFT0102b/[80QXJ608J6QP24Q8@208j>SP0509fMW@1YJFT0_Kfm0;fm_@2=SHd00P1[Jf/01@2RXZ80
YZJV07alO01lO7`0WYjN0080De=C00D0clo?0861P@21PH40QhN70:j^[P0206e]K@050:VYZ@1aLG40
LG5a0=cLg00S8b<00P2h^;P01@2ATI40[:b/0:b/[02BTY80WYjN00809bLW00@0c/k>09jNWP2NWYh0
dM7A0P0M7Ad01@2WYjL0Z:RX08Z:RP2:RXX0UYJF0080^KVi00D0JFUY07IfMP26QXH0QXJ60;^k^`02
08Z:RP0507]kN`2QXJ40XJ6Q08B4Q02TY:@00P2LW9`01@18B4P0WinO09nOW`2^[Zh0SXj>0080YJFU
00D0QXJ608N7Q`27QhL0XZ:R0861P@0208n?S`0408V9R@2BTY80TY:B08n?S`80T92@00D0TY:B08j>
SP2b/[80/[:b07moO`0207IfMP050;Bd]01ZJVX0Q8B408B4Q02j^[X00P2:RXX01@1oOgl0QhN708N7
Q`2SXj<0O7al0080Z:RX00@0UiNG06i^KP1^KVh0_Kfm2P3oool0102PX:00WinO09nOW`2YZJT20:NW
Y`030:ZZZP2d];@0a/K60080a/K60P3Bd]801@30`<00Xj>S0:>SX`21PH40IVIV0080B4Q800D0Bd];
05=CD`1CDe<0I6AT06][J`0208J6QP0408F5Q@1jNWX0NWYj06e]K@80MWIf00D0L71`079bLP21PH40
PH6109nOW`020:VYZ@050:b/[02h^;P0^KVi0;Vi^@2TY:@00P2GUiL01@2IVIT0W9bL0:>SX`2SXj<0
]kNg0080`l?300D0a<C40<O7a`37alL0`/;20;Fe]@020:^[Z`050:b/[02OWil0WinO0::RXP2OWil0
0P2`/;00102h^;P0`<300<30`02i^KT20<71`@050<O7a`2g]kL0Z:RX0:RXZ02IVIT00P27QhL01@1T
I6@0HF5Q06IVIP1VIVH0KFe]0080LW9b00D0QHF508J6QP26QXH0OWin071`L00206][J`0506UYJ@1Z
JVX0JVYZ06a/K023Ph<00P2ATI4308^;R`0508b<S025QHD0PH610861P@2:RXX00P2CTi<01@2IVIT0
YZJV0:JVYP2YZJT0[jn_0080]kNg00D0`<300;fm_@2m_Kd0`L710;Zj^P020;Rh^0040<?3``3Lg=`0
g=cL0>CTi080lO7a00D0oooo0?clo03Ng]h0g]kN0<c<c0020;bl_00509^KV`2GUiL0WYjN09jNWP2V
YZH00P2UYJD01@2/[:`0W9bL08f=S@2=SHd0NWYj0080MgMg00@0Jf][08R8R028R8P0Ti>C0`2?Shl0
102PX:00TI6A096AT@2@T90309nOW`0408n?S`2SXj<0Xj>S0<?3``80h^;R00D0n?Sh0?ooo`3no_h0
o_kn0=WIf@020;Jf]P030:NWY`3oool0oooo00d0oooo000=0?ooo`0406UYJ@20P800P8200=;BdP80
M7Ad00D0Ng]k09jNWP2?Shl0Shn?07YjNP02092@T0050;Ng]`1iNGT0NGUi08J6QP2FUYH00P2XZ:P0
1@2>SXh0O7al07alO028R8P0OWin0080_[jn00@0QHF508J6QP26QXH0Z:RX0P27QhL01@2=SHd0N7Qh
0;Jf]P2f][H0KFe]0080TY:B00D0PH6109JFUP2g]kL0]kNg0:ZZZP0205YJFP0507QhN02FUYH0[:b/
0:b/[02KVi/00P2>SXh01@2KVi/0J6QX06QXJ02EUID0PH610080c<c<00D0D51@0:b/[02/[:`0PH61
0;Rh^002069RHP040;Fe]@2;Rh/0Rh^;08R8R080Ph>300D0X:2P06i^KP2f][H0][Jf09JFUP0206e]
K@0509^KV`2SXj<0PX:208:2PP2IVIT00P1?Cdl01@3Jf]X0OGem07emO@29RHT0Xj>S0080N7Qh00D0
XZ:R07=cL`1cLg<0hn?S01/K6`020;Vi^@0509^KV`2RXZ80XZ:R09:BTP2LW9`00P0/;2`01036a/H0
YjNW0:NWY`3>c/h201dM7@050:FUY@2][Jd0QhN708N7Q`2FUYH00P2h^;P01@1ZJVX0MWIf08B4Q024
Q8@0_Kfm0080RHV900D0N7Qh0::RXP2RXZ80QXJ60:FUY@0209NGU`0504m?C`2HV9P0V9RH0;:b/P2<
S8`00P2TY:@01@28R8P0RXZ:08Z:RP2LW9`0OWin0080UYJF00@0QXJ609FEU@2EUID0RXZ:0P2ATI40
1@2KVi/0PH610:^[Z`2[Zj/0Ti>C0080LG5a00D0[Zj^06a/K029RHT0RHV90;Fe]@0208R8R00508V9
R@1jNWX0NWYj0:FUY@29RHT00P2SXj<0102BTY80L71`071`L02k^k/:0?ooo`0408^;R`2PX:00X:2P
0;Rh^080`<3000D0alO70;Rh^02PX:00X:2P09ZJVP0209^KV`0509jNWP2VYZH0YZJV0;6a/@2b/[80
0P2NWYh01@24Q8@0QHF508F5Q@1iNGT0QXJ60080S8b<00@0W9bL0:2PX02PX:00YJFU0P2;Rh/01@29
RHT0R8R808J6QP26QXH0OWin0080PX:200D0QHF508R8R023Ph<0Ph>308J6QP0208V9R@0508F5Q@1i
NGT0NWYj07YjNP1]KFd00P1VIVH01@1UIFD0GUiN05iNGP1FEUH0IfMW0080MGEe00D0Ng]k08N7Q`27
QhL0RHV908j>SP0208>3P`0407moO`1kNg/0Ng]k07]kN`80MGEe00D0NGUi08^;R`2LW9`0W9bL0;Jf
]P020<30`0050<G5a@2h^;P0ZJVY0:VYZ@2HV9P00P2@T9001@2>SXh0VYZJ09ZJVP2WYjL0/;2`0080
^;Rh00D0/k>c0:f][@2][Jd0ZZZZ09nOW`0208V9R@05092@T02:RXX0RXZ:08N7Q`2GUiL00P2LW9`0
102>SXh0QhN708N7Q`21PH42075aL@05071`L01fMWH0LG5a075aL@1ZJVX00P1OGel01@1EEED0F5QH
05]KF`1KFe/0GUiN0080G5aL00D0JFUY069RHP1RHV80EUIF055AD@0206=SH`0506e]K@1hN7P0N7Qh
08n?S`2KVi/00P2IVIT01@2@T900Shn?08n?S`27QhL0TY:B0080Ti>C00@0S8b<09JFUP2FUYH0UiNG
0P1oOgl01@1`L700PH61079bLP1bLW80GemO0080GUiN00D0M7Ad06YZJP1WIfL0IfMW0861P@0208j>
SP0408b<S02@T900T92@096AT@<0Ph>300@0L71`07=cL`1cLg<0OGem3`3oool000d0oooo00@0JFUY
0820P020P800d];B0P1dM7@01@1kNg/0WYjN08n?S`2?Shl0NWYj0080T92@00D0]kNg07UiN@1iNGT0
QXJ609JFUP020:RXZ00508j>SP1lO7`0O7al08R8R01nOWh00P2n_[h01025QHD0QXJ608J6QP2XZ:P2
08N7Q`0508f=S@1hN7P0][Jf0;Jf]P1]KFd00P2BTY801@21PH40UYJF0;Ng]`2g]kL0ZZZZ0080FUYJ
00D0N7Qh09JFUP2/[:`0[:b/09^KV`0208j>SP0509^KV`1XJ6P0J6QX09FEU@21PH400P3<c<`01@1@
D500[:b/0:b/[021PH40^;Rh0080HV9R00@0]KFe08^;R`2;Rh/0R8R80P23Ph<01@2PX:00KVi^0;Jf
]P2f][H0UYJF0080KFe]00D0Vi^K0:>SX`22PX80PX:209VIV@0204m?C`050=[JfP1mOGd0OGem08V9
R@2SXj<00P1hN7P01@2RXZ80Lg=c07=cL`3Shn<06a/K0080^KVi00D0Vi^K0::RXP2RXZ80TY:B09bL
W00202`/;0040<K6aP2WYjL0YjNW0<k>cP807AdM00D0YJFU0:f][@27QhL0QhN709JFUP020;Rh^005
06YZJP1fMWH0Q8B408B4Q02m_Kd00P29RHT01@1hN7P0XZ:R0::RXP26QXH0YJFU0080UiNG00D0Cdm?
09RHV02HV9P0/[:b08b<S0020:BTY00508R8R02:RXX0RXZ:09bLW01nOWh00P2FUYH01026QXH0UIFE
09FEU@2:RXX2096AT@0509^KV`21PH40Zj^[0:^[Z`2CTi<00P1aLG401@2^[Zh0K6a/08V9R@29RHT0
]KFe0080R8R800D0RHV907YjNP1jNWX0YJFU08V9R@020:>SX`0409:BTP1`L700L71`0;^k^`X0oooo
00@0Rh^;0:2PX02PX:00^;Rh0P30`<001@37alL0^;Rh0:2PX02PX:00VYZJ0080Vi^K00D0WYjN0:JV
YP2VYZH0/K6a0;:b/P0209jNWP0508B4Q025QHD0QHF507UiN@26QXH00P2<S8`0102LW9`0X:2P0:2P
X02UYJD208^;R`0508V9R@28R8P0QXJ608J6QP1nOWh00P22PX801@25QHD0R8R808>3P`23Ph<0QXJ6
0080RHV900D0QHF507UiN@1jNWX0NWYj06e]K@0206IVIP0506EUI@1NGUh0GUiN05IFEP1WIfL00P1e
MGD01@1kNg/0QhN708N7Q`29RHT0SXj>0080Ph>300@0Ogmo07]kN`1kNg/0Ng]k0P1eMGD01@1iNGT0
Rh^;09bLW02LW9`0][Jf0080`<3000D0aLG50;Rh^02YZJT0ZJVY09RHV002092@T00508j>SP2JVYX0
VYZJ0:NWY`2`/;000P2h^;P01@2c/k<0[Jf]0:f][@2ZZZX0WinO0080RHV900D0T92@08Z:RP2:RXX0
QhN709NGU`0209bLW00408j>SP27QhL0QhN70861P@80LG5a00D0L71`07IfMP1aLG40LG5a06YZJP02
05mOG`0505EEE@1HF5P0Fe]K05]KF`1NGUh00P1LG5`01@1YJFT0HV9R069RHP1FEUH0DE5A0080Hf=S
00D0KFe]07QhN01hN7P0Shn?09^KV`0209VIV@05092@T02?Shl0Shn?08N7Q`2BTY800P2CTi<0102<
S8`0UYJF09JFUP2GUiL207moO`05071`L021PH40LW9b079bLP1OGel00P1NGUh01@1dM7@0JVYZ06MW
I`1WIfL0PH610080SXj>00@0S8b<092@T02@T900TI6A0`23Ph<0101`L700Lg=c07=cL`1mOGd?0?oo
o`003@3oool0101]KFd0P8200820P03AdM4207EeM@0507]kN`2LW9`0TY:B09:BTP1jNWX00P2=SHd0
1@2k^k/0MgMg07MgM`23Ph<0UiNG0080[:b/00D0Rh^;07emO@1mOGd0RXZ:08:2PP020;Ng]`<0QXJ6
00D0XZ:R08f=S@2=SHd0SHf=07YjNP020;Bd]00506e]K@2ATI40TI6A08N7Q`2ATI400P2i^KT01@2Y
ZJT0FEUI05UIF@1fMWH0Vi^K0080[Jf]00@0VIVI08f=S@2=SHd0W9bL0P1VIVH01@2DU9@0PH610=3@
d03@d=00Bd];0080/k>c00D0PX:20;2`/01TI6@0I6AT0;Rh^00208f=S@0508V9R@1gMgL0MgMg0:RX
Z01bLW800P2^[Zh01@2JVYX0KVi^06i^KP2KVi/0WIfM0080RXZ:00@0UIFE04m?C`1?Cdl0hN7Q0P1i
NGT01@2?Shl0U9BD08R8R028R8P0U9BD0080P82000D0h^;R01LG5`2d];@0];Bd0:ZZZP0209RHV005
092@T02QXJ40;Rh^02h^;P2n_[h00P2^[Zh01@3;bl/07alO01lO7`2PX:00]KFe0080P82000D0Vi^K
0;Jf]P2f][H0JVYZ07MgM`0208F5Q@040;fm_@2;Rh/0Rh^;07IfMP80Xj>S00D0QhN70::RXP2GUiL0
UiNG04m?C`0209NGU`050;>c/`2=SHd0XJ6Q0:6QX@2;Rh/00P2?Shl01@2BTY80OWin09bLW02LW9`0
Q8B40080W9bL00D0P82009RHV02HV9P0WYjN07alO0020::RXP0509fMW@1cLg<0Lg=c0:RXZ01^KVh0
0P2ATI40102/[:`0QhN708N7Q`2;Rh/207]kN`050:BTY02ATI40UIFE09FEU@2GUiL00P1[Jf/00`2m
_Kd0oooo0?ooo`080?ooo`040;bl_02QXJ40XJ6Q08F5Q@80NGUi00D0Lg=c06e]K@1jNWX0NWYj07Ad
M00207=cL`0507QhN025QHD0QHF508b<S02KVi/00P2k^k/01@3De=@0eMGE0=GEe@3Cdm<0b<S80080
]KFe00@0WinO0:ZZZP2ZZZX0[jn_0P34a<@01@2o_kl0^KVi0:>SX`2SXj<0WIfM0080UYJF00D0Shn?
08N7Q`26QXH0QXJ608Z:RP0208R8R00508V9R@2BTY80VYZJ09ZJVP2NWYh00P2KVi/01@2PX:00YJFU
0:FUY@2PX:00UiNG0080Shn?00D0RHV908N7Q`27QhL0RXZ:0861P@0208:2PP0407UiN@1/K6`0K6a/
069RHP80JFUY00D0J6QX06ATI01]KFd0KFe]07YjNP0207inOP0508j>SP2OWil0YjNW0:NWY`2/[:`0
0P2f][H01@2WYjL0Ti>C09>CT`22PX80MgMg0080M7Ad00D0OGem08Z:RP2:RXX0V9RH0::RXP020:^[
Z`040:b/[02i^KT0^KVi0;^k^`<0[:b/00@0^[Zj0;6a/@2a/K40ZJVY0P2^[Zh01@2LW9`0SHf=096A
T@2ATI40UiNG0080Xj>S00D0ZZZZ09BDU02>SXh0SXj>0861P@0207=cL`0506i^KP1iNGT0NGUi07in
OP2=SHd00`2BTY8209^KV`0509FEU@2HV9P0VYZJ09ZJVP2SXj<00P2/[:`01@2e]KD0/K6a0<30`030
`<00cLg=00<0c<c<0P3Cdm<01@3GemL0alO70<C4a034a<@0d];B0080c<c<00D0YjNW0:VYZ@2`/;00
/;2`09>CT`0208N7Q`0508b<S02:RXX0RXZ:07MgM`1oOgl00P2?Shl0102][Jd0];Bd0;Bd]02k^k/?
0?ooo`003@3oool0101^KVh0PX:208:2PP3=cLd207alO00507IfMP2LW9`0T92@092@T01jNWX00P2A
TI401@2k^k/0N7Qh07QhN021PH40TY:B0080/K6a00D0RXZ:07]kN`1kNg/0SXj>08B4Q0020:n_[`04
08f=S@22PX80PX:20::RXP80T92@00D0S8b<07YjNP2b/[80/[:b06m_K`0208f=S@0508Z:RP2@T900
^KVi0;Vi^@2[Zj/00P1GEeL01@1cLg<0XJ6Q0:f][@2][Jd0UYJF0080SXj>00D0VIVI06UYJ@1YJFT0
TI6A0820P0020=;BdP0504Y:BP2i^KT0^KVi0861P@2VYZH00P1XJ6P0102l_;`0SHf=08f=S@2:RXX2
06i^KP050:f][@1jNWX0YJFU0:FUY@2LW9`00P1aLG401@2LW9`0SXj>09VIV@2IVIT0Rh^;0080De=C
00D0i^KV075aL@1aLG40UYJF08R8R00209JFUP0508R8R027QhL0QhN70>3Ph00K6a/00P2[Zj/01@2f
][H0T92@092@T02<S8`0Z:RX0080<C4a00@0]kNg0;2`/02`/;00cLg=0P0O7al01@2MWId0^KVi07]k
N`1kNg/0X:2P0080/K6a00D0K6a/07MgM`23Ph<0Ph>30<;2`P0208^;R`0507=cL`2SXj<0Xj>S08b<
S02LW9`00P2HV9P01@1CDe<0UIFE09FEU@2c/k<0Shn?0080Vi^K00D0Shn?09JFUP2FUYH0RXZ:07al
O00209jNWP0408J6QP2NWYh0WYjN07IfMP80XZ:R00D0UYJF07inOP2VYZH0YZJV09ZJVP0207IfMP05
09nOW`1dM7@0VIVI09VIV@2WYjL00P23Ph<01@2;Rh/0Ogmo07moO`2TY:@0V9RH0080Rh^;00@0VYZJ
06][J`1[Jf/0_;bl2P3oool0101lO7`0V9RH09RHV02/[:`20;Ng]`030;Bd]02k^k/0[:b/0080[:b/
0P2LW9`01@2JVYX0UiNG09NGU`2;Rh/0N7Qh0080NGUi00D0MGEe075aL@1aLG40OWin08Z:RP0208F5
Q@0408R8R01dM7@0M7Ad075aL@80L71`00D0Q8B409:BTP2XZ:P0Z:RX0:BTY0020:NWY`050:JVYP2X
Z:P0[Zj^0:j^[P2`/;000P2[Zj/01@2d];@0_;bl0;Zj^P2j^[X0_;bl0080aLG500D0_Kfm0;Fe]@2e
]KD0][Jf0:n_[`020:^[Z`040:RXZ02MWId0WIfM09NGU`<0VYZJ00@0VIVI09jNWP2NWYh0X:2P0P2T
Y:@01@2LW9`0VYZJ08j>SP2>SXh0OGem0080K6a/00D0Hf=S05YJFP1ZJVX0JVYZ07MgM`0207=cL`05
07inOP2ATI40TI6A08n?S`2CTi<00`2JVYX209JFUP0509:BTP2:RXX0Shn?08n?S`2=SHd00P25QHD0
1@2CTi<0Y:BT0:>SX`2SXj<0Z:RX00<0^[Zj0P2f][H01@2l_;`0`<300;Rh^02h^;P0/[:b0080][Jf
00D0_[jn0<_;b`3<c<`0c<c<0=GEe@020<k>cP050<C4a02n_[h0_[jn0;Rh^02ZZZX00P2XZ:P01@2Y
ZJT0XJ6Q0:6QX@2WYjL0Xj>S0080YjNW00D0XZ:R0:>SX`2SXj<0WYjN09fMW@02092@T00308n?S`24
Q8@0Q8B400<0PH6100D0O7al06i^KP21PH40PH6108N7Q`0209^KV`050;Bd]03De=@0_kno0;no_`2k
^k/00P2d];@01@2][Jd0U9BD09BDU02[Zj/0Z:RX0080VIVI00@0RHV908^;R`2;Rh/0O7al3`3oool0
00d0oooo00@0K6a/08J6QP26QXH0a/K60P20P8001@1gMgL0VYZJ08f=S@2=SHd0OWin0080TY:B00D0
^KVi07QhN01hN7P0PX:209:BTP020:n_[`0508f=S@1lO7`0O7al08f=S@23Ph<00P2/[:`0102BTY80
PX:208:2PP2OWil209:BTP0508j>SP1iNGT0Zj^[0:^[Z`1eMGD00P2;Rh/208n?S`80]KFe00D0[Jf]
05QHF01HF5P0LW9b0:BTY0020:^[Z`0409NGU`2;Rh/0Rh^;09bLW080Jf][00D0RXZ:08B4Q03Bd]80
d];B04Q8B0020;jn_P0507inOP2NWYh0LG5a075aL@2h^;P00P2ATI401@2:RXX0IfMW06MWI`2d];@0
OWin0080WinO00D0W9bL07AdM01dM7@0X:2P07]kN`020:^[Z`0408>3P`1HF5P0F5QH0>OWi`80IfMW
00D0WIfM08>3P`2PX:00X:2P07emO@0208n?S`050=gMg@0P8200X:2P0:2PX032`/800P25QHD01@2;
Rh/0/K6a03<c<`0c<c<0Zj^[0080]KFe00D0dM7A01/K6`0K6a/0VYZJ0<30`00207AdM0050:NWY`2/
[:`0[:b/06i^KP1hN7P00P1oOgl01033`l<0T92@092@T01_Kfl20:BTY00508n?S`2FUYH0VIVI09VI
V@1GEeL00P2CTi<00`2a/K40Ti>C09BDU00209BDU080VIVI00D0QHF507alO02NWYh0WYjN08b<S002
0:2PX005075aL@2RXZ80XZ:R096AT@23Ph<00P2VYZH01@2DU9@0PX:208:2PP2CTi<0NGUi0080VIVI
00@0ZZZZ07inOP1nOWh0QHF50P29RHT01@2QXJ40W9bL08B4Q024Q8@0VIVI0080LW9b00<0^;Rh0?oo
o`3oool0203oool0102FUYH0OWin07inOP1XJ6P2065QH@0505]KF`1ZJVX0PX:208:2PP2FUYH00P2_
[jl01@2][Jd0WYjN09jNWP2JVYX0Vi^K0080OGem00D0NGUi08:2PP22PX80QHF507inOP0209:BTP04
09bLW02KVi/0Vi^K08b<S080QhN700D0Lg=c06QXJ01MGEd0GEeM06IVIP0206ATI00506=SH`1LG5`0
EeMG05MGE`1CDe<00`1JFUX0101IFET0GUiN05iNGP1QHF4205aLG005065QH@1]KFd0KFe]07EeM@24
Q8@00P2@T90309RHV00509JFUP2MWId0XJ6Q0:6QX@2VYZH00P2`/;001@36a/H0_[jn0;jn_P39bLT0
e]KF0080f=SH00D0clo?0=3@d03@d=00b<S80;no_`020;^k^`040:n_[`2[Zj/0Zj^[0:^[Z`80YJFU
00D0]KFe0;Ng]`2i^KT0^KVi0;2`/0020;Fe]@050:>SX`2RXZ80UiNG09NGU`2@T9000P2:RXX01@20
P800NWYj07emO@1mOGd0Ng]k0080MGEe00D0NWYj07inOP1nOWh0PH6108>3P`0208:2PP0307]kN`1X
J6P0J6QX00@0GUiN00@0HF5Q07IfMP1fMWH0Q8B40P29RHT01@2?Shl0UIFE09RHV02HV9P0TI6A0080
TY:B00<0Rh^;08F5Q@1mOGd00P1mOGd207UiN@0507IfMP1iNGT0OGem07emO@22PX800P26QXH01@2>
SXh0T92@092@T02VYZH0][Jf0080ZJVY00D0Vi^K09BDU02DU9@0P82006EUI@0208>3P`0408b<S02;
Rh/0Rh^;08N7Q`80X:2P00D0Rh^;0:6QX@2ZZZX0ZZZZ0;2`/0020:>SX`030:b/[03oool0oooo00d0
oooo000=0?ooo`0406a/K026QXH0QXJ60<K6aP80P82000D0MgMg09ZJVP2=SHd0SHf=07inOP0209:B
TP050;Vi^@1hN7P0N7Qh08:2PP2BTY800P2_[jl01@2=SHd0O7al07alO02=SHd0Ph>30080[:b/00@0
TY:B08:2PP22PX80WinO0P2BTY801@2>SXh0NGUi0:^[Z`2[Zj/0MGEe0080Rh^;0P2?Shl20;Fe]@05
0:f][@1HF5P0F5QH079bLP2TY:@00P2[Zj/0102GUiL0Rh^;08^;R`2LW9`206][J`0508Z:RP24Q8@0
d];B0=;BdP18B4P00P2n_[h01@1nOWh0WYjN075aL@1aLG40^;Rh0080TI6A00D0RXZ:06MWI`1WIfL0
];Bd07inOP0209nOW`0509bLW01dM7@0M7Ad0:2PX01kNg/00P2[Zj/01023Ph<0F5QH05QHF03WinL2
06MWI`0509fMW@23Ph<0X:2P0:2PX01mOGd00P2?Shl01@3MgMd0820P0:2PX02PX:00`/;20080QHF5
00D0Rh^;0;6a/@0c<c<0<c<c0:^[Z`020;Fe]@050=7Ad@0K6a/06a/K09ZJVP30`<000P1dM7@01@2W
YjL0[:b/0:b/[01^KVh0N7Qh0080Ogmo00@0`l?3092@T02@T900Kfm_0P2TY:@01@2?Shl0UYJF09VI
V@2IVIT0EeMG0080Ti>C00<0/K6a09>CT`2DU9@00P2DU9@209VIV@0508F5Q@1lO7`0WYjN09jNWP2<
S8`00P2PX:001@1aLG40XZ:R0::RXP2ATI40Ph>30080YZJV00D0U9BD08:2PP22PX80Ti>C07UiN@02
09VIV@040:ZZZP1nOWh0OWin08F5Q@80RHV900D0XJ6Q09bLW024Q8@0Q8B409VIV@02079bLP030;Rh
^03oool0oooo00P0oooo00@0UYJF07inOP1nOWh0J6QX0P1QHF401@1KFe/0JVYZ08:2PP22PX80UYJF
0080[jn_00D0[Jf]09jNWP2NWYh0VYZJ09^KV`0207emO@0507UiN@22PX80PX:208F5Q@1nOWh00P2B
TY80102LW9`0Vi^K09^KV`2<S8`208N7Q`0507=cL`1XJ6P0GEeM05eMG@1VIVH00P1TI6@01@1SHf<0
G5aL05MGE`1GEeL0De=C00<0FUYJ00@0FEUI05iNGP1NGUh0HF5Q0P1LG5`01@1QHF40KFe]06e]K@1e
MGD0Q8B40080T92@0`2HV9P01@2FUYH0WIfM0:6QX@2QXJ40YZJV0080/;2`00D0a/K60;jn_P2n_[h0
bLW90=KFeP020=SHf0050<o?c`3@d=00d=3@0<S8b02o_kl00P2k^k/0102_[jl0Zj^[0:^[Z`2[Zj/2
0:FUY@050;Fe]@2g]kL0^KVi0;Vi^@2`/;000P2e]KD01@2SXj<0XZ:R09NGU`2GUiL0T92@0080RXZ:
00D0P82007YjNP1mOGd0OGem07]kN`0207EeM@0507YjNP1nOWh0OWin0861P@23Ph<00P22PX800`1k
Ng/0J6QX06QXJ00405iNGP04065QH@1fMWH0MWIf08B4Q080RHV900D0Shn?09FEU@2HV9P0V9RH096A
T@0209:BTP0308^;R`25QHD0OGem0080OGem0P1iNGT01@1fMWH0NGUi07emO@1mOGd0PX:20080QXJ6
00D0SXj>092@T02@T900YZJV0;Jf]P020:VYZ@0509^KV`2DU9@0U9BD0820P01UIFD00P23Ph<0102<
S8`0Rh^;08^;R`27QhL20:2PX00508^;R`2QXJ40ZZZZ0:ZZZP2`/;000P2SXj<00`2/[:`0oooo0?oo
o`0=0?ooo`003@3oool0101]KFd0R8R808R8R034a<@208>3P`0307AdM02KVi/0R8R80080R8R80P2=
SHd01@2k^k/0Lg=c07=cL`24Q8@0UYJF0080Z:RX00D0T92@07emO@1mOGd0SHf=08:2PP020:^[Z`04
09>CT`1nOWh0OWin0:6QX@80TI6A00D0UYJF07=cL`2VYZH0YZJV07alO00208F5Q@0309BDU02ATI40
[jn_0080[jn_0P1KFe/01@1^KVh0YjNW0:VYZ@2YZJT0V9RH0080RHV900D0X:2P06][J`1[Jf/0Q8B4
08N7Q`020=;BdP0504U9B@30`<00`<3007moO`2ATI400P21PH40102c/k<0TY:B09:BTP28R8P206AT
I0050;Zj^P20P800Vi^K09^KV`2JVYX00P1fMWH01@2UYJD0KVi^0;Vi^@2i^KT0Ng]k0080HF5Q00D0
gmoO06EUI@1UIFD0YZJV07alO0020:FUY@0507EeM@2EUID0UIFE0=gMg@0U9BD00P2DU9@01@3=cLd0
Ng]k07]kN`2<S8`0][Jf0080>3Ph00@0WYjN0;Ng]`2g]kL0fMWI0P0L71`01@2@T900a<C4071`L01`
L700[:b/0080ZZZZ00D0Kfm_07YjNP1kNg/0Ng]k0<G5a@0208j>SP03079bLP2PX:00X:2P00@0UIFE
00D0FEUI09FEU@2EUID0/;2`09BDU002092@T00509FEU@2MWId0WIfM0820P01nOWh00P2KVi/0102A
TI40X:2P0:2PX01aLG420:6QX@0508n?S`24Q8@0[:b/0:b/[025QHD00P2BTY801@27QhL0Ogmo09^K
V`2KVi/0ZJVY0080NGUi00D0Ogmo09NGU`2GUiL0WYjN09^KV`0208>3P`0409RHV01bLW80LW9b0;Vi
^@X0oooo00@0Xj>S0:f][@2][Jd0/K6a0P2g]kL01@2a/K40WYjN08n?S`2?Shl0N7Qh0080IVIV00D0
Lg=c08R8R028R8P0TY:B0:^[Z`020<G5a@050<c<c035aLD0aLG50;Vi^@2_[jl00P2UYJD0102QXJ40
/;2`0;2`/03:b/X20=?Cd`050=gMg@3Ng]h0i^KV0>KViP3Kfm/00P3Bd]801@3?cll0d];B0=;BdP3B
d]80eMGE0080f][J00D0e]KF0<71`@2UYJD0YJFU08n?S`020861P@0507=cL`1`L700L71`06a/K01Z
JVX00P1XJ6P01@1YJFT0KVi^06i^KP1kNg/0NWYj0080OGem00@0Ph>308j>SP2>SXh0Ogmo0P25QHD0
1@29RHT0NWYj079bLP1bLW80OGem00<0O7al0`2;Rh/0102EUID0XZ:R0::RXP2OWil209jNWP0408j>
SP2=SHd0QXJ608J6QP<0S8b<00<0WinO09jNWP2YZJT00P2YZJT20:BTY00509JFUP2<S8`0NWYj07Yj
NP1gMgL00P1fMWH01@1lO7`0N7Qh07QhN022PX80Q8B40080SHf=00D0Vi^K0;2`/02`/;00/[:b0;Vi
^@020;bl_0040;:b/P2RXZ80XZ:R09ZJVP80SXj>00D0RXZ:08V9R@1mOGd0OGem07moO`0208F5Q@05
08J6QP24Q8@0Q8B408B4Q02;Rh/00`27QhL0102;Rh/0Ti>C09>CT`2;Rh/209:BTP0508>3P`1fMWH0
MWIf08>3P`2@T9000P2HV9P01@2][Jd0/K6a0;6a/@2LW9`0TI6A0080Ng]k00@0MWIf07YjNP1jNWX0
OWin0P1XJ6P01@1ZJVX0FUYJ05mOG`1OGel0Kfm_0080QHF500<0Shn?0?ooo`3oool03@3oool000d0
oooo00@0LW9b08F5Q@25QHD0`/;20P22PX801@1iNGT0W9bL08N7Q`27QhL0RHV90080Rh^;00D0_;bl
07AdM01dM7@0P82009RHV0020:^[Z`0508b<S01iNGT0NGUi09>CT`22PX800P2YZJT0102FUYH0NWYj
07YjNP2PX:0209FEU@0509RHV01aLG40WinO09nOW`24Q8@00P23Ph<01@2FUYH0T92@0:b/[02/[:`0
[Jf]0080H61P00D0Jf][0:ZZZP2VYZH0YZJV09NGU`0208R8R0050:JVYP1ZJVX0JVYZ07emO@27QhL0
0P3Jf]X01@1:BTX0^k^k0;^k^`20P800QXJ60080Ti>C00@0Zj^[09:BTP2BTY80QXJ60P1VIVH01@2m
_Kd0Ng]k09jNWP2NWYh0UYJF0080N7Qh00D0ZZZZ065QH@38b<P0b<S807AdM00206IVIP050=WIf@1T
I6@0I6AT0:b/[01lO7`00P2VYZH01@1/K6`0WYjN09jNWP3Hf=P0<C4a0080PX:200D0fMWI07IfMP1f
MWH0Shn?0;Ng]`0203/k>`0409FEU@2k^k/0^k^k0=_Kf`807alO00D0S8b<0<C4a01_Kfl0Kfm_0:f]
[@020:RXZ00507=cL`1jNWX0Ng]k07]kN`36a/H00P2<S8`01@1cLg<0WinO09nOW`2HV9P0UIFE0080
T92@00D0FUYJ09JFUP2FUYH0[jn_09FEU@0208j>SP0309JFUP2OWil0WinO0080OWin0`2GUiL209nO
W`0507=cL`2LW9`0W9bL092@T029RHT00P2`/;001@1iNGT0V9RH09RHV022PX80Q8B40080WinO00@0
Y:BT07emO@1mOGd0M7Ad0P2PX:001@2LW9`0Vi^K0820P020P800WYjN0080LW9b00<0];Bd0?ooo`3o
ool0203oool0101fMWH0MGEe07EeM@23Ph<20820P00508N7Q`2ATI40X:2P0:2PX02b/[800P2n_[h0
1@2c/k<0[Jf]0:f][@2][Jd0X:2P0080WinO00<0WYjN096AT@2ATI400P28R8P208>3P`0408J6QP23
Ph<0Ph>308>3P`80PX:200D0NGUi071`L01]KFd0KFe]06m_K`0207YjNP0508J6QP29RHT0PX:208:2
PP1kNg/00P1ZJVX01@1OGel0N7Qh08n?S`2?Shl0Xj>S0080_kno00<0e=CD0=GEe@3EeMD00P3Ti>@2
0=oOg`050=WIf@3AdM40dM7A0<O7a`2m_Kd00P2_[jl0102XZ:P0Vi^K09^KV`2HV9P208f=S@0508F5
Q@2>SXh0Ti>C09>CT`2ATI400P2LW9`01@2IVIT0TI6A08j>SP2>SXh0OGem0080JFUY00D0Fe]K05YJ
FP1JFUX0FUYJ05MGE`0206ATI00507UiN@1jNWX0NWYj07alO028R8P00P1gMgL01@1nOWh0QhN708N7
Q`2HV9P0YjNW0080`/;200@0a<C40<O7a`37alL0^k^k0P2l_;`20;Ng]`80[jn_00D0Zj^[09jNWP2N
WYh0WIfM09:BTP0308^;R`80SXj>00D0RXZ:08V9R@29RHT0PH6107]kN`0208>3P`<0QhN700D0TY:B
09^KV`2CTi<0Ti>C08J6QP0208F5Q@0507inOP1iNGT0MWIf07IfMP28R8P00P2?Shl01@2SXj<0/[:b
0;:b/P2>SXh0JVYZ0080HV9R00D0FUYJ069RHP1RHV80Vi^K0;^k^`020<c<c0040=KFeP3EeMD0eMGE
0=SHf080gmoO00D0f=SH0;Zj^P2OWil0WinO07UiN@0206a/K00306IVIP3oool0oooo00d0oooo000=
0?ooo`04079bLP25QHD0QHF50<;2`P80PX:200D0NGUi09bLW027QhL0QhN708V9R@0208^;R`050;bl
_01dM7@0M7Ad0820P02HV9P00P2[Zj/01@2<S8`0NGUi07UiN@2CTi<0PX:20080ZJVY00@0UYJF07Yj
NP1jNWX0X:2P0P2EUID01@2HV9P0LG5a09nOW`2OWil0Q8B40080Ph>300D0UYJF092@T02/[:`0[:b/
0:f][@02061PH00506][J`2ZZZX0YZJV0:JVYP2GUiL00P28R8P01@2VYZH0JVYZ06YZJP1mOGd0QhN7
0080f][J00D0BTY:0;^k^`2k^k/0P82008J6QP0209>CT`040:^[Z`2BTY80TY:B08J6QP80IVIV00D0
_Kfm07]kN`2NWYh0WYjN09JFUP0207QhN0050:ZZZP1QHF40b<S80<S8b01dM7@00P1VIVH01@3IfMT0
I6AT06ATI02/[:`0O7al0080YZJV00D0K6a/09jNWP2NWYh0f=SH034a<@0208:2PP050=WIf@1fMWH0
MWIf08n?S`2g]kL00P0k>c/0102EUID0^k^k0;^k^`3Kfm/201lO7`0508b<S034a<@0Kfm_06m_K`2]
[Jd00P2XZ:P01@1cLg<0NWYj07]kN`1kNg/0a/K60080S8b<00D0Lg=c09nOW`2OWil0V9RH09FEU@02
092@T00505YJFP2FUYH0UYJF0:n_[`2EUID00P2>SXh00`2FUYH0WinO09nOW`0207inOP<0UiNG0P2O
Wil01@1cLg<0W9bL09bLW02@T900RHV90080/;2`00D0NGUi09RHV02HV9P0PX:208B4Q00209nOW`04
0:BTY01mOGd0OGem07AdM080X:2P00D0W9bL09^KV`20P800P82009jNWP02079bLP030;Bd]03oool0
oooo00P0oooo00@0MWIf07EeM@1eMGD0Ph>30P20P8001@27QhL0TI6A0:2PX02PX:00/[:b0080_[jn
00D0/k>c0:f][@2][Jd0[Jf]0:2PX00209nOW`0309jNWP2ATI40TI6A0080R8R80P23Ph<01026QXH0
Ph>308>3P`23Ph<208:2PP0507UiN@1`L700KFe]06e]K@1_Kfl00P1jNWX01@26QXH0RHV908:2PP22
PX80Ng]k0080JVYZ00D0GemO07QhN02?Shl0Shn?0:>SX`020;no_`030=CDe03EeMD0eMGE0080i>CT
0P3Ogml01@3IfMT0dM7A0=7Ad@37alL0_Kfm0080[jn_00@0Z:RX09^KV`2KVi/0V9RH0P2=SHd01@25
QHD0SXj>09>CT`2CTi<0TI6A0080W9bL00D0VIVI096AT@2>SXh0SXj>07emO@0206UYJ@0505]KF`1J
FUX0FUYJ05YJFP1GEeL00P1TI6@01@1iNGT0NWYj07YjNP1lO7`0R8R80080MgMg00D0OWin08N7Q`27
QhL0V9RH0:NWY`020<;2`P040<C4a037alL0alO70;^k^`80_;bl0P2g]kL20:n_[`050:^[Z`2NWYh0
WYjN09fMW@2BTY800`2;Rh/208j>SP0508Z:RP29RHT0RHV90861P@1kNg/00P23Ph<308N7Q`0509:B
TP2KVi/0Ti>C09>CT`26QXH00P25QHD01@1nOWh0NGUi07IfMP1fMWH0R8R80080Shn?00D0Xj>S0;:b
/P2b/[80SXj>06YZJP02069RHP0505YJFP1RHV80HV9R09^KV`2k^k/00P3<c<`0103Fe]H0eMGE0=GE
e@3Hf=P20=oOg`050=SHf02j^[X0WinO09nOW`1iNGT00P1/K6`00`1VIVH0oooo0?ooo`0=0?ooo`00
3@3oool0101hN7P0Ogmo07moO`35aLD207emO@0307UiN@2NWYh0R8R80080R8R80P2:RXX01@2m_Kd0
MGEe07EeM@1nOWh0VIVI0080[Jf]00D0Shn?079bLP1bLW80UIFE08F5Q@020:BTY00409ZJVP1kNg/0
Ng]k09fMW@80UiNG00D0W9bL06UYJ@2MWId0WIfM08^;R`0207moO`0509RHV02ATI40ZJVY0:VYZ@2]
[Jd00P1SHf<01@1[Jf/0[:b/0::RXP2RXZ80UYJF0080RHV900D0Zj^[06YZJP1ZJVX0MWIf08N7Q`02
0>?Sh`0504Q8B02f][H0][Jf0861P@1nOWh00P2SXj<0102OWil0VIVI09VIV@22PX8206][J`050;Ng
]`1nOWh0W9bL09bLW02DU9@00P1kNg/01@2WYjL0GemO0=;BdP3Bd]80Kfm_0080IfMW00D0e=CD06EU
I@1UIFD0Zj^[08B4Q00209nOW`0506e]K@2OWil0WinO0=?Cd`0k>c/00P1fMWH01@3MgMd0MWIf07If
MP2>SXh0^;Rh0080@41000@0RHV90<;2`P32`/80gMgM0P0K6a/01@2@T900`<3006m_K`1_Kfl0[Zj^
0080YjNW00D0MGEe07UiN@1gMgL0MgMg0<[:bP0208N7Q`0307QhN02KVi/0Vi^K0080VYZJ0P2;Rh/0
1@1KFe/0UIFE09FEU@2b/[80Ti>C0080Shn?00D0UIFE09nOW`2OWil0OWin0861P@0209:BTP0409bL
W02NWYh0WYjN07AdM080VYZJ00D0S8b<08f=S@2d];@0];Bd07EeM@0209^KV`0507moO`23Ph<0XJ6Q
0:6QX@2TY:@00P1nOWh00`1`L700YjNW0:NWY`0209JFUP80QhN700@0Vi^K07inOP1nOWh0Z:RX2P3o
ool0102KVi/0WIfM09fMW@2HV9P209^KV`050:JVYP2OWil0TI6A096AT@2>SXh00P2<S8`01@2>SXh0
R8R808R8R024Q8@0Kfm_0080GUiN00D0FUYJ05mOG`1OGel0M7Ad09:BTP0309nOW`80YjNW00D0W9bL
09>CT`2CTi<0VIVI0:RXZ0020:FUY@050:>SX`2UYJD0YJFU0:6QX@2OWil00P2`/;001@30`<00bLW9
0<W9b@3<c<`0/k>c0080WinO00@0S8b<06i^KP1^KVh0HV9R0P1OGel01@1=CDd0CTi>05=CD`1CDe<0
EeMG0080Hf=S00D0L71`07MgM`27QhL0QhN708>3P`0208N7Q`0508V9R@2>SXh0SXj>092@T02=SHd0
0P26QXH01@1eMGD0Jf][06][J`1/K6`0JVYZ0080K6a/00@0MWIf08F5Q@25QHD0W9bL0P2^[Zh01@2b
/[80b/[:0<71`@31`L40YjNW0080U9BD00<0T92@0820P023Ph<00P23Ph<208F5Q@0507moO`1kNg/0
MGEe07EeM@1aLG400P1nOWh01@2=SHd0TY:B09:BTP2>SXh0QhN70080OGem00D0Kfm_07EeM@1eMGD0
Ogmo096AT@0209bLW0040:RXZ02TY:@0Y:BT0:>SX`80/;2`00<0alO70<W9b@38b<P00P38b<P20;>c
/`050:2PX02UYJD0/K6a0;6a/@2f][H00P38b<P01@3De=@0c/k>0<S8b038b<P0];Bd0080XZ:R00D0
UiNG09>CT`2CTi<0_[jn0>CTi0020>c/k0050>SXj03De=@0e=CD09jNWP1mOGd00P1_Kfl0101HF5P0
EUIF05IFEP1FEUH205eMG@0506IVIP2DU9@0[:b/0:b/[02i^KT00P2k^k/00`2`/;00oooo0?ooo`0=
0?ooo`003@3oool01025QHD0MWIf07IfMP3?cll207=cL`0507alO02MWId0SHf=08f=S@24Q8@00P2:
RXX01@2l_;`0MWIf07IfMP1mOGd0VIVI0080/;2`00D0S8b<079bLP1bLW80TI6A08V9R@020::RXP04
09bLW01oOgl0Ogmo09NGU`80VYZJ00D0XZ:R061PH02JVYX0VYZJ09NGU`0207MgM`0509^KV`2DU9@0
X:2P0:2PX02/[:`00P1ZJVX01@1^KVh0YjNW0:2PX02PX:00UiNG0080QhN700D0/;2`06UYJ@1YJFT0
LG5a08R8R0020>_[j`0504Q8B02b/[80/[:b07moO`1jNWX00P2a/K40102DU9@0WYjN09jNWP1oOgl2
06m_K`050;Fe]@1lO7`0WYjN09jNWP2FUYH00P1eMGD01@2WYjL0IFEU0=;BdP3Bd]80Kfm_0080I6AT
00D0dM7A06a/K01/K6`0Z:RX08Z:RP0209NGU`05075aL@2RXZ80XZ:R0<g=c@13@d<00P1aLG401@3I
fMT0N7Qh07QhN02FUYH0/;2`0080Bd];00@0O7al0<G5a@35aLD0h>3P0P0M7Ad01@2=SHd0_kno071`
L01`L700/;2`0080YJFU00D0Lg=c07emO@1dM7@0M7Ad0<c<c00208F5Q@0507emO@2FUYH0UYJF09^K
V`2OWil00P1oOgl0101[Jf/0Rh^;08^;R`2d];@3096AT@0509BDU02OWil0WinO07emO@23Ph<00P2@
T900102LW9`0X:2P0:2PX01dM7@209ZJVP0508V9R@2<S8`0/k>c0;>c/`1jNWX00P2KVi/01@20P800
Ph>309jNWP2NWYh0X:2P0080Q8B400D0Kfm_0:^[Z`2[Zj/0RHV909VIV@0208^;R`0409VIV@26QXH0
QXJ609jNWPX0oooo00@0XJ6Q08^;R`2;Rh/0OGem0P1VIVH01@1YJFT0Kfm_07inOP1nOWh0O7al0080
Ph>300D0Ng]k07alO01lO7`0TI6A0;Ng]`020<;2`P050<30`03;bl/0bl_;0;:b/P2ATI400P23Ph<0
101jNWX0Kfm_06m_K`1]KFd206a/K00506][J`1VIVH0Jf][06][J`1fMWH00P1iNGT01@23Ph<0SHf=
08>3P`23Ph<0OGem0080Ph>300D0TY:B0:ZZZP2k^k/0^k^k0<g=c@020>7Qh@050=cLg03<c<`0c<c<
0=?Cd`3@d=000P38b<P01@32`/80a/K60<K6aP2l_;`0/k>c0080Zj^[00@0Z:RX0:ZZZP2ZZZX0/[:b
0P2d];@01@2a/K40^[Zj0<30`030`<00bl_;0080dm?C00D0g]kN0>_[j`3_knl0kno_0?Gem@020?Cd
m0050>7Qh@3EeMD0eMGE0=GEe@30`<000P32`/80103;bl/0e]KF0=KFeP3<c<`30<C4a0050<o?c`37
alL0alO70<30`02o_kl00P2c/k<0102QXJ40PX:208:2PP1iNGT307IfMP0407inOP2=SHd0SHf=09>C
T`80S8b<00D0Ogmo06e]K@1]KFd0KFe]06MWI`0207=cL`0507YjNP1nOWh0OWin079bLP1mOGd00P22
PX801025QHD0T92@092@T02NWYh309NGU`0309jNWP2OWil0WinO00D0W9bL0P2?Shl01@23Ph<0Q8B4
08B4Q01RHV80DE5A0080FUYJ00D0IfMW06i^KP1^KVh0TI6A0:6QX@020:VYZ@040<O7a`3@d=00d=3@
0<C4a080[Zj^00D0VYZJ06YZJP1RHV80HV9R06a/K00208>3P`0309NGU`3oool0oooo00d0oooo000=
0?ooo`0408n?S`1YJFT0JFUY0=_Kf`80JFUY00D0Ogmo09fMW@2ATI40TI6A07YjNP0209:BTP050;Rh
^01fMWH0MWIf0820P02GUiL00P2d];@00`29RHT0MgMg07MgM`0208f=S@80WinO00@0VIVI08N7Q`27
QhL0S8b<0P2TY:@01@2QXJ40G5aL09RHV02HV9P0XJ6Q0080KVi^00D0X:2P09JFUP2MWId0WIfM0:NW
Y`02075aL@0506i^KP2WYjL0WYjN09jNWP2EUID00P2<S8`01@2[Zj/0JVYZ06YZJP1cLg<0Ph>30080
lo?c00D0BDU90:ZZZP2ZZZX0PX:207=cL`020;no_`0408b<S02NWYh0WYjN07emO@80MWIf00D0/;2`
07QhN02QXJ40XJ6Q09VIV@0207=cL`050:2PX01_Kfl0d];B0=;BdP1ZJVX00P1VIVH01@3<c<`0L71`
071`L02XZ:P0S8b<0080Ti>C00D0L71`0:NWY`2WYjL0a<C404e=C@0207=cL`050<S8b025QHD0QHF5
09NGU`2XZ:P00P1HF5P0101`L700bl_;0<_;b`3MgMd201hN7P0509>CT`2g]kL0LG5a075aL@2b/[80
0P2VYZH01@1_Kfl0Q8B4071`L01`L700cLg=0080PX:200D0Q8B408f=S@2=SHd0WYjN0:>SX`0207Ad
M00507UiN@23Ph<0Ph>30;Fe]@2?Shl00P2EUID01@2DU9@0Vi^K09^KV`1oOgl0QHF50080TI6A00@0
UIFE0:NWY`2WYjL0LG5a0P2HV9P01@2@T900QHF50;Ng]`2g]kL0N7Qh0080WYjN00D0O7al08B4Q02Q
XJ40XJ6Q09nOW`0208:2PP0507=cL`2`/;00/;2`07]kN`2LW9`00P2ATI40102FUYH0S8b<08b<S02F
UYH:0?ooo`040;no_`3Shn<0hn?S0?Shn0@0oooo0P3^k^h0103]kNd0h^;R0>;RhP3Jf]X20<_;b`05
0:BTY02:RXX0Ph>308>3P`25QHD00P2<S8`01@2VYZH0XZ:R0:JVYP2VYZH0];Bd0080[Zj^00@0^KVi
0<c<c03<c<`0d];B0`3Lg=`01@3AdM40c<c<0<c<c02a/K40TY:B0080OWin00D0KVi^06=SH`1SHf<0
H61P05]KF`0206UYJ@0406QXJ01NGUh0GUiN06=SH`80N7Qh00D0OGem08V9R@2JVYX0VYZJ09fMW@02
09BDU0@0SXj>00@0VIVI09fMW@2MWId0VYZJ0`2TY:@0102MWId0Ti>C09>CT`1lO7`206i^KP0506][
J`1WIfL0IFEU06EUI@1bLW800P1aLG401@1_Kfl0HF5Q065QH@1FEUH0GEeM0080F5QH00D0FUYJ05MG
E`1GEeL0IfMW06YZJP02071`L005061PH01/K6`0K6a/07IfMP1mOGd00P26QXH0102SXj<0ZZZZ0:ZZ
ZP2WYjL20:b/[080[Jf]0P36a/H01@3@d=00fMWI0=WIf@3Lg=`0gMgM0080aLG500@0`<300;Ng]`2g
]kL0/K6a0P2VYZH01@2YZJT0WYjN09RHV02HV9P0VYZJ0080WinO00D0Vi^K09FEU@2?Shl0Shn?07Yj
NP0206i^KP0506YZJP1bLW80O7al07alO02;Rh/00P2UYJD01@2c/k<0X:2P0:2PX02ATI40Rh^;0080
KVi^00D0HV9R07EeM@1eMGD0MWIf07alO00208B4Q00407YjNP20P800P82009^KV`80[:b/00D0`<30
0<o?c`36a/H0a/K60;Vi^@020:f][@030:VYZ@3oool0oooo00d0oooo000=0?ooo`0408n?S`1YJFT0
JFUY0=_Kf`80JFUY00D0Ogmo09fMW@2ATI40TI6A07YjNP0209:BTP050;Rh^01fMWH0MWIf0820P02G
UiL00P2d];@00`29RHT0MgMg07MgM`0208f=S@80WinO00@0VIVI08N7Q`27QhL0S8b<0P2TY:@01@2Q
XJ40G5aL09RHV02HV9P0XJ6Q0080KVi^00D0X:2P09JFUP2MWId0WIfM0:NWY`02075aL@0506i^KP2W
YjL0WYjN09jNWP2EUID00P2<S8`01@2[Zj/0JVYZ06YZJP1cLg<0Ph>30080lo?c00D0BDU90:ZZZP2Z
ZZX0PX:207=cL`020;no_`0408b<S02NWYh0WYjN07emO@80MWIf00D0/;2`07QhN02QXJ40XJ6Q09VI
V@0207=cL`050:2PX01_Kfl0d];B0=;BdP1ZJVX00P1VIVH01@3<c<`0L71`071`L02XZ:P0S8b<0080
Ti>C00D0L71`0:NWY`2WYjL0a<C404e=C@0207=cL`050<S8b025QHD0QHF509NGU`2XZ:P00P1HF5P0
101`L700bl_;0<_;b`3MgMd201hN7P0509>CT`2g]kL0LG5a075aL@2b/[800P2VYZH01@1_Kfl0Q8B4
071`L01`L700cLg=0080PX:200D0Q8B408f=S@2=SHd0WYjN0:>SX`0207AdM00507UiN@23Ph<0Ph>3
0;Fe]@2?Shl00P2EUID01@2DU9@0Vi^K09^KV`1oOgl0QHF50080TI6A00@0UIFE0:NWY`2WYjL0LG5a
0P2HV9P01@2@T900QHF50;Ng]`2g]kL0N7Qh0080WYjN00D0O7al08B4Q02QXJ40XJ6Q09nOW`0208:2
PP0507=cL`2`/;00/;2`07]kN`2LW9`00P2ATI40102FUYH0S8b<08b<S02FUYH:0?ooo`040;no_`3S
hn<0hn?S0?Shn0@0oooo0P3^k^h0103]kNd0h^;R0>;RhP3Jf]X20<_;b`050:BTY02:RXX0Ph>308>3
P`25QHD00P2<S8`01@2VYZH0XZ:R0:JVYP2VYZH0];Bd0080[Zj^00@0^KVi0<c<c03<c<`0d];B0`3L
g=`01@3AdM40c<c<0<c<c02a/K40TY:B0080OWin00D0KVi^06=SH`1SHf<0H61P05]KF`0206UYJ@04
06QXJ01NGUh0GUiN06=SH`80N7Qh00D0OGem08V9R@2JVYX0VYZJ09fMW@0209BDU0@0SXj>00@0VIVI
09fMW@2MWId0VYZJ0`2TY:@0102MWId0Ti>C09>CT`1lO7`206i^KP0506][J`1WIfL0IFEU06EUI@1b
LW800P1aLG401@1_Kfl0HF5Q065QH@1FEUH0GEeM0080F5QH00D0FUYJ05MGE`1GEeL0IfMW06YZJP02
071`L005061PH01/K6`0K6a/07IfMP1mOGd00P26QXH0102SXj<0ZZZZ0:ZZZP2WYjL20:b/[080[Jf]
0P36a/H01@3@d=00fMWI0=WIf@3Lg=`0gMgM0080aLG500@0`<300;Ng]`2g]kL0/K6a0P2VYZH01@2Y
ZJT0WYjN09RHV02HV9P0VYZJ0080WinO00D0Vi^K09FEU@2?Shl0Shn?07YjNP0206i^KP0506YZJP1b
LW80O7al07alO02;Rh/00P2UYJD01@2c/k<0X:2P0:2PX02ATI40Rh^;0080KVi^00D0HV9R07EeM@1e
MGD0MWIf07alO00208B4Q00407YjNP20P800P82009^KV`80[:b/00D0`<300<o?c`36a/H0a/K60;Vi
^@020:f][@030:VYZ@3oool0oooo00d0oooo000=0?ooo`0409FEU@1QHF40HF5Q0>7Qh@80IfMW00D0
Ogmo09bLW02GUiL0UiNG075aL@0209VIV@050;>c/`1iNGT0NGUi07moO`2EUID00P2h^;P01@27QhL0
MWIf07IfMP2;Rh/0Ti>C0080V9RH00@0UIFE09JFUP2FUYH0OGem0P2/[:`01@2PX:00FUYJ09JFUP2F
UYH0Zj^[0080IFEU00D0YJFU09FEU@2KVi/0Vi^K0:>SX`0207MgM`0506e]K@2XZ:P0VYZJ09ZJVP2D
U9@00P2?Shl01@2YZJT0JVYZ06YZJP1eMGD0P8200080n?Sh00D0BDU90:BTY02TY:@0Ph>3079bLP02
0<S8b00408F5Q@2PX:00X:2P07alO080N7Qh00D0[jn_07=cL`2RXZ80XZ:R0:6QX@0206e]K@0509fM
W@1fMWH0d];B0=;BdP1]KFd00P1SHf<01@3;bl/0Kfm_06m_K`2XZ:P0Shn?0080U9BD00D0Kfm_0:RX
Z02XZ:P0^k^k05QHF00207IfMP050;Fe]@2GUiL0UiNG09FEU@2NWYh00P1PH600101ZJVX0dM7A0=7A
d@3EeMD2028R8P0509ZJVP2][Jd0N7Qh07QhN02`/;000P2WYjL01@1[Jf/0RHV906e]K@1]KFd0clo?
0080OWin00D0S8b<0861P@21PH40ZJVY09fMW@0207=cL`0508B4Q01nOWh0OWin0;2`/02?Shl00P2E
UID01@2DU9@0WIfM09fMW@1oOgl0QHF50080T92@00@0Shn?0;2`/02`/;00KVi^0P2BTY801@2GUiL0
P8200;Vi^@2i^KT0O7al0080V9RH00D0PH6108F5Q@2IVIT0VIVI0:2PX00208F5Q@0507alO02YZJT0
ZJVY06i^KP2VYZH00P2DU9@0102@T900V9RH09RHV02;Rh/:0?ooo`0404i>CP15ADD0ADE504a<C080
D51@00D0E5AD04i>CP1FEUH0EUIF0410@00203De=@0504E5A@1MGEd0GEeM07UiN@2?Shl00P2][Jd0
1@2g]kL0ZJVY0:VYZ@2GUiL0WinO0080VIVI00@0R8R808^;R`2;Rh/0QHF50P1kNg/01@1/K6`0IVIV
06i^KP1^KVh0MGEe0080P82000D0WIfM0;6a/@3;bl/0bl_;0>GUi@020>KViP050=kNgP3GemL0^k^k
0;^k^`2QXJ400P2JVYX309FEU@05096AT@29RHT0QXJ608J6QP25QHD00P23Ph<01@2;Rh/0UIFE09BD
U02DU9@0UYJF0080SHf=00D0RHV907AdM01dM7@0MWIf07MgM`0207YjNP0508N7Q`2FUYH0UYJF08R8
R01gMgL00P1]KFd0101KFe/0FUYJ05YJFP1`L70208>3P`05092@T02IVIT0WinO09nOW`2KVi/00P2N
WYh01@2^[Zh0_kno0;fm_@2m_Kd0bl_;0080alO700D0^;Rh0;no_`30`<00`<300:b/[0030<?3``80
Z:RX00D0Y:BT0:>SX`23Ph<0Ph>307YjNP0207emO@0508J6QP2<S8`0WinO09nOW`2/[:`00P2d];@0
1@2f][H0/[:b0;:b/P2ATI40V9RH0080Ti>C00D0RHV908f=S@2=SHd0Xj>S09fMW@0209bLW0050;>c
/`2/[:`0[:b/0;6a/@2ZZZX00P2SXj<0102@T900Ti>C09>CT`2;Rh/209JFUP050:ZZZP2/[:`0YjNW
0:NWY`2MWId00P2CTi<01@25QHD0MWIf06i^KP1^KVh0NWYj0080MgMg00D0HV9R071`L01`L700PH61
096AT@0208b<S00409FEU@21PH40PH6106][J`l0oooo000=0?ooo`0409RHV01NGUh0GUiN0>CTi080
IFEU00D0Ogmo09fMW@2GUiL0UiNG071`L00209^KV`050;2`/01iNGT0NGUi0820P02EUID00P2f][H0
1@2:RXX0NWYj07YjNP26QXH0VYZJ0080Shn?00@0TY:B0:JVYP2VYZH0Kfm_0P2b/[801@2PX:00F5QH
09NGU`2GUiL0/;2`0080G5aL00D0ZZZZ09FEU@2EUID0UIFE0:JVYP0207UiN@0306i^KP2YZJT0UYJF
0080UYJF0P2@T9001@2VYZH0JFUY06UYJ@1jNWX0OWin0080m_Kf00D0C4a<0::RXP2RXZ80PH6107=c
L`020<k>cP0407moO`2QXJ40XJ6Q07moO`80N7Qh00D0ZJVY07EeM@2PX:00X:2P0:ZZZP0206IVIP05
09NGU`20P800d=3@0=3@d01/K6`00P1QHF401@38b<P0Lg=c07=cL`2WYjL0Shn?0080UIFE00D0Kfm_
0:ZZZP2ZZZX0];Bd05aLG0020820P0050:6QX@2RXZ80XZ:R09JFUP2HV9P00P1]KFd0101PH600eMGE
0=GEe@3Bd]8201hN7P050:NWY`2QXJ40Ogmo07moO`2][Jd00P2ZZZX01@1TI6@0T92@06YZJP1ZJVX0
c/k>0080NWYj00D0Vi^K06i^KP1^KVh0][Jf09FEU@02079bLP0508j>SP1fMWH0MWIf0;2`/02ATI40
0P2CTi<01@2EUID0Vi^K09^KV`23Ph<0Q8B40080TY:B00@0Rh^;0;Jf]P2f][H0KFe]0P2=SHd01@2I
VIT0OGem0;^k^`2k^k/0PH610080U9BD00D0QHF508V9R@2<S8`0S8b<0:>SX`0208V9R@0508B4Q02Q
XJ40XJ6Q06QXJ02_[jl00P2CTi<0102:RXX0WIfM09fMW@28R8P:0?ooo`040<30`02`/;00/;2`09^K
V`80RHV900D0QhN708n?S`2SXj<0Xj>S0<C4a0020<c<c0050;fm_@2e]KD0]KFe09VIV@1[Jf/00P1>
CTh01@16ATH0B4Q804Q8B01MGEd0MWIf0080Shn?00@0WIfM0;2`/02`/;00[Jf]0P2/[:`01@2^[Zh0
Zj^[09VIV@2IVIT0V9RH0080Rh^;00D0RXZ:09:BTP2CTi<0Ti>C08:2PP0208b<S00508J6QP29RHT0
X:2P0:2PX02h^;P00P2l_;`01@34a<@0^k^k0;^k^`2/[:`0YjNW0080WIfM0`2KVi/01@2IVIT0WIfM
0:NWY`2WYjL0Xj>S0080ZZZZ00D0[jn_0:RXZ02XZ:P0WYjN09NGU`020:>SX`050;2`/02o_kl0_kno
0=gMg@3emOD00`3oool20?knoP050>KViP3MgMd0gMgM0=WIf@2l_;`00P2h^;P01@2a/K40Y:BT0:BT
Y02<S8`0Ng]k0080Lg=c00D0KFe]06UYJ@1YJFT0GemO05YJFP0205mOG`0406][J`1GEeL0EeMG069R
HP80O7al00D0NWYj07EeM@24Q8@0Q8B408>3P`0207emO@0507moO`26QXH0QhN708N7Q`24Q8@00P1l
O7`01@1iNGT0MWIf07IfMP2>SXh0PH610080Rh^;00D0Shn?08V9R@29RHT0Lg=c0820P002075aL@05
065QH@1XJ6P0J6QX06m_K`1bLW800P1mOGd0102@T900OWin07inOP25QHD209>CT`0509VIV@2OWil0
e]KF0=KFeP3QhN400`3De=@0103QhN40aLG50<G5a@2/[:`20:JVYP050:j^[P2ATI40TI6A08>3P`1i
NGT00P27QhL0102:RXX0YjNW0:NWY`2f][H?0?ooo`003@3oool0102HV9P0GUiN05iNGP3Ti>@206EU
I@0507moO`2MWId0UiNG09NGU`1`L7000P2KVi/01@2`/;00NGUi07UiN@20P800UIFE0080][Jf00D0
RXZ:07YjNP1jNWX0QXJ609ZJVP0208n?S`0409:BTP2VYZH0YZJV06m_K`80/[:b00D0X:2P05QHF02G
UiL0UiNG0;2`/00205aLG0050:ZZZP2EUID0UIFE09FEU@2VYZH00P1iNGT00`1^KVh0ZJVY09JFUP02
09JFUP80T92@00D0YZJV06UYJ@1YJFT0NWYj07inOP020?KfmP0504a<C02RXZ80XZ:R0861P@1cLg<0
0P3>c/h0101oOgl0XJ6Q0:6QX@1oOgl207QhN0050:VYZ@1eMGD0X:2P0:2PX02ZZZX00P1VIVH01@2G
UiL0P8200=3@d03@d=00K6a/0080HF5Q00D0b<S807=cL`1cLg<0YjNW08n?S`0209FEU@0506m_K`2Z
ZZX0ZZZZ0;Bd]01LG5`00P20P8001@2QXJ40XZ:R0::RXP2FUYH0V9RH0080KFe]00@0H61P0=GEe@3E
eMD0d];B0P0N7Qh01@2WYjL0XJ6Q07moO`1oOgl0[Jf]0080ZZZZ00D0I6AT092@T01ZJVX0JVYZ0<k>
cP0207YjNP0509^KV`1^KVh0KVi^0;Jf]P2EUID00P1bLW801@2>SXh0MWIf07IfMP2`/;00TI6A0080
Ti>C00D0UIFE09^KV`2KVi/0Ph>308B4Q00209:BTP0408^;R`2f][H0][Jf06e]K@80SHf=00D0VIVI
07emO@2k^k/0^k^k0861P@0209BDU00508F5Q@29RHT0S8b<08b<S02SXj<00P29RHT01@24Q8@0XJ6Q
0:6QX@1XJ6P0[jn_0080Ti>C00@0RXZ:09fMW@2MWId0R8R82P3oool01030`<00/;2`0;2`/02KVi/2
08V9R@0508N7Q`2?Shl0Xj>S0:>SX`34a<@00P3<c<`01@2m_Kd0]KFe0;Fe]@2IVIT0Jf][0080CTi>
00D0ATI604Q8B018B4P0GEeM07IfMP0208n?S`0409fMW@2`/;00/;2`0:f][@80[:b/00D0[Zj^0:^[
Z`2IVIT0VIVI09RHV00208^;R`0508Z:RP2BTY80Ti>C09>CT`22PX800P2<S8`01@26QXH0RHV90:2P
X02PX:00^;Rh0080_;bl00D0a<C40;^k^`2k^k/0[:b/0:NWY`0209fMW@<0Vi^K00D0VIVI09fMW@2W
YjL0YjNW0:>SX`020:ZZZP050:n_[`2XZ:P0Z:RX09jNWP2GUiL00P2SXj<01@2`/;00_kno0;no_`3M
gMd0mOGe00<0oooo0P3no_h01@3Vi^H0gMgM0=gMg@3IfMT0_;bl0080^;Rh00D0/K6a0:BTY02TY:@0
S8b<07]kN`0207=cL`0506e]K@1YJFT0JFUY05mOG`1JFUX00P1OGel0101[Jf/0EeMG05MGE`1RHV82
07alO00507YjNP1eMGD0Q8B408B4Q023Ph<00P1mOGd01@1oOgl0QXJ608N7Q`27QhL0Q8B40080O7al
00D0NGUi07IfMP1fMWH0SXj>0861P@0208^;R`0508n?S`29RHT0RHV907=cL`20P8000P1aLG401@1Q
HF40J6QX06QXJ01_Kfl0LW9b0080OGem00@0T92@07inOP1nOWh0QHF50P2CTi<01@2IVIT0WinO0=KF
eP3Fe]H0hN7Q00<0e=CD00@0hN7Q0<G5a@35aLD0[:b/0P2VYZH01@2^[Zh0TI6A096AT@23Ph<0NGUi
0080QhN700@0RXZ:0:NWY`2WYjL0][Jf3`3oool000d0oooo00@0UiNG05mOG`1OGel0iNGU0P1VIVH0
1@21PH40Vi^K09FEU@2EUID0L71`0080WIfM00D0[Zj^07QhN01hN7P0QXJ609BDU0020;Bd]00508R8
R01nOWh0OWin08B4Q02IVIT00P2<S8`0102BTY80ZJVY0:VYZ@1/K6`20;:b/P050::RXP1IFET0UIFE
09FEU@2d];@00P1IFET01@2^[Zh0TY:B096AT@2ATI40ZZZZ0080N7Qh00D0K6a/0:b/[02@T900T92@
09VIV@0209BDU0050:>SX`1WIfL0IfMW07emO@21PH400P3`l?001@1ADE40X:2P0:2PX021PH40Lg=c
0080d];B00@0O7al09jNWP2NWYh0Q8B40P1gMgL01@2UYJD0MWIf0:6QX@2QXJ40/[:b0080H61P00D0
UIFE08>3P`3<c<`0c<c<06i^KP0206=SH`050<?3``1gMgL0MgMg0:JVYP2>SXh00P2EUID01@1aLG40
YjNW0:NWY`2a/K40Hf=S0080Q8B400D0U9BD0:JVYP2VYZH0X:2P08N7Q`0207UiN@0405iNGP3AdM40
dM7A0=7Ad@80820P00D0ZJVY09^KV`26QXH0QXJ60:RXZ0020:f][@05069RHP2CTi<0JVYZ06YZJP39
bLT00P1kNg/01@2QXJ40IVIV06IVIP30`<00Rh^;0080LG5a00D0Xj>S06QXJ01XJ6P0[Zj^09:BTP02
09>CT`0509NGU`2HV9P0V9RH08R8R01oOgl00P2EUID01028R8P0^;Rh0;Rh^01`L70208B4Q0050:2P
X01lO7`0^KVi0;Vi^@21PH400P2<S8`01@2=SHd0TI6A07alO01lO7`0ZJVY0080R8R800D0Shn?09FE
U@2EUID0IVIV0;^k^`0208j>SP0408N7Q`2KVi/0Vi^K08^;R`X0oooo00@0UYJF09^KV`2KVi/0Vi^K
0P2UYJD01@2KVi/0XZ:R08^;R`2;Rh/0OGem0080RXZ:00D0XJ6Q0:NWY`2WYjL0a/K60>c/k0020>g]
k@050?3`l03fm_H0m_Kf0?7al@3Kfm/00P3?cll01038b<P0[Jf]0:f][@2HV9P208f=S@0508V9R@25
QHD0SHf=08f=S@2DU9@00P2PX:001@2DU9@0SXj>08n?S`2?Shl0UiNG0080TI6A00D0V9RH08n?S`1e
MGD0MGEe06][J`0206IVIP0506MWI`1^KVh0KVi^07YjNP1fMWH00P1dM7@01@1aLG40MgMg07MgM`1m
OGd0Ng]k0080P82000@0S8b<08>3P`23Ph<0Ph>30P2IVIT01@2NWYh0WinO09NGU`2GUiL0TY:B0080
NWYj00D0GemO04m?C`1=CDd0CDe=04=3@`0204];B`0505iNGP1FEUH0EUIF04e=C@1]KFd00P1dM7@0
1@22PX80Ti>C09>CT`2MWId0V9RH00<0VIVI0P2NWYh01@2PX:00Ti>C08^;R`2;Rh/0MWIf0080Ng]k
00D0QHF508:2PP22PX80QhN709JFUP0208n?S`05096AT@2IVIT0VIVI09:BTP2=SHd00P28R8P01025
QHD0NWYj07YjNP22PX8207inOP0508f=S@2<S8`0VIVI09VIV@2JVYX00P2WYjL01@2SXj<0YjNW0;Zj
^P2j^[X0a/K60080d=3@00@0c/k>0=GEe@3:b/X0b/[:0`31`L401@2j^[X0[Jf]0:f][@2_[jl0[Jf]
0080MWIf00D0M7Ad08>3P`23Ph<0MWIf05EEE@02075aL@040861P@1^KVh0KVi^06IVIP80Rh^;00D0
UIFE09NGU`2UYJD0YJFU0;>c/`030:6QX@l0oooo000=0?ooo`0409>CT`1PH600H61P0>7Qh@80Jf][
00D0PX:209^KV`2BTY80TY:B079bLP0209fMW@050;:b/P1`L700L71`08R8R02GUiL00P2a/K401@27
QhL0Ph>308>3P`23Ph<0Vi^K0080QXJ600@0UYJF0:RXZ02XZ:P0KFe]0P2b/[801@2NWYh0GEeM096A
T@2ATI40^;Rh0080EUIF00D0/[:b092@T02=SHd0SHf=0:n_[`0207MgM`0506UYJ@2f][H0PX:208:2
PP2RXZ800P2GUiL01@2NWYh0IFEU06EUI@23Ph<0Ogmo0080jn_[00D0EUIF09bLW02LW9`0Q8B4079b
LP020=GEe@0407]kN`2KVi/0Vi^K08B4Q080Ng]k00D0WYjN07MgM`2RXZ80XZ:R0;Jf]P0205iNGP05
09>CT`26QXH0b/[:0<[:bP1^KVh00P1UIFD01@2m_Kd0NWYj07YjNP2TY:@0UIFE0080U9BD00D0Kfm_
0:JVYP2VYZH0/;2`06IVIP0208N7Q`0508f=S@2XZ:P0Z:RX0:RXZ01lO7`00P20P800101JFUX0f][J
0=[JfP39bLT201lO7`050;:b/P2CTi<0QhN708N7Q`2VYZH00P2_[jl01@1RHV80TI6A06m_K`1_Kfl0
a<C40080Ng]k00D0Xj>S06IVIP1VIVH0a<C408>3P`0207=cL`050:VYZ@1VIVH0IVIV0:f][@2?Shl0
0P2FUYH01@2IVIT0U9BD09BDU02;Rh/0OWin0080Ti>C00@0S8b<0;>c/`2c/k<0MWIf0P1hN7P01@2/
[:`0Ng]k0;>c/`2c/k<0R8R80080Rh^;00D0RXZ:09RHV01`L700L71`0:n_[`0208R8R00509FEU@27
QhL0QhN7079bLP2l_;`00P28R8P0102:RXX0W9bL09bLW02<S8`:0?ooo`0406IVIP1SHf<0Hf=S06IV
IP80JVYZ00D0Kfm_075aL@20P800P82008J6QP0207emO@0507EeM@1bLW80LW9b071`L01_Kfl00P1j
NWX00`1hN7P0M7Ad07AdM00206MWI`80Fe]K00@0FEUI069RHP1RHV80MGEe0P1mOGd01@2ATI40UiNG
09VIV@2IVIT0UIFE0080Shn?00D0Ph>308J6QP1fMWH0MWIf06][J`0206ATI00506e]K@1hN7P0RHV9
08V9R@2HV9P00`2VYZH209nOW`050:>SX`2TY:@0ZZZZ0:ZZZP2[Zj/00P2ZZZX01@2TY:@0WIfM08V9
R@29RHT0MWIf0080NWYj00D0LW9b071`L01`L700Ng]k08N7Q`0208^;R`0509>CT`2LW9`0W9bL0;:b
/P2k^k/00P2e]KD0102d];@0/K6a0;6a/@2MWId20:RXZ0050:n_[`2SXj<0VIVI09VIV@2DU9@00P24
Q8@01@1eMGD0Ph>308V9R@29RHT0R8R80080S8b<00D0[jn_0<30`03:b/X0b/[:0>[ZjP020>7Qh@05
0<K6aP2l_;`0_;bl0;Ng]`2KVi/00P2PX:001@2MWId0T92@092@T02@T900RXZ:0080Ph>300@0QHF5
09>CT`2CTi<0S8b<0`2PX:00102[Zj/0U9BD09BDU02?Shl207inOP0508F5Q@1nOWh0Ogmo07moO`1l
O7`00P1`L7001@1UIFD0GUiN06IVIP1VIVH0KVi^0080NWYj00D0O7al07inOP1nOWh0Kfm_06a/K002
08N7Q`<0U9BD00D0/;2`0<[:bP33`l<0`l?30<;2`P020<30`0050;fm_@2/[:`0[:b/09nOW`2PX:00
0P2GUiL01023Ph<0MgMg07MgM`1^KVh?0?ooo`003@3oool0102=SHd0IVIV06IVIP3Lg=`2071`L005
0820P02LW9`0SXj>08j>SP1iNGT00P2DU9@01@2i^KT0L71`071`L027QhL0UYJF0080/K6a00D0R8R8
0861P@21PH40Q8B409fMW@0207inOP0409fMW@2UYJD0YJFU07=cL`80[Jf]00D0WYjN065QH@2@T900
T92@0;^k^`02059BDP050;>c/`2=SHd0RHV908V9R@2g]kL00P1dM7@01@1[Jf/0][Jf07alO01lO7`0
YZJV0080Vi^K00D0WIfM05mOG`1OGel0S8b<07alO0020>?Sh`05061PH02BTY80TY:B08b<S01bLW80
0P3Cdm<0101kNg/0VIVI09VIV@25QHD208:2PP0509>CT`21PH40V9RH09RHV030`<000P1JFUX01@2B
TY80RXZ:0<K6aP36a/H0Kfm_0080IVIV00D0]kNg08>3P`23Ph<0WIfM09RHV00209:BTP0507MgM`2L
W9`0W9bL0;6a/@1VIVH00P27QhL01@2BTY80X:2P0:2PX02c/k<0KVi^0080QhN700@0EEEE0>KViP3V
i^H0`<300P0N7Qh01@2l_;`0QhN708j>SP2>SXh0Xj>S0080/;2`00D0I6AT08n?S`1fMWH0MWIf0;Vi
^@020861P@0509nOW`1[Jf/0Jf][0<C4a020P8000P1bLW801@2_[jl0Hf=S06=SH`2`/;00R8R80080
W9bL00D0V9RH09JFUP2FUYH0RHV907emO@02096AT@0409>CT`2_[jl0[jn_07YjNP80KVi^00D0/K6a
0820P02][Jd0[Jf]08Z:RP0208B4Q00509BDU02LW9`0HV9R069RHP2a/K400P2?Shl01@2GUiL0Ng]k
07]kN`1mOGd0_Kfm0080PH6100@0SXj>09RHV02HV9P0TI6A2P3oool01038b<P0cLg=0<g=c@3=cLd3
0=3@d0040<g=c@31`L40`L710;fm_@80/[:b00D0YZJV09ZJVP2JVYX0Shn?08^;R`0208Z:RP05096A
T@2<S8`0S8b<08R8R021PH400P1fMWH0101gMgL0MWIf07IfMP1jNWX207UiN@050820P01kNg/0PX:2
08:2PP2:RXX00P27QhL208^;R`80S8b<00D0R8R808n?S`2?Shl0S8b<08>3P`0208f=S@0408n?S`2B
TY80TY:B09FEU@80[Zj^00D0];Bd0;fm_@2l_;`0_;bl0<71`@020;Fe]@80Z:RX0P2b/[80102j^[X0
_;bl0;bl_030`<020;Jf]P050:RXZ02IVIT0Shn?08n?S`2;Rh/00P2CTi<0102;Rh/0RHV909:BTP2B
TY8309RHV0<0YjNW00D0Xj>S0:JVYP2IVIT0VIVI092@T00209nOW`050:^[Z`2ZZZX0]KFe0;Fe]@34
a<@00P2h^;P01@2LW9`0SXj>0820P020P800IFEU0080LW9b00D0Ph>308j>SP2>SXh0WYjN0;Rh^002
0:f][@050;Jf]P2a/K40/K6a0:FUY@2LW9`00P2TY:@0102?Shl0TY:B09:BTP2CTi<208B4Q005069R
HP1^KVh0MGEe07EeM@1mOGd00P27QhL01@2LW9`0WIfM09nOW`2OWil0XJ6Q0080ZJVY00D0ZZZZ0:VY
Z@2IVIT0VIVI08Z:RP0207moO`0508B4Q022PX80PX:208j>SP2CTi<00P1jNWX01@1QHF40EUIF05IF
EP11@D40BDU90080Hf=S00@0Kfm_08:2PP22PX80U9BD0P2=SHd01@2EUID0WinO0:>SX`2SXj<0[Zj^
0080^k^k00<0`<300?ooo`3oool03@3oool000d0oooo00@0SHf=06IVIP1VIVH0g=cL0P1`L7001@20
P800W9bL08j>SP2>SXh0NGUi0080U9BD00D0^KVi071`L01`L700QhN709JFUP020;6a/@0508R8R021
PH40PH6108B4Q02MWId00P1nOWh0102MWId0YJFU0:FUY@1cLg<20:f][@0509jNWP1QHF40T92@092@
T02k^k/00P1BDU801@2c/k<0SHf=08V9R@29RHT0]kNg0080M7Ad00D0Jf][0;Jf]P1lO7`0O7al0:JV
YP0209^KV`0509fMW@1OGel0GemO08b<S01lO7`00P3Shn<01@1PH600TY:B09:BTP2<S8`0LW9b0080
dm?C00@0Ng]k09VIV@2IVIT0QHF50P22PX801@2CTi<0PH6109RHV02HV9P0`<300080FUYJ00D0TY:B
08Z:RP36a/H0a/K606m_K`0206IVIP050;Ng]`23Ph<0Ph>309fMW@2HV9P00P2BTY801@1gMgL0W9bL
09bLW02a/K40IVIV0080QhN700D0TY:B0:2PX02PX:00/k>c06i^KP0208N7Q`0405EEE@3Vi^H0i^KV
0<30`0807QhN00D0_;bl08N7Q`2>SXh0SXj>0:>SX`020;2`/00506ATI02?Shl0MWIf07IfMP2i^KT0
0P21PH401@2OWil0Jf][06][J`34a<@0P8200080LW9b00D0[jn_06=SH`1SHf<0/;2`08R8R00209bL
W00509RHV02FUYH0UYJF08V9R@1mOGd00P2ATI40102CTi<0[jn_0:n_[`1jNWX206i^KP050;6a/@20
P800[Jf]0:f][@2:RXX00P24Q8@01@2DU9@0W9bL069RHP1RHV80/K6a0080Shn?00D0UiNG07]kN`1k
Ng/0OGem0;fm_@020861P@0408j>SP2HV9P0V9RH096AT@X0oooo00@0b<S80<g=c@3=cLd0cLg=0`3@
d=00103=cLd0`L710<71`@2m_Kd20;:b/P050:JVYP2JVYX0VYZJ08n?S`2;Rh/00P2:RXX01@2ATI40
S8b<08b<S028R8P0PH610080MWIf00@0MgMg07IfMP1fMWH0NWYj0P1iNGT01@20P800Ng]k08:2PP22
PX80RXZ:0080QhN70P2;Rh/208b<S00508R8R02?Shl0Shn?08b<S023Ph<00P2=SHd0102?Shl0TY:B
09:BTP2EUID20:j^[P050;Bd]02m_Kd0_;bl0;bl_031`L400P2e]KD20:RXZ080/[:b00@0^[Zj0;bl
_02l_;`0`<300P2f][H01@2XZ:P0VIVI08n?S`2?Shl0Rh^;0080Ti>C00@0Rh^;08V9R@2BTY80TY:B
0`2HV9P30:NWY`050:>SX`2VYZH0VIVI09VIV@2@T9000P2OWil01@2[Zj/0ZZZZ0;Fe]@2e]KD0a<C4
0080^;Rh00D0W9bL08j>SP20P800P82006EUI@02079bLP0508>3P`2>SXh0SXj>09jNWP2h^;P00P2]
[Jd01@2f][H0/K6a0;6a/@2UYJD0W9bL0080Y:BT00@0Shn?09:BTP2BTY80Ti>C0P24Q8@01@1RHV80
KVi^07EeM@1eMGD0OGem0080QhN700D0W9bL09fMW@2OWil0WinO0:6QX@020:VYZ@050:ZZZP2YZJT0
VIVI09VIV@2:RXX00P1oOgl01@24Q8@0PX:208:2PP2>SXh0Ti>C0080NWYj00D0HF5Q05IFEP1FEUH0
@D5104U9B@0206=SH`0406m_K`22PX80PX:209BDU080SHf=00D0UIFE09nOW`2SXj<0Xj>S0:j^[P02
0;^k^`030<30`03oool0oooo00d0oooo000=0?ooo`0408N7Q`1/K6`0K6a/0=?Cd`80MWIf00D0PH61
09^KV`2:RXX0RXZ:07moO`0208n?S`050;^k^`1/K6`0K6a/08n?S`2BTY800P2`/;001@26QXH0Q8B4
08B4Q020P800X:2P0080N7Qh00@0Y:BT09jNWP2NWYh0NWYj0P2[Zj/01@2LW9`0IFEU08j>SP2>SXh0
^k^k0080De=C00D0/k>c08f=S@25QHD0QHF50;bl_00207AdM00506a/K02g]kL0LG5a075aL@2_[jl0
0P2MWId01@2JVYX0GEeM05eMG@2ATI40OWin0080f=SH00D0Jf][08J6QP26QXH0TI6A07QhN0020<c<
c0040820P02@T900T92@08b<S080RXZ:00D0QhN708R8R02CTi<0Ti>C0<?3``0205QHF00509FEU@2>
SXh0_kno0;no_`1`L7000P1WIfL01@2a/K40SXj>08j>SP2CTi<0X:2P0080Rh^;00D0OGem09FEU@2E
UID0];Bd06IVIP0208B4Q00509VIV@2GUiL0UiNG0;jn_P1TI6@00P2ATI40101=CDd0k^k^0>k^kP2k
^k/201PH60050<O7a`1oOgl0Shn?08n?S`2QXJ400P2c/k<01@1TI6@0Rh^;08B4Q024Q8@0XJ6Q0080
TY:B00D0UiNG07EeM@1eMGD0^;Rh08B4Q00207EeM@050;:b/P1MGEd0GEeM0;6a/@25QHD00P2RXZ80
1@2FUYH0Ti>C09>CT`2>SXh0Ng]k0080SHf=00@0VYZJ0:^[Z`2[Zj/0Ng]k0P1^KVh01@2`/;00QXJ6
0:JVYP2VYZH0T92@0080Ph>300D0U9BD0:2PX01KFe/0Fe]K0;Bd]00208f=S@0509NGU`1jNWX0NWYj
08:2PP2m_Kd00P1nOWh0102CTi<0Shn?08n?S`2JVYX:0?ooo`@0QhN70P1oOgl01@1kNg/0MgMg07al
O01lO7`0Ph>30080UIFE00D0XZ:R0:j^[P2^[Zh0[Zj^09VIV@0208R8R00507emO@20P800P82008Z:
RP2OWil00P2h^;P01033`l<0d];B0=;BdP3Lg=`20>OWi`050=WIf@3Ogml0d];B0=;BdP31`L400P2n
_[h01@38b<P0^k^k0;no_`2o_kl0b/[:0080bLW900D0^[Zj0;Rh^02WYjL0YjNW09BDU00207inOP05
08F5Q@1jNWX0NWYj075aL@1`L7000P1cLg<01@1]KFd0N7Qh07QhN027QhL0SHf=0080TY:B00@0QXJ6
07]kN`1kNg/0MgMg0P1eMGD00`20P800Ti>C09^KV`0209^KV`80V9RH0P2@T90208n?S`0309:BTP2>
SXh0SXj>00<0PX:200D0Rh^;08j>SP2WYjL0YjNW0<30`0020;Bd]0050:ZZZP2VYZH0T92@092@T01f
MWH00P1nOWh01@24Q8@0Ng]k08F5Q@25QHD0TY:B00<0TI6A0P2QXJ401@2@T900QhN708^;R`2;Rh/0
RHV90080RXZ:00D0WYjN0;2`/02f][H0][Jf0;Zj^P020<C4a0050<S8b03@d=00d=3@0>GUi@3Kfm/0
0P36a/H01@2o_kl0/;2`0;2`/02HV9P0W9bL00<0X:2P0P2OWil01@2TY:@0[:b/0;Jf]P2f][H0^k^k
0080_[jn00D0^[Zj0;6a/@2a/K40X:2P09NGU`020;Zj^P050=?Cd`3Ng]h0g]kN0?KfmP3`l?000P3<
c<`0102e]KD0YZJV0:JVYP2HV9P209jNWP0408N7Q`1dM7@0Lg=c07=cL`<0KFe]00<0OWin0?ooo`3o
ool03@3oool000d0oooo00@0P820071`L01`L700c/k>0P1mOGd01@1oOgl0UiNG08Z:RP2:RXX0Q8B4
0080S8b<00D0_;bl06YZJP1ZJVX0U9BD092@T0020:f][@0508R8R027QhL0QhN707]kN`2XZ:P00P1a
LG40102XZ:P0Vi^K09^KV`1nOWh20:NWY`0509ZJVP1XJ6P0S8b<08b<S02l_;`00P1CDe<01@2c/k<0
R8R808F5Q@25QHD0_Kfm0080N7Qh00D0KVi^0;Bd]01XJ6P0J6QX0;Rh^0020:BTY005092@T01PH600
H61P09FEU@1lO7`00P3@d=0307MgM`0509^KV`1jNWX0b/[:0<[:bP23Ph<00P28R8P01@2ATI40SXj>
08j>SP1oOgl0SXj>0080SHf=00D0b<S805EEE@1EEED0V9RH09BDU0020;Bd]00407MgM`1XJ6P0J6QX
0:VYZ@80VIVI00D0S8b<0:>SX`2;Rh/0Rh^;08:2PP0208f=S@050;Rh^01VIVH0Ph>308>3P`2NWYh0
0P2>SXh01@3:b/X0F5QH09JFUP2FUYH0Bd];0080l_;b00D0]kNg01XJ6P0J6QX0b/[:07UiN@0209>C
T`0509jNWP2e]KD0]KFe06EUI@26QXH00P2@T900102ATI40WinO09nOW`28R8P208B4Q0050:j^[P25
QHD0OWin07inOP2][Jd00P1NGUh01@2/[:`0QHF50:NWY`2WYjL0Ti>C0080T92@00D0TY:B07]kN`2:
RXX0RXZ:09bLW0020:VYZ@0507]kN`1^KVh0KVi^0;2`/028R8P00P2OWil01@2CTi<0QHF508F5Q@2B
TY80XZ:R0080FEUI00@0];Bd08b<S02<S8`0UYJF0P1kNg/01@27QhL0^;Rh07emO@1mOGd0UiNG0080
RXZ:00<0X:2P0?ooo`3oool0203oool01025QHD0SHf=08f=S@2FUYH209fMW@050::RXP2WYjL0Xj>S
0:>SX`2ATI400P26QXH01@29RHT0R8R808R8R02?Shl0/[:b0080bLW900D0cLg=0<[:bP3:b/X0a/K6
0;Bd]0020:VYZ@040:2PX02HV9P0V9RH08V9R@80MgMg00@0LG5a06][J`1`L700L71`0`1lO7`00`1j
NWX0OWin07IfMP0407IfMP0508:2PP2;Rh/0VIVI09VIV@2MWId00P2][Jd00`2TY:@0WinO09nOW`02
09^KV`80U9BD102CTi<0102=SHd0Shn?08n?S`2IVIT20::RXP050:FUY@2_[jl0[jn_0:6QX@2BTY80
0P27QhL01@22PX80Lg=c07=cL`1oOgl0OWin0080MWIf00@0LG5a07UiN@1iNGT0Q8B40P23Ph<01@1n
OWh0O7al079bLP1bLW80HF5Q0080JVYZ00@0LW9b07AdM01jNWX0NWYj0`28R8P01@2>SXh0UIFE09VI
V@2IVIT0V9RH0080SHf=00D0Shn?07moO`1oOgl0OWin07UiN@0207YjNP0506UYJ@1cLg<0Lg=c07=c
L`1_Kfl00P1gMgL0102:RXX0OGem07emO@1YJFT206MWI`0506QXJ01ZJVX0R8R808R8R02RXZ800P2`
/;001@2e]KD0[Zj^0:BTY02TY:@0WIfM0080UiNG00@0UYJF08b<S029RHT0RHV90`2=SHd01@2<S8`0
WinO09nOW`2c/k<0]kNg0080Y:BT00D0VIVI08n?S`2?Shl0NWYj07IfMP0208^;R`0408f=S@2QXJ40
XJ6Q0:b/[080[Jf]00D0`L710<g=c@2h^;P0^;Rh0:ZZZP020:6QX@0308R8R03oool0oooo00d0oooo
000=0?ooo`040820P01`L700L71`0<k>cP80OGem00D0Ogmo09NGU`2:RXX0RXZ:08B4Q00208b<S005
0;bl_01ZJVX0JVYZ09BDU02@T9000P2][Jd01@28R8P0QhN708N7Q`1kNg/0Z:RX0080LG5a00@0Z:RX
09^KV`2KVi/0OWin0P2WYjL01@2JVYX0J6QX08b<S02<S8`0_;bl0080De=C00D0/k>c08R8R025QHD0
QHF50;fm_@0207QhN00506i^KP2d];@0J6QX06QXJ02h^;P00P2TY:@01@2@T900H61P061PH02EUID0
O7al0080d=3@0`1gMgL01@2KVi/0NWYj0<[:bP3:b/X0Ph>30080R8R800D0TI6A08j>SP2>SXh0Ogmo
08j>SP0208f=S@050<S8b01EEED0EEEE09RHV02DU9@00P2d];@0101gMgL0J6QX06QXJ02YZJT209VI
V@0508b<S02SXj<0Rh^;08^;R`22PX800P2=SHd01@2h^;P0IVIV08>3P`23Ph<0WYjN0080SXj>00D0
b/[:05QHF02FUYH0UYJF04];B`020?;blP050;Ng]`0J6QX06QXJ0<[:bP1iNGT00P2CTi<01@2NWYh0
]KFe0;Fe]@1UIFD0QXJ60080T92@00@0TI6A09nOW`2OWil0R8R80P24Q8@01@2^[Zh0QHF507inOP1n
OWh0[Jf]0080GUiN00D0[:b/08F5Q@2WYjL0YjNW09>CT`02092@T00509:BTP1kNg/0RXZ:08Z:RP2L
W9`00P2YZJT01@1kNg/0KVi^06i^KP2`/;00R8R80080WinO00D0Ti>C08F5Q@25QHD0TY:B0::RXP02
05UIF@040;Bd]02<S8`0S8b<09JFUP80Ng]k00D0QhN70;Rh^01mOGd0OGem09NGU`0208Z:RP030:2P
X03oool0oooo00P0oooo00@0QHF508f=S@2=SHd0UYJF0P2MWId01@2RXZ80YjNW0:>SX`2SXj<0TI6A
0080QXJ600D0RHV908R8R028R8P0Shn?0;:b/P020<W9b@050<g=c@3:b/X0b/[:0<K6aP2d];@00P2Y
ZJT0102PX:00V9RH09RHV029RHT207MgM`04075aL@1[Jf/0L71`071`L0<0O7al00<0NWYj07inOP1f
MWH0101fMWH01@22PX80Rh^;09VIV@2IVIT0WIfM0080[Jf]00<0Y:BT09nOW`2OWil00P2KVi/209BD
U0@0Ti>C00@0SHf=08n?S`2?Shl0VIVI0P2RXZ801@2UYJD0[jn_0:n_[`2QXJ40TY:B0080QhN700D0
PX:207=cL`1cLg<0Ogmo07inOP0207IfMP04075aL@1iNGT0NGUi08B4Q080Ph>300D0OWin07alO01b
LW80LW9b065QH@0206YZJP04079bLP1dM7@0NWYj07YjNP<0R8R800D0SXj>09FEU@2IVIT0VIVI09RH
V00208f=S@0508n?S`1oOgl0Ogmo07inOP1iNGT00P1jNWX01@1YJFT0Lg=c07=cL`1cLg<0Kfm_0080
MgMg00@0RXZ:07emO@1mOGd0JFUY0P1WIfL01@1XJ6P0JVYZ08R8R028R8P0XZ:R0080/;2`00D0]KFe
0:j^[P2TY:@0Y:BT09fMW@0209NGU`0409JFUP2<S8`0RHV908V9R@<0SHf=00D0S8b<09nOW`2OWil0
/k>c0;Ng]`020:BTY00509VIV@2?Shl0Shn?07YjNP1fMWH00P2;Rh/0102=SHd0XJ6Q0:6QX@2/[:`2
0:f][@050<71`@3=cLd0^;Rh0;Rh^02ZZZX00P2QXJ400`28R8P0oooo0?ooo`0=0?ooo`003@3oool0
101kNg/0MGEe07EeM@38b<P208F5Q@0507emO@2EUID0RHV908V9R@26QXH00P2<S8`01@2i^KT0K6a/
06a/K02GUiL0Rh^;0080ZZZZ00D0QXJ609JFUP2FUYH0Lg=c0:ZZZP0206a/K0040:ZZZP2QXJ40XJ6Q
07YjNP80YjNW00D0VIVI06YZJP29RHT0RHV90<30`002059BDP050;6a/@2:RXX0QHF508F5Q@2i^KT0
0P1oOgl01@1/K6`0/K6a069RHP1RHV80_Kfm0080ZJVY00D0R8R806IVIP1VIVH0VYZJ07QhN0020<O7
a`0508B4Q01[Jf/0Jf][0:>SX`1jNWX00P37alL01025QHD0OGem07emO@2IVIT209:BTP0507UiN@2D
U9@0RXZ:08Z:RP3:b/X00P1@D50209VIV@80[Zj^00@0O7al06MWI`1WIfL0Xj>S0P2OWil01@28R8P0
YZJV08F5Q@25QHD0Rh^;0080R8R800D0][Jf06EUI@25QHD0QHF50:2PX00208V9R@050=;BdP1GEeL0
U9BD09BDU019BDT00P3gmoL01@2b/[806ATI01TI6@3AdM40LW9b0080UIFE00D0WYjN0;Ng]`2g]kL0
IVIV08>3P`0209JFUP0408^;R`2QXJ40XJ6Q08J6QP80R8R800D0ZZZZ0861P@2@T900T92@09VIV@02
06YZJP050:JVYP25QHD0[:b/0:b/[02>SXh00`2BTY80101lO7`0Rh^;08^;R`2HV9P20:ZZZP0507Yj
NP1cLg<0Lg=c0:b/[02:RXX00P2OWil01@2@T900SHf=08f=S@2;Rh/0YJFU0080FEUI00@0/K6a092@
T02@T900U9BD0P1jNWX01@2;Rh/0]KFe07inOP1nOWh0UYJF0080Shn?00<0WinO0?ooo`3oool0203o
ool0102TY:@0UiNG09NGU`2<S8`20820P005075aL@1^KVh0MgMg07MgM`24Q8@00P27QhL01@2<S8`0
UYJF09JFUP2EUID0PX:20080PH610`1mOGd01@25QHD0TY:B09NGU`2GUiL0VYZJ0080VIVI00<0TY:B
09NGU`2GUiL00P2OWil209NGU`0508b<S02;Rh/0Rh^;08B4Q02<S8`00P2RXZ801@2][Jd0]kNg0;Ng
]`2][Jd0YjNW0080TY:B00@0RXZ:0820P020P800Ph>30P27QhL01@2ATI40UiNG09^KV`2KVi/0W9bL
0080Vi^K0P2@T90207moO`0408R8R021PH40PH6108j>SP80S8b<00D0YjNW0:b/[02][Jd0[Jf]0:n_
[`020;Vi^@030:BTY02WYjL0^;Rh0080^;Rh0P2d];@01@2h^;P0_;bl0;bl_02m_Kd0`<300080^k^k
00D0^KVi0;6a/@2a/K40Zj^[0::RXP020:FUY@050:2PX02JVYX0VYZJ09FEU@2SXj<00P2LW9`0102I
VIT0XJ6Q0:6QX@2DU9@208f=S@0509FEU@2QXJ40[Jf]0:f][@3>c/h00P3Cdm<01@3Ogml0f=SH0<C4
a034a<@0^KVi0080_Kfm00D0]KFe0:b/[02/[:`0^KVi0:ZZZP0209^KV`0307moO`27QhL0QhN70080
NGUi0P1WIfL01@1_Kfl0NGUi07UiN@1mOGd0PH610080T92@00@0PX:207inOP1nOWh0NWYj0P1]KFd0
1@1TI6@0LW9b071`L01`L700N7Qh0080PH6100D0Shn?09ZJVP2ATI40TI6A08Z:RP0208N7Q`0507Mg
M`1[Jf/0Jf][06QXJ01dM7@00P1nOWh0102CTi<0Y:BT0:BTY02d];@?0?ooo`003@3oool0101kNg/0
M7Ad07AdM036a/H208R8R00507inOP2BTY80RHV908V9R@2:RXX00P29RHT01@2e]KD0Lg=c07=cL`2H
V9P0RXZ:0080Y:BT00D0Q8B409fMW@2MWId0Kfm_0:ZZZP0206i^KP040:NWY`2YZJT0ZJVY07AdM080
YjNW00D0UYJF06e]K@2;Rh/0Rh^;0<71`@0205=CD`050:b/[02<S8`0QHF508F5Q@2h^;P00P25QHD0
1@1/K6`0[:b/06ATI01TI6@0_;bl0080[Zj^00D0OWin06m_K`1_Kfl0VIVI07UiN@020;fm_@0509:B
TP1PH600H61P0:ZZZP1kNg/00P35aLD01026QXH0MgMg07MgM`2UYJD208b<S00507EeM@2HV9P0QHF5
08F5Q@3?cll00P1;Bd/209^KV`80Z:RX00@0PH6106QXJ01XJ6P0Vi^K0P2WYjL01@25QHD0ZJVY07mo
O`1oOgl0UIFE0080PX:200D0/k>c06UYJ@25QHD0QHF509fMW@0208Z:RP050=SHf01@D500UIFE09FE
U@1<C4`00P3dm?@01@2c/k<05ADE01DE5@3Lg=`0J6QX0080VIVI00D0Vi^K0;Vi^@2i^KT0JVYZ07mo
O`0209JFUP0408^;R`2QXJ40XJ6Q08J6QP80QHF500D0[:b/07YjNP2UYJD0YJFU08J6QP02075aL@05
09jNWP2;Rh/0[Jf]0:f][@29RHT00P2HV9P01@2<S8`0Ph>308^;R`2;Rh/0Ti>C0080[:b/00D0N7Qh
07UiN@1iNGT0Z:RX08f=S@0209fMW@0508b<S02@T900T92@08^;R`2RXZ800P1LG5`0102^[Zh0Shn?
08n?S`2GUiL207alO00408J6QP2b/[80Q8B408B4Q0<0TY:B00<0WYjN0?ooo`3oool0203oool0102X
Z:P0/K6a0;6a/@2g]kL20;bl_0050<o?c`3@d=00alO70<O7a`2n_[h00P33`l<01@2b/[80X:2P0:2P
X02>SXh0R8R80080L71`0`1SHf<01@1VIVH0HV9R06IVIP1VIVH0M7Ad0080MGEe00D0OWin08B4Q024
Q8@0QXJ608B4Q00208^;R`0509RHV02MWId0WIfM09nOW`2MWId00P2=SHd01@21PH40NGUi07UiN@2;
Rh/0VYZJ0080];Bd00@0^k^k0<[:bP3:b/X0c/k>0P33`l<01@2f][H0/;2`0:NWY`2WYjL0XZ:R0080
X:2P00D0[Jf]0;2`/031`L40`L710;fm_@020<G5a@050;Fe]@2i^KT0^KVi0:BTY02RXZ800`2[Zj/2
0:2PX0050:>SX`2FUYH0PH610861P@1kNg/00P1eMGD01@1cLg<0Jf][06][J`1ZJVX0JFUY0080MWIf
00D0O7al08R8R028R8P0SXj>09^KV`0209NGU`0409RHV02SXj<0Xj>S0:VYZ@<0YjNW00@0[:b/0:j^
[P2^[Zh0/k>c0`2/[:`0102QXJ40T92@092@T01iNGT207MgM`0505eMG@1]KFd0O7al07alO020P800
0P1aLG401@2;Rh/0Ph>308>3P`1fMWH0Ogmo0080SHf=00D0RXZ:0861P@21PH40Q8B408R8R00209FE
U@0509BDU02;Rh/0Rh^;08j>SP2=SHd00P2;Rh/0102VYZH0]KFe0;Fe]@32`/820=WIf@050>?Sh`3I
fMT0hn?S0>?Sh`3GemL00P30`<001@2d];@0YjNW0:>SX`2SXj<0/;2`0080Y:BT00D0Zj^[0;>c/`2c
/k<0ZJVY09BDU0020:>SX`0409fMW@2GUiL0UiNG09>CT`l0oooo000=0?ooo`0407]kN`1dM7@0M7Ad
0<K6aP80R8R800D0OWin09:BTP29RHT0RHV908Z:RP0208V9R@050;Fe]@1cLg<0Lg=c09RHV02:RXX0
0P2TY:@01@24Q8@0WIfM09fMW@1_Kfl0ZZZZ0080KVi^00@0YjNW0:VYZ@2YZJT0M7Ad0P2WYjL01@2F
UYH0KFe]08^;R`2;Rh/0`L710080De=C00D0[:b/08b<S025QHD0QHF50;Rh^00208F5Q@0506a/K02/
[:`0I6AT06ATI02l_;`00P2^[Zh01@1nOWh0Kfm_06m_K`2IVIT0NGUi0080_Kfm00D0TY:B061PH01P
H600ZZZZ07]kN`020<G5a@0408J6QP1gMgL0MgMg0:FUY@80S8b<00D0MGEe09RHV025QHD0QHF50<o?
c`0204];B`80Vi^K0P2XZ:P01021PH40J6QX06QXJ02KVi/20:NWY`0508F5Q@2YZJT0Ogmo07moO`2E
UID00P22PX801@2c/k<0JFUY08F5Q@25QHD0WIfM0080RXZ:00D0f=SH051@D02EUID0UIFE04a<C002
0?Cdm0050;>c/`0E5AD05ADE0=cLg01XJ6P00P2IVIT01@2KVi/0^KVi0;Vi^@1ZJVX0Ogmo0080UYJF
00@0Rh^;0:6QX@2QXJ40QXJ60P25QHD01@2/[:`0NWYj0:FUY@2UYJD0QXJ60080LG5a00D0WYjN08^;
R`2][Jd0[Jf]08V9R@0209RHV00508b<S023Ph<0Rh^;08^;R`2CTi<00P2/[:`01@1hN7P0NGUi07Ui
N@2XZ:P0SHf=0080WIfM00D0S8b<092@T02@T900Rh^;0::RXP0205aLG0040:j^[P2?Shl0Shn?09NG
U`80O7al00@0QXJ60;:b/P24Q8@0Q8B40`2BTY800`2NWYh0oooo0?ooo`080?ooo`040:RXZ02a/K40
/K6a0;Ng]`80_;bl00D0clo?0=3@d037alL0alO70;jn_P020<?3``050;:b/P2PX:00X:2P08j>SP28
R8P00P1`L70306=SH`0506IVIP1RHV80IVIV06IVIP1dM7@00P1eMGD01@1nOWh0Q8B408B4Q026QXH0
Q8B40080Rh^;00D0V9RH09fMW@2MWId0WinO09fMW@0208f=S@050861P@1iNGT0NGUi08^;R`2JVYX0
0P2d];@0102k^k/0b/[:0<[:bP3>c/h20<?3``050;Jf]P2`/;00YjNW0:NWY`2RXZ800P2PX:001@2]
[Jd0/;2`0<71`@31`L40_Kfm0080aLG500D0]KFe0;Vi^@2i^KT0Y:BT0::RXP030:^[Z`80X:2P00D0
Xj>S09JFUP21PH40PH6107]kN`0207EeM@0507=cL`1[Jf/0Jf][06YZJP1YJFT00P1fMWH01@1lO7`0
R8R808R8R02>SXh0Vi^K0080UiNG00@0V9RH0:>SX`2SXj<0ZJVY0`2WYjL0102/[:`0[Zj^0:j^[P2c
/k<30:b/[0040:6QX@2@T900T92@07UiN@80MgMg00D0GEeM06e]K@1lO7`0O7al0820P002075aL@05
08^;R`23Ph<0Ph>307IfMP1oOgl00P2=SHd01@2:RXX0PH610861P@24Q8@0R8R80080UIFE00D0U9BD
08^;R`2;Rh/0SXj>08f=S@0208^;R`040:JVYP2e]KD0]KFe0<;2`P80fMWI00D0hn?S0=WIf@3Shn<0
hn?S0=OGe`020<30`0050;Bd]02WYjL0Xj>S0:>SX`2`/;000P2TY:@01@2[Zj/0/k>c0;>c/`2YZJT0
U9BD0080Xj>S00@0WIfM09NGU`2GUiL0Ti>C3`3oool000d0oooo00@0O7al079bLP1bLW80aLG50P2:
RXX0101oOgl0Shn?08Z:RP2:RXX308^;R`050;6a/@1hN7P0N7Qh09RHV02<S8`00P2NWYh01@22PX80
Y:BT0:BTY01/K6`0[:b/0080Kfm_00@0XJ6Q0:f][@2][Jd0MWIf0P2TY:@01@2DU9@0KVi^08j>SP2>
SXh0_;bl0080F5QH00D0YjNW09:BTP20P800P8200;Vi^@0208Z:RP0506MWI`2ZZZX0Hf=S06=SH`2m
_Kd00P2d];@01@1bLW80OGem07emO@2?Shl0P8200080/;2`00D0WYjN05eMG@1MGEd0Z:RX07emO@02
0<G5a@0408J6QP1bLW80LW9b0:f][@80QHF500D0MWIf09ZJVP26QXH0QXJ60=3@d00204E5A@050:2P
X02KVi/0Xj>S0:>SX`27QhL00P1VIVH01@2GUiL0[Jf]0:f][@20P800/;2`0080M7Ad00D0WYjN07in
OP1nOWh0/[:b06e]K@0208F5Q@0509NGU`2=SHd0SHf=0=_Kf`1>CTh00P2EUID0101BDU80i^KV0>KV
iP2k^k/201@D50050>3Ph01TI6@0VYZJ09ZJVP2HV9P00P2n_[h01@1[Jf/0NGUi09FEU@2EUID0T92@
0080WYjN00D0RHV908B4Q024Q8@0[Zj^06m_K`020;bl_00307AdM01gMgL0MgMg0080UIFE0P2ZZZX0
1@27QhL0W9bL09bLW022PX80U9BD0080Q8B400@0Shn?0:f][@2][Jd0M7Ad0P28R8P01@2LW9`0TY:B
09bLW02LW9`0QhN70080TY:B00D0S8b<0:6QX@1NGUh0GUiN0:^[Z`02092@T00509VIV@1kNg/0Ng]k
08F5Q@2`/;000P27QhL309>CT`0309fMW@3oool0oooo00P0oooo00@0Ph>3079bLP1bLW80Jf][0`1b
LW80101fMWH0OWin07inOP28R8P20861P@050820P01oOgl0Ogmo08B4Q01iNGT00P29RHT01@2WYjL0
ZJVY0:VYZ@2SXj<0[Jf]0080YZJV00@0QhN70820P020P800RHV90P2?Shl01@2;Rh/0Shn?09VIV@2I
VIT0SHf=0080Rh^;00D0UYJF09^KV`2QXJ40XJ6Q0:>SX`0209bLW00508j>SP1fMWH0EeMG05MGE`1>
CTh00P0o?cl01@0Y:BT0<c<c03<c<`0o?cl0?Shn0080DE5A00D0JVYZ07AdM01dM7@0Ng]k09:BTP02
08b<S00408J6QP1oOgl0Ogmo07alO080J6QX00D0L71`07YjNP1oOgl0Ogmo08V9R@0209NGU`050:>S
X`2`/;00_;bl0;bl_03@d=000P3MgMd01@3Hf=P0f][J0=[JfP37alL0[jn_0080Vi^K00D0QXJ6079b
LP1bLW80MGEe06a/K00207AdM00507UiN@22PX80PX:20820P027QhL00P2:RXX0102>SXh0Ogmo07mo
O`1jNWX208>3P`0507inOP21PH40QhN708N7Q`2FUYH00P2ATI401@2:RXX0QHF507QhN01hN7P0OGem
0080SXj>00D0Y:BT0:n_[`2_[jl0`L710;Zj^P020;>c/`050;Rh^02j^[X0^[Zj0;no_`2g]kL00P2l
_;`01@2^[Zh0Xj>S0:>SX`2MWId0YJFU0080UYJF00@0R8R808b<S02<S8`0QHF50P1ZJVX01@1]KFd0
M7Ad06EUI@1UIFD0HV9R0080NWYj00D0LG5a079bLP1oOgl0Ogmo08R8R002096AT@0509:BTP2?Shl0
Shn?09VIV@2?Shl00P29RHT308^;R`0308>3P`3oool0oooo00d0oooo000=0?ooo`0407emO@1bLW80
LW9b0<[:bP80QXJ600D0Ogmo08j>SP2=SHd0SHf=08R8R00208^;R`050:f][@20P800P82009:BTP2>
SXh00P2KVi/01@1oOgl0[:b/0:b/[01]KFd0XZ:R0080MGEe00@0YJFU0:VYZ@2YZJT0NWYj0P2MWId0
1@2GUiL0JVYZ09>CT`2CTi<0^KVi0080GEeM00D0XJ6Q09>CT`20P800P8200;^k^`0208j>SP0506MW
I`2SXj<0K6a/06a/K02d];@00P2l_;`01@1XJ6P0R8R808R8R028R8P0QhN70080X:2P00D0ZJVY05mO
G`1OGel0YJFU07inOP020<G5a@0408J6QP1_Kfl0Kfm_0;6a/@80PH6100D0MgMg09bLW025QHD0QHF5
0=GEe@020410@00509nOW`2NWYh0X:2P0:2PX02:RXX00P1VIVH01@2BTY80[jn_0:n_[`20P800]KFe
0080KFe]00D0Y:BT07alO01lO7`0[Zj^075aL@0208N7Q`0508n?S`2ATI40TI6A0=oOg`1<C4`00P2D
U9@0101CDe<0g]kN0=kNgP34a<@2010@40050>KViP1OGel0W9bL09bLW02HV9P00P2l_;`01@1`L700
MgMg08n?S`2?Shl0W9bL0080Ti>C00D0Shn?07inOP1nOWh0][Jf065QH@020<g=c@0506UYJ@1jNWX0
NWYj09:BTP2LW9`00P2WYjL01@27QhL0X:2P0:2PX01gMgL0WYjN0080QHF500@0SHf=0:ZZZP2ZZZX0
LW9b0P2@T9001@2EUID0UiNG09VIV@2IVIT0Ph>30080UYJF00D0RXZ:0:BTY01PH600H61P0:^[Z`02
08n?S`0509fMW@1gMgL0MgMg08R8R02[Zj/00P2:RXX0102ATI40UYJF09JFUP2JVYX:0?ooo`040:b/
[02i^KT0^KVi0<;2`P80/K6a00D0YZJV09RHV02?Shl0Shn?08J6QP02096AT@0509bLW02d];@0];Bd
0=CDe03moOd00P3emOD01@3Ti>@0c<c<0<c<c02h^;P0Vi^K0080XJ6Q00@0^KVi0=;BdP3Bd]80bLW9
0P2h^;P01@2b/[80ZZZZ09bLW02LW9`0XZ:R0080[Jf]00D0YJFU09bLW02CTi<0Ti>C09:BTP0209BD
U0050:FUY@2k^k/0emOG0=OGe`3WinL00P3no_h30?ooo`050?clo03hn?P0hn?S0>?Sh`3=cLd00P2l
_;`01@2WYjL0P82007UiN@1iNGT0PX:20080Q8B400D0Shn?0:JVYP2VYZH0XZ:R09>CT`0208f=S@05
08^;R`2<S8`0S8b<08^;R`28R8P00P26QXH0101eMGD0IVIV06IVIP1OGel206EUI@0507]kN`2CTi<0
YZJV0:JVYP31`L400P3Cdm<01@3GemL0fm_K0=[JfP3Jf]X0gmoO0080c<c<00D0_;bl0;2`/02UYJD0
YJFU09BDU00209fMW@050:VYZ@2a/K40/K6a0;Jf]P2d];@00P2`/;001@2SXj<0WYjN09jNWP2OWil0
VYZJ0080Y:BT00@0Vi^K09BDU02DU9@0QHF50P28R8P01@1hN7P0QHF507emO@1mOGd0Ng]k00<0MgMg
00@0MWIf08J6QP26QXH0UYJF0P2PX:001@2SXj<0WIfM09BDU02DU9@0TY:B0080Ph>300D0Q8B409BD
U02DU9@0SHf=096AT@020:NWY`050;jn_P2a/K40/K6a0<C4a031`L400P2/[:`0102ATI40V9RH09RH
V02NWYh20:>SX`050:BTY02g]kL0Zj^[0:^[Z`2JVYX00P2RXZ800`2/[:`0oooo0?ooo`0=0?ooo`00
3@3oool0101lO7`0M7Ad07AdM03;bl/208>3P`050861P@2?Shl0S8b<08b<S026QXH00P2=SHd01@2/
[:`0PX:208:2PP2>SXh0UYJF0080U9BD00D0OWin0;6a/@2a/K40L71`09:BTP0208R8R00409nOW`2U
YJD0YJFU08B4Q080U9BD00D0VYZJ06UYJ@2CTi<0Ti>C0;bl_00205mOG`0509RHV02GUiL0PH610861
P@2m_Kd00P2=SHd01@1TI6@0XZ:R07AdM01dM7@0Z:RX0080alO700D0GemO09>CT`2CTi<0Ogmo096A
T@02092@T0050;2`/01WIfL0IfMW09jNWP23Ph<00P2m_Kd01028R8P0LW9b079bLP2^[Zh20861P@05
07UiN@2IVIT0RHV908V9R@3De=@00P0o?cl01@2PX:00W9bL0::RXP2RXZ80R8R80080IVIV00D0Ti>C
0:f][@2][Jd0Ogmo0;bl_00206EUI@050:ZZZP1hN7P0N7Qh0;2`/01bLW800P28R8P01@27QhL0VIVI
09VIV@3Ng]h0C4a<0080U9BD00@0D51@0=gMg@3MgMd0a/K60P0>3Ph01@3/k>`0FUYJ09ZJVP2JVYX0
W9bL0080^KVi00D0MGEe079bLP2;Rh/0Rh^;0:VYZ@0208f=S@0509:BTP1kNg/0Ng]k0;Vi^@1GEeL0
0P3IfMT01@1SHf<0NGUi07UiN@2DU9@0WYjN0080YjNW00D0PX:20:BTY02TY:@0Lg=c0:>SX`0208N7
Q`0408V9R@2[Zj/0Zj^[06i^KP80UIFE00D0UiNG09BDU02MWId0WIfM07inOP0209BDU00508j>SP2V
YZH0GEeM05eMG@2/[:`00P2>SXh01@2LW9`0NGUi07UiN@24Q8@0Zj^[0080S8b<00@0T92@09FEU@2E
UID0VYZJ2P3oool0102BTY80TI6A096AT@2=SHd209RHV00309jNWP2MWId0W9bL0080W9bL0P2@T900
1@23Ph<0L71`071`L01DE5@0@D510080C4a<00D0De=C07EeM@1eMGD0UiNG0;2`/0020:JVYP040:6Q
X@2<S8`0S8b<08J6QP80PX:200D0UYJF09>CT`2:RXX0RXZ:07QhN00206MWI`0505eMG@1VIVH0NWYj
07YjNP2;Rh/00P2CTi<01@2?Shl0RHV908B4Q024Q8@0OGem0080NWYj00D0N7Qh07alO01lO7`0NWYj
07EeM@0207UiN@050861P@27QhL0QhN709FEU@2_[jl00P2j^[X0102d];@0/[:b0;:b/P2][Jd20:6Q
X@0509ZJVP2RXZ80XJ6Q0:6QX@2OWil00P2JVYX01@2IVIT0UiNG08b<S02<S8`0SXj>0080Vi^K00D0
WinO0:>SX`2SXj<0Zj^[0:FUY@0209JFUP0508j>SP23Ph<0Ph>307MgM`1dM7@00P1bLW801@1PH600
GUiN05iNGP1VIVH0KFe]0080KVi^00@0NWYj0820P020P800NGUi0P1]KFd01@1cLg<0NWYj08B4Q024
Q8@0T92@0080WIfM0P2ZZZX209nOW`0409^KV`2MWId0WIfM09FEU@80UiNG00<0Ti>C09:BTP2CTi<0
0P2CTi<209FEU@0509^KV`2QXJ40UiNG09NGU`2<S8`00P2FUYH209fMW@80Zj^[00@0[jn_0:RXZ02X
Z:P0WIfM0P2GUiL209^KV`80P82000D0KFe]07=cL`1cLg<0IfMW06][J`02092@T0<0[jn_00D0/[:b
0;Fe]@2e]KD0[:b/0:NWY`020:VYZ@040;2`/02RXZ80XZ:R09RHV0l0oooo000=0?ooo`0407alO01d
M7@0M7Ad0<_;b`80Ph>300D0PH6108n?S`2<S8`0S8b<08J6QP0208f=S@050:b/[022PX80PX:208j>
SP2FUYH00P2DU9@01@1nOWh0/K6a0;6a/@1`L700TY:B0080R8R800@0WinO0:FUY@2UYJD0Q8B40P2D
U9@01@2JVYX0JFUY09>CT`2CTi<0_;bl0080GemO00D0V9RH09NGU`21PH40PH610;fm_@0208f=S@05
06ATI02RXZ80M7Ad07AdM02XZ:P00P37alL01@1OGel0Ti>C09>CT`1oOgl0TI6A0080T92@00D0/;2`
06MWI`1WIfL0WYjN08>3P`020;fm_@0408R8R01bLW80LW9b0:j^[P80PH6100D0NGUi09VIV@29RHT0
RHV90=CDe00203lo?`050:2PX02LW9`0XZ:R0::RXP28R8P00P1VIVH01@2CTi<0[Jf]0:f][@1oOgl0
_;bl0080IFEU00D0ZZZZ07QhN01hN7P0/;2`079bLP0208R8R00508N7Q`2IVIT0VIVI0=kNgP1<C4`0
0P2DU9@0101@D500gMgM0=gMg@36a/H200h>3P050>c/k01JFUX0VYZJ09ZJVP2LW9`00P2i^KT01@1e
MGD0LW9b08^;R`2;Rh/0ZJVY0080SHf=00D0TY:B07]kN`1kNg/0^KVi05MGE`020=WIf@0506=SH`1i
NGT0NGUi09BDU02NWYh00P2WYjL01@22PX80Y:BT0:BTY01cLg<0Xj>S0080QhN700@0RHV90:^[Z`2[
Zj/0KVi^0P2EUID01@2GUiL0U9BD09fMW@2MWId0OWin0080U9BD00D0SXj>0:JVYP1MGEd0GEeM0:b/
[00208j>SP0509bLW01iNGT0NGUi08B4Q02[Zj/00P2<S8`0102@T900UIFE09FEU@2JVYX:0?ooo`04
09:BTP2ATI40TI6A08f=S@80V9RH00<0WYjN09fMW@2LW9`00P2LW9`2092@T00508>3P`1`L700L71`
05ADE011@D400P1<C4`01@1CDe<0MGEe07EeM@2GUiL0/;2`0080YZJV00@0XJ6Q08b<S02<S8`0QXJ6
0P22PX801@2FUYH0Ti>C08Z:RP2:RXX0N7Qh0080IfMW00D0GEeM06IVIP1jNWX0NWYj08^;R`0209>C
T`0508n?S`29RHT0Q8B408B4Q01mOGd00P1jNWX01@1hN7P0O7al07alO01jNWX0MGEe0080NGUi00D0
PH6108N7Q`27QhL0UIFE0:n_[`020;Zj^P040;Bd]02b/[80/[:b0:f][@80XJ6Q00D0VYZJ0::RXP2Q
XJ40XJ6Q09nOW`0209ZJVP0509VIV@2GUiL0S8b<08b<S02>SXh00P2KVi/01@2OWil0Xj>S0:>SX`2[
Zj/0YJFU0080UYJF00D0SXj>08>3P`23Ph<0MgMg07AdM002079bLP05061PH01NGUh0GUiN06IVIP1]
KFd00P1^KVh0101jNWX0P8200820P01iNGT206e]K@0507=cL`1jNWX0Q8B408B4Q02@T9000P2MWId2
0:ZZZP80WinO00@0Vi^K09fMW@2MWId0UIFE0P2GUiL00`2CTi<0TY:B09>CT`0209>CT`80UIFE00D0
Vi^K0:6QX@2GUiL0UiNG08b<S00209JFUP80WIfM0P2[Zj/0102_[jl0Z:RX0:RXZ02MWId209NGU`80
Vi^K0P20P8001@1]KFd0Lg=c07=cL`1WIfL0Jf][0080T92@0`2_[jl01@2b/[80]KFe0;Fe]@2/[:`0
YjNW0080ZJVY00@0/;2`0::RXP2RXZ80V9RH3`3oool000d0oooo00@0N7Qh07IfMP1fMWH0clo?0P1l
O7`01@25QHD0SHf=08j>SP2>SXh0QhN70080S8b<00D0Zj^[08N7Q`27QhL0Ph>30:FUY@0208f=S@05
07emO@2`/;00/;2`071`L02?Shl00P2BTY80102EUID0X:2P0:2PX02CTi<208Z:RP0509bLW01WIfL0
UYJF09JFUP2n_[h00P1PH6001@2ATI40UiNG08>3P`23Ph<0_kno0080SXj>00D0Hf=S09ZJVP23Ph<0
Ph>309ZJVP020=CDe00505EEE@2JVYX0VYZJ07UiN@2HV9P00P26QXH01@2f][H0KFe]06e]K@2EUID0
Rh^;0080]KFe00@0Rh^;07UiN@1iNGT0Z:RX0P21PH401@1jNWX0UYJF08b<S02<S8`0e]KF0080?Shn
00D0XJ6Q09ZJVP2QXJ40XJ6Q08^;R`02069RHP0509NGU`2][Jd0[Jf]07]kN`33`l<00P1QHF401@2Z
ZZX0MgMg07MgM`2d];@0Kfm_0080S8b<00D0P8200:2PX02PX:00g]kN04E5A@0209ZJVP04051@D03K
fm/0fm_K0<W9b@8030`<00D0l?3`059BDP2NWYh0WYjN09^KV`020;Ng]`0507YjNP1/K6`0RXZ:08Z:
RP2`/;000`2<S8`207moO`050;Ng]`1FEUH0gmoO0=oOg`1NGUh00P1hN7P01@2CTi<0YJFU0:>SX`2S
Xj<0Ph>30080WIfM00D0N7Qh0:BTY026QXH0QXJ608V9R@020:VYZ@0506][J`2KVi/0Vi^K09FEU@2C
Ti<00P2NWYh01@1iNGT0VYZJ09ZJVP2;Rh/0XZ:R0080H61P00@0[Jf]092@T02@T900UiNG0P21PH40
1@25QHD0Y:BT08R8R028R8P0W9bL0080SHf=00<0WYjN0?ooo`3oool0203oool306m_K`05071`L01e
MGD0MGEe07alO025QHD00P2=SHd0102HV9P0YjNW0:NWY`2`/;020:j^[P050;>c/`2YZJT0X:2P0:2P
X02SXj<00P2=SHd01@1YJFT0K6a/079bLP1bLW80HV9R0080LW9b00D0Shn?09RHV02HV9P0TY:B0:6Q
X@020;bl_0050=;BdP3De=@0e=CD0=;BdP2n_[h00P2KVi/00`1mOGd0LW9b079bLP02071`L080Jf][
00@0Kfm_06UYJ@1YJFT0J6QX0P1`L7000`20P800Ph>308b<S00408b<S00508>3P`20P800O7al07al
O01mOGd00P1gMgL00`23Ph<0QXJ608J6QP0208b<S080Shn?00D0QHF508:2PP22PX80OGem0820P002
08b<S004096AT@22PX80PX:208:2PP80MWIf00D0Jf][06a/K01nOWh0OWin08>3P`0209:BTP0509^K
V`2OWil0XJ6Q0:6QX@2/[:`00P2g]kL01@31`L40_;bl0<;2`P32`/80`<300080][Jf00D0YjNW0:b/
[02/[:`0WinO09^KV`0208Z:RP0507MgM`1YJFT0JFUY06e]K@1XJ6P00P1bLW80102?Shl0UiNG09NG
U`2HV9P209^KV`050:VYZ@2JVYX0VYZJ09ZJVP2HV9P00P2DU9@01@2>SXh0UIFE092@T02@T900WinO
0080TI6A00D0QhN708Z:RP2EUID0UIFE096AT@020:BTY0050:n_[`2QXJ40XJ6Q08Z:RP1]KFd00P1^
KVh01@1UIFD0F5QH05QHF01KFe/0IfMW0080Cdm?00@0AdM704i>CP1>CTh0F5QH0P1PH6001@1iNGT0
RHV9096AT@2ATI40SHf=0080PX:200<0MWIf0?ooo`3oool03@3oool000d0oooo00@0L71`07alO01l
O7`0d];B0P1fMWH01@27QhL0SHf=08b<S02<S8`0RHV90080S8b<00D0[:b/08J6QP26QXH0Q8B40::R
XP0208j>SP0507moO`2d];@0];Bd06YZJP2?Shl00P2JVYX0102?Shl0V9RH09RHV02QXJ4208>3P`05
0:2PX01SHf<0V9RH09RHV02j^[X00P1VIVH01@2<S8`0UYJF08V9R@29RHT0_Kfm0080S8b<00D0Hf=S
09FEU@2?Shl0Shn?08f=S@020=oOg`0504e=C@2PX:00X:2P07=cL`2LW9`00P22PX801@2b/[80MgMg
07MgM`2@T900TY:B0080ZZZZ00@0SXj>07emO@1mOGd0WinO0P2:RXX01@1hN7P0U9BD08j>SP2>SXh0
eMGE0080?Shn00D0X:2P09bLW02OWil0WinO08n?S`0205aLG00509jNWP2/[:`0[:b/07QhN034a<@0
0P1RHV801@2YZJT0MGEe07EeM@2g]kL0L71`0080SXj>00D0N7Qh0:JVYP2VYZH0fm_K04E5A@0209jN
WP0404U9B@3Ph>00h>3P0<K6aP803Ph>00D0kno_059BDP2RXZ80XZ:R09JFUP020;Rh^00507YjNP1Z
JVX0SHf=08f=S@2c/k<00`29RHT208:2PP050;Ng]`1@D500i^KV0>KViP1JFUX00P1lO7`01@2=SHd0
[:b/0::RXP2RXZ80PX:20080TY:B00D0R8R809bLW029RHT0RHV908^;R`020:JVYP0506QXJ02QXJ40
XJ6Q09>CT`2BTY800P2PX:001@1gMgL0UiNG09NGU`2;Rh/0Z:RX0080Fe]K00@0/;2`09>CT`2CTi<0
T92@0P29RHT01@23Ph<0XJ6Q08N7Q`27QhL0Xj>S0080PX:200<0Z:RX0?ooo`3oool0203oool0102/
[:`0[jn_0:n_[`2[Zj/20:b/[0050:>SX`2UYJD0XZ:R0::RXP2PX:000P2ATI401@24Q8@0SHf=08f=
S@27QhL0Rh^;0080T92@00D0TY:B09>CT`2CTi<0`<300;Bd]0020:f][@040;fm_@2h^;P0^;Rh08f=
S@80TI6A00<0RXZ:0861P@1fMWH00P1fMWH207UiN@0509>CT`2e]KD0d=3@0=3@d03Kfm/00P3QhN40
1@3Lg=`0a<C40;Bd]02d];@0[:b/0080ZJVY00D0Zj^[0:6QX@2QXJ40X:2P0:JVYP020:>SX`050:2P
X02^[Zh0[Zj^0;Fe]@2/[:`00P2`/;00102XZ:P0X:2P0:2PX02CTi<209BDU00508j>SP2<S8`0Shn?
08n?S`2JVYX00P2SXj<01@2][Jd0/k>c0:j^[P2^[Zh0[Jf]0080_[jn00D0_;bl0;fm_@2m_Kd0`l?3
0;no_`020:ZZZP050:>SX`2IVIT0VIVI08b<S026QXH00P2:RXX308B4Q00508R8R02;Rh/0Shn?08n?
S`2EUID00P2QXJ401@2^[Zh0[jn_0:n_[`2ZZZX0[:b/0080^;Rh00D0alO70<k>cP3>c/h0`l?30<C4
a0020<71`@040:JVYP2LW9`0W9bL09nOW`80VYZJ00D0QHF508n?S`2?Shl0Shn?09NGU`0209ZJVP05
0:FUY@2OWil0UiNG09NGU`2BTY800P2@T9001@27QhL0Lg=c079bLP1bLW80L71`0080F5QH00D0HV9R
08F5Q@25QHD0Y:BT0<c<c0020?7al@050?clo03oool0oooo0?ooo`3bl_800P3clo<0103Ogml0_[jn
0;jn_P2KVi/208:2PP0505aLG01ADE40De=C05=CD`1/K6`00P26QXH00`2SXj<0oooo0?ooo`0=0?oo
o`003@3oool0101`L700O7al07alO03Bd]8207IfMP0508N7Q`2=SHd0S8b<08b<S029RHT00P2<S8`0
1@2/[:`0QXJ608J6QP24Q8@0XZ:R0080SXj>00D0Ogmo0;Bd]02d];@0JVYZ08n?S`0209ZJVP0408n?
S`2HV9P0V9RH0:6QX@80Ph>300D0X:2P06=SH`2HV9P0V9RH0;Zj^P0206IVIP0508b<S02FUYH0RHV9
08V9R@2m_Kd00P2<S8`01@1SHf<0UIFE08n?S`2?Shl0SHf=0080gmoO00D0CDe=0:2PX02PX:00Lg=c
09bLW00208:2PP050;:b/P1gMgL0MgMg092@T02BTY800P2ZZZX0102>SXh0OGem07emO@2OWil208Z:
RP0507QhN02DU9@0SXj>08j>SP3EeMD00P0n?Sh01@2PX:00W9bL09nOW`2OWil0Shn?0080G5aL00D0
WYjN0:b/[02/[:`0N7Qh0<C4a002069RHP050:VYZ@1eMGD0MGEe0;Ng]`1`L7000P2>SXh01@1hN7P0
YZJV0:JVYP3Kfm/0ADE50080WYjN00@0BDU90>3Ph03Ph>00a/K60P0>3Ph01@3_knl0DU9B0::RXP2R
XZ80UYJF0080^;Rh00D0NWYj06YZJP2=SHd0SHf=0;>c/`0308V9R@80PX:200D0]kNg051@D03Vi^H0
i^KV05YJFP0207alO00508f=S@2/[:`0XZ:R0::RXP22PX800P2BTY801@28R8P0W9bL08V9R@29RHT0
Rh^;0080YZJV00D0J6QX0:6QX@2QXJ40Ti>C09:BTP020:2PX00507MgM`2GUiL0UiNG08^;R`2XZ:P0
0P1KFe/0102`/;00Ti>C09>CT`2@T90208V9R@0508>3P`2QXJ40QhN708N7Q`2SXj<00P22PX800`2X
Z:P0oooo0?ooo`080?ooo`040:b/[02_[jl0[jn_0:^[Z`80[:b/00D0Xj>S0:FUY@2RXZ80XZ:R0:2P
X002096AT@0508B4Q02=SHd0SHf=08N7Q`2;Rh/00P2@T9001@2BTY80Ti>C09>CT`30`<00];Bd0080
[Jf]00@0_Kfm0;Rh^02h^;P0SHf=0P2ATI400`2:RXX0PH6107IfMP0207IfMP80NGUi00D0Ti>C0;Fe
]@3@d=00d=3@0=_Kf`020>7Qh@050=cLg034a<@0];Bd0;Bd]02/[:`00P2YZJT01@2[Zj/0XJ6Q0:6Q
X@2PX:00YZJV0080Xj>S00D0X:2P0:j^[P2^[Zh0]KFe0:b/[0020;2`/0040:RXZ02PX:00X:2P09>C
T`80U9BD00D0SXj>08b<S02?Shl0Shn?09ZJVP020:>SX`050:f][@2c/k<0[Zj^0:j^[P2][Jd00P2n
_[h01@2l_;`0_Kfm0;fm_@33`l<0_kno0080ZZZZ00D0Xj>S09VIV@2IVIT0S8b<08J6QP0208Z:RP<0
Q8B400D0R8R808^;R`2?Shl0Shn?09FEU@020:6QX@050:j^[P2_[jl0[jn_0:ZZZP2/[:`00P2h^;P0
1@37alL0c/k>0<k>cP33`l<0a<C40080`L7100@0YZJV09bLW02LW9`0WinO0P2JVYX01@25QHD0Shn?
08n?S`2?Shl0UiNG0080VYZJ00D0YJFU09nOW`2GUiL0UiNG09:BTP02092@T00508N7Q`1cLg<0LW9b
079bLP1`L7000P1HF5P01@1RHV80QHF508F5Q@2TY:@0c<c<0080lO7a00D0o?cl0?ooo`3oool0oooo
0?;blP020??cl`040=oOg`2n_[h0_[jn09^KV`80PX:200D0G5aL055AD@1CDe<0De=C06a/K00208J6
QP030:>SX`3oool0oooo00d0oooo000=0?ooo`0406MWI`23Ph<0Ph>30=CDe080LG5a00@0RHV908j>
SP2:RXX0RXZ:0`2;Rh/01@2_[jl0Q8B408B4Q024Q8@0X:2P0080SHf=00D0PH610;Vi^@2i^KT0IFEU
08V9R@020:FUY@0408V9R@2EUID0UIFE0:NWY`80OWin00D0YZJV061PH02IVIT0VIVI0;Vi^@0206][
J`0508N7Q`2@T900TY:B09:BTP2m_Kd00P2;Rh/01@1QHF40TI6A09ZJVP2JVYX0PH610080j>SX00D0
B4Q80:>SX`2SXj<0Lg=c09VIV@0208J6QP050:^[Z`20P800P82008^;R`2IVIT00P2MWId0102ATI40
Ph>308>3P`2LW9`208b<S00507QhN02@T900Shn?08n?S`3GemL00P0o?cl01@2LW9`0WinO09fMW@2M
WId0TI6A0080G5aL00D0W9bL0:f][@2][Jd0MWIf0<?3``0206IVIP050:NWY`1dM7@0M7Ad0;Rh^01_
Kfl00P2?Shl01@1eMGD0[:b/0:b/[03De=@0BTY:0080WYjN00@0@D510>c/k03/k>`0_;bl0P0C4a<0
1@3_knl0CTi>0:VYZ@2YZJT0Ti>C0080/k>c00D0PH6106ATI02@T900T92@0;Fe]@0208V9R@0508J6
QP22PX80PX:20;Fe]@1CDe<00P3[jn/01@1@D500Q8B408B4Q027QhL0/k>c0080XJ6Q00@0P82008Z:
RP2:RXX0UiNG0`2@T900102;Rh/0Xj>S0:>SX`1XJ6P20:BTY080TI6A0P2PX:001@1jNWX0UIFE09FE
U@26QXH0[:b/0080Fe]K00@0/K6a09:BTP2BTY80Rh^;0P2CTi<01@1oOgl0X:2P08J6QP26QXH0YZJV
0080O7al00<0[jn_0?ooo`3oool0203oool0102ZZZX0Xj>S0:>SX`2RXZ8209VIV@0509RHV02CTi<0
TI6A096AT@27QhL00P2CTi<01@2FUYH0Rh^;08^;R`2GUiL0Y:BT0080[jn_00D0^;Rh0=_Kf`3Kfm/0
c/k>0=3@d0020<S8b0040;no_`2QXJ40XJ6Q0:NWY`80WYjN0P2OWil209fMW@0509JFUP2JVYX0VYZJ
08f=S@1cLg<00P1ZJVX01@1aLG40IfMW06MWI`1`L700SXj>0080ZJVY00@0][Jf0<30`030`<00_;bl
0P2g]kL01@2YZJT0Vi^K09^KV`2KVi/0VIVI0080T92@00D0RXZ:08f=S@27QhL0QhN709:BTP020:VY
Z@050;:b/P2`/;00/;2`0;>c/`2a/K400P2UYJD01@2KVi/0Shn?08n?S`20P800NGUi0080Lg=c00@0
LW9b075aL@1aLG40Ogmo0P26QXH208N7Q`80SHf=00D0R8R808>3P`23Ph<0QXJ608n?S`0209>CT`05
09^KV`2EUID0UIFE07]kN`1_Kfl00P1PH600101EEED0EeMG05MGE`1]KFd207YjNP0509FEU@2IVIT0
VYZJ09ZJVP2MWId00P2PX:00102HV9P0WinO09bLW02LW9`309VIV@0509>CT`2@T900T92@09VIV@2G
UiL00P2LW9`01@2OWil0XZ:R0::RXP2OWil0/;2`0080]KFe00D0^k^k0<;2`P32`/80cLg=0=SHf002
0<o?c`040=3@d03Xj>P0j>SX0=[JfP80];Bd00@0Y:BT08J6QP1XJ6P0J6QX0`1_Kfl01@1ZJVX0MgMg
06e]K@1]KFd0JFUY0080NWYj00D0X:2P0<71`@31`L40c<c<0<k>cP020=GEe@040;jn_P2XZ:P0Z:RX
0:>SX`l0oooo000=0?ooo`04069RHP24Q8@0Q8B40=GEe@80KVi^00D0Rh^;092@T022PX80PX:2096A
T@0208V9R@050;>c/`1nOWh0OWin08N7Q`2NWYh00P2<S8`01@24Q8@0^[Zj0;Zj^P1RHV80RXZ:0080
[:b/00@0OGem09JFUP2FUYH0[Jf]0P1iNGT01@2ZZZX0GUiN09^KV`2KVi/0]KFe0080LG5a00D0Q8B4
08n?S`2FUYH0UYJF0;bl_00208Z:RP0505eMG@2?Shl0XZ:R0::RXP1lO7`00P3]kNd01@13@d<0Z:RX
0:RXZ01bLW80Ti>C0080Shn?00D0Y:BT08F5Q@25QHD0RXZ:0:6QX@02096AT@0409>CT`27QhL0QhN7
09bLW080S8b<00D0NGUi08f=S@2BTY80TY:B0=CDe00204=3@`0509ZJVP2LW9`0WYjN09jNWP2@T900
0P1MGEd01@2MWId0[Jf]0:f][@1dM7@0`/;20080JVYZ00D0Y:BT07AdM01dM7@0][Jf075aL@0208j>
SP0507MgM`2a/K40/K6a0<S8b01EEED00P2OWil0100i>CT0n_[j0?[jnP2_[jl201LG5`050>g]k@1>
CTh0[jn_0:n_[`2?Shl00P2d];@01@24Q8@0GEeM09JFUP2FUYH0/[:b0080Shn?00D0Ng]k08f=S@2=
SHd0Zj^[05iNGP020>OWi`0504e=C@28R8P0R8R808:2PP2g]kL00P2QXJ401@1mOGd0QHF508F5Q@2Q
XJ40RHV90080U9BD00@0R8R80:>SX`2SXj<0JVYZ0P2TY:@01@2DU9@0Rh^;0:BTY02TY:@0Ogmo0080
SXj>00D0R8R80:f][@1IFET0FEUI0;2`/00209NGU`0508:2PP2JVYX0VYZJ07moO`2OWil00P26QXH0
102YZJT0MGEe07EeM@2e]KD:0?ooo`0407IfMP23Ph<0Ph>308V9R@80TI6A0P2EUID209BDU0040:6Q
X@2GUiL0UiNG0;no_`80c<c<00D0a/K60;Bd]02VYZH0YZJV079bLP0204a<C080?Cdm0P1=CDd0101B
DU80L71`071`L025QHD208j>SP0509NGU`2JVYX0VYZJ09ZJVP2KVi/00P2JVYX01@2MWId0];Bd0<30
`030`<00_kno0080bl_;00D0^k^k0:JVYP2<S8`0S8b<07inOP02071`L00506i^KP1WIfL0IfMW07Mg
M`1lO7`00P1ZJVX01@1[Jf/0LG5a075aL@1]KFd0KVi^0080NWYj00@0KFe]05iNGP1NGUh0EUIF0P1M
GEd01@1XJ6P0N7Qh08V9R@29RHT0TI6A0080VIVI00D0W9bL09fMW@2TY:@0Y:BT0:ZZZP020:RXZ005
0:BTY02MWId0WIfM09JFUP2GUiL00P2KVi/00`2GUiL0YJFU0:FUY@020;Fe]@80/K6a00D0/k>c0;Vi
^@2i^KT0bl_;0=?Cd`020=kNgP040>?Sh`3Fe]H0e]KF0:VYZ@80V9RH00<0Q8B407alO01eMGD0101e
MGD01@22PX80Shn?09FEU@2EUID0YZJV0080[:b/00@0/[:b0:ZZZP2ZZZX0ZJVY0`2/[:`01@2QXJ40
VIVI09VIV@2ATI40NGUi0080K6a/00D0IVIV069RHP1RHV80HF5Q06i^KP0207EeM@0407IfMP1_Kfl0
Kfm_07IfMP<0R8R800@0XZ:R0:FUY@2UYJD0Ti>C0P28R8P01@2=SHd0OGem08^;R`2;Rh/0ZJVY0080
]kNg00D0YZJV096AT@2ATI40Xj>S0:6QX@0208B4Q00408N7Q`2GUiL0UiNG08B4Q0l0oooo000=0?oo
o`04069RHP25QHD0QHF50=OGe`80Jf][00D0SHf=09:BTP1mOGd0OGem09BDU00208N7Q`050;Rh^01i
NGT0NGUi08b<S02FUYH00P2CTi<01@1oOgl0_kno0;no_`1NGUh0T92@0080Z:RX00@0Ng]k09NGU`2G
UiL0/;2`0P1hN7P01@2ZZZX0GEeM09nOW`2OWil0[Jf]0080MWIf00D0PX:2092@T02HV9P0V9RH0;Vi
^@0208^;R`0505iNGP2:RXX0Zj^[0:^[Z`1eMGD00P3^k^h01@12@T80ZZZZ0:ZZZP1aLG40Shn?0080
UIFE00D0WinO08R8R028R8P0R8R80:FUY@0208J6QP0409bLW023Ph<0Ph>309nOW`80Rh^;00D0N7Qh
08f=S@2BTY80TY:B0=GEe@020492@P0509VIV@2MWId0WinO09nOW`2BTY800P1OGel01@2IVIT0/K6a
0;6a/@1bLW80`/;20080JVYZ00D0Y:BT07IfMP1fMWH0/k>c07IfMP0208^;R`0507IfMP2g]kL0]kNg
0;^k^`1NGUh00P2NWYh0100c<c<0oooo0?ooo`2SXj<201`L70050>_[j`1@D500/;2`0;2`/02:RXX0
0P2g]kL01@25QHD0FUYJ09bLW02LW9`0[Jf]0080TI6A00D0MgMg09JFUP2FUYH0WYjN06][J`020>3P
h00504];B`2<S8`0S8b<0820P02g]kL00P2QXJ401@1oOgl0PX:208:2PP2VYZH0QXJ60080U9BD00@0
Rh^;09bLW02LW9`0Lg=c0P2TY:@01@2<S8`0TI6A0:6QX@2QXJ40PX:20080RXZ:00D0Rh^;0:b/[01L
G5`0G5aL0:^[Z`0209bLW00507]kN`2RXZ80XZ:R07inOP2JVYX00P28R8P0102ZZZX0Lg=c07=cL`2e
]KD:0?ooo`040:ZZZP2NWYh0WYjN09RHV080Ti>C00D0TI6A09:BTP2CTi<0Ti>C09:BTP0209JFUP03
071`L01UIFD0IFEU0080GemO0P1MGEd01@26QXH0Shn?08n?S`2HV9P0WYjN0080Y:BT00@0Xj>S09nO
W`2OWil0Vi^K0P2FUYH00`2ATI40T92@09BDU00209BDU080SXj>00D0Ng]k06IVIP1NGUh0GUiN05UI
F@0205YJFP0506YZJP1jNWX0QXJ608J6QP2<S8`00P2=SHd309>CT`0508V9R@2CTi<0[Jf]0:f][@2g
]kL00P31`L401@3AdM40cLg=0;Zj^P2j^[X0a/K60080bl_;00D0dM7A0=GEe@3EeMD0clo?0;Ng]`02
0:VYZ@0509fMW@2CTi<0Ti>C09jNWP2KVi/00P2PX:0309^KV`0509>CT`2LW9`0W9bL09VIV@2LW9`0
0P2OWil01@2/[:`0YZJV0:JVYP2=SHd0Ph>30080NWYj00<0H61P05IFEP1FEUH00P1JFUX205eMG@04
06YZJP1fMWH0MWIf09RHV080X:2P00@0XJ6Q0:^[Z`2[Zj/0Zj^[0`2TY:@01@2QXJ40OWin07EeM@1e
MGD0IVIV0080HF5Q00D0DE5A06a/K01/K6`0MWIf07=cL`0206i^KP050861P@23Ph<0Ph>307moO`23
Ph<00P2FUYH01@2;Rh/0QXJ608J6QP1oOgl0KFe]00<0EUIF0P1HF5P01@1BDU80F5QH05QHF01MGEd0
EeMG0080GUiN00D0MWIf08Z:RP2:RXX0YJFU0<?3``020<;2`P040:n_[`2RXZ80XZ:R096AT@80S8b<
00D0QXJ608F5Q@2IVIT0VIVI0::RXP0209^KV`030:2PX03oool0oooo00d0oooo000=0?ooo`04069R
HP25QHD0QHF50=OGe`80Jf][00D0SHf=09:BTP1mOGd0OGem09BDU00208N7Q`050;Rh^01iNGT0NGUi
08b<S02FUYH00P2CTi<01@1oOgl0_kno0;no_`1NGUh0T92@0080Z:RX00@0Ng]k09NGU`2GUiL0/;2`
0P1hN7P01@2ZZZX0GEeM09nOW`2OWil0[Jf]0080MWIf00D0PX:2092@T02HV9P0V9RH0;Vi^@0208^;
R`0505iNGP2:RXX0Zj^[0:^[Z`1eMGD00P3^k^h01@12@T80ZZZZ0:ZZZP1aLG40Shn?0080UIFE00D0
WinO08R8R028R8P0R8R80:FUY@0208J6QP0409bLW023Ph<0Ph>309nOW`80Rh^;00D0N7Qh08f=S@2B
TY80TY:B0=GEe@020492@P0509VIV@2MWId0WinO09nOW`2BTY800P1OGel01@2IVIT0/K6a0;6a/@1b
LW80`/;20080JVYZ00D0Y:BT07IfMP1fMWH0/k>c07IfMP0208^;R`0507IfMP2g]kL0]kNg0;^k^`1N
GUh00P2NWYh0100c<c<0oooo0?ooo`2SXj<201`L70050>_[j`1@D500/;2`0;2`/02:RXX00P2g]kL0
1@25QHD0FUYJ09bLW02LW9`0[Jf]0080TI6A00D0MgMg09JFUP2FUYH0WYjN06][J`020>3Ph00504];
B`2<S8`0S8b<0820P02g]kL00P2QXJ401@1oOgl0PX:208:2PP2VYZH0QXJ60080U9BD00@0Rh^;09bL
W02LW9`0Lg=c0P2TY:@01@2<S8`0TI6A0:6QX@2QXJ40PX:20080RXZ:00D0Rh^;0:b/[01LG5`0G5aL
0:^[Z`0209bLW00507]kN`2RXZ80XZ:R07inOP2JVYX00P28R8P0102ZZZX0Lg=c07=cL`2e]KD:0?oo
o`040:ZZZP2NWYh0WYjN09RHV080Ti>C00D0TI6A09:BTP2CTi<0Ti>C09:BTP0209JFUP03071`L01U
IFD0IFEU0080GemO0P1MGEd01@26QXH0Shn?08n?S`2HV9P0WYjN0080Y:BT00@0Xj>S09nOW`2OWil0
Vi^K0P2FUYH00`2ATI40T92@09BDU00209BDU080SXj>00D0Ng]k06IVIP1NGUh0GUiN05UIF@0205YJ
FP0506YZJP1jNWX0QXJ608J6QP2<S8`00P2=SHd309>CT`0508V9R@2CTi<0[Jf]0:f][@2g]kL00P31
`L401@3AdM40cLg=0;Zj^P2j^[X0a/K60080bl_;00D0dM7A0=GEe@3EeMD0clo?0;Ng]`020:VYZ@05
09fMW@2CTi<0Ti>C09jNWP2KVi/00P2PX:0309^KV`0509>CT`2LW9`0W9bL09VIV@2LW9`00P2OWil0
1@2/[:`0YZJV0:JVYP2=SHd0Ph>30080NWYj00<0H61P05IFEP1FEUH00P1JFUX205eMG@0406YZJP1f
MWH0MWIf09RHV080X:2P00@0XJ6Q0:^[Z`2[Zj/0Zj^[0`2TY:@01@2QXJ40OWin07EeM@1eMGD0IVIV
0080HF5Q00D0DE5A06a/K01/K6`0MWIf07=cL`0206i^KP050861P@23Ph<0Ph>307moO`23Ph<00P2F
UYH01@2;Rh/0QXJ608J6QP1oOgl0KFe]00<0EUIF0P1HF5P01@1BDU80F5QH05QHF01MGEd0EeMG0080
GUiN00D0MWIf08Z:RP2:RXX0YJFU0<?3``020<;2`P040:n_[`2RXZ80XZ:R096AT@80S8b<00D0QXJ6
08F5Q@2IVIT0VIVI0::RXP0209^KV`030:2PX03oool0oooo00d0oooo000=0?ooo`0406EUI@24Q8@0
Q8B40=SHf080JVYZ00D0SHf=09NGU`1fMWH0MWIf09FEU@0208V9R@050;fm_@1_Kfl0Kfm_09NGU`2;
Rh/00P2GUiL01@1oOgl0_kno0;no_`1PH600Rh^;0080[Zj^00@0NWYj09FEU@2EUID0[jn_0P1hN7P0
1@2YZJT0GemO0::RXP2RXZ80Y:BT0080NWYj00D0P82009:BTP2KVi/0Vi^K0;Zj^P0208R8R00505eM
G@28R8P0[jn_0:n_[`1dM7@00P3Xj>P01@17AdL0[jn_0:n_[`1]KFd0RHV90080WIfM00D0Vi^K08b<
S02<S8`0R8R80:NWY`0207UiN@040:JVYP22PX80PX:209nOW`80RHV900D0OWin08V9R@2ATI40TI6A
0=GEe@020492@P0509VIV@2MWId0W9bL09bLW02CTi<00P1RHV801@2CTi<0/k>c0;>c/`1bLW80`/;2
0080Jf][00D0YJFU07EeM@1eMGD0[Zj^07emO@0208F5Q@0507]kN`2i^KT0^KVi0:f][@1^KVh00P2K
Vi/0100/;2`0oooo0?ooo`2CTi<202@T90050>KViP1HF5P0[:b/0:b/[029RHT00P2i^KT01@22PX80
Fe]K09nOW`2OWil0[Zj^0080Rh^;00D0NWYj09ZJVP2JVYX0TY:B07QhN0020=SHf00504Y:BP2ATI40
TI6A08B4Q02_[jl00P2UYJD01@1mOGd0Q8B408B4Q02VYZH0QhN70080Shn?00@0SXj>09VIV@2IVIT0
NGUi0P2PX:001@2>SXh0Ti>C09ZJVP2JVYX0S8b<0080Ogmo00D0TI6A0:^[Z`1OGel0GemO0:JVYP02
09bLW00507YjNP2VYZH0YZJV07emO@2FUYH00P2ATI40102TY:@0LW9b079bLP2f][H:0?ooo`040820
P023Ph<0Ph>308V9R@<0R8R800@0S8b<092@T02@T900TY:B0P2?Shl01@2GUiL0UYJF09JFUP2NWYh0
Y:BT00<0YjNW0P2[Zj/0102KVi/0Ti>C08f=S@2=SHd308N7Q`0508R8R02:RXX0RXZ:08n?S`2>SXh0
0P2:RXX00`28R8P0TY:B09:BTP0209fMW@80Vi^K00D0X:2P09>CT`2CTi<0PH6108>3P`0308B4Q080
Rh^;00<0UIFE0:6QX@2QXJ400P2ZZZX209fMW@0508^;R`1bLW80LW9b065QH@1VIVH00P1bLW80101i
NGT0N7Qh07QhN01jNWX206a/K005075aL@1gMgL0Q8B408B4Q02GUiL00P2OWil01@2GUiL0Vi^K09BD
U02DU9@0SHf=0080Q8B400D0Ph>308:2PP22PX80S8b<08N7Q`0208j>SP0508^;R`2:RXX0RXZ:08n?
S`2CTi<00P2HV9P01@2SXj<0YjNW0:NWY`2_[jl0];Bd0080^;Rh00@0_;bl0;^k^`2k^k/0XZ:R0P2N
WYh01@2FUYH0QXJ608J6QP26QXH0Rh^;0080QhN700D0VIVI0:^[Z`2`/;00/;2`0;>c/`020;bl_005
0;Rh^02i^KT0^KVi0;:b/P2o_kl00P2h^;P00`2c/k<0ZZZZ0:ZZZP020;:b/P80]kNg00D0a/K60=WI
f@3IfMT0jNWY0?KfmP020?ooo`040?gmo@3YjNT0jNWY0>;RhP80cLg=00D0_kno0:f][@2RXZ80XZ:R
09>CT`0208j>SP0507emO@1_Kfl0Ng]k07]kN`27QhL00P23Ph<01@2DU9@0XZ:R0::RXP2OWil0WIfM
0080WinO00@0TY:B09>CT`2CTi<0T92@3`3oool000d0oooo00@0J6QX08>3P`23Ph<0emOG0P1YJFT0
1@2?Shl0UiNG075aL@1aLG40VYZJ0080RHV900D0_[jn06YZJP1ZJVX0VYZJ08b<S00209FEU@0508:2
PP2j^[X0^[Zj06=SH`27QhL00P2b/[80101nOWh0T92@092@T02][Jd207]kN`050:ZZZP1PH600YJFU
0:FUY@2NWYh00P1lO7`01@1oOgl0UIFE09VIV@2IVIT0_Kfm0080QhN700D0G5aL08>3P`2g]kL0]kNg
075aL@020>CTi00504a<C02_[jl0[jn_06m_K`21PH400P2QXJ401@2OWil0SHf=08f=S@23Ph<0Zj^[
0080Kfm_00@0/;2`0820P020P800XZ:R0P24Q8@01@21PH40R8R808j>SP2>SXh0e]KF0080AdM700D0
VIVI09bLW02IVIT0VIVI09FEU@02069RHP0509JFUP2a/K40/K6a07AdM033`l<00P1WIfL01@2WYjL0
MGEe07EeM@2][Jd0OGem0080PX:200D0PH610;bl_02l_;`0XJ6Q07UiN@0209RHV00402XZ:P3oool0
oooo08J6QP80:RXZ00D0hn?S05eMG@2XZ:P0Z:RX08^;R`020;Vi^@050861P@1KFe/0XJ6Q0:6QX@2`
/;000P27QhL01@1lO7`0W9bL09bLW02;Rh/0RHV90080a/K600D0Bd];09BDU02DU9@0SXj>0:>SX`02
0:VYZ@0507]kN`29RHT0RHV90::RXP2<S8`00P29RHT0102>SXh0UiNG09NGU`22PX8209^KV`0508n?
S`2BTY80V9RH09RHV02>SXh00P1iNGT01@2LW9`0YJFU06=SH`1SHf<0X:2P0080WYjN00D0Ng]k09jN
WP2NWYh0QXJ609VIV@0208n?S`0409jNWP1jNWX0NWYj0:n_[`X0oooo00@0][Jf0:n_[`2_[jl0[:b/
0P2_[jl20;>c/`80[jn_0`2[Zj/01@2VYZH0[Zj^0:j^[P2h^;P0^k^k0080_Kfm00D0[jn_0;2`/02`
/;00][Jf0;:b/P020:j^[P040;^k^`2h^;P0^;Rh0:j^[P80];Bd00D0ZZZZ0:NWY`2IVIT0VIVI09:B
TP0208N7Q`0508j>SP2FUYH0TY:B09:BTP2DU9@00P2OWil0102b/[80[:b/0:n_[`2_[jl30;Bd]005
0:BTY02OWil0WinO09jNWP2MWId00P2UYJD01@2h^;P0a<C40<C4a03:b/X0a/K60080`<3000@0Zj^[
0:VYZ@2YZJT0Z:RX0P2^[Zh01@2SXj<0[Zj^0::RXP2RXZ80Ti>C0080Rh^;00D0SHf=08N7Q`2>SXh0
SXj>09NGU`020:NWY`050:j^[P2/[:`0[:b/0::RXP2VYZH00P2FUYH01@2BTY80Ti>C09>CT`2RXZ80
Z:RX0080/k>c00D0`L710<;2`P32`/80[Zj^09jNWP0208Z:RP04071`L01YJFT0JFUY07YjNP80RHV9
00D0Ti>C09jNWP2SXj<0Xj>S09^KV`0209>CT`0508F5Q@2=SHd0R8R808R8R02@T9000P2=SHd0102L
W9`0S8b<08b<S029RHT307alO00507moO`27QhL0QhN708R8R02;Rh/00P23Ph<01@1kNg/0MWIf07If
MP1^KVh0K6a/0080Lg=c00@0O7al08V9R@29RHT0TY:B0P2`/;001@3<c<`0d];B0=7Ad@3AdM40e=CD
0080^;Rh00D0[Zj^0:b/[02TY:@0Y:BT09bLW0020:BTY00309VIV@2:RXX0RXZ:0080OWin0P22PX80
102;Rh/0U9BD09BDU02UYJD?0?ooo`003@3oool0101XJ6P0Ph>308>3P`3GemL206UYJ@0508n?S`2G
UiL0LG5a075aL@2JVYX00P29RHT01@2n_[h0JVYZ06YZJP2JVYX0S8b<0080UIFE00D0PX:20;Zj^P2j
^[X0Hf=S08N7Q`020;:b/P0407inOP2@T900T92@0:f][@80Ng]k00D0ZZZZ061PH02UYJD0YJFU09jN
WP0207alO00507moO`2EUID0VIVI09VIV@2m_Kd00P27QhL01@1LG5`0Ph>30;Ng]`2g]kL0LG5a0080
i>CT00D0C4a<0:n_[`2_[jl0Kfm_0861P@020:6QX@0509nOW`2=SHd0SHf=08>3P`2[Zj/00P1_Kfl0
102`/;00P8200820P02RXZ8208B4Q0050861P@28R8P0SXj>08j>SP3Fe]H00P17AdL01@2IVIT0W9bL
09VIV@2IVIT0UIFE0080HV9R00D0UYJF0;6a/@2a/K40M7Ad0<?3``0206MWI`050:NWY`1eMGD0MGEe
0:f][@1mOGd00P22PX801@21PH40_;bl0;bl_02QXJ40NGUi0080V9RH00@0:RXZ0?ooo`3oool0QXJ6
0P0Z:RX01@3Shn<0GEeM0:RXZ02XZ:P0Rh^;0080^KVi00D0PH6105]KF`2QXJ40XJ6Q0;2`/00208N7
Q`0507alO02LW9`0W9bL08^;R`29RHT00P36a/H01@1;Bd/0U9BD09BDU02>SXh0Xj>S0080ZJVY00D0
Ng]k08V9R@29RHT0XZ:R08b<S00208V9R@0408j>SP2GUiL0UiNG08:2PP80Vi^K00D0Shn?09:BTP2H
V9P0V9RH08j>SP0207UiN@0509bLW02UYJD0Hf=S06=SH`2PX:000P2NWYh01@1kNg/0WYjN09jNWP26
QXH0VIVI0080Shn?00@0WYjN07YjNP1jNWX0[jn_2P3oool0102f][H0[jn_0:n_[`2/[:`20:n_[`80
/k>c0P2_[jl30:^[Z`050:JVYP2^[Zh0[Zj^0;Rh^02k^k/00P2m_Kd01@2_[jl0/;2`0;2`/02f][H0
/[:b0080[Zj^00@0^k^k0;Rh^02h^;P0[Zj^0P2d];@01@2ZZZX0YjNW09VIV@2IVIT0TY:B0080QhN7
00D0SXj>09JFUP2BTY80TY:B09BDU00209nOW`040;:b/P2/[:`0[jn_0:n_[`<0];Bd00D0Y:BT09nO
W`2OWil0WYjN09fMW@020:FUY@050;Rh^034a<@0a<C40<[:bP36a/H00P30`<00102[Zj/0ZJVY0:VY
Z@2XZ:P20:j^[P050:>SX`2^[Zh0XZ:R0::RXP2CTi<00P2;Rh/01@2=SHd0QhN708j>SP2>SXh0UiNG
0080YjNW00D0[Zj^0:b/[02/[:`0XZ:R0:JVYP0209JFUP0509:BTP2CTi<0Ti>C0::RXP2XZ:P00P2c
/k<01@31`L40`/;20<;2`P2^[Zh0WYjN0080RXZ:00@0L71`06UYJ@1YJFT0NWYj0P29RHT01@2CTi<0
WYjN0:>SX`2SXj<0Vi^K0080Ti>C00D0QHF508f=S@28R8P0R8R8092@T00208f=S@0409bLW02<S8`0
S8b<08V9R@<0O7al00D0Ogmo08N7Q`27QhL0R8R808^;R`0208>3P`0507]kN`1fMWH0MWIf06i^KP1/
K6`00P1cLg<0101lO7`0RHV908V9R@2BTY820;2`/0050<c<c03Bd]80dM7A0=7Ad@3De=@00P2h^;P0
1@2^[Zh0[:b/0:BTY02TY:@0W9bL0080Y:BT00<0VIVI08Z:RP2:RXX00P1nOWh208:2PP0408^;R`2D
U9@0U9BD0:FUY@l0oooo000=0?ooo`0406e]K@20P800P8200=OGe`80JFUY00D0Shn?09JFUP1fMWH0
MWIf09BDU00208^;R`050;fm_@1[Jf/0Jf][09NGU`2=SHd00P2FUYH01@26QXH0][Jf0;Jf]P1TI6@0
QXJ60080];Bd00@0OWin09:BTP2BTY80ZZZZ0P1mOGd01@2UYJD0IFEU0:FUY@2UYJD0VYZJ0080OGem
00D0Ng]k09fMW@2CTi<0Ti>C0;fm_@0208V9R@0505YJFP22PX80_;bl0;bl_01`L7000P3Lg=`01@1F
EUH0[Zj^0:j^[P1^KVh0OWin0080XJ6Q00D0X:2P08n?S`2?Shl0OWin0:n_[`0206MWI`040;Vi^@1m
OGd0OGem0:2PX080Q8B400D0Ph>308N7Q`2<S8`0S8b<0=KFeP0204Y:BP0509VIV@2JVYX0U9BD09BD
U02LW9`00P1LG5`01@2LW9`0[:b/0:b/[01fMWH0`/;20080IVIV00D0ZJVY079bLP1bLW80/;2`07]k
N`0208F5Q@0508:2PP2m_Kd0_Kfm09RHV021PH400P2HV9P0100X:2P0oooo0?ooo`1nOWh202l_;`05
0=cLg01VIVH0XZ:R0::RXP2;Rh/00P2m_Kd01@1lO7`0GUiN09fMW@2MWId0[Zj^0080SHf=00D0Ogmo
09RHV02HV9P0R8R809:BTP020;Jf]P0305ADE02@T900T92@0080VIVI0P2ZZZX01@1mOGd0RXZ:08Z:
RP2RXZ80SHf=0080QHF500@0SXj>09NGU`2GUiL0QHF50P2IVIT01@2BTY80T92@09VIV@2IVIT0SHf=
0080M7Ad00D0ZZZZ09bLW01UIFD0IFEU09nOW`020:6QX@0507YjNP2EUID0UIFE09>CT`2DU9@00P2A
TI40102NWYh0LW9b079bLP2d];@:0?ooo`0408R8R02JVYX0VYZJ0:6QX@80X:2P00@0Vi^K08j>SP2:
RXX0RXZ:0`27QhL01@22PX80OWin07inOP1ZJVX0I6AT0080HV9R00D0O7al07YjNP1jNWX0R8R809^K
V`020:ZZZP040:>SX`2/[:`0[:b/0;2`/080Z:RX00D0ZJVY0:b/[02m_Kd0_Kfm0<c<c0020=?Cd`03
0<_;b`38b<P0d=3@0080d=3@0P39bLT01@2o_kl0^KVi0:RXZ02XZ:P0UYJF0080SXj>00D0U9BD08b<
S02<S8`0QXJ60861P@0207alO00507=cL`1gMgL0MgMg07QhN01gMgL00P1iNGT0101lO7`0Kfm_06m_
K`1[Jf/206a/K00506e]K@1XJ6P0NWYj07YjNP26QXH00P2GUiL01@2KVi/0ZZZZ0:JVYP2VYZH0YJFU
0080TY:B00D0Rh^;08F5Q@25QHD0QHF50861P@0208V9R@0508Z:RP20P800P82006a/K01RHV800P1H
F5P01@1=CDd0E5AD05ADE01SHf<0M7Ad0080RXZ:00@0W9bL0:6QX@2QXJ40W9bL0P2;Rh/408:2PP05
08f=S@2FUYH0UYJF08b<S02CTi<00P2ATI40102FUYH0UiNG09NGU`2UYJD209jNWP050::RXP2DU9@0
Shn?08n?S`28R8P00`24Q8@0102<S8`0Shn?08n?S`2:RXX208b<S00308J6QP22PX80Ph>30080Ph>3
0P1lO7`01@23Ph<0M7Ad07AdM01NGUh0HF5Q0080L71`00D0MGEe08b<S02<S8`0U9BD09>CT`0207]k
N`0406YZJP1GEeL0EeMG05iNGP80Hf=S00<0M7Ad07YjNP1nOWh00P1nOWh207moO`030820P03oool0
oooo00d0oooo000=0?ooo`0406i^KP21PH40PH610=CDe080JFUY00D0T92@09:BTP1mOGd0OGem08j>
SP0208b<S0050;fm_@1_Kfl0Kfm_09BDU02@T9000P2BTY801@28R8P0]kNg0;Ng]`1RHV80R8R80080
]KFe00@0NGUi09JFUP2FUYH0Z:RX0P20P8001@2QXJ40IfMW0:RXZ02XZ:P0UYJF0080OWin00D0NWYj
0:BTY02?Shl0Shn?0;bl_00208R8R00505]KF`22PX80`/;20<;2`P1ZJVX00P3GemL01@1PH600ZZZZ
0:ZZZP1/K6`0OGem0080Y:BT00D0WinO09BDU02DU9@0Ng]k0:n_[`0206ATI0040;fm_@20P800P820
09bLW080PX:200D0R8R808N7Q`28R8P0R8R80=cLg00204M7A`0509FEU@2RXZ80SHf=08f=S@2SXj<0
0P1EEED01@2TY:@0YjNW0:NWY`1gMgL0a<C40080Hf=S00D0[Jf]06a/K01/K6`0]KFe07QhN00208J6
QP0508>3P`2n_[h0_[jn09:BTP22PX800P2KVi/0100W9bL0oooo0?ooo`1jNWX2034a<@050=SHf01^
KVh0WYjN09jNWP2;Rh/00P2o_kl01@1jNWX0HF5Q09BDU02DU9@0^KVi0080Rh^;00D0Q8B408n?S`2?
Shl0SXj>09BDU0020:b/[00505IFEP2BTY80TY:B0:BTY02?Shl00P2/[:`01@1lO7`0Rh^;08^;R`2Q
XJ40SXj>0080PH6100@0TI6A09JFUP2FUYH0RXZ:0P2DU9@01@2EUID0TI6A09JFUP2FUYH0RHV90080
M7Ad00D0/K6a09NGU`1ZJVX0JVYZ09bLW00209jNWP0507moO`2ATI40TI6A09RHV02@T9000P2ATI40
102MWId0MgMg07MgM`2a/K4:0?ooo`0408f=S@1oOgl0Ogmo07QhN080LG5a00D0Hf=S06a/K01gMgL0
MgMg075aL@0207=cL`0508b<S02BTY80TY:B09RHV02a/K400P30`<001@2^[Zh0Z:RX0:RXZ02FUYH0
P8200080Jf][00@0GUiN04i>CP1>CTh0EEEE0P1ADE401@1?Cdl0EUIF05QHF01HF5P0D51@0080EeMG
00@0H61P06QXJ01_Kfl0Kfm_0`1fMWH01@1kNg/0OGem08J6QP26QXH0U9BD0080UiNG00D0V9RH0:BT
Y02TY:@0Z:RX0:^[Z`030;6a/@<0YjNW00@0Y:BT0:NWY`2WYjL0/k>c0P3Cdm<01@3Fe]H0g=cL0=cL
g03IfMT0`L710080X:2P00D0Shn?07alO01lO7`0LW9b06m_K`0305mOG`80IFEU00D0MGEe08R8R028
R8P0Y:BT0:^[Z`020:n_[`050;Bd]02i^KT0^KVi0<g=c@3De=@00P3Jf]X01@3Rh^80gMgM0=gMg@3<
c<`0alO70080_;bl00@0[Jf]0:RXZ02XZ:P0Y:BT0`2QXJ40102EUID0QHF508F5Q@1jNWX207EeM@05
07]kN`1dM7@0Ng]k07]kN`1cLg<00P1WIfL01@1PH600MgMg07MgM`22PX80W9bL0080/K6a00D0]KFe
0;2`/02`/;00[Zj^0:NWY`020:f][@050;Rh^02c/k<0/k>c0;bl_030`<000P2b/[80102UYJD0ZJVY
0:VYZ@2OWil209fMW@050;2`/02d];@0WYjN09jNWP2@T9000P2;Rh/20820P080Xj>S00@0c/k>0=WI
f@3IfMT0b/[:0P3Bd]801@3=cLd0Z:RX0:2PX02PX:00[:b/0080X:2P00<0TY:B0?ooo`3oool03@3o
ool000d0oooo00@0KVi^0861P@21PH40e=CD0P1YJFT01@2@T900TY:B07emO@1mOGd0SXj>0080S8b<
00D0_Kfm06m_K`1_Kfl0U9BD092@T00209:BTP0508R8R02g]kL0]kNg069RHP28R8P00P2e]KD0101i
NGT0UYJF09JFUP2XZ:P20820P0050:6QX@1WIfL0Z:RX0:RXZ02FUYH00P1nOWh01@1jNWX0Y:BT08n?
S`2?Shl0_;bl0080R8R800D0Fe]K08:2PP32`/80`/;206YZJP020=OGe`05061PH02ZZZX0ZZZZ06a/
K01mOGd00P2TY:@01@2OWil0U9BD09BDU01kNg/0[jn_0080I6AT00@0_Kfm0820P020P800W9bL0P22
PX801@28R8P0QhN708R8R028R8P0g=cL0080AdM700D0UIFE0::RXP2=SHd0SHf=0:>SX`0205EEE@05
0:BTY02WYjL0YjNW07MgM`34a<@00P1SHf<01@2][Jd0K6a/06a/K02e]KD0N7Qh0080QXJ600D0Ph>3
0;jn_P2n_[h0TY:B08:2PP0209^KV`0402LW9`3oool0oooo07YjNP80<C4a00D0f=SH06i^KP2NWYh0
WYjN08^;R`020;no_`0507YjNP1QHF40U9BD09BDU02i^KT00P2;Rh/01@24Q8@0Shn?08n?S`2>SXh0
U9BD0080[:b/00D0EUIF09:BTP2BTY80Y:BT08n?S`020:b/[00507alO02;Rh/0Rh^;0:6QX@2>SXh0
0P21PH40102ATI40UYJF09JFUP2:RXX209BDU00509FEU@2ATI40UYJF09JFUP29RHT00P1dM7@01@2a
/K40UiNG06YZJP1ZJVX0W9bL0080WYjN00D0Ogmo096AT@2ATI40V9RH092@T002096AT@0409fMW@1g
MgL0MgMg0;6a/@X0oooo00@0SHf=07moO`1oOgl0N7Qh0P1aLG401@1SHf<0K6a/07MgM`1gMgL0LG5a
0080Lg=c00D0S8b<09:BTP2BTY80V9RH0;6a/@020<30`0050:j^[P2XZ:P0Z:RX09JFUP20P8000P1[
Jf/0101NGUh0CTi>04i>CP1EEED2055AD@0504m?C`1FEUH0F5QH05QHF01@D5000P1GEeL0101PH600
J6QX06m_K`1_Kfl307IfMP0507]kN`1mOGd0QXJ608J6QP2DU9@00P2GUiL01@2HV9P0Y:BT0:BTY02X
Z:P0Zj^[00<0/K6a0`2WYjL0102TY:@0YjNW0:NWY`2c/k<20=?Cd`050=KFeP3Lg=`0g=cL0=WIf@31
`L400P2PX:001@2?Shl0O7al07alO01bLW80Kfm_00<0GemO0P1UIFD01@1eMGD0R8R808R8R02TY:@0
Zj^[0080[jn_00D0];Bd0;Vi^@2i^KT0cLg=0=CDe0020=[JfP050>;RhP3MgMd0gMgM0<c<c037alL0
0P2l_;`0102][Jd0Z:RX0:RXZ02TY:@30:6QX@0409FEU@25QHD0QHF507YjNP80MGEe00D0Ng]k07Ad
M01kNg/0Ng]k07=cL`0206MWI`05061PH01gMgL0MgMg08:2PP2LW9`00P2a/K401@2e]KD0/;2`0;2`
/02^[Zh0YjNW0080[Jf]00D0^;Rh0;>c/`2c/k<0_;bl0<30`0020;:b/P040:FUY@2YZJT0ZJVY09nO
W`80WIfM00D0/;2`0;Bd]02NWYh0WYjN092@T00208^;R`80P8200P2SXj<0103>c/h0fMWI0=WIf@3:
b/X20=;BdP050<g=c@2XZ:P0X:2P0:2PX02/[:`00P2PX:000`2BTY80oooo0?ooo`0=0?ooo`003@3o
ool0101XJ6P0Q8B408B4Q03Bd]8206YZJP80T92@0P20P800102@T900Rh^;08^;R`2k^k/2079bLP05
08j>SP2HV9P0RXZ:08Z:RP2ATI400P2^[Zh01@1VIVH0Ph>30;fm_@2m_Kd0MWIf0080UYJF00D0YZJV
07moO`1oOgl0Xj>S06QXJ0020:ZZZP0509:BTP1nOWh0OWin07QhN02ZZZX00P2<S8`01@2j^[X0S8b<
08b<S01GEeL0Ph>30080a/K600@0J6QX0=3@d03@d=00JVYZ0P2XZ:P01@1ZJVX0O7al0:JVYP2VYZH0
Vi^K0080VYZJ00D0N7Qh0:j^[P1UIFD0IFEU0;Zj^P0208B4Q00309^KV`1nOWh0OWin0080RXZ:0P24
Q8@01@3Ogml0B4Q804Q8B02@T900XJ6Q0080Shn?00@0YJFU05ADE01DE5@0ZZZZ0P2MWId01@1lO7`0
`l?3069RHP1RHV80[jn_0080IfMW00D0_;bl07AdM025QHD0QHF508R8R0020;bl_005096AT@22PX80
Vi^K09^KV`0Z:RX00P3oool01@1gMgL0<c<c03<c<`3De=@0MWIf0080W9bL00D0R8R80<71`@31`L40
N7Qh06ATI00208Z:RP040<O7a`22PX80PX:208^;R`80R8R800D0UYJF08n?S`2YZJT0ZJVY05ADE002
09VIV@050:JVYP2:RXX0[Jf]0:f][@1lO7`00P2>SXh01@2KVi/0TY:B07emO@1mOGd0U9BD0080UIFE
00D0QXJ609VIV@2IVIT0TY:B092@T00209VIV@0508^;R`1_Kfl0Kfm_0;Ng]`2?Shl00P1/K6`0102P
X:00VYZJ09ZJVP25QHD208V9R@050:6QX@2>SXh0TI6A096AT@2JVYX00P1gMgL00`2f][H0oooo0?oo
o`080?ooo`0407alO02=SHd0SHf=09FEU@80U9BD00D0^k^k0<30`02f][H0][Jf0;Vi^@020<c<c005
0::RXP28R8P0R8R807QhN01JFUX00P0j>SX01@0k>c/0BTY:04Y:BP1QHF40Jf][0080O7al00@0Ti>C
0:FUY@2UYJD0X:2P0P2h^;P01@30`<00]kNg0;:b/P2b/[80][Jf0080/[:b00D0ZJVY09NGU`24Q8@0
Q8B406][J`0206YZJP0506MWI`1hN7P0Ogmo07moO`2?Shl00P2BTY801@2;Rh/0Ph>308>3P`25QHD0
OWin0080Lg=c00D0MGEe07UiN@1iNGT0Ogmo08f=S@0208j>SP0408n?S`22PX80PX:207UiN@80Kfm_
00D0N7Qh09ZJVP2i^KT0^KVi0<g=c@020=cLg0050>7Qh@3De=@0gMgM0=gMg@3Hf=P00P3Jf]X01@3=
cLd0];Bd0;Bd]02CTi<0R8R80080MgMg00<0Lg=c079bLP1bLW800P1ZJVX206a/K00306EUI@1/K6`0
K6a/0080NWYj0P1gMgL01023Ph<0Rh^;08^;R`2ATI4209NGU`050:NWY`2h^;P0alO70<O7a`3AdM40
0P3MgMd01@3IfMT0YjNW09>CT`2CTi<0U9BD0080TI6A00D0SHf=09bLW02LW9`0SHf=07UiN@0206e]
K@0505mOG`1^KVh0KVi^07=cL`1_Kfl00P1WIfL01@1YJFT0IVIV06IVIP1ZJVX0J6QX0080O7al00@0
PX:208V9R@29RHT0QHF50P1oOgl01@1MGEd0De=C055AD@1ADE40F5QH0080G5aL00D0IFEU06e]K@1[
Jf/0Jf][05YJFP0206m_K`0509VIV@2RXZ80XZ:R0:b/[03Shn<00P3@d=00102[Zj/0Y:BT0:BTY02I
VIT?0?ooo`003@3oool0101QHF40RXZ:08Z:RP3;bl/2075aL@0508n?S`2>SXh0P8200820P02BTY80
0P2:RXX01@2i^KT0N7Qh07QhN025QHD0XJ6Q0080Q8B400D0VYZJ0:BTY02TY:@0IfMW08J6QP020;^k
^`0407IfMP2IVIT0VIVI0::RXP80PX:200D0YZJV069RHP2][Jd0[Jf]092@T00207moO`0507IfMP2`
/;00S8b<08b<S02b/[800P2ATI401@1CDe<0QXJ60<W9b@39bLT0I6AT0080c<c<00D0LG5a0:FUY@2U
YJD0JFUY07alO0020:RXZ00509FEU@2QXJ40XJ6Q07QhN02ZZZX00P1ZJVX0102f][H0QXJ608J6QP2L
W9`207YjNP0508Z:RP2ATI40Ogmo07moO`3QhN400P19BDT01@2>SXh0UiNG0:>SX`2SXj<0TI6A0080
G5aL00D0/k>c09BDU02DU9@0Ogmo0<30`00206=SH`050;2`/01VIVH0IVIV0;no_`1bLW800P24Q8@0
1@27QhL0_[jn0;jn_P2@T900P8200080Vi^K00@0;Rh^0?ooo`3oool0NGUi0P0d=3@01@3?cll0NGUi
09jNWP2NWYh0QhN70080_[jn00D0Ng]k06EUI@24Q8@0Q8B40<k>cP0207alO00509:BTP21PH40PH61
0:2PX027QhL00P2UYJD01@1GEeL0W9bL09bLW02RXZ80T92@0080Zj^[00D0MWIf09FEU@2EUID0UYJF
096AT@020820P00409JFUP2?Shl0Shn?08^;R`80VIVI00D0TI6A08n?S`2NWYh0WYjN08Z:RP0206MW
I`050<?3``27QhL0KVi^06i^KP2OWil00P2LW9`01@27QhL0Ph>308>3P`2NWYh0UiNG0080SHf=00@0
UIFE07YjNP1jNWX0^[Zj2P3oool00`35aLD0Zj^[0:^[Z`0309VIV@0307MgM`1dM7@0NGUi0080NGUi
0P1WIfL01@28R8P0Z:RX0:RXZ03<c<`0gMgM0080mOGe00D0n?Sh0>GUi@3UiND0c<c<0<W9b@020;^k
^`040:ZZZP2NWYh0WYjN09bLW080Rh^;00@0SHf=08j>SP27QhL0QhN70`1jNWX01@1nOWh0RXZ:09BD
U02DU9@0YjNW0080[:b/00D0Zj^[0:6QX@2[Zj/0Zj^[0:BTY0030:>SX`80Z:RX00D0Xj>S0:6QX@2P
X:00X:2P0::RXP0209jNWP0509BDU028R8P0R8R808R8R024Q8@00P1gMgL0101fMWH0N7Qh07QhN01_
Kfl3069RHP05059BDP1<C4`0C4a<05QHF01RHV800P1/K6`01023Ph<0QhN708N7Q`1oOgl208Z:RP05
092@T02ATI40WinO09nOW`2XZ:P00P2e]KD20;Zj^P<0];Bd0P2KVi/01@2GUiL0V9RH09^KV`2KVi/0
V9RH0080Ti>C00D0R8R808J6QP26QXH0PH6107]kN`0207emO@050820P01lO7`0O7al07alO02UYJD0
0P2g]kL0102`/;00];Bd0;Bd]02j^[X20::RXP050:j^[P2g]kL0];Bd0;Bd]02h^;P00P2[Zj/01@2T
Y:@0[Jf]0;Rh^02h^;P0]kNg0080_;bl00D0[Zj^0:b/[02JVYX0VYZJ09nOW`0209FEU@0309fMW@2Z
ZZX0ZZZZ0080bLW90P3Ti>@01@3WinL0gmoO0=oOg`3Ng]h0gmoO0080`/;200@0/[:b0:FUY@2UYJD0
PX:20P1^KVh01@1VIVH0ADE505]KF`1KFe/0O7al0080RXZ:00<0XZ:R0?ooo`3oool03@3oool000d0
oooo00@0F5QH092@T02@T900aLG50P1iNGT01@2;Rh/0SHf=08>3P`23Ph<0SXj>0080RHV900D0^[Zj
07emO@1mOGd0NGUi0:NWY`0208F5Q@<0WIfM00D0J6QX08n?S`2j^[X0^[Zj06a/K0020:2PX00509nO
W`22PX80PX:20:ZZZP1NGUh00P2^[Zh01@2ATI40OGem07emO@1dM7@0]KFe0080S8b<00D0[Jf]09:B
TP2BTY80E5AD08Z:RP020<O7a`0406=SH`38b<P0b<S807]kN`80XJ6Q00D0IfMW07moO`2YZJT0ZJVY
08j>SP020:RXZ00507EeM@2YZJT0KFe]06e]K@2b/[800P28R8P01@2MWId0MWIf07IfMP2=SHd0UiNG
0080NGUi00<0hn?S04Q8B018B4P00P2?Shl20;2`/00408J6QP1UIFD0IFEU0;2`/080TI6A00D0Ogmo
0<30`01WIfL0IfMW0:j^[P0206MWI`050;jn_P1dM7@0P8200820P02;Rh/00P2m_Kd01@2<S8`0QHF5
09VIV@2IVIT0;bl_0080oooo00D0NWYj03De=@0e=CD0cLg=07]kN`020:2PX00508F5Q@2m_Kd0_Kfm
07emO@1TI6@00P22PX80103AdM40N7Qh07QhN02HV9P207]kN`050:NWY`1kNg/0[Jf]0:f][@1GEeL0
0`2NWYh0102IVIT0YJFU0:FUY@1cLg<209nOW`0508R8R02FUYH0Ph>308>3P`2FUYH00P2@T9001@25
QHD0W9bL09bLW02=SHd0U9BD0080WIfM00D0Rh^;065QH@1QHF40b/[:08>3P`02071`L0040:2PX02J
VYX0VYZJ08F5Q@80S8b<00D0V9RH09:BTP2CTi<0Ti>C09FEU@0207MgM`030<30`03oool0oooo00P0
oooo00@0RHV909jNWP2NWYh0YJFU0P2g]kL01@2l_;`0_Kfm0;fm_@2m_Kd0`l?30080^[Zj00D0/;2`
0:>SX`2SXj<0RHV908Z:RP0208:2PP0508J6QP2;Rh/0Rh^;09NGU`2CTi<00P2QXJ430;2`/0050:f]
[@2YZJT0ZJVY09bLW02KVi/00P2/[:`01@2h^;P0/k>c0;>c/`2d];@0[:b/0080YJFU00D0WIfM09^K
V`2KVi/0VIVI09FEU@0207]kN`0406e]K@1^KVh0KVi^07QhN080Ogmo00D0SHf=09ZJVP2MWId0WIfM
09RHV00209>CT`0509VIV@2PX:00W9bL09bLW02KVi/00`2_[jl20;:b/P050;no_`33`l<0]kNg0;Ng
]`37alL00P2/[:`01@2>SXh0K6a/05QHF01HF5P0>CTi0080B4Q800D0GEeM07=cL`1cLg<0Ogmo08^;
R`02092@T00508j>SP2?Shl0Shn?08V9R@2;Rh/00P2=SHd01@2FUYH0ZZZZ0:ZZZP2XZ:P0XJ6Q0080
WinO00@0UYJF08j>SP2>SXh0WinO0P2WYjL01@2TY:@0Xj>S0::RXP2RXZ80VIVI0080U9BD00D0X:2P
0;Rh^02h^;P0^;Rh0;Zj^P020;bl_0050;2`/02;Rh/0Rh^;07inOP1lO7`00P2;Rh/00`2>SXh0WinO
09nOW`020:6QX@80SHf=00D0R8R808J6QP26QXH0S8b<08n?S`0209bLW004096AT@2HV9P0V9RH092@
T080O7al00D0HF5Q07MgM`1]KFd0KFe]07alO00208b<S00508Z:RP1^KVh0LW9b079bLP1aLG400P1Z
JVX01@1jNWX0Rh^;08^;R`2@T900WinO0080W9bL00@0XZ:R0:6QX@2QXJ40UiNG3`3oool000d0oooo
00@0F5QH092@T02@T900aLG50P1iNGT01@2;Rh/0SHf=08>3P`23Ph<0SXj>0080RHV900D0^[Zj07em
O@1mOGd0NGUi0:NWY`0208F5Q@<0WIfM00D0J6QX08n?S`2j^[X0^[Zj06a/K0020:2PX00509nOW`22
PX80PX:20:ZZZP1NGUh00P2^[Zh01@2ATI40OGem07emO@1dM7@0]KFe0080S8b<00D0[Jf]09:BTP2B
TY80E5AD08Z:RP020<O7a`0406=SH`38b<P0b<S807]kN`80XJ6Q00D0IfMW07moO`2YZJT0ZJVY08j>
SP020:RXZ00507EeM@2YZJT0KFe]06e]K@2b/[800P28R8P01@2MWId0MWIf07IfMP2=SHd0UiNG0080
NGUi00<0hn?S04Q8B018B4P00P2?Shl20;2`/00408J6QP1UIFD0IFEU0;2`/080TI6A00D0Ogmo0<30
`01WIfL0IfMW0:j^[P0206MWI`050;jn_P1dM7@0P8200820P02;Rh/00P2m_Kd01@2<S8`0QHF509VI
V@2IVIT0;bl_0080oooo00D0NWYj03De=@0e=CD0cLg=07]kN`020:2PX00508F5Q@2m_Kd0_Kfm07em
O@1TI6@00P22PX80103AdM40N7Qh07QhN02HV9P207]kN`050:NWY`1kNg/0[Jf]0:f][@1GEeL00`2N
WYh0102IVIT0YJFU0:FUY@1cLg<209nOW`0508R8R02FUYH0Ph>308>3P`2FUYH00P2@T9001@25QHD0
W9bL09bLW02=SHd0U9BD0080WIfM00D0Rh^;065QH@1QHF40b/[:08>3P`02071`L0040:2PX02JVYX0
VYZJ08F5Q@80S8b<00D0V9RH09:BTP2CTi<0Ti>C09FEU@0207MgM`030<30`03oool0oooo00P0oooo
00@0RHV909jNWP2NWYh0YJFU0P2g]kL01@2l_;`0_Kfm0;fm_@2m_Kd0`l?30080^[Zj00D0/;2`0:>S
X`2SXj<0RHV908Z:RP0208:2PP0508J6QP2;Rh/0Rh^;09NGU`2CTi<00P2QXJ430;2`/0050:f][@2Y
ZJT0ZJVY09bLW02KVi/00P2/[:`01@2h^;P0/k>c0;>c/`2d];@0[:b/0080YJFU00D0WIfM09^KV`2K
Vi/0VIVI09FEU@0207]kN`0406e]K@1^KVh0KVi^07QhN080Ogmo00D0SHf=09ZJVP2MWId0WIfM09RH
V00209>CT`0509VIV@2PX:00W9bL09bLW02KVi/00`2_[jl20;:b/P050;no_`33`l<0]kNg0;Ng]`37
alL00P2/[:`01@2>SXh0K6a/05QHF01HF5P0>CTi0080B4Q800D0GEeM07=cL`1cLg<0Ogmo08^;R`02
092@T00508j>SP2?Shl0Shn?08V9R@2;Rh/00P2=SHd01@2FUYH0ZZZZ0:ZZZP2XZ:P0XJ6Q0080WinO
00@0UYJF08j>SP2>SXh0WinO0P2WYjL01@2TY:@0Xj>S0::RXP2RXZ80VIVI0080U9BD00D0X:2P0;Rh
^02h^;P0^;Rh0;Zj^P020;bl_0050;2`/02;Rh/0Rh^;07inOP1lO7`00P2;Rh/00`2>SXh0WinO09nO
W`020:6QX@80SHf=00D0R8R808J6QP26QXH0S8b<08n?S`0209bLW004096AT@2HV9P0V9RH092@T080
O7al00D0HF5Q07MgM`1]KFd0KFe]07alO00208b<S00508Z:RP1^KVh0LW9b079bLP1aLG400P1ZJVX0
1@1jNWX0Rh^;08^;R`2@T900WinO0080W9bL00@0XZ:R0:6QX@2QXJ40UiNG3`3oool000d0oooo00@0
De=C09JFUP2FUYH0_[jn0P20P80208^;R`80OWin00@0UYJF08J6QP26QXH0^KVi0P1nOWh01@1gMgL0
ZZZZ0861P@21PH40XZ:R0080UiNG00D0IFEU09jNWP2c/k<0/k>c06UYJ@020:2PX00509fMW@23Ph<0
Ph>30;2`/01IFET00P2][Jd01@2BTY80OWin07inOP1dM7@0];Bd0080TI6A00D0ZJVY096AT@2ATI40
EeMG08R8R0020<S8b00406=SH`33`l<0`l?308>3P`80VYZJ00D0IfMW08:2PP2YZJT0ZJVY08V9R@02
0:n_[`0507AdM02VYZH0L71`071`L02/[:`00P2@T9001@2KVi/0LW9b079bLP2>SXh0WYjN0080N7Qh
00D0h>3P04Y:BP1:BTX0SXj>08V9R@020;Rh^00407moO`1]KFd0KFe]0:b/[080SXj>00D0PH610<30
`01YJFT0JFUY0:b/[00206YZJP050;bl_01hN7P0N7Qh07QhN02>SXh00P2o_kl01@2:RXX0QHF509ZJ
VP2JVYX0<30`0080oooo00D0NWYj03@d=00d=3@0clo?07inOP0209jNWP0508B4Q02m_Kd0_Kfm07em
O@1RHV800P26QXH0103IfMT0Hf=S06=SH`2PX:0207inOP050:b/[01aLG40][Jf0;Jf]P1>CTh00P2T
Y:@01@2KVi/0X:2P0:6QX@2QXJ40KFe]0080Z:RX00D0OGem09bLW024Q8@0Q8B409ZJVP0208Z:RP05
08V9R@2JVYX0VYZJ08b<S02HV9P00P2IVIT01@2>SXh0GUiN05iNGP3=cLd0OWin0080Lg=c00@0WYjN
09^KV`2KVi/0Q8B40P2DU9@01@2>SXh0UIFE09FEU@2EUID0TI6A0080PH6100<0^[Zj0?ooo`3oool0
203oool0102LW9`0Ti>C09>CT`2GUiL2096AT@0509>CT`2HV9P0VYZJ09ZJVP2KVi/00P2WYjL30:JV
YP050:ZZZP2SXj<0WIfM09fMW@2HV9P00P2OWil01@2BTY80RHV907UiN@1iNGT0IfMW0080Hf=S00D0
O7al092@T02@T900VYZJ0:6QX@0209>CT`050820P01nOWh0OWin08V9R@2IVIT00P2YZJT01@2f][H0
_;bl0;bl_02h^;P0];Bd0080`L7100@0`l?30;bl_02l_;`0]kNg0P2b/[801@2UYJD0WYjN09fMW@2M
WId0WYjN0080X:2P00D0UIFE08j>SP2ATI40TI6A08^;R`0207alO0<0Ogmo0P1jNWX20820P00508V9
R@2KVi/0Vi^K0<S8b03Ph>000P3Xj>P0103Zj^X0iNGU0>GUi@31`L430;Bd]0040:b/[02VYZH0YZJV
09ZJVP80T92@00D0U9BD096AT@2;Rh/0Rh^;08N7Q`0208>3P`0507alO023Ph<0PX:208:2PP2<S8`0
0P2FUYH01@2IVIT0TI6A096AT@2@T900U9BD0080RHV900D0R8R808^;R`2;Rh/0SHf=0861P@0208F5
Q@04092@T02JVYX0VYZJ09nOW`80/k>c00D0/;2`0:^[Z`2RXZ80XZ:R09ZJVP0209VIV@80];Bd0P2j
^[X01@3:b/X0`l?30<?3``2e]KD0^;Rh0080Zj^[00@0^;Rh0;bl_02l_;`0bl_;0P3Lg=`01@3no_h0
l?3`0?7al@3alO40h^;R0080fm_K00<0hN7Q0?3`l03oool0103oool01@3Vi^H0e=CD0=CDe031`L40
[Jf]0080Vi^K00@0UiNG09FEU@2EUID0Vi^K3`3oool000d0oooo00@0CTi>09VIV@2IVIT0^KVi0P28
R8P01@29RHT0QhN707inOP1nOWh0W9bL0080Q8B400D0]kNg08:2PP22PX80Lg=c0:ZZZP020820P005
0:f][@2<S8`0S8b<06ATI02WYjL00P2`/;00101ZJVX0WIfM09fMW@2MWId208>3P`050;Fe]@1HF5P0
ZZZZ0:ZZZP2GUiL00P1oOgl01@1^KVh0];Bd09NGU`2GUiL0YjNW0080Shn?00D0EeMG08R8R038b<P0
b<S806QXJ0020;Vi^@0508^;R`2IVIT0VIVI06ATI025QHD00P2WYjL01@25QHD0][Jf0;Jf]P1`L700
YJFU0080Lg=c00@0ZJVY09JFUP2FUYH0UIFE0P1eMGD01@2;Rh/0Xj>S07QhN01hN7P0f=SH0080Cdm?
00D0TY:B07emO@30`<00`<3007alO00207EeM@050:VYZ@2>SXh0SXj>08:2PP2o_kl00P1[Jf/01@2V
YZH0KFe]06e]K@2m_Kd0NWYj0080LW9b00D0U9BD0;jn_P2n_[h0QhN708^;R`0209>CT`0403Hf=P3o
ool0oooo07YjNP80<c<c00D0dm?C07]kN`2NWYh0WYjN08F5Q@020;^k^`0507inOP1PH600S8b<08b<
S03Ng]h00P1BDU801@2VYZH0PX:208:2PP2_[jl0IFEU0080aLG500D0ATI60:RXZ02XZ:P0UiNG0:RX
Z00209bLW00506QXJ02b/[80/[:b079bLP2PX:000P25QHD0102JVYX0Rh^;08^;R`27QhL209RHV005
08b<S02JVYX0VIVI09VIV@2ATI400P1GEeL0103Bd]80N7Qh07MgM`1gMgL309jNWP0508B4Q02CTi<0
Ti>C08^;R`2EUID00P2LW9`01029RHT0PH610861P@2o_kl:0?ooo`0409VIV@2EUID0UIFE08f=S@80
P82000@0Q8B40820P01kNg/0Ng]k0`1fMWH01@1oOgl0MGEe07EeM@1eMGD0M7Ad0080L71`00D0EeMG
05aLG01LG5`0Ng]k09bLW0020;Ng]`040=KFeP3IfMT0fMWI0;2`/080UYJF00D0RHV908R8R02FUYH0
UYJF0:b/[0020;>c/`040:JVYP2LW9`0RXZ:08Z:RP<0P82000D0T92@096AT@2ATI40TI6A09VIV@02
09BDU00508f=S@29RHT0RHV908^;R`28R8P00P2>SXh01@2@T900UiNG09NGU`2RXZ80XJ6Q0080WinO
00@0ZZZZ0;Fe]@2e]KD0^k^k0P35aLD01@32`/80/k>c0:FUY@2UYJD0TI6A0080WinO00D0P82009ZJ
VP2d];@0];Bd0<?3``020:JVYP050;Zj^P2NWYh0WYjN08F5Q@1lO7`00P1jNWX01@27QhL0Shn?08n?
S`29RHT0Rh^;0080Shn?00D0RXZ:08^;R`2;Rh/0VIVI09^KV`0309bLW080TY:B00D0Ph>308:2PP22
PX80Q8B40861P@0208j>SP0509JFUP2CTi<0Ti>C092@T02;Rh/00P25QHD0101fMWH0KFe]06e]K@1W
IfL206YZJP0507QhN029RHT0Rh^;08^;R`2GUiL00P2NWYh01@21PH40N7Qh08^;R`2;Rh/0MgMg0080
L71`00D0PH6107YjNP1nOWh0OWin07moO`020861P@05075aL@1eMGD0MGEe05MGE`1=CDd00P0n?Sh0
1@0d=3@0;2`/02`/;00Z:RX0@T920080DU9B00@0I6AT06i^KP1^KVh0VIVI0P2KVi/01@2SXj<0];Bd
0;no_`2o_kl0ZJVY0080Z:RX00<0WIfM0?ooo`3oool03@3oool000d0oooo00@0CTi>09VIV@2IVIT0
^KVi0P28R8P01@29RHT0QhN707inOP1nOWh0W9bL0080Q8B400D0]kNg08:2PP22PX80Lg=c0:ZZZP02
0820P0050:f][@2<S8`0S8b<06ATI02WYjL00P2`/;00101ZJVX0WIfM09fMW@2MWId208>3P`050;Fe
]@1HF5P0ZZZZ0:ZZZP2GUiL00P1oOgl01@1^KVh0];Bd09NGU`2GUiL0YjNW0080Shn?00D0EeMG08R8
R038b<P0b<S806QXJ0020;Vi^@0508^;R`2IVIT0VIVI06ATI025QHD00P2WYjL01@25QHD0][Jf0;Jf
]P1`L700YJFU0080Lg=c00@0ZJVY09JFUP2FUYH0UIFE0P1eMGD01@2;Rh/0Xj>S07QhN01hN7P0f=SH
0080Cdm?00D0TY:B07emO@30`<00`<3007alO00207EeM@050:VYZ@2>SXh0SXj>08:2PP2o_kl00P1[
Jf/01@2VYZH0KFe]06e]K@2m_Kd0NWYj0080LW9b00D0U9BD0;jn_P2n_[h0QhN708^;R`0209>CT`04
03Hf=P3oool0oooo07YjNP80<c<c00D0dm?C07]kN`2NWYh0WYjN08F5Q@020;^k^`0507inOP1PH600
S8b<08b<S03Ng]h00P1BDU801@2VYZH0PX:208:2PP2_[jl0IFEU0080aLG500D0ATI60:RXZ02XZ:P0
UiNG0:RXZ00209bLW00506QXJ02b/[80/[:b079bLP2PX:000P25QHD0102JVYX0Rh^;08^;R`27QhL2
09RHV00508b<S02JVYX0VIVI09VIV@2ATI400P1GEeL0103Bd]80N7Qh07MgM`1gMgL309jNWP0508B4
Q02CTi<0Ti>C08^;R`2EUID00P2LW9`01029RHT0PH610861P@2o_kl:0?ooo`0409VIV@2EUID0UIFE
08f=S@80P82000@0Q8B40820P01kNg/0Ng]k0`1fMWH01@1oOgl0MGEe07EeM@1eMGD0M7Ad0080L71`
00D0EeMG05aLG01LG5`0Ng]k09bLW0020;Ng]`040=KFeP3IfMT0fMWI0;2`/080UYJF00D0RHV908R8
R02FUYH0UYJF0:b/[0020;>c/`040:JVYP2LW9`0RXZ:08Z:RP<0P82000D0T92@096AT@2ATI40TI6A
09VIV@0209BDU00508f=S@29RHT0RHV908^;R`28R8P00P2>SXh01@2@T900UiNG09NGU`2RXZ80XJ6Q
0080WinO00@0ZZZZ0;Fe]@2e]KD0^k^k0P35aLD01@32`/80/k>c0:FUY@2UYJD0TI6A0080WinO00D0
P82009ZJVP2d];@0];Bd0<?3``020:JVYP050;Zj^P2NWYh0WYjN08F5Q@1lO7`00P1jNWX01@27QhL0
Shn?08n?S`29RHT0Rh^;0080Shn?00D0RXZ:08^;R`2;Rh/0VIVI09^KV`0309bLW080TY:B00D0Ph>3
08:2PP22PX80Q8B40861P@0208j>SP0509JFUP2CTi<0Ti>C092@T02;Rh/00P25QHD0101fMWH0KFe]
06e]K@1WIfL206YZJP0507QhN029RHT0Rh^;08^;R`2GUiL00P2NWYh01@21PH40N7Qh08^;R`2;Rh/0
MgMg0080L71`00D0PH6107YjNP1nOWh0OWin07moO`020861P@05075aL@1eMGD0MGEe05MGE`1=CDd0
0P0n?Sh01@0d=3@0;2`/02`/;00Z:RX0@T920080DU9B00@0I6AT06i^KP1^KVh0VIVI0P2KVi/01@2S
Xj<0];Bd0;no_`2o_kl0ZJVY0080Z:RX00<0WIfM0?ooo`3oool03@3oool000d0oooo00@0EUIF09VI
V@2IVIT0/k>c0P2=SHd01@28R8P0PX:208F5Q@25QHD0VYZJ0080QHF500D0]KFe08B4Q024Q8@0L71`
0:6QX@0208^;R`050:f][@29RHT0RHV906EUI@2ZZZX00P2^[Zh0101VIVH0WinO09nOW`2JVYX208J6
QP050;Rh^01BDU80ZZZZ0:ZZZP2IVIT00P20P8001@1[Jf/0];Bd09^KV`2KVi/0YZJV0080S8b<00D0
G5aL08>3P`3:b/X0b/[:06][J`020;Fe]@05092@T02CTi<0Ti>C06ATI027QhL00P2XZ:P01@20P800
^k^k0;^k^`1^KVh0XZ:R0080MGEe00@0YjNW09nOW`2OWil0SXj>0P1gMgL01@2:RXX0YJFU07UiN@1i
NGT0dM7A0080E5AD00D0UiNG07QhN02o_kl0_kno07QhN00207alO0050:FUY@2@T900T92@0820P031
`L400P1[Jf/01@2PX:00M7Ad07AdM02i^KT0OGem0080Kfm_00D0UiNG0;fm_@2m_Kd0Q8B408n?S`02
092@T00403Ph>03oool0oooo07QhN080<C4a00D0fm_K07IfMP2OWil0WinO08V9R@020;Fe]@050820
P01NGUh0Ti>C09>CT`3Kfm/00P1=CDd01@2VYZH0QHF508F5Q@2[Zj/0Hf=S0080d=3@00D0?Shn0:RX
Z02XZ:P0UiNG0;2`/00209JFUP0506=SH`2l_;`0_;bl06UYJ@2PX:000P2;Rh/0102IVIT0RHV908V9
R@2<S8`309:BTP0409^KV`2EUID0UIFE08n?S`80Fe]K00D0dM7A07QhN01kNg/0Ng]k09VIV@020:6Q
X@0508:2PP2DU9@0U9BD08f=S@2?Shl00P2SXj<01028R8P0Ogmo07moO`2j^[X:0?ooo`0408f=S@2?
Shl0Shn?09nOW`80YJFU00D0X:2P09bLW02SXj<0Xj>S0::RXP0209fMW@0309jNWP2YZJT0ZJVY0080
WinO0P2b/[801@33`l<0`L710<71`@2d];@0ZJVY0080VYZJ00@0SXj>08b<S02<S8`0Xj>S0`2`/;00
102JVYX0RHV908V9R@23Ph<207AdM00506m_K`1cLg<0NWYj07YjNP1aLG400P1^KVh01@1VIVH0MGEe
07emO@1mOGd0QhN70080UiNG00<0Y:BT0:^[Z`2[Zj/00P2[Zj/20:VYZ@050:f][@2YZJT0ZJVY0:VY
Z@2OWil00P2DU9@01023Ph<0Lg=c07=cL`1SHf<205EEE@0505eMG@1fMWH0RXZ:08Z:RP2FUYH00P2O
Wil01@2GUiL0OGem06IVIP1VIVH0HV9R0080L71`00D0QXJ60:2PX02PX:00[Zj^0;Bd]0020:b/[005
0:6QX@2FUYH0UYJF09^KV`2IVIT00P2OWil01@2VYZH0XZ:R0::RXP2NWYh0XJ6Q0080YJFU00@0XZ:R
0:6QX@2QXJ40WinO0P2TY:@01@2SXj<0X:2P0:BTY02TY:@0X:2P0080UiNG00D0Ti>C096AT@2CTi<0
Ti>C09bLW0020:NWY`050:ZZZP2^[Zh0[Zj^0:b/[02SXj<00P2NWYh01@2KVi/0Shn?08n?S`2<S8`0
U9BD0080OGem00D0OWin08V9R@29RHT0P82007inOP0208B4Q00407moO`1gMgL0MgMg07inOP80M7Ad
0P1iNGT208N7Q`0509NGU`2MWId0WIfM09^KV`23Ph<00P1UIFD0101>CTh0ADE504E5A@0e=CD204Q8
B00505IFEP1KFe/0Hf=S06=SH`1dM7@00P1jNWX00`23Ph<0oooo0?ooo`0=0?ooo`003@3oool0101I
FET0VYZJ09ZJVP2a/K4208f=S@0508J6QP20P800S8b<08b<S02LW9`00P21PH401@2/[:`0SXj>08j>
SP1dM7@0UIFE0080UYJF00D0YJFU08Z:RP2:RXX0IFEU0:n_[`020;6a/@0405iNGP2NWYh0WYjN09fM
W@80Ph>300D0^[Zj05ADE02ZZZX0ZZZZ09RHV00207moO`0506YZJP2c/k<0WIfM09fMW@2UYJD00P2=
SHd01@1MGEd0OWin0<k>cP3>c/h0L71`0080ZJVY00D0Vi^K08Z:RP2:RXX0IfMW08V9R@020:VYZ@05
07emO@2o_kl0_kno06a/K02OWil00P1jNWX0102NWYh0ZZZZ0:ZZZP24Q8@207moO`0508F5Q@2TY:@0
OWin07inOP39bLT00P1JFUX01@2GUiL0O7al0:n_[`2_[jl0QXJ60080Ng]k00D0W9bL09FEU@2EUID0
OWin0<O7a`0206QXJ00509jNWP1eMGD0MGEe0;Rh^01nOWh00P1/K6`01@2MWId0^;Rh0;Rh^025QHD0
TI6A0080TY:B00@0<S8b0?ooo`3oool0Ng]k0P0^;Rh01@3Ph>00Lg=c09jNWP2NWYh0RHV90080]KFe
00D0PH6105aLG02EUID0UIFE0=SHf002051@D0050:FUY@28R8P0R8R80:JVYP1RHV800P3MgMd01@0g
=cL0Y:BT0:BTY02HV9P0/K6a0080UIFE00D0HF5Q0<?3``33`l<0GemO0:6QX@0208n?S`0409RHV02=
SHd0SHf=08N7Q`80SHf=00D0VIVI09fMW@2>SXh0SXj>092@T002065QH@050<W9b@1jNWX0OWin07in
OP2IVIT00P2QXJ401@1nOWh0UYJF09JFUP2CTi<0QhN70080ZJVY0`24Q8@00`2d];@0oooo0?ooo`08
0?ooo`0407QhN028R8P0R8R808^;R`80RXZ:00D0TI6A09ZJVP2CTi<0Ti>C08n?S`0209VIV@<0Vi^K
00D0Zj^[0;Jf]P2b/[80/[:b0<C4a0020;bl_0050;Bd]02`/;00YZJV0:JVYP2@T9000P2FUYH01@2A
TI40RHV908V9R@2GUiL0[Jf]00<0`<300P3=cLd01@3Bd]80bl_;0<?3``33`l<0clo?0080cLg=00D0
bLW90<C4a02l_;`0_;bl0:VYZ@020::RXP0509bLW02ATI40TI6A08^;R`2?Shl00P28R8P01@1nOWh0
MgMg07MgM`1dM7@0Rh^;0080ZJVY00@0`/;20=[JfP3Jf]X0mOGe0P3fm_H01@3QhN40alO70;2`/02`
/;00VIVI0080Ogmo00@0QhN708n?S`2CTi<0Ti>C0`2?Shl01@1nOWh0Ogmo07moO`2?Shl0Vi^K0080
XJ6Q00D0YZJV0:>SX`2SXj<0T92@08n?S`0208b<S00508:2PP28R8P0R8R808^;R`25QHD00P22PX80
102@T900Ti>C09>CT`2UYJD20:JVYP050:ZZZP2`/;00[:b/0:b/[02YZJT00P2c/k<01@2_[jl0X:2P
0:6QX@2QXJ40Ti>C0080RHV900D0QhN708>3P`23Ph<0Ng]k07inOP0207YjNP0507MgM`1kNg/0Ng]k
07emO@1dM7@00P22PX801@2ATI40VIVI09VIV@2SXj<0XZ:R0080W9bL00@0UiNG08^;R`2;Rh/0R8R8
0P2CTi<01@2PX:00[jn_0<;2`P32`/80_;bl0080][Jf00D0[:b/0:NWY`2OWil0WinO0:f][@020:j^
[P050;:b/P2WYjL0YjNW0;2`/02YZJT00P2SXj<0102JVYX0U9BD09BDU025QHD?0?ooo`003@3oool0
101NGUh0WYjN09jNWP2YZJT208j>SP0508J6QP1mOGd0TY:B09:BTP2KVi/00P22PX801@2UYJD0Ti>C
09>CT`1jNWX0S8b<0080VYZJ00D0YJFU08n?S`2?Shl0H61P0:b/[0020;Bd]004061PH02KVi/0Vi^K
0:6QX@80PH6100D0^KVi05QHF02XZ:P0Z:RX09BDU00208>3P`0506][J`2_[jl0Y:BT0:BTY02PX:00
0P2?Shl01@1KFe/0Ogmo0=3@d03@d=00MWIf0080WinO00D0XJ6Q08N7Q`27QhL0IVIV08j>SP020:VY
Z@0507UiN@30`<00`<30071`L02JVYX00P21PH40102DU9@0^;Rh0;Rh^01cLg<208b<S0050861P@2P
X:00QHF508F5Q@33`l<00P1OGel01@2DU9@0Ogmo0:ZZZP2ZZZX0RHV90080OGem00D0VYZJ09JFUP2F
UYH0OGem0<[:bP0206=SH`0509fMW@1fMWH0MWIf0;Vi^@1nOWh00P1[Jf/01@2QXJ40]KFe0;Fe]@27
QhL0S8b<0080VYZJ00@0;2`/0?ooo`3oool0PX:20P0/;2`01@3Ogml0M7Ad09^KV`2KVi/0SHf=0080
/K6a00D0Q8B405aLG02JVYX0VYZJ0<_;b`0205aLG00509jNWP2>SXh0SXj>09fMW@1SHf<00P3Shn<0
1@0m?Cd0VIVI09VIV@2JVYX0/K6a0080UYJF00D0H61P0<C4a034a<@0H61P09nOW`0208f=S@0409fM
W@2>SXh0SXj>08F5Q@80RXZ:00D0VIVI0::RXP27QhL0QhN709FEU@0206IVIP050<30`01iNGT0P820
0820P02KVi/00P2TY:@01@1hN7P0UIFE09FEU@2EUID0R8R80080ZJVY00@0Ph>308R8R028R8P0[Jf]
2P3oool0102?Shl0O7al07alO01fMWH207EeM@0506e]K@1OGel0IfMW06MWI`1oOgl00P20P8001@1k
Ng/0KVi^06i^KP1YJFT0De=C00<0ADE50P1GEeL01@1KFe/0FEUI06UYJ@1YJFT0KVi^0080K6a/00D0
Kfm_07alO01lO7`0Ng]k07UiN@0206e]K@0506IVIP1WIfL0IfMW06YZJP1^KVh00P1eMGD0101jNWX0
N7Qh07QhN01kNg/306m_K`0407EeM@1fMWH0MWIf07=cL`80O7al00D0Ph>307moO`24Q8@0Q8B4092@
T00209nOW`050:6QX@2>SXh0LW9b079bLP1HF5P00P15ADD01@0e=CD0?Cdm03dm?@1DE5@0J6QX0080
MgMg00D0SHf=09ZJVP2JVYX0ZZZZ0:2PX0020::RXP0409nOW`2LW9`0W9bL096AT@80Ti>C00D0R8R8
08J6QP2ATI40TI6A09JFUP0209ZJVP80Y:BT0P2JVYX00`2WYjL0Xj>S0:>SX`0209nOW`80XZ:R00@0
SHf=08^;R`2;Rh/0Ph>30P1lO7`01@1ZJVX0IVIV06ATI01TI6@0GEeM0080FEUI00D0J6QX071`L01c
Lg<0Lg=c08J6QP0209BDU00508b<S02CTi<0Ti>C09^KV`2MWId00P2TY:@40;Fe]@040;Jf]P2UYJD0
YJFU09^KV`80Ti>C00D0TY:B09nOW`2ZZZX0ZZZZ0:f][@020<G5a@050=;BdP3EeMD0eMGE0=CDe037
alL00P2c/k<01@2YZJT0Xj>S0:>SX`2/[:`0_[jn0080c<c<00@0a<C40;Fe]@2e]KD0[jn_0P2VYZH2
08>3P`80Rh^;00@0NGUi07=cL`1cLg<0QhN73`3oool000d0oooo00@0GUiN09jNWP2NWYh0ZJVY0P2>
SXh01@26QXH0OGem09:BTP2BTY80Vi^K0080PX:200D0YJFU09>CT`2CTi<0NWYj08b<S00209ZJVP05
0:FUY@2?Shl0Shn?061PH02/[:`00P2d];@0101PH600Vi^K09^KV`2QXJ420861P@050;Vi^@1HF5P0
Z:RX0:RXZ02DU9@00P23Ph<01@1[Jf/0[jn_0:BTY02TY:@0X:2P0080Shn?00D0Fe]K07moO`3@d=00
d=3@07IfMP0209nOW`050:6QX@27QhL0QhN706IVIP2>SXh00P2YZJT01@1iNGT0`<300<30`01`L700
VYZJ0080PH6100@0U9BD0;Rh^02h^;P0Lg=c0P2<S8`01@21PH40X:2P08F5Q@25QHD0`l?30080GemO
00D0U9BD07moO`2ZZZX0ZZZZ08V9R@0207emO@0509ZJVP2FUYH0UYJF07emO@3:b/X00P1SHf<01@2M
WId0MWIf07IfMP2i^KT0OWin0080Jf][00D0XJ6Q0;Fe]@2e]KD0QhN708b<S00209ZJVP0402`/;03o
ool0oooo08:2PP80;2`/00D0gmoO07AdM02KVi/0Vi^K08f=S@020;6a/@0508B4Q01LG5`0VYZJ09ZJ
VP3;bl/00P1LG5`01@2NWYh0SXj>08j>SP2MWId0Hf=S0080hn?S00D0?Cdm09VIV@2IVIT0VYZJ0;6a
/@0209JFUP05061PH034a<@0a<C4061PH02OWil00P2=SHd0102MWId0SXj>08j>SP25QHD208Z:RP05
09VIV@2RXZ80QhN708N7Q`2EUID00P1VIVH01@30`<00NGUi0820P020P800Vi^K0080Y:BT00D0N7Qh
09FEU@2EUID0UIFE08R8R0020:VYZ@0408>3P`28R8P0R8R80:f][@X0oooo00@0Shn?07alO01lO7`0
MWIf0P1eMGD01@1]KFd0GemO06MWI`1WIfL0Ogmo0080P82000D0Ng]k06i^KP1^KVh0JFUY05=CD`03
04E5A@80EeMG00D0Fe]K05UIF@1YJFT0JFUY06i^KP0206a/K00506m_K`1lO7`0O7al07]kN`1iNGT0
0P1]KFd01@1VIVH0IfMW06MWI`1ZJVX0KVi^0080MGEe00@0NWYj07QhN01hN7P0Ng]k0`1_Kfl0101e
MGD0MWIf07IfMP1cLg<207alO00508>3P`1oOgl0Q8B408B4Q02@T9000P2OWil01@2QXJ40SXj>079b
LP1bLW80F5QH0080ADE500D0=CDe03dm?@0m?Cd0E5AD06QXJ00207MgM`0508f=S@2JVYX0VYZJ0:ZZ
ZP2PX:000P2RXZ80102OWil0W9bL09bLW02ATI4209>CT`0508R8R026QXH0TI6A096AT@2FUYH00P2J
VYX20:BTY080VYZJ00<0YjNW0:>SX`2SXj<00P2OWil20::RXP0408f=S@2;Rh/0Rh^;08>3P`80O7al
00D0JVYZ06IVIP1TI6@0I6AT05eMG@0205UIF@0506QXJ01`L700Lg=c07=cL`26QXH00P2DU9@01@2<
S8`0Ti>C09>CT`2KVi/0WIfM0080Y:BT102e]KD0102f][H0YJFU0:FUY@2KVi/209>CT`0509:BTP2O
Wil0ZZZZ0:ZZZP2][Jd00P35aLD01@3Bd]80eMGE0=GEe@3De=@0alO70080/k>c00D0ZJVY0:>SX`2S
Xj<0[:b/0;jn_P020<c<c0040<C4a02e]KD0]KFe0:n_[`80YZJV0P23Ph<208^;R`0407UiN@1cLg<0
Lg=c08N7Q`l0oooo000=0?ooo`04061PH02TY:@0Y:BT09fMW@80Ti>C00D0Q8B407emO@2FUYH0UYJF
09VIV@0208N7Q`0509fMW@2GUiL0UiNG07inOP28R8P00P2NWYh01@2KVi/0U9BD09BDU01TI6@0Xj>S
0080^k^k00@0Fe]K09fMW@2MWId0XZ:R0P21PH401@2g]kL0FUYJ0:VYZ@2YZJT0TI6A0080Ph>300D0
K6a/0;6a/@2VYZH0YZJV09^KV`02096AT@0505]KF`1mOGd0dm?C0=?Cd`1hN7P00P2CTi<01@2XZ:P0
QhN708N7Q`1QHF40Ti>C0080[:b/00D0M7Ad0;no_`2o_kl0M7Ad09BDU00208^;R`0408j>SP31`L40
`L7106=SH`80UIFE00D0PH6109fMW@26QXH0QXJ60<;2`P02065QH@0509>CT`20P800ZZZZ0:ZZZP23
Ph<00P24Q8@309RHV00507alO03<c<`0HV9R069RHP2NWYh00P1eMGD01@2g]kL0PX:206UYJ@1YJFT0
YZJV0080/;2`00D0RXZ:08R8R02NWYh0WYjN02TY:@020?ooo`0508>3P`0c<c<0<c<c0=?Cd`1fMWH0
0P2HV9P01@2FUYH0Z:RX0:RXZ02:RXX0FEUI0080WinO00@0`<3006UYJ@1YJFT0Ti>C0P2GUiL01@2D
U9@0IVIV0>KViP3Vi^H0@D510080TI6A00D0W9bL0;>c/`2FUYH0UYJF05mOG`020<O7a`05061PH02L
W9`0SXj>08j>SP2NWYh00P2CTi<01@20P800RHV908V9R@2LW9`0Xj>S0080Q8B400D0VYZJ06=SH`1S
Hf<0_Kfm07MgM`0208F5Q@0409jNWP2OWil0WinO07EeM@80U9BD00D0WIfM08F5Q@2XZ:P0Z:RX08F5
Q@0208N7Q`030:f][@3oool0oooo00P0oooo00@0mOGe0?knoP3no_h0i>CT0P3Ogml01@3Bd]80dm?C
0<K6aP36a/H0X:2P0080QhN700D0RXZ:0:2PX02PX:00]kNg0>GUi@020?knoP050>c/k035aLD0aLG5
0:JVYP2KVi/00P29RHT0102HV9P0VYZJ09ZJVP2CTi<208N7Q`0508J6QP21PH40OWin07inOP2:RXX0
0P2<S8`01@2@T900S8b<09^KV`2KVi/0WIfM0080WinO00D0X:2P0;Rh^02b/[80/[:b0:j^[P020:b/
[0050:n_[`2TY:@0Y:BT0:FUY@2XZ:P00P2ZZZX01@2PX:00U9BD09BDU02IVIT0Xj>S0080^;Rh00@0
a/K60=SHf03Hf=P0g=cL0P3Fe]H01@38b<P0aLG50;bl_02l_;`0[jn_0080[:b/00D0XZ:R0:VYZ@2V
YZH0YZJV0:VYZ@020:^[Z`030:j^[P2SXj<0Xj>S0080Vi^K0P2CTi<01@2?Shl0SXj>08j>SP2FUYH0
U9BD0080Ti>C00D0S8b<08n?S`2?Shl0UiNG09>CT`0208b<S00409VIV@2YZJT0ZJVY0:FUY@80/K6a
0P3AdM420<K6aP050=7Ad@3Lg=`0g=cL0<[:bP35aLD00P2i^KT0102^[Zh0VIVI09VIV@2QXJ420:BT
Y080X:2P0P2WYjL00`2SXj<0XZ:R0::RXP020;Bd]080/;2`00D0ZJVY0:RXZ02XZ:P0VIVI08R8R002
08J6QP0408b<S01mOGd0OGem07AdM080K6a/00D0G5aL05YJFP1WIfL0IfMW07AdM0020820P080QXJ6
0P2?Shl0102DU9@0YJFU0:FUY@2NWYh209nOW`050::RXP2CTi<0TI6A096AT@35aLD00P3Cdm<00`3K
fm/0oooo0?ooo`0=0?ooo`003@3oool0101RHV80ZJVY0:VYZ@2DU9@209RHV0050861P@23Ph<0UIFE
09FEU@2FUYH00P2:RXX01@2GUiL0Vi^K09^KV`23Ph<0Q8B40080X:2P00D0U9BD09RHV02HV9P0J6QX
09jNWP020;bl_00405eMG@2KVi/0Vi^K0:FUY@80OWin00D0^KVi05]KF`2WYjL0YjNW096AT@020861
P@05071`L02a/K40YZJV0:JVYP2GUiL00P2BTY801@1JFUX0OWin0=CDe03De=@0N7Qh0080Shn?00D0
[:b/08N7Q`27QhL0HF5Q09:BTP020;2`/00406e]K@32`/80`/;207IfMP<0T92@00@0QXJ60<W9b@39
bLT0Fe]K0P2KVi/01@1oOgl0WYjN08F5Q@25QHD0`/;20080Hf=S00D0Shn?08N7Q`2[Zj/0Zj^[07Qh
N00208f=S@0509BDU02IVIT0VIVI07alO03:b/X00P1UIFD01@2MWId0MWIf07IfMP2b/[80Ph>30080
JFUY00D0ZJVY0:^[Z`2[Zj/0T92@08:2PP020:6QX@0402LW9`3oool0oooo08:2PP80>SXj00D0a<C4
07moO`2EUID0UIFE09fMW@020:2PX00508b<S01KFe/0XZ:R0::RXP2i^KT00P1aLG401@2;Rh/0X:2P
0:2PX02;Rh/0JVYZ0080i>CT00D0BTY:08J6QP26QXH0WinO0;Fe]@0209BDU00505iNGP34a<@0a<C4
06IVIP2HV9P00P2?Shl0102QXJ40TI6A096AT@1oOgl208b<S005096AT@2][Jd0Ogmo07moO`2KVi/0
0P1UIFD01@2l_;`0MGEe08b<S02<S8`0WYjN0080XJ6Q00D0JVYZ09BDU02DU9@0XJ6Q08Z:RP020:6Q
X@0408Z:RP2;Rh/0Rh^;0:FUY@X0oooo00@0Hf=S05aLG01LG5`0LG5a0P1lO7`01@2?Shl0U9BD0:>S
X`2SXj<0a<C40080dm?C00D0b<S80;Rh^02h^;P0SHf=05QHF00204i>CP0505YJFP1hN7P0N7Qh0:6Q
X@2c/k<00P2][Jd309bLW0050:NWY`2g]kL0]kNg0;fm_@30`<000P2n_[h01@2i^KT0YZJV0:JVYP2I
VIT0XZ:R0080Shn?00D0MWIf07MgM`1gMgL0MgMg069RHP02075aL@040820P022PX80PX:207alO080
QXJ600D0Ph>308^;R`27QhL0QhN709BDU00209nOW`80XZ:R0P2[Zj/0102YZJT0Vi^K09^KV`2DU9@2
08n?S`050820P01eMGD0NWYj07YjNP1hN7P00P1aLG401@1fMWH0Ogmo0820P020P800Shn?0080Vi^K
00D0YJFU0:BTY02TY:@0ZJVY09RHV00209>CT`0508j>SP2@T900T92@08n?S`2FUYH00P2QXJ401@2T
Y:@0VYZJ09ZJVP2;Rh/0SXj>0080R8R800@0OWin08F5Q@25QHD0QhN70P1oOgl01@1/K6`0KFe]06UY
J@1YJFT0J6QX0080Hf=S00D0R8R809NGU`2`/;00/;2`0;bl_0020=3@d0050<?3``2m_Kd0_Kfm0::R
XP2NWYh00P29RHT01@1fMWH0Kfm_06m_K`1YJFT0HV9R0080JVYZ00D0L71`07]kN`1kNg/0SXj>09JF
UP0209RHV004096AT@2IVIT0VIVI09>CT`80TY:B00D0T92@09VIV@22PX80PX:208^;R`0209:BTP05
09FEU@2DU9@0UiNG09NGU`2DU9@00P2BTY801@2NWYh0Y:BT0:BTY02UYJD0/;2`0080YZJV00@0RXZ:
0820P020P800O7al3`3oool000d0oooo00@0HV9R0:VYZ@2YZJT0U9BD0P2HV9P01@21PH40Ph>309FE
U@2EUID0UYJF0080RXZ:00D0UiNG09^KV`2KVi/0Ph>308B4Q0020:2PX00509BDU02HV9P0V9RH06QX
J02NWYh00P2l_;`0101MGEd0Vi^K09^KV`2UYJD207inOP050;Vi^@1KFe/0YjNW0:NWY`2ATI400P21
PH401@1`L700/K6a0:JVYP2VYZH0UiNG0080TY:B00D0FUYJ07inOP3De=@0e=CD07QhN00208n?S`05
0:b/[027QhL0QhN7065QH@2BTY800P2`/;00101]KFd0`/;20<;2`P1fMWH3092@T00408J6QP39bLT0
bLW905]KF`80Vi^K00D0Ogmo09jNWP25QHD0QHF50<;2`P0206=SH`0508n?S`27QhL0Zj^[0:^[Z`1h
N7P00P2=SHd01@2DU9@0VIVI09VIV@1lO7`0b/[:0080IFEU00D0WIfM07IfMP1fMWH0/[:b08>3P`02
06UYJ@050:VYZ@2[Zj/0Zj^[092@T022PX800P2QXJ40100W9bL0oooo0?ooo`22PX8203Xj>P050<C4
a01oOgl0UIFE09FEU@2MWId00P2PX:001@2<S8`0Fe]K0::RXP2RXZ80^KVi0080LG5a00D0Rh^;0:2P
X02PX:00Rh^;06YZJP020>CTi00504Y:BP26QXH0QXJ609nOW`2e]KD00P2DU9@01@1NGUh0a<C40<C4
a01VIVH0V9RH0080Shn?00@0XJ6Q096AT@2ATI40Ogmo0P2<S8`01@2ATI40[Jf]07moO`1oOgl0Vi^K
0080IFEU00D0_;bl07EeM@2<S8`0S8b<09jNWP020:6QX@0506YZJP2DU9@0U9BD0:6QX@2:RXX00P2Q
XJ40102:RXX0Rh^;08^;R`2UYJD:0?ooo`0406=SH`1LG5`0G5aL075aL@80O7al00D0Shn?09BDU02S
Xj<0Xj>S0<C4a0020=?Cd`050<S8b02h^;P0^;Rh08f=S@1HF5P00P1>CTh01@1JFUX0N7Qh07QhN02Q
XJ40/k>c0080[Jf]0`2LW9`01@2WYjL0]kNg0;Ng]`2m_Kd0`<300080_[jn00D0^KVi0:JVYP2VYZH0
VIVI0::RXP0208n?S`0507IfMP1gMgL0MgMg07MgM`1RHV800P1aLG401020P800PX:208:2PP1lO7`2
08J6QP0508>3P`2;Rh/0QhN708N7Q`2DU9@00P2OWil20::RXP80Zj^[00@0ZJVY09^KV`2KVi/0U9BD
0P2?Shl01@20P800MGEe07YjNP1jNWX0N7Qh0080LG5a00D0MWIf07moO`20P800P82008n?S`0209^K
V`050:FUY@2TY:@0Y:BT0:VYZ@2HV9P00P2CTi<01@2>SXh0T92@092@T02?Shl0UYJF0080XJ6Q00D0
Y:BT09ZJVP2JVYX0Rh^;08j>SP0208R8R00407inOP25QHD0QHF508N7Q`80Ogmo00D0K6a/06e]K@1Y
JFT0JFUY06QXJ00206=SH`0508R8R02GUiL0/;2`0;2`/02l_;`00P3@d=001@33`l<0_Kfm0;fm_@2R
XZ80WYjN0080RHV900D0MWIf06m_K`1_Kfl0JFUY069RHP0206YZJP05071`L01kNg/0Ng]k08j>SP2F
UYH00P2HV9P0102ATI40VIVI09VIV@2CTi<209:BTP05092@T02IVIT0PX:208:2PP2;Rh/00P2BTY80
1@2EUID0U9BD09NGU`2GUiL0U9BD0080TY:B00D0WYjN0:BTY02TY:@0YJFU0;2`/0020:JVYP0408Z:
RP20P800P82007alO0l0oooo000=0?ooo`0405iNGP2/[:`0[:b/08j>SP80WIfM00D0OWin08F5Q@2E
UID0UIFE09NGU`0208R8R00509:BTP2SXj<0Xj>S08J6QP23Ph<00P2MWId01@2ATI40W9bL09bLW01S
Hf<0WinO0080_[jn00@0H61P09NGU`2GUiL0Z:RX0P1lO7`01@2g]kL0GUiN0:>SX`2SXj<0UIFE0080
OWin00D0Lg=c0;2`/02TY:@0Y:BT09ZJVP0209:BTP0505IFEP24Q8@0dm?C0=?Cd`1jNWX00P28R8P0
1@2^[Zh0RHV908V9R@1QHF40TY:B0080/;2`00D0K6a/0<?3``33`l<0N7Qh08j>SP0209:BTP0408B4
Q039bLT0bLW905iNGP80VIVI00D0PH6109ZJVP25QHD0QHF50<;2`P0206EUI@0508b<S028R8P0/K6a
0;6a/@1`L7000P2ATI401@2FUYH0U9BD09BDU022PX80`L710080K6a/00D0W9bL07IfMP1fMWH0/K6a
08>3P`0206UYJ@050:^[Z`2VYZH0YZJV09FEU@21PH400P2PX:00100U9BD0oooo0?ooo`27QhL20410
@0050;6a/@2;Rh/0U9BD09BDU02NWYh00P2KVi/01@2?Shl0Fe]K0::RXP2RXZ80]KFe0080MWIf00D0
QXJ60:JVYP2VYZH0QXJ606YZJP020>?Sh`0505ADE01nOWh0OWin09jNWP2i^KT00P2CTi<01@1NGUh0
_;bl0;bl_01^KVh0V9RH0080Rh^;00@0YjNW096AT@2ATI40OGem0P2?Shl01@26QXH0]kNg07inOP1n
OWh0WinO0080HV9R00D0^k^k075aL@2@T900T92@0::RXP0209fMW@0506IVIP2BTY80TY:B0:>SX`2?
Shl00P2MWId0102:RXX0T92@092@T02TY:@:0?ooo`0407emO@24Q8@0Q8B408V9R@80QhN700D0OWin
07MgM`1bLW80LW9b06ATI00206=SH`0506][J`25QHD0QHF50:NWY`2o_kl00P2f][H01@2d];@0X:2P
0:2PX027QhL0NGUi0080T92@00@0V9RH09NGU`2GUiL0UIFE0P2CTi<01@27QhL0RXZ:09:BTP2BTY80
TI6A0080Y:BT00D0/K6a0:n_[`2e]KD0]KFe0<[:bP030<G5a@040<c<c02k^k/0^k^k0:2PX080UIFE
00D0QhN707IfMP1fMWH0N7Qh07emO@0208B4Q00508>3P`1mOGd0OGem075aL@1WIfL00P1ADE40101F
EUH0G5aL05aLG01VIVH206m_K`0507inOP29RHT0Shn?08n?S`2LW9`00P2YZJT01@2`/;00YZJV0:JV
YP2VYZH0UIFE0080QXJ600D0Ogmo07]kN`1kNg/0Ng]k092@T00209RHV00509bLW02ZZZX0ZZZZ0;2`
/02ZZZX00P2YZJT01@2_[jl0^[Zj0;Zj^P2l_;`0^[Zj0080b<S800@0`L710;:b/P2b/[80/K6a0P2d
];@01@2YZJT0/;2`0;2`/02`/;00ZZZZ0080W9bL00D0NGUi06UYJ@1KFe/0Fe]K04a<C00204U9B@05
065QH@1]KFd0KFe]09>CT`2KVi/00P2/[:`01@2f][H0^KVi0;Vi^@2XZ:P0]kNg0080];Bd00@0/;2`
09jNWP2NWYh0V9RH0`2FUYH0102IVIT0UIFE09FEU@2IVIT209RHV0050:JVYP2b/[80`/;20<;2`P2h
^;P00P2_[jl00`2WYjL0WinO09NGU`0209NGU`80VIVI00D0V9RH09JFUP2FUYH0YZJV0;6a/@020:f]
[@040:2PX02FUYH0UYJF08Z:RPl0oooo000=0?ooo`04069RHP2ZZZX0ZZZZ08j>SP80W9bL00D0PH61
08F5Q@2BTY80TY:B09NGU`0208V9R@0509:BTP2RXZ80XZ:R08R8R020P8000P2NWYh01@2@T900X:2P
0:2PX01QHF40Vi^K0080_[jn00@0I6AT09RHV02HV9P0YZJV0P1mOGd01@2i^KT0GEeM09jNWP2NWYh0
W9bL0080OGem00<0Lg=c0:n_[`2PX:000P2PX:0208n?S`0505ADE029RHT0c/k>0<k>cP1kNg/00P2;
Rh/01@2[Zj/0S8b<08b<S01OGel0Ti>C0080/;2`00D0KFe]0<?3``33`l<0MWIf09>CT`0208V9R@04
08j>SP33`l<0`l?3061PH080UYJF00D0Ph>309bLW022PX80PX:20<G5a@0206ATI00508V9R@2:RXX0
][Jf0;Jf]P1YJFT00P2EUID01@2IVIT0Shn?08n?S`2:RXX0];Bd0080N7Qh00D0UIFE07UiN@1iNGT0
]KFe07alO00206m_K`050:RXZ02TY:@0Y:BT09bLW01oOgl00P2MWId0100Z:RX0oooo0?ooo`26QXH2
04M7A`050::RXP2EUID0UYJF09JFUP2RXZ800P2ATI401@2CTi<0G5aL0:JVYP2VYZH0/K6a0080N7Qh
00D0Ogmo0:n_[`2_[jl0Ph>306a/K0020>3Ph00505EEE@1jNWX0NWYj0::RXP2o_kl00P2<S8`01@1Q
HF40/k>c0;>c/`1iNGT0UiNG0080QhN700@0YZJV096AT@2ATI40P8200P2EUID01@1fMWH0`L710820
P020P800Vi^K0080IVIV00D0^KVi06][J`2HV9P0V9RH0::RXP0209RHV00506QXJ02=SHd0SHf=0:RX
Z02?Shl00P2HV9P0102BTY80Rh^;08^;R`2SXj<:0?ooo`0409FEU@2@T900T92@08F5Q@80QXJ600D0
VIVI0:b/[02WYjL0YjNW0:RXZ0030:NWY`80UIFE00D0SHf=09FEU@2IVIT0VIVI09^KV`020:BTY005
0:NWY`2b/[80Zj^[0:^[Z`2_[jl00P2/[:`0102a/K40Xj>S0:>SX`2PX:0309FEU@0509JFUP2DU9@0
U9BD09BDU02CTi<00P2@T9001@29RHT0Q8B408B4Q01kNg/0KVi^0080NGUi00@0S8b<09bLW02LW9`0
alO70P3Zj^X01@3_knl0g]kN0=CDe03De=@0][Jf0080/;2`00D0/K6a0<K6aP38b<P0b<S80<k>cP02
0<W9b@050<71`@2k^k/0^k^k0<?3``2i^KT00P2][Jd01@2JVYX0QHF508F5Q@1dM7@0LW9b0080M7Ad
00@0Q8B409:BTP2BTY80VYZJ0P2RXZ801@2WYjL0VYZJ09FEU@2EUID0Ti>C0080Ph>300D0L71`07=c
L`1[Jf/0Jf][05UIF@0205mOG`0506EUI@1ZJVX0KVi^06i^KP29RHT00P26QXH308N7Q`0509^KV`2H
V9P0/;2`0;2`/02i^KT00P39bLT01@33`l<0aLG50;Zj^P2j^[X0^k^k0080[Jf]00D0YjNW09VIV@2I
VIT0S8b<08^;R`020861P@0507emO@1nOWh0OWin08f=S@2;Rh/00P2@T9001@2IVIT0WinO09nOW`2K
Vi/0V9RH0080VIVI00@0X:2P0;Ng]`2g]kL0^k^k0P2l_;`01@32`/80YJFU08N7Q`27QhL0OWin0080
Lg=c00D0KVi^07IfMP26QXH0QXJ609NGU`0209^KV`0508V9R@28R8P0R8R807IfMP1PH6000P1^KVh0
1027QhL0U9BD09BDU02>SXh?0?ooo`003@3oool0101RHV80ZZZZ0:ZZZP2>SXh209bLW0050861P@25
QHD0TY:B09:BTP2GUiL00P29RHT01@2BTY80XZ:R0::RXP28R8P0P8200080WYjN00D0T92@0:2PX02P
X:00HF5Q09^KV`020;jn_P0406ATI02HV9P0V9RH0:JVYP80OGem00D0^KVi05eMG@2NWYh0WYjN09bL
W00207emO@0307=cL`2_[jl0X:2P0080X:2P0P2?Shl01@1DE5@0RHV90<k>cP3>c/h0Ng]k0080Rh^;
00D0Zj^[08b<S02<S8`0GemO09>CT`020;2`/00506e]K@33`l<0`l?307IfMP2CTi<00P29RHT0102>
SXh0`l?30<?3``1PH60209JFUP0508>3P`2LW9`0PX:208:2PP35aLD00P1TI6@01@29RHT0RXZ:0;Jf
]P2f][H0JFUY0080UIFE00D0VIVI08n?S`2?Shl0RXZ:0;Bd]00207QhN00509FEU@1iNGT0NGUi0;Fe
]@1lO7`00P1_Kfl01@2XZ:P0Y:BT0:BTY02LW9`0Ogmo0080WIfM00@0:RXZ0?ooo`3oool0QXJ60P17
AdL01@2RXZ80UIFE09JFUP2FUYH0XZ:R0080TI6A00D0Ti>C05aLG02VYZH0YZJV0;6a/@0207QhN005
07moO`2_[jl0[jn_08>3P`1/K6`00P3Ph>001@1EEED0NWYj07YjNP2RXZ80_kno0080S8b<00D0HF5Q
0;>c/`2c/k<0NGUi09NGU`0208N7Q`040:JVYP2ATI40TI6A0820P080UIFE00D0MWIf0<71`@20P800
P82009^KV`0206IVIP050;Vi^@1[Jf/0V9RH09RHV02RXZ800P2HV9P01@1XJ6P0SHf=08f=S@2XZ:P0
Shn?0080V9RH00@0TY:B08^;R`2;Rh/0Xj>S2P3oool0102EUID0T92@092@T025QHD208J6QP0509VI
V@2/[:`0YjNW0:NWY`2XZ:P00`2WYjL209FEU@0508f=S@2EUID0VIVI09VIV@2KVi/00P2TY:@01@2W
YjL0/[:b0:^[Z`2[Zj/0[jn_0080[:b/00@0/K6a0:>SX`2SXj<0X:2P0`2EUID01@2FUYH0U9BD09BD
U02DU9@0Ti>C0080T92@00D0RHV908B4Q024Q8@0Ng]k06i^KP0207UiN@0408b<S02LW9`0W9bL0<O7
a`80j^[Z00D0kno_0=kNgP3De=@0e=CD0;Jf]P020;2`/0050;6a/@36a/H0b<S80<S8b03>c/h00P39
bLT01@31`L40^k^k0;^k^`33`l<0^KVi0080[Jf]00D0VYZJ08F5Q@25QHD0M7Ad079bLP0207AdM004
08B4Q02BTY80TY:B09ZJVP80XZ:R00D0YjNW09ZJVP2EUID0UIFE09>CT`0208>3P`05071`L01cLg<0
Jf][06][J`1IFET00P1OGel01@1UIFD0JVYZ06i^KP1^KVh0RHV90080QXJ60`27QhL01@2KVi/0V9RH
0;2`/02`/;00^KVi0080bLW900D0`l?30<G5a@2j^[X0^[Zj0;^k^`020:f][@050:NWY`2IVIT0VIVI
08b<S02;Rh/00P21PH401@1mOGd0OWin07inOP2=SHd0Rh^;0080T92@00D0VIVI09nOW`2OWil0Vi^K
09RHV00209VIV@040:2PX02g]kL0]kNg0;^k^`80_;bl00D0`/;20:FUY@27QhL0QhN707inOP0207=c
L`0506i^KP1fMWH0QXJ608J6QP2GUiL00P2KVi/01@29RHT0R8R808R8R01fMWH0H61P0080KVi^00@0
QhN709BDU02DU9@0SXj>3`3oool000d0oooo00@0J6QX0:NWY`2WYjL0Ti>C0P2IVIT208>3P`80T92@
00@0Vi^K08N7Q`27QhL0T92@0P2UYJD01@29RHT0P8200:2PX02PX:00QXJ60080YZJV00D0I6AT09RH
V02m_Kd0_Kfm06EUI@0209ZJVP050:FUY@1mOGd0OGem0;Ng]`1LG5`00P2LW9`01@2TY:@0NGUi07Ui
N@1dM7@0/;2`0080VIVI00D0YjNW092@T02@T900E5AD08N7Q`020<c<c00407alO02?Shl0Shn?0:JV
YP80SHf=00D0HV9R092@T02_[jl0[jn_071`L0020<C4a005075aL@2GUiL0Ph>308>3P`2HV9P00P2j
^[X01@1UIFD0TI6A096AT@24Q8@0WinO0080P82000D0alO7061PH01PH600RHV908f=S@020;Vi^@04
061PH02KVi/0Vi^K09RHV080RXZ:00D0Ti>C0:JVYP25QHD0QHF508b<S00207emO@050;Zj^P1dM7@0
M7Ad07AdM02RXZ800P2UYJD01@2QXJ40OWin09VIV@2IVIT0:b/[0080oooo00D0Q8B404Y:BP1:BTX0
VIVI09^KV`0209VIV@050:>SX`28R8P0R8R809JFUP1KFe/00P2TY:@0102k^k/0LG5a075aL@1oOgl2
0:n_[`0508J6QP1bLW80f=SH0=SHf01>CTh00P20P8001@2TY:@0aLG508:2PP22PX80IVIV0080ZZZZ
00D0PX:209>CT`2=SHd0SHf=0::RXP02092@T00508:2PP2GUiL0UiNG06m_K`34a<@00P27QhL01@2@
T900K6a/06a/K02i^KT0IfMW0080XJ6Q00@0WYjN09>CT`2CTi<0KFe]0P28R8P01@2_[jl0Rh^;09NG
U`2GUiL0UIFE0080RHV900<0X:2P0?ooo`3oool0203oool0102JVYX0YZJV0:JVYP2d];@20:n_[`05
0:NWY`2KVi/0V9RH09RHV02ATI400P2?Shl01@27QhL0MgMg07MgM`1cLg<0KFe]0080NWYj00D0PX:2
08b<S02<S8`0WIfM09^KV`0209FEU@0409>CT`2PX:00X:2P09NGU`80VYZJ0P2@T90208B4Q0050820
P01kNg/0Ng]k075aL@1]KFd00`1/K6`207IfMP05092@T02SXj<0YjNW0:NWY`2XZ:P00P2OWil01@1o
Ogl0Hf=S06=SH`18B4P0@d=30080@T9200D0G5aL06MWI`1WIfL0KVi^05mOG`0204Q8B00403Ti>@0b
<S80<S8b04I6AP80DE5A00D0Jf][07IfMP23Ph<0Ph>309BDU00209^KV`050:6QX@2UYJD0Y:BT0:BT
Y02GUiL00P2EUID01@2HV9P0UiNG09NGU`2JVYX0VIVI0080WYjN00@0Vi^K0:>SX`2SXj<0Zj^[0`2Z
ZZX01@2[Zj/0WinO09nOW`2JVYX0UiNG0080SXj>00@0QhN708^;R`2;Rh/0SXj>0`2;Rh/00`28R8P0
OGem07emO@0307IfMP050861P@27QhL0Shn?08n?S`2HV9P00P2OWil309^KV`0509jNWP2CTi<0X:2P
0:2PX02XZ:P00P2b/[801@2g]kL0alO70;no_`2o_kl0_Kfm0080a<C400D0_kno0:f][@2KVi/0Vi^K
08>3P`0205eMG@0505MGE`1CDe<0De=C04a<C01SHf<00P2;Rh/01@2OWil0^k^k0;^k^`3;bl/0b<S8
0080YZJV00@0Shn?07moO`1oOgl0V9RH0P2FUYH0102WYjL0/;2`0:6QX@2QXJ4308F5Q@0308f=S@3o
ool0oooo00d0oooo000=0?ooo`0406e]K@2NWYh0WYjN0:2PX080Shn?00D0Q8B408F5Q@2>SXh0SXj>
09nOW`0207moO`0509JFUP2RXZ80XZ:R08b<S01mOGd00P2QXJ401@23Ph<0[Jf]0:f][@1QHF40UiNG
0080^KVi00@0JFUY09^KV`2KVi/0YjNW0P1hN7P01@2g]kL0G5aL09VIV@2IVIT0[Zj^00<0M7Ad00@0
/;2`09>CT`2CTi<0[Zj^0P2?Shl01@1CDe<0QXJ60<[:bP3:b/X0NGUi0080WIfM00D0VYZJ096AT@2A
TI40IVIV08Z:RP020:j^[P0507=cL`36a/H0a/K606i^KP2KVi/00P1jNWX0102SXj<0[jn_0:n_[`1`
L70208b<S00508F5Q@2PX:00OWin07inOP3:b/X00P1MGEd01@24Q8@0TI6A0;no_`2o_kl0FUYJ0080
WIfM00D0VIVI08J6QP26QXH0WIfM09NGU`0209:BTP0508:2PP24Q8@0Q8B40;jn_P1UIFD00P22PX80
1@2HV9P0Xj>S0:>SX`2YZJT0O7al0080VIVI00@0;Bd]0?ooo`3oool0R8R80P13@d<01@2MWId0W9bL
09nOW`2OWil0XZ:R0080P82000D0UYJF05iNGP2MWId0WIfM0<S8b00206EUI@0508R8R02SXj<0Xj>S
096AT@1jNWX00P37alL01@1>CTh0Q8B408B4Q02XZ:P0b<S80080NWYj00D0IVIV0:^[Z`2[Zj/0QhN7
08f=S@0209:BTP0409ZJVP2FUYH0UYJF08B4Q080V9RH00D0IfMW0<O7a`2<S8`0S8b<08B4Q00207Ui
N@050;Fe]@1SHf<0ZZZZ0:ZZZP2KVi/00P2=SHd01@1aLG40Q8B408B4Q02d];@0R8R80080UIFE00@0
UiNG08f=S@2=SHd0Vi^K2P3oool0102][Jd0Vi^K09^KV`2CTi<209NGU`05096AT@27QhL0SXj>08j>
SP2EUID00P2FUYH01@2SXj<0/[:b0;:b/P2d];@0ZZZZ0080UIFE00D0Rh^;08J6QP26QXH0MWIf06i^
KP0207EeM@0406e]K@1JFUX0FUYJ05mOG`80K6a/00D0OGem08b<S02QXJ40XJ6Q0:ZZZP020:n_[`04
0;>c/`2_[jl0/;2`0;2`/0<0][Jf00D0YZJV09fMW@2GUiL0UiNG08j>SP0208b<S00509ZJVP2[Zj/0
Zj^[0<?3``3GemL00P3YjNT01@3QhN40i^KV0>KViP3MgMd0hn?S00H0oooo0P3_knl01@2h^;P0[Jf]
0:2PX02PX:00Vi^K0080XJ6Q00D0WIfM09BDU02;Rh/0Rh^;08V9R@0308>3P`80QHF500D0QXJ608n?
S`29RHT0RHV9096AT@0208Z:RP0509:BTP2CTi<0UiNG09NGU`2LW9`00P2XZ:P01@2SXj<0YZJV0:n_
[`2_[jl0YZJV0080WYjN00D0UIFE08N7Q`27QhL0NGUi07EeM@0207=cL`0307MgM`1oOgl0Ogmo0080
Ph>30P26QXH01023Ph<0Ng]k07]kN`1jNWX208V9R@0509NGU`2LW9`0U9BD09BDU02?Shl00P1kNg/0
1@1UIFD0Cdm?05ADE01DE5@0FEUI0080FUYJ00D0Lg=c09:BTP2WYjL0YjNW0;Rh^0020<O7a`050<30
`033`l<0`l?30<o?c`2o_kl00P2d];@01@2ZZZX0UIFE09FEU@27QhL0T92@0080WIfM00@0WinO0:NW
Y`2WYjL0TY:B0P2ATI401@26QXH0Shn?09nOW`2OWil0/;2`0080[jn_00<0/;2`0?ooo`3oool03@3o
ool000d0oooo00@0Lg=c09^KV`2KVi/0Vi^K0P2BTY801@26QXH0PX:2096AT@2ATI40WinO0080NWYj
00D0W9bL09^KV`2KVi/0SXj>0820P0020:BTY00507UiN@2g]kL0]kNg05]KF`2KVi/00P2f][H0101V
IVH0XZ:R0::RXP2TY:@207QhN0050;Bd]01MGEd0V9RH09RHV02d];@00P1`L7001@1hN7P0ZZZZ08n?
S`2?Shl0^;Rh0080S8b<00D0De=C08>3P`3<c<`0c<c<07AdM0020:f][@0508V9R@2FUYH0UYJF06MW
I`27QhL00P2/[:`01@1kNg/0`<300<30`01/K6`0WYjN0080M7Ad00@0[:b/0:NWY`2WYjL0MgMg0P29
RHT01@27QhL0WinO07]kN`1kNg/0dM7A0080EeMG00D0QHF5096AT@34a<@0a<C405MGE`0209RHV005
0:2PX021PH40PH610:JVYP2:RXX00P2KVi/01@1kNg/0SHf=08f=S@31`L40EeMG0080TI6A00D0Rh^;
0:>SX`2SXj<0/k>c07EeM@0209^KV`0402l_;`3oool0oooo08Z:RP80@d=300D0V9RH0:2PX02QXJ40
XJ6Q0:>SX`0207]kN`0509JFUP1TI6@0T92@092@T03De=@00P1NGUh01@2ATI40UIFE09FEU@2MWId0
Ph>30080[Jf]00D0Fe]K08J6QP26QXH0YjNW0<W9b@0207AdM00506QXJ02b/[80/[:b08F5Q@2=SHd0
0P2ATI40102DU9@0W9bL09bLW023Ph<209VIV@0506EUI@36a/H0TY:B09:BTP1mOGd00P21PH401@2d
];@0G5aL0:j^[P2^[Zh0Vi^K0080QhN700D0MWIf08R8R028R8P0]KFe0820P00209JFUP0409ZJVP2:
RXX0RXZ:09bLW0X0oooo00@0JVYZ07=cL`1cLg<0OWin0P25QHD01@2=SHd0W9bL0:BTY02TY:@0Z:RX
0080ZZZZ00D0XJ6Q09nOW`2OWil0V9RH09BDU00209^KV`0509RHV02CTi<0Ti>C09FEU@2KVi/00P2A
TI40102IVIT0ZJVY0:VYZ@2RXZ8309NGU`0408^;R`1eMGD0MGEe07MgM`80NWYj00@0Ph>309>CT`2M
WId0WIfM0`2NWYh01@2MWId0W9bL0:6QX@2QXJ40YJFU0080YZJV00D0Xj>S0:BTY02TY:@0VYZJ08j>
SP020820P00508B4Q01^KVh0KVi^07AdM01_Kfl00P1[Jf/0101JFUX0HV9R069RHP1TI6@2075aL@05
08N7Q`2ATI40UiNG09NGU`2EUID00P2IVIT01@2RXZ80/;2`0;no_`2o_kl0b/[:0080alO700D0^KVi
0;2`/02`/;00Xj>S09>CT`0209JFUP0309FEU@2MWId0WIfM0080WinO0`2TY:@2096AT@0309FEU@2B
TY80QHF50080QHF50P2:RXX01@26QXH0TY:B09:BTP2HV9P0VYZJ0080XJ6Q00D0YZJV09^KV`2KVi/0
Ti>C092@T00208V9R@0408j>SP2DU9@0U9BD0:2PX080YjNW00D0WinO09:BTP2ATI40TI6A092@T002
08n?S`0509:BTP2HV9P0W9bL09bLW02ATI400P1mOGd01@1dM7@0Kfm_07AdM01dM7@0Ogmo0080TI6A
00D0Xj>S09nOW`2OWil0RHV908N7Q`0207IfMP0506UYJ@1aLG40LG5a07MgM`1]KFd00P1iNGT0101o
Ogl0QHF508F5Q@2GUiL20:2PX0050:ZZZP2RXZ80TI6A096AT@1mOGd00P1aLG400`1YJFT0oooo0?oo
o`0=0?ooo`003@3oool0101cLg<0Vi^K09^KV`2KVi/209:BTP0508J6QP22PX80TI6A096AT@2OWil0
0P1jNWX01@2LW9`0Vi^K09^KV`2>SXh0P8200080Y:BT00D0NGUi0;Ng]`2g]kL0Fe]K09^KV`020;Jf
]P0406IVIP2RXZ80XZ:R0:BTY080N7Qh00D0];Bd05eMG@2HV9P0V9RH0;Bd]002071`L00507QhN02Z
ZZX0Shn?08n?S`2h^;P00P2<S8`01@1CDe<0Ph>30<c<c03<c<`0M7Ad0080[Jf]00D0RHV909JFUP2F
UYH0IfMW08N7Q`020:b/[00507]kN`30`<00`<3006a/K02NWYh00P1dM7@0102/[:`0YjNW0:NWY`1g
MgL208V9R@0508N7Q`2OWil0Ng]k07]kN`3AdM400P1GEeL01@25QHD0TI6A0<C4a034a<@0EeMG0080
V9RH00D0X:2P0861P@21PH40YZJV08Z:RP0209^KV`0507]kN`2=SHd0SHf=0<71`@1GEeL00P2ATI40
1@2;Rh/0Xj>S0:>SX`2c/k<0MGEe0080Vi^K00@0;bl_0?ooo`3oool0RXZ:0P13@d<01@2HV9P0X:2P
0:6QX@2QXJ40Xj>S0080Ng]k00D0UYJF06ATI02@T900T92@0=CDe00205iNGP05096AT@2EUID0UIFE
09fMW@23Ph<00P2][Jd01@1KFe/0QXJ608J6QP2WYjL0bLW90080M7Ad00D0J6QX0;:b/P2b/[80QHF5
08f=S@02096AT@0409BDU02LW9`0W9bL08>3P`80VIVI00D0IFEU0<K6aP2BTY80TY:B07emO@020861
P@050;Bd]01LG5`0[Zj^0:j^[P2KVi/00P27QhL01@1fMWH0R8R808R8R02e]KD0P8200080UYJF00@0
VYZJ08Z:RP2:RXX0W9bL2P3oool0101ZJVX0Lg=c07=cL`1nOWh208F5Q@0508f=S@2LW9`0Y:BT0:BT
Y02XZ:P00P2ZZZX01@2QXJ40WinO09nOW`2HV9P0U9BD0080Vi^K00D0V9RH09>CT`2CTi<0UIFE09^K
V`02096AT@0409VIV@2YZJT0ZJVY0::RXP<0UiNG00@0Rh^;07EeM@1eMGD0MgMg0P1jNWX01023Ph<0
Ti>C09fMW@2MWId309jNWP0509fMW@2LW9`0XJ6Q0:6QX@2UYJD00P2VYZH01@2SXj<0Y:BT0:BTY02J
VYX0SXj>0080P82000D0Q8B406i^KP1^KVh0M7Ad06m_K`0206][J`0405YJFP1RHV80HV9R06ATI080
LG5a00D0QhN7096AT@2GUiL0UiNG09FEU@0209VIV@050::RXP2`/;00_kno0;no_`3:b/X00P37alL0
1@2i^KT0/;2`0;2`/02SXj<0Ti>C0080UYJF00<0UIFE09fMW@2MWId00P2OWil30:BTY080TI6A00<0
UIFE09:BTP25QHD00P25QHD208Z:RP0508J6QP2BTY80TY:B09RHV02JVYX00P2QXJ401@2VYZH0Vi^K
09^KV`2CTi<0T92@0080RHV900@0SXj>09BDU02DU9@0X:2P0P2WYjL01@2OWil0TY:B096AT@2ATI40
T92@0080Shn?00D0TY:B09RHV02LW9`0W9bL096AT@0207emO@0507AdM01_Kfl0M7Ad07AdM01oOgl0
0P2ATI401@2SXj<0WinO09nOW`29RHT0QhN70080MWIf00D0JFUY075aL@1aLG40MgMg06e]K@0207Ui
N@0407moO`25QHD0QHF509NGU`80X:2P00D0ZZZZ0::RXP2ATI40TI6A07emO@02075aL@0306UYJ@3o
ool0oooo00d0oooo000=0?ooo`0407UiN@2MWId0WIfM096AT@80UYJF00D0RXZ:07inOP2CTi<0Ti>C
0:2PX00207MgM`050::RXP2CTi<0Ti>C08f=S@2:RXX00P2NWYh01@1cLg<0`L710<71`@1HF5P0WinO
0080[Jf]00@0JFUY0:FUY@2UYJD0XJ6Q0P1iNGT01@2d];@0GemO09BDU02DU9@0^;Rh0080K6a/00D0
Ogmo0:JVYP2;Rh/0Rh^;0;jn_P0208b<S005059BDP25QHD0a/K60<K6aP1bLW800P2o_kl01@1hN7P0
WIfM09fMW@1YJFT0PX:20080[jn_00D0Ogmo0;bl_02l_;`0JFUY0:JVYP0206YZJP040;Ng]`2TY:@0
Y:BT079bLP80SHf=00D0QXJ609nOW`1jNWX0NWYj0=WIf@0204m?C`0508F5Q@2DU9@0aLG50<G5a@1E
EED00P2EUID01@2UYJD0O7al07alO02[Zj/0PX:20080XJ6Q00D0MGEe09BDU02DU9@0alO704M7A`02
0:2PX0050861P@2SXj<0Xj>S0;fm_@1YJFT00P2QXJ40100^;Rh0oooo0?ooo`29RHT204I6AP0509:B
TP2SXj<0Xj>S0:>SX`2VYZH00P1hN7P01@2CTi<0Jf][08J6QP26QXH0fMWI0080GEeM00D0TY:B09FE
U@2EUID0X:2P092@T00208j>SP05075aL@21PH40PH610:NWY`3;bl/00P1[Jf/01@1_Kfl0/k>c0;>c
/`27QhL0RXZ:0080UYJF00@0R8R80:BTY02TY:@0Ogmo0P2LW9`01@1TI6@0a/K609>CT`2CTi<0LW9b
0080RXZ:00D0^KVi05=CD`2f][H0][Jf09RHV00208>3P`0507QhN02<S8`0S8b<0;Bd]01nOWh00P2D
U9@0102OWil0Rh^;08^;R`2FUYH:0?ooo`040;2`/02c/k<0/k>c0::RXP80Ti>C00D0UIFE08n?S`24
Q8@0Q8B4096AT@0209FEU@0509>CT`2DU9@0U9BD096AT@28R8P00P24Q8@308>3P`0508j>SP2CTi<0
XZ:R0::RXP2YZJT00P2SXj<01@2_[jl0^[Zj0;Zj^P2e]KD0^;Rh0080a/K600D0^KVi0:f][@2][Jd0
X:2P08n?S`0207emO@0507EeM@1/K6`0K6a/06YZJP1QHF400P1NGUh0101IFET0GUiN05iNGP1FEUH2
05MGE`05061PH01^KVh0LW9b079bLP1hN7P00P29RHT01@27QhL0PX:2071`L01`L700Kfm_0080HV9R
00D0Hf=S06QXJ01XJ6P0KFe]07EeM@0208>3P`0508J6QP21PH40PH6108J6QP24Q8@00P1dM7@0101W
IfL0Jf][06][J`1cLg<206YZJP0506a/K01fMWH0Ng]k07]kN`20P8000P1oOgl01@25QHD0T92@08^;
R`2;Rh/0SHf=0080VYZJ00D0UYJF09>CT`2HV9P0V9RH09BDU00208b<S00509^KV`2MWId0WIfM0:>S
X`2ZZZX00P2f][H30:b/[0050:ZZZP2YZJT0YJFU0:FUY@2TY:@00P2CTi<01@26QXH0OWin07inOP1j
NWX0OGem0080Rh^;00D0VYZJ09jNWP2NWYh0[:b/0:6QX@020:BTY0050:b/[02l_;`0_;bl0;Zj^P2i
^KT00P2UYJD0102;Rh/0KVi^06i^KP1MGEd2075aL@050861P@2=SHd0WYjN09jNWP2WYjL00P2KVi/0
102CTi<0Vi^K09JFUP2FUYH3096AT@0508n?S`2:RXX0RXZ:08V9R@2>SXh00P2BTY80102QXJ40Zj^[
0:^[Z`2][Jd?0?ooo`003@3oool0101lO7`0Xj>S0:>SX`21PH420:6QX@0508V9R@1iNGT0V9RH09RH
V02OWil00P1eMGD01@2XZ:P0Rh^;08^;R`29RHT0Vi^K0080U9BD00D0K6a/0<_;b`3;bl/0DU9B0:JV
YP020:FUY@0406e]K@2RXZ80XZ:R0:BTY080NWYj00D0/[:b05iNGP2FUYH0UYJF0;Vi^@0206][J`05
08:2PP2RXZ80RHV908V9R@31`L400P2<S8`01@1CDe<0QHF50<?3``33`l<0KVi^0080dM7A00D0IFEU
0:FUY@2UYJD0JVYZ07]kN`020;2`/00508>3P`2e]KD0]KFe06i^KP2UYJD00P1YJFT0102g]kL0Y:BT
0:BTY01bLW8308^;R`0409VIV@1lO7`0O7al0=kNgP80BDU900D0QXJ609JFUP37alL0alO705=CD`02
09:BTP050:f][@1eMGD0MGEe0;6a/@1jNWX00P2VYZH01@1`L700Vi^K09^KV`3;bl/0?Shn0080YjNW
00D0O7al0:6QX@2QXJ40a/K605iNGP020:JVYP0402d];@3oool0oooo08R8R080AdM700D0SXj>0:RX
Z02QXJ40XJ6Q0:VYZ@0207QhN00508b<S01cLg<0P8200820P03Hf=P00P1SHf<01@2>SXh0VIVI09VI
V@2LW9`0V9RH0080OGem00D0O7al08V9R@29RHT0WIfM0<c<c002069RHP0507moO`2YZJT0ZJVY08V9
R@2<S8`00P2JVYX0101mOGd0[Zj^0:j^[P1jNWX20:2PX00506EUI@31`L40UIFE09FEU@1_Kfl00P2<
S8`01@31`L40BTY:0;Vi^@2i^KT0UYJF0080Ogmo00D0OGem08j>SP2>SXh0/;2`07inOP0209NGU`04
0:2PX022PX80PX:209^KV`X0oooo00@0O7al07]kN`1kNg/0RHV90P2<S8`01@1eMGD0R8R808^;R`2;
Rh/0Ogmo0080Q8B400D0P82008^;R`2;Rh/0YjNW0;no_`020<K6aP050=;BdP3De=@0e=CD0<C4a02k
^k/00P2c/k<0102/[:`0YZJV0:JVYP2CTi<208:2PP0507moO`1kNg/0M7Ad07AdM027QhL00P2FUYH0
1@2KVi/0[Zj^0;no_`2o_kl0_Kfm0080_[jn00D0`<300;no_`34a<@0a<C40<O7a`020<[:bP050=GE
e@3Cdm<0dm?C0<G5a@2m_Kd00P2i^KT01@2/[:`0YjNW0:NWY`2][Jd0[jn_0080_;bl00@0a<C40<O7
a`37alL0_[jn0P2i^KT01@2[Zj/0VIVI07inOP1nOWh0N7Qh0080NGUi00D0MgMg08>3P`2HV9P0V9RH
0:^[Z`020:n_[`050;6a/@2n_[h0_[jn0<G5a@2i^KT00P2`/;001@2WYjL0Vi^K09^KV`2?Shl0SHf=
0080Shn?00D0U9BD09ZJVP2JVYX0Vi^K09RHV00209nOW`040:6QX@2d];@0];Bd0;2`/080];Bd00D0
[Jf]0:FUY@2;Rh/0Rh^;096AT@020:2PX0050:RXZ02YZJT0ZJVY0:VYZ@2PX:000P2OWil01@2TY:@0
YZJV0:JVYP2CTi<0Xj>S0080WYjN00D0Shn?08J6QP26QXH0S8b<08Z:RP0208:2PP0507moO`2CTi<0
Ti>C09VIV@2RXZ800P2ZZZX0102j^[X0_kno0;no_`37alL20;6a/@050:BTY02MWId0U9BD09BDU02N
WYh00P2b/[801@2m_Kd0[:b/0:FUY@2UYJD0UYJF0080Shn?00D0Rh^;09NGU`2GUiL0Vi^K0:NWY`02
09nOW`0409JFUP2@T900T92@0:6QX@l0oooo000=0?ooo`0407alO02SXj<0Xj>S0861P@80XJ6Q00D0
RHV907UiN@2HV9P0V9RH09nOW`0207EeM@050:RXZ02;Rh/0Rh^;08V9R@2KVi/00P2DU9@01@1/K6`0
bl_;0<_;b`1BDU80YZJV0080YJFU00@0KFe]0::RXP2RXZ80Y:BT0P1jNWX01@2b/[80GUiN09JFUP2F
UYH0^KVi0080Jf][00D0PX:20::RXP29RHT0RHV90<71`@0208b<S00505=CD`25QHD0`l?30<?3``1^
KVh00P3AdM401@1UIFD0YJFU0:FUY@1ZJVX0Ng]k0080/;2`00D0Ph>30;Fe]@2e]KD0KVi^0:FUY@02
06UYJ@040;Ng]`2TY:@0Y:BT079bLP<0Rh^;00@0VIVI07alO01lO7`0g]kN0P19BDT01@26QXH0UYJF
0<O7a`37alL0De=C0080TY:B00D0[Jf]07EeM@1eMGD0/K6a07YjNP020:JVYP05071`L02KVi/0Vi^K
0<_;b`0n?Sh00P2WYjL01@1lO7`0XJ6Q0:6QX@36a/H0GUiN0080YZJV00@0;Bd]0?ooo`3oool0R8R8
0P17AdL01@2>SXh0Z:RX0:6QX@2QXJ40ZJVY0080N7Qh00D0S8b<07=cL`20P800P8200=SHf00206=S
H`0508j>SP2IVIT0VIVI09bLW02HV9P00P1mOGd01@1lO7`0RHV908V9R@2MWId0c<c<0080HV9R00D0
Ogmo0:VYZ@2YZJT0RHV908b<S00209ZJVP0407emO@2^[Zh0[Zj^07YjNP80X:2P00D0IFEU0<71`@2E
UID0UIFE06m_K`0208b<S0050<71`@1:BTX0^KVi0;Vi^@2FUYH00P1oOgl01@1mOGd0SXj>08j>SP2`
/;00OWin0080UiNG00@0X:2P08:2PP22PX80Vi^K2P3oool0101lO7`0Ng]k07]kN`29RHT208b<S005
07EeM@28R8P0Rh^;08^;R`1oOgl00P24Q8@01@20P800Rh^;08^;R`2WYjL0_kno0080a/K600D0d];B
0=CDe03De=@0a<C40;^k^`020;>c/`040:b/[02VYZH0YZJV09>CT`80PX:200D0Ogmo07]kN`1dM7@0
M7Ad08N7Q`0209JFUP0509^KV`2^[Zh0_kno0;no_`2m_Kd00P2n_[h01@30`<00_kno0<C4a034a<@0
alO70080b/[:00D0eMGE0=?Cd`3Cdm<0aLG50;fm_@020;Vi^@050:b/[02WYjL0YjNW0:f][@2_[jl0
0P2l_;`01034a<@0alO70<O7a`2n_[h20;Vi^@050:^[Z`2IVIT0OWin07inOP1hN7P00P1iNGT01@1g
MgL0Ph>309RHV02HV9P0Zj^[0080[jn_00D0/K6a0;jn_P2n_[h0aLG50;Vi^@020;2`/0050:NWY`2K
Vi/0Vi^K08n?S`2=SHd00P2?Shl01@2DU9@0VYZJ09ZJVP2KVi/0V9RH0080WinO00@0XJ6Q0;Bd]02d
];@0/;2`0P2d];@01@2][Jd0YJFU08^;R`2;Rh/0TI6A0080X:2P00D0Z:RX0:VYZ@2YZJT0ZJVY0:2P
X00209nOW`050:BTY02VYZH0YZJV09>CT`2SXj<00P2NWYh01@2?Shl0QXJ608J6QP2<S8`0RXZ:0080
PX:200D0Ogmo09>CT`2CTi<0VIVI0::RXP020:ZZZP040;Zj^P2o_kl0_kno0<O7a`80/K6a00D0Y:BT
09fMW@2DU9@0U9BD09jNWP020;:b/P050;fm_@2/[:`0YJFU0:FUY@2FUYH00P2?Shl01@2;Rh/0UiNG
09NGU`2KVi/0YjNW0080WinO00@0UYJF092@T02@T900XJ6Q3`3oool000d0oooo00@0OGem0:FUY@2U
YJD0MGEe0P2][Jd00`27QhL0MWIf09bLW00209bLW080M7Ad00D0[Jf]08N7Q`27QhL0PX:20:ZZZP02
08f=S@0506UYJ@3?cll0clo?04m?C`2ZZZX00P2OWil0101aLG40Xj>S0:>SX`2RXZ8207UiN@050;Fe
]@1KFe/0UYJF09JFUP2i^KT00P1ZJVX01@24Q8@0XJ6Q08F5Q@25QHD0a<C40080S8b<00D0De=C08N7
Q`2n_[h0_[jn06YZJP020>;RhP0505=CD`2b/[80/[:b06QXJ01fMWH00P2b/[801@27QhL0[jn_0:n_
[`1_Kfl0Z:RX0080IVIV00@0]KFe0:FUY@2UYJD0MWIf0P26QXH01@2ATI40UIFE07]kN`1kNg/0hn?S
0080A4A400D0QhN709NGU`34a<@0a<C405QHF00208^;R`050;Ng]`1aLG40LG5a0;2`/01eMGD00P2Y
ZJT01@1/K6`0WinO09nOW`3@d=00=CDe0080Zj^[00D0PH6109JFUP2FUYH0d];B05ADE0020:VYZ@04
02h^;P3oool0oooo08B4Q080BTY:00D0R8R80:j^[P2NWYh0WYjN0:ZZZP0207QhN00508V9R@1hN7P0
P8200820P03@d=000P1]KFd01@27QhL0WIfM09fMW@2KVi/0UYJF0080PX:200D0MGEe09:BTP2BTY80
UIFE0<c<c002065QH@0508R8R02TY:@0Y:BT08F5Q@2@T9000P2IVIT0101fMWH0]KFe0;Fe]@1gMgL2
0:JVYP0506MWI`2j^[X0UIFE09FEU@1]KFd00P2@T9001@38b<P0@T920;Vi^@2i^KT0VIVI0080NWYj
00D0QHF508Z:RP2:RXX0[:b/08B4Q00209NGU`040:2PX01iNGT0NGUi0::RXPX0oooo00@0jNWY0=oO
g`3Ogml0f][J0P3IfMT01@3GemL0^;Rh0:^[Z`2[Zj/0W9bL0080TY:B00D0SXj>08F5Q@25QHD0KFe]
06MWI`0206IVIP0506i^KP1cLg<0Lg=c08V9R@2IVIT00P2KVi/0102DU9@0Shn?08n?S`2FUYH209VI
V@0509bLW02UYJD0Zj^[0:^[Z`2KVi/00P2@T9000`29RHT0MgMg075aL@02075aL@80Ng]k00D0O7al
08N7Q`1oOgl0Ogmo08Z:RP0207alO00507emO@1lO7`0O7al08R8R027QhL00P28R8P01@2;Rh/0Ti>C
09>CT`24Q8@0PX:20080OWin00@0O7al07YjNP1jNWX0TY:B0P2GUiL0102YZJT0^KVi0<[:bP3:b/X3
0=?Cd`050<K6aP2XZ:P0Ti>C09>CT`23Ph<00P24Q8@01@26QXH0Shn?08n?S`2CTi<0Vi^K0080UYJF
00@0UIFE09^KV`2KVi/0Shn?0`23Ph<01022PX80NGUi07UiN@2?Shl309NGU`0409ZJVP2GUiL0UiNG
09NGU`80Ti>C00D0TY:B08j>SP2FUYH0UYJF08V9R@0207QhN0050861P@1oOgl0QhN708N7Q`1kNg/0
0P2GUiL01@2;Rh/0QHF508F5Q@28R8P0V9RH0080TY:B00D0W9bL0;Jf]P2f][H0]kNg0<g=c@020;^k
^`050;>c/`2GUiL0UiNG09:BTP1dM7@00P1nOWh0101jNWX0P8200820P01mOGd2096AT@0509^KV`2R
XZ80Xj>S0:>SX`2EUID00P1lO7`0101fMWH0Q8B408j>SP2>SXh30:BTY00509VIV@21PH40PH61079b
LP1OGel00P1lO7`0102GUiL0[jn_0:n_[`2l_;`?0?ooo`003@3oool0101nOWh0ZZZZ0:ZZZP1ZJVX2
0;Zj^P050861P@1dM7@0WinO09nOW`2MWId00P1cLg<01@2][Jd0Rh^;08^;R`1gMgL0^[Zj0080R8R8
00D0IVIV0<_;b`3;bl/0EEEE0:ZZZP0209nOW`04071`L02RXZ80XZ:R0::RXP80OGem00D0/k>c05YJ
FP2JVYX0VYZJ0;Jf]P0206e]K@0508J6QP2MWId0PX:208:2PP38b<P00P2:RXX01@1EEED0RHV90;Rh
^02h^;P0JFUY0080k^k^00D0ATI60;Zj^P2j^[X0JFUY075aL@020;>c/`0508R8R02_[jl0[jn_071`
L02ZZZX00P1VIVH0102`/;00ZJVY0:VYZ@1fMWH208>3P`0509BDU02@T900Ogmo07moO`3Ph>000P11
@D401@2<S8`0UiNG0<30`030`<00Fe]K0080RHV900D0`<3006][J`1[Jf/0[Zj^07=cL`020:ZZZP05
06QXJ02QXJ40XJ6Q0=GEe@0a<C400P2ZZZX01@28R8P0S8b<08b<S03Lg=`0CDe=0080ZJVY00@0;2`/
0?ooo`3oool0NGUi0P1@D5001@1oOgl0][Jf09VIV@2IVIT0Zj^[0080OWin00D0Ph>307]kN`24Q8@0
Q8B40<30`00207inOP0507]kN`2ZZZX0ZZZZ08j>SP2GUiL00P29RHT01@1fMWH0U9BD09BDU02@T900
c<c<0080HF5Q00D0U9BD09ZJVP2JVYX0PX:209FEU@0209BDU00407]kN`2^[Zh0[Zj^07emO@80Y:BT
00D0K6a/0;:b/P2HV9P0V9RH06UYJ@0209BDU0050<g=c@0m?Cd0]KFe0;Fe]@2MWId00P1fMWH01@2:
RXX0T92@092@T02QXJ40RHV90080VIVI00@0Vi^K07]kN`1kNg/0X:2P2P3oool0101:BTX0EUIF05IF
EP1FEUH2061PH005079bLP26QXH0Ti>C09>CT`2NWYh00P2PX:001@2UYJD0YjNW0:NWY`2_[jl0[Zj^
0080Zj^[00D0Xj>S09bLW02LW9`0QhN707YjNP0207AdM00407YjNP2:RXX0RXZ:09^KV`80WIfM00D0
YjNW0::RXP2OWil0WinO09JFUP0209ZJVP0509bLW02MWId0T92@092@T02IVIT00P2GUiL01@2HV9P0
WinO0:^[Z`2[Zj/0XZ:R0080[Jf]00D0[:b/0:j^[P2^[Zh0[Jf]0:n_[`020:ZZZP050:VYZ@2OWil0
WinO0:n_[`2f][H00P38b<P0103Bd]80f=SH0=SHf033`l<20;Zj^P040:b/[02JVYX0UYJF09JFUP<0
Shn?00D0SXj>09NGU`2JVYX0VYZJ09jNWP0209ZJVP<0WinO00D0XZ:R0:JVYP2[Zj/0Zj^[0:FUY@02
0:JVYP030:f][@2a/K40/[:b0080/[:b0P2`/;001@2JVYX0Rh^;08F5Q@25QHD0QhN70080NWYj00D0
MgMg07inOP1nOWh0Ph>30861P@0208F5Q@0508Z:RP26QXH0QXJ60861P@23Ph<00P2>SXh0102WYjL0
[:b/0:b/[02f][H20:f][@050<71`@2IVIT0UYJF09JFUP2=SHd00P2@T9001@1aLG40S8b<09fMW@2M
WId0WinO0080Y:BT00D0ZZZZ0:FUY@2ATI40TI6A09FEU@0209VIV@0509nOW`2CTi<0Ti>C096AT@2?
Shl00P2@T9001@2>SXh0Y:BT0:BTY02][Jd0Z:RX0080WIfM00@0VIVI09ZJVP2JVYX0WYjN0P2_[jl0
1@3<c<`0jNWY0=3@d03@d=00`<300080Y:BT00<0N7Qh0?ooo`3oool03@3oool000d0oooo00@0OGem
0:^[Z`2[Zj/0KVi^0P2h^;P01@1mOGd0MWIf09fMW@2MWId0XZ:R0080Kfm_00D0ZJVY09>CT`2CTi<0
KFe]0<K6aP020820P00506YZJP37alL0alO705YJFP2VYZH00P2NWYh0101cLg<0WinO09nOW`2UYJD2
07alO0050;Bd]01FEUH0WIfM09fMW@2d];@00P1^KVh01@26QXH0WinO07inOP1nOWh0a/K60080T92@
00D0EEEE08f=S@2`/;00/;2`06UYJ@020?Cdm0050492@P2l_;`0_;bl06UYJ@1]KFd00P2c/k<01@29
RHT0/K6a0;6a/@1^KVh0[Zj^0080IfMW00@0ZJVY0:n_[`2_[jl0MGEe0P23Ph<01@2GUiL0RXZ:08N7
Q`27QhL0f][J0080@D5100D0TY:B09BDU02n_[h0_[jn05aLG00208f=S@050<?3``1XJ6P0J6QX0:^[
Z`1eMGD00P2[Zj/01@1YJFT0WYjN09jNWP3Kfm/0;bl_0080Y:BT00D0UIFE08:2PP22PX80hn?S04E5
A@020:f][@0402HV9P3oool0oooo06e]K@80CTi>00D0RHV90;6a/@2FUYH0UYJF0:b/[0020861P@05
0820P01iNGT0UIFE09FEU@2WYjL00P2ATI401@1]KFd0^KVi0;Vi^@1lO7`0Xj>S0080R8R800D0LW9b
09RHV02HV9P0S8b<0<k>cP0205aLG00509jNWP2DU9@0U9BD07emO@2JVYX00P2DU9@01024Q8@0WIfM
09fMW@25QHD20:6QX@0507UiN@2TY:@0VIVI09VIV@1ZJVX00P2EUID01@3AdM40?Cdm0:b/[02/[:`0
Y:BT0080LG5a00D0TY:B08V9R@29RHT0XZ:R08Z:RP0209nOW`04092@T026QXH0QXJ609ZJVPX0oooo
00@0WIfM09>CT`2CTi<0SXj>0P29RHT00`2FUYH0U9BD09VIV@0209VIV@80WIfM00D0XJ6Q09bLW02L
W9`0Ti>C09fMW@0209ZJVP<0T92@00D0UYJF08R8R02<S8`0S8b<08j>SP0208f=S@0508>3P`2@T900
T92@08n?S`2ATI400P2DU9@01@2RXZ80Xj>S0:>SX`2UYJD0[:b/0080^;Rh00D0]kNg0;:b/P2b/[80
[:b/0:>SX`0209JFUP0408b<S023Ph<0Ph>307MgM`80KFe]00D0HV9R05iNGP1RHV80HV9R06QXJ002
06YZJP05079bLP1cLg<0IFEU06EUI@1NGUh00P1TI6@01@1VIVH0LW9b079bLP20P800QhN70080Ogmo
00D0P82008>3P`23Ph<0Ph>308f=S@0209JFUP0409ZJVP2KVi/0Vi^K09BDU080RXZ:00D0Q8B408:2
PP1kNg/0Ng]k08N7Q`0208Z:RP0508>3P`27QhL0R8R808R8R02:RXX00P2<S8`01@2OWil0Xj>S0:NW
Y`2WYjL0Xj>S0080Z:RX00D0Y:BT09nOW`2OWil0Vi^K09fMW@0209JFUP050:2PX02NWYh0WYjN09^K
V`2NWYh00P2IVIT0102EUID0QhN708N7Q`26QXH207UiN@0508F5Q@2=SHd0S8b<08b<S026QXH00P1m
OGd01@1hN7P0D51@06UYJ@1YJFT0NWYj0080RXZ:00D0OWin09JFUP2BTY80TY:B08B4Q00207UiN@05
07inOP1jNWX0NWYj07IfMP1lO7`00P23Ph<00`24Q8@0OWin07inOP0207AdM080OWin00@0S8b<09:B
TP2BTY80WYjN0P2QXJ401@2FUYH0M7Ad07QhN01hN7P0O7al0080PH6100<0PX:20?ooo`3oool03@3o
ool000d0oooo00@0OGem0:^[Z`2[Zj/0KVi^0P2h^;P01@1mOGd0MWIf09fMW@2MWId0XZ:R0080Kfm_
00D0ZJVY09>CT`2CTi<0KFe]0<K6aP020820P00506YZJP37alL0alO705YJFP2VYZH00P2NWYh0101c
Lg<0WinO09nOW`2UYJD207alO0050;Bd]01FEUH0WIfM09fMW@2d];@00P1^KVh01@26QXH0WinO07in
OP1nOWh0a/K60080T92@00D0EEEE08f=S@2`/;00/;2`06UYJ@020?Cdm0050492@P2l_;`0_;bl06UY
J@1]KFd00P2c/k<01@29RHT0/K6a0;6a/@1^KVh0[Zj^0080IfMW00@0ZJVY0:n_[`2_[jl0MGEe0P23
Ph<01@2GUiL0RXZ:08N7Q`27QhL0f][J0080@D5100D0TY:B09BDU02n_[h0_[jn05aLG00208f=S@05
0<?3``1XJ6P0J6QX0:^[Z`1eMGD00P2[Zj/01@1YJFT0WYjN09jNWP3Kfm/0;bl_0080Y:BT00D0UIFE
08:2PP22PX80hn?S04E5A@020:f][@0402HV9P3oool0oooo06e]K@80CTi>00D0RHV90;6a/@2FUYH0
UYJF0:b/[0020861P@050820P01iNGT0UIFE09FEU@2WYjL00P2ATI401@1]KFd0^KVi0;Vi^@1lO7`0
Xj>S0080R8R800D0LW9b09RHV02HV9P0S8b<0<k>cP0205aLG00509jNWP2DU9@0U9BD07emO@2JVYX0
0P2DU9@01024Q8@0WIfM09fMW@25QHD20:6QX@0507UiN@2TY:@0VIVI09VIV@1ZJVX00P2EUID01@3A
dM40?Cdm0:b/[02/[:`0Y:BT0080LG5a00D0TY:B08V9R@29RHT0XZ:R08Z:RP0209nOW`04092@T026
QXH0QXJ609ZJVPX0oooo00@0WIfM09>CT`2CTi<0SXj>0P29RHT00`2FUYH0U9BD09VIV@0209VIV@80
WIfM00D0XJ6Q09bLW02LW9`0Ti>C09fMW@0209ZJVP<0T92@00D0UYJF08R8R02<S8`0S8b<08j>SP02
08f=S@0508>3P`2@T900T92@08n?S`2ATI400P2DU9@01@2RXZ80Xj>S0:>SX`2UYJD0[:b/0080^;Rh
00D0]kNg0;:b/P2b/[80[:b/0:>SX`0209JFUP0408b<S023Ph<0Ph>307MgM`80KFe]00D0HV9R05iN
GP1RHV80HV9R06QXJ00206YZJP05079bLP1cLg<0IFEU06EUI@1NGUh00P1TI6@01@1VIVH0LW9b079b
LP20P800QhN70080Ogmo00D0P82008>3P`23Ph<0Ph>308f=S@0209JFUP0409ZJVP2KVi/0Vi^K09BD
U080RXZ:00D0Q8B408:2PP1kNg/0Ng]k08N7Q`0208Z:RP0508>3P`27QhL0R8R808R8R02:RXX00P2<
S8`01@2OWil0Xj>S0:NWY`2WYjL0Xj>S0080Z:RX00D0Y:BT09nOW`2OWil0Vi^K09fMW@0209JFUP05
0:2PX02NWYh0WYjN09^KV`2NWYh00P2IVIT0102EUID0QhN708N7Q`26QXH207UiN@0508F5Q@2=SHd0
S8b<08b<S026QXH00P1mOGd01@1hN7P0D51@06UYJ@1YJFT0NWYj0080RXZ:00D0OWin09JFUP2BTY80
TY:B08B4Q00207UiN@0507inOP1jNWX0NWYj07IfMP1lO7`00P23Ph<00`24Q8@0OWin07inOP0207Ad
M080OWin00@0S8b<09:BTP2BTY80WYjN0P2QXJ401@2FUYH0M7Ad07QhN01hN7P0O7al0080PH6100<0
PX:20?ooo`3oool03@3oool000d0oooo00@0O7al0:ZZZP2ZZZX0MgMg0P2e]KD01@1gMgL0Ng]k09VI
V@2IVIT0Z:RX0080K6a/00D0Y:BT09ZJVP2JVYX0J6QX0<_;b`0207alO005071`L032`/80`/;205]K
F`2SXj<00P2OWil0101cLg<0XJ6Q0:6QX@2VYZH207emO@050;6a/@1CDe<0XZ:R0::RXP2b/[800P1`
L7001@22PX80XZ:R07emO@1mOGd0`l?30080TI6A00D0FEUI08Z:RP2_[jl0[jn_06UYJ@020?Ogm`05
03hn?P2o_kl0_kno06QXJ01^KVh00P2`/;001@29RHT0/k>c0;>c/`1^KVh0[Zj^0080JVYZ00@0X:2P
0;Bd]02d];@0K6a/0P2>SXh01@2FUYH0QXJ608Z:RP2:RXX0eMGE0080@D5100D0Ti>C09FEU@2l_;`0
_;bl05mOG`0208b<S0050<?3``1ZJVX0JVYZ0:BTY01iNGT00P2YZJT01@1ZJVX0Vi^K09^KV`3MgMd0
<30`0080WYjN00D0WinO07UiN@1iNGT0inOW0492@P020:j^[P0402LW9`3oool0oooo06][J`80BDU9
00D0UIFE0:f][@2ATI40TI6A0:ZZZP0208R8R00507emO@1cLg<0ZJVY0:VYZ@2@T9000P2OWil01@1X
J6P0^KVi0;Vi^@1fMWH0Z:RX0080Shn?00D0I6AT0:BTY02TY:@0Rh^;0<W9b@0205eMG@050:>SX`2E
UID0UIFE07IfMP2HV9P00P2DU9@0102@T900RHV908V9R@2ATI4209VIV@0508^;R`2CTi<0W9bL09bL
W01^KVh00P2CTi<01@3Bd]80@D510:6QX@2QXJ40Zj^[0080Lg=c00D0TI6A08R8R028R8P0WinO09:B
TP0209jNWP0408J6QP29RHT0RHV909ZJVPX0oooo00@0W9bL0:NWY`2WYjL0ZZZZ0P2^[Zh01@2TY:@0
W9bL08V9R@29RHT0QXJ60080PX:200D0QHF508N7Q`27QhL0RHV908Z:RP020861P@0508:2PP20P800
P82008n?S`2JVYX00P2XZ:P0102SXj<0YJFU0:FUY@2HV9P208N7Q`80OWin0P1lO7`01@20P800QHF5
08F5Q@2;Rh/0UYJF0080T92@00D0RXZ:08b<S02<S8`0T92@08b<S00208f=S@0409^KV`2SXj<0Xj>S
0:VYZ@80];Bd00D0bLW90<?3``32`/80`/;20<30`0020;fm_@050;2`/02d];@0]kNg0;Ng]`2a/K40
0P2/[:`00`2XZ:P0Vi^K09^KV`0208n?S`80TI6A00D0Shn?08^;R`2;Rh/0TI6A08N7Q`0208F5Q@04
0861P@24Q8@0Q8B408N7Q`80Shn?00D0SXj>09>CT`2IVIT0VIVI096AT@0208j>SP0509^KV`2JVYX0
VIVI09VIV@2JVYX00P2LW9`01@2?Shl0SHf=096AT@2ATI40U9BD0080SXj>00D0UIFE09nOW`2OWil0
Vi^K09VIV@020:VYZ@050::RXP2YZJT0ZJVY0;:b/P2h^;P00P2f][H0102`/;00];Bd0;Bd]02][Jd2
0<G5a@050::RXP2/[:`0X:2P0:2PX02ZZZX00P2OWil01@32`/80^;Rh0:VYZ@2YZJT0WYjN0080Ti>C
00D0Shn?09nOW`2WYjL0YjNW0;Ng]`020;Bd]0050;2`/02WYjL0YjNW0:f][@2JVYX00P2HV9P01@2M
WId0XJ6Q0:6QX@2PX:00Xj>S0080V9RH00@0LW9b06i^KP1^KVh0M7Ad0P1`L700101_Kfl0O7al07in
OP1nOWh3071`L00307]kN`3oool0oooo00d0oooo000=0?ooo`0407emO@2XZ:P0Z:RX07inOP80/;2`
00D0MgMg07alO02IVIT0VIVI0:VYZ@0206][J`050::RXP2OWil0WinO06=SH`3<c<`00P1kNg/01@1d
M7@0_Kfm0;fm_@1NGUh0XJ6Q0080X:2P00@0M7Ad0:>SX`2SXj<0YZJV0P1iNGT01@2b/[80EUIF0:>S
X`2SXj<0[Zj^0080LG5a00D0PX:20::RXP1mOGd0OGem0<?3``02096AT@0505]KF`29RHT0[Zj^0:j^
[P1ZJVX00P3dm?@01@0n?Sh0`l?30<?3``1VIVH0Kfm_0080[Zj^00D0RXZ:0;Fe]@2e]KD0Jf][0;6a
/@0206a/K00409fMW@2g]kL0]kNg06IVIP80UYJF00D0Ti>C08F5Q@2<S8`0S8b<0=;BdP020451@@05
09NGU`2FUYH0][Jf0;Jf]P1TI6@00P2;Rh/01@30`<00LW9b079bLP2HV9P0PX:20080YZJV00D0Jf][
09RHV02HV9P0h^;R02h^;P0209ZJVP050:^[Z`1`L700L71`0>WYj@11@D400P2`/;00100Z:RX0oooo
0?ooo`1]KFd204A4A0050:6QX@2YZJT0SXj>08j>SP2WYjL00P2>SXh01@1lO7`0KFe]0;Vi^@2i^KT0
P8200080YJFU00D0K6a/0;2`/02`/;00MWIf0:n_[`0208Z:RP0506IVIP2OWil0WinO09>CT`31`L40
0P1RHV801@2PX:00WIfM09fMW@1dM7@0TY:B0080UIFE00@0VYZJ07YjNP1jNWX0UiNG0P2EUID01@2J
VYX0RXZ:09bLW02LW9`0LG5a0080SHf=00D0dm?C04U9B@2FUYH0UYJF0;2`/00207QhN00508^;R`2A
TI40TI6A09BDU02JVYX00P2OWil0101jNWX0UiNG09NGU`2CTi<:0?ooo`040:NWY`2PX:00X:2P09RH
V080TI6A00D0Rh^;09>CT`2SXj<0Xj>S0:NWY`020:>SX`0509fMW@2IVIT0VIVI09:BTP2=SHd00P2U
YJD01@2d];@0_;bl0;bl_02_[jl0[Zj^0080Ti>C00@0Shn?08:2PP22PX80Ti>C0P2PX:001@2YZJT0
YjNW0:NWY`2WYjL0WinO0080VYZJ00D0UiNG0861P@25QHD0QHF508Z:RP0208N7Q`0508J6QP2IVIT0
Vi^K09^KV`2LW9`00P2JVYX00`2GUiL0Shn?08n?S`0208>3P`80Q8B40`1lO7`01@20P800M7Ad071`
L01`L700M7Ad0080MWIf00@0O7al08V9R@29RHT0TY:B0`2KVi/01@2QXJ40XZ:R0::RXP2RXZ80Z:RX
0080/;2`00@0[Zj^0:BTY02TY:@0TI6A0P24Q8@207MgM`80P82000D0TY:B09ZJVP2JVYX0Ti>C08Z:
RP0308J6QP80Ph>300D0SXj>09BDU02ATI40TI6A08f=S@0208J6QP0508f=S@2:RXX0RXZ:08n?S`2G
UiL00P2IVIT01@2:RXX0Ogmo07moO`1jNWX0LG5a0080LW9b00@0O7al08F5Q@25QHD0Ogmo0P2=SHd0
1@2DU9@0TY:B09^KV`2KVi/0WinO0080UYJF00D0TI6A09BDU02BTY80TY:B08b<S00207emO@0507]k
N`23Ph<0R8R808R8R02;Rh/00P2GUiL01@2TY:@0XZ:R0::RXP2GUiL0Zj^[0080[Zj^00D0Y:BT0:2P
X02PX:00Y:BT09>CT`0209fMW@040<30`02_[jl0[jn_0:>SX`80WYjN00D0V9RH08R8R02FUYH0UYJF
0:RXZ0020;Vi^@030;no_`3oool0oooo00d0oooo000=0?ooo`0407emO@2XZ:P0Z:RX07inOP80/;2`
00D0MgMg07alO02IVIT0VIVI0:VYZ@0206][J`050::RXP2OWil0WinO06=SH`3<c<`00P1kNg/01@1d
M7@0_Kfm0;fm_@1NGUh0XJ6Q0080X:2P00@0M7Ad0:>SX`2SXj<0YZJV0P1iNGT01@2b/[80EUIF0:>S
X`2SXj<0[Zj^0080LG5a00D0PX:20::RXP1mOGd0OGem0<?3``02096AT@0505]KF`29RHT0[Zj^0:j^
[P1ZJVX00P3dm?@01@0n?Sh0`l?30<?3``1VIVH0Kfm_0080[Zj^00D0RXZ:0;Fe]@2e]KD0Jf][0;6a
/@0206a/K00409fMW@2g]kL0]kNg06IVIP80UYJF00D0Ti>C08F5Q@2<S8`0S8b<0=;BdP020451@@05
09NGU`2FUYH0][Jf0;Jf]P1TI6@00P2;Rh/01@30`<00LW9b079bLP2HV9P0PX:20080YZJV00D0Jf][
09RHV02HV9P0h^;R02h^;P0209ZJVP050:^[Z`1`L700L71`0>WYj@11@D400P2`/;00100Z:RX0oooo
0?ooo`1]KFd204A4A0050:6QX@2YZJT0SXj>08j>SP2WYjL00P2>SXh01@1lO7`0KFe]0;Vi^@2i^KT0
P8200080YJFU00D0K6a/0;2`/02`/;00MWIf0:n_[`0208Z:RP0506IVIP2OWil0WinO09>CT`31`L40
0P1RHV801@2PX:00WIfM09fMW@1dM7@0TY:B0080UIFE00@0VYZJ07YjNP1jNWX0UiNG0P2EUID01@2J
VYX0RXZ:09bLW02LW9`0LG5a0080SHf=00D0dm?C04U9B@2FUYH0UYJF0;2`/00207QhN00508^;R`2A
TI40TI6A09BDU02JVYX00P2OWil0101jNWX0UiNG09NGU`2CTi<:0?ooo`040:NWY`2PX:00X:2P09RH
V080TI6A00D0Rh^;09>CT`2SXj<0Xj>S0:NWY`020:>SX`0509fMW@2IVIT0VIVI09:BTP2=SHd00P2U
YJD01@2d];@0_;bl0;bl_02_[jl0[Zj^0080Ti>C00@0Shn?08:2PP22PX80Ti>C0P2PX:001@2YZJT0
YjNW0:NWY`2WYjL0WinO0080VYZJ00D0UiNG0861P@25QHD0QHF508Z:RP0208N7Q`0508J6QP2IVIT0
Vi^K09^KV`2LW9`00P2JVYX00`2GUiL0Shn?08n?S`0208>3P`80Q8B40`1lO7`01@20P800M7Ad071`
L01`L700M7Ad0080MWIf00@0O7al08V9R@29RHT0TY:B0`2KVi/01@2QXJ40XZ:R0::RXP2RXZ80Z:RX
0080/;2`00@0[Zj^0:BTY02TY:@0TI6A0P24Q8@207MgM`80P82000D0TY:B09ZJVP2JVYX0Ti>C08Z:
RP0308J6QP80Ph>300D0SXj>09BDU02ATI40TI6A08f=S@0208J6QP0508f=S@2:RXX0RXZ:08n?S`2G
UiL00P2IVIT01@2:RXX0Ogmo07moO`1jNWX0LG5a0080LW9b00@0O7al08F5Q@25QHD0Ogmo0P2=SHd0
1@2DU9@0TY:B09^KV`2KVi/0WinO0080UYJF00D0TI6A09BDU02BTY80TY:B08b<S00207emO@0507]k
N`23Ph<0R8R808R8R02;Rh/00P2GUiL01@2TY:@0XZ:R0::RXP2GUiL0Zj^[0080[Zj^00D0Y:BT0:2P
X02PX:00Y:BT09>CT`0209fMW@040<30`02_[jl0[jn_0:>SX`80WYjN00D0V9RH08R8R02FUYH0UYJF
0:RXZ0020;Vi^@030;no_`3oool0oooo00d0oooo000=0?ooo`0408B4Q02TY:@0Y:BT08:2PP80[:b/
00D0MGEe0820P02HV9P0V9RH0:VYZ@0206YZJP050:BTY02LW9`0W9bL06EUI@3;bl/00P1hN7P01@1i
NGT0^KVi0;Vi^@1RHV80WIfM0080X:2P00@0M7Ad0:FUY@2UYJD0YZJV0P1iNGT01@2`/;00EeMG0:NW
Y`2WYjL0ZJVY0080M7Ad00D0PX:20:6QX@1lO7`0O7al0<G5a@0208j>SP0505iNGP27QhL0[jn_0:n_
[`1ZJVX00P3clo<01@10@400`/;20<;2`P1VIVH0L71`0080[jn_00D0QXJ60;Ng]`2g]kL0Jf][0;:b
/P0206QXJ0040:6QX@2i^KT0^KVi05aLG080Y:BT00D0Rh^;08B4Q02ATI40TI6A0<k>cP020410@005
09^KV`2EUID0]kNg0;Ng]`1TI6@00P29RHT01@2l_;`0Ng]k07]kN`2?Shl0RXZ:0080XJ6Q00D0Kfm_
09FEU@2EUID0hn?S02/[:`0209VIV@050;:b/P1ZJVX0JVYZ0>[ZjP11@D400P2_[jl0100/;2`0oooo
0?ooo`1/K6`203hn?P050;2`/02NWYh0SXj>08j>SP2VYZH00P2EUID01@1fMWH0Kfm_0;no_`2o_kl0
NWYj0080YJFU00D0L71`0;2`/02`/;00LG5a0;jn_P02071`L00507alO02FUYH0UYJF09RHV02n_[h0
0P1QHF401@2PX:00Vi^K09^KV`1mOGd0RXZ:0080VIVI00@0WYjN075aL@1aLG40VYZJ0P2CTi<01@2P
X:00QXJ609ZJVP2JVYX0NGUi0080QHF500D0e]KF04a<C02>SXh0SXj>0;:b/P0207emO@050861P@2Q
XJ40XJ6Q08F5Q@2NWYh00P2RXZ80101bLW80Y:BT0:BTY028R8P:0?ooo`0406e]K@1VIVH0IVIV07Ee
M@80Q8B400D0Shn?092@T02ATI40TI6A09FEU@0209RHV0050:6QX@2XZ:P0Z:RX0:BTY02GUiL00P2<
S8`01@1gMgL0KFe]06e]K@1gMgL0NWYj0080QHF500@0SXj>09VIV@2IVIT0Shn?0P2:RXX01022PX80
R8R808N7Q`27QhL308V9R@0508b<S02OWil0XJ6Q0:6QX@2RXZ800P2PX:001@2LW9`0Rh^;08R8R028
R8P0QhN700<0Rh^;0P29RHT01@26QXH0SHf=08b<S02<S8`0VIVI0080XZ:R0P2GUiL209VIV@0407]k
N`1/K6`0K6a/07AdM080LW9b00D0L71`08V9R@2KVi/0Vi^K09fMW@0209BDU00509FEU@2DU9@0Rh^;
08^;R`2BTY800P2WYjL01@2m_Kd0b/[:0<[:bP3EeMD0e=CD0080a<C400D0/K6a0:BTY02TY:@0XJ6Q
0:>SX`020::RXP0509RHV02DU9@0U9BD08f=S@2OWil00P2FUYH0102QXJ40/;2`0;2`/02ZZZX209NG
U`050:BTY02KVi/0V9RH09RHV02YZJT00P2WYjL01@2QXJ40YjNW09^KV`2KVi/0Shn?0080QHF500D0
Ti>C07]kN`1kNg/0RXZ:08J6QP0309>CT`80Xj>S00D0UiNG0:NWY`2KVi/0Vi^K0:^[Z`020<K6aP05
0=OGe`2n_[h0`<300<30`02RXZ800P2=SHd01@1dM7@0OWin07inOP24Q8@0Ph>30080RXZ:00D0TI6A
08f=S@2=SHd0S8b<08n?S`0208j>SP0408:2PP2BTY80TY:B096AT@80Z:RX00D0[:b/0<g=c@37alL0
alO70;fm_@0209^KV`0308N7Q`3oool0oooo00d0oooo000=0?ooo`0408^;R`2QXJ40XJ6Q08:2PP80
[:b/00D0MWIf0861P@2HV9P0V9RH0:NWY`0206][J`050:BTY02KVi/0Vi^K06UYJ@35aLD00`1jNWX2
0;bl_005069RHP2KVi/0WYjN09jNWP1gMgL00P2WYjL01@2VYZH0MgMg07MgM`2`/;00F5QH0080YjNW
00D0ZZZZ075aL@1aLG40QHF50:6QX@0207UiN@050<K6aP2@T900T92@05eMG@27QhL00P2_[jl0101]
KFd0l?3`0?3`l010@4020<?3``0506EUI@1bLW80[Zj^0:j^[P27QhL00P2c/k<01@1_Kfl0/k>c06AT
I01TI6@0YJFU0080^[Zj00D0E5AD0;>c/`2c/k<0P82008N7Q`0208n?S`050=3@d00l?3`0?3`l09jN
WP2CTi<00P2i^KT0101XJ6P0QHF508F5Q@2g]kL208:2PP0508Z:RP2@T900WYjN09jNWP1aLG400P2A
TI401@3WinL0:2PX09^KV`2KVi/0^;Rh0080IVIV00D0i>CT04E5A@2[Zj/0Zj^[03De=@020?ooo`05
061PH010@400@4100;^k^`2HV9P00P2=SHd01@2TY:@0VIVI09VIV@1bLW80LG5a0080a<C400@0Lg=c
0:FUY@2UYJD0Lg=c0P2/[:`01@1bLW80a<C4065QH@1QHF40RHV90080TI6A00D0WIfM0;fm_@1IFET0
FEUI0:^[Z`0208f=S@0508j>SP1nOWh0XJ6Q0:6QX@2NWYh00P1/K6`01@2IVIT0UiNG09NGU`2MWId0
QhN70080UYJF00D0Ph>307YjNP1jNWX0fMWI055AD@0208>3P`040;Rh^024Q8@0Q8B407MgM`80YZJV
00D0Ogmo0:BTY02SXj<0Xj>S075aL@020:NWY`030820P03oool0oooo00P0oooo00@0`l?30=3@d03@
d=00d=3@0P2n_[h01@2XZ:P0UiNG08b<S02<S8`0QHF50080S8b<00D0Rh^;08n?S`2?Shl0Zj^[0;6a
/@020:^[Z`050:n_[`2b/[80/[:b09ZJVP2KVi/00P2OWil0102RXZ80V9RH09RHV02JVYX209JFUP05
09jNWP2GUiL0XZ:R0::RXP2][Jd00P2YZJT01@2HV9P0RXZ:0861P@21PH40OWin0080Q8B400D0SXj>
09^KV`2JVYX0VYZJ08^;R`0208F5Q@0508Z:RP2;Rh/0Rh^;09FEU@2SXj<00P2[Zj/01@2UYJD0XZ:R
0::RXP2VYZH0Z:RX0080[jn_00@0g]kN0??cl`3clo<0l?3`0P3WinL01@3Hf=P0YJFU08V9R@29RHT0
QXJ60080VYZJ00D0Xj>S0:ZZZP2d];@0];Bd0:VYZ@02092@T00507moO`1cLg<0Lg=c06m_K`1gMgL0
0P1lO7`01@2;Rh/0UiNG09NGU`2NWYh0Xj>S0080[:b/00D0[jn_0;2`/02`/;00ZZZZ09jNWP0209bL
W00409FEU@2BTY80TY:B08n?S`80TY:B00D0TI6A09RHV02<S8`0S8b<08R8R00209JFUP05096AT@2?
Shl0UiNG09NGU`2UYJD00P2LW9`01@2QXJ40YJFU0:FUY@2UYJD0Z:RX0080XZ:R00D0W9bL09fMW@2M
WId0YJFU0:2PX00209VIV@0508B4Q01_Kfl0Kfm_06MWI`1LG5`00P1[Jf/01021PH40U9BD09BDU02;
Rh/208n?S`0508b<S02CTi<0RHV908V9R@2=SHd00P2@T9001@2EUID0V9RH09RHV02HV9P0WIfM0080
/k>c00D0/;2`09FEU@2EUID0SHf=07YjNP0205iNGP0405aLG01mOGd0OGem0:2PX0l0oooo000=0?oo
o`0409BDU02LW9`0W9bL08:2PP80Zj^[00D0Ng]k07inOP2HV9P0V9RH0::RXP02075aL@050:JVYP2C
Ti<0Ti>C06m_K`31`L400P1nOWh01@1eMGD0_[jn0;jn_P1SHf<0WYjN0080WIfM00@0NGUi0:JVYP2V
YZH0XZ:R0P1kNg/01@2/[:`0FUYJ0:JVYP2VYZH0Zj^[0080Kfm_00D0QXJ60:>SX`1dM7@0M7Ad0<[:
bP0208n?S`0505iNGP27QhL0[jn_0:n_[`1^KVh00P3^k^h01@0l?3`0b<S80<S8b01RHV80MWIf0080
ZZZZ00D0Rh^;0:b/[02/[:`0MWIf0;2`/00205mOG`040:b/[02f][H0][Jf059BDP80_;bl00D0MGEe
08j>SP29RHT0RHV90=GEe@0203/k>`0509nOW`2BTY80]kNg0;Ng]`1/K6`00P20P8001@2c/k<0Rh^;
08^;R`24Q8@0UIFE0080WIfM00D0KFe]09>CT`2CTi<0g=cL03Ti>@0209:BTP050;fm_@1SHf<0Hf=S
0=gMg@1>CTh00P2UYJD0100n?Sh0oooo0?ooo`1IFET20492@P050;jn_P2FUYH0SHf=08f=S@2RXZ80
0P2OWil01@1]KFd0LG5a0<O7a`37alL0LW9b0080XZ:R00D0NWYj0::RXP2RXZ80P8200;Zj^P0205mO
G`0508f=S@2ATI40TI6A09jNWP2j^[X00P1HF5P01@2f][H0N7Qh07QhN02SXj<0M7Ad0080XJ6Q00@0
Vi^K075aL@1aLG40V9RH0P2EUID01@2NWYh0RXZ:092@T02@T900Rh^;0080MWIf00D0e]KF05QHF01g
MgL0MgMg0<30`00208^;R`0506IVIP2h^;P0^;Rh071`L02ZZZX00P2RXZ80101cLg<0YjNW0:NWY`1i
NGT:0?ooo`0408V9R@1iNGT0NGUi06m_K`80KVi^00D0PH6108j>SP2GUiL0UiNG0:JVYP0209bLW005
09NGU`2DU9@0U9BD08N7Q`29RHT00P2CTi<01@2KVi/0Y:BT0:BTY02j^[X0];Bd0080][Jf00@0[:b/
0;Fe]@2e]KD0^;Rh0P31`L401@2l_;`0^k^k0:>SX`2SXj<0Shn?0080SXj>00D0UYJF0:BTY02`/;00
/;2`0;Bd]0020:n_[`050:f][@2TY:@0[:b/0:b/[033`l<00P39bLT01@35aLD0a/K60<K6aP2l_;`0
YJFU0080VIVI00<0WYjN0::RXP2RXZ800P2NWYh209nOW`0408N7Q`22PX80PX:208:2PP80Q8B400<0
Shn?0:BTY02VYZH00P2VYZH209NGU`0508b<S02;Rh/0Ph>308>3P`27QhL00P2BTY801@2FUYH0VIVI
09VIV@2JVYX0U9BD0080W9bL00D0VYZJ09>CT`2CTi<0TI6A08n?S`0208N7Q`0508^;R`2ATI40TI6A
09FEU@1nOWh00P26QXH01024Q8@0OWin07inOP23Ph<209:BTP0507moO`1kNg/0R8R808R8R02>SXh0
0P2KVi/01@2SXj<0Zj^[0:FUY@2UYJD0UiNG0080UIFE00D0V9RH09VIV@2IVIT0TI6A09>CT`0208Z:
RP0507]kN`1ZJVX0JVYZ06MWI`1_Kfl00P1mOGd01@2>SXh0TI6A096AT@2BTY80SHf=0080S8b<00@0
VIVI0;Rh^02h^;P0e=CD0P3Ph>001@3Hf=P0b/[:0;Bd]02d];@0/k>c0080/[:b00D0/k>c0;Jf]P2^
[Zh0[Zj^09NGU`0207alO00507YjNP1gMgL0MgMg07AdM01fMWH00P2CTi<0102DU9@0VYZJ09ZJVP2F
UYH?0?ooo`003@3oool0102DU9@0W9bL09bLW022PX820:^[Z`0507]kN`1nOWh0V9RH09RHV02RXZ80
0P1aLG401@2VYZH0Ti>C09>CT`1_Kfl0`L710080OWin00D0MGEe0;jn_P2n_[h0Hf=S09jNWP0209fM
W@0407UiN@2VYZH0YZJV0::RXP80Ng]k00D0[:b/05YJFP2VYZH0YZJV0:^[Z`0206m_K`0508J6QP2S
Xj<0M7Ad07AdM03:b/X00P2?Shl01@1NGUh0QhN70:n_[`2_[jl0KVi^0080k^k^00D0?3`l0<S8b038
b<P0HV9R07IfMP020:ZZZP0508^;R`2/[:`0[:b/07IfMP2`/;000P1OGel0102/[:`0][Jf0;Jf]P1B
DU820;bl_00507EeM@2>SXh0RHV908V9R@3EeMD00P0k>c/01@2OWil0TY:B0;Ng]`2g]kL0K6a/0080
P82000D0/k>c08^;R`2;Rh/0Q8B409FEU@0209fMW@0506e]K@2CTi<0Ti>C0=cLg00i>CT00P2BTY80
1@2m_Kd0Hf=S06=SH`3MgMd0CTi>0080YJFU00@0?Shn0?ooo`3oool0FEUI0P12@T801@2n_[h0UYJF
08f=S@2=SHd0XZ:R0080WinO00D0KFe]075aL@37alL0alO7079bLP020::RXP0507YjNP2RXZ80XZ:R
0820P02j^[X00P1OGel01@2=SHd0TI6A096AT@2NWYh0^[Zj0080F5QH00D0][Jf07QhN01hN7P0Xj>S
07AdM0020:6QX@0409^KV`1aLG40LG5a09RHV080UIFE00D0WYjN08Z:RP2@T900T92@08^;R`0207If
MP050=KFeP1HF5P0MgMg07MgM`30`<000P2;Rh/01@1VIVH0^;Rh0;Rh^01`L700ZZZZ0080XZ:R00@0
Lg=c0:NWY`2WYjL0NGUi2P3oool01029RHT0NGUi07UiN@1_Kfl206i^KP050861P@2>SXh0UiNG09NG
U`2VYZH00P2LW9`01@2GUiL0U9BD09BDU027QhL0RHV90080Ti>C00D0Vi^K0:BTY02TY:@0^[Zj0;Bd
]0020;Jf]P040:b/[02e]KD0]KFe0;Rh^080`L7100D0_;bl0;^k^`2SXj<0Xj>S08n?S`0208j>SP05
09JFUP2TY:@0/;2`0;2`/02d];@00P2_[jl01@2][Jd0Y:BT0:b/[02/[:`0`l?30080bLW900D0aLG5
0<K6aP36a/H0_;bl0:FUY@0209VIV@0309jNWP2RXZ80XZ:R0080WYjN0P2OWil01027QhL0PX:208:2
PP22PX8208B4Q00308n?S`2TY:@0YZJV0080YZJV0P2GUiL01@2<S8`0Rh^;08>3P`23Ph<0QhN70080
TY:B00D0UYJF09VIV@2IVIT0VYZJ09BDU00209bLW00509ZJVP2CTi<0Ti>C096AT@2?Shl00P27QhL0
1@2;Rh/0TI6A096AT@2EUID0OWin0080QXJ600@0Q8B407inOP1nOWh0Ph>30P2BTY801@1oOgl0Ng]k
08R8R028R8P0SXj>0080Vi^K00D0Xj>S0:^[Z`2UYJD0YJFU09NGU`0209FEU@0509RHV02IVIT0VIVI
096AT@2CTi<00P2:RXX01@1kNg/0JVYZ06YZJP1WIfL0Kfm_0080OGem00D0SXj>096AT@2ATI40TY:B
08f=S@0208b<S00409VIV@2h^;P0^;Rh0=CDe080h>3P00D0f=SH0<[:bP2d];@0];Bd0;>c/`020;:b
/P050;>c/`2f][H0[Zj^0:j^[P2GUiL00P1lO7`01@1jNWX0MgMg07MgM`1dM7@0MWIf0080Ti>C00@0
U9BD09ZJVP2JVYX0UYJF3`3oool000d0oooo00@0W9bL09RHV02HV9P0Ogmo0P2[Zj/01@20P800O7al
09NGU`2GUiL0X:2P0080LW9b00D0[Jf]08f=S@2=SHd0L71`0;no_`0208>3P`0506i^KP31`L40`L71
06IVIP2LW9`00P2JVYX0101lO7`0YZJV0:JVYP2PX:0207alO0050:ZZZP1MGEd0Y:BT0:BTY02[Zj/0
0P1_Kfl01@28R8P0X:2P07AdM01dM7@0c/k>0080S8b<00D0H61P08B4Q02a/K40/K6a06a/K0020?7a
l@0503Ph>03<c<`0c<c<05iNGP1mOGd00P2SXj<01@2=SHd0ZZZZ0:ZZZP1jNWX0[Zj^0080H61P00@0
[:b/0;>c/`2c/k<0GUiN0P2`/;001@1aLG40UiNG08N7Q`27QhL0dM7A0080?Shn00D0YJFU08^;R`2e
]KD0]KFe079bLP0207inOP050:j^[P2ATI40TI6A0861P@2KVi/00P2OWil01@1/K6`0T92@092@T03J
f]X0>c/k0080TI6A00D0`/;2069RHP1RHV80dM7A05]KF`0209ZJVP0404U9B@3oool0oooo04Y:BP80
ATI600D0`l?309JFUP2=SHd0SHf=0:2PX00209bLW00506m_K`1cLg<0b<S80<S8b01bLW800P2KVi/0
1@23Ph<0WIfM09fMW@26QXH0];Bd0080FEUI00D0VIVI08R8R028R8P0Y:BT0;Vi^@0205ADE0050;bl
_01/K6`0K6a/0:j^[P1fMWH00P2OWil0102FUYH0MWIf07IfMP2IVIT209>CT`0509VIV@2ATI40SXj>
08j>SP2ATI400P1_Kfl01@3GemL0GemO06e]K@1]KFd0b<S80080SXj>00D0EeMG0<S8b038b<P0JFUY
0:VYZ@020::RXP0407QhN02YZJT0ZJVY07=cL`X0oooo00@0Ti>C09fMW@2MWId0YJFU0P2b/[801@2`
/;00];Bd0:b/[02/[:`0U9BD0080Ti>C00D0V9RH08R8R028R8P0OWin07alO00206m_K`05069RHP1Q
HF40HF5Q065QH@1^KVh00P1eMGD0101mOGd0OWin07inOP1jNWX207AdM00506m_K`1iNGT0QHF508F5
Q@2BTY800P2HV9P01@2PX:00S8b<08B4Q024Q8@0Ng]k0080NGUi00D0MGEe07emO@1fMWH0MWIf06e]
K@0306QXJ080K6a/00D0LG5a07YjNP1hN7P0N7Qh07=cL`0206QXJ005079bLP1cLg<0KVi^06i^KP1d
M7@00P1jNWX01@1hN7P0QXJ608J6QP2=SHd0UiNG0080Y:BT00D0YZJV09bLW02LW9`0Vi^K08V9R@02
07inOP0407YjNP1bLW80LW9b07YjNP80OGem00D0Ph>308N7Q`26QXH0QXJ607emO@0207inOP0508>3
P`26QXH0VIVI09VIV@2LW9`00P2MWId01@2>SXh0UYJF0:FUY@2UYJD0Zj^[0080^;Rh00D0`L710<K6
aP36a/H0][Jf0;>c/`020:6QX@0509NGU`1nOWh0OWin08:2PP1lO7`00P2>SXh0102MWId0YjNW0:NW
Y`2PX:0209RHV00508n?S`25QHD0QXJ608J6QP2DU9@00P2i^KT01@2h^;P0]kNg0;Ng]`2g]kL0/;2`
0080Y:BT00D0YJFU0;Fe]@2ZZZX0ZZZZ09nOW`0208^;R`050820P01bLW80LW9b08:2PP23Ph<00P2C
Ti<01@2KVi/0XJ6Q0:6QX@2BTY80UIFE0080VIVI00<0YJFU09^KV`2KVi/00`2OWil01@2HV9P0Shn?
09JFUP2FUYH0WIfM0080T92@00<0Rh^;0?ooo`3oool03@3oool000d0oooo00@0Y:BT09BDU02DU9@0
O7al0P2][Jd01@22PX80OGem09BDU02DU9@0WIfM0080MGEe00D0[jn_08V9R@29RHT0M7Ad0;^k^`02
08N7Q`0506m_K`2m_Kd0_Kfm06IVIP2NWYh00P2IVIT0101jNWX0ZJVY0:VYZ@2NWYh207inOP050:ZZ
ZP1NGUh0WinO09nOW`2b/[800P1[Jf/01@29RHT0Xj>S071`L01`L700c/k>0080SHf=00D0HF5Q08F5
Q@2b/[80/[:b06QXJ0020?KfmP0503<c<`3=cLd0cLg=05iNGP25QHD00P2IVIT01@2ATI40ZJVY0:VY
Z@1mOGd0ZZZZ0080HV9R00@0Zj^[0:b/[02/[:`0Jf][0P2/[:`01@1VIVH0Xj>S08Z:RP2:RXX0`/;2
0080B4Q800D0Z:RX0820P02j^[X0^[Zj07AdM00207inOP050:RXZ02DU9@0U9BD0820P02PX:000P2J
VYX01@1dM7@0RXZ:08Z:RP3De=@0@4100080TI6A00D0a<C406IVIP1VIVH0a/K606EUI@0208f=S@04
05IFEP3oool0oooo03Ph>080BDU900D0c<c<092@T02?Shl0Shn?0:>SX`0209VIV@0506e]K@1bLW80
bl_;0<_;b`1aLG400P2HV9P01@27QhL0VIVI09VIV@2ATI40Zj^[0080De=C00D0YZJV0820P020P800
YJFU0;^k^`0205=CD`050;fm_@1]KFd0KFe]0:^[Z`1fMWH00P2PX:00102EUID0MWIf07IfMP2OWil2
08j>SP0509BDU02FUYH0RHV908V9R@2FUYH00P1_Kfl01@3EeMD0GUiN06YZJP1ZJVX0cLg=0080SXj>
00D0Cdm?0<c<c03<c<`0LW9b09jNWP020:>SX`0407emO@2YZJT0ZJVY06a/K0X0oooo00@0Ph>307Yj
NP1jNWX0N7Qh0`1fMWH0101cLg<0QXJ608J6QP2JVYX209NGU`0508Z:RP2GUiL0UiNG0:6QX@2CTi<0
0P2EUID01@2CTi<0Q8B408B4Q01bLW80N7Qh0080PH6100@0UIFE0:BTY02TY:@0/[:b0P2`/;001@2/
[:`0XZ:R09fMW@2MWId0Ti>C0080SXj>00D0Shn?09^KV`2PX:00X:2P0:b/[0020:j^[P050:f][@2V
YZH0Y:BT0:BTY02NWYh00P2LW9`01@2JVYX0W9bL09bLW02GUiL0WIfM0080Zj^[00D0/[:b0;Rh^02h
^;P0_[jn0<30`0020;Vi^@040;jn_P2f][H0][Jf0:n_[`80Y:BT00D0WIfM08>3P`1iNGT0NGUi07in
OP0208b<S00409NGU`2/[:`0_[jn0;jn_P<0_kno0`2d];@01@2g]kL0^[Zj0<S8b038b<P0^;Rh0080
`/;200D0/[:b0:ZZZP28R8P0R8R809^KV`0209>CT`050:VYZ@2d];@0X:2P0:2PX02JVYX00P27QhL0
1@1`L700G5aL05aLG01fMWH0OWin0080TI6A00D0Vi^K0:BTY02TY:@0Vi^K092@T00207AdM00406EU
I@1KFe/0Fe]K06IVIP80OGem00D0V9RH0:JVYP31`L40`L710;Zj^P0209BDU00508n?S`2;Rh/0RXZ:
08Z:RP2;Rh/00P2/[:`01@2XZ:P0X:2P09:BTP2BTY80UYJF0080KFe]00D0JVYZ06e]K@1]KFd0H61P
05EEE@0206YZJP05065QH@1NGUh0GUiN06m_K`1gMgL00P27QhL0102EUID0Zj^[0:^[Z`2m_Kd20<o?
c`050=KFeP3Kfm/0aLG50<G5a@2_[jl00P2SXj<00`2CTi<0oooo0?ooo`0=0?ooo`003@3oool0102T
Y:@0U9BD09BDU01lO7`20:f][@0508:2PP1mOGd0U9BD09BDU02MWId00P1eMGD01@2_[jl0RHV908V9
R@1dM7@0^k^k0080QhN700D0Kfm_0;fm_@2m_Kd0IVIV09jNWP0209VIV@0407YjNP2YZJT0ZJVY09jN
WP80OWin00D0ZZZZ05iNGP2OWil0WinO0;:b/P0206][J`0508V9R@2SXj<0L71`071`L03>c/h00P2=
SHd01@1QHF40QHF50;:b/P2b/[80J6QX0080m_Kf00D0<c<c0<g=c@3=cLd0GUiN08F5Q@0209VIV@05
096AT@2YZJT0ZJVY07emO@2ZZZX00P1RHV80102[Zj/0[:b/0:b/[01[Jf/20:b/[00506IVIP2SXj<0
RXZ:08Z:RP32`/800P18B4P01@2XZ:P0P8200;Zj^P2j^[X0M7Ad0080OWin00D0Z:RX09BDU02DU9@0
P8200:2PX00209ZJVP0507AdM02:RXX0RXZ:0=CDe010@4000P2ATI401@34a<@0IVIV06IVIP36a/H0
IFEU0080SHf=00@0EUIF0?ooo`3oool0>3Ph0P19BDT01@3<c<`0T92@08n?S`2?Shl0Xj>S0080VIVI
00D0KFe]079bLP3;bl/0bl_;075aL@0209RHV00508N7Q`2IVIT0VIVI096AT@2[Zj/00P1CDe<01@2V
YZH0P8200820P02UYJD0^k^k0080De=C00D0_Kfm06e]K@1]KFd0Zj^[07IfMP020:2PX00409FEU@1f
MWH0MWIf09nOW`80SXj>00D0U9BD09JFUP29RHT0RHV909JFUP0206m_K`050=GEe@1NGUh0JVYZ06YZ
JP3=cLd00P2>SXh01@1?Cdl0c<c<0<c<c01bLW80WYjN0080Xj>S00@0OGem0:VYZ@2YZJT0K6a/2P3o
ool01023Ph<0NWYj07YjNP1hN7P307IfMP0407=cL`26QXH0QXJ609ZJVP80UiNG00D0RXZ:09NGU`2G
UiL0XJ6Q09>CT`0209FEU@0509>CT`24Q8@0Q8B4079bLP1hN7P00P21PH40102EUID0Y:BT0:BTY02b
/[820;2`/0050:b/[02RXZ80WIfM09fMW@2CTi<00P2>SXh01@2?Shl0Vi^K0:2PX02PX:00[:b/0080
[Zj^00D0[Jf]0:JVYP2TY:@0Y:BT09jNWP0209bLW00509ZJVP2LW9`0W9bL09NGU`2MWId00P2[Zj/0
1@2b/[80^;Rh0;Rh^02n_[h0`<300080^KVi00@0_[jn0;Jf]P2f][H0[jn_0P2TY:@01@2MWId0Ph>3
07UiN@1iNGT0OWin0080S8b<00@0UiNG0:b/[02n_[h0_[jn0`2o_kl30;Bd]0050;Ng]`2j^[X0b<S8
0<S8b02h^;P00P32`/801@2b/[80ZZZZ08R8R028R8P0Vi^K0080Ti>C00D0ZJVY0;Bd]02PX:00X:2P
09ZJVP0208N7Q`05071`L01LG5`0G5aL07IfMP1nOWh00P2ATI401@2KVi/0Y:BT0:BTY02KVi/0T92@
0080M7Ad00@0IFEU05]KF`1KFe/0IVIV0P1mOGd01@2HV9P0YZJV0<71`@31`L40^[Zj0080U9BD00D0
Shn?08^;R`2:RXX0RXZ:08^;R`020:b/[0050:RXZ02PX:00TY:B09:BTP2FUYH00P1]KFd01@1ZJVX0
KFe]06e]K@1PH600EEEE0080JVYZ00D0HF5Q05iNGP1NGUh0Kfm_07MgM`0208N7Q`0409FEU@2[Zj/0
Zj^[0;fm_@80clo?00D0e]KF0=_Kf`35aLD0aLG50:n_[`020:>SX`0309>CT`3oool0oooo00d0oooo
000=0?ooo`040:JVYP2CTi<0Ti>C07UiN@80[jn_00D0Q8B407YjNP2DU9@0U9BD09fMW@0207EeM@05
0:n_[`2;Rh/0Rh^;075aL@2l_;`00P2:RXX01@1]KFd0_Kfm0;fm_@1RHV80Xj>S0080Vi^K00@0MWIf
0:^[Z`2[Zj/0Vi^K0P22PX801@2UYJD0Hf=S09NGU`2GUiL0^k^k0080I6AT00D0Rh^;0:BTY01`L700
L71`0<[:bP02092@T005061PH026QXH0/[:b0;:b/P1VIVH00P3jn_X01@0_;bl0c/k>0<k>cP1NGUh0
Rh^;0080T92@00D0UYJF0:JVYP2VYZH0Ogmo0:RXZ00206UYJ@040:JVYP2SXj<0Xj>S07]kN`80XZ:R
00D0IFEU0:b/[028R8P0R8R80;^k^`0204e=C@050:n_[`1bLW80`L710<71`@1dM7@00P20P8001@2T
Y:@0UYJF09JFUP1oOgl0YjNW0080TY:B00D0OGem08N7Q`27QhL0bLW904I6AP0209FEU@050<71`@1^
KVh0KVi^0;Bd]01hN7P00P1mOGd0101VIVH0oooo0?ooo`0/;2`204a<C0050=?Cd`2ATI40Rh^;08^;
R`2UYJD00P2CTi<01@1aLG40Kfm_0=?Cd`3Cdm<0JFUY0080VYZJ00D0R8R809NGU`2GUiL0UIFE0:ZZ
ZP0204e=C@050:j^[P1nOWh0OWin0:FUY@2j^[X00P1BDU801@2i^KT0MgMg07MgM`2SXj<0N7Qh0080
XJ6Q00@0TI6A07QhN01hN7P0Xj>S0P28R8P01@2EUID0VIVI08Z:RP2:RXX0UIFE0080L71`00D0clo?
065QH@1^KVh0KVi^0<g=c@02092@T00504Q8B03;bl/0bl_;07inOP2FUYH00P2QXJ40101oOgl0Zj^[
0:^[Z`1ZJVX:0?ooo`040<?3``3AdM40dM7A0=CDe080clo?00D0_Kfm0;Jf]P2FUYH0UYJF0861P@02
08V9R@0509^KV`2OWil0WinO0:^[Z`39bLT00P3Ph>000`3no_h0oooo0?ooo`020?ooo`80emOG00@0
Zj^[08V9R@29RHT0MWIf0P1lO7`01@28R8P0RXZ:08n?S`2?Shl0VYZJ0080TI6A00D0QhN708J6QP1o
Ogl0Ogmo07MgM`020820P00508b<S02=SHd0UYJF09JFUP2SXj<00P2][Jd01@2[Zj/0[:b/0:b/[02^
[Zh0WinO00<0UiNG0P2CTi<01@2?Shl0UIFE096AT@2ATI40U9BD0080Rh^;00D0QXJ607emO@1mOGd0
Shn?092@T00209jNWP<0Zj^[00D0VIVI08j>SP27QhL0QhN708>3P`020861P@0507inOP1eMGD0MGEe
069RHP1MGEd00P1<C4`01@20P800OWin07inOP2=SHd0R8R80080WinO00D0IfMW071`L01`L700JFUY
07AdM00207YjNP0408^;R`2CTi<0Ti>C0:>SX`80ZJVY00D0[jn_0;Bd]02/[:`0[:b/0:RXZ00209jN
WP0509bLW02MWId0Z:RX0:RXZ02UYJD00P2c/k<01@2RXZ80Rh^;08^;R`1jNWX0QXJ60080KFe]00D0
MgMg08V9R@29RHT0WIfM08b<S00208n?S`0508Z:RP1nOWh0OWin08>3P`2GUiL00P2PX:00102UYJD0
`/;20<;2`P2f][H20:b/[0050;^k^`3AdM40`<300<30`036a/H00P35aLD01@2f][H0XJ6Q09>CT`2C
Ti<0R8R80080MgMg00D0Jf][06m_K`1_Kfl0LG5a07alO00209BDU0040:>SX`2UYJD0YJFU0;^k^`l0
oooo000=0?ooo`040:VYZ@2BTY80TY:B07EeM@80[jn_00D0RHV907MgM`2@T900T92@0:2PX00207Mg
M`050;2`/028R8P0R8R806e]K@35aLD00P28R8P01@1]KFd0^[Zj0;Zj^P1MGEd0Zj^[0080Vi^K00@0
M7Ad0:j^[P2^[Zh0U9BD0P26QXH01@2UYJD0HV9R09FEU@2EUID0_kno0080HF5Q00D0SHf=0:FUY@1b
LW80LW9b0<K6aP02096AT@0506ATI024Q8@0/k>c0;>c/`1RHV800P3lo?`01@0_;bl0c/k>0<k>cP1M
GEd0TI6A0080R8R800D0VIVI0:VYZ@2YZJT0Ng]k0:JVYP02075aL@040::RXP2HV9P0V9RH08^;R`80
UYJF00D0JFUY0:j^[P2>SXh0SXj>0:ZZZP0205MGE`050;Fe]@1XJ6P0`/;20<;2`P1gMgL00P21PH40
1@2RXZ80UIFE09FEU@1jNWX0];Bd0080Q8B400D0S8b<08J6QP26QXH0^KVi04i>CP0209RHV0050;Zj
^P1lO7`0O7al09nOW`2;Rh/00P1ZJVX0101iNGT0oooo0?ooo`0_;bl204Y:BP050=[JfP2;Rh/0SHf=
08f=S@2/[:`00P27QhL01@1gMgL0KFe]0=GEe@3EeMD0JFUY0080V9RH00D0R8R809bLW02LW9`0Shn?
0;:b/P0204M7A`050;6a/@20P800P82009nOW`2k^k/00P1JFUX01@2/[:`0R8R808R8R02FUYH0OWin
0080XJ6Q00@0Rh^;0861P@21PH40XZ:R0P21PH401@2MWId0UYJF08^;R`2;Rh/0UYJF0080LG5a00D0
c<c<05YJFP1nOWh0OWin0<;2`P0209>CT`0504E5A@38b<P0b<S808V9R@2>SXh00P2RXZ80101oOgl0
Zj^[0:^[Z`1[Jf/:0?ooo`0408>3P`1nOWh0OWin07QhN080NWYj00D0Q8B408N7Q`2QXJ40XJ6Q0;2`
/0020:^[Z`050:2PX02HV9P0V9RH08:2PP1mOGd00P1hN7P01@1RHV80GemO05mOG`1ZJVX0LW9b0080
QhN700@0XZ:R0:NWY`2WYjL0YZJV0P2SXj<01@2JVYX0VIVI0:>SX`2SXj<0W9bL0080YZJV00D0^;Rh
0;Jf]P2k^k/0^k^k0;jn_P020;:b/P0509jNWP2OWil0U9BD09BDU029RHT00P1jNWX01@20P800O7al
07alO01nOWh0QhN70080TI6A00@0RXZ:08F5Q@25QHD0Ogmo0`1jNWX0101ZJVX0MWIf07IfMP1jNWX2
07QhN00507alO02=SHd0QXJ608J6QP22PX800P25QHD01@2:RXX0Ti>C09RHV02HV9P0XZ:R0080[Zj^
00D0/[:b0<30`030`<00^;Rh0;Fe]@020;Bd]00309BDU029RHT0RHV90080UiNG0P2>SXh01@2e]KD0
/[:b0;:b/P2WYjL0XZ:R0080WYjN00@0RHV908>3P`23Ph<0QHF50P1mOGd01@1^KVh0Hf=S06UYJ@1Y
JFT0JVYZ0080O7al00D0R8R808n?S`2ATI40TI6A09ZJVP0208V9R@0509>CT`2KVi/0Vi^K09NGU`23
Ph<00P2EUID01@2@T900Shn?08n?S`27QhL0TI6A0080WYjN00D0[Zj^0:JVYP2VYZH0VYZJ08^;R`02
07EeM@0405mOG`1YJFT0JFUY07emO@80Ti>C00D0SHf=07YjNP1bLW80LW9b06a/K00205UIF@0506a/
K024Q8@0Ng]k07]kN`1mOGd00P2;Rh/01@26QXH0M7Ad07AdM027QhL0Q8B40080PH6100@0O7al08V9
R@29RHT0Q8B43`3oool000d0oooo00@0ZJVY09:BTP2BTY80MGEe0P2_[jl01@29RHT0MgMg092@T02@
T900X:2P0080MgMg00D0/;2`08R8R028R8P0KFe]0<G5a@0208R8R00506e]K@2j^[X0^[Zj05eMG@2[
Zj/00P2KVi/0101dM7@0[Zj^0:j^[P2DU9@208J6QP050:FUY@1RHV80UIFE09FEU@2o_kl00P1QHF40
1@2=SHd0YJFU079bLP1bLW80a/K60080TI6A00D0I6AT08B4Q02c/k<0/k>c069RHP020?clo00502l_
;`3>c/h0c/k>05eMG@2ATI400P28R8P01@2IVIT0ZJVY0:VYZ@1kNg/0YZJV0080LG5a00@0XZ:R09RH
V02HV9P0Rh^;0P2FUYH01@1YJFT0[Zj^08j>SP2>SXh0ZZZZ0080EeMG00D0]KFe06QXJ032`/80`/;2
07MgM`020861P@050::RXP2EUID0UIFE07YjNP2d];@00P24Q8@01@2<S8`0QXJ608J6QP2i^KT0CTi>
0080V9RH00D0^[Zj07alO01lO7`0WinO08^;R`0206YZJP0407UiN@3oool0oooo02l_;`80BTY:00D0
f][J08^;R`2=SHd0SHf=0:b/[00208N7Q`0507MgM`1]KFd0eMGE0=GEe@1YJFT00P2HV9P01@28R8P0
W9bL09bLW02?Shl0/[:b0080AdM700D0/K6a0820P020P800WinO0;^k^`0205YJFP050:b/[028R8P0
R8R809JFUP1nOWh00P2QXJ40102;Rh/0PH610861P@2RXZ820861P@0509fMW@2FUYH0Rh^;08^;R`2F
UYH00P1aLG401@3<c<`0FUYJ07inOP1nOWh0`/;20080Ti>C00D0ADE50<S8b038b<P0RHV908j>SP02
0::RXP0407moO`2[Zj/0Zj^[06][J`X0oooo00@0Ph>307inOP1nOWh0N7Qh0P1jNWX01@24Q8@0QhN7
0:6QX@2QXJ40/;2`0080Zj^[00D0X:2P09RHV02HV9P0PX:207emO@0207QhN005069RHP1OGel0GemO
06YZJP1bLW800P27QhL0102RXZ80YjNW0:NWY`2VYZH20:>SX`0509ZJVP2IVIT0Xj>S0:>SX`2LW9`0
0P2VYZH01@2h^;P0][Jf0;^k^`2k^k/0_[jn0080/[:b00D0WYjN09nOW`2DU9@0U9BD08V9R@0207Yj
NP050820P01lO7`0O7al07inOP27QhL00P2ATI40102:RXX0QHF508F5Q@1oOgl307YjNP0406YZJP1f
MWH0MWIf07YjNP80N7Qh00D0O7al08f=S@26QXH0QXJ608:2PP0208F5Q@0508Z:RP2CTi<0V9RH09RH
V02RXZ800P2^[Zh01@2b/[80`<300<30`02h^;P0]KFe0080];Bd00<0U9BD08V9R@29RHT00P2GUiL2
08j>SP050;Fe]@2b/[80/[:b0:NWY`2RXZ800P2NWYh01029RHT0Ph>308>3P`25QHD207emO@0506i^
KP1SHf<0JFUY06UYJ@1ZJVX00P1lO7`01@28R8P0Shn?096AT@2ATI40VYZJ0080RHV900D0Ti>C09^K
V`2KVi/0UiNG08>3P`0209FEU@05092@T02?Shl0Shn?08N7Q`2ATI400P2NWYh01@2^[Zh0YZJV0:JV
YP2JVYX0Rh^;0080MGEe00@0GemO06UYJ@1YJFT0OGem0P2CTi<01@2=SHd0NWYj079bLP1bLW80K6a/
0080FEUI00D0K6a/08B4Q01kNg/0Ng]k07emO@0208^;R`0508J6QP1dM7@0M7Ad08N7Q`24Q8@00P21
PH40101lO7`0RHV908V9R@24Q8@?0?ooo`003@3oool0102YZJT0TI6A096AT@1dM7@20:n_[`0508Z:
RP1hN7P0S8b<08b<S02VYZH00P1aLG401@2f][H0QhN708N7Q`1ZJVX0a/K60080RHV900D0LG5a0;Bd
]02d];@0G5aL0:^[Z`0209^KV`04079bLP2e]KD0]KFe08f=S@80Rh^;00D0Y:BT069RHP2ATI40TI6A
0<G5a@0205aLG005092@T02SXj<0Lg=c07=cL`34a<@00P2@T9001@1WIfL0QHF50;6a/@2a/K40GemO
0080oooo00D0<30`0<W9b@39bLT0GemO09FEU@0208F5Q@0509NGU`2][Jd0[Jf]07YjNP2SXj<00P1j
NWX0102PX:00T92@092@T02ATI4208n?S`05071`L02][Jd0Ti>C09>CT`2KVi/00P1XJ6P01@2a/K40
H61P0<O7a`37alL0MWIf0080Q8B400D0X:2P096AT@2ATI40N7Qh0<71`@0207AdM00509bLW024Q8@0
Q8B40;Fe]@14A4@00P2VYZH01@2/[:`0T92@092@T02;Rh/0WIfM0080EEEE00@0TI6A0?ooo`3oool0
<S8b0P1:BTX01@3Jf]X0SXj>08R8R028R8P0^[Zj0080LW9b00D0Q8B406e]K@3@d=00d=3@06e]K@02
09NGU`0508F5Q@2TY:@0Y:BT08:2PP2f][H00P1BDU801@2VYZH0Q8B408B4Q02LW9`0^k^k0080GEeM
00D0XJ6Q09NGU`2GUiL0S8b<07emO@020:RXZ00408:2PP27QhL0QhN70:2PX080PX:200<0VYZJ09RH
V02?Shl00P2?Shl207EeM@050<g=c@1<C4`0VIVI09VIV@2_[jl00P2BTY801@1>CTh0_kno0;no_`2D
U9@0R8R80080Xj>S00@0P8200:VYZ@2YZJT0K6a/2P3oool0102?Shl0T92@092@T02>SXh208B4Q005
08N7Q`2=SHd0Ph>308>3P`1nOWh00`28R8P208V9R@0509>CT`2:RXX0NWYj07YjNP1lO7`00P1`L700
1@1RHV80IfMW06m_K`1_Kfl0JVYZ0080QXJ600D0Shn?09>CT`2CTi<0V9RH0::RXP0208n?S`0509BD
U02ATI40TI6A08N7Q`26QXH00`29RHT2096AT@0509RHV02GUiL0UiNG09NGU`2KVi/00P2NWYh01@2M
WId0VYZJ09ZJVP2LW9`0XJ6Q0080WinO00D0Xj>S0:b/[02/[:`0/K6a0;2`/0020<71`@040=7Ad@3=
cLd0cLg=0=OGe`80gmoO00D0`L710;^k^`2i^KT0^KVi0:ZZZP0209RHV0050::RXP2EUID0RHV908V9
R@23Ph<00P1nOWh01@1oOgl0Q8B408B4Q02PX:00Y:BT0080][Jf00D0`<300;Ng]`2g]kL0ZJVY0;2`
/0020:VYZ@0509:BTP2HV9P0V9RH09fMW@2BTY800P2:RXX0102IVIT0WYjN09jNWP2FUYH20:^[Z`05
0;fm_@3;bl/0a<C40<C4a036a/H00P2g]kL01@2ZZZX0YJFU0:b/[02/[:`0[Jf]0080^k^k0`2[Zj/0
1@2ZZZX0Z:RX09JFUP2FUYH0XJ6Q0080WYjN00D0WinO0:VYZ@2KVi/0Vi^K08n?S`0208j>SP80VIVI
0P2l_;`01038b<P0_Kfm0;fm_@2WYjL2092@T00508>3P`2DU9@0XZ:R0::RXP2VYZH00P2e]KD01@2^
[Zh0X:2P0:RXZ02XZ:P0[jn_0080]KFe00D0Zj^[0:n_[`2_[jl0W9bL08V9R@0208>3P`04096AT@2?
Shl0Shn?08^;R`l0oooo000=0?ooo`040:NWY`2ATI40TI6A07IfMP80[Zj^00D0QhN707moO`26QXH0
QXJ60:RXZ002075aL@050;Zj^P21PH40PH6106i^KP35aLD00P25QHD01@1iNGT0Zj^[0:^[Z`1NGUh0
[Jf]0080WYjN00@0Kfm_0;Fe]@2e]KD0RHV90P2?Shl01@2TY:@0HF5Q09:BTP2BTY80alO70080EeMG
00D0U9BD0:>SX`1cLg<0Lg=c0<71`@0209>CT`0506IVIP27QhL0[:b/0:b/[01SHf<00P3no_h01@0d
=3@0`/;20<;2`P1UIFD0U9BD0080QXJ600D0UYJF0:j^[P2^[Zh0MGEe0:BTY00208B4Q00409ZJVP2=
SHd0SHf=096AT@80Ti>C00D0L71`0:ZZZP2LW9`0W9bL08Z:RP0207MgM`050:b/[01QHF40b<S80<S8
b01`L7000P2=SHd01@2OWil0S8b<08b<S01iNGT0b<S80080J6QX00D0Xj>S08b<S02<S8`0YJFU04Q8
B0020:n_[`0509VIV@2XZ:P0Z:RX07YjNP2WYjL00P14A4@0102VYZH0oooo0?ooo`0d=3@204i>CP05
0=GEe@2@T900Ph>308>3P`3:b/X00P1PH6001@2<S8`0L71`0<71`@31`L40NGUi0080Vi^K00D0OGem
0:NWY`2WYjL0P8200;6a/@0206ATI00509:BTP2ATI40TI6A09^KV`2h^;P00P1QHF401@2GUiL0XJ6Q
0:6QX@2;Rh/0Ng]k0080Z:RX00@0OGem096AT@2ATI40VYZJ0P28R8P209JFUP80Ti>C00D0Q8B408:2
PP22PX80c<c<03/k>`020;Fe]@0409bLW02?Shl0Shn?05]KF`80^KVi00D0U9BD08F5Q@2XZ:P0Z:RX
07emO@020:VYZ@0306e]K@3oool0oooo00P0oooo00@0UiNG092@T02@T900TY:B0P2LW9`01@2CTi<0
Rh^;08j>SP2>SXh0TY:B0080R8R800D0Shn?09VIV@2IVIT0W9bL0:6QX@020:NWY`050:RXZ02/[:`0
[:b/0:b/[02ZZZX00P2`/;00102d];@0WinO09nOW`2TY:@209ZJVP0509>CT`29RHT0Ti>C09>CT`2:
RXX00`2ATI400`2CTi<0S8b<08b<S00308j>SP0509>CT`2IVIT0Vi^K09^KV`2IVIT00P2OWil01@2J
VYX0UiNG09NGU`2IVIT0QhN70080OWin00D0OGem07UiN@1iNGT0NWYj08V9R@0207emO@0406i^KP1[
Jf/0Jf][06QXJ080GemO00D0LG5a07QhN020P800P82007]kN`0208N7Q`05079bLP1_Kfl0LG5a075a
L@22PX800P23Ph<01@2=SHd0Rh^;08^;R`1jNWX0Kfm_0080GemO00D0FUYJ06UYJ@1YJFT0O7al07mo
O`0209NGU`040;2`/02b/[80/[:b0:b/[0<0`<300`2d];@01@2n_[h0WinO09nOW`26QXH0PH610080
NWYj00@0LW9b08^;R`2;Rh/0VIVI0`2KVi/0102CTi<0T92@092@T02JVYX2092@T00509BDU02OWil0
WinO09nOW`2MWId00P2UYJD01@2JVYX0TI6A08N7Q`27QhL0PX:20080Ph>300D0NWYj07UiN@1bLW80
LW9b07]kN`0208>3P`0509fMW@2d];@0];Bd0<30`02d];@00P2ZZZX01@2][Jd0Y:BT0:BTY02SXj<0
YjNW0080Z:RX00@0W9bL09^KV`2KVi/0XJ6Q0P2LW9`01@2UYJD0[jn_0:ZZZP2ZZZX0X:2P0080WinO
00<0W9bL0?ooo`3oool03@3oool000d0oooo00@0YJFU08f=S@2=SHd0OWin0P2][Jd01@20P800RHV9
07emO@1mOGd0ZZZZ0080L71`00D0`<3007alO01lO7`0LG5a0<C4a00208F5Q@0507UiN@2YZJT0ZJVY
06=SH`2WYjL00P2RXZ80101`L700/k>c0;>c/`26QXH209JFUP050:2PX01NGUh0UiNG09NGU`34a<@0
0P1CDe<01@2JVYX0WYjN07MgM`1gMgL0`<300080TI6A00D0J6QX08^;R`2UYJD0YJFU06QXJ0020?_k
n`0503Ph>02m_Kd0_Kfm06UYJ@2BTY800P28R8P01@2EUID0[Jf]0:f][@1eMGD0X:2P0080Shn?00@0
Ti>C092@T02@T900RXZ:0P2BTY801@1kNg/0WinO09nOW`2OWil0Rh^;0080MWIf00D0ZZZZ06MWI`36
a/H0a/K606QXJ00209JFUP0509fMW@29RHT0RHV907]kN`3:b/X00P1RHV801@2QXJ40WIfM09fMW@2D
U9@0C4a<0080^k^k00D0Q8B40;bl_02l_;`0Jf][0;Jf]P02034a<@040;Zj^P3lo?`0o?cl03<c<`80
G5aL00D0a<C409RHV01nOWh0OWin0=KFeP0205EEE@0508f=S@1jNWX0];Bd0;Bd]01oOgl00P2PX:00
1@1dM7@0[Zj^0:j^[P1lO7`0[Zj^0080LW9b00D0Q8B409BDU02DU9@0X:2P0;>c/`0206EUI@0509>C
T`2LW9`0W9bL09>CT`1gMgL00P2/[:`0101iNGT0UiNG09NGU`2BTY82092@T00509>CT`2ATI40W9bL
09bLW01eMGD00P2ATI401@39bLT0:b/[0=;BdP3Bd]80R8R80080SXj>00D0JVYZ0:f][@2][Jd0TY:B
08V9R@020:VYZ@0407emO@2WYjL0YjNW071`L0X0oooo00@0QhN708b<S02<S8`0RXZ:0P2?Shl01@2N
WYh0Z:RX0::RXP2RXZ80YjNW0080ZJVY00D0[:b/09jNWP2NWYh0WYjN09BDU00208b<S00508^;R`2?
Shl0Shn?08j>SP2?Shl00P2:RXX0101hN7P0MgMg07MgM`1cLg<207alO00507moO`27QhL0R8R808R8
R02DU9@00P2ATI401@2CTi<0UiNG09nOW`2OWil0VYZJ0080VIVI00D0UiNG08j>SP2?Shl0Shn?09VI
V@0209>CT`0409NGU`2KVi/0Vi^K09FEU@<0VYZJ00D0UIFE09:BTP2BTY80QHF5075aL@0208N7Q`04
09JFUP2MWId0WIfM0:FUY@80];Bd00@0TY:B07IfMP1hN7P0N7Qh0`1oOgl01@2[Zj/0d=3@0=KFeP3F
e]H0d];B0080c/k>00<0_;bl0;Bd]02d];@00P2l_;`20;fm_@050;Vi^@2f][H0][Jf09fMW@2CTi<0
0P1nOWh01@1hN7P0Kfm_06m_K`1cLg<0KFe]0080N7Qh00@0O7al08>3P`23Ph<0M7Ad0P2;Rh/01@2D
U9@0Ti>C08J6QP26QXH0TI6A0080Ph>300D0P82007alO021PH40PH61096AT@0208b<S00509NGU`2?
Shl0Shn?0:2PX02FUYH00P2GUiL01@2;Rh/0Vi^K09^KV`2<S8`0Shn?0080UYJF00D0Vi^K09JFUP2F
UYH0VYZJ0:2PX00209fMW@0409NGU`2HV9P0V9RH09FEU@80S8b<00<0U9BD09FEU@2IVIT00P2IVIT2
09ZJVP0509VIV@2NWYh0UiNG09NGU`2KVi/00P2LW9`01@2NWYh0XZ:R0::RXP2VYZH0YjNW0080Xj>S
00@0WinO09JFUP2FUYH0Rh^;3`3oool000d0oooo00@0YJFU08f=S@2=SHd0OWin0P2][Jd01@20P800
RHV907emO@1mOGd0ZZZZ0080L71`00D0`<3007alO01lO7`0LG5a0<C4a00208F5Q@0507UiN@2YZJT0
ZJVY06=SH`2WYjL00P2RXZ80101`L700/k>c0;>c/`26QXH209JFUP050:2PX01NGUh0UiNG09NGU`34
a<@00P1CDe<01@2JVYX0WYjN07MgM`1gMgL0`<300080TI6A00D0J6QX08^;R`2UYJD0YJFU06QXJ002
0?_kn`0503Ph>02m_Kd0_Kfm06UYJ@2BTY800P28R8P01@2EUID0[Jf]0:f][@1eMGD0X:2P0080Shn?
00@0Ti>C092@T02@T900RXZ:0P2BTY801@1kNg/0WinO09nOW`2OWil0Rh^;0080MWIf00D0ZZZZ06MW
I`36a/H0a/K606QXJ00209JFUP0509fMW@29RHT0RHV907]kN`3:b/X00P1RHV801@2QXJ40WIfM09fM
W@2DU9@0C4a<0080^k^k00D0Q8B40;bl_02l_;`0Jf][0;Jf]P02034a<@040;Zj^P3lo?`0o?cl03<c
<`80G5aL00D0a<C409RHV01nOWh0OWin0=KFeP0205EEE@0508f=S@1jNWX0];Bd0;Bd]01oOgl00P2P
X:001@1dM7@0[Zj^0:j^[P1lO7`0[Zj^0080LW9b00D0Q8B409BDU02DU9@0X:2P0;>c/`0206EUI@05
09>CT`2LW9`0W9bL09>CT`1gMgL00P2/[:`0101iNGT0UiNG09NGU`2BTY82092@T00509>CT`2ATI40
W9bL09bLW01eMGD00P2ATI401@39bLT0:b/[0=;BdP3Bd]80R8R80080SXj>00D0JVYZ0:f][@2][Jd0
TY:B08V9R@020:VYZ@0407emO@2WYjL0YjNW071`L0X0oooo00@0QhN708b<S02<S8`0RXZ:0P2?Shl0
1@2NWYh0Z:RX0::RXP2RXZ80YjNW0080ZJVY00D0[:b/09jNWP2NWYh0WYjN09BDU00208b<S00508^;
R`2?Shl0Shn?08j>SP2?Shl00P2:RXX0101hN7P0MgMg07MgM`1cLg<207alO00507moO`27QhL0R8R8
08R8R02DU9@00P2ATI401@2CTi<0UiNG09nOW`2OWil0VYZJ0080VIVI00D0UiNG08j>SP2?Shl0Shn?
09VIV@0209>CT`0409NGU`2KVi/0Vi^K09FEU@<0VYZJ00D0UIFE09:BTP2BTY80QHF5075aL@0208N7
Q`0409JFUP2MWId0WIfM0:FUY@80];Bd00@0TY:B07IfMP1hN7P0N7Qh0`1oOgl01@2[Zj/0d=3@0=KF
eP3Fe]H0d];B0080c/k>00<0_;bl0;Bd]02d];@00P2l_;`20;fm_@050;Vi^@2f][H0][Jf09fMW@2C
Ti<00P1nOWh01@1hN7P0Kfm_06m_K`1cLg<0KFe]0080N7Qh00@0O7al08>3P`23Ph<0M7Ad0P2;Rh/0
1@2DU9@0Ti>C08J6QP26QXH0TI6A0080Ph>300D0P82007alO021PH40PH61096AT@0208b<S00509NG
U`2?Shl0Shn?0:2PX02FUYH00P2GUiL01@2;Rh/0Vi^K09^KV`2<S8`0Shn?0080UYJF00D0Vi^K09JF
UP2FUYH0VYZJ0:2PX00209fMW@0409NGU`2HV9P0V9RH09FEU@80S8b<00<0U9BD09FEU@2IVIT00P2I
VIT209ZJVP0509VIV@2NWYh0UiNG09NGU`2KVi/00P2LW9`01@2NWYh0XZ:R0::RXP2VYZH0YjNW0080
Xj>S00@0WinO09JFUP2FUYH0Rh^;3`3oool000d0oooo00@0XJ6Q08f=S@2=SHd0QHF50P2/[:`01@1m
OGd0Shn?07EeM@1eMGD0[Zj^0080L71`00D0alO7079bLP1bLW80MGEe0<30`00208V9R@0507QhN02U
YJD0YJFU06e]K@2NWYh00P2RXZ80101dM7@0/K6a0;6a/@27QhL209FEU@050::RXP1MGEd0VYZJ09ZJ
VP33`l<00P1?Cdl01@2QXJ40W9bL07IfMP1fMWH0`<300080SXj>00D0JVYZ092@T02KVi/0Vi^K06m_
K`020?Gem@0503hn?P2h^;P0^;Rh06UYJ@2DU9@00P25QHD01@2GUiL0[Zj^0:j^[P1cLg<0VIVI0080
WYjN00@0S8b<09BDU02DU9@0PH610P2DU9@01@26QXH0Ti>C0:VYZ@2YZJT0QhN70080MWIf00D0YJFU
071`L033`l<0`l?305mOG`020::RXP0509^KV`27QhL0QhN707emO@34a<@00P1ZJVX01@2EUID0[Jf]
0:f][@29RHT0De=C0080_kno00D0Kfm_0<o?c`3?cll0IFEU0;^k^`02028R8P040=;BdP3Xj>P0j>SX
03@d=080K6a/00D0]KFe09^KV`1oOgl0Ogmo0=WIf@0205IFEP0508F5Q@24Q8@0Zj^[0:^[Z`24Q8@0
0P2QXJ401@1`L700/[:b0;:b/P1mOGd0XZ:R0080Ph>300D0N7Qh09BDU02DU9@0Z:RX0:j^[P02061P
H0050::RXP2;Rh/0Rh^;09bLW01hN7P00P2XZ:P0101mOGd0UiNG09NGU`2ATI4309>CT`0408b<S02O
Wil0WinO06QXJ080Y:BT00D0`L7101lO7`3Vi^H0i^KV07emO@0208b<S00507UiN@2KVi/0Vi^K09bL
W023Ph<00P2^[Zh0101kNg/0Z:RX0:RXZ01`L70:0?ooo`040::RXP2VYZH0YZJV09nOW`80W9bL00D0
UYJF08b<S029RHT0RHV908^;R`0208:2PP0507inOP2CTi<0Ti>C08j>SP2BTY800P2OWil01@2QXJ40
TY:B09:BTP2LW9`0Y:BT0080Vi^K00@0YjNW0:f][@2][Jd0[:b/0P2OWil0102_[jl0[:b/0:j^[P2^
[Zh30:b/[0050:2PX02FUYH0Shn?08n?S`2=SHd00P2:RXX01@23Ph<0Rh^;08J6QP26QXH0Q8B40080
Rh^;00D0TI6A08j>SP2>SXh0S8b<09:BTP0209bLW00509nOW`2VYZH0YZJV0;Rh^02c/k<00P2?Shl0
1024Q8@0PX:208:2PP1fMWH2071`L0050:>SX`38b<P0`L710<71`@32`/800P3>c/h01@2_[jl0Q8B4
0861P@21PH40P8200080NGUi00D0PH6108>3P`23Ph<0QHF508:2PP0207moO`0507]kN`21PH40PH61
08F5Q@2?Shl00`2GUiL209ZJVP0509^KV`2IVIT0UIFE09FEU@2?Shl00P2=SHd01@2FUYH0TY:B09:B
TP2GUiL0Vi^K0080];Bd00D0/K6a0;Bd]02d];@0Y:BT09^KV`0208>3P`04079bLP1VIVH0IVIV07If
MP80T92@00D0QhN708j>SP2DU9@0U9BD09VIV@0208Z:RP050:JVYP2`/;00/[:b0;:b/P2^[Zh00P36
a/H01@31`L40]KFe0;Bd]02d];@0YjNW0080Ti>C00D0SXj>09BDU02DU9@0Vi^K0:>SX`0209ZJVP05
08j>SP2CTi<0Ti>C08N7Q`25QHD00P28R8P01022PX80NGUi07UiN@1iNGT207MgM`05079bLP1lO7`0
Ogmo07moO`29RHT00P2@T9000`2OWil0oooo0?ooo`0=0?ooo`003@3oool0102JVYX0SHf=08f=S@2<
S8`20:b/[00507UiN@2ATI40LG5a075aL@2][Jd00P1aLG401@3>c/h0J6QX06QXJ01nOWh0^KVi0080
SXj>00D0N7Qh0:6QX@2QXJ40N7Qh09>CT`020:BTY00307QhN02/[:`0[:b/00<0Shn?00D0XZ:R05mO
G`2GUiL0UiNG0<C4a00204];B`050:JVYP2HV9P0N7Qh07QhN02n_[h00P2ATI401@1VIVH0V9RH08j>
SP2>SXh0N7Qh0080lO7a00D0@T920;:b/P2b/[80K6a/09NGU`020820P00509jNWP2XZ:P0Z:RX07Mg
M`2ATI400P2[Zj/01026QXH0UYJF09JFUP1lO7`209BDU00508j>SP2:RXX0Zj^[0:^[Z`2:RXX00P1f
MWH01@2QXJ40N7Qh0<30`030`<00EEEE0080[:b/00D0VIVI08R8R028R8P0PH610;Ng]`0207MgM`05
0820P030`<00`<3007moO`1LG5`00P2n_[h01@1UIFD0eMGE0=GEe@1]KFd0][Jf00806ATI00@0hn?S
0=[JfP3Jf]X0<c<c0P1mOGd01@2TY:@0WinO08:2PP22PX80eMGE0080Fe]K00D0NWYj08f=S@2][Jd0
[Jf]0820P00209jNWP0507MgM`2XZ:P0Z:RX08f=S@2DU9@00P29RHT01@1eMGD0Ti>C09>CT`2`/;00
YZJV0080G5aL00D0];Bd07IfMP1fMWH0XZ:R07moO`0209jNWP0308N7Q`2?Shl0Shn?00<0UIFE00D0
TY:B08V9R@2PX:00X:2P065QH@020;>c/`050;Vi^@0J6QX0lO7a0?7al@1iNGT00P29RHT01@27QhL0
SXj>08j>SP2MWId0QhN70080[Jf]00@0Ng]k0:BTY02TY:@0MWIf2P3oool0101nOWh0P8200820P02:
RXX208f=S@0509VIV@2PX:00YjNW0:NWY`2SXj<00P2ZZZX01@2TY:@0TY:B09:BTP2FUYH0Ti>C0080
RHV900D0Rh^;09jNWP2NWYh0U9BD08n?S`0209:BTP0408n?S`2>SXh0SXj>09FEU@80X:2P00D0UiNG
08j>SP22PX80PX:2079bLP0206IVIP0506m_K`1kNg/0Ogmo07moO`21PH400P2=SHd01@2BTY80Ti>C
09fMW@2MWId0UiNG0080SXj>00D0S8b<096AT@2ATI40TY:B09^KV`0209VIV@0509fMW@2GUiL0UiNG
09:BTP2KVi/00P2m_Kd01034a<@0`<300<30`03=cLd20=3@d0050:>SX`2KVi/0VIVI09VIV@25QHD0
0P1`L7001@1oOgl0O7al08:2PP22PX80QXJ60080VYZJ00D0YjNW0;2`/02`/;00[Jf]0;>c/`020:b/
[00509nOW`2ATI40TI6A09NGU`2JVYX00P2DU9@01@2CTi<0UIFE09FEU@2@T900TI6A0080WIfM00@0
X:2P0:b/[02/[:`0];Bd0P2a/K401@2b/[80[:b/09nOW`2OWil0Shn?0080RXZ:00D0XZ:R0<G5a@3H
f=P0f=SH0>c/k0020?KfmP050=WIf@3?cll0clo?0;bl_036a/H00P33`l<01@2i^KT0Xj>S0:>SX`2K
Vi/0Shn?0080UYJF00D0WIfM0820P020P800NWYj07IfMP02071`L00407IfMP2FUYH0UYJF0::RXP80
VYZJ00D0Rh^;08F5Q@2?Shl0Shn?09>CT`0208Z:RP0509>CT`2>SXh0QXJ608J6QP2PX:000P2a/K40
1@2h^;P0`/;20<;2`P39bLT0/k>c0080[:b/00@0WYjN09JFUP2FUYH0QhN73`3oool000d0oooo00@0
VYZJ08f=S@2=SHd0S8b<0P2/[:`01@1iNGT0TI6A075aL@1aLG40[Jf]0080LG5a00D0c/k>06QXJ01X
J6P0OWin0;Vi^@0208j>SP0507QhN02QXJ40XJ6Q07QhN02CTi<00P2TY:@00`1hN7P0[:b/0:b/[003
08n?S`050::RXP1OGel0UiNG09NGU`34a<@00P1;Bd/01@2VYZH0V9RH07QhN01hN7P0_[jn0080TI6A
00D0IVIV09RHV02>SXh0SXj>07QhN0020?7al@050492@P2b/[80/[:b06a/K02GUiL00P20P8001@2N
WYh0Z:RX0:RXZ01gMgL0TI6A0080Zj^[00@0QXJ609JFUP2FUYH0O7al0P2DU9@01@2>SXh0RXZ:0:^[
Z`2[Zj/0RXZ:0080MWIf00D0XJ6Q07QhN030`<00`<3005EEE@020:b/[00509VIV@28R8P0R8R80861
P@2g]kL00P1gMgL01@20P800`<300<30`01oOgl0G5aL0080_[jn00D0IFEU0=GEe@3EeMD0KFe]0;Jf
]P0201TI6@040>?Sh`3Jf]X0f][J03<c<`80OGem00D0Y:BT09nOW`22PX80PX:20=GEe@0205]KF`05
07YjNP2=SHd0[Jf]0:f][@20P8000P2NWYh01@1gMgL0Z:RX0:RXZ02=SHd0U9BD0080RHV900D0MGEe
09>CT`2CTi<0/;2`0:JVYP0205aLG0050;Bd]01fMWH0MWIf0::RXP1oOgl00P2NWYh00`27QhL0Shn?
08n?S`0309FEU@0509:BTP29RHT0X:2P0:2PX01QHF400P2c/k<01@2i^KT06QXJ0?7al@3alO40NGUi
0080RHV900D0QhN708j>SP2>SXh0WIfM08N7Q`020:f][@0407]kN`2TY:@0Y:BT07IfMPX0oooo00@0
OWin0820P020P800RXZ:0P2=SHd01@2IVIT0X:2P0:NWY`2WYjL0Xj>S0080ZZZZ00D0Y:BT09:BTP2B
TY80UYJF09>CT`0208V9R@0508^;R`2NWYh0WYjN09BDU02?Shl00P2BTY80102?Shl0SXj>08j>SP2E
UID20:2PX00509NGU`2>SXh0PX:208:2PP1bLW800P1VIVH01@1_Kfl0Ng]k07moO`1oOgl0PH610080
SHf=00D0TY:B09>CT`2MWId0WIfM09NGU`0208j>SP0508b<S02ATI40TI6A09:BTP2KVi/00P2IVIT0
1@2MWId0UiNG09NGU`2BTY80Vi^K0080_Kfm00@0a<C40<30`030`<00cLg=0P3@d=001@2SXj<0Vi^K
09VIV@2IVIT0QHF50080L71`00D0Ogmo07alO022PX80PX:208J6QP0209ZJVP050:NWY`2`/;00/;2`
0:f][@2c/k<00P2/[:`01@2OWil0TI6A096AT@2GUiL0VYZJ0080U9BD00D0Ti>C09FEU@2EUID0T92@
096AT@0209fMW@040:2PX02/[:`0[:b/0;Bd]080/K6a00D0/[:b0:b/[02OWil0WinO08n?S`0208Z:
RP050::RXP35aLD0f=SH0=SHf03/k>`00P3fm_H01@3IfMT0clo?0<o?c`2l_;`0a/K60080`l?300D0
^KVi0:>SX`2SXj<0Vi^K08n?S`0209JFUP0509fMW@20P800P82007YjNP1fMWH00P1`L700101fMWH0
UYJF09JFUP2RXZ8209ZJVP0508^;R`25QHD0Shn?08n?S`2CTi<00P2:RXX01@2CTi<0SXj>08J6QP26
QXH0X:2P0080/K6a00D0^;Rh0<;2`P32`/80bLW90;>c/`020:b/[00409jNWP2FUYH0UYJF08N7Q`l0
oooo000=0?ooo`0408f=S@2BTY80TY:B096AT@80[Jf]00D0MGEe09:BTP1`L700L71`0:VYZ@0207Qh
N0050<o?c`1RHV80HV9R0861P@2f][H00P2?Shl01@1kNg/0W9bL09bLW01mOGd0SHf=0080Xj>S00@0
O7al0:RXZ02XZ:P0V9RH0P26QXH01@2UYJD0HF5Q09RHV02HV9P0`<300080Bd];00D0ZZZZ09JFUP1j
NWX0NWYj0;bl_00209BDU00306=SH`2OWil0Ph>30080Ph>30P3Xj>P01@18B4P0[jn_0:n_[`1/K6`0
VYZJ0080NWYj00D0YZJV0:6QX@2QXJ40Ng]k08N7Q`020;Rh^00408:2PP2DU9@0U9BD07QhN080UiNG
00D0U9BD08B4Q02/[:`0[:b/08j>SP0206a/K0050:>SX`22PX80^k^k0;^k^`1<C4`00P2g]kL01@2F
UYH0RXZ:08Z:RP27QhL0YJFU0080RXZ:00D0KVi^0<g=c@3=cLd0NGUi06EUI@020;fm_@0505iNGP3B
d]80d];B07MgM`2`/;000P0E5AD0103bl_80b<S80<S8b00a<C42096AT@0509bLW02JVYX0RHV908V9
R@39bLT00P1/K6`01@1WIfL0UYJF0;>c/`2c/k<0Ng]k0080Vi^K00D0P82009^KV`2KVi/0VYZJ092@
T00207emO@0508F5Q@28R8P0R8R80;Jf]P2OWil00P1NGUh01@33`l<0Hf=S06=SH`2UYJD0RXZ:0080
Ti>C00@0T92@08J6QP26QXH0WinO0P2<S8`01@2MWId0PH610:2PX02PX:00GEeM0080_kno00D0[Zj^
01lO7`3_knl0kno_07emO@020861P@05092@T02:RXX0RXZ:09NGU`2=SHd00P2/[:`0101jNWX0Xj>S
0:>SX`1nOWh:0?ooo`040;6a/@2SXj<0Xj>S0:NWY`80Vi^K00D0S8b<08^;R`2>SXh0SXj>08N7Q`02
09:BTP0509JFUP2ATI40TI6A08n?S`2BTY800P2@T9001@2JVYX0XZ:R0::RXP2SXj<0W9bL0080Vi^K
00@0V9RH09>CT`2CTi<0Ph>30P24Q8@01@21PH40Q8B408Z:RP2:RXX0WIfM0080[jn_00D0]kNg0;Bd
]02i^KT0^KVi0;jn_P020;6a/@80[jn_0P2SXj<0102WYjL0[Zj^0:j^[P2YZJT20:RXZ0050:ZZZP2P
X:00UYJF09JFUP2GUiL00P2:RXX01@23Ph<0PH6107IfMP1fMWH0KVi^0080LW9b00D0KVi^06ATI01T
I6@0M7Ad07UiN@0208>3P`0509bLW02^[Zh0[Zj^0:NWY`2`/;000P2QXJ40102ATI40R8R808R8R022
PX8207AdM00508R8R02;Rh/0RHV908V9R@2=SHd00P2OWil01@2CTi<0TY:B09FEU@2EUID0VIVI0080
TY:B00D0UYJF09^KV`2JVYX0VYZJ09^KV`0208n?S`0508N7Q`1oOgl0Ogmo08B4Q01jNWX00P26QXH0
1@2<S8`0Ph>308>3P`1^KVh0JFUY0080FEUI00@0EEEE06MWI`1WIfL0Lg=c0P1jNWX01@2<S8`0Ph>3
07inOP1nOWh0Q8B40080TY:B00D0OWin08j>SP29RHT0RHV907alO00208F5Q@050:2PX02QXJ40YjNW
0:NWY`2h^;P00P2PX:001@2GUiL0U9BD09BDU02>SXh0QhN70080Rh^;00D0QHF5092@T02@T900S8b<
08n?S`0209NGU`0409:BTP1_Kfl0Kfm_07IfMP80KVi^00D0IFEU06ATI026QXH0QXJ609>CT`0209^K
V`030:BTY03oool0oooo00d0oooo000=0?ooo`0408:2PP2FUYH0UYJF09JFUP80[:b/00D0MWIf08Z:
RP1hN7P0N7Qh0::RXP0207inOP050<k>cP1PH600H61P0820P02d];@00P2EUID01@1mOGd0UIFE09FE
U@27QhL0R8R80080X:2P00@0OGem0:VYZ@2YZJT0WYjN0P1nOWh01@2[Zj/0H61P09JFUP2FUYH0`<30
0080C4a<00D0[:b/09BDU01jNWX0NWYj0;Zj^P0209NGU`05065QH@2TY:@0Ng]k07]kN`29RHT00P3T
i>@01@1:BTX0[jn_0:n_[`1ZJVX0WYjN0080MWIf00D0Zj^[09ZJVP2JVYX0Ph>307]kN`020<C4a004
08:2PP2ATI40TI6A07EeM@80UYJF00D0W9bL0820P02WYjL0YjNW09VIV@02069RHP050:FUY@27QhL0
^KVi0;Vi^@18B4P00P2j^[X01@2GUiL0SXj>08j>SP28R8P0VIVI0080UIFE00D0HF5Q0=?Cd`3Cdm<0
MWIf06i^KP020;Rh^005065QH@39bLT0bLW90861P@2/[:`00P0A4A40103oool0];Bd0;Bd]00_;bl2
0:2PX00509NGU`2HV9P0SXj>08j>SP2i^KT00P1kNg/01@1HF5P0WYjN0<30`030`<00LW9b0080Ti>C
00D0Rh^;09>CT`2CTi<0XZ:R092@T002071`L00509FEU@1mOGd0OGem0;^k^`2KVi/00P1KFe/01@3B
d]80EeMG05MGE`2SXj<0Shn?0080TI6A00@0UIFE0820P020P800YjNW0P1iNGT01@2/[:`0O7al0:6Q
X@2QXJ40Fe]K0080bLW900D0WIfM02l_;`3Vi^H0i^KV08N7Q`0207QhN00509VIV@20P800P82009bL
W02?Shl00P2/[:`0101fMWH0Y:BT0:BTY023Ph<:0?ooo`0408^;R`2KVi/0Vi^K0:6QX@80[Jf]0P2i
^KT20;Rh^0040:j^[P2FUYH0UYJF08^;R`80UIFE00D0TI6A09NGU`2PX:00X:2P09>CT`030861P@04
08B4Q025QHD0QHF508n?S`80T92@0`2KVi/209nOW`80ZZZZ00D0Y:BT09RHV02HV9P0UYJF08n?S`03
08^;R`80UiNG00<0V9RH09fMW@2OWil00P2OWil209bLW00509jNWP2RXZ80XZ:R09nOW`2PX:000P2V
YZH01@2WYjL0^KVi0;Vi^@32`/80a/K60080^;Rh00@0];Bd0:RXZ02XZ:P0XJ6Q0P2VYZH01@2/[:`0
XJ6Q09ZJVP2JVYX0T92@0080Q8B400D0P82008Z:RP2BTY80TY:B09RHV00209>CT`0509bLW02WYjL0
YjNW0::RXP2ZZZX00P2d];@01@2g]kL0/;2`0;2`/02YZJT0Z:RX0080YZJV00D0[Jf]0:b/[02/[:`0
/k>c0:6QX@0209^KV`0408b<S02;Rh/0Rh^;08f=S@80U9BD00@0UYJF0:f][@2YZJT0ZJVY0`2WYjL0
1@2ZZZX0VIVI09BDU02DU9@0T92@0080Ogmo00D0L71`06e]K@1]KFd0K6a/06MWI`0207emO@0508^;
R`22PX80PX:209FEU@2?Shl00`2;Rh/209^KV`0508b<S02MWId0VIVI09VIV@2DU9@00P2>SXh01@27
QhL0PX:208:2PP20P800RHV90080Ph>300D0T92@09FEU@2EUID0Vi^K09JFUP0209ZJVP0408n?S`2Z
ZZX0ZZZZ09nOW`80YjNW00D0/;2`0<G5a@2KVi/0Vi^K0:2PX00209RHV00309FEU@3oool0oooo00d0
oooo000=0?ooo`0407MgM`2JVYX0VYZJ09VIV@80Zj^[00D0NWYj07inOP25QHD0QHF509RHV00208F5
Q@050<[:bP1RHV80HV9R0820P02c/k<00P2EUID01@25QHD0R8R808R8R02ATI40QHF50080VYZJ00@0
PX:20:VYZ@2YZJT0XJ6Q0P1eMGD01@2d];@0HF5Q08n?S`2?Shl0`L710080C4a<00D0[Jf]09FEU@1g
MgL0MgMg0;Rh^0020:2PX00505YJFP2YZJT0MGEe07EeM@2>SXh00P3Ph>001@1@D500[:b/0:b/[01Y
JFT0XZ:R0080LW9b00D0[Zj^09NGU`2GUiL0QhN707=cL`020<c<c00408B4Q02:RXX0RXZ:07QhN080
T92@00D0YZJV07emO@2SXj<0Xj>S09bLW00205iNGP050:NWY`2:RXX0]KFe0;Fe]@18B4P00P2k^k/0
1@2GUiL0TI6A096AT@27QhL0UIFE0080V9RH00D0GEeM0=7Ad@3AdM40N7Qh07EeM@020:j^[P05071`
L02g]kL0]kNg08f=S@2UYJD00P0A4A40103oool0XJ6Q0:6QX@0b<S820:JVYP0509VIV@2FUYH0Ti>C
09>CT`2/[:`00P1oOgl01@1JFUX0VYZJ0<o?c`3?cll0JVYZ0080S8b<00D0VIVI08V9R@29RHT0Xj>S
09BDU00206IVIP0509jNWP1gMgL0MgMg0<71`@2GUiL00P1HF5P01@3Lg=`0E5AD05ADE02NWYh0UYJF
0080SHf=00@0TY:B08B4Q024Q8@0[Jf]0P1UIFD01@2j^[X0NWYj09jNWP2NWYh0GemO0080b/[:00D0
T92@04E5A@3?cll0clo?09NGU`0207AdM00509JFUP1nOWh0OWin09nOW`2BTY800P2][Jd0101_Kfl0
YZJV0:JVYP29RHT:0?ooo`040:6QX@2KVi/0Vi^K08J6QP80P82000D0NWYj07MgM`1fMWH0MWIf08N7
Q`020:2PX0050:RXZ02SXj<0Xj>S09jNWP2HV9P00P2=SHd01@2>SXh0Vi^K09^KV`2VYZH0YjNW0080
ZZZZ00@0ZJVY0:NWY`2WYjL0YJFU0`2TY:@0102VYZH0WinO09nOW`2PX:020:NWY`0509VIV@2KVi/0
V9RH09RHV02BTY800`23Ph<0101lO7`0N7Qh07QhN01bLW8207EeM@0507IfMP1^KVh0KVi^07MgM`1l
O7`00P1hN7P01@1eMGD0LW9b079bLP1YJFT0IfMW0080Ogmo00@0QHF509>CT`2CTi<0WYjN0P2ZZZX0
1@2MWId0Xj>S0:FUY@2UYJD0Xj>S0080WinO00@0YZJV0:6QX@2OWil0WinO0`2SXj<01@2DU9@0Rh^;
08^;R`1lO7`0NGUi00<0M7Ad0P1cLg<01@1mOGd0O7al08:2PP22PX80O7al0080P82000D0PX:208^;
R`2;Rh/0Rh^;09BDU00209FEU@0509JFUP2MWId0WIfM09VIV@2=SHd00P2>SXh01@2?Shl0SHf=08f=
S@2=SHd0UiNG0080[Jf]00@0_[jn0<W9b@39bLT0c/k>0P36a/H01@2c/k<0/K6a09jNWP2NWYh0UiNG
0080WYjN00D0Xj>S08n?S`2;Rh/0Rh^;09:BTP0208n?S`0509>CT`2JVYX0Vi^K09^KV`2[Zj/00P2`
/;001@2h^;P0^KVi0;Vi^@32`/80ZZZZ0080[Zj^00D0V9RH09ZJVP2JVYX0V9RH0:NWY`020:RXZ004
0:>SX`2KVi/0Vi^K09fMW@80S8b<00D0RHV908^;R`2CTi<0Ti>C09JFUP0209VIV@0309RHV03oool0
oooo00d0oooo000=0?ooo`0407MgM`2JVYX0VYZJ09VIV@80Zj^[00D0NWYj07inOP25QHD0QHF509RH
V00208F5Q@050<[:bP1RHV80HV9R0820P02c/k<00P2EUID01@25QHD0R8R808R8R02ATI40QHF50080
VYZJ00@0PX:20:VYZ@2YZJT0XJ6Q0P1eMGD01@2d];@0HF5Q08n?S`2?Shl0`L710080C4a<00D0[Jf]
09FEU@1gMgL0MgMg0;Rh^0020:2PX00505YJFP2YZJT0MGEe07EeM@2>SXh00P3Ph>001@1@D500[:b/
0:b/[01YJFT0XZ:R0080LW9b00D0[Zj^09NGU`2GUiL0QhN707=cL`020<c<c00408B4Q02:RXX0RXZ:
07QhN080T92@00D0YZJV07emO@2SXj<0Xj>S09bLW00205iNGP050:NWY`2:RXX0]KFe0;Fe]@18B4P0
0P2k^k/01@2GUiL0TI6A096AT@27QhL0UIFE0080V9RH00D0GEeM0=7Ad@3AdM40N7Qh07EeM@020:j^
[P05071`L02g]kL0]kNg08f=S@2UYJD00P0A4A40103oool0XJ6Q0:6QX@0b<S820:JVYP0509VIV@2F
UYH0Ti>C09>CT`2/[:`00P1oOgl01@1JFUX0VYZJ0<o?c`3?cll0JVYZ0080S8b<00D0VIVI08V9R@29
RHT0Xj>S09BDU00206IVIP0509jNWP1gMgL0MgMg0<71`@2GUiL00P1HF5P01@3Lg=`0E5AD05ADE02N
WYh0UYJF0080SHf=00@0TY:B08B4Q024Q8@0[Jf]0P1UIFD01@2j^[X0NWYj09jNWP2NWYh0GemO0080
b/[:00D0T92@04E5A@3?cll0clo?09NGU`0207AdM00509JFUP1nOWh0OWin09nOW`2BTY800P2][Jd0
101_Kfl0YZJV0:JVYP29RHT:0?ooo`040:6QX@2KVi/0Vi^K08J6QP80P82000D0NWYj07MgM`1fMWH0
MWIf08N7Q`020:2PX0050:RXZ02SXj<0Xj>S09jNWP2HV9P00P2=SHd01@2>SXh0Vi^K09^KV`2VYZH0
YjNW0080ZZZZ00@0ZJVY0:NWY`2WYjL0YJFU0`2TY:@0102VYZH0WinO09nOW`2PX:020:NWY`0509VI
V@2KVi/0V9RH09RHV02BTY800`23Ph<0101lO7`0N7Qh07QhN01bLW8207EeM@0507IfMP1^KVh0KVi^
07MgM`1lO7`00P1hN7P01@1eMGD0LW9b079bLP1YJFT0IfMW0080Ogmo00@0QHF509>CT`2CTi<0WYjN
0P2ZZZX01@2MWId0Xj>S0:FUY@2UYJD0Xj>S0080WinO00@0YZJV0:6QX@2OWil0WinO0`2SXj<01@2D
U9@0Rh^;08^;R`1lO7`0NGUi00<0M7Ad0P1cLg<01@1mOGd0O7al08:2PP22PX80O7al0080P82000D0
PX:208^;R`2;Rh/0Rh^;09BDU00209FEU@0509JFUP2MWId0WIfM09VIV@2=SHd00P2>SXh01@2?Shl0
SHf=08f=S@2=SHd0UiNG0080[Jf]00@0_[jn0<W9b@39bLT0c/k>0P36a/H01@2c/k<0/K6a09jNWP2N
WYh0UiNG0080WYjN00D0Xj>S08n?S`2;Rh/0Rh^;09:BTP0208n?S`0509>CT`2JVYX0Vi^K09^KV`2[
Zj/00P2`/;001@2h^;P0^KVi0;Vi^@32`/80ZZZZ0080[Zj^00D0V9RH09ZJVP2JVYX0V9RH0:NWY`02
0:RXZ0040:>SX`2KVi/0Vi^K09fMW@80S8b<00D0RHV908^;R`2CTi<0Ti>C09JFUP0209VIV@0309RH
V03oool0oooo00d0oooo000=0?ooo`0406][J`2NWYh0WYjN09bLW080ZJVY00<0Ng]k07UiN@2?Shl0
0P2?Shl208^;R`050<;2`P1WIfL0IfMW08>3P`2^[Zh00P2ATI401@2GUiL0MWIf07IfMP2HV9P0QHF5
0080U9BD00@0QHF50:ZZZP2ZZZX0VIVI0P20P8001@2g]kL0G5aL08n?S`2?Shl0_Kfm0080DE5A00D0
[:b/09>CT`1jNWX0NWYj0;>c/`020:JVYP0505EEE@2[Zj/0LW9b079bLP2DU9@00P3MgMd01@1@D500
Z:RX0:RXZ01/K6`0Y:BT0080L71`00D0[jn_09JFUP2FUYH0RHV906e]K@020=3@d00408Z:RP1oOgl0
Ogmo08>3P`80QXJ600D0/;2`07alO02JVYX0VYZJ0:6QX@0205eMG@050:NWY`2?Shl0[jn_0:n_[`1:
BTX00P2m_Kd309BDU00508V9R@2DU9@0UYJF09JFUP1VIVH00P34a<@01@1kNg/0O7al0::RXP2RXZ80
QhN70080XJ6Q00D0UYJF09fMW@0F5QH05QHF0?ooo`0209:BTP0503Hf=P2XZ:P0Z:RX09^KV`2IVIT0
0P2DU9@01@2SXj<0NWYj07YjNP1/K6`0Rh^;0080f][J00@0HV9R08Z:RP2:RXX0XZ:R0P1oOgl01@2T
Y:@0VIVI069RHP1RHV80XZ:R0080Lg=c00D0a/K608n?S`1LG5`0G5aL0=SHf002061PH00309FEU@2J
VYX0SXj>0080SXj>0P27QhL01@2a/K40EEEE05EEE@34a<@0Ng]k0080W9bL00D0IVIV0<?3``33`l<0
S8b<05QHF0020<30`00409VIV@1eMGD0MGEe08n?S`80RHV900D0UIFE09fMW@2WYjL0YjNW071`L002
0:BTY00309:BTP3oool0oooo00P0oooo00@0RHV908>3P`23Ph<0Shn?0P22PX801@1nOWh0O7al0861
P@21PH40OWin0080Ogmo00D0QhN709:BTP2BTY80UiNG0::RXP020:FUY@050:BTY02JVYX0VYZJ09FE
U@2<S8`00P29RHT01023Ph<0P8200820P026QXH308Z:RP0408N7Q`2;Rh/0Rh^;08>3P`80O7al00D0
Q8B408J6QP21PH40PH6108:2PP0208B4Q00508f=S@2DU9@0YZJV0:JVYP2^[Zh00P2a/K401@2ZZZX0
Z:RX0:RXZ02MWId0Vi^K00<0XJ6Q0P2VYZH01@2WYjL0WYjN08Z:RP2:RXX0TI6A0080Rh^;00D0Ph>3
07]kN`1kNg/0R8R807emO@0207IfMP0507alO023Ph<0Ph>307inOP27QhL00P2>SXh0102=SHd0UiNG
09NGU`2IVIT209fMW@050:BTY02UYJD0YJFU0:FUY@2c/k<00P2b/[820:^[Z`80/;2`00D0Zj^[0:RX
Z02XZ:P0Xj>S09nOW`0209BDU00409JFUP2>SXh0SXj>08V9R@80QhN700D0Shn?09NGU`2KVi/0Vi^K
0:FUY@020:JVYP0509bLW02<S8`0PX:208:2PP1ZJVX00P1WIfL01@1lO7`0QhN708N7Q`2PX:00Zj^[
0080XJ6Q0`2@T9001@28R8P0TI6A0:2PX02PX:00/;2`0080[Jf]00D0Zj^[0:BTY02_[jl0[jn_09VI
V@0209BDU00507inOP1oOgl0Ogmo07alO02;Rh/00P2BTY801@2PX:00YjNW0:NWY`2OWil0U9BD0080
Shn?00<0WinO08b<S02<S8`00`2;Rh/01@1oOgl0L71`08F5Q@25QHD0O7al0080PH6100<0R8R80?oo
o`3oool03@3oool000d0oooo00@0J6QX09fMW@2MWId0Xj>S0P2RXZ801@1nOWh0M7Ad09ZJVP2JVYX0
QhN70080SXj>00D0_Kfm06][J`1[Jf/0QHF50:RXZ00208n?S`050:JVYP1WIfL0IfMW09bLW02:RXX0
0P2=SHd01029RHT0ZJVY0:VYZ@2ATI4208n?S`050;2`/01NGUh0Shn?08n?S`2h^;P00P1EEED01@2[
Zj/0TY:B07alO01lO7`0/k>c0080Xj>S00D0EeMG0:^[Z`1aLG40LG5a09ZJVP020=KFeP0505=CD`2U
YJD0YJFU06m_K`2QXJ400P1dM7@01@2/[:`0UiNG09NGU`2:RXX0IfMW0080e=CD00@0SHf=07emO@1m
OGd0Ph>30P1nOWh01@2k^k/0O7al09BDU02DU9@0XZ:R0080FUYJ00D0Zj^[096AT@2[Zj/0Zj^[04a<
C0020;bl_00508j>SP2JVYX0VYZJ08F5Q@2JVYX00P2>SXh01@1fMWH0];Bd0;Bd]01nOWh0O7al0080
WinO00D0VYZJ08n?S`2?Shl0UiNG09ZJVP0201XJ6P040?ooo`23Ph<0Ph>303`l?080Xj>S00D0WYjN
0::RXP2>SXh0SXj>09nOW`0207UiN@0507MgM`23Ph<0g=cL0=cLg01OGel00P2@T9001@2RXZ80OGem
07emO@2NWYh0WinO0080HV9R00D0YZJV06a/K01/K6`0clo?08J6QP0206=SH`050<o?c`1ZJVX0JVYZ
09>CT`2GUiL00P2CTi<01027QhL0SHf=08f=S@2a/K4204Y:BP050<_;b`1lO7`0W9bL09bLW01YJFT0
0P2n_[h01@25QHD0KVi^0:n_[`2_[jl0W9bL0080MgMg00@0Q8B409FEU@2EUID0TI6A0`2QXJ40101`
L700Z:RX0:RXZ02BTY8:0?ooo`0409ZJVP2OWil0WinO09fMW@80Y:BT00D0[:b/0;:b/P2b/[80/[:b
0;2`/0020:NWY`0309jNWP2HV9P0V9RH0080UiNG0P2KVi/01@2MWId0WYjN09jNWP2HV9P0X:2P0080
Y:BT00<0YZJV0:6QX@2QXJ400`2OWil01@2NWYh0YjNW0:n_[`2_[jl0]kNg0080];Bd00D0^;Rh0;Fe
]@35aLD0aLG50<[:bP020<g=c@050;Zj^P2/[:`0TI6A096AT@27QhL00P1nOWh01@2;Rh/0UYJF09JF
UP2PX:00Vi^K0080WIfM00D0UiNG096AT@2ATI40T92@09^KV`020:6QX@040:BTY02HV9P0V9RH09^K
V`80WinO00D0Xj>S0:b/[02k^k/0^k^k0;bl_0020;fm_@050;Rh^02[Zj/0[:b/0:b/[02SXj<00P2I
VIT01@2CTi<0UYJF09JFUP24Q8@0Rh^;0080S8b<00D0TI6A08j>SP2>SXh0V9RH09^KV`0209:BTP05
092@T02?Shl0Shn?09RHV02BTY800P2KVi/0102OWil0Z:RX0:RXZ02PX:0209NGU`0508b<S021PH40
L71`071`L01iNGT00P27QhL01@2JVYX0Vi^K0:JVYP2VYZH0YJFU0080XZ:R00D0QXJ607inOP1nOWh0
MGEe079bLP02071`L00508>3P`27QhL0QhN708f=S@27QhL00P2;Rh/01@22PX80NWYj07YjNP1jNWX0
Lg=c0080KFe]00@0Kfm_08R8R028R8P0UiNG0P2YZJT01@2UYJD0/K6a0:JVYP2VYZH0YjNW0080XJ6Q
00D0[Jf]09bLW02RXZ80XZ:R09ZJVP020:2PX00509jNWP2][Jd0[Jf]0;Jf]P2o_kl01@2d];@00`2W
YjL0oooo0?ooo`0=0?ooo`003@3oool0101XJ6P0WIfM09fMW@2SXj<20::RXP0507inOP1dM7@0VYZJ
09ZJVP27QhL00P2>SXh01@2m_Kd0Jf][06][J`25QHD0Z:RX0080Shn?00D0YZJV06MWI`1WIfL0W9bL
08Z:RP0208f=S@0408V9R@2YZJT0ZJVY096AT@80Shn?00D0/;2`05iNGP2?Shl0Shn?0;Rh^00205EE
E@050:^[Z`2BTY80O7al07alO02c/k<00P2SXj<01@1GEeL0Zj^[075aL@1aLG40VYZJ0080e]KF00D0
De=C0:FUY@2UYJD0Kfm_0:6QX@0207AdM0050:b/[02GUiL0UiNG08Z:RP1WIfL00P3De=@0102=SHd0
OGem07emO@23Ph<207inOP050;^k^`1lO7`0U9BD09BDU02RXZ800P1JFUX01@2[Zj/0TI6A0:^[Z`2[
Zj/0C4a<0080_;bl00D0SXj>09ZJVP2JVYX0QHF509ZJVP0208j>SP0507IfMP2d];@0];Bd07inOP1l
O7`00P2OWil01@2JVYX0Shn?08n?S`2GUiL0VYZJ00806QXJ00@0oooo08>3P`23Ph<0?3`l0P2SXj<0
1@2NWYh0XZ:R08j>SP2>SXh0WinO0080NGUi00D0MgMg08>3P`3Lg=`0g=cL05mOG`02092@T0050::R
XP1mOGd0OGem09jNWP2OWil00P1RHV801@2VYZH0K6a/06a/K03?cll0QXJ60080Hf=S00D0clo?06YZ
JP1ZJVX0Ti>C09NGU`0209>CT`0408N7Q`2=SHd0SHf=0;6a/@80BTY:00D0bl_;07alO02LW9`0W9bL
06UYJ@020;jn_P0508F5Q@1^KVh0[jn_0:n_[`2LW9`00P1gMgL01024Q8@0UIFE09FEU@2ATI430:6Q
X@04071`L02XZ:P0Z:RX09:BTPX0oooo00@0VYZJ09nOW`2OWil0WIfM0P2TY:@01@2/[:`0/[:b0;:b
/P2b/[80/;2`0080YjNW00<0WYjN09RHV02HV9P00P2GUiL209^KV`0509fMW@2NWYh0WYjN09RHV02P
X:000P2TY:@00`2VYZH0XJ6Q0:6QX@0309nOW`0509jNWP2WYjL0[jn_0:n_[`2g]kL00P2d];@01@2h
^;P0]KFe0<G5a@35aLD0b/[:0080cLg=00D0^[Zj0:b/[02ATI40TI6A08N7Q`0207inOP0508^;R`2F
UYH0UYJF0:2PX02KVi/00P2MWId01@2GUiL0TI6A096AT@2@T900Vi^K0080XJ6Q00@0Y:BT09RHV02H
V9P0Vi^K0P2OWil01@2SXj<0[:b/0;^k^`2k^k/0_;bl0080_Kfm00D0^;Rh0:^[Z`2/[:`0[:b/0:>S
X`0209VIV@0509>CT`2FUYH0UYJF08B4Q02;Rh/00P2<S8`01@2ATI40SXj>08j>SP2HV9P0Vi^K0080
TY:B00D0T92@08n?S`2?Shl0V9RH09:BTP0209^KV`0409nOW`2XZ:P0Z:RX0:2PX080UiNG00D0S8b<
0861P@1`L700L71`07UiN@0208N7Q`0509ZJVP2KVi/0YZJV0:JVYP2UYJD00P2RXZ801@26QXH0OWin
07inOP1eMGD0LW9b0080L71`00D0Ph>308N7Q`27QhL0SHf=08N7Q`0208^;R`0508:2PP1jNWX0NWYj
07YjNP1cLg<00P1]KFd0101_Kfl0R8R808R8R02GUiL20:VYZ@050:FUY@2a/K40YZJV0:JVYP2WYjL0
0P2QXJ401@2][Jd0W9bL0::RXP2RXZ80VYZJ0080X:2P00D0WYjN0:f][@2][Jd0][Jf0;no_`050;Bd
]0030:NWY`3oool0oooo00d0oooo000=0?ooo`0406][J`2DU9@0U9BD0:n_[`80UYJF00D0Q8B4071`
L02TY:@0Y:BT07emO@0209FEU@050;Fe]@1_Kfl0Kfm_08Z:RP2RXZ800P2>SXh01@2_[jl0G5aL05aL
G02QXJ40SXj>0080QhN700@0SHf=0:>SX`2SXj<0TI6A0P2FUYH01@2][Jd0GUiN092@T02@T900/k>c
0080Fe]K00D0ZJVY092@T022PX80PX:20:b/[0020:>SX`0505QHF02ZZZX0LG5a075aL@2PX:000P3=
cLd01@1JFUX0WIfM09fMW@1fMWH0WYjN0080NGUi00D0Z:RX09VIV@2IVIT0S8b<069RHP020=CDe004
09BDU01hN7P0N7Qh08Z:RP80Lg=c00D0aLG507UiN@2GUiL0UiNG09^KV`0205UIF@050;:b/P2>SXh0
ZJVY0:VYZ@1CDe<00P2h^;P01@2:RXX0WinO09nOW`21PH40X:2P0080Ph>300D0RHV90:FUY@2UYJD0
PH6107YjNP0209fMW@030:b/[022PX80PX:20080UYJF0P0M7Ad0103oool0MgMg07MgM`14A4@209VI
V@050:6QX@2[Zj/0S8b<08b<S02JVYX00P1fMWH01@23Ph<0NWYj0=_Kf`3Kfm/0GemO0080UYJF00D0
Vi^K08J6QP26QXH0UYJF0:FUY@0205eMG@050:JVYP1YJFT0JFUY0=WIf@1kNg/00P1/K6`01@36a/H0
Kfm_06m_K`2HV9P0Shn?0080V9RH00@0PH6109FEU@2EUID0ZJVY0P1CDe<01@32`/80QHF509NGU`2G
UiL0L71`0080]kNg00D0NWYj08N7Q`2QXJ40XJ6Q09bLW00307emO@80VIVI00D0T92@0::RXP2MWId0
WIfM07=cL`020:JVYP0309BDU03oool0oooo00P0oooo00@0ZZZZ0:j^[P2^[Zh0/;2`0P2^[Zh01@2P
X:00Vi^K09JFUP2FUYH0SXj>0080QhN700<0S8b<07inOP1nOWh00P1_Kfl307=cL`80OWin00D0TI6A
08j>SP2=SHd0SHf=06YZJP02079bLP0506YZJP1PH600H61P05iNGP1fMWH00P1[Jf/01@1ZJVX0LG5a
075aL@1`L700Ng]k0080KVi^00D0JVYZ06UYJ@1YJFT0KVi^07MgM`0209FEU@040:BTY02`/;00/;2`
0:n_[`80YjNW00D0V9RH09NGU`2HV9P0V9RH0:6QX@020:2PX00509nOW`2KVi/0TI6A096AT@27QhL0
0P2@T9001@2HV9P0Vi^K09^KV`2MWId0V9RH0080S8b<00D0P82007MgM`1gMgL0N7Qh08:2PP0208>3
P`0408j>SP2@T900T92@09NGU`80RHV900D0S8b<08^;R`2@T900T92@08F5Q@0209:BTP05092@T028
R8P0SXj>08j>SP2FUYH00P2DU9@01@2HV9P0X:2P09^KV`2KVi/0WinO0080XJ6Q00D0WYjN09nOW`2O
Wil0WIfM08b<S00208>3P`0508R8R02>SXh0SXj>09>CT`2YZJT00`2n_[h20;Bd]0050;>c/`2/[:`0
[:b/0:>SX`2KVi/00P2YZJT01@2`/;00^KVi0;Vi^@2d];@0^[Zj0080YjNW00D0TI6A08V9R@29RHT0
RHV909NGU`0209fMW@040:FUY@2LW9`0W9bL09RHV080OGem00D0MgMg07EeM@1[Jf/0Jf][06UYJ@02
06YZJP0508B4Q02FUYH0Y:BT0:BTY02OWil00P2XZ:P01@2DU9@0SXj>08j>SP1jNWX0MGEe0080MWIf
00@0NGUi07AdM01dM7@0TI6A3`3oool000d0oooo00@0KVi^08b<S02<S8`0^k^k0P28R8P01@2:RXX0
Lg=c0:NWY`2WYjL0MWIf0080V9RH00D0[jn_07EeM@1eMGD0SHf=09ZJVP0208j>SP050;Ng]`1FEUH0
EUIF09nOW`2FUYH00P1oOgl0102CTi<0W9bL09bLW02>SXh20:JVYP050::RXP1PH600TY:B09:BTP2^
[Zh00P1MGEd01@2[Zj/0SXj>08R8R028R8P0ZJVY0080WinO00D0FUYJ0:^[Z`1aLG40LG5a0:NWY`02
0<71`@0506QXJ02@T900T92@07alO02IVIT00P20P8001@2RXZ80Vi^K09^KV`2@T900GUiN0080c/k>
00@0W9bL07IfMP1fMWH0RHV90P1aLG401@3=cLd0MGEe09^KV`2KVi/0T92@0080GEeM00D0][Jf08V9
R@2ZZZX0ZZZZ05YJFP020;>c/`0508R8R02OWil0WinO0861P@2TY:@00P1jNWX01@2KVi/0VYZJ09ZJ
VP21PH40N7Qh0080Vi^K00D0^k^k07MgM`1gMgL0VIVI08n?S`0202HV9P040?ooo`1^KVh0KVi^04];
B`80SXj>00D0YJFU0:ZZZP2DU9@0U9BD09:BTP0207UiN@0508^;R`1bLW80emOG0=OGe`1OGel00P2N
WYh01@2@T900TI6A096AT@28R8P0/k>c0080EeMG00D0YjNW06IVIP1VIVH0h>3P071`L00207MgM`05
0;no_`1]KFd0KFe]09jNWP2:RXX00P2OWil0101iNGT0Vi^K09^KV`2OWil206ATI0050;>c/`2=SHd0
SXj>08j>SP1nOWh00P2[Zj/01@1iNGT0Ti>C09RHV02HV9P0UYJF0080QhN700D0MGEe0:6QX@2QXJ40
Rh^;0:FUY@0209RHV00407MgM`2TY:@0Y:BT09JFUPX0oooo00@0NGUi071`L01`L700O7al0P20P800
1@2@T900UiNG09nOW`2OWil0[jn_0080/;2`00D0[:b/0;:b/P2b/[80`l?30;2`/0020:ZZZP0509nO
W`2CTi<0Ti>C0820P02=SHd00P2@T9001032`/80e]KF0=KFeP3IfMT20=SHf0040=CDe02_[jl0XZ:R
0::RXP<0YjNW0P2/[:`20:^[Z`<0ZZZZ00D0[Zj^0:b/[02OWil0WinO09NGU`0208n?S`0508^;R`21
PH40PH6108f=S@2?Shl00P2;Rh/00`26QXH0Shn?08n?S`02096AT@80XZ:R00@0YjNW0:BTY02TY:@0
UYJF0P2ATI401@26QXH0RHV908j>SP2>SXh0WIfM0080Y:BT102OWil0102EUID0UiNG09NGU`2CTi<2
09JFUP0509FEU@2CTi<0Shn?08n?S`2LW9`00P2<S8`01@2?Shl0TI6A096AT@2ATI40S8b<0080VIVI
00D0S8b<08^;R`2>SXh0SXj>08f=S@0208^;R`0509:BTP2IVIT0VIVI09>CT`2OWil00P33`l<01@2i
^KT0/k>c0;>c/`2][Jd0U9BD0080IfMW00@0JVYZ071`L01`L700OWin0P2DU9@01@2IVIT0YjNW0:NW
Y`2WYjL0XZ:R0080T92@00D0V9RH09jNWP2OWil0WinO0:^[Z`020;Jf]P050:NWY`2CTi<0S8b<08b<
S01fMWH00P1^KVh01@1eMGD0PH610861P@2<S8`0UiNG0080Y:BT00D0YJFU09nOW`2OWil0NWYj07Ad
M00206UYJ@0407=cL`1mOGd0OGem09jNWP80YZJV00D0];Bd0;:b/P2[Zj/0Zj^[09^KV`0209VIV@03
08:2PP3oool0oooo00d0oooo000=0?ooo`0406i^KP2<S8`0S8b<0;^k^`80R8R800D0RXZ:07=cL`2W
YjL0YjNW07IfMP0209RHV0050:n_[`1eMGD0MGEe08f=S@2JVYX00P2>SXh01@2g]kL0EUIF05IFEP2O
Wil0UYJF0080Ogmo00@0Ti>C09bLW02LW9`0SXj>0P2VYZH01@2RXZ80H61P09:BTP2BTY80[Zj^0080
GEeM00D0Zj^[08j>SP28R8P0R8R80:VYZ@0209nOW`0505YJFP2[Zj/0LG5a075aL@2WYjL00P31`L40
1@1XJ6P0T92@092@T01lO7`0VIVI0080P82000D0XZ:R09^KV`2KVi/0T92@05iNGP020<k>cP0409bL
W01fMWH0MWIf08V9R@80LG5a00D0cLg=07EeM@2KVi/0Vi^K092@T00205eMG@050;Jf]P29RHT0ZZZZ
0:ZZZP1JFUX00P2c/k<01@28R8P0WinO09nOW`21PH40Y:BT0080NWYj00D0Vi^K09ZJVP2JVYX0PH61
07QhN00209^KV`050;^k^`1gMgL0MgMg09VIV@2?Shl00P0V9RH0103oool0KVi^06i^KP1;Bd/208j>
SP050:FUY@2ZZZX0U9BD09BDU02BTY800P1iNGT01@2;Rh/0LW9b0=OGe`3GemL0GemO0080WYjN00D0
T92@096AT@2ATI40R8R80;>c/`0205MGE`050:NWY`1VIVH0IVIV0>3Ph01`L7000P1gMgL01@2o_kl0
KFe]06e]K@2NWYh0RXZ:0080WinO00@0NGUi09^KV`2KVi/0WinO0P1TI6@01@2c/k<0SHf=08j>SP2>
SXh0OWin0080Zj^[00D0NGUi09>CT`2HV9P0V9RH09JFUP0208N7Q`0507EeM@2QXJ40XJ6Q08^;R`2U
YJD00P2HV9P0101gMgL0Y:BT0:BTY02FUYH:0?ooo`0407UiN@1`L700L71`07alO080P82000D0T92@
09NGU`2OWil0WinO0:n_[`020;2`/0050:b/[02b/[80/[:b0<?3``2`/;000P2ZZZX01@2OWil0Ti>C
09>CT`20P800SHf=0080T92@00@0`/;20=KFeP3Fe]H0fMWI0P3Hf=P0103De=@0[jn_0::RXP2RXZ83
0:NWY`80[:b/0P2[Zj/30:ZZZP050:j^[P2/[:`0WinO09nOW`2GUiL00P2?Shl01@2;Rh/0PH610861
P@2=SHd0Shn?0080Rh^;00<0QXJ608n?S`2?Shl00P2ATI420::RXP040:NWY`2TY:@0Y:BT09JFUP80
TI6A00D0QXJ608V9R@2>SXh0SXj>09fMW@020:BTY0@0WinO00@0UIFE09NGU`2GUiL0Ti>C0P2FUYH0
1@2EUID0Ti>C08n?S`2?Shl0W9bL0080S8b<00D0Shn?096AT@2ATI40TI6A08b<S00209VIV@0508b<
S02;Rh/0SXj>08j>SP2=SHd00P2;Rh/01@2BTY80VIVI09VIV@2CTi<0WinO0080`l?300D0^KVi0;>c
/`2c/k<0[Jf]09BDU00206MWI`0406YZJP1`L700L71`07inOP80U9BD00D0VIVI0:NWY`2WYjL0YjNW
0::RXP02092@T00509RHV02NWYh0WinO09nOW`2[Zj/00P2f][H01@2WYjL0Ti>C08b<S02<S8`0MWIf
0080KVi^00D0MGEe0861P@21PH40S8b<09NGU`020:BTY0050:FUY@2OWil0WinO07YjNP1dM7@00P1Y
JFT0101cLg<0OGem07emO@2NWYh20:JVYP050;Bd]02b/[80Zj^[0:^[Z`2KVi/00P2IVIT00`22PX80
oooo0?ooo`0=0?ooo`003@3oool0101cLg<0QXJ608J6QP33`l<207alO00509>CT`1aLG40ZZZZ0:ZZ
ZP1cLg<00P2LW9`01@2VYZH0NGUi07UiN@2BTY80U9BD0080SXj>00D0_[jn05=CD`1CDe<0Vi^K0:2P
X00207MgM`0409BDU02NWYh0WYjN08>3P`80^k^k00D0TI6A065QH@2HV9P0V9RH0:NWY`0206ATI005
0:JVYP2@T900S8b<08b<S02XZ:P00P2DU9@01@1SHf<0YjNW07AdM01dM7@0[Jf]0080]KFe00D0MGEe
08F5Q@25QHD0PX:209>CT`0208V9R@0509nOW`2GUiL0UiNG09FEU@1NGUh00P35aLD0102PX:00NGUi
07UiN@25QHD207AdM0050<_;b`1dM7@0Xj>S0:>SX`23Ph<00P1UIFD01@2c/k<0R8R80:^[Z`2[Zj/0
I6AT0080Z:RX00D0SHf=09NGU`2GUiL0QhN70:BTY00207UiN@050::RXP2BTY80TY:B0820P01hN7P0
0P2MWId01@2n_[h0MGEe07EeM@2GUiL0RXZ:0080:b/[00@0oooo06ATI01TI6@0DU9B0P25QHD01@2[
Zj/0Y:BT09jNWP2NWYh0RHV90080PX:200D0R8R807UiN@39bLT0bLW906=SH`020:>SX`0508F5Q@2Q
XJ40XJ6Q07YjNP2l_;`00P1JFUX01@2KVi/0LG5a075aL@3MgMd0JFUY0080Q8B400D0^[Zj06=SH`1S
Hf<0ZJVY08N7Q`0209nOW`0407UiN@2KVi/0Vi^K09JFUP80NGUi00D0XZ:R09NGU`22PX80PX:208Z:
RP020::RXP0507YjNP2LW9`0Ti>C09>CT`2ATI400P2:RXX01@1eMGD0YjNW0:NWY`27QhL0YJFU0080
TY:B00@0Ogmo0:6QX@2QXJ40UYJF2P3oool00`2;Rh/0TY:B09:BTP0308N7Q`0508Z:RP1lO7`0Ng]k
07]kN`1jNWX00P27QhL01@2<S8`0WIfM09fMW@2YZJT0]kNg0080^;Rh00D0`<300<;2`P32`/80_kno
0;^k^`020;>c/`040;:b/P2PX:00X:2P0:2PX080Vi^K00D0WIfM08b<S02CTi<0Ti>C08R8R00208N7
Q`0508R8R02:RXX0UYJF09JFUP2KVi/00P2LW9`00`2FUYH0U9BD08F5Q@0208F5Q@80QhN700D0QHF5
08V9R@29RHT0Shn?08^;R`0208N7Q`0508j>SP2DU9@0U9BD096AT@2CTi<00P2<S8`01023Ph<0Q8B4
08B4Q02;Rh/208:2PP0508Z:RP2<S8`0QXJ608J6QP23Ph<00`26QXH01023Ph<0OWin07inOP27QhL2
08j>SP0509fMW@2QXJ40XJ6Q0:JVYP2LW9`00P2JVYX01@2;Rh/0Ti>C09>CT`2@T900SXj>0080S8b<
00@0SHf=08N7Q`27QhL0Rh^;0`2?Shl00`2>SXh0T92@092@T00309RHV0050:FUY@2TY:@0Ti>C09>C
T`2;Rh/00P2=SHd01@20P800RHV909^KV`2KVi/0T92@0080S8b<00D0RXZ:08J6QP26QXH0P82007mo
O`0207QhN00506i^KP1RHV80HV9R069RHP1ZJVX00P1dM7@01@2;Rh/0WinO09nOW`2_[jl0];Bd0080
[Zj^00@0YjNW0:JVYP2VYZH0Xj>S0P2XZ:P0102_[jl0];Bd0;Ng]`2g]kL30;2`/080_Kfm0P2WYjL0
102RXZ80WYjN09jNWP2IVIT2092@T00409bLW02XZ:P0WIfM09fMW@<0VYZJ00<0U9BD0?ooo`3oool0
3@3oool000d0oooo00@0Ng]k07alO01lO7`0d=3@0P1_Kfl01@2JVYX0L71`0:f][@2][Jd0Kfm_0080
XJ6Q00D0Vi^K07alO01lO7`0V9RH092@T002096AT@050;Vi^@1FEUH0EUIF09^KV`2UYJD00P1bLW80
102BTY80XZ:R0::RXP21PH420;no_`0508Z:RP1RHV80WinO09nOW`2QXJ400P1XJ6P01@2UYJD0Ti>C
08f=S@2=SHd0ZZZZ0080RHV900D0J6QX0:JVYP1gMgL0MgMg0:b/[0020:j^[P0508>3P`1gMgL0MgMg
08N7Q`2<S8`00P2HV9P01@2CTi<0Vi^K09^KV`2FUYH0Hf=S0080^[Zj00@0Xj>S07moO`1oOgl0O7al
0P1nOWh01034a<@0MWIf0:f][@2][Jd3079bLP050:f][@25QHD0[Jf]0:f][@1ZJVX00P2QXJ401@2E
UID0RXZ:08Z:RP2?Shl0YjNW0080LW9b00D0ZJVY096AT@2ATI40OWin07IfMP020:>SX`050;Ng]`1o
Ogl0Ogmo08n?S`24Q8@00P0f=SH0103oool0G5aL05aLG01EEED208J6QP050:n_[`2FUYH0[Jf]0:f]
[@22PX800P2>SXh01@1dM7@0SHf=0;6a/@2a/K40N7Qh0080W9bL00D0OGem0:j^[P2^[Zh0M7Ad0;Zj
^P0206MWI`0508N7Q`21PH40PH610=cLg01LG5`00P2EUID01@2`/;00G5aL05aLG02e]KD0P8200080
XJ6Q00<0Ng]k09^KV`2KVi/00`2>SXh01@2DU9@0W9bL07UiN@1iNGT0T92@0080Y:BT00D0MWIf09nO
W`2@T900T92@08n?S`0208Z:RP050820P02RXZ80XZ:R08F5Q@2UYJD00P2BTY80101nOWh0XZ:R0::R
XP2CTi<:0?ooo`040;Ng]`2][Jd0[Jf]0:6QX@80WYjN00D0SXj>09JFUP2?Shl0Shn?08f=S@0208R8
R00508b<S022PX80PX:207MgM`1fMWH00P1lO7`01@1iNGT0O7al07alO028R8P0Ph>30080NWYj00@0
FUYJ05MGE`1GEeL0GUiN0P1]KFd0101jNWX0ZJVY0:n_[`2_[jl30;:b/P050:>SX`2HV9P0TI6A096A
T@2:RXX00P26QXH01@2GUiL0UYJF0:2PX02PX:00ZJVY0080/K6a00D0];Bd0;Rh^02h^;P0];Bd0;>c
/`020:^[Z`0509fMW@2NWYh0WYjN0:6QX@2KVi/00P2QXJ40102SXj<0VIVI09VIV@2DU9@209jNWP05
09^KV`2LW9`0YjNW0:NWY`2[Zj/00P2UYJD01@2XZ:P0/k>c0:^[Z`2[Zj/0Z:RX0080Xj>S00D0UiNG
08n?S`2?Shl0Ti>C08^;R`0208n?S`0509NGU`2MWId0WIfM09nOW`2WYjL00P2RXZ800`2KVi/0SXj>
08j>SP0208V9R@80TI6A00@0U9BD09FEU@2EUID0U9BD0P21PH400`1dM7@0KVi^075aL@02075aL@80
QhN700D0WIfM0:n_[`2g]kL0]kNg0;no_`020<30`0050;6a/@2KVi/0Vi^K09fMW@2KVi/00P2RXZ80
1@2g]kL0fMWI0=WIf@3IfMT0eMGE0080b/[:00D0[Zj^08Z:RP2:RXX0P82007MgM`0207emO@0408f=
S@2JVYX0VYZJ09bLW080X:2P00D0UYJF08^;R`1mOGd0OGem08R8R00208^;R`0508V9R@24Q8@0U9BD
09BDU026QXH00P1hN7P01@1_Kfl0N7Qh07QhN01eMGD0LG5a0080RHV900@0W9bL0:2PX02PX:00/;2`
3`3oool000d0oooo00@0QXJ607MgM`1gMgL0cLg=0P1/K6`01@2NWYh0L71`0:f][@2][Jd0KFe]0080
XJ6Q00D0XZ:R07EeM@1eMGD0XJ6Q08F5Q@0209:BTP050;Bd]01TI6@0I6AT09FEU@2NWYh00P1nOWh0
102@T900VYZJ09ZJVP2@T9020:RXZ00509JFUP1SHf<0UiNG09NGU`2[Zj/00P1RHV801@2/[:`0Shn?
08n?S`2?Shl0/K6a0080LW9b00D0MWIf0:>SX`26QXH0QXJ60:RXZ0020:6QX@0508J6QP1kNg/0Ng]k
08N7Q`2<S8`00P2JVYX01@2?Shl0UYJF09JFUP2HV9P0LG5a0080[:b/00@0YJFU08:2PP22PX80LG5a
0P2FUYH01@2_[jl0OWin0;2`/02`/;00I6AT0080RXZ:00D0XZ:R0861P@2_[jl0[jn_06=SH`020;2`
/00508b<S02>SXh0SXj>08j>SP2OWil00P1iNGT01@2[Zj/0SHf=08f=S@1jNWX0P8200080W9bL00D0
_Kfm07emO@1mOGd0RHV908J6QP0204M7A`040?ooo`1iNGT0NGUi04Y:BP80RXZ:00D0[jn_08b<S02b
/[80/[:b08R8R00208b<S005071`L02?Shl0/K6a0;6a/@1nOWh00P2EUID01@1kNg/0/k>c0;>c/`1h
N7P0YJFU0080MGEe00D0QhN708^;R`2;Rh/0d];B05mOG`0209BDU0050:b/[01UIFD0IFEU0;6a/@1n
OWh00P2RXZ80101fMWH0X:2P0:2PX02:RXX209bLW00508^;R`2IVIT0NGUi07UiN@2FUYH00P2NWYh0
1@1mOGd0U9BD09VIV@2IVIT0Rh^;0080PX:200D0Rh^;0:BTY02TY:@0Q8B40:BTY00208b<S00408:2
PP2MWId0WIfM09:BTPX0oooo00@0SHf=09:BTP2BTY80YZJV0P2/[:`01@2^[Zh0];Bd0<C4a034a<@0
_kno0080/k>c00D0XZ:R09ZJVP2JVYX0Ph>307AdM00206e]K@<0LG5a00D0LW9b07EeM@2JVYX0VYZJ
0;Rh^0020;no_`050;^k^`2h^;P0^;Rh09BDU01^KVh00P1ZJVX305iNGP05071`L027QhL0Rh^;08^;
R`2MWId00P2PX:001@2CTi<0SHf=08n?S`2?Shl0OWin0080Lg=c00D0LW9b06m_K`1_Kfl0J6QX07Ui
N@0208b<S00509FEU@2IVIT0VIVI0::RXP2KVi/00P2?Shl0102GUiL0WIfM09fMW@2IVIT209ZJVP05
0:2PX02KVi/0UiNG09NGU`2=SHd00P2DU9@01@2ATI40Rh^;08^;R`2;Rh/0UYJF00<0Shn?0P2@T900
1@2GUiL0X:2P0:6QX@2QXJ40Vi^K0080Shn?00D0RXZ:07emO@20P800P82008b<S0020:BTY0050::R
XP2UYJD0XJ6Q0:6QX@2KVi/00P2EUID0102LW9`0/K6a0;6a/@31`L430=3@d0050;bl_02SXj<0Xj>S
092@T01nOWh00P1_Kfl0101gMgL0NGUi07UiN@28R8P208Z:RP050:6QX@2KVi/0VIVI09VIV@1mOGd0
0P1^KVh01@1KFe/0H61P069RHP1RHV80LG5a0080Rh^;00D0SXj>09JFUP2JVYX0VYZJ09RHV003092@
T080UiNG00D0Vi^K0:2PX02YZJT0ZJVY0:^[Z`0209fMW@0509JFUP2KVi/0UiNG09NGU`2RXZ800P2Z
ZZX01@2b/[80ZJVY0:VYZ@2TY:@0XJ6Q0080WYjN00@0Ti>C09BDU02DU9@0UiNG3`3oool000d0oooo
00@0QXJ607MgM`1gMgL0cLg=0P1/K6`01@2NWYh0L71`0:f][@2][Jd0KFe]0080XJ6Q00D0XZ:R07Ee
M@1eMGD0XJ6Q08F5Q@0209:BTP050;Bd]01TI6@0I6AT09FEU@2NWYh00P1nOWh0102@T900VYZJ09ZJ
VP2@T9020:RXZ00509JFUP1SHf<0UiNG09NGU`2[Zj/00P1RHV801@2/[:`0Shn?08n?S`2?Shl0/K6a
0080LW9b00D0MWIf0:>SX`26QXH0QXJ60:RXZ0020:6QX@0508J6QP1kNg/0Ng]k08N7Q`2<S8`00P2J
VYX01@2?Shl0UYJF09JFUP2HV9P0LG5a0080[:b/00@0YJFU08:2PP22PX80LG5a0P2FUYH01@2_[jl0
OWin0;2`/02`/;00I6AT0080RXZ:00D0XZ:R0861P@2_[jl0[jn_06=SH`020;2`/00508b<S02>SXh0
SXj>08j>SP2OWil00P1iNGT01@2[Zj/0SHf=08f=S@1jNWX0P8200080W9bL00D0_Kfm07emO@1mOGd0
RHV908J6QP0204M7A`040?ooo`1iNGT0NGUi04Y:BP80RXZ:00D0[jn_08b<S02b/[80/[:b08R8R002
08b<S005071`L02?Shl0/K6a0;6a/@1nOWh00P2EUID01@1kNg/0/k>c0;>c/`1hN7P0YJFU0080MGEe
00D0QhN708^;R`2;Rh/0d];B05mOG`0209BDU0050:b/[01UIFD0IFEU0;6a/@1nOWh00P2RXZ80101f
MWH0X:2P0:2PX02:RXX209bLW00508^;R`2IVIT0NGUi07UiN@2FUYH00P2NWYh01@1mOGd0U9BD09VI
V@2IVIT0Rh^;0080PX:200D0Rh^;0:BTY02TY:@0Q8B40:BTY00208b<S00408:2PP2MWId0WIfM09:B
TPX0oooo00@0SHf=09:BTP2BTY80YZJV0P2/[:`01@2^[Zh0];Bd0<C4a034a<@0_kno0080/k>c00D0
XZ:R09ZJVP2JVYX0Ph>307AdM00206e]K@<0LG5a00D0LW9b07EeM@2JVYX0VYZJ0;Rh^0020;no_`05
0;^k^`2h^;P0^;Rh09BDU01^KVh00P1ZJVX305iNGP05071`L027QhL0Rh^;08^;R`2MWId00P2PX:00
1@2CTi<0SHf=08n?S`2?Shl0OWin0080Lg=c00D0LW9b06m_K`1_Kfl0J6QX07UiN@0208b<S00509FE
U@2IVIT0VIVI0::RXP2KVi/00P2?Shl0102GUiL0WIfM09fMW@2IVIT209ZJVP050:2PX02KVi/0UiNG
09NGU`2=SHd00P2DU9@01@2ATI40Rh^;08^;R`2;Rh/0UYJF00<0Shn?0P2@T9001@2GUiL0X:2P0:6Q
X@2QXJ40Vi^K0080Shn?00D0RXZ:07emO@20P800P82008b<S0020:BTY0050::RXP2UYJD0XJ6Q0:6Q
X@2KVi/00P2EUID0102LW9`0/K6a0;6a/@31`L430=3@d0050;bl_02SXj<0Xj>S092@T01nOWh00P1_
Kfl0101gMgL0NGUi07UiN@28R8P208Z:RP050:6QX@2KVi/0VIVI09VIV@1mOGd00P1^KVh01@1KFe/0
H61P069RHP1RHV80LG5a0080Rh^;00D0SXj>09JFUP2JVYX0VYZJ09RHV003092@T080UiNG00D0Vi^K
0:2PX02YZJT0ZJVY0:^[Z`0209fMW@0509JFUP2KVi/0UiNG09NGU`2RXZ800P2ZZZX01@2b/[80ZJVY
0:VYZ@2TY:@0XJ6Q0080WYjN00@0Ti>C09BDU02DU9@0UiNG3`3oool000d0oooo00@0Ti>C07IfMP1f
MWH0`L710P1bLW801@2PX:00KFe]0:n_[`2_[jl0L71`0080Vi^K00D0Z:RX06m_K`1_Kfl0ZZZZ07in
OP02096AT@050;>c/`1`L700L71`08n?S`2CTi<00P2;Rh/0102>SXh0UYJF09JFUP2EUID209jNWP05
09bLW01UIFD0SXj>08j>SP2h^;P00P1KFe/01@2c/k<0Rh^;08^;R`2;Rh/0^k^k0080G5aL00D0Ph>3
09nOW`2FUYH0UYJF0:6QX@0209NGU`0508B4Q022PX80PX:208N7Q`2=SHd00P2JVYX01@2<S8`0TI6A
096AT@2HV9P0PH610080WYjN00@0YZJV08N7Q`27QhL0I6AT0P2YZJT01@2QXJ40Q8B40:b/[02/[:`0
Fe]K0080YJFU00D0T92@08:2PP2`/;00/;2`05YJFP020;bl_00508J6QP2CTi<0Ti>C08^;R`2JVYX0
0P20P8001@2][Jd0QXJ608J6QP1fMWH0Shn?0080TY:B00D0_Kfm0861P@21PH40PX:208J6QP0205QH
F0040?_kn`2DU9@0U9BD03hn?P80Shn?00D0/[:b08:2PP2c/k<0/k>c096AT@0208J6QP0506m_K`2?
Shl0/[:b0;:b/P23Ph<00P2=SHd0101oOgl0/K6a0;6a/@23Ph<308V9R@0508F5Q@2CTi<0Ti>C0<W9
b@1RHV800P2@T9001@2WYjL0L71`071`L02ZZZX0P8200080YJFU00@0Kfm_0:FUY@2UYJD0QHF50P2W
YjL01@25QHD0UIFE07emO@1mOGd0U9BD0080VYZJ00D0R8R808J6QP2PX:00X:2P08V9R@0207emO@05
096AT@2UYJD0YJFU08F5Q@2SXj<00P2:RXX01024Q8@0VYZJ09ZJVP2=SHd:0?ooo`<0Shn?00D0QhN7
0820P020P800RXZ:08^;R`0208>3P`0408N7Q`2CTi<0Ti>C0:6QX@80Y:BT00D0_kno0<k>cP3=cLd0
cLg=0=CDe0020=WIf@050=3@d03:b/X0]KFe0;Fe]@2MWId00P2CTi<01@2:RXX0QHF508F5Q@2NWYh0
[Jf]0080ZJVY00D0[:b/0:ZZZP2ZZZX0UYJF07inOP020820P00507EeM@1iNGT0NGUi08N7Q`2;Rh/0
0P2>SXh0102OWil0YjNW0:NWY`2UYJD20;6a/@050;Vi^@2NWYh0UYJF09JFUP2?Shl00P24Q8@0101g
MgL0Shn?096AT@2ATI4308f=S@0508^;R`23Ph<0Ph>307alO01nOWh00P21PH401@2?Shl0Ti>C09>C
T`2OWil0W9bL0080WinO00@0W9bL0:>SX`2SXj<0YZJV0P2k^k/01@2e]KD0Zj^[0:FUY@2UYJD0YjNW
0080[Zj^00D0`L710<O7a`3EeMD0eMGE0<_;b`020:NWY`050:>SX`2QXJ40TI6A096AT@29RHT00P2L
W9`01@2ATI40QHF508F5Q@1hN7P0NGUi0080O7al00D0Rh^;09RHV02HV9P0Shn?09^KV`0209RHV004
09FEU@28R8P0R8R80:>SX`80V9RH00D0Shn?08J6QP2?Shl0Shn?0::RXP020;Ng]`050<?3``30`<00
bLW90<W9b@2c/k<00P2IVIT01@2;Rh/0S8b<07emO@1mOGd0OWin0080QXJ600D0V9RH08j>SP2>SXh0
VYZJ092@T00209>CT`05096AT@2QXJ40XJ6Q0:n_[`2d];@00P2YZJT0102QXJ40WYjN09jNWP25QHD2
08V9R@0409RHV02;Rh/0S8b<08b<S0<0Ti>C00<0Ph>30?ooo`3oool03@3oool000d0oooo00@0X:2P
07AdM01dM7@0]kNg0P1gMgL01@2QXJ40JVYZ0;:b/P2b/[80Lg=c0080UYJF00D0[Zj^06UYJ@1YJFT0
/[:b07EeM@0209FEU@050:ZZZP1nOWh0OWin09>CT`20P8000P2HV9P0102>SXh0U9BD09BDU02MWId2
08b<S0050:FUY@1XJ6P0Q8B408B4Q036a/H00P1DE5@01@2g]kL0RXZ:08b<S02<S8`0_kno0080BDU9
00D0TY:B09ZJVP2QXJ40XJ6Q09jNWP0208n?S`0507inOP2=SHd0SHf=08N7Q`2BTY800P2CTi<308j>
SP0509BDU02?Shl0UYJF09JFUP2UYJD00P29RHT01@1LG5`0_Kfm0;fm_@2=SHd0SXj>0080Z:RX00D0
EUIF0;Zj^P2j^[X0Ogmo08R8R0020:j^[P0404m?C`3<c<`0c<c<07emO@80Vi^K00D0QhN709FEU@29
RHT0RHV90:j^[P0207inOP0507EeM@2KVi/0SXj>08j>SP2f][H00P2;Rh/01@1hN7P0R8R806EUI@1U
IFD0gMgM0080[Zj^00D0=CDe09BDU02DU9@0][Jf07alO0020:b/[00509^KV`24Q8@0Q8B406m_K`2=
SHd00P2d];@0102<S8`0PX:208:2PP28R8P20:^[Z`05096AT@1XJ6P0Vi^K09^KV`27QhL00P2HV9P0
1@31`L40Jf][08N7Q`27QhL0Y:BT0080Ng]k00D0Xj>S08F5Q@2PX:00X:2P075aL@020:RXZ0050861
P@2[Zj/0Zj^[08F5Q@2?Shl00P26QXH01@2@T900VYZJ09ZJVP2>SXh0Ng]k0080ZZZZ00@0PX:207Ui
N@1iNGT0VYZJ0P2WYjL01@23Ph<0WinO08b<S02<S8`0Q8B40080VYZJ00<0QXJ60?ooo`3oool0203o
ool01027QhL0Rh^;08^;R`2KVi/209bLW005079bLP1RHV80=3@d03@d=00f=SH00P0];Bd01@11@D40
EUIF05IFEP1bLW80De=C0080G5aL00D0BTY:01dM7@0M7Ad071`L04e=C@0204A4A00407UiN@2GUiL0
UiNG09nOW`80UiNG00D0OGem051@D01EEED0EEEE07=cL`02075aL@0509fMW@2i^KT0Zj^[0:^[Z`2;
Rh/00P1WIfL01@1QHF40LG5a09bLW02LW9`0SXj>0080XJ6Q00D0VYZJ08V9R@29RHT0NGUi0;Rh^002
0;no_`050;Rh^02NWYh0WYjN09jNWP27QhL00P2EUID0102PX:00_[jn0;jn_P34a<@20<K6aP050;>c
/`2SXj<0Rh^;08^;R`28R8P00P24Q8@01@2EUID0SXj>09FEU@2EUID0HV9R0080Fe]K00D0DE5A04U9
B@19BDT0@410075aL@0206UYJ@05051@D01PH600H61P04=3@`1:BTX00P10@4001@1<C4`0JFUY06UY
J@2SXj<0HV9R0080L71`00@0Q8B407EeM@1eMGD0D51@0P2IVIT01@29RHT0S8b<07]kN`1kNg/0RXZ:
0080C4a<00D0N7Qh069RHP1bLW80LW9b07inOP020;Ng]`050;>c/`3:b/X0b/[:09BDU029RHT00P1o
Ogl01@1:BTX0Bd];04];B`1aLG40FEUI0080GUiN00D0QHF508n?S`2?Shl0/k>c0<c<c0020<G5a@04
0<71`@2WYjL0YjNW08Z:RP80MGEe00D0HV9R06MWI`1QHF40HF5Q06UYJ@0206EUI@0505YJFP1IFET0
Kfm_06m_K`1EEED00P1TI6@01@23Ph<0Rh^;08^;R`20P800Z:RX0080YZJV00@0SHf=07]kN`1kNg/0
U9BD3`3oool000d0oooo00@0X:2P07AdM01dM7@0]kNg0P1gMgL01@2QXJ40JVYZ0;:b/P2b/[80Lg=c
0080UYJF00D0[Zj^06UYJ@1YJFT0/[:b07EeM@0209FEU@050:ZZZP1nOWh0OWin09>CT`20P8000P2H
V9P0102>SXh0U9BD09BDU02MWId208b<S0050:FUY@1XJ6P0Q8B408B4Q036a/H00P1DE5@01@2g]kL0
RXZ:08b<S02<S8`0_kno0080BDU900D0TY:B09ZJVP2QXJ40XJ6Q09jNWP0208n?S`0507inOP2=SHd0
SHf=08N7Q`2BTY800P2CTi<308j>SP0509BDU02?Shl0UYJF09JFUP2UYJD00P29RHT01@1LG5`0_Kfm
0;fm_@2=SHd0SXj>0080Z:RX00D0EUIF0;Zj^P2j^[X0Ogmo08R8R0020:j^[P0404m?C`3<c<`0c<c<
07emO@80Vi^K00D0QhN709FEU@29RHT0RHV90:j^[P0207inOP0507EeM@2KVi/0SXj>08j>SP2f][H0
0P2;Rh/01@1hN7P0R8R806EUI@1UIFD0gMgM0080[Zj^00D0=CDe09BDU02DU9@0][Jf07alO0020:b/
[00509^KV`24Q8@0Q8B406m_K`2=SHd00P2d];@0102<S8`0PX:208:2PP28R8P20:^[Z`05096AT@1X
J6P0Vi^K09^KV`27QhL00P2HV9P01@31`L40Jf][08N7Q`27QhL0Y:BT0080Ng]k00D0Xj>S08F5Q@2P
X:00X:2P075aL@020:RXZ0050861P@2[Zj/0Zj^[08F5Q@2?Shl00P26QXH01@2@T900VYZJ09ZJVP2>
SXh0Ng]k0080ZZZZ00@0PX:207UiN@1iNGT0VYZJ0P2WYjL01@23Ph<0WinO08b<S02<S8`0Q8B40080
VYZJ00<0QXJ60?ooo`3oool0203oool01027QhL0Rh^;08^;R`2KVi/209bLW005079bLP1RHV80=3@d
03@d=00f=SH00P0];Bd01@11@D40EUIF05IFEP1bLW80De=C0080G5aL00D0BTY:01dM7@0M7Ad071`L
04e=C@0204A4A00407UiN@2GUiL0UiNG09nOW`80UiNG00D0OGem051@D01EEED0EEEE07=cL`02075a
L@0509fMW@2i^KT0Zj^[0:^[Z`2;Rh/00P1WIfL01@1QHF40LG5a09bLW02LW9`0SXj>0080XJ6Q00D0
VYZJ08V9R@29RHT0NGUi0;Rh^0020;no_`050;Rh^02NWYh0WYjN09jNWP27QhL00P2EUID0102PX:00
_[jn0;jn_P34a<@20<K6aP050;>c/`2SXj<0Rh^;08^;R`28R8P00P24Q8@01@2EUID0SXj>09FEU@2E
UID0HV9R0080Fe]K00D0DE5A04U9B@19BDT0@410075aL@0206UYJ@05051@D01PH600H61P04=3@`1:
BTX00P10@4001@1<C4`0JFUY06UYJ@2SXj<0HV9R0080L71`00@0Q8B407EeM@1eMGD0D51@0P2IVIT0
1@29RHT0S8b<07]kN`1kNg/0RXZ:0080C4a<00D0N7Qh069RHP1bLW80LW9b07inOP020;Ng]`050;>c
/`3:b/X0b/[:09BDU029RHT00P1oOgl01@1:BTX0Bd];04];B`1aLG40FEUI0080GUiN00D0QHF508n?
S`2?Shl0/k>c0<c<c0020<G5a@040<71`@2WYjL0YjNW08Z:RP80MGEe00D0HV9R06MWI`1QHF40HF5Q
06UYJ@0206EUI@0505YJFP1IFET0Kfm_06m_K`1EEED00P1TI6@01@23Ph<0Rh^;08^;R`20P800Z:RX
0080YZJV00@0SHf=07]kN`1kNg/0U9BD3`3oool000d0oooo00@0Zj^[075aL@1aLG40[jn_0P1lO7`0
1@2SXj<0I6AT0;Ng]`2g]kL0LW9b0080TI6A00D0^[Zj061PH01PH600][Jf06e]K@0209fMW@0509jN
WP2=SHd0SHf=096AT@1cLg<00P2QXJ40102ATI40RHV908V9R@2^[Zh207QhN0050:b/[01/K6`0NWYj
07YjNP3Bd]800P1=CDd01@2o_kl0Q8B408j>SP2>SXh0`L710080?Shn00D0Vi^K09NGU`2^[Zh0[Zj^
09JFUP0208R8R00507emO@2FUYH0UYJF08>3P`2HV9P00P2>SXh01@2?Shl0S8b<08b<S02ATI40UiNG
0080Ti>C00@0YJFU08V9R@29RHT0E5AD0P3=cLd01@1lO7`0UiNG0:6QX@2QXJ40EEEE0080cLg=00D0
LG5a08^;R`2][Jd0[Jf]04=3@`020=gMg@05075aL@2WYjL0YjNW0820P02>SXh00P2@T9001@2d];@0
N7Qh07QhN01]KFd0Zj^[0080QXJ600D0[Zj^09VIV@2IVIT0KFe]08b<S002075aL@040<71`@32`/80
`/;2030`<080V9RH00D0]KFe07alO02QXJ40XJ6Q0:NWY`0208>3P`0506a/K023Ph<0_Kfm0;fm_@2@
T9000P1fMWH01@2EUID0WinO09nOW`2SXj<0CDe=0080XJ6Q00D0UYJF09FEU@2EUID0_;bl07=cL`02
07alO0050:6QX@2:RXX0RXZ:09VIV@23Ph<00P2SXj<0101_Kfl0ZJVY0:VYZ@23Ph<20:b/[00508N7
Q`24Q8@0V9RH09RHV01nOWh00P2SXj<01@2>SXh0MgMg0;2`/02`/;00PH610080LW9b00D0WinO0:NW
Y`2WYjL0QXJ609bLW00208R8R00408N7Q`2GUiL0UiNG08B4Q0X0oooo00@0Shn?08j>SP2>SXh0RXZ:
0P2?Shl01@2^[Zh0a<C40?;blP3bl_80jNWY0080m?Cd00D0f=SH0;fm_@2m_Kd0UiNG0;Jf]P020;Fe
]@050=3@d03kno/0no_k0?_kn`37alL00P36a/H0102<S8`0M7Ad07AdM01hN7P208F5Q@0509jNWP3B
d]80f][J0=[JfP3>c/h00P3Ogml01@32`/80YjNW0:n_[`2_[jl0b<S80080hN7Q00D0gMgM0=CDe02O
Wil0WinO09jNWP0208>3P`0508N7Q`2CTi<0Ti>C09jNWP1^KVh00P1YJFT01@1iNGT0U9BD09BDU02I
VIT0Xj>S0080VYZJ00@0Ti>C07IfMP1fMWH0OWin0P23Ph<01@2>SXh0Shn?0:NWY`2WYjL0UYJF0080
SHf=00D0Ogmo09>CT`28R8P0R8R80;Rh^0020<C4a0050<o?c`33`l<0`l?30<g=c@2a/K400P2l_;`0
1@3De=@0c/k>0<k>cP3Xj>P0dM7A0080bLW900@0a<C40;Ng]`2g]kL0NGUi0`33`l<0102d];@0Z:RX
0:RXZ03?cll209FEU@80/[:b0P37alL01@32`/80lO7a0?7al@3>c/h0f=SH0080dM7A00@0`l?309BD
U02DU9@0Ph>30P20P8001@2ZZZX0_[jn0;bl_02l_;`0g=cL0080_[jn00D0W9bL0:^[Z`2IVIT0VIVI
07alO00208>3P`05079bLP1VIVH0PX:208:2PP2DU9@00P2][Jd0102b/[80_[jn0;jn_P3<c<`30<S8
b0040;Rh^02n_[h0_[jn0;^k^`<0_;bl00@0inOW0=SHf03Hf=P0b<S80P2`/;001@2TY:@0QHF507al
O01lO7`0RXZ:0080WYjN00<0SXj>0?ooo`3oool03@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 197.562}, {389.5, 201.375}} -> {-9.28531, \
-9.30743, 0.707857, 0.707857}, {{201.375, 389.438}, {389.5, 201.375}} -> \
{-145.105, -9.30743, 0.707857, 0.707857}, {{9.5, 197.562}, {197.562, 9.5}} -> \
{-9.28531, -145.15, 0.707857, 0.707857}, {{201.375, 389.438}, {197.562, 9.5}} -> \
{-145.105, -145.15, 0.707857, 0.707857}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Compute two-dimensional (horiztonal/vertical) feature vectors\
\>", \
"Subsection"],

Cell[BoxData[
    \(\(pr = {{\(-100\), 100}, {\(-100\), 100}};\)\)], "Input"],

Cell[BoxData[{
    \(\(wood3 = {Flatten[wood1], Flatten[wood2]}\  // \ 
          Transpose;\)\), "\n", 
    \(\(brick3 = {Flatten[brick1], Flatten[brick2]}\  // \ 
          Transpose;\)\)}], "Input"],

Cell[BoxData[
    \(g1 = 
      Show[Graphics[{Red, Point /@ wood3}], \ AspectRatio \[Rule] Automatic, 
        PlotRange \[Rule] All, \ nS]; 
    g2 = Show[Graphics[{Blue, Point /@ brick3}], \ 
        AspectRatio \[Rule] Automatic, \ PlotRange \[Rule] All, 
        nS];\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Visualize two-dimensional (horiztonal/vertical) feature \
vectors\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(distrr = 
        Show[g1, g2, \ ImageSize \[Rule] 288, Frame \[Rule] True, 
          PlotRange \[Rule] pr, FrameTicks \[Rule] None, yS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 288 288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.005 0.5 0.005 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.008 w
.87 .6 Mdot
.20125 .55125 Mdot
.6875 .455 Mdot
.35375 .4075 Mdot
.70375 .39625 Mdot
.0175 .35 Mdot
.95125 .3275 Mdot
.20625 .36625 Mdot
.42375 .39125 Mdot
.97875 .5425 Mdot
.0375 .51625 Mdot
.69125 .45125 Mdot
.54625 .4025 Mdot
.63125 .40875 Mdot
.44625 .4075 Mdot
.12875 .46 Mdot
.75625 .51375 Mdot
.5975 .54375 Mdot
.26875 .54375 Mdot
.015 .55375 Mdot
.88625 .5675 Mdot
.19375 .55875 Mdot
.12625 .5375 Mdot
.3 .4225 Mdot
.5075 .4075 Mdot
.69125 .47 Mdot
.55 .45125 Mdot
.955 .47125 Mdot
.54125 .46625 Mdot
.28875 .45625 Mdot
.2825 .465 Mdot
.655 .48875 Mdot
.34125 .4875 Mdot
.64875 .5075 Mdot
.40375 .54 Mdot
.5525 .56375 Mdot
.36375 .56625 Mdot
.53875 .5975 Mdot
.6225 .61625 Mdot
.51 .59625 Mdot
.7375 .55875 Mdot
.41 .57625 Mdot
.17375 .49375 Mdot
.63875 .5425 Mdot
.56875 .5025 Mdot
.055 .56625 Mdot
.49 .53 Mdot
.7925 .54125 Mdot
.02875 .4575 Mdot
.92 .45125 Mdot
.24125 .45 Mdot
.41375 .415 Mdot
.62375 .4125 Mdot
.85625 .4275 Mdot
.22375 .39625 Mdot
.09375 .375 Mdot
.865 .4125 Mdot
.35625 .45375 Mdot
.8075 .45625 Mdot
.59625 .50375 Mdot
.12375 .52125 Mdot
.5025 .51125 Mdot
.2225 .49125 Mdot
.7775 .48875 Mdot
.56625 .49375 Mdot
.93125 .495 Mdot
.32625 .45375 Mdot
.49125 .445 Mdot
.87875 .43 Mdot
.32375 .43625 Mdot
.17625 .42875 Mdot
.26 .4675 Mdot
.46875 .43 Mdot
.18625 .43625 Mdot
.69625 .43375 Mdot
.51625 .43625 Mdot
.81625 .44875 Mdot
.61875 .47375 Mdot
.83375 .49625 Mdot
.45375 .55125 Mdot
.845 .56 Mdot
.3925 .58 Mdot
.17125 .61125 Mdot
.65 .64875 Mdot
.585 .62625 Mdot
.45 .57375 Mdot
.42625 .505 Mdot
.6875 .47 Mdot
.11875 .435 Mdot
.79375 .38625 Mdot
.34875 .4225 Mdot
.79125 .43625 Mdot
.3925 .40125 Mdot
.3875 .3825 Mdot
.68375 .41375 Mdot
.21375 .45375 Mdot
.73 .4825 Mdot
.48 .545 Mdot
.205 .53625 Mdot
.88625 .49125 Mdot
.37375 .44875 Mdot
.11125 .4675 Mdot
.63625 .465 Mdot
.80375 .5075 Mdot
.44375 .54 Mdot
.5775 .5375 Mdot
.40875 .55125 Mdot
.4125 .56875 Mdot
.5425 .57375 Mdot
.37125 .57125 Mdot
.8925 .41875 Mdot
.19125 .4825 Mdot
.6975 .59625 Mdot
.33125 .66 Mdot
.75375 .6975 Mdot
.1925 .6875 Mdot
.40625 .635 Mdot
.96375 .48375 Mdot
.77625 .55875 Mdot
.49375 .55 Mdot
.65625 .5475 Mdot
.44875 .53625 Mdot
.1225 .48625 Mdot
.695 .42125 Mdot
.625 .47 Mdot
.32 .4725 Mdot
.955 .4725 Mdot
.07125 .46625 Mdot
.86125 .46375 Mdot
.18875 .4425 Mdot
.1175 .45125 Mdot
.97875 .48875 Mdot
.29875 .49 Mdot
.55125 .5175 Mdot
.97625 .505 Mdot
.6925 .50125 Mdot
.54 .5425 Mdot
.97375 .5275 Mdot
.52 .5575 Mdot
.275 .61375 Mdot
.35 .605 Mdot
.5875 .55625 Mdot
.3375 .55 Mdot
.66125 .5175 Mdot
.4275 .4375 Mdot
.56125 .38 Mdot
.3425 .35125 Mdot
.55875 .30375 Mdot
.57875 .255 Mdot
.52375 .27375 Mdot
.7375 .32625 Mdot
.42625 .34375 Mdot
.135 .47625 Mdot
.75625 .45625 Mdot
.44 .4875 Mdot
.01125 .4725 Mdot
.545 .42 Mdot
.77 .435 Mdot
.055 .55875 Mdot
.90125 .5675 Mdot
.28375 .545 Mdot
.3325 .545 Mdot
.68875 .56375 Mdot
.85875 .545 Mdot
.25375 .56875 Mdot
.0225 .60125 Mdot
.89875 .6025 Mdot
.37625 .54 Mdot
.69125 .52 Mdot
.735 .48875 Mdot
.09125 .46375 Mdot
.51125 .47375 Mdot
.1525 .47375 Mdot
.87625 .495 Mdot
.5575 .465 Mdot
.26875 .465 Mdot
.46375 .46625 Mdot
.855 .47875 Mdot
.38375 .46875 Mdot
.16625 .50875 Mdot
.245 .475 Mdot
.515 .43 Mdot
.1325 .42375 Mdot
.79375 .37125 Mdot
.44125 .375 Mdot
.83125 .40375 Mdot
.57875 .43875 Mdot
.85625 .4675 Mdot
.455 .43875 Mdot
.8 .4425 Mdot
.4625 .44875 Mdot
.2 .4775 Mdot
.56875 .515 Mdot
.60875 .5425 Mdot
.44 .585 Mdot
.44125 .62625 Mdot
.6825 .5825 Mdot
.11 .52625 Mdot
.7875 .5475 Mdot
.39125 .49625 Mdot
.73125 .47375 Mdot
.42875 .51875 Mdot
.3875 .49125 Mdot
.71375 .43 Mdot
.11 .335 Mdot
.84375 .2275 Mdot
.35875 .07875 Mdot
.3525 .12 Mdot
.8 .2025 Mdot
.39875 .31875 Mdot
.10875 .345 Mdot
.6225 .44125 Mdot
.80125 .48625 Mdot
.455 .4625 Mdot
.54375 .4775 Mdot
.46625 .5 Mdot
.36875 .4875 Mdot
.58625 .4425 Mdot
.3275 .4525 Mdot
.87375 .64875 Mdot
.17 .6375 Mdot
.73625 .55875 Mdot
.31125 .51375 Mdot
.78875 .475 Mdot
.2025 .49125 Mdot
.38625 .5225 Mdot
.925 .63875 Mdot
.89375 .63375 Mdot
.38875 .615 Mdot
.71125 .585 Mdot
.46 .57875 Mdot
.12875 .595 Mdot
.6425 .62125 Mdot
.625 .585 Mdot
.34625 .565 Mdot
.95625 .53125 Mdot
.07125 .515 Mdot
.8625 .4975 Mdot
.205 .49125 Mdot
.0775 .5025 Mdot
.98 .5075 Mdot
.26 .545 Mdot
.6 .55 Mdot
.94875 .54625 Mdot
.7 .535 Mdot
.53875 .5025 Mdot
.9825 .52625 Mdot
.515 .53875 Mdot
.27375 .50625 Mdot
.37375 .515 Mdot
.58 .52625 Mdot
.3275 .51 Mdot
.655 .5025 Mdot
.435 .56 Mdot
.58 .60375 Mdot
.31375 .6325 Mdot
.5725 .645 Mdot
.55625 .6775 Mdot
.53375 .64 Mdot
.74 .5975 Mdot
.405 .55375 Mdot
.03625 .53 Mdot
.8825 .55375 Mdot
.3775 .5675 Mdot
.015 .5825 Mdot
0 .61875 Mdot
.55875 .59625 Mdot
.75 .5725 Mdot
.07375 .4525 Mdot
.86125 .485 Mdot
.3275 .53375 Mdot
.3325 .5475 Mdot
.66625 .5375 Mdot
.85375 .59 Mdot
.29125 .555 Mdot
.88375 .50875 Mdot
.44 .5325 Mdot
.60875 .49125 Mdot
.765 .4875 Mdot
.08125 .5225 Mdot
.55875 .465 Mdot
.10125 .495 Mdot
.92875 .495 Mdot
.98125 .50125 Mdot
.53125 .585 Mdot
.22125 .61125 Mdot
.4675 .595 Mdot
.82625 .56 Mdot
.465 .5575 Mdot
.09875 .5 Mdot
.255 .48875 Mdot
.4025 .5975 Mdot
.11 .59625 Mdot
.9025 .63875 Mdot
.39375 .625 Mdot
.8225 .595 Mdot
.56125 .52125 Mdot
.85125 .51 Mdot
.48625 .50125 Mdot
.7325 .49375 Mdot
.5475 .48 Mdot
.2 .4625 Mdot
.5225 .4175 Mdot
.63875 .445 Mdot
.42375 .46875 Mdot
.405 .49875 Mdot
.69375 .55125 Mdot
.11625 .635 Mdot
.82 .63375 Mdot
.37375 .61 Mdot
.69 .61125 Mdot
.45875 .54375 Mdot
.39125 .59 Mdot
.73625 .66375 Mdot
.055 .8125 Mdot
.93125 .8975 Mdot
.76875 .93875 Mdot
.40125 .78875 Mdot
.1125 .72125 Mdot
.59625 .5775 Mdot
.815 .49 Mdot
.46625 .50125 Mdot
.53625 .4775 Mdot
.4125 .4875 Mdot
.455 .53625 Mdot
.57375 .5875 Mdot
.31 .585 Mdot
.8825 .38625 Mdot
.15625 .3575 Mdot
.74875 .4225 Mdot
.3425 .45875 Mdot
.8025 .49875 Mdot
.14 .48375 Mdot
.43 .455 Mdot
.95375 .3225 Mdot
.9675 .3225 Mdot
.3725 .37875 Mdot
.66375 .4225 Mdot
.45 .495 Mdot
.23125 .4925 Mdot
.54375 .51125 Mdot
.64 .49625 Mdot
.365 .5075 Mdot
.92875 .52625 Mdot
.12 .56375 Mdot
.8475 .545 Mdot
.20625 .5625 Mdot
.05125 .54 Mdot
.96625 .49625 Mdot
.22625 .46 Mdot
.62375 .42 Mdot
.94625 .41625 Mdot
.675 .41125 Mdot
.54 .4125 Mdot
.48 .42125 Mdot
.24875 .43 Mdot
.38 .425 Mdot
.5825 .43875 Mdot
.30875 .4625 Mdot
.65 .505 Mdot
.49625 .48625 Mdot
.52875 .46875 Mdot
.30875 .455 Mdot
.61125 .4675 Mdot
.50875 .45625 Mdot
.58375 .50625 Mdot
.7125 .54625 Mdot
.40875 .585 Mdot
.08 .515 Mdot
.865 .48875 Mdot
.3725 .44625 Mdot
.04375 .43625 Mdot
.5225 .43875 Mdot
.74125 .47125 Mdot
.07875 .5325 Mdot
.84375 .4875 Mdot
.33875 .43625 Mdot
.30625 .42625 Mdot
.6975 .42375 Mdot
.82 .33375 Mdot
.37125 .3675 Mdot
.91125 .3775 Mdot
.4575 .39125 Mdot
.59 .475 Mdot
.74125 .5375 Mdot
.0975 .58375 Mdot
.61 .6325 Mdot
.04 .62875 Mdot
.9825 .6075 Mdot
.8775 .55625 Mdot
.53625 .47 Mdot
.17875 .44125 Mdot
.51625 .44875 Mdot
.805 .495 Mdot
.495 .505 Mdot
.05 .585 Mdot
.27625 .59625 Mdot
.39 .58375 Mdot
.06375 .62375 Mdot
.99875 .5925 Mdot
.3375 .61 Mdot
.81625 .6025 Mdot
.5525 .6125 Mdot
.835 .59875 Mdot
.5225 .60625 Mdot
.64 .58875 Mdot
.615 .57375 Mdot
.26375 .54375 Mdot
.43875 .5425 Mdot
.66125 .505 Mdot
.43625 .4675 Mdot
.3475 .43875 Mdot
.7625 .41375 Mdot
.08 .41375 Mdot
.80375 .4125 Mdot
.4025 .51875 Mdot
.67875 .5725 Mdot
.43 .6425 Mdot
.4625 .615 Mdot
.74 .585 Mdot
.10125 .29375 Mdot
.59125 .26375 Mdot
.72 .28625 Mdot
.44125 .34375 Mdot
.0925 .3875 Mdot
.5575 .45125 Mdot
.8125 .4975 Mdot
.5125 .48625 Mdot
.5425 .50125 Mdot
.37375 .47125 Mdot
.45875 .44 Mdot
.56625 .425 Mdot
.31875 .41375 Mdot
.87375 .5125 Mdot
.125 .5175 Mdot
.795 .4575 Mdot
.34125 .42875 Mdot
.7975 .38 Mdot
.1925 .3675 Mdot
.38875 .40125 Mdot
.99875 .5125 Mdot
.40125 .4625 Mdot
.62125 .44875 Mdot
.455 .40625 Mdot
.22375 .43375 Mdot
.5475 .42125 Mdot
.62125 .44 Mdot
.4275 .44875 Mdot
.83875 .435 Mdot
.2 .41375 Mdot
.825 .45375 Mdot
.21875 .4625 Mdot
.0175 .485 Mdot
.95375 .58875 Mdot
.21125 .59625 Mdot
.6525 .62375 Mdot
.9325 .59125 Mdot
.695 .53 Mdot
.54875 .4925 Mdot
.49625 .37625 Mdot
.2375 .36 Mdot
.34625 .40125 Mdot
.58875 .45 Mdot
.33125 .47375 Mdot
.6275 .50375 Mdot
.52875 .52625 Mdot
.47125 .50875 Mdot
.3625 .49625 Mdot
.615 .4775 Mdot
.49625 .4825 Mdot
.60625 .44375 Mdot
.66875 .4175 Mdot
.4075 .405 Mdot
.115 .47375 Mdot
.84625 .4975 Mdot
.37875 .51 Mdot
.1 .47375 Mdot
.45625 .48 Mdot
.7425 .45 Mdot
.055 .4225 Mdot
.84125 .49125 Mdot
.35625 .5425 Mdot
.29125 .565 Mdot
.70375 .5475 Mdot
.7875 .615 Mdot
.425 .56 Mdot
.85375 .58375 Mdot
.485 .59375 Mdot
.61625 .5375 Mdot
.69875 .46125 Mdot
.16375 .39125 Mdot
.5575 .32875 Mdot
.06875 .31875 Mdot
.95 .38 Mdot
.8625 .4675 Mdot
.52125 .5125 Mdot
.14125 .49 Mdot
.5475 .46375 Mdot
.78625 .4125 Mdot
.49375 .38125 Mdot
.08375 .405 Mdot
.26375 .43125 Mdot
.415 .43625 Mdot
.055 .45625 Mdot
.32375 .4225 Mdot
.81 .43625 Mdot
.5575 .455 Mdot
.80375 .43 Mdot
.57 .42375 Mdot
.56625 .42125 Mdot
.6675 .4375 Mdot
.29625 .44375 Mdot
.405 .455 Mdot
.66875 .455 Mdot
.4175 .47375 Mdot
.3575 .475 Mdot
.77375 .51375 Mdot
.0675 .4675 Mdot
.785 .4725 Mdot
.45 .38625 Mdot
.6525 .31625 Mdot
.435 .22875 Mdot
.4575 .23875 Mdot
.7425 .22 Mdot
.7 .49375 Mdot
.68625 .5375 Mdot
.40875 .54 Mdot
.1325 .545 Mdot
.555 .545 Mdot
.80875 .54875 Mdot
.5175 .50875 Mdot
.57125 .535 Mdot
.35125 .5375 Mdot
.41 .54875 Mdot
.65125 .53375 Mdot
.27625 .56875 Mdot
.8925 .45125 Mdot
.07375 .4975 Mdot
.885 .57125 Mdot
.32125 .61625 Mdot
.8075 .6925 Mdot
.2325 .66 Mdot
.39125 .6075 Mdot
.46875 .5725 Mdot
.5325 .56375 Mdot
.4975 .555 Mdot
.20625 .50875 Mdot
.54625 .5225 Mdot
.585 .51625 Mdot
.49625 .505 Mdot
.76875 .53625 Mdot
.27875 .52625 Mdot
.78625 .51125 Mdot
.235 .51625 Mdot
.9875 .4125 Mdot
.22375 .42 Mdot
.62 .42125 Mdot
.93 .48125 Mdot
.73875 .61 Mdot
.54125 .70375 Mdot
.49125 .825 Mdot
.2625 .83 Mdot
.3325 .745 Mdot
.60375 .6325 Mdot
.3275 .55875 Mdot
.62875 .46375 Mdot
.53 .42 Mdot
.44125 .44 Mdot
.40875 .445 Mdot
.57125 .45875 Mdot
.52625 .4875 Mdot
.63625 .53625 Mdot
.605 .5325 Mdot
.4225 .52125 Mdot
.13625 .49875 Mdot
.84 .5 Mdot
.39125 .52125 Mdot
.1675 .52 Mdot
.39875 .52125 Mdot
.7575 .5475 Mdot
.04875 .58625 Mdot
.8275 .52375 Mdot
.3575 .50375 Mdot
.27 .4725 Mdot
.7075 .4875 Mdot
.825 .45875 Mdot
.39625 .52125 Mdot
.82625 .495 Mdot
.52625 .47125 Mdot
.59 .49875 Mdot
.71375 .535 Mdot
.18125 .56625 Mdot
.55 .6125 Mdot
.09125 .61125 Mdot
.88625 .54625 Mdot
.8275 .485 Mdot
.5175 .43875 Mdot
.97875 .43375 Mdot
.14875 .465 Mdot
.58375 .48625 Mdot
.775 .52625 Mdot
.5125 .60375 Mdot
.07625 .475 Mdot
.22375 .44625 Mdot
.36625 .3875 Mdot
.06375 .3175 Mdot
.9775 .40875 Mdot
.41375 .4325 Mdot
.80375 .435 Mdot
.57375 .4775 Mdot
.785 .51 Mdot
.59 .5175 Mdot
.53 .5275 Mdot
.6925 .50875 Mdot
.285 .4725 Mdot
.44625 .45125 Mdot
.6125 .44125 Mdot
.4975 .42125 Mdot
.285 .42 Mdot
.8225 .41375 Mdot
.04375 .44 Mdot
.7775 .46625 Mdot
.485 .4975 Mdot
.61 .5475 Mdot
.475 .66625 Mdot
.39 .71125 Mdot
.79 .7625 Mdot
.86375 .5725 Mdot
.57 .48125 Mdot
.41375 .48125 Mdot
.2 .4675 Mdot
.50125 .465 Mdot
.83875 .4675 Mdot
.50375 .57625 Mdot
.5775 .55375 Mdot
.34375 .545 Mdot
.43 .5025 Mdot
.62125 .49125 Mdot
.27125 .40875 Mdot
.885 .64 Mdot
.04 .57875 Mdot
.9325 .47625 Mdot
.295 .4125 Mdot
.77125 .315 Mdot
.99625 .375 Mdot
.2875 .42625 Mdot
.385 .46875 Mdot
.5325 .5775 Mdot
.42 .53875 Mdot
.5425 .53375 Mdot
.205 .5275 Mdot
.54375 .4875 Mdot
.59375 .4725 Mdot
.50875 .51125 Mdot
.7325 .5075 Mdot
.35875 .5325 Mdot
.71 .52375 Mdot
.26375 .50875 Mdot
.9825 .48875 Mdot
.2525 .46375 Mdot
.56 .44375 Mdot
.97375 .42375 Mdot
.71125 .35125 Mdot
.55625 .30125 Mdot
.50625 .285 Mdot
.26625 .29 Mdot
.31875 .37 Mdot
.63375 .45 Mdot
.3225 .4925 Mdot
.62375 .515 Mdot
.5075 .5375 Mdot
.43375 .52 Mdot
.4625 .5475 Mdot
.51 .5875 Mdot
.5775 .6075 Mdot
.61625 .61125 Mdot
.5975 .65625 Mdot
.44125 .65875 Mdot
.1875 .56875 Mdot
.74 .52625 Mdot
.4875 .50875 Mdot
.195 .5525 Mdot
.395 .55625 Mdot
.77 .55 Mdot
.0625 .5225 Mdot
.80875 .545 Mdot
.34125 .51125 Mdot
.3525 .52 Mdot
.64375 .50625 Mdot
.81625 .52125 Mdot
.37875 .48 Mdot
.71375 .44375 Mdot
.62875 .43125 Mdot
.55 .43 Mdot
.6875 .40625 Mdot
.2525 .42125 Mdot
.4725 .435 Mdot
.16375 .4475 Mdot
.8325 .4525 Mdot
.79 .4875 Mdot
.05375 .47125 Mdot
.46375 .52125 Mdot
.8575 .53125 Mdot
.2425 .51 Mdot
.5625 .49625 Mdot
.78625 .51 Mdot
.525 .4725 Mdot
.0675 .54625 Mdot
.21875 .55 Mdot
.2975 .5875 Mdot
.13 .595 Mdot
.86625 .54 Mdot
.53 .5525 Mdot
.7975 .545 Mdot
.52625 .5075 Mdot
.785 .50125 Mdot
.6025 .49125 Mdot
.5325 .4675 Mdot
.67 .49125 Mdot
.315 .56875 Mdot
.45375 .5825 Mdot
.57625 .6 Mdot
.51375 .62625 Mdot
.27875 .62375 Mdot
.8325 .5625 Mdot
.07375 .5475 Mdot
.73 .535 Mdot
.5025 .5825 Mdot
.6475 .58125 Mdot
.41875 .54125 Mdot
.41 .49875 Mdot
.8 .4425 Mdot
.99375 .35625 Mdot
.5075 .38875 Mdot
.39125 .39625 Mdot
.28 .38375 Mdot
.49 .4025 Mdot
.81 .45 Mdot
.5025 .42625 Mdot
.5625 .42 Mdot
.36375 .4725 Mdot
.4625 .54 Mdot
.57375 .57125 Mdot
.29375 .6275 Mdot
.8775 .30875 Mdot
.00125 .3725 Mdot
.99125 .46875 Mdot
.275 .55875 Mdot
.7425 .6575 Mdot
.935 .6175 Mdot
.29375 .58125 Mdot
.39625 .54125 Mdot
.65875 .39 Mdot
.25375 .4325 Mdot
.61 .45625 Mdot
.20125 .4825 Mdot
.54 .5125 Mdot
.60125 .53375 Mdot
.54 .4925 Mdot
.64875 .4575 Mdot
.45375 .43625 Mdot
.64375 .44375 Mdot
.295 .44125 Mdot
.96125 .51875 Mdot
.3225 .55875 Mdot
.52625 .60875 Mdot
.9675 .62625 Mdot
.70625 .595 Mdot
.54125 .5325 Mdot
.5075 .425 Mdot
.23375 .38875 Mdot
.33375 .34125 Mdot
.6125 .3575 Mdot
.325 .3825 Mdot
.66 .42625 Mdot
.49625 .47375 Mdot
.4 .50125 Mdot
.53625 .47375 Mdot
.44125 .4275 Mdot
.6275 .36125 Mdot
.60375 .2725 Mdot
.57625 .25875 Mdot
.49625 .2775 Mdot
.24625 .43 Mdot
.675 .44625 Mdot
.5225 .4375 Mdot
.27 .4375 Mdot
.35875 .41875 Mdot
.8 .40375 Mdot
.04375 .40375 Mdot
.79875 .43625 Mdot
.3275 .4875 Mdot
.32875 .52875 Mdot
.69 .54125 Mdot
.85125 .55625 Mdot
.305 .55625 Mdot
.02875 .575 Mdot
.64 .575 Mdot
.68625 .595 Mdot
.57625 .54875 Mdot
.66375 .5725 Mdot
.32625 .5675 Mdot
.34125 .555 Mdot
.24875 .53 Mdot
.7825 .56625 Mdot
.755 .5825 Mdot
.18 .5775 Mdot
.46375 .5625 Mdot
.67375 .56875 Mdot
.35125 .58625 Mdot
.57625 .5775 Mdot
.75375 .545 Mdot
.58125 .50625 Mdot
.06125 .4925 Mdot
.21625 .48875 Mdot
.37375 .42875 Mdot
.13375 .445 Mdot
.75625 .45 Mdot
.6475 .42375 Mdot
.79 .42375 Mdot
.4325 .475 Mdot
.82 .4775 Mdot
.5725 .475 Mdot
.58125 .45625 Mdot
.6425 .41125 Mdot
.29875 .3325 Mdot
.5 .3075 Mdot
.51 .29875 Mdot
.5525 .3375 Mdot
.3 .37375 Mdot
.78375 .48625 Mdot
.17375 .5225 Mdot
.61625 .515 Mdot
.5875 .4325 Mdot
.58625 .37125 Mdot
.44625 .27 Mdot
.44375 .25125 Mdot
.72625 .28 Mdot
.0075 .3725 Mdot
.45125 .6825 Mdot
.36375 .6575 Mdot
.32875 .6425 Mdot
.495 .59875 Mdot
.73375 .50375 Mdot
.565 .43125 Mdot
.5125 .45625 Mdot
.47125 .405 Mdot
.35 .34875 Mdot
.595 .34125 Mdot
.3175 .325 Mdot
.855 .64625 Mdot
.24 .36875 Mdot
.7275 .2825 Mdot
.0075 .26625 Mdot
.8675 .2975 Mdot
.3725 .3575 Mdot
.3575 .38875 Mdot
.7575 .54375 Mdot
.1575 .51 Mdot
.6325 .48 Mdot
.15625 .455 Mdot
.6025 .44625 Mdot
.57625 .4475 Mdot
.57625 .495 Mdot
.58375 .545 Mdot
.53875 .555 Mdot
.56875 .55625 Mdot
.31625 .575 Mdot
.94375 .48625 Mdot
.3775 .41625 Mdot
.51 .3525 Mdot
.94125 .325 Mdot
.6675 .405 Mdot
.56125 .50375 Mdot
1 .5725 Mdot
.5425 .61375 Mdot
.20625 .66875 Mdot
.35875 .705 Mdot
.61125 .68375 Mdot
.32 .66125 Mdot
.64375 .66125 Mdot
.50875 .6125 Mdot
.4 .5825 Mdot
.5475 .5825 Mdot
.38375 .57 Mdot
.715 .57625 Mdot
.56 .65875 Mdot
.5575 .64625 Mdot
.5225 .62875 Mdot
.26 .5175 Mdot
.7 .53 Mdot
.475 .5325 Mdot
.02625 .52375 Mdot
.34125 .485 Mdot
.3375 .495 Mdot
.77 .495 Mdot
.03375 .44 Mdot
.77375 .3875 Mdot
.3675 .38125 Mdot
.34875 .35 Mdot
.59875 .3475 Mdot
.955 .34875 Mdot
.2375 .34 Mdot
.1125 .30375 Mdot
.5025 .35625 Mdot
.73375 .38125 Mdot
.63375 .45125 Mdot
.63375 .475 Mdot
.36625 .46625 Mdot
.2525 .44625 Mdot
.34125 .47625 Mdot
.69625 .4675 Mdot
.7625 .46125 Mdot
.315 .48 Mdot
.38375 .495 Mdot
.53375 .46 Mdot
.52125 .4225 Mdot
.49625 .3925 Mdot
.8 .40875 Mdot
.56875 .4175 Mdot
.04625 .4675 Mdot
.2625 .45875 Mdot
.3375 .58625 Mdot
.23625 .5975 Mdot
.605 .545 Mdot
.7375 .60125 Mdot
.82125 .5775 Mdot
.33625 .5325 Mdot
.8375 .57875 Mdot
.57375 .57875 Mdot
.62 .64625 Mdot
.61875 .69375 Mdot
.27 .7675 Mdot
.565 .7475 Mdot
.44 .7375 Mdot
.575 .6125 Mdot
.33 .555 Mdot
.74 .425 Mdot
.295 .40125 Mdot
.47125 .405 Mdot
.65 .49 Mdot
.56125 .58125 Mdot
.49625 .71625 Mdot
.405 .8 Mdot
.6375 .81125 Mdot
.17125 .76375 Mdot
.37625 .35 Mdot
.35125 .37125 Mdot
.38 .43625 Mdot
.52 .47375 Mdot
.63 .5125 Mdot
.59625 .54 Mdot
.5125 .49 Mdot
.5 .48125 Mdot
.35 .51625 Mdot
.605 .5575 Mdot
.31875 .6175 Mdot
.835 .44375 Mdot
.21125 .5825 Mdot
.6875 .6325 Mdot
.08125 .67 Mdot
.835 .64625 Mdot
.3525 .5575 Mdot
.38875 .56375 Mdot
.01125 .51125 Mdot
.9475 .49375 Mdot
.97875 .45875 Mdot
.83 .49 Mdot
.0375 .52875 Mdot
.71875 .57625 Mdot
.15 .61875 Mdot
.6 .65125 Mdot
.5375 .64375 Mdot
.62625 .5875 Mdot
.53125 .5175 Mdot
.59375 .485 Mdot
.5175 .4475 Mdot
.3325 .41875 Mdot
.94625 .515 Mdot
.39125 .58625 Mdot
.5325 .64875 Mdot
.885 .69375 Mdot
.6275 .67125 Mdot
.5675 .64625 Mdot
.55 .595 Mdot
.18625 .5525 Mdot
.39625 .49 Mdot
.60375 .43875 Mdot
.31875 .41625 Mdot
.63625 .37625 Mdot
.50875 .38375 Mdot
.40875 .4075 Mdot
.5175 .4225 Mdot
.37375 .44 Mdot
.77625 .46875 Mdot
.50875 .46125 Mdot
.575 .45625 Mdot
.54375 .4575 Mdot
.2425 .46125 Mdot
.7425 .50125 Mdot
.4225 .52 Mdot
.0925 .58 Mdot
.90875 .5975 Mdot
.44875 .6225 Mdot
.3475 .61125 Mdot
.72625 .6475 Mdot
.0275 .78125 Mdot
.7225 .78625 Mdot
.415 .7225 Mdot
.37625 .72125 Mdot
.5575 .69 Mdot
.94375 .62375 Mdot
.24625 .64875 Mdot
.175 .6675 Mdot
.42 .6125 Mdot
.7275 .58375 Mdot
.725 .57875 Mdot
.56375 .53625 Mdot
.41375 .55125 Mdot
.20375 .53875 Mdot
.3325 .505 Mdot
.7075 .47125 Mdot
.7875 .48 Mdot
.39 .465 Mdot
.30625 .42625 Mdot
.42 .44875 Mdot
.65875 .455 Mdot
.46875 .47 Mdot
.82125 .46875 Mdot
.5225 .535 Mdot
.05375 .51875 Mdot
.29 .59875 Mdot
.26625 .55 Mdot
.30875 .5375 Mdot
.475 .585 Mdot
.8225 .5275 Mdot
.8225 .55375 Mdot
.19125 .56125 Mdot
.88875 .51125 Mdot
.5875 .52875 Mdot
.60625 .49375 Mdot
.645 .4775 Mdot
.22 .43625 Mdot
.58375 .46375 Mdot
.42 .4625 Mdot
.615 .53 Mdot
.335 .57375 Mdot
.68625 .6725 Mdot
.40875 .7025 Mdot
.39125 .66 Mdot
.625 .6025 Mdot
.56375 .5475 Mdot
.51625 .44125 Mdot
.43625 .3475 Mdot
.5675 .2975 Mdot
.33 .28 Mdot
.825 .28625 Mdot
.29875 .60125 Mdot
.36 .66125 Mdot
.42125 .64 Mdot
.4875 .62875 Mdot
.6175 .6 Mdot
.6075 .61 Mdot
.445 .6375 Mdot
.60875 .6675 Mdot
.32625 .655 Mdot
.5625 .605 Mdot
.3525 .51125 Mdot
.73125 .55 Mdot
.175 .52 Mdot
.6725 .475 Mdot
.1275 .4375 Mdot
.83875 .4375 Mdot
.32875 .47125 Mdot
.42625 .50375 Mdot
.9525 .53375 Mdot
.1125 .545 Mdot
.8225 .5375 Mdot
.9375 .4825 Mdot
.86875 .4425 Mdot
.7275 .3825 Mdot
.18 .36625 Mdot
.5725 .32625 Mdot
.55875 .31625 Mdot
.6225 .365 Mdot
.495 .43375 Mdot
.6675 .4575 Mdot
.45375 .52125 Mdot
.345 .54625 Mdot
.01625 .5375 Mdot
.93875 .48 Mdot
.35875 .46125 Mdot
.62625 .43375 Mdot
.8075 .38625 Mdot
.53375 .3575 Mdot
.615 .34875 Mdot
.555 .35875 Mdot
.14875 .39875 Mdot
.42625 .475 Mdot
.59625 .50875 Mdot
.3025 .5375 Mdot
.63375 .58 Mdot
.53875 .555 Mdot
.39625 .50875 Mdot
.475 .495 Mdot
.43125 .48625 Mdot
.75375 .445 Mdot
.49 .39375 Mdot
.60125 .38625 Mdot
.54875 .38125 Mdot
.185 .515 Mdot
.80125 .505 Mdot
.375 .5175 Mdot
.14875 .49125 Mdot
.765 .4825 Mdot
.56875 .43375 Mdot
.355 .445 Mdot
.65625 .40125 Mdot
.025 .22 Mdot
.6775 .25375 Mdot
.44 .30125 Mdot
.435 .2925 Mdot
.47625 .37125 Mdot
.93125 .4725 Mdot
.33375 .47875 Mdot
.105 .4975 Mdot
.4525 .56875 Mdot
.67125 .58625 Mdot
.84 .5075 Mdot
.445 .48875 Mdot
.56875 .47625 Mdot
.04875 .485 Mdot
.36125 .50125 Mdot
.72125 .5675 Mdot
.85375 .52125 Mdot
.40375 .525 Mdot
.175 .57625 Mdot
.435 .575 Mdot
.71875 .6225 Mdot
.485 .69375 Mdot
.80875 .7 Mdot
.45125 .66 Mdot
.1375 .61375 Mdot
.31875 .4875 Mdot
.22125 .48375 Mdot
.38625 .46 Mdot
.39 .47 Mdot
.85125 .49875 Mdot
.81375 .475 Mdot
.05125 .44375 Mdot
.89625 .435 Mdot
.62875 .41875 Mdot
.57125 .4125 Mdot
.665 .4175 Mdot
.25875 .3975 Mdot
.5425 .4025 Mdot
.39875 .40125 Mdot
.59125 .4025 Mdot
.40125 .40625 Mdot
.6375 .3975 Mdot
.46375 .3625 Mdot
.36875 .4225 Mdot
.62125 .4575 Mdot
.55625 .44375 Mdot
.545 .465 Mdot
.4525 .515 Mdot
.46375 .5375 Mdot
.46125 .5675 Mdot
.68 .64125 Mdot
.24875 .5375 Mdot
.37 .48125 Mdot
.41875 .46375 Mdot
.5125 .44 Mdot
.55 .46875 Mdot
.61 .45125 Mdot
.46375 .40375 Mdot
.605 .37125 Mdot
.34625 .3775 Mdot
.56875 .3875 Mdot
.4125 .47375 Mdot
.6375 .41375 Mdot
.04 .44125 Mdot
.12875 .54375 Mdot
.6625 .59625 Mdot
.0975 .59375 Mdot
.9075 .57875 Mdot
.30875 .5575 Mdot
.4375 .49875 Mdot
.92125 .445 Mdot
.12375 .44875 Mdot
.7575 .46875 Mdot
.8875 .50625 Mdot
.915 .53125 Mdot
.7325 .57 Mdot
.26125 .57 Mdot
.48 .62125 Mdot
.56875 .6675 Mdot
.62625 .6375 Mdot
.5075 .59875 Mdot
.6625 .60875 Mdot
.45625 .565 Mdot
.35 .5375 Mdot
.0275 .5475 Mdot
.95125 .55375 Mdot
.3475 .52875 Mdot
.7025 .5075 Mdot
.71 .50125 Mdot
.45875 .48125 Mdot
.645 .46625 Mdot
.53375 .47125 Mdot
.1675 .455 Mdot
.41875 .4425 Mdot
.5775 .48125 Mdot
.31125 .495 Mdot
.64875 .47375 Mdot
.5525 .485 Mdot
.38375 .51375 Mdot
.42375 .52 Mdot
.47 .53125 Mdot
.79125 .57375 Mdot
.44375 .65375 Mdot
.60875 .66375 Mdot
.53 .67375 Mdot
.1425 .53625 Mdot
.85 .51125 Mdot
.33 .46125 Mdot
.205 .43875 Mdot
.6375 .45125 Mdot
.695 .5 Mdot
.31625 .52125 Mdot
.6075 .595 Mdot
.03375 .7375 Mdot
.62375 .7025 Mdot
.4775 .7 Mdot
.45375 .65 Mdot
.405 .56875 Mdot
.935 .49125 Mdot
.4425 .4875 Mdot
.00125 .4275 Mdot
.53125 .40875 Mdot
.56375 .39875 Mdot
.96375 .485 Mdot
.3375 .5125 Mdot
.63 .4775 Mdot
.0225 .47125 Mdot
.38875 .5025 Mdot
.69125 .455 Mdot
.8875 .45125 Mdot
.4525 .50125 Mdot
.035 .495 Mdot
.5175 .4975 Mdot
.71 .4825 Mdot
.51875 .44125 Mdot
.78125 .4425 Mdot
.415 .43375 Mdot
.18625 .45875 Mdot
.35125 .5175 Mdot
.975 .5425 Mdot
.29125 .51625 Mdot
.375 .55125 Mdot
.41 .48875 Mdot
.83625 .455 Mdot
.7475 .445 Mdot
.105 .455 Mdot
.8875 .49125 Mdot
.6775 .51 Mdot
.4925 .5425 Mdot
.72375 .53375 Mdot
.2525 .5625 Mdot
.55375 .5875 Mdot
.36375 .59625 Mdot
.62625 .5875 Mdot
.38375 .56 Mdot
.63875 .52625 Mdot
.485 .4925 Mdot
.3625 .44 Mdot
.5675 .38875 Mdot
.5875 .40125 Mdot
.55875 .425 Mdot
.48125 .4575 Mdot
.36125 .47875 Mdot
.5475 .5075 Mdot
.61875 .5025 Mdot
.2675 .38 Mdot
.315 .3375 Mdot
.43125 .32625 Mdot
.5325 .3925 Mdot
.46625 .41 Mdot
.67875 .45 Mdot
.45125 .5425 Mdot
.5775 .56875 Mdot
.3675 .52875 Mdot
.5625 .50625 Mdot
.47 .44625 Mdot
.5575 .53625 Mdot
.0775 .525 Mdot
.10625 .425 Mdot
.63375 .42375 Mdot
.12625 .435 Mdot
.9475 .47125 Mdot
.27125 .50375 Mdot
.47125 .54 Mdot
.86 .575 Mdot
.175 .565 Mdot
.6625 .55125 Mdot
.085 .5125 Mdot
.80625 .52625 Mdot
.88875 .505 Mdot
.03625 .49625 Mdot
.67875 .4475 Mdot
.33875 .46125 Mdot
.36875 .38125 Mdot
.63375 .34 Mdot
.6175 .335 Mdot
.50125 .35875 Mdot
.65875 .34625 Mdot
.4775 .4075 Mdot
.31625 .44875 Mdot
.08125 .45625 Mdot
.95 .475 Mdot
.2975 .51 Mdot
.7925 .56 Mdot
.65 .56 Mdot
.38375 .58125 Mdot
.70125 .565 Mdot
.525 .5675 Mdot
.18125 .57875 Mdot
.44875 .54625 Mdot
.53875 .51625 Mdot
.31625 .50125 Mdot
.6175 .50125 Mdot
.605 .52375 Mdot
.37 .58375 Mdot
.3875 .5925 Mdot
.52 .58375 Mdot
.80625 .55875 Mdot
.415 .475 Mdot
.59625 .4175 Mdot
.51 .41875 Mdot
.05875 .48375 Mdot
.93125 .505 Mdot
.29625 .51625 Mdot
.205 .5175 Mdot
.58 .49 Mdot
.7675 .45625 Mdot
.365 .42375 Mdot
.475 .3675 Mdot
.0825 .4025 Mdot
.5625 .45875 Mdot
.51875 .47 Mdot
.53625 .52125 Mdot
.27625 .56375 Mdot
.875 .5475 Mdot
.67625 .49125 Mdot
.6075 .48 Mdot
.49375 .39125 Mdot
.29375 .38 Mdot
.6325 .42375 Mdot
.05125 .44875 Mdot
.36125 .4825 Mdot
.72625 .4975 Mdot
.84625 .5025 Mdot
.5125 .46 Mdot
.735 .415 Mdot
.6575 .39375 Mdot
.47875 .395 Mdot
.82 .3725 Mdot
.35125 .40875 Mdot
.225 .39875 Mdot
.3825 .3975 Mdot
.8775 .38125 Mdot
.38625 .3875 Mdot
.35375 .35 Mdot
.4 .39 Mdot
.8525 .4075 Mdot
.66625 .47875 Mdot
.20125 .50875 Mdot
.8425 .51375 Mdot
.7025 .47125 Mdot
.44 .435 Mdot
.765 .45875 Mdot
.28625 .46875 Mdot
.505 .44 Mdot
.3925 .4775 Mdot
.61875 .5175 Mdot
.38625 .4725 Mdot
.63875 .465 Mdot
.455 .5325 Mdot
.38375 .58375 Mdot
.5375 .61125 Mdot
.63875 .6775 Mdot
.5275 .67625 Mdot
.51875 .59875 Mdot
.30875 .55375 Mdot
.575 .51125 Mdot
.60875 .485 Mdot
.28 .69375 Mdot
.32125 .73875 Mdot
.41875 .73875 Mdot
.555 .63625 Mdot
.43125 .5825 Mdot
.71625 .4925 Mdot
.42625 .39375 Mdot
.51125 .36 Mdot
.45625 .445 Mdot
.56625 .4625 Mdot
.48875 .50375 Mdot
.46 .50625 Mdot
.115 .47875 Mdot
.08125 .5325 Mdot
.57875 .51375 Mdot
.18625 .53 Mdot
.945 .52875 Mdot
.25625 .57375 Mdot
.5175 .55 Mdot
.7625 .54875 Mdot
.25875 .525 Mdot
.5725 .5025 Mdot
.21125 .49875 Mdot
.6975 .4975 Mdot
.8925 .495 Mdot
.09125 .51875 Mdot
.65625 .5775 Mdot
.36 .56 Mdot
.3325 .5975 Mdot
.66 .6425 Mdot
.60125 .61875 Mdot
.55 .60125 Mdot
.57625 .615 Mdot
.535 .57125 Mdot
.28625 .5175 Mdot
.115 .51125 Mdot
.96125 .48 Mdot
.24375 .46875 Mdot
.855 .45375 Mdot
.615 .5075 Mdot
.37125 .54125 Mdot
.7025 .56 Mdot
.47125 .55 Mdot
.27 .51 Mdot
.42875 .5 Mdot
.4875 .5175 Mdot
.35125 .49875 Mdot
.64625 .51875 Mdot
.57 .52125 Mdot
.3575 .4475 Mdot
.41125 .44 Mdot
.535 .4425 Mdot
.79375 .4375 Mdot
.40625 .47125 Mdot
.60875 .565 Mdot
.48 .5475 Mdot
.9875 .4625 Mdot
.28375 .485 Mdot
.23625 .5025 Mdot
.4925 .5175 Mdot
.8225 .5325 Mdot
.4325 .55 Mdot
.38 .5325 Mdot
.1225 .43125 Mdot
.495 .38125 Mdot
.54375 .38375 Mdot
.5875 .3775 Mdot
.23375 .37375 Mdot
.75375 .41125 Mdot
.905 .47875 Mdot
.69375 .58125 Mdot
.44125 .70125 Mdot
.2725 .61 Mdot
.66875 .5875 Mdot
.05625 .5625 Mdot
.32125 .4625 Mdot
.775 .49625 Mdot
.80625 .515 Mdot
.56625 .51875 Mdot
.93625 .56125 Mdot
.54875 .57125 Mdot
.5 .58875 Mdot
.7875 .6025 Mdot
.32875 .5525 Mdot
.36875 .535 Mdot
.28625 .52 Mdot
.83 .5 Mdot
.435 .52875 Mdot
.34875 .60875 Mdot
.44375 .645 Mdot
.8375 .65625 Mdot
.56625 .61875 Mdot
.2875 .5675 Mdot
.0375 .51 Mdot
.7675 .49875 Mdot
.7075 .5425 Mdot
.45375 .55 Mdot
.7425 .51875 Mdot
.31 .5025 Mdot
.49625 .52625 Mdot
.44 .50375 Mdot
.57625 .48875 Mdot
.39375 .57625 Mdot
.61875 .5975 Mdot
.415 .5375 Mdot
.49875 .51125 Mdot
.44125 .50375 Mdot
.66625 .4425 Mdot
.48625 .44125 Mdot
.61875 .45875 Mdot
.25875 .47625 Mdot
.58375 .5025 Mdot
.5975 .4625 Mdot
.30625 .37 Mdot
.31375 .36875 Mdot
.395 .42125 Mdot
.5675 .49 Mdot
.4375 .5525 Mdot
.76125 .62625 Mdot
.36 .665 Mdot
.52625 .6875 Mdot
.46625 .5925 Mdot
.56625 .55375 Mdot
.5325 .5275 Mdot
.3325 .55875 Mdot
.15625 .54375 Mdot
.08375 .46125 Mdot
.51 .46375 Mdot
.26 .48375 Mdot
.955 .4875 Mdot
.2225 .42625 Mdot
.56375 .455 Mdot
.6675 .445 Mdot
.31625 .48875 Mdot
.53375 .50875 Mdot
.28 .4775 Mdot
.6275 .44 Mdot
.91 .4425 Mdot
.13625 .3775 Mdot
.60875 .315 Mdot
.36875 .3875 Mdot
.3125 .4325 Mdot
.72375 .4075 Mdot
.545 .43875 Mdot
.6025 .4675 Mdot
.5 .4475 Mdot
.6 .43 Mdot
.25875 .48 Mdot
.115 .525 Mdot
.1925 .55875 Mdot
.9125 .51625 Mdot
.6 .46125 Mdot
.31875 .48625 Mdot
.75875 .51125 Mdot
.995 .495 Mdot
.48 .51875 Mdot
.28625 .52625 Mdot
.4175 .52875 Mdot
.4575 .455 Mdot
.35875 .43875 Mdot
.6825 .3575 Mdot
.5675 .30875 Mdot
.3425 .32 Mdot
.42375 .3475 Mdot
.5275 .3925 Mdot
.78875 .46375 Mdot
.40125 .5125 Mdot
.62125 .5075 Mdot
.46 .5625 Mdot
.2525 .51375 Mdot
.29875 .50625 Mdot
.3975 .53625 Mdot
.83625 .54 Mdot
.5 .5675 Mdot
.32 .58875 Mdot
.21 .58625 Mdot
.42875 .5775 Mdot
.555 .5575 Mdot
.64875 .54875 Mdot
.16125 .56125 Mdot
.68875 .56125 Mdot
.8 .4575 Mdot
.43 .4325 Mdot
.3175 .57 Mdot
.66875 .59875 Mdot
.05875 .66875 Mdot
.3725 .69125 Mdot
.7175 .62875 Mdot
.76 .56375 Mdot
.6325 .55125 Mdot
.4825 .4625 Mdot
.49125 .485 Mdot
.7525 .46875 Mdot
.37625 .4675 Mdot
.4375 .49 Mdot
.21625 .54375 Mdot
.7625 .5525 Mdot
.54 .51125 Mdot
.275 .46125 Mdot
.49625 .4425 Mdot
.83875 .3825 Mdot
.51625 .37875 Mdot
.305 .4575 Mdot
.12625 .4825 Mdot
.66375 .48 Mdot
.69125 .495 Mdot
.5325 .505 Mdot
.66375 .48875 Mdot
.36125 .51125 Mdot
.53625 .495 Mdot
.37375 .5025 Mdot
.62 .495 Mdot
.36875 .475 Mdot
.62875 .455 Mdot
.35375 .48625 Mdot
.57625 .4425 Mdot
.42875 .4025 Mdot
.655 .3975 Mdot
.46625 .41125 Mdot
.6875 .42 Mdot
.1575 .44125 Mdot
.62375 .45375 Mdot
.615 .47375 Mdot
.38 .4025 Mdot
.29125 .36875 Mdot
.36625 .3375 Mdot
.5775 .3775 Mdot
.42125 .35375 Mdot
.765 .3475 Mdot
.385 .39625 Mdot
.50625 .4425 Mdot
.48 .5025 Mdot
.60125 .56625 Mdot
.55625 .59625 Mdot
.24375 .44875 Mdot
.24 .48375 Mdot
.1425 .53125 Mdot
.4375 .515 Mdot
.34625 .47125 Mdot
.925 .44625 Mdot
.21 .4375 Mdot
.6025 .43 Mdot
.58875 .47125 Mdot
.3775 .49 Mdot
.4925 .5 Mdot
.34 .60875 Mdot
.56125 .655 Mdot
.93375 .68125 Mdot
.17375 .675 Mdot
.585 .70875 Mdot
.3375 .6075 Mdot
.35125 .525 Mdot
.69875 .49875 Mdot
.56625 .53 Mdot
.615 .50375 Mdot
.43125 .49125 Mdot
.65875 .51 Mdot
.2175 .4475 Mdot
.16 .38125 Mdot
.14875 .42875 Mdot
.95875 .4575 Mdot
.57 .49375 Mdot
.40125 .4675 Mdot
.6925 .43375 Mdot
.48375 .435 Mdot
.27625 .43 Mdot
.39375 .4375 Mdot
.48875 .5425 Mdot
.3675 .57625 Mdot
.6475 .6475 Mdot
.6 .7125 Mdot
.33375 .7375 Mdot
.42875 .665 Mdot
.50625 .59625 Mdot
.82375 .53625 Mdot
.38375 .45375 Mdot
.635 .3925 Mdot
.44375 .34375 Mdot
.24625 .49625 Mdot
.34625 .49 Mdot
.32 .46625 Mdot
.835 .47875 Mdot
.5725 .4425 Mdot
.27875 .44 Mdot
.34 .47375 Mdot
.34375 .49375 Mdot
.61375 .50875 Mdot
.6525 .5 Mdot
.1375 .48 Mdot
.61 .48875 Mdot
.81625 .49875 Mdot
.44 .47625 Mdot
.95875 .40375 Mdot
.3825 .34625 Mdot
.57375 .3125 Mdot
.1725 .26375 Mdot
.345 .30375 Mdot
.72375 .365 Mdot
.65 .43625 Mdot
.76875 .48625 Mdot
.4475 .58375 Mdot
.43375 .50375 Mdot
.73 .5275 Mdot
.4875 .56 Mdot
.4225 .54625 Mdot
.15 .47875 Mdot
.725 .5075 Mdot
.6575 .5125 Mdot
.205 .5 Mdot
.53375 .49375 Mdot
.8175 .5575 Mdot
.50875 .58 Mdot
.30375 .515 Mdot
.17875 .50875 Mdot
.6075 .52375 Mdot
.665 .52125 Mdot
.59375 .4825 Mdot
.65125 .5025 Mdot
.33375 .49625 Mdot
.56625 .48125 Mdot
.345 .4575 Mdot
.6825 .465 Mdot
.32375 .445 Mdot
.62 .49375 Mdot
.35875 .5 Mdot
.59 .55625 Mdot
.39625 .59625 Mdot
.6825 .60875 Mdot
.43375 .56375 Mdot
.7575 .585 Mdot
.11125 .6075 Mdot
.635 .6275 Mdot
.61125 .69125 Mdot
.405 .68375 Mdot
.2925 .66625 Mdot
.33375 .62625 Mdot
.60375 .5375 Mdot
.44125 .505 Mdot
.7325 .53625 Mdot
.39375 .51375 Mdot
.52625 .47625 Mdot
.455 .4725 Mdot
.61875 .465 Mdot
.57125 .4175 Mdot
.1425 .5275 Mdot
.295 .52 Mdot
.225 .525 Mdot
.34875 .56125 Mdot
.405 .58125 Mdot
.9225 .585 Mdot
.15875 .605 Mdot
.675 .56875 Mdot
.47625 .51 Mdot
.4925 .4575 Mdot
.42125 .44875 Mdot
.3975 .41875 Mdot
.52625 .43875 Mdot
.9125 .435 Mdot
.23125 .4975 Mdot
.58125 .505 Mdot
.25 .5325 Mdot
.455 .58375 Mdot
.64875 .6075 Mdot
.57125 .57375 Mdot
.6075 .58 Mdot
.42625 .60625 Mdot
.695 .56875 Mdot
.1725 .615 Mdot
.2225 .62625 Mdot
.0725 .51 Mdot
.5825 .47 Mdot
.4525 .40125 Mdot
.66875 .42375 Mdot
.9875 .39 Mdot
.52375 .4325 Mdot
.2225 .4675 Mdot
.40875 .50125 Mdot
.52625 .42125 Mdot
.35625 .41875 Mdot
.57625 .42125 Mdot
.68375 .39125 Mdot
.295 .38375 Mdot
.46125 .44625 Mdot
.49625 .47 Mdot
.79375 .46 Mdot
.42 .51375 Mdot
.61125 .54 Mdot
.48125 .5425 Mdot
.24875 .55 Mdot
.37875 .5325 Mdot
.255 .49 Mdot
.845 .46125 Mdot
.66 .45625 Mdot
.20625 .4375 Mdot
.06625 .45 Mdot
.46125 .46875 Mdot
.2575 .4525 Mdot
.6525 .46 Mdot
.68125 .4725 Mdot
.10125 .49375 Mdot
.5875 .4825 Mdot
.8875 .47875 Mdot
.4325 .46375 Mdot
.8625 .535 Mdot
.48625 .54875 Mdot
.54875 .58125 Mdot
.2175 .62125 Mdot
.265 .62625 Mdot
.7825 .56875 Mdot
.54625 .555 Mdot
.885 .46625 Mdot
.3325 .37 Mdot
.4675 .4225 Mdot
.675 .4425 Mdot
.5775 .4325 Mdot
.45375 .4575 Mdot
.07125 .55125 Mdot
.685 .5325 Mdot
.7475 .51875 Mdot
.1775 .51625 Mdot
.49875 .505 Mdot
.8275 .45 Mdot
.5875 .42 Mdot
.23625 .4575 Mdot
.205 .4875 Mdot
.59 .475 Mdot
.625 .44375 Mdot
.6525 .47 Mdot
.6525 .50625 Mdot
.335 .5 Mdot
.50875 .5325 Mdot
.38875 .54625 Mdot
.6675 .5525 Mdot
.37375 .53 Mdot
.56625 .4925 Mdot
.34375 .475 Mdot
.62875 .48125 Mdot
.3875 .5125 Mdot
.6825 .54875 Mdot
.41375 .615 Mdot
.78 .60875 Mdot
.12625 .555 Mdot
.63125 .48375 Mdot
.585 .39125 Mdot
.34625 .42875 Mdot
.3525 .4625 Mdot
.28 .51 Mdot
.6 .535 Mdot
.4825 .545 Mdot
.7375 .48875 Mdot
.36125 .47125 Mdot
.56 .47625 Mdot
.4275 .5075 Mdot
.65625 .50375 Mdot
.5875 .53 Mdot
.065 .465 Mdot
.365 .455 Mdot
.24125 .46375 Mdot
.335 .40875 Mdot
.4375 .39125 Mdot
.885 .3875 Mdot
.17375 .3725 Mdot
.7025 .385 Mdot
.39125 .41875 Mdot
.5675 .43875 Mdot
.4 .45875 Mdot
.39375 .43625 Mdot
.54875 .42125 Mdot
.9275 .42875 Mdot
.20375 .43 Mdot
.59125 .45 Mdot
.16375 .4725 Mdot
.57375 .45625 Mdot
.59625 .44125 Mdot
.54875 .45375 Mdot
.64875 .43 Mdot
.415 .415 Mdot
.6975 .48 Mdot
.13875 .46 Mdot
.28125 .45 Mdot
.04875 .46125 Mdot
.59375 .465 Mdot
.46 .54 Mdot
.66 .56875 Mdot
.97875 .63625 Mdot
.53125 .5925 Mdot
.23375 .60125 Mdot
.415 .5925 Mdot
.545 .60125 Mdot
.33 .59625 Mdot
.5825 .6075 Mdot
.6625 .60625 Mdot
.29125 .5875 Mdot
.4875 .57375 Mdot
.47375 .58 Mdot
.775 .6 Mdot
.45125 .58125 Mdot
.60625 .57875 Mdot
.515 .59125 Mdot
.95125 .4625 Mdot
.26625 .42125 Mdot
.4325 .4225 Mdot
.1625 .44875 Mdot
.8675 .4625 Mdot
.70125 .5125 Mdot
.20125 .52875 Mdot
.11625 .53125 Mdot
.5375 .53625 Mdot
.21375 .5175 Mdot
.68375 .50125 Mdot
.67 .5075 Mdot
.07875 .46625 Mdot
.60125 .46 Mdot
.93125 .55375 Mdot
.40125 .61875 Mdot
.7725 .5775 Mdot
.59125 .58375 Mdot
.50875 .52375 Mdot
.28625 .45375 Mdot
.21625 .39 Mdot
.76375 .42125 Mdot
.515 .405 Mdot
.9725 .48 Mdot
.2225 .585 Mdot
.53 .59625 Mdot
.60375 .55375 Mdot
.65625 .52875 Mdot
.5 .485 Mdot
.65125 .385 Mdot
.835 .40625 Mdot
.14375 .4 Mdot
.5175 .43 Mdot
.79375 .49 Mdot
.65 .50875 Mdot
.2025 .49125 Mdot
.18875 .5075 Mdot
.57875 .49125 Mdot
.64625 .48875 Mdot
.65375 .51375 Mdot
.65375 .485 Mdot
.33 .46875 Mdot
.4825 .455 Mdot
.42625 .43875 Mdot
.6525 .41375 Mdot
.3975 .43875 Mdot
.56625 .45875 Mdot
.30875 .475 Mdot
.65625 .46125 Mdot
.3525 .425 Mdot
.745 .37375 Mdot
.35875 .33375 Mdot
.7825 .34 Mdot
.1925 .37375 Mdot
.5525 .4125 Mdot
.6225 .51625 Mdot
.35625 .54 Mdot
.3475 .54375 Mdot
.275 .52375 Mdot
.60625 .52375 Mdot
.5375 .54875 Mdot
.65375 .5875 Mdot
.41 .60625 Mdot
.60375 .5675 Mdot
.34375 .53125 Mdot
.6625 .4875 Mdot
.6425 .49125 Mdot
.4425 .49375 Mdot
.26 .54125 Mdot
.3175 .61125 Mdot
.475 .63875 Mdot
.86875 .645 Mdot
.12375 .65625 Mdot
.7625 .6475 Mdot
.3625 .615 Mdot
.57375 .58 Mdot
.375 .5525 Mdot
.42375 .54875 Mdot
.59875 .53 Mdot
.85375 .51625 Mdot
.23125 .5125 Mdot
.5825 .50625 Mdot
.16625 .50125 Mdot
.595 .5075 Mdot
.55375 .50125 Mdot
.57875 .47875 Mdot
.62375 .4925 Mdot
.44375 .51375 Mdot
.69375 .52 Mdot
.13125 .57 Mdot
.285 .63 Mdot
.03625 .63125 Mdot
.59 .61375 Mdot
.48625 .55625 Mdot
.63625 .48125 Mdot
.99875 .38875 Mdot
.61125 .39625 Mdot
.12125 .3725 Mdot
.45 .3775 Mdot
.57125 .4025 Mdot
.295 .4175 Mdot
.57125 .41 Mdot
.69625 .41375 Mdot
.27375 .41625 Mdot
.49 .42 Mdot
.465 .41875 Mdot
.7875 .3925 Mdot
.44375 .4025 Mdot
.61125 .41375 Mdot
.555 .4125 Mdot
.92 .505 Mdot
.2825 .51375 Mdot
.45 .5075 Mdot
.10125 .51375 Mdot
.88375 .50125 Mdot
.75 .47 Mdot
.18625 .4775 Mdot
.1675 .46625 Mdot
.93375 .4475 Mdot
.555 .43375 Mdot
.235 .46625 Mdot
.67375 .47125 Mdot
.68125 .50875 Mdot
.04375 .53625 Mdot
.6625 .52625 Mdot
.99375 .4325 Mdot
.40625 .38 Mdot
.64 .415 Mdot
.69375 .425 Mdot
.46 .45125 Mdot
.35625 .49375 Mdot
.195 .53125 Mdot
.72125 .5175 Mdot
.4875 .53125 Mdot
.1875 .56 Mdot
.595 .50875 Mdot
.54625 .4825 Mdot
.7225 .51625 Mdot
.4425 .53375 Mdot
.63125 .56125 Mdot
.955 .55375 Mdot
.0275 .56 Mdot
.55375 .56125 Mdot
.77875 .56875 Mdot
.6875 .53 Mdot
.22625 .52875 Mdot
.10375 .515 Mdot
.605 .5125 Mdot
.68 .525 Mdot
.62 .55875 Mdot
.675 .5425 Mdot
.35875 .56875 Mdot
.40875 .55125 Mdot
.465 .57125 Mdot
.645 .54875 Mdot
.425 .57 Mdot
.57875 .52 Mdot
.28875 .52375 Mdot
.57375 .515 Mdot
.43625 .53 Mdot
.765 .53375 Mdot
.35875 .5575 Mdot
.72125 .53 Mdot
.2525 .4975 Mdot
.4775 .47375 Mdot
.6675 .43625 Mdot
.4175 .46625 Mdot
.38125 .4675 Mdot
.23625 .44375 Mdot
.59625 .46625 Mdot
.5475 .4525 Mdot
.64375 .41125 Mdot
.4425 .37875 Mdot
.61 .42625 Mdot
.29625 .38875 Mdot
.69875 .41375 Mdot
.6775 .4125 Mdot
.5 .43125 Mdot
.265 .39 Mdot
.33 .3275 Mdot
.4875 .3275 Mdot
.84125 .3675 Mdot
.1025 .36875 Mdot
.815 .39125 Mdot
.31625 .44875 Mdot
.60625 .47 Mdot
.33375 .4825 Mdot
.4475 .47875 Mdot
.65125 .4925 Mdot
.7725 .48375 Mdot
.30125 .46125 Mdot
.535 .41875 Mdot
.1775 .43 Mdot
.6275 .42625 Mdot
.5 .44 Mdot
.5775 .47 Mdot
.64125 .49625 Mdot
.47125 .465 Mdot
.66625 .4175 Mdot
.13 .385 Mdot
.3275 .35625 Mdot
.04875 .43375 Mdot
.94125 .44125 Mdot
.65875 .465 Mdot
.53125 .4975 Mdot
.65 .5275 Mdot
.92 .54125 Mdot
.67875 .585 Mdot
.09625 .605 Mdot
.46625 .5925 Mdot
.565 .65875 Mdot
.2625 .6725 Mdot
.6175 .62375 Mdot
.64875 .60125 Mdot
.30125 .60375 Mdot
.48875 .55 Mdot
.45375 .53875 Mdot
.785 .57 Mdot
.47375 .57125 Mdot
.5775 .5675 Mdot
.57625 .5725 Mdot
.89625 .51125 Mdot
.32125 .51375 Mdot
.445 .53625 Mdot
.05875 .53875 Mdot
.9075 .55 Mdot
.78 .5425 Mdot
.14375 .54375 Mdot
.24125 .5325 Mdot
.8425 .5575 Mdot
.54625 .575 Mdot
.30875 .575 Mdot
.6425 .545 Mdot
.68625 .52375 Mdot
.00875 .51 Mdot
.76 .52375 Mdot
.99625 .5625 Mdot
.43125 .60125 Mdot
.515 .56375 Mdot
.81125 .53875 Mdot
.3325 .56875 Mdot
.5175 .56375 Mdot
.1175 .53875 Mdot
.68 .5325 Mdot
.485 .50875 Mdot
.11625 .38875 Mdot
.63375 .45625 Mdot
.52625 .5025 Mdot
.7575 .4925 Mdot
.4325 .50625 Mdot
.57125 .51875 Mdot
.00125 .57875 Mdot
.55875 .57875 Mdot
.72625 .5375 Mdot
.715 .585 Mdot
.28625 .58875 Mdot
.00875 .5625 Mdot
.635 .58 Mdot
.71875 .5725 Mdot
.5625 .49875 Mdot
.715 .48875 Mdot
.41125 .45375 Mdot
.24875 .44875 Mdot
.57125 .42875 Mdot
.615 .48875 Mdot
.47625 .5125 Mdot
.54125 .555 Mdot
.3375 .54 Mdot
.4775 .5525 Mdot
.51 .525 Mdot
.77875 .51625 Mdot
.31875 .53625 Mdot
.6975 .55125 Mdot
.35625 .575 Mdot
.3525 .61875 Mdot
.7325 .56375 Mdot
.4425 .3975 Mdot
.4025 .345 Mdot
.20625 .42625 Mdot
.60125 .43125 Mdot
.58125 .47125 Mdot
.61625 .55375 Mdot
.47 .6225 Mdot
.5925 .57625 Mdot
.28375 .595 Mdot
.6575 .5825 Mdot
.75 .54875 Mdot
.515 .69125 Mdot
.2575 .66375 Mdot
.33375 .6925 Mdot
.4825 .64 Mdot
.8575 .56125 Mdot
.1025 .56125 Mdot
.81125 .565 Mdot
.26375 .51 Mdot
.6225 .55125 Mdot
.35375 .595 Mdot
.43875 .595 Mdot
.72 .55875 Mdot
.6625 .55 Mdot
.37 .54875 Mdot
.50875 .545 Mdot
.21 .50125 Mdot
.6 .51125 Mdot
.50375 .53 Mdot
.55625 .5175 Mdot
.6775 .49875 Mdot
.47125 .5475 Mdot
.65 .55 Mdot
.1625 .5375 Mdot
.3325 .50625 Mdot
.1075 .50375 Mdot
.815 .49125 Mdot
.76375 .49375 Mdot
.54125 .42625 Mdot
.72125 .47375 Mdot
.76375 .55375 Mdot
.78625 .53 Mdot
.0825 .53 Mdot
.4925 .52875 Mdot
.51625 .41125 Mdot
.285 .3575 Mdot
.60375 .39 Mdot
.66 .42125 Mdot
.29 .4375 Mdot
.50125 .49625 Mdot
.44375 .505 Mdot
.80125 .50875 Mdot
.48 .50375 Mdot
.53 .495 Mdot
.64375 .47625 Mdot
.87 .51625 Mdot
.34375 .535 Mdot
.45125 .54 Mdot
.02875 .5475 Mdot
.925 .55 Mdot
.8075 .55375 Mdot
.12 .57 Mdot
.24125 .56 Mdot
.84875 .5325 Mdot
.49125 .5125 Mdot
.3925 .50875 Mdot
.6 .51125 Mdot
.69625 .52625 Mdot
.86375 .52875 Mdot
.94125 .50125 Mdot
.475 .48 Mdot
.40875 .46875 Mdot
.955 .46375 Mdot
.21 .41 Mdot
.615 .37125 Mdot
.07375 .38625 Mdot
.62625 .43125 Mdot
.51 .495 Mdot
.09875 .58 Mdot
.68875 .5475 Mdot
.49375 .5725 Mdot
.74875 .58875 Mdot
.44875 .575 Mdot
.5575 .525 Mdot
.5875 .46125 Mdot
.65125 .455 Mdot
.7475 .4225 Mdot
.35125 .385 Mdot
.7 .39375 Mdot
.73125 .39125 Mdot
.52625 .4175 Mdot
.7175 .4575 Mdot
.475 .4825 Mdot
.1125 .495 Mdot
.70625 .505 Mdot
.54375 .47125 Mdot
.52 .44875 Mdot
.47375 .4275 Mdot
.4625 .43375 Mdot
.305 .425 Mdot
.6525 .46625 Mdot
.745 .4675 Mdot
.295 .44 Mdot
.69 .44125 Mdot
.42625 .455 Mdot
.225 .455 Mdot
.85875 .4925 Mdot
.97 .6125 Mdot
.51875 .6575 Mdot
.42625 .6775 Mdot
.1725 .59375 Mdot
.58125 .56 Mdot
.63375 .48 Mdot
.62375 .39625 Mdot
.40625 .31 Mdot
.65375 .38 Mdot
.23625 .43375 Mdot
.66875 .48875 Mdot
.79 .54875 Mdot
.52125 .3025 Mdot
.2575 .37375 Mdot
.34875 .39125 Mdot
.47125 .44125 Mdot
.85625 .5 Mdot
.145 .4925 Mdot
.77875 .47125 Mdot
.2525 .49 Mdot
.635 .44375 Mdot
.34 .385 Mdot
.44625 .40375 Mdot
.77375 .46375 Mdot
.58 .48375 Mdot
.41375 .51375 Mdot
.46 .56625 Mdot
.27 .61375 Mdot
.5525 .58875 Mdot
.565 .56875 Mdot
.52375 .5625 Mdot
.70125 .54125 Mdot
.4125 .48625 Mdot
.66875 .49125 Mdot
.17125 .51125 Mdot
.36375 .53 Mdot
1 .555 Mdot
.1575 .4675 Mdot
.72375 .47375 Mdot
.7975 .45125 Mdot
.60125 .56875 Mdot
.70875 .52125 Mdot
.68 .46875 Mdot
.835 .49625 Mdot
.0725 .4275 Mdot
.5225 .4075 Mdot
.46375 .48375 Mdot
.33625 .5 Mdot
.6125 .49 Mdot
.60375 .47625 Mdot
.3225 .48625 Mdot
.49875 .44625 Mdot
.44 .46 Mdot
.83125 .425 Mdot
.4325 .39375 Mdot
.5525 .38125 Mdot
.6425 .37875 Mdot
.89125 .395 Mdot
.33625 .42125 Mdot
.4825 .4475 Mdot
.94 .46 Mdot
.80125 .46125 Mdot
.12875 .41875 Mdot
.24375 .39625 Mdot
.83375 .3975 Mdot
.44875 .39 Mdot
.49875 .37125 Mdot
.54 .4 Mdot
.68125 .41375 Mdot
.915 .4775 Mdot
.81 .52 Mdot
.5875 .54625 Mdot
.29375 .56125 Mdot
.06875 .64125 Mdot
.68375 .67875 Mdot
.1025 .66375 Mdot
.51875 .62625 Mdot
.58625 .575 Mdot
.17 .47125 Mdot
.66 .43375 Mdot
.5025 .38 Mdot
.71875 .34375 Mdot
.45625 .365 Mdot
.53625 .47 Mdot
.64 .4775 Mdot
.5625 .505 Mdot
.75 .505 Mdot
.4725 .535 Mdot
.73875 .5675 Mdot
.745 .575 Mdot
.52 .59875 Mdot
.68875 .58625 Mdot
.53 .55875 Mdot
.06 .55625 Mdot
.75625 .5425 Mdot
.5 .47625 Mdot
.54375 .42875 Mdot
.44625 .44375 Mdot
.54125 .4575 Mdot
.205 .49 Mdot
.74 .51 Mdot
.68 .545 Mdot
.33375 .57375 Mdot
.6975 .56875 Mdot
.40875 .53125 Mdot
.195 .49875 Mdot
.90625 .50875 Mdot
.825 .44625 Mdot
.6325 .44875 Mdot
.405 .47625 Mdot
.16125 .52125 Mdot
.59 .54375 Mdot
.67125 .61375 Mdot
.57375 .65125 Mdot
.40875 .72875 Mdot
.71 .65375 Mdot
.17875 .57875 Mdot
.6725 .495 Mdot
.815 .42625 Mdot
.55125 .69 Mdot
.26875 .61875 Mdot
.32375 .57875 Mdot
.49625 .59375 Mdot
.8575 .59 Mdot
.11625 .5925 Mdot
.80375 .59 Mdot
.27875 .59875 Mdot
.59125 .565 Mdot
.29875 .565 Mdot
.5 .52375 Mdot
.8225 .49 Mdot
.4775 .46125 Mdot
.48375 .4475 Mdot
.4275 .38875 Mdot
.31875 .35875 Mdot
.505 .37125 Mdot
.57 .3825 Mdot
.525 .38 Mdot
.74375 .40625 Mdot
.32875 .465 Mdot
.7375 .54 Mdot
.18125 .53875 Mdot
.3375 .55125 Mdot
.98125 .54875 Mdot
.20125 .57875 Mdot
.65125 .5775 Mdot
.8525 .63375 Mdot
.6275 .605 Mdot
.7275 .605 Mdot
.6275 .6075 Mdot
.8875 .545 Mdot
.04125 .55125 Mdot
.4775 .5875 Mdot
.4775 .51875 Mdot
.4075 .53 Mdot
.55125 .53875 Mdot
.62625 .54375 Mdot
.3175 .49125 Mdot
.4925 .555 Mdot
.44625 .54875 Mdot
.8425 .575 Mdot
.42875 .62875 Mdot
.55 .6575 Mdot
.6225 .66125 Mdot
.91 .53875 Mdot
.31625 .48375 Mdot
.515 .43625 Mdot
.92625 .4375 Mdot
.81 .4525 Mdot
.14625 .485 Mdot
.24875 .54875 Mdot
.78875 .58375 Mdot
.4425 .59875 Mdot
.57125 .635 Mdot
.495 .6225 Mdot
.67875 .57125 Mdot
.915 .4975 Mdot
.995 .45625 Mdot
.68625 .445 Mdot
.71125 .4375 Mdot
.18875 .43125 Mdot
.705 .36125 Mdot
.1825 .3475 Mdot
.39375 .32625 Mdot
.6425 .36375 Mdot
.21125 .59 Mdot
.67 .6325 Mdot
.47625 .67 Mdot
.725 .67375 Mdot
.48 .65125 Mdot
.565 .55 Mdot
.6375 .53875 Mdot
.4825 .525 Mdot
.77 .52 Mdot
.58875 .505 Mdot
.765 .48 Mdot
.745 .455 Mdot
.52625 .43375 Mdot
.67375 .41375 Mdot
.56 .45375 Mdot
.0625 .48 Mdot
.73 .5125 Mdot
.50875 .5775 Mdot
.51375 .63125 Mdot
.46125 .595 Mdot
.58625 .5675 Mdot
.14 .5125 Mdot
.83125 .47375 Mdot
.55875 .43 Mdot
.4575 .3925 Mdot
.61375 .365 Mdot
.42375 .41125 Mdot
.2125 .44625 Mdot
.90375 .455 Mdot
.01875 .47625 Mdot
.6525 .51375 Mdot
.76 .485 Mdot
.4325 .45 Mdot
.135 .43625 Mdot
.585 .4525 Mdot
.6375 .4025 Mdot
.60375 .39 Mdot
.39375 .35125 Mdot
.765 .38375 Mdot
.09625 .425 Mdot
.73 .5175 Mdot
.82625 .59125 Mdot
.5575 .35125 Mdot
.27625 .3575 Mdot
.32875 .3475 Mdot
.49625 .30625 Mdot
.82875 .2625 Mdot
.1675 .27 Mdot
.775 .305 Mdot
.26125 .33 Mdot
.58625 .39375 Mdot
.305 .4475 Mdot
.5 .51625 Mdot
.87625 .525 Mdot
.3875 .545 Mdot
.5575 .53875 Mdot
.38875 .565 Mdot
.35125 .57125 Mdot
.46625 .6 Mdot
.60875 .64 Mdot
.515 .65 Mdot
.7275 .66625 Mdot
.29125 .6025 Mdot
.79 .49125 Mdot
.20875 .42875 Mdot
.355 .4075 Mdot
.89 .3675 Mdot
.2625 .31625 Mdot
.57 .3025 Mdot
.92375 .28 Mdot
.64375 .2675 Mdot
.76875 .29125 Mdot
.54125 .285 Mdot
.88375 .275 Mdot
.10125 .31 Mdot
.47375 .27375 Mdot
.43875 .33875 Mdot
.465 .35625 Mdot
.505 .4025 Mdot
.6125 .44375 Mdot
.36625 .49875 Mdot
.47 .4825 Mdot
.46125 .485 Mdot
.825 .4875 Mdot
.41375 .465 Mdot
.545 .45625 Mdot
.64875 .45375 Mdot
.88625 .5775 Mdot
.325 .59875 Mdot
.52125 .635 Mdot
.89625 .5875 Mdot
.82 .5625 Mdot
.16625 .52 Mdot
.265 .4575 Mdot
.68375 .43 Mdot
.5325 .43 Mdot
.56875 .3925 Mdot
.505 .42375 Mdot
.6225 .46625 Mdot
.07125 .4825 Mdot
.86875 .46625 Mdot
.975 .48 Mdot
.54375 .44875 Mdot
.82 .4375 Mdot
.1575 .465 Mdot
.72625 .50375 Mdot
.2075 .545 Mdot
.32625 .5625 Mdot
.64625 .53625 Mdot
.25125 .34875 Mdot
.635 .33 Mdot
.47125 .3125 Mdot
.74125 .33 Mdot
.50125 .3525 Mdot
.59 .4375 Mdot
.585 .49 Mdot
.435 .49875 Mdot
.80125 .49 Mdot
.68375 .48625 Mdot
.77375 .4675 Mdot
.73125 .47875 Mdot
.53125 .4725 Mdot
.6525 .49875 Mdot
.6075 .50875 Mdot
.09875 .47625 Mdot
.6425 .46375 Mdot
.5775 .48125 Mdot
.4475 .4325 Mdot
.46875 .465 Mdot
.58375 .51125 Mdot
.2075 .53375 Mdot
.81875 .545 Mdot
.48 .63125 Mdot
.5275 .62125 Mdot
.605 .6675 Mdot
.4 .66 Mdot
.2025 .62875 Mdot
.94625 .58375 Mdot
.0575 .6075 Mdot
.505 .54625 Mdot
.85125 .555 Mdot
.43125 .59 Mdot
.15375 .585 Mdot
.54125 .5325 Mdot
.71 .555 Mdot
.5375 .55125 Mdot
.40625 .52875 Mdot
.78 .5325 Mdot
.0975 .5075 Mdot
.6725 .46125 Mdot
.87125 .4225 Mdot
.51875 .5475 Mdot
.2825 .57625 Mdot
.3525 .63 Mdot
.47 .6475 Mdot
.8325 .68875 Mdot
.2175 .7225 Mdot
.71625 .71375 Mdot
.24875 .6625 Mdot
.5975 .64125 Mdot
.32625 .60125 Mdot
.50125 .49125 Mdot
.92625 .44875 Mdot
.28 .46625 Mdot
.61875 .48375 Mdot
.38125 .505 Mdot
.36 .5375 Mdot
.43625 .50625 Mdot
.64 .43625 Mdot
.49 .39875 Mdot
.78 .36875 Mdot
.1925 .43125 Mdot
.88 .49875 Mdot
.1925 .58125 Mdot
.3825 .63 Mdot
.80625 .66 Mdot
.31625 .6675 Mdot
.545 .70875 Mdot
.94375 .68625 Mdot
.6725 .69875 Mdot
.72 .7 Mdot
.5975 .7125 Mdot
.83 .7875 Mdot
.12625 .82625 Mdot
.46125 .8525 Mdot
.43875 .8225 Mdot
.5425 .77625 Mdot
.38875 .70125 Mdot
.6725 .6275 Mdot
.3525 .56625 Mdot
.48375 .49625 Mdot
.46375 .4675 Mdot
.82 .46625 Mdot
.39875 .45875 Mdot
.56375 .4575 Mdot
.6525 .50375 Mdot
.8575 .49 Mdot
.30875 .485 Mdot
.53 .44875 Mdot
.00875 .44 Mdot
.85625 .44625 Mdot
.84375 .46375 Mdot
.18125 .48 Mdot
.28875 .52375 Mdot
.6025 .53875 Mdot
.58875 .5375 Mdot
.56875 .5475 Mdot
.5325 .535 Mdot
.51625 .51625 Mdot
.1825 .5275 Mdot
.82625 .53 Mdot
.9 .52625 Mdot
.3975 .53 Mdot
.93625 .53875 Mdot
.135 .54 Mdot
.66125 .58 Mdot
.28 .56125 Mdot
.28125 .56 Mdot
.64 .58 Mdot
.2425 .49875 Mdot
.63375 .48875 Mdot
.45625 .4675 Mdot
.77 .44625 Mdot
.505 .44 Mdot
.62875 .4725 Mdot
.51625 .4775 Mdot
.4475 .4475 Mdot
.83 .46625 Mdot
.71875 .49375 Mdot
.74125 .5125 Mdot
.7275 .55 Mdot
.53125 .53125 Mdot
.66 .54375 Mdot
.62375 .5225 Mdot
.195 .565 Mdot
.50625 .5475 Mdot
.625 .58375 Mdot
.41125 .59875 Mdot
.50375 .60125 Mdot
.54625 .54875 Mdot
.24625 .535 Mdot
.84 .5125 Mdot
.365 .42125 Mdot
.655 .42875 Mdot
.57875 .3925 Mdot
.335 .38 Mdot
.26375 .3725 Mdot
.95375 .35 Mdot
.085 .25625 Mdot
.36125 .26875 Mdot
.95875 .28625 Mdot
.4225 .29 Mdot
.17125 .36125 Mdot
.51125 .45125 Mdot
.745 .49375 Mdot
.47125 .5375 Mdot
.46 .55375 Mdot
.765 .55875 Mdot
.09625 .59625 Mdot
.66 .58 Mdot
.88625 .54875 Mdot
.46 .54 Mdot
.2825 .56625 Mdot
.35375 .53375 Mdot
.46375 .5325 Mdot
.82125 .52125 Mdot
.23 .45375 Mdot
.7125 .41125 Mdot
.285 .43875 Mdot
.58125 .44 Mdot
.2575 .4425 Mdot
.6 .51375 Mdot
.88125 .54375 Mdot
.2525 .49875 Mdot
.67375 .45375 Mdot
.35125 .3975 Mdot
.355 .35 Mdot
.4525 .3825 Mdot
.65125 .395 Mdot
.46875 .42375 Mdot
.805 .41875 Mdot
.115 .38 Mdot
.97125 .34 Mdot
.1375 .31625 Mdot
.415 .29 Mdot
.7825 .31625 Mdot
.35375 .5025 Mdot
.56 .4925 Mdot
.93625 .525 Mdot
.62625 .465 Mdot
.72 .3975 Mdot
.65875 .365 Mdot
.75125 .32375 Mdot
.1875 .29125 Mdot
.4275 .27375 Mdot
.45375 .30125 Mdot
.5575 .32625 Mdot
.38 .34625 Mdot
.6475 .38 Mdot
.36125 .44625 Mdot
.5 .5075 Mdot
.4525 .53125 Mdot
.82875 .49375 Mdot
.36875 .46875 Mdot
.5875 .4425 Mdot
.645 .38625 Mdot
0 .47375 Mdot
.86375 .46 Mdot
.285 .47125 Mdot
.5325 .47 Mdot
.04125 .49875 Mdot
.8375 .5025 Mdot
.8075 .52375 Mdot
.2225 .52875 Mdot
.30375 .52625 Mdot
.535 .4975 Mdot
.64625 .51375 Mdot
.56375 .50875 Mdot
.55375 .5275 Mdot
.4275 .52125 Mdot
.32125 .5375 Mdot
.75 .53625 Mdot
.82625 .53125 Mdot
.335 .485 Mdot
.12375 .44 Mdot
.62 .5 Mdot
.38375 .51625 Mdot
.22 .52875 Mdot
.61375 .49875 Mdot
.21125 .63875 Mdot
.65875 .66875 Mdot
.4475 .7125 Mdot
.77625 .725 Mdot
.49875 .715 Mdot
.66875 .57375 Mdot
.36875 .45625 Mdot
.53625 .48125 Mdot
.8025 .4925 Mdot
.75875 .50125 Mdot
.6675 .53125 Mdot
.73125 .4925 Mdot
.5 .48625 Mdot
.72125 .48125 Mdot
.66125 .46375 Mdot
.215 .4575 Mdot
.3675 .51 Mdot
.7225 .4875 Mdot
.38125 .4525 Mdot
.54875 .4775 Mdot
.44625 .47375 Mdot
.3425 .48 Mdot
.785 .4725 Mdot
.325 .54125 Mdot
.79375 .52875 Mdot
.51 .525 Mdot
.2625 .51 Mdot
.37375 .565 Mdot
.8375 .6275 Mdot
.20375 .71625 Mdot
.2425 .76875 Mdot
.375 .71125 Mdot
.26 .63125 Mdot
.44 .56 Mdot
.7825 .52375 Mdot
.415 .46625 Mdot
.52625 .5225 Mdot
.71125 .505 Mdot
.09625 .465 Mdot
.655 .4725 Mdot
.8625 .5225 Mdot
.43375 .44875 Mdot
.29375 .41 Mdot
.37125 .4075 Mdot
.43 .40875 Mdot
.83875 .41125 Mdot
.22375 .4 Mdot
.68875 .40625 Mdot
.31625 .38875 Mdot
.5725 .37875 Mdot
.24125 .39625 Mdot
.655 .4525 Mdot
.82 .5175 Mdot
.2325 .58 Mdot
.75 .6275 Mdot
.36 .68125 Mdot
.2775 .7025 Mdot
.50875 .63625 Mdot
.63125 .65 Mdot
.445 .6525 Mdot
.85125 .66875 Mdot
.08 .66 Mdot
.1425 .66625 Mdot
.365 .66625 Mdot
.79375 .62875 Mdot
.9325 .5325 Mdot
.40875 .4575 Mdot
.52 .42125 Mdot
.9875 .38625 Mdot
.59875 .4175 Mdot
.78375 .48125 Mdot
.61375 .50625 Mdot
.7225 .505 Mdot
.275 .505 Mdot
.38875 .50875 Mdot
.435 .4725 Mdot
.53375 .47625 Mdot
.385 .4875 Mdot
.6875 .49 Mdot
.34 .45625 Mdot
.51875 .43875 Mdot
.43625 .4425 Mdot
.82 .5075 Mdot
.39625 .565 Mdot
.585 .61 Mdot
.6075 .615 Mdot
.04 .45125 Mdot
.8525 .44375 Mdot
.29 .465 Mdot
.51125 .485 Mdot
.08375 .46625 Mdot
.7825 .4525 Mdot
.84375 .42875 Mdot
.225 .4525 Mdot
.3175 .45125 Mdot
.49625 .49375 Mdot
.6675 .5175 Mdot
.565 .5275 Mdot
.57125 .49 Mdot
.355 .5225 Mdot
.42625 .4775 Mdot
.695 .45875 Mdot
.77 .46625 Mdot
.31125 .50625 Mdot
.1425 .5725 Mdot
.53875 .4275 Mdot
.52375 .41 Mdot
.16875 .365 Mdot
.54625 .38875 Mdot
.2225 .35375 Mdot
.6775 .315 Mdot
.43625 .2475 Mdot
.7925 .2475 Mdot
.4875 .29375 Mdot
.71875 .46 Mdot
.05 .5125 Mdot
.22875 .54875 Mdot
.69875 .54625 Mdot
.6875 .55375 Mdot
.81625 .57125 Mdot
.545 .5175 Mdot
.73125 .535 Mdot
.51125 .55125 Mdot
.6925 .56375 Mdot
.7375 .5825 Mdot
.22625 .57 Mdot
.27125 .52125 Mdot
.825 .47875 Mdot
.32 .5 Mdot
.5975 .455 Mdot
.3725 .49875 Mdot
.37375 .50625 Mdot
.79 .5225 Mdot
.26625 .47 Mdot
.87125 .48625 Mdot
.49625 .505 Mdot
.2625 .52625 Mdot
.36625 .47375 Mdot
.785 .45625 Mdot
.37875 .4475 Mdot
.04375 .40375 Mdot
.405 .48 Mdot
.2775 .51375 Mdot
.37 .505 Mdot
.85125 .51625 Mdot
.3575 .52375 Mdot
.595 .46125 Mdot
.6625 .44 Mdot
.1 .4525 Mdot
.58625 .4575 Mdot
.9175 .4475 Mdot
.41625 .51375 Mdot
.315 .52375 Mdot
.33125 .52875 Mdot
.4025 .505 Mdot
.865 .46875 Mdot
.2625 .53 Mdot
.66 .5875 Mdot
.27875 .6 Mdot
.605 .64625 Mdot
.26625 .62625 Mdot
.65 .51875 Mdot
.79625 .4225 Mdot
.2375 .38625 Mdot
.74125 .33375 Mdot
.34375 .33375 Mdot
.285 .35 Mdot
.58625 .40875 Mdot
.56375 .42375 Mdot
.46 .455 Mdot
.84375 .47125 Mdot
.08625 .49375 Mdot
.15875 .49375 Mdot
.3575 .49125 Mdot
.76 .495 Mdot
.0675 .5075 Mdot
.85 .50625 Mdot
.46375 .52625 Mdot
.4825 .5425 Mdot
.64125 .58375 Mdot
.78 .5625 Mdot
.55875 .55375 Mdot
.71375 .565 Mdot
.35875 .5675 Mdot
.38 .5775 Mdot
.4175 .6125 Mdot
.49875 .6275 Mdot
.405 .6375 Mdot
.70625 .63125 Mdot
.34 .63625 Mdot
.52125 .65 Mdot
.425 .63 Mdot
.825 .575 Mdot
.3725 .525 Mdot
.6 .5 Mdot
.60125 .50375 Mdot
.11375 .555 Mdot
.8025 .56 Mdot
.34 .52625 Mdot
.475 .56875 Mdot
.12125 .5825 Mdot
.735 .62875 Mdot
.8975 .61875 Mdot
.195 .58875 Mdot
.32875 .55625 Mdot
.475 .5275 Mdot
.6525 .45625 Mdot
.605 .4675 Mdot
.5925 .49125 Mdot
.2725 .465 Mdot
.525 .49625 Mdot
.63875 .53 Mdot
.7275 .55375 Mdot
.0075 .55875 Mdot
.2625 .585 Mdot
.16375 .515 Mdot
.4825 .5275 Mdot
.53 .56125 Mdot
.21375 .61875 Mdot
.485 .61875 Mdot
.30125 .5725 Mdot
.63125 .6325 Mdot
.47125 .695 Mdot
.7775 .69125 Mdot
.4775 .62375 Mdot
.75 .4125 Mdot
.195 .405 Mdot
.07 .40875 Mdot
.8425 .45125 Mdot
.58 .45125 Mdot
.92375 .4525 Mdot
.4375 .465 Mdot
.775 .44875 Mdot
.4925 .485 Mdot
.67375 .435 Mdot
.80375 .40625 Mdot
.2 .4225 Mdot
.245 .455 Mdot
.84625 .46 Mdot
.37875 .5025 Mdot
.50875 .54375 Mdot
.3975 .50125 Mdot
.4 .47375 Mdot
.7575 .47625 Mdot
.26625 .49 Mdot
.86 .47375 Mdot
.535 .51875 Mdot
.24375 .48875 Mdot
.3975 .4475 Mdot
.7125 .42625 Mdot
.485 .39625 Mdot
.3325 .3625 Mdot
.35875 .365 Mdot
.2725 .43375 Mdot
.93125 .475 Mdot
.3125 .51125 Mdot
.65625 .5375 Mdot
.61625 .57375 Mdot
.15 .53875 Mdot
.51125 .52625 Mdot
.9525 .5 Mdot
.4125 .5225 Mdot
.325 .54375 Mdot
.31125 .54375 Mdot
.4 .58375 Mdot
.9025 .6 Mdot
.2475 .55375 Mdot
.645 .50375 Mdot
.28 .51125 Mdot
.60875 .465 Mdot
.28375 .47 Mdot
.65375 .5325 Mdot
.74375 .57 Mdot
.29375 .5725 Mdot
.73125 .585 Mdot
.35625 .58125 Mdot
.1725 .57 Mdot
.7125 .56 Mdot
.5425 .5275 Mdot
.415 .51125 Mdot
.91125 .4975 Mdot
.01375 .51 Mdot
.13375 .49 Mdot
.3625 .47 Mdot
.745 .46625 Mdot
.0975 .43375 Mdot
.8025 .43375 Mdot
.48875 .4325 Mdot
.465 .4175 Mdot
.6525 .42625 Mdot
.80625 .42875 Mdot
.49 .46375 Mdot
.70625 .48 Mdot
.4375 .4625 Mdot
.34 .43 Mdot
.4425 .38625 Mdot
.435 .3425 Mdot
.455 .30625 Mdot
.73 .2925 Mdot
.305 .305 Mdot
.5425 .32125 Mdot
.375 .35375 Mdot
.86875 .405 Mdot
.41125 .43125 Mdot
.53875 .465 Mdot
.6025 .49 Mdot
.19625 .49625 Mdot
.7775 .49125 Mdot
.39125 .50125 Mdot
.4325 .44125 Mdot
.1575 .4425 Mdot
.67625 .4 Mdot
.9375 .40125 Mdot
.2 .4175 Mdot
.35125 .46625 Mdot
.42875 .48125 Mdot
.65125 .5225 Mdot
.67 .51625 Mdot
.5375 .4925 Mdot
.22 .48625 Mdot
.6225 .465 Mdot
.595 .4325 Mdot
.7 .4075 Mdot
.05875 .40375 Mdot
.23375 .40875 Mdot
.23 .485 Mdot
.40375 .5125 Mdot
.58125 .48875 Mdot
.23875 .45125 Mdot
.4525 .48125 Mdot
.3025 .52 Mdot
.60625 .46625 Mdot
.5 .475 Mdot
.78625 .50375 Mdot
.46875 .56375 Mdot
.7925 .685 Mdot
.91375 .66625 Mdot
.26625 .645 Mdot
.9625 .49 Mdot
.45125 .47375 Mdot
.98125 .46125 Mdot
.31 .5 Mdot
.8125 .52625 Mdot
.5 .46375 Mdot
.665 .4375 Mdot
.78375 .455 Mdot
.20375 .37125 Mdot
.2825 .355 Mdot
.74375 .3925 Mdot
.50125 .40875 Mdot
.45375 .38375 Mdot
.47 .43125 Mdot
.3125 .4575 Mdot
.80625 .40875 Mdot
.215 .38 Mdot
.87875 .4025 Mdot
.53 .32625 Mdot
.3075 .3225 Mdot
.36375 .45875 Mdot
.6625 .5425 Mdot
.53875 .57375 Mdot
.27 .63375 Mdot
.4775 .58 Mdot
.165 .5125 Mdot
.975 .4275 Mdot
.27625 .41 Mdot
.725 .4275 Mdot
.55 .425 Mdot
.1575 .47625 Mdot
.51625 .49875 Mdot
.96125 .53 Mdot
.455 .53375 Mdot
.3825 .49375 Mdot
.2375 .5 Mdot
.40875 .4725 Mdot
.91375 .4875 Mdot
.235 .52375 Mdot
.655 .54625 Mdot
.3 .56375 Mdot
.55875 .56875 Mdot
.29375 .55125 Mdot
.70875 .54125 Mdot
.65 .53625 Mdot
.36125 .47625 Mdot
.73125 .475 Mdot
.3575 .46375 Mdot
.11125 .41625 Mdot
.79125 .405 Mdot
.515 .44375 Mdot
.41375 .445 Mdot
.91625 .4175 Mdot
.1075 .47125 Mdot
.37375 .50375 Mdot
.75125 .525 Mdot
.0925 .56 Mdot
.775 .5475 Mdot
.5275 .52875 Mdot
.42 .53625 Mdot
.62375 .4525 Mdot
.8675 .43375 Mdot
.39125 .3825 Mdot
.74875 .33375 Mdot
.4875 .355 Mdot
.295 .40125 Mdot
.4775 .46 Mdot
.33125 .515 Mdot
.55375 .57 Mdot
.7075 .60125 Mdot
.29875 .6025 Mdot
.56875 .5825 Mdot
.34375 .56875 Mdot
.90875 .54 Mdot
.37875 .5425 Mdot
.52625 .52 Mdot
.58875 .50375 Mdot
.21125 .49875 Mdot
.77625 .5075 Mdot
.49 .50625 Mdot
.31625 .50625 Mdot
.26625 .5325 Mdot
.60875 .5625 Mdot
.925 .5825 Mdot
.22125 .58375 Mdot
.34 .55125 Mdot
.4575 .51625 Mdot
.64625 .4925 Mdot
.6775 .4825 Mdot
.51125 .49125 Mdot
.20125 .5125 Mdot
.6875 .54625 Mdot
.52625 .5825 Mdot
.7275 .58625 Mdot
.0875 .57125 Mdot
.215 .56625 Mdot
.9825 .54125 Mdot
.39 .49125 Mdot
.03875 .5275 Mdot
.335 .52125 Mdot
.6025 .535 Mdot
.26875 .535 Mdot
.41875 .47375 Mdot
.36875 .4775 Mdot
.57125 .47875 Mdot
.525 .44875 Mdot
.78 .40625 Mdot
.44125 .39625 Mdot
.8325 .3925 Mdot
.82375 .4275 Mdot
.31625 .4325 Mdot
.045 .45 Mdot
.9 .52875 Mdot
.45375 .52375 Mdot
.26 .49625 Mdot
.80125 .4925 Mdot
.53 .5225 Mdot
.645 .58125 Mdot
.75625 .58375 Mdot
.1825 .61375 Mdot
.3975 .59875 Mdot
.60625 .56 Mdot
.62125 .52375 Mdot
.38125 .53125 Mdot
.52 .52875 Mdot
.295 .53625 Mdot
.77625 .62 Mdot
.235 .645 Mdot
.85375 .6275 Mdot
.57625 .67875 Mdot
.3 .705 Mdot
.36375 .59 Mdot
.58375 .53375 Mdot
.6325 .54875 Mdot
.18625 .49875 Mdot
.5775 .515 Mdot
.07125 .47 Mdot
.31 .41875 Mdot
.6975 .36625 Mdot
.525 .40375 Mdot
.18375 .4625 Mdot
.525 .48625 Mdot
.9525 .4925 Mdot
.48375 .37875 Mdot
.40125 .38375 Mdot
.25875 .38875 Mdot
.4125 .40375 Mdot
.86875 .4275 Mdot
.23125 .44375 Mdot
.6625 .445 Mdot
.30125 .425 Mdot
.53625 .455 Mdot
.37125 .4775 Mdot
.64375 .47875 Mdot
.66625 .5025 Mdot
.34625 .6175 Mdot
.74125 .625 Mdot
.38875 .6075 Mdot
.05375 .6525 Mdot
.85 .64875 Mdot
.4825 .57125 Mdot
.4175 .54125 Mdot
.895 .58125 Mdot
.02625 .545 Mdot
.0975 .5 Mdot
.37125 .4825 Mdot
.765 .47375 Mdot
.06625 .48625 Mdot
.76375 .5075 Mdot
.58 .54 Mdot
.37625 .5725 Mdot
.68 .65875 Mdot
.8675 .67125 Mdot
.285 .69125 Mdot
.8125 .715 Mdot
.53375 .70375 Mdot
.25 .65 Mdot
.5025 .6175 Mdot
.2575 .58625 Mdot
.6475 .55875 Mdot
.64125 .5475 Mdot
.33875 .545 Mdot
.57375 .52375 Mdot
.3075 .53875 Mdot
.945 .52875 Mdot
.35625 .50875 Mdot
.5675 .54125 Mdot
.47625 .5575 Mdot
.10375 .5325 Mdot
.8925 .55125 Mdot
.29375 .565 Mdot
.69 .5325 Mdot
.66875 .5325 Mdot
.15875 .53375 Mdot
.39 .48375 Mdot
.48125 .43875 Mdot
.1825 .42625 Mdot
.35625 .45625 Mdot
.4525 .535 Mdot
.63 .58625 Mdot
.69375 .57 Mdot
.50875 .57875 Mdot
.205 .5275 Mdot
.7225 .47875 Mdot
.45 .455 Mdot
.765 .475 Mdot
.11625 .475 Mdot
.18875 .5225 Mdot
.9175 .4975 Mdot
.57375 .46375 Mdot
.81875 .39875 Mdot
.185 .38375 Mdot
.3075 .335 Mdot
.545 .3625 Mdot
.3225 .38875 Mdot
.40125 .41375 Mdot
.95875 .435 Mdot
.4125 .4375 Mdot
.52125 .45875 Mdot
.5625 .4375 Mdot
.78875 .45 Mdot
.43375 .44875 Mdot
.8275 .46875 Mdot
.75 .4975 Mdot
.3075 .53125 Mdot
.19125 .56625 Mdot
.77 .48375 Mdot
.43875 .515 Mdot
.175 .49625 Mdot
.8075 .5675 Mdot
.59125 .56625 Mdot
.58625 .56375 Mdot
.6525 .59 Mdot
.28125 .57 Mdot
.48 .495 Mdot
.45875 .47875 Mdot
.725 .465 Mdot
.3175 .42375 Mdot
.61625 .4275 Mdot
.18875 .46125 Mdot
.845 .44875 Mdot
.23625 .435 Mdot
.71375 .4725 Mdot
.705 .42875 Mdot
.35375 .43625 Mdot
.275 .47375 Mdot
.5875 .48375 Mdot
.67625 .41625 Mdot
.10875 .4125 Mdot
.66875 .46625 Mdot
.3725 .72875 Mdot
.67 .7375 Mdot
.495 .65875 Mdot
.25 .54125 Mdot
.45 .46 Mdot
.9925 .4375 Mdot
.5275 .59 Mdot
.39875 .665 Mdot
.22625 .6925 Mdot
.43625 .71375 Mdot
.865 .67875 Mdot
.195 .62625 Mdot
.7225 .57625 Mdot
.26125 .525 Mdot
.54375 .49 Mdot
.36625 .4675 Mdot
.63375 .44875 Mdot
.7075 .44 Mdot
.3325 .39 Mdot
.715 .415 Mdot
.385 .4525 Mdot
.09 .45125 Mdot
.865 .44875 Mdot
.4275 .515 Mdot
.45375 .51875 Mdot
.89375 .49625 Mdot
.01125 .50125 Mdot
.06125 .5025 Mdot
.4525 .5 Mdot
.72 .48875 Mdot
.04 .48875 Mdot
.77625 .50125 Mdot
.58125 .48625 Mdot
.38625 .49375 Mdot
.66125 .47625 Mdot
.865 .5175 Mdot
.24875 .525 Mdot
.8425 .54625 Mdot
.57375 .57125 Mdot
.22 .6075 Mdot
.5125 .58125 Mdot
.22375 .545 Mdot
.73 .50375 Mdot
.5525 .46 Mdot
.3725 .455 Mdot
.60125 .48 Mdot
.2825 .4575 Mdot
.94375 .48875 Mdot
.33125 .49625 Mdot
.59875 .465 Mdot
.41625 .43625 Mdot
.23 .45 Mdot
.76 .43 Mdot
.385 .46125 Mdot
.55375 .46375 Mdot
.88375 .47 Mdot
.5325 .565 Mdot
.38875 .5575 Mdot
.16625 .5175 Mdot
.3525 .47625 Mdot
.45125 .415 Mdot
.64 .395 Mdot
.6925 .47 Mdot
.51 .475 Mdot
.2025 .5075 Mdot
.78375 .5425 Mdot
.3175 .5675 Mdot
.83625 .56875 Mdot
.17875 .54375 Mdot
.1125 .4875 Mdot
.8575 .535 Mdot
.75625 .5825 Mdot
.61 .59625 Mdot
.3075 .63625 Mdot
.30875 .6725 Mdot
.4475 .62375 Mdot
.43375 .58875 Mdot
.38125 .57375 Mdot
.90375 .5475 Mdot
.44625 .54875 Mdot
.47375 .55875 Mdot
.59375 .595 Mdot
.815 .6025 Mdot
.385 .5775 Mdot
.85375 .47125 Mdot
.675 .4475 Mdot
.295 .34375 Mdot
.385 .34375 Mdot
.52125 .40875 Mdot
.615 .405 Mdot
.91625 .3925 Mdot
.03625 .4575 Mdot
.12375 .415 Mdot
.83625 .34125 Mdot
.60125 .375 Mdot
.6225 .36125 Mdot
.51625 .36625 Mdot
.35875 .445 Mdot
.55625 .5475 Mdot
.33625 .58625 Mdot
.78125 .60375 Mdot
.27375 .64 Mdot
.74 .60125 Mdot
.0625 .55125 Mdot
.8825 .5125 Mdot
.3075 .5725 Mdot
.5925 .53125 Mdot
.745 .58125 Mdot
.38875 .54875 Mdot
.29625 .52375 Mdot
.5375 .47875 Mdot
.615 .55125 Mdot
.0875 .5675 Mdot
.01 .61625 Mdot
.73875 .565 Mdot
.97625 .4075 Mdot
.46375 .385 Mdot
.62375 .4025 Mdot
.44625 .465 Mdot
.31 .5125 Mdot
.47625 .56125 Mdot
.985 .575 Mdot
.5375 .435 Mdot
.40125 .38625 Mdot
.24875 .34875 Mdot
.42375 .305 Mdot
.8325 .33 Mdot
.2 .3475 Mdot
.685 .35375 Mdot
.33375 .4125 Mdot
.50875 .425 Mdot
.3875 .47 Mdot
.62875 .47 Mdot
.6925 .4425 Mdot
.3425 .4025 Mdot
.7325 .3975 Mdot
.38625 .3725 Mdot
.0425 .38625 Mdot
.9075 .42625 Mdot
.4175 .40125 Mdot
.4425 .41875 Mdot
.91875 .41625 Mdot
.0075 .43125 Mdot
.03625 .45625 Mdot
.54375 .45 Mdot
.68375 .44375 Mdot
.01875 .4225 Mdot
.78 .4125 Mdot
.5775 .415 Mdot
.4025 .36625 Mdot
.66875 .405 Mdot
.83625 .36125 Mdot
.22875 .3775 Mdot
.88375 .34125 Mdot
.56375 .3 Mdot
.22 .3175 Mdot
.495 .38625 Mdot
.19375 .43875 Mdot
.83 .5025 Mdot
.455 .56 Mdot
.41375 .545 Mdot
.62875 .50875 Mdot
.25625 .4875 Mdot
.90125 .4675 Mdot
.3575 .43125 Mdot
.6375 .42625 Mdot
.3325 .42625 Mdot
.37625 .44875 Mdot
.56875 .4225 Mdot
.55 .42125 Mdot
.39875 .4625 Mdot
.67125 .49625 Mdot
.34375 .56375 Mdot
.9975 .60125 Mdot
.2 .59375 Mdot
.31375 .6025 Mdot
.5025 .55 Mdot
.64625 .46125 Mdot
.6825 .38875 Mdot
.47875 .37375 Mdot
.22375 .37875 Mdot
.8375 .4 Mdot
.185 .41 Mdot
.92125 .39 Mdot
.215 .425 Mdot
.09875 .4675 Mdot
.75875 .4675 Mdot
.92875 .46 Mdot
.43 .5125 Mdot
.3925 .4975 Mdot
.29625 .49375 Mdot
.44 .5175 Mdot
.45125 .565 Mdot
.4075 .56 Mdot
.87875 .5275 Mdot
.475 .51125 Mdot
.4525 .48125 Mdot
.60375 .44625 Mdot
.83375 .4575 Mdot
.34 .48 Mdot
.82125 .565 Mdot
.66 .6175 Mdot
.22125 .72 Mdot
.62125 .7175 Mdot
.2675 .69125 Mdot
.78125 .69375 Mdot
.73625 .68125 Mdot
.17375 .61 Mdot
.10625 .62875 Mdot
.8175 .6575 Mdot
.62625 .605 Mdot
.62875 .59 Mdot
.44125 .54375 Mdot
.41375 .50625 Mdot
.62375 .4625 Mdot
.255 .46375 Mdot
.7175 .49875 Mdot
.35875 .48 Mdot
.7975 .4775 Mdot
.9125 .50625 Mdot
.40125 .39875 Mdot
.44375 .44125 Mdot
.82 .425 Mdot
.39625 .415 Mdot
.27375 .45625 Mdot
.5475 .54125 Mdot
.58375 .50375 Mdot
.19875 .48875 Mdot
.03 .44 Mdot
.74625 .43 Mdot
.96125 .505 Mdot
.5475 .53125 Mdot
.505 .56625 Mdot
.4375 .55375 Mdot
.3925 .52 Mdot
.44625 .52125 Mdot
.99125 .5075 Mdot
.53 .6975 Mdot
.4225 .6275 Mdot
.255 .61125 Mdot
.38875 .585 Mdot
.76125 .5225 Mdot
.30625 .51125 Mdot
.59875 .5875 Mdot
.4325 .565 Mdot
.46875 .54875 Mdot
.40125 .50375 Mdot
.58125 .5425 Mdot
.74 .53375 Mdot
.34 .5525 Mdot
.69875 .55875 Mdot
.37 .5875 Mdot
.14 .54625 Mdot
.8975 .5175 Mdot
.34 .58875 Mdot
.46 .60875 Mdot
.91375 .6225 Mdot
.05625 .62875 Mdot
.04375 .5925 Mdot
.57875 .57125 Mdot
.64125 .58375 Mdot
.045 .5625 Mdot
.75 .52375 Mdot
.58375 .5175 Mdot
.405 .56125 Mdot
.6625 .52 Mdot
.775 .515 Mdot
.2325 .46125 Mdot
.92375 .4825 Mdot
.56125 .5 Mdot
.235 .465 Mdot
.44125 .43 Mdot
.215 .43 Mdot
.8525 .405 Mdot
.42125 .41875 Mdot
.4325 .48125 Mdot
.64875 .5425 Mdot
.2775 .58125 Mdot
.80625 .58875 Mdot
.3725 .62875 Mdot
.73375 .59 Mdot
.19125 .5825 Mdot
.52375 .5675 Mdot
.45625 .59625 Mdot
.63875 .555 Mdot
.2825 .53625 Mdot
.75 .405 Mdot
.36 .36125 Mdot
.88625 .35 Mdot
.27375 .37625 Mdot
.23625 .4 Mdot
.59625 .47375 Mdot
.6175 .555 Mdot
.65375 .58875 Mdot
.47 .62375 Mdot
.28875 .60875 Mdot
.815 .56125 Mdot
.13 .53875 Mdot
.97625 .54625 Mdot
.23625 .53 Mdot
.07875 .50125 Mdot
.70375 .505 Mdot
.39125 .42 Mdot
.38375 .35875 Mdot
.28 .3625 Mdot
.4725 .3475 Mdot
.42625 .32 Mdot
.4525 .3825 Mdot
.8975 .505 Mdot
.49625 .55375 Mdot
.455 .5925 Mdot
.60875 .64625 Mdot
.8525 .63125 Mdot
.2625 .6175 Mdot
.08125 .59625 Mdot
.74125 .5575 Mdot
.69875 .495 Mdot
.19 .4425 Mdot
.76 .4925 Mdot
.035 .51875 Mdot
.56 .50625 Mdot
.22 .53125 Mdot
.145 .46375 Mdot
.79125 .39875 Mdot
.605 .41375 Mdot
.67875 .42375 Mdot
.40875 .4575 Mdot
.39875 .4875 Mdot
.73875 .5175 Mdot
.18125 .50125 Mdot
.655 .48625 Mdot
.435 .495 Mdot
.74375 .47625 Mdot
.00375 .45625 Mdot
.82125 .50375 Mdot
.5575 .56125 Mdot
.33 .51125 Mdot
.81 .5325 Mdot
.41875 .57125 Mdot
.31875 .50625 Mdot
.47375 .47375 Mdot
.5875 .5175 Mdot
.33875 .54 Mdot
.91125 .49 Mdot
.09 .54125 Mdot
.6975 .545 Mdot
.00125 .52125 Mdot
.94125 .475 Mdot
.6075 .49 Mdot
.40875 .4025 Mdot
.51875 .40125 Mdot
.405 .46375 Mdot
.42375 .47375 Mdot
.9875 .51125 Mdot
.53625 .23625 Mdot
.9825 .30875 Mdot
.40875 .38375 Mdot
.305 .41375 Mdot
.3775 .4925 Mdot
.68875 .52 Mdot
.42125 .52 Mdot
.46875 .44125 Mdot
.55625 .47125 Mdot
.4425 .47875 Mdot
.40875 .5225 Mdot
.51375 .50125 Mdot
.7825 .565 Mdot
.38875 .585 Mdot
.58875 .5475 Mdot
.3825 .53625 Mdot
.20125 .57 Mdot
.93 .56125 Mdot
.2825 .49 Mdot
.5 .505 Mdot
.89375 .4925 Mdot
.03375 .475 Mdot
.09875 .49875 Mdot
.5875 .51875 Mdot
.56 .53125 Mdot
.105 .57 Mdot
.72 .6 Mdot
.5875 .5825 Mdot
.425 .53375 Mdot
.72875 .5225 Mdot
.66125 .5875 Mdot
.275 .645 Mdot
.92 .64375 Mdot
.5875 .6625 Mdot
.26375 .67375 Mdot
.33875 .64875 Mdot
.2625 .62875 Mdot
.89125 .61625 Mdot
.4025 .5775 Mdot
.43125 .53 Mdot
.675 .45 Mdot
.255 .405 Mdot
.7175 .3775 Mdot
.42625 .36 Mdot
.81625 .39 Mdot
.05 .39375 Mdot
.70375 .4 Mdot
.325 .39375 Mdot
.71875 .4025 Mdot
.1325 .40625 Mdot
.7775 .5325 Mdot
.40875 .55125 Mdot
.7875 .5225 Mdot
.37125 .50875 Mdot
.1675 .4525 Mdot
.605 .43375 Mdot
.64 .4025 Mdot
.63 .40625 Mdot
.45625 .3675 Mdot
.345 .36625 Mdot
.775 .37375 Mdot
.1175 .35625 Mdot
.995 .36125 Mdot
.25625 .3925 Mdot
.08375 .41375 Mdot
.71125 .43 Mdot
.95375 .4825 Mdot
.41125 .53125 Mdot
.375 .61625 Mdot
.31125 .63625 Mdot
.47875 .6475 Mdot
.4 .6525 Mdot
.5025 .6 Mdot
.8625 .43875 Mdot
.555 .38875 Mdot
.435 .3575 Mdot
.63625 .32875 Mdot
.84875 .35625 Mdot
.185 .37125 Mdot
.1975 .41875 Mdot
.65125 .47875 Mdot
.73125 .5175 Mdot
.16375 .54875 Mdot
.86625 .50375 Mdot
.4625 .42 Mdot
.3125 .39375 Mdot
.14 .4525 Mdot
.74875 .4775 Mdot
.6175 .50125 Mdot
.6875 .5175 Mdot
.385 .50875 Mdot
.4125 .50875 Mdot
.7875 .4975 Mdot
.2025 .51125 Mdot
.54625 .48375 Mdot
.5175 .495 Mdot
.69875 .49875 Mdot
.0325 .54 Mdot
.77 .53 Mdot
.64625 .55125 Mdot
.2825 .575 Mdot
.74125 .535 Mdot
.52125 .49875 Mdot
.28375 .53125 Mdot
.46375 .5225 Mdot
.56 .45625 Mdot
.4625 .4675 Mdot
.77125 .51875 Mdot
.17 .46875 Mdot
.60625 .465 Mdot
.125 .49625 Mdot
.85875 .4725 Mdot
.64875 .405 Mdot
.32125 .44875 Mdot
.60625 .4225 Mdot
.38875 .355 Mdot
.4425 .3575 Mdot
.945 .34 Mdot
.55125 .6775 Mdot
.955 .61 Mdot
.425 .535 Mdot
.305 .455 Mdot
.38 .39125 Mdot
.58625 .3775 Mdot
.575 .3825 Mdot
.36 .4225 Mdot
.6425 .4675 Mdot
.42875 .48125 Mdot
.385 .47625 Mdot
.5075 .48875 Mdot
.785 .43 Mdot
.48 .38 Mdot
.465 .41625 Mdot
.36625 .4225 Mdot
.22625 .41 Mdot
.22625 .45 Mdot
.48125 .3775 Mdot
.8975 .3575 Mdot
.00625 .3775 Mdot
.12125 .4075 Mdot
.60375 .45125 Mdot
.50125 .46125 Mdot
.14875 .44375 Mdot
.71125 .4325 Mdot
.5675 .4575 Mdot
.41875 .48875 Mdot
.735 .4825 Mdot
.60125 .425 Mdot
.32125 .38125 Mdot
.925 .3725 Mdot
.5575 .3575 Mdot
.32625 .36875 Mdot
.22125 .3875 Mdot
.2825 .40875 Mdot
.92375 .42 Mdot
.49875 .435 Mdot
.34875 .4475 Mdot
.70875 .51375 Mdot
.26375 .55375 Mdot
.60625 .58625 Mdot
.50875 .6 Mdot
.83875 .59 Mdot
.795 .62625 Mdot
.2475 .6525 Mdot
.76125 .63 Mdot
.03875 .63875 Mdot
.7925 .47625 Mdot
.51375 .49625 Mdot
.5925 .53875 Mdot
.53875 .57 Mdot
.075 .6225 Mdot
.6525 .65875 Mdot
.64375 .6675 Mdot
.62375 .6325 Mdot
.40125 .5875 Mdot
.43 .55625 Mdot
.7025 .5675 Mdot
.1175 .6 Mdot
.285 .60625 Mdot
.06 .58 Mdot
.75375 .54125 Mdot
.82875 .48625 Mdot
.5025 .47125 Mdot
.35375 .445 Mdot
.32625 .4525 Mdot
.4675 .46375 Mdot
.39125 .48125 Mdot
.575 .47125 Mdot
.8175 .47625 Mdot
.635 .475 Mdot
.39 .525 Mdot
.68375 .515 Mdot
.8625 .50875 Mdot
.08625 .4725 Mdot
.275 .4325 Mdot
.57625 .4025 Mdot
.78375 .36875 Mdot
.16875 .335 Mdot
.89 .3625 Mdot
.3875 .48 Mdot
.3375 .54 Mdot
.16625 .54 Mdot
.68625 .5475 Mdot
.65125 .53875 Mdot
.67625 .515 Mdot
.39875 .5225 Mdot
.39375 .51375 Mdot
.86125 .5275 Mdot
.12125 .55875 Mdot
.5425 .55375 Mdot
.59625 .57125 Mdot
.59375 .60375 Mdot
.1475 .555 Mdot
.66 .54875 Mdot
.6925 .555 Mdot
.33625 .52375 Mdot
.6875 .5475 Mdot
.51875 .575 Mdot
.3 .5275 Mdot
.45 .5275 Mdot
.54625 .5225 Mdot
.53375 .47625 Mdot
.6275 .4575 Mdot
.33375 .4675 Mdot
.45875 .49 Mdot
.28625 .46 Mdot
.765 .48 Mdot
.655 .54125 Mdot
.255 .55875 Mdot
.68375 .58875 Mdot
.38625 .6725 Mdot
.48125 .715 Mdot
.89125 .705 Mdot
.51125 .42375 Mdot
.96625 .45625 Mdot
.4225 .50625 Mdot
.32125 .56625 Mdot
.36 .6175 Mdot
.53125 .66875 Mdot
.67125 .6975 Mdot
.25125 .69625 Mdot
.77125 .625 Mdot
.36625 .61625 Mdot
.41625 .59375 Mdot
.45125 .61375 Mdot
.78625 .63875 Mdot
.56 .6625 Mdot
.41375 .5975 Mdot
.34375 .54375 Mdot
.21 .47375 Mdot
.2175 .4925 Mdot
.44875 .54625 Mdot
.86875 .59125 Mdot
.04 .60875 Mdot
.155 .53125 Mdot
.6025 .5 Mdot
.46375 .4925 Mdot
.1875 .50125 Mdot
.65625 .52875 Mdot
.5925 .5425 Mdot
.3875 .53875 Mdot
.75875 .52375 Mdot
.545 .53125 Mdot
.33125 .565 Mdot
.97125 .585 Mdot
.49625 .58875 Mdot
.37875 .54375 Mdot
.13625 .5125 Mdot
.3525 .4775 Mdot
.8625 .4475 Mdot
.595 .45125 Mdot
.3025 .46375 Mdot
.7175 .44125 Mdot
.30625 .405 Mdot
.45125 .3825 Mdot
.6375 .34 Mdot
.85 .385 Mdot
.87625 .45 Mdot
.18375 .45 Mdot
.79125 .53 Mdot
.7875 .49875 Mdot
.59375 .44 Mdot
.4075 .43 Mdot
.7175 .41625 Mdot
.685 .42 Mdot
.6175 .4625 Mdot
.6375 .5025 Mdot
.36875 .56125 Mdot
.5125 .615 Mdot
.6125 .60875 Mdot
.16375 .57125 Mdot
.265 .57 Mdot
.0925 .53625 Mdot
.79 .53 Mdot
.695 .5275 Mdot
.57125 .515 Mdot
.36625 .4675 Mdot
.38125 .45375 Mdot
.41625 .46125 Mdot
.35625 .46 Mdot
.63875 .5025 Mdot
.8025 .5825 Mdot
.7225 .62 Mdot
.32625 .5725 Mdot
.725 .5875 Mdot
.875 .56875 Mdot
.38375 .585 Mdot
.44875 .55375 Mdot
.87875 .55875 Mdot
.1475 .5775 Mdot
.91625 .525 Mdot
.44125 .53625 Mdot
.34125 .48625 Mdot
.18875 .5125 Mdot
.6 .53125 Mdot
.69875 .51 Mdot
.6575 .4925 Mdot
.4175 .44 Mdot
.39 .415 Mdot
.895 .405 Mdot
.07625 .37125 Mdot
.52875 .3775 Mdot
.65125 .39375 Mdot
.49 .4 Mdot
.325 .3775 Mdot
.5525 .365 Mdot
.67125 .35625 Mdot
.36875 .4 Mdot
.6675 .38 Mdot
.575 .4 Mdot
.21125 .4525 Mdot
.54125 .43875 Mdot
.515 .47625 Mdot
.5125 .51875 Mdot
.57 .5025 Mdot
.4825 .5425 Mdot
.32125 .5675 Mdot
.38625 .5925 Mdot
.70625 .61375 Mdot
.64625 .6275 Mdot
.20875 .5725 Mdot
.8175 .545 Mdot
.325 .45125 Mdot
.475 .3775 Mdot
.8575 .4025 Mdot
.065 .5175 Mdot
.45875 .49875 Mdot
.37625 .4725 Mdot
.3375 .47125 Mdot
.3875 .42625 Mdot
.49875 .4125 Mdot
.6625 .385 Mdot
.26375 .34875 Mdot
.8175 .37125 Mdot
.34 .405 Mdot
.3975 .42875 Mdot
.445 .41875 Mdot
.785 .45625 Mdot
.6075 .52375 Mdot
.38625 .5875 Mdot
.28625 .65 Mdot
.265 .76 Mdot
.225 .65875 Mdot
.43625 .62625 Mdot
.825 .5775 Mdot
.03125 .48875 Mdot
.17125 .50125 Mdot
.58 .4925 Mdot
.44 .47 Mdot
.2225 .4775 Mdot
.6125 .46375 Mdot
.62625 .45375 Mdot
.37 .4575 Mdot
.76875 .5125 Mdot
.5525 .53375 Mdot
.275 .52125 Mdot
.4725 .49 Mdot
.395 .49125 Mdot
.0625 .43625 Mdot
.415 .4425 Mdot
.81 .45625 Mdot
.70125 .4275 Mdot
.24625 .41875 Mdot
.71375 .475 Mdot
.34 .5225 Mdot
.35625 .5625 Mdot
.72125 .65 Mdot
.8375 .63625 Mdot
.935 .52875 Mdot
.185 .49875 Mdot
.71375 .43125 Mdot
.00375 .465 Mdot
.78875 .585 Mdot
.6525 .62625 Mdot
.2825 .605 Mdot
.855 .59125 Mdot
.70375 .5325 Mdot
.60625 .47375 Mdot
.61625 .49875 Mdot
.35875 .51 Mdot
.61375 .51 Mdot
.45125 .525 Mdot
.265 .57375 Mdot
.24625 .515 Mdot
.06875 .5425 Mdot
.84375 .54875 Mdot
.57 .54625 Mdot
.635 .5925 Mdot
.39625 .59625 Mdot
.41125 .575 Mdot
.34875 .55 Mdot
.405 .51875 Mdot
.65125 .45 Mdot
.79 .40125 Mdot
.75875 .385 Mdot
.3125 .4175 Mdot
.7375 .4425 Mdot
.885 .4625 Mdot
.465 .4875 Mdot
.3425 .52625 Mdot
.95 .5225 Mdot
.14375 .5225 Mdot
.9175 .545 Mdot
.4975 .55875 Mdot
.35875 .5925 Mdot
.17125 .605 Mdot
.525 .59375 Mdot
.7475 .61 Mdot
.68 .63625 Mdot
.39875 .69875 Mdot
.37625 .6525 Mdot
.9175 .6125 Mdot
.04375 .59125 Mdot
.5575 .57 Mdot
.6525 .47875 Mdot
.405 .48625 Mdot
.48625 .48875 Mdot
.46125 .44875 Mdot
.5975 .4525 Mdot
.48 .45625 Mdot
.67125 .48125 Mdot
.545 .5 Mdot
.22625 .5675 Mdot
.49875 .56625 Mdot
.5625 .505 Mdot
.44625 .46125 Mdot
.5775 .46625 Mdot
.59 .395 Mdot
.18625 .3775 Mdot
.55625 .42375 Mdot
.55375 .4575 Mdot
.66 .4425 Mdot
.22875 .51 Mdot
.8675 .53125 Mdot
.285 .57625 Mdot
.48 .6 Mdot
.8125 .56375 Mdot
.12125 .425 Mdot
.4175 .49375 Mdot
.30625 .46625 Mdot
.3775 .515 Mdot
.41 .51625 Mdot
.5125 .47125 Mdot
.5775 .48125 Mdot
.33 .5575 Mdot
.8 .5225 Mdot
.3425 .46625 Mdot
.37125 .41375 Mdot
.495 .34375 Mdot
.73875 .2725 Mdot
.63375 .21125 Mdot
.40625 .22625 Mdot
.2275 .225 Mdot
.25875 .215 Mdot
.275 .30125 Mdot
.4025 .32625 Mdot
.785 .38625 Mdot
.0425 .4775 Mdot
.19125 .5725 Mdot
.575 .5975 Mdot
.445 .6175 Mdot
.2275 .59 Mdot
.57125 .5575 Mdot
.65125 .52 Mdot
.37 .4925 Mdot
.81 .47 Mdot
.5575 .45875 Mdot
.20625 .44375 Mdot
.4025 .42875 Mdot
.39625 .51625 Mdot
.03125 .6225 Mdot
.44625 .6425 Mdot
.80625 .6775 Mdot
.76 .71125 Mdot
.20875 .67875 Mdot
.68875 .59625 Mdot
.375 .575 Mdot
.2875 .5375 Mdot
.79 .50625 Mdot
.82125 .44625 Mdot
.91875 .4825 Mdot
.19875 .5125 Mdot
.705 .48375 Mdot
.77 .35375 Mdot
.72125 .3525 Mdot
.17875 .37375 Mdot
.94125 .37625 Mdot
.75875 .36375 Mdot
.58 .3775 Mdot
.615 .31375 Mdot
.34375 .29 Mdot
.71 .3 Mdot
.30625 .32625 Mdot
.33125 .305 Mdot
.23625 .37375 Mdot
.08 .3875 Mdot
.8825 .3825 Mdot
.43625 .415 Mdot
.67375 .40875 Mdot
.475 .4575 Mdot
.4225 .51375 Mdot
.2475 .55625 Mdot
.5025 .6 Mdot
.605 .6425 Mdot
.74 .66 Mdot
.8225 .6575 Mdot
.28125 .6325 Mdot
.7675 .6025 Mdot
.845 .5675 Mdot
.51375 .51125 Mdot
.25125 .48125 Mdot
.095 .48875 Mdot
.945 .49625 Mdot
.9375 .47 Mdot
.59125 .45375 Mdot
.40875 .40625 Mdot
.095 .3725 Mdot
.49125 .35375 Mdot
.805 .34875 Mdot
.66875 .355 Mdot
.4125 .34 Mdot
.355 .4225 Mdot
.86125 .47875 Mdot
.12375 .475 Mdot
.5525 .4725 Mdot
.60375 .535 Mdot
.41875 .53375 Mdot
.54875 .585 Mdot
.4375 .655 Mdot
.51625 .64375 Mdot
.5175 .62125 Mdot
.73 .54875 Mdot
.53125 .50625 Mdot
.2225 .46375 Mdot
.48625 .49875 Mdot
.61125 .58125 Mdot
.29875 .67125 Mdot
.69125 .675 Mdot
.6075 .69875 Mdot
.08875 .68 Mdot
.70875 .56875 Mdot
.41 .4675 Mdot
.7325 .46 Mdot
.2275 .40875 Mdot
.835 .39125 Mdot
.28125 .39625 Mdot
.4925 .4075 Mdot
.79125 .375 Mdot
.1775 .55375 Mdot
.3425 .51375 Mdot
.215 .56125 Mdot
.39125 .56375 Mdot
.45 .57125 Mdot
.5125 .63 Mdot
.485 .655 Mdot
.4475 .61 Mdot
.7275 .6025 Mdot
.37875 .64875 Mdot
.36625 .685 Mdot
.5025 .71375 Mdot
.7275 .75125 Mdot
.59875 .745 Mdot
.49875 .69375 Mdot
.155 .65125 Mdot
.2625 .62625 Mdot
.2975 .64 Mdot
.37125 .6375 Mdot
.76 .60875 Mdot
.10125 .57875 Mdot
.1625 .45125 Mdot
.59125 .4125 Mdot
.44375 .385 Mdot
.255 .395 Mdot
.51625 .45 Mdot
.6825 .49875 Mdot
.34875 .5275 Mdot
.75875 .50375 Mdot
.605 .48875 Mdot
.15625 .515 Mdot
.3325 .55 Mdot
.42125 .50125 Mdot
.52 .47625 Mdot
.725 .465 Mdot
.85625 .44875 Mdot
.15625 .46 Mdot
.62125 .47625 Mdot
.5025 .46375 Mdot
.17875 .43875 Mdot
.855 .4175 Mdot
.80625 .4675 Mdot
.79875 .4275 Mdot
.27 .45625 Mdot
.69875 .52625 Mdot
.015 .56 Mdot
.76 .68875 Mdot
.745 .6775 Mdot
.1375 .6575 Mdot
.95875 .66625 Mdot
.84125 .69625 Mdot
.5375 .695 Mdot
.60375 .74125 Mdot
.325 .7025 Mdot
.825 .6225 Mdot
.20875 .57375 Mdot
.37125 .5725 Mdot
.2175 .535 Mdot
.085 .5525 Mdot
.8675 .56125 Mdot
.4025 .53625 Mdot
.68375 .485 Mdot
.53 .4475 Mdot
.44 .415 Mdot
.10625 .38375 Mdot
.68 .3475 Mdot
.49125 .36875 Mdot
.7275 .41625 Mdot
.835 .41375 Mdot
.27375 .38875 Mdot
.7875 .3675 Mdot
.81375 .40375 Mdot
.5125 .45875 Mdot
.20125 .50375 Mdot
.07875 .5 Mdot
.89875 .49625 Mdot
.85625 .50375 Mdot
.6225 .53125 Mdot
.47625 .555 Mdot
.53375 .59875 Mdot
.8075 .63 Mdot
.67375 .6575 Mdot
.435 .6575 Mdot
.35 .6525 Mdot
.7875 .62625 Mdot
.17875 .6275 Mdot
.545 .6325 Mdot
.59125 .61375 Mdot
.43125 .5625 Mdot
.575 .48625 Mdot
.45375 .42625 Mdot
.4625 .4375 Mdot
.48125 .425 Mdot
.81625 .5175 Mdot
.49 .52875 Mdot
.25625 .52 Mdot
.44625 .43875 Mdot
.70375 .3925 Mdot
.1 .28125 Mdot
.80875 .29875 Mdot
.6525 .33875 Mdot
.0275 .3725 Mdot
.74 .4475 Mdot
.37125 .54625 Mdot
.7275 .5475 Mdot
.315 .555 Mdot
.7525 .5725 Mdot
.32375 .56 Mdot
.5125 .52875 Mdot
.72625 .57125 Mdot
.21875 .54125 Mdot
.30625 .53125 Mdot
.165 .4675 Mdot
.33625 .41375 Mdot
.53 .42 Mdot
.58125 .4325 Mdot
.335 .415 Mdot
.55125 .42875 Mdot
.6825 .4625 Mdot
.35375 .4575 Mdot
.42125 .45125 Mdot
.485 .4725 Mdot
.71 .46375 Mdot
.6 .49625 Mdot
.54375 .50875 Mdot
.12375 .5 Mdot
.2625 .49625 Mdot
.295 .415 Mdot
.40625 .3925 Mdot
.75625 .38625 Mdot
.095 .37875 Mdot
.14875 .46625 Mdot
.59125 .5025 Mdot
.4325 .545 Mdot
.29 .56125 Mdot
.45875 .55 Mdot
.71125 .54125 Mdot
.35375 .525 Mdot
.705 .52 Mdot
.61625 .5325 Mdot
.1825 .52625 Mdot
.34625 .50625 Mdot
.47375 .50375 Mdot
.57875 .4975 Mdot
.635 .51 Mdot
.875 .505 Mdot
.195 .51 Mdot
.52125 .5075 Mdot
.63625 .505 Mdot
.05 .5125 Mdot
.91625 .5375 Mdot
.84875 .5125 Mdot
.69125 .53 Mdot
.35125 .515 Mdot
.70125 .46125 Mdot
.0275 .4775 Mdot
.7425 .4175 Mdot
.71125 .4075 Mdot
.21125 .37 Mdot
.88125 .3475 Mdot
.8825 .3175 Mdot
.47 .3375 Mdot
.6325 .3375 Mdot
.28625 .38875 Mdot
.93625 .455 Mdot
.09875 .48125 Mdot
.45 .48125 Mdot
.17 .505 Mdot
.13875 .48125 Mdot
.79625 .47375 Mdot
.4025 .5025 Mdot
.68875 .53875 Mdot
.57625 .54625 Mdot
.43 .5525 Mdot
.025 .54 Mdot
.8475 .545 Mdot
.36 .50625 Mdot
.71375 .47375 Mdot
.835 .49125 Mdot
.29 .53 Mdot
.76125 .5525 Mdot
.805 .53875 Mdot
.525 .49875 Mdot
.16625 .485 Mdot
.11625 .4775 Mdot
.8625 .4875 Mdot
.0675 .4575 Mdot
.755 .45125 Mdot
.5975 .43375 Mdot
.59 .42625 Mdot
.6275 .40625 Mdot
.7775 .37875 Mdot
.69125 .37125 Mdot
.4525 .3325 Mdot
.34125 .3075 Mdot
.68875 .33375 Mdot
.315 .34 Mdot
.49375 .35 Mdot
.55375 .4075 Mdot
.4575 .45625 Mdot
.6575 .52125 Mdot
.38375 .57 Mdot
.4875 .52375 Mdot
.40125 .5175 Mdot
.81375 .47 Mdot
.54875 .44875 Mdot
.3 .45 Mdot
.39 .52875 Mdot
.77375 .57125 Mdot
.58125 .5175 Mdot
.03125 .49 Mdot
.7025 .4475 Mdot
.35 .45375 Mdot
.76625 .46625 Mdot
.40875 .5025 Mdot
.63375 .5125 Mdot
.34 .53625 Mdot
.57375 .5375 Mdot
.6675 .5275 Mdot
.2425 .50625 Mdot
.2725 .49875 Mdot
.13125 .51875 Mdot
.32375 .5175 Mdot
.6125 .49125 Mdot
.56875 .44375 Mdot
.24875 .41125 Mdot
.64875 .36875 Mdot
.60125 .365 Mdot
.34625 .365 Mdot
.49375 .375 Mdot
.45875 .4025 Mdot
.735 .43 Mdot
.56625 .41 Mdot
.5375 .425 Mdot
.0975 .45 Mdot
.30875 .4275 Mdot
.295 .4675 Mdot
.485 .475 Mdot
.685 .4975 Mdot
.10625 .53375 Mdot
.10625 .51125 Mdot
.6225 .495 Mdot
.3875 .455 Mdot
.33875 .45125 Mdot
.40875 .44375 Mdot
.755 .445 Mdot
.37375 .485 Mdot
.7025 .45375 Mdot
.59625 .45 Mdot
.2575 .40125 Mdot
.38 .445 Mdot
.49125 .45625 Mdot
.6425 .5075 Mdot
.59 .505 Mdot
.89 .51375 Mdot
.2025 .52625 Mdot
.44 .55875 Mdot
.715 .55875 Mdot
.0175 .5925 Mdot
.90625 .63375 Mdot
.8975 .67 Mdot
.61 .69625 Mdot
.40875 .66125 Mdot
.68875 .6375 Mdot
.09375 .545 Mdot
.67875 .51625 Mdot
.7225 .54125 Mdot
.2675 .60125 Mdot
.8175 .60625 Mdot
.88 .58375 Mdot
.4725 .52875 Mdot
.605 .45625 Mdot
.255 .4275 Mdot
.57625 .49 Mdot
.17375 .55875 Mdot
.13375 .54375 Mdot
.79 .56375 Mdot
.3525 .54 Mdot
.74125 .525 Mdot
.5875 .52625 Mdot
.465 .535 Mdot
.25625 .5425 Mdot
.72 .575 Mdot
.8075 .575 Mdot
.33125 .55875 Mdot
.71125 .55375 Mdot
.81375 .525 Mdot
.0475 .5375 Mdot
.47125 .5225 Mdot
.15375 .5175 Mdot
.1425 .5025 Mdot
.76375 .495 Mdot
.1725 .50875 Mdot
.71125 .4925 Mdot
.545 .465 Mdot
.6975 .48375 Mdot
.76125 .45625 Mdot
.7075 .435 Mdot
.7325 .43875 Mdot
.44625 .455 Mdot
.36375 .4725 Mdot
.5375 .46 Mdot
.47875 .48875 Mdot
.44625 .49875 Mdot
.54375 .46125 Mdot
.4825 .46625 Mdot
.655 .49875 Mdot
.35 .51125 Mdot
.5625 .57 Mdot
.28 .6175 Mdot
.87 .62125 Mdot
.5375 .5925 Mdot
.37 .56625 Mdot
.255 .50125 Mdot
.94625 .45625 Mdot
.455 .4775 Mdot
.11375 .4825 Mdot
.6575 .46 Mdot
.33125 .39875 Mdot
.78375 .32875 Mdot
.50875 .3025 Mdot
.46125 .32 Mdot
.42125 .35625 Mdot
.6125 .40875 Mdot
.61375 .47875 Mdot
.25875 .40875 Mdot
.24875 .4375 Mdot
.14 .42375 Mdot
.295 .435 Mdot
.67375 .4775 Mdot
.5425 .49875 Mdot
.2325 .57875 Mdot
.67375 .605 Mdot
.56625 .60125 Mdot
.3375 .5875 Mdot
.57625 .56625 Mdot
.4475 .52875 Mdot
.67125 .53125 Mdot
.56375 .5725 Mdot
.53875 .5875 Mdot
.1225 .62125 Mdot
.31625 .6275 Mdot
.31625 .59625 Mdot
.48375 .59 Mdot
.66 .56 Mdot
.1625 .54375 Mdot
.10625 .54875 Mdot
.65875 .5475 Mdot
.34375 .55125 Mdot
.38875 .53125 Mdot
.355 .52125 Mdot
.765 .5175 Mdot
.40125 .50125 Mdot
.655 .61125 Mdot
.60375 .56625 Mdot
.2875 .54125 Mdot
.4125 .47875 Mdot
.5125 .4375 Mdot
.74625 .43875 Mdot
.505 .44875 Mdot
.9175 .42875 Mdot
.1975 .4125 Mdot
.38375 .39625 Mdot
.76125 .42125 Mdot
.02 .43875 Mdot
.8675 .4075 Mdot
.97125 .38125 Mdot
.5225 .37125 Mdot
.46375 .365 Mdot
.69875 .40125 Mdot
.1125 .4675 Mdot
.56375 .4775 Mdot
.75 .445 Mdot
.32375 .4275 Mdot
.7575 .4425 Mdot
.855 .525 Mdot
.4325 .58625 Mdot
.6425 .665 Mdot
.22375 .6725 Mdot
.66 .63125 Mdot
.85125 .5475 Mdot
.265 .545 Mdot
.0775 .555 Mdot
.81 .53375 Mdot
.33 .52875 Mdot
.785 .50875 Mdot
.565 .485 Mdot
.53 .45125 Mdot
.1725 .46375 Mdot
.7375 .41 Mdot
.79375 .3625 Mdot
.33375 .34125 Mdot
.72 .33375 Mdot
.80375 .3675 Mdot
.07375 .40875 Mdot
.445 .4275 Mdot
.135 .4425 Mdot
.1625 .49875 Mdot
.65875 .49125 Mdot
.25625 .54 Mdot
.69875 .565 Mdot
.49625 .57125 Mdot
.79 .55 Mdot
.89375 .55125 Mdot
.635 .57 Mdot
.75875 .55875 Mdot
.4825 .56125 Mdot
.32375 .51625 Mdot
.4675 .50125 Mdot
.595 .48125 Mdot
.41875 .4725 Mdot
.51 .505 Mdot
.49375 .515 Mdot
.70875 .49125 Mdot
.2625 .4875 Mdot
.66875 .45875 Mdot
.16125 .39625 Mdot
.855 .42 Mdot
.61625 .4625 Mdot
.3675 .4825 Mdot
.2775 .52 Mdot
.96625 .555 Mdot
.33 .5525 Mdot
.23875 .5575 Mdot
.485 .5975 Mdot
.485 .6575 Mdot
.735 .68625 Mdot
.58375 .69 Mdot
.3175 .66125 Mdot
.47125 .59875 Mdot
.68 .525 Mdot
.56125 .46 Mdot
.28 .60625 Mdot
.24625 .585 Mdot
.1625 .59375 Mdot
.25125 .62 Mdot
.7175 .61875 Mdot
.535 .62375 Mdot
.2025 .56125 Mdot
.71875 .55875 Mdot
.5475 .54625 Mdot
.30375 .50875 Mdot
.65625 .5125 Mdot
.4125 .52875 Mdot
.65875 .49125 Mdot
.55625 .4175 Mdot
.505 .4075 Mdot
.175 .33 Mdot
.32875 .29125 Mdot
.30125 .35375 Mdot
.5075 .36375 Mdot
.68 .41125 Mdot
.0975 .42125 Mdot
.0625 .4225 Mdot
.69625 .42375 Mdot
.30375 .41625 Mdot
.42375 .41875 Mdot
.31625 .415 Mdot
.7875 .4125 Mdot
.41625 .3875 Mdot
.605 .38625 Mdot
.5725 .45875 Mdot
.37 .585 Mdot
.405 .64625 Mdot
.5525 .68625 Mdot
.84625 .6225 Mdot
.385 .5925 Mdot
.9775 .6375 Mdot
.1825 .61125 Mdot
.34875 .5925 Mdot
.78875 .55125 Mdot
.04875 .48125 Mdot
.81375 .4175 Mdot
.47375 .34 Mdot
.4925 .3875 Mdot
.6875 .3975 Mdot
.16125 .40625 Mdot
.4725 .39 Mdot
.74875 .41 Mdot
.42 .425 Mdot
.68125 .43 Mdot
.035 .4475 Mdot
.7875 .4625 Mdot
.40625 .47375 Mdot
.66375 .4375 Mdot
.22375 .46125 Mdot
.73375 .42375 Mdot
.71125 .4 Mdot
.36125 .39625 Mdot
.01375 .35375 Mdot
.84 .355 Mdot
.3075 .35 Mdot
.84125 .4425 Mdot
.53 .48125 Mdot
.60375 .5275 Mdot
.13125 .53625 Mdot
.71375 .54375 Mdot
.805 .5625 Mdot
.3075 .58375 Mdot
.72375 .61375 Mdot
.82625 .5875 Mdot
.08875 .5075 Mdot
.43875 .53125 Mdot
.12375 .55 Mdot
.24 .5075 Mdot
.57375 .54875 Mdot
.3025 .4975 Mdot
.70625 .45625 Mdot
.43625 .44875 Mdot
.8475 .47625 Mdot
.99875 .5 Mdot
.56875 .5125 Mdot
.7675 .545 Mdot
.52125 .54875 Mdot
.30125 .59625 Mdot
.4475 .6 Mdot
.6475 .5975 Mdot
.3775 .6 Mdot
.51375 .5575 Mdot
.50625 .5175 Mdot
.695 .52 Mdot
.2675 .48125 Mdot
.73 .46375 Mdot
.01125 .50875 Mdot
.96625 .47125 Mdot
.58625 .3975 Mdot
.36875 .38 Mdot
.255 .36875 Mdot
.3 .51875 Mdot
.30875 .55 Mdot
.33875 .545 Mdot
.62375 .545 Mdot
.6775 .6025 Mdot
.61375 .61 Mdot
.21875 .59625 Mdot
.59 .61375 Mdot
.69125 .64375 Mdot
.485 .6175 Mdot
.25625 .3525 Mdot
.2425 .3775 Mdot
.19125 .43125 Mdot
.21 .40125 Mdot
.735 .39375 Mdot
.55375 .3625 Mdot
.18125 .36375 Mdot
.70875 .36625 Mdot
.5825 .4025 Mdot
.2575 .50625 Mdot
.695 .54875 Mdot
.42375 .51625 Mdot
.61875 .5025 Mdot
.595 .50875 Mdot
.46125 .425 Mdot
.205 .46375 Mdot
.30875 .58625 Mdot
.2775 .61375 Mdot
.4925 .6575 Mdot
.7125 .61 Mdot
.04625 .54875 Mdot
.0225 .535 Mdot
.71875 .5225 Mdot
.29 .5775 Mdot
.44 .60625 Mdot
.26875 .635 Mdot
.825 .61 Mdot
.44375 .61 Mdot
.61625 .49625 Mdot
.5225 .4775 Mdot
.41625 .415 Mdot
.9625 .3975 Mdot
.44875 .36125 Mdot
.535 .38 Mdot
.88375 .4225 Mdot
.30125 .42875 Mdot
.22 .42 Mdot
.28625 .42625 Mdot
.77625 .4325 Mdot
.1175 .455 Mdot
.78125 .48875 Mdot
.4175 .62125 Mdot
.54625 .6325 Mdot
.66 .63875 Mdot
.21625 .64375 Mdot
.3225 .65875 Mdot
.76875 .65375 Mdot
.525 .62125 Mdot
.59375 .625 Mdot
.16375 .565 Mdot
.665 .52 Mdot
.40125 .495 Mdot
.70375 .44875 Mdot
.22625 .4025 Mdot
.81 .4325 Mdot
.57 .495 Mdot
.475 .4675 Mdot
.9175 .53 Mdot
.23625 .5275 Mdot
.86875 .4675 Mdot
.5325 .47875 Mdot
.65625 .45 Mdot
.15625 .445 Mdot
.71125 .455 Mdot
.7975 .4775 Mdot
.3025 .4925 Mdot
.71 .4675 Mdot
.86375 .50875 Mdot
.0875 .5875 Mdot
.4125 .5825 Mdot
.12125 .56 Mdot
.31125 .56125 Mdot
.53125 .51375 Mdot
.33625 .5225 Mdot
.66875 .54375 Mdot
.44875 .575 Mdot
.8575 .565 Mdot
.51625 .56125 Mdot
.78125 .49875 Mdot
.5375 .51375 Mdot
.27625 .51625 Mdot
.4725 .545 Mdot
.6525 .53125 Mdot
.36125 .5325 Mdot
.5225 .52875 Mdot
.4825 .49625 Mdot
.705 .4075 Mdot
.23625 .39875 Mdot
.82375 .4075 Mdot
.97875 .36875 Mdot
.64125 .51 Mdot
.37625 .54375 Mdot
.27 .59625 Mdot
.995 .60125 Mdot
.305 .45375 Mdot
.405 .4025 Mdot
.16375 .4175 Mdot
.77 .39375 Mdot
.655 .32875 Mdot
.57 .35 Mdot
.2025 .3425 Mdot
.64375 .3075 Mdot
.65125 .2975 Mdot
.52125 .33 Mdot
.2325 .63125 Mdot
.25125 .595 Mdot
.1775 .53375 Mdot
.235 .52125 Mdot
.70375 .49375 Mdot
.555 .51875 Mdot
.1825 .52875 Mdot
.7175 .5575 Mdot
.57875 .54875 Mdot
.26875 .48875 Mdot
.68375 .4625 Mdot
.4675 .4925 Mdot
.5625 .5025 Mdot
.6025 .5525 Mdot
.45125 .66375 Mdot
.2125 .68 Mdot
.3425 .60625 Mdot
.2825 .565 Mdot
.47375 .465 Mdot
.7275 .455 Mdot
.04125 .48875 Mdot
.0875 .47125 Mdot
.71375 .515 Mdot
.2575 .48 Mdot
.4625 .46625 Mdot
.24 .45625 Mdot
.84375 .48375 Mdot
.47875 .50125 Mdot
.59125 .505 Mdot
.495 .5075 Mdot
.44625 .50625 Mdot
.97125 .47125 Mdot
.43375 .54875 Mdot
.5325 .5525 Mdot
.88625 .50125 Mdot
.2725 .50875 Mdot
.22625 .49625 Mdot
.2775 .53 Mdot
.71625 .58125 Mdot
.26 .59875 Mdot
.69125 .61125 Mdot
.9925 .5825 Mdot
.06 .55875 Mdot
.3575 .51625 Mdot
.57375 .5 Mdot
.635 .46625 Mdot
.2575 .4375 Mdot
.0925 .41125 Mdot
.1775 .40375 Mdot
.84125 .41875 Mdot
.56625 .45375 Mdot
.5125 .45625 Mdot
.29375 .49875 Mdot
.52125 .51625 Mdot
.45625 .53125 Mdot
.69125 .60875 Mdot
.26625 .655 Mdot
.86625 .58875 Mdot
.425 .505 Mdot
.6375 .50625 Mdot
.1775 .52875 Mdot
.90625 .55875 Mdot
.57 .55375 Mdot
.57625 .57 Mdot
.1875 .58125 Mdot
.72125 .5775 Mdot
.7925 .55625 Mdot
.31375 .5125 Mdot
.70625 .4875 Mdot
.8625 .4425 Mdot
.125 .40875 Mdot
.3425 .38375 Mdot
.1225 .37875 Mdot
.25875 .42875 Mdot
.47625 .45375 Mdot
.39875 .48625 Mdot
.63 .50625 Mdot
.47 .5025 Mdot
.85375 .48625 Mdot
.47875 .415 Mdot
.7775 .41625 Mdot
.55375 .40125 Mdot
.2825 .39 Mdot
.47125 .38875 Mdot
.7025 .4275 Mdot
.2875 .465 Mdot
.53125 .4525 Mdot
.50375 .49625 Mdot
.65375 .57875 Mdot
.28625 .5725 Mdot
.80375 .58125 Mdot
.625 .545 Mdot
.29125 .50375 Mdot
.36375 .46 Mdot
.91875 .39875 Mdot
.35875 .52875 Mdot
.4625 .54125 Mdot
.0825 .55875 Mdot
.845 .53125 Mdot
.6 .53 Mdot
.53 .51875 Mdot
.265 .55 Mdot
.67625 .58125 Mdot
.53875 .60875 Mdot
.60875 .63875 Mdot
.215 .46125 Mdot
.27875 .51125 Mdot
.1925 .54875 Mdot
.2375 .57875 Mdot
.675 .615 Mdot
.55125 .59375 Mdot
.215 .57125 Mdot
.695 .54375 Mdot
.6 .51375 Mdot
.31 .49375 Mdot
.57375 .48625 Mdot
.5725 .5125 Mdot
.48625 .5675 Mdot
.6125 .5925 Mdot
.4525 .5625 Mdot
.2725 .59125 Mdot
.3225 .5975 Mdot
.28 .52125 Mdot
.4275 .57375 Mdot
.77875 .58875 Mdot
.08625 .585 Mdot
.99 .58 Mdot
.16625 .5825 Mdot
.72125 .5425 Mdot
.25125 .505 Mdot
.4825 .485 Mdot
.25375 .48375 Mdot
.79 .4725 Mdot
.52125 .46125 Mdot
.53375 .5075 Mdot
.48375 .48375 Mdot
.4875 .49375 Mdot
.96 .52 Mdot
.43625 .49625 Mdot
.51375 .4625 Mdot
.83625 .4925 Mdot
.285 .50375 Mdot
.22625 .49625 Mdot
.2825 .46625 Mdot
.6475 .44625 Mdot
.45125 .44 Mdot
.58375 .465 Mdot
.925 .48375 Mdot
.15625 .53 Mdot
.3025 .5525 Mdot
.60875 .5225 Mdot
.63 .5225 Mdot
.2525 .53 Mdot
.975 .53375 Mdot
.19 .5425 Mdot
.095 .58375 Mdot
.88875 .57125 Mdot
.60125 .5625 Mdot
.41625 .5375 Mdot
.43125 .53 Mdot
.39125 .51 Mdot
.51875 .5125 Mdot
.65375 .46625 Mdot
.30875 .455 Mdot
.89875 .4275 Mdot
.315 .4725 Mdot
.7925 .49375 Mdot
.21125 .505 Mdot
.91875 .46625 Mdot
.5575 .43875 Mdot
.5775 .385 Mdot
.255 .2975 Mdot
.735 .35625 Mdot
.76 .44375 Mdot
.335 .55375 Mdot
.73625 .64625 Mdot
.84 .69 Mdot
.11 .70125 Mdot
.3375 .68125 Mdot
.155 .62125 Mdot
.33 .49375 Mdot
.435 .4275 Mdot
.4625 .385 Mdot
.545 .36625 Mdot
.52375 .36 Mdot
.83625 .385 Mdot
.50875 .50375 Mdot
.7225 .5225 Mdot
.61375 .53375 Mdot
.2675 .535 Mdot
.50375 .51125 Mdot
.6875 .52625 Mdot
.31375 .5025 Mdot
.47125 .5075 Mdot
.48875 .48625 Mdot
.64625 .4625 Mdot
.31625 .48875 Mdot
.78 .44375 Mdot
.68125 .46375 Mdot
.18375 .4825 Mdot
.46875 .55375 Mdot
.8325 .6175 Mdot
.915 .57125 Mdot
.565 .49375 Mdot
.4525 .47125 Mdot
.01875 .45375 Mdot
.9475 .46125 Mdot
.56875 .48 Mdot
.36625 .48375 Mdot
.4 .455 Mdot
.705 .46125 Mdot
.43875 .47875 Mdot
.68375 .44875 Mdot
.16 .445 Mdot
.30625 .4275 Mdot
.21125 .45625 Mdot
.2425 .43125 Mdot
.67375 .4 Mdot
.52 .4325 Mdot
.24 .4525 Mdot
.68375 .44 Mdot
.6325 .45375 Mdot
.32375 .48625 Mdot
.50875 .4775 Mdot
.5975 .43375 Mdot
.525 .385 Mdot
.6125 .33875 Mdot
.40125 .33 Mdot
.305 .2875 Mdot
.2975 .28 Mdot
.2775 .3525 Mdot
.41875 .38 Mdot
.83625 .35875 Mdot
.08 .39 Mdot
.9125 .41875 Mdot
.18375 .44875 Mdot
.74375 .43125 Mdot
.2425 .515 Mdot
.47625 .53625 Mdot
.26625 .53625 Mdot
.79 .555 Mdot
.56875 .60125 Mdot
.4975 .63875 Mdot
.43125 .64 Mdot
.59625 .5625 Mdot
.88875 .53 Mdot
.43125 .525 Mdot
.5275 .485 Mdot
.0275 .46625 Mdot
.72875 .495 Mdot
.31 .46375 Mdot
.19625 .43375 Mdot
.32875 .445 Mdot
.57625 .4425 Mdot
.625 .46375 Mdot
.45125 .4475 Mdot
.8825 .45875 Mdot
.225 .42 Mdot
.28375 .43375 Mdot
.645 .45 Mdot
.60875 .47 Mdot
.2075 .44875 Mdot
.9425 .45125 Mdot
.31375 .4525 Mdot
.05375 .44375 Mdot
.8675 .43875 Mdot
.645 .44375 Mdot
.35125 .44625 Mdot
.52 .425 Mdot
.255 .4225 Mdot
.65375 .40875 Mdot
.56 .42875 Mdot
.355 .43125 Mdot
.9025 .5325 Mdot
.235 .53875 Mdot
.925 .53375 Mdot
.1975 .5475 Mdot
.93625 .52875 Mdot
.5875 .57625 Mdot
.55 .6425 Mdot
.35 .8 Mdot
.74875 .685 Mdot
.7275 .54625 Mdot
.375 .415 Mdot
.7075 .3425 Mdot
.85125 .31125 Mdot
.11875 .2875 Mdot
.29875 .35 Mdot
.2075 .45375 Mdot
.37125 .5575 Mdot
.41 .6225 Mdot
.50375 .5925 Mdot
.5 .53875 Mdot
.575 .53125 Mdot
.775 .51125 Mdot
.93125 .47375 Mdot
.55875 .4825 Mdot
.6575 .4875 Mdot
.6475 .47 Mdot
.31125 .46 Mdot
.46875 .475 Mdot
.7075 .4525 Mdot
.3325 .45625 Mdot
.435 .5025 Mdot
.50875 .5525 Mdot
.5525 .53125 Mdot
.43625 .555 Mdot
.675 .66 Mdot
.02625 .76625 Mdot
.96125 .7775 Mdot
.77375 .81375 Mdot
.12625 .81875 Mdot
.4375 .72875 Mdot
.8325 .635 Mdot
.64875 .6 Mdot
.76875 .675 Mdot
.41875 .7 Mdot
.05 .685 Mdot
.86125 .67875 Mdot
.59 .69125 Mdot
.295 .65 Mdot
.55625 .605 Mdot
.685 .56125 Mdot
.3475 .50875 Mdot
.76125 .485 Mdot
.085 .54625 Mdot
.34 .55125 Mdot
.2075 .51875 Mdot
.275 .52875 Mdot
.66625 .56625 Mdot
.49125 .54375 Mdot
.3 .54 Mdot
.58625 .60375 Mdot
.70125 .60375 Mdot
.325 .545 Mdot
.45625 .54 Mdot
.65375 .53 Mdot
.5125 .45375 Mdot
.6375 .4525 Mdot
.3625 .49 Mdot
.3175 .50125 Mdot
.27875 .5225 Mdot
.24875 .59375 Mdot
.45625 .6425 Mdot
.82625 .71875 Mdot
.1625 .6925 Mdot
.7625 .64875 Mdot
.22875 .60875 Mdot
.76 .54 Mdot
.2225 .47125 Mdot
.49875 .45875 Mdot
.285 .44625 Mdot
.735 .44 Mdot
.6525 .39875 Mdot
.945 .34875 Mdot
.415 .32375 Mdot
.44375 .33375 Mdot
.67625 .42875 Mdot
.76875 .46 Mdot
.48 .455 Mdot
.56375 .485 Mdot
.045 .5025 Mdot
.65 .46875 Mdot
.36375 .48125 Mdot
.99625 .5275 Mdot
.14 .5175 Mdot
.3975 .51875 Mdot
.5275 .53625 Mdot
.75875 .5275 Mdot
.33375 .5075 Mdot
.8575 .48625 Mdot
.2925 .46375 Mdot
.28 .43 Mdot
.64125 .44125 Mdot
.5925 .455 Mdot
.1525 .4725 Mdot
.965 .48375 Mdot
.365 .4825 Mdot
.0675 .46 Mdot
.8075 .465 Mdot
.71875 .4875 Mdot
.27875 .5 Mdot
.6025 .55 Mdot
.115 .5925 Mdot
.7975 .6125 Mdot
.4875 .60375 Mdot
.38875 .605 Mdot
.9725 .5725 Mdot
.88 .505 Mdot
.16 .54 Mdot
.26875 .4775 Mdot
.905 .51 Mdot
.5675 .50625 Mdot
.56 .46625 Mdot
.47125 .365 Mdot
.755 .445 Mdot
.71375 .525 Mdot
.42375 .60375 Mdot
.64625 .605 Mdot
.895 .6025 Mdot
.1025 .6325 Mdot
.24875 .545 Mdot
.28625 .46125 Mdot
.41375 .45625 Mdot
.3725 .42875 Mdot
.5575 .53375 Mdot
.435 .62625 Mdot
.65125 .6575 Mdot
.73125 .64875 Mdot
.82625 .61 Mdot
.63625 .5825 Mdot
.61125 .5775 Mdot
.65625 .61375 Mdot
.36125 .60125 Mdot
.4325 .64375 Mdot
.71625 .66625 Mdot
.33875 .65125 Mdot
.44375 .59375 Mdot
.465 .55 Mdot
.5525 .5125 Mdot
.48125 .44125 Mdot
.55875 .32375 Mdot
.2525 .24 Mdot
.76375 .21625 Mdot
.855 .12125 Mdot
.115 .10875 Mdot
.4525 .17 Mdot
.80625 .18125 Mdot
.02 .18125 Mdot
.47375 .19125 Mdot
.915 .14125 Mdot
.41875 .1475 Mdot
.0975 .27125 Mdot
.75375 .3225 Mdot
.60125 .37625 Mdot
.27625 .41875 Mdot
.6925 .465 Mdot
.6125 .4475 Mdot
.2475 .48125 Mdot
.89375 .51 Mdot
.08625 .475 Mdot
.36 .43875 Mdot
.2175 .39375 Mdot
.2775 .39125 Mdot
.66625 .375 Mdot
.4725 .36625 Mdot
.32625 .3825 Mdot
.5425 .31 Mdot
.76375 .3475 Mdot
.3025 .42625 Mdot
.4075 .51 Mdot
.66875 .58625 Mdot
.5775 .7425 Mdot
.59 .75625 Mdot
.3 .7075 Mdot
.4 .67 Mdot
.31 .625 Mdot
.2825 .48 Mdot
.45 .41875 Mdot
.80125 .3925 Mdot
.265 .39625 Mdot
.5975 .43 Mdot
.2825 .4575 Mdot
.815 .53375 Mdot
.17375 .50875 Mdot
.52125 .49 Mdot
.31 .49875 Mdot
.645 .47125 Mdot
.77625 .48375 Mdot
.87375 .55875 Mdot
.32875 .59 Mdot
.485 .59875 Mdot
.74625 .55125 Mdot
.66625 .53125 Mdot
.49375 .52 Mdot
.6075 .53 Mdot
.075 .5125 Mdot
.57625 .55625 Mdot
.395 .55125 Mdot
.04125 .5725 Mdot
.5325 .59375 Mdot
.44 .55125 Mdot
.8775 .5525 Mdot
.20375 .52875 Mdot
.86375 .5175 Mdot
.335 .535 Mdot
.3275 .5725 Mdot
.57 .5425 Mdot
.61875 .5075 Mdot
.10125 .50125 Mdot
.98 .51 Mdot
.41375 .5175 Mdot
.08 .55875 Mdot
.76125 .63875 Mdot
.74375 .63125 Mdot
.25125 .60125 Mdot
.6525 .5575 Mdot
.965 .48625 Mdot
.4225 .47625 Mdot
.415 .4975 Mdot
.9025 .54625 Mdot
.02375 .5525 Mdot
.8375 .56 Mdot
.1575 .5275 Mdot
.97 .47 Mdot
.38625 .52 Mdot
.8675 .515 Mdot
.56375 .49625 Mdot
.53625 .49 Mdot
.53625 .47625 Mdot
.73375 .47375 Mdot
.725 .45125 Mdot
.45875 .41625 Mdot
.58125 .41625 Mdot
.925 .43125 Mdot
.1075 .4125 Mdot
.22125 .4975 Mdot
.36 .54375 Mdot
.3825 .4725 Mdot
.335 .45625 Mdot
.62375 .3725 Mdot
.3975 .30125 Mdot
.68625 .30625 Mdot
.67375 .36 Mdot
.7425 .4175 Mdot
.72 .47375 Mdot
.53875 .46 Mdot
.69375 .42625 Mdot
.37375 .43 Mdot
.4225 .36125 Mdot
.7125 .31375 Mdot
.34 .33625 Mdot
.45375 .38 Mdot
.45625 .43125 Mdot
.52875 .4925 Mdot
.51125 .59 Mdot
.4825 .62125 Mdot
.43625 .60375 Mdot
.62625 .62 Mdot
.85125 .66875 Mdot
.1775 .62625 Mdot
.37375 .605 Mdot
.8175 .6725 Mdot
.10375 .65625 Mdot
.39125 .66875 Mdot
.925 .72 Mdot
.42875 .66875 Mdot
.2475 .4625 Mdot
.5475 .3675 Mdot
.65 .28625 Mdot
.26875 .22375 Mdot
.7725 .2775 Mdot
.56875 .435 Mdot
.16 .48875 Mdot
.96875 .48875 Mdot
.085 .52875 Mdot
.3525 .5275 Mdot
.20875 .54875 Mdot
.305 .55625 Mdot
.6475 .58625 Mdot
.49125 .635 Mdot
.29875 .635 Mdot
.505 .66875 Mdot
.8475 .6175 Mdot
.315 .53625 Mdot
.335 .44125 Mdot
.63375 .365 Mdot
.69375 .28125 Mdot
.5325 .29 Mdot
.26625 .3125 Mdot
.45 .36125 Mdot
.3 .38 Mdot
.99 .455 Mdot
.35375 .45375 Mdot
.4375 .42375 Mdot
.7475 .38625 Mdot
.375 .41 Mdot
.46125 .395 Mdot
.285 .4 Mdot
.88 .44125 Mdot
.15 .525 Mdot
.535 .55375 Mdot
.33125 .5625 Mdot
.57375 .59625 Mdot
.8725 .6 Mdot
.81375 .54125 Mdot
.29125 .51 Mdot
.52375 .5175 Mdot
.77375 .53625 Mdot
.6225 .59375 Mdot
.51875 .62625 Mdot
.57875 .63 Mdot
.09625 .6375 Mdot
.5775 .625 Mdot
.3675 .58875 Mdot
.6575 .52625 Mdot
.38625 .535 Mdot
.94 .52625 Mdot
.0925 .57375 Mdot
.8575 .595 Mdot
.39875 .6175 Mdot
.38 .59875 Mdot
.48 .62125 Mdot
.64 .6375 Mdot
.09625 .5925 Mdot
.965 .55125 Mdot
.4725 .50875 Mdot
.11625 .46 Mdot
.6875 .36125 Mdot
.7275 .35125 Mdot
.29625 .36625 Mdot
.64375 .385 Mdot
.34875 .45625 Mdot
.4125 .435 Mdot
.81125 .395 Mdot
.13875 .38125 Mdot
.76625 .37375 Mdot
.17875 .37625 Mdot
.92125 .4875 Mdot
.5075 .47 Mdot
.78875 .46875 Mdot
.52625 .47375 Mdot
.64625 .4525 Mdot
.64875 .49125 Mdot
.74125 .55375 Mdot
.75 .57125 Mdot
.44 .5925 Mdot
.56625 .6175 Mdot
.92875 .61125 Mdot
.0925 .62125 Mdot
.22875 .60125 Mdot
.39625 .595 Mdot
.95125 .62625 Mdot
.4375 .69625 Mdot
.2875 .72 Mdot
.67375 .75625 Mdot
.375 .815 Mdot
.71125 .7875 Mdot
.63 .70375 Mdot
.655 .60875 Mdot
.81 .51625 Mdot
.48125 .5025 Mdot
.72125 .52375 Mdot
.39875 .54625 Mdot
.4075 .5425 Mdot
.685 .5625 Mdot
.34375 .51875 Mdot
.49 .47625 Mdot
.4275 .4225 Mdot
.52625 .415 Mdot
.4925 .38 Mdot
.5 .46125 Mdot
.5225 .49125 Mdot
.47875 .48 Mdot
.8575 .48125 Mdot
.3275 .52875 Mdot
.23125 .4875 Mdot
.87625 .485 Mdot
.10625 .525 Mdot
.37375 .5275 Mdot
.93375 .48 Mdot
.44375 .53625 Mdot
.32375 .62625 Mdot
.41 .715 Mdot
.70375 .775 Mdot
.29125 .845 Mdot
.7525 .7925 Mdot
.5725 .69 Mdot
.14875 .59125 Mdot
.96875 .55 Mdot
.10125 .46875 Mdot
.34 .52875 Mdot
.21375 .62 Mdot
.2875 .63875 Mdot
.6425 .595 Mdot
.49375 .52875 Mdot
.27875 .51125 Mdot
.50125 .51375 Mdot
.9075 .5225 Mdot
.25875 .54625 Mdot
.4025 .57625 Mdot
.56375 .57875 Mdot
.75125 .52375 Mdot
.485 .45125 Mdot
.295 .4525 Mdot
.42 .41875 Mdot
.31375 .455 Mdot
.97875 .47375 Mdot
.38875 .5175 Mdot
.39375 .52875 Mdot
.75 .5425 Mdot
.40625 .47 Mdot
.47375 .46375 Mdot
.2525 .4625 Mdot
.89375 .45625 Mdot
.14375 .4325 Mdot
.5225 .445 Mdot
.3475 .45375 Mdot
.56875 .4625 Mdot
.91125 .44875 Mdot
.76875 .45625 Mdot
.2525 .45375 Mdot
.56375 .42 Mdot
.79 .4225 Mdot
.6125 .38625 Mdot
.48375 .3675 Mdot
.615 .36375 Mdot
.09 .3425 Mdot
.54875 .32 Mdot
.35125 .37 Mdot
.7925 .4575 Mdot
.35125 .46375 Mdot
.91625 .4775 Mdot
.02875 .44875 Mdot
.88625 .4375 Mdot
.455 .425 Mdot
.4175 .425 Mdot
.36375 .40875 Mdot
.66625 .42 Mdot
.145 .47 Mdot
.895 .51875 Mdot
.56625 .59 Mdot
.14 .61875 Mdot
.6125 .63375 Mdot
.70125 .59625 Mdot
.36125 .555 Mdot
.5925 .50625 Mdot
.3 .5125 Mdot
.43125 .55 Mdot
.70375 .57375 Mdot
.2575 .5975 Mdot
.69125 .58125 Mdot
.205 .565 Mdot
.9275 .46375 Mdot
.62125 .485 Mdot
.69125 .4675 Mdot
.5275 .46 Mdot
.63125 .5025 Mdot
.73625 .46 Mdot
.715 .395 Mdot
.80125 .41125 Mdot
.40625 .39625 Mdot
.56625 .37625 Mdot
.92125 .3475 Mdot
.10875 .3175 Mdot
.23375 .32625 Mdot
.38 .33625 Mdot
.97375 .3425 Mdot
.425 .3375 Mdot
.2575 .375 Mdot
.69375 .355 Mdot
.4 .32125 Mdot
.715 .3075 Mdot
.57875 .3575 Mdot
.5875 .41625 Mdot
.8575 .4825 Mdot
.46375 .51375 Mdot
.71 .50875 Mdot
.415 .485 Mdot
.44 .48 Mdot
.63 .46 Mdot
.31375 .49 Mdot
.56625 .4925 Mdot
.4 .47375 Mdot
.5575 .50125 Mdot
.43625 .5025 Mdot
.51625 .4375 Mdot
.61625 .395 Mdot
.34375 .44125 Mdot
.78375 .40125 Mdot
.53625 .3475 Mdot
.1775 .34375 Mdot
.81125 .405 Mdot
.1275 .3775 Mdot
.4325 .36875 Mdot
.88375 .4425 Mdot
.41875 .47875 Mdot
.425 .47375 Mdot
.27125 .485 Mdot
.7175 .48625 Mdot
.4275 .44625 Mdot
.6975 .44625 Mdot
.5275 .39375 Mdot
.16875 .4025 Mdot
.94875 .43 Mdot
.1375 .60625 Mdot
.33875 .53125 Mdot
.22375 .41875 Mdot
.28375 .40375 Mdot
.6225 .38625 Mdot
.52 .42125 Mdot
.2775 .405 Mdot
.46625 .4025 Mdot
.9525 .4175 Mdot
.23875 .45375 Mdot
.36625 .4725 Mdot
.57625 .515 Mdot
.7875 .605 Mdot
.45125 .675 Mdot
.3075 .6775 Mdot
.4425 .6725 Mdot
.35625 .64125 Mdot
.90625 .5875 Mdot
.39875 .52625 Mdot
.40125 .5575 Mdot
.69375 .57 Mdot
.46875 .63 Mdot
.47 .61625 Mdot
.27 .6 Mdot
.87125 .53625 Mdot
.14 .52 Mdot
.51375 .50125 Mdot
.40375 .4825 Mdot
.51625 .45875 Mdot
.9225 .45625 Mdot
.76625 .4675 Mdot
.2275 .465 Mdot
.61375 .49 Mdot
.8075 .5125 Mdot
.595 .52375 Mdot
.4675 .51625 Mdot
.62375 .53 Mdot
.0675 .54375 Mdot
.54 .53 Mdot
.34625 .50375 Mdot
.87 .4575 Mdot
.35375 .46625 Mdot
.83 .44125 Mdot
.0475 .44375 Mdot
.92 .42 Mdot
.475 .3825 Mdot
.4275 .355 Mdot
.24625 .37375 Mdot
.755 .37125 Mdot
.19 .36125 Mdot
.815 .385 Mdot
.60375 .42375 Mdot
.15 .43375 Mdot
.61125 .47875 Mdot
.6325 .52625 Mdot
.435 .54875 Mdot
.54875 .56375 Mdot
.26 .49125 Mdot
.4875 .44375 Mdot
.54625 .415 Mdot
.41875 .405 Mdot
.54 .43 Mdot
.33125 .46625 Mdot
.875 .56 Mdot
.76875 .5625 Mdot
.5875 .59875 Mdot
.4975 .60375 Mdot
.67875 .5625 Mdot
.98 .6025 Mdot
.8125 .5775 Mdot
.665 .5175 Mdot
.88125 .475 Mdot
.3325 .48625 Mdot
.61125 .505 Mdot
.89125 .5375 Mdot
.10625 .5575 Mdot
.245 .495 Mdot
.3925 .4775 Mdot
.96875 .44125 Mdot
.45 .4025 Mdot
.23125 .38875 Mdot
.70375 .42 Mdot
.40875 .435 Mdot
.69125 .47625 Mdot
.575 .48875 Mdot
.57875 .515 Mdot
.86125 .49875 Mdot
.4725 .50625 Mdot
.67875 .5125 Mdot
.455 .53625 Mdot
.49625 .56125 Mdot
.51875 .58875 Mdot
.31125 .5775 Mdot
.62375 .62 Mdot
.3725 .655 Mdot
.62875 .65375 Mdot
.33125 .6525 Mdot
.585 .6725 Mdot
.64375 .68375 Mdot
.295 .6375 Mdot
.6925 .63 Mdot
.6375 .67 Mdot
.20375 .65375 Mdot
.74875 .55 Mdot
.15125 .55375 Mdot
.5075 .5725 Mdot
.7975 .49375 Mdot
.4125 .45875 Mdot
.44875 .4725 Mdot
.28625 .4675 Mdot
.7075 .415 Mdot
.51625 .4375 Mdot
.55875 .48125 Mdot
.57375 .56625 Mdot
.12125 .585 Mdot
.965 .605 Mdot
.14875 .4275 Mdot
.36 .50625 Mdot
.29 .5925 Mdot
.235 .58375 Mdot
.625 .605 Mdot
.5 .56375 Mdot
.2725 .56375 Mdot
.51 .5175 Mdot
.95 .51125 Mdot
.25125 .50375 Mdot
.35 .47 Mdot
.52375 .41625 Mdot
.84375 .41875 Mdot
.4425 .4075 Mdot
.2875 .39625 Mdot
.48125 .435 Mdot
.37375 .46625 Mdot
.8275 .4525 Mdot
.47 .46125 Mdot
.35375 .405 Mdot
.68875 .39625 Mdot
.50125 .395 Mdot
.46 .45 Mdot
.275 .49 Mdot
.8575 .55125 Mdot
.16375 .54125 Mdot
.4725 .5475 Mdot
.435 .545 Mdot
.50625 .55125 Mdot
.93 .56875 Mdot
.78625 .575 Mdot
.1975 .585 Mdot
.67875 .60625 Mdot
.80125 .60125 Mdot
.5625 .60875 Mdot
.48625 .63375 Mdot
.595 .61125 Mdot
.10125 .58875 Mdot
.51125 .59 Mdot
.33875 .57125 Mdot
.9225 .52 Mdot
.34375 .50375 Mdot
.735 .5125 Mdot
.09125 .5125 Mdot
.955 .50875 Mdot
.47125 .52375 Mdot
.4425 .52875 Mdot
.15375 .54 Mdot
.8075 .51875 Mdot
.2775 .51125 Mdot
.71875 .47875 Mdot
.62375 .43125 Mdot
.18375 .38375 Mdot
.62375 .3575 Mdot
.48125 .33375 Mdot
.595 .37625 Mdot
.45 .41375 Mdot
.17625 .48625 Mdot
.5625 .48125 Mdot
.415 .4925 Mdot
.56875 .51125 Mdot
.42125 .51125 Mdot
.40375 .5 Mdot
.78375 .4825 Mdot
.89375 .475 Mdot
.49875 .45375 Mdot
.4575 .49375 Mdot
.75 .54125 Mdot
.905 .55125 Mdot
.8325 .60125 Mdot
.635 .60875 Mdot
.92875 .61875 Mdot
.28 .59625 Mdot
.66375 .57875 Mdot
.8475 .59 Mdot
.12375 .6125 Mdot
.245 .64875 Mdot
.36875 .65125 Mdot
.45 .65875 Mdot
.20125 .62875 Mdot
.70125 .6125 Mdot
.46375 .5975 Mdot
.62625 .5575 Mdot
.58 .55125 Mdot
.55625 .53125 Mdot
.86625 .54875 Mdot
.49 .53875 Mdot
.6175 .54875 Mdot
.48875 .53375 Mdot
.56 .53625 Mdot
.4425 .52375 Mdot
.29375 .52125 Mdot
.65 .48375 Mdot
.4025 .4825 Mdot
.65125 .45125 Mdot
.23375 .44125 Mdot
.68875 .44125 Mdot
.5625 .42875 Mdot
.31375 .39 Mdot
.7325 .44125 Mdot
.60125 .46 Mdot
.2275 .515 Mdot
.65875 .58375 Mdot
.215 .67625 Mdot
.59375 .61625 Mdot
.74 .60375 Mdot
.365 .585 Mdot
.4525 .565 Mdot
.3225 .495 Mdot
.71 .56 Mdot
.58125 .55125 Mdot
.45 .50875 Mdot
.61 .465 Mdot
.11375 .47125 Mdot
.955 .42875 Mdot
.13 .50125 Mdot
.4025 .43375 Mdot
.3375 .35125 Mdot
.24375 .335 Mdot
.605 .3775 Mdot
.47375 .44375 Mdot
.3125 .50125 Mdot
.52125 .57 Mdot
.92875 .565 Mdot
.2525 .52375 Mdot
.36 .5125 Mdot
.52625 .51375 Mdot
.81875 .43125 Mdot
.46875 .41875 Mdot
.29125 .44375 Mdot
.46625 .4525 Mdot
.3675 .43375 Mdot
.78875 .49 Mdot
.52625 .5175 Mdot
.3525 .51625 Mdot
.65875 .47375 Mdot
.52375 .45875 Mdot
.48375 .40375 Mdot
.26375 .3725 Mdot
.78625 .34 Mdot
.2175 .36625 Mdot
.45 .36 Mdot
.4875 .3575 Mdot
.495 .3375 Mdot
.88375 .325 Mdot
.79875 .3125 Mdot
.19 .33125 Mdot
.71 .32875 Mdot
.7825 .34375 Mdot
.57625 .3525 Mdot
.4475 .33875 Mdot
.6275 .3525 Mdot
.11625 .38625 Mdot
.43875 .40875 Mdot
.38 .45125 Mdot
.9825 .50625 Mdot
.32 .50125 Mdot
.64375 .52 Mdot
.185 .5325 Mdot
.9175 .545 Mdot
.51125 .575 Mdot
.43625 .63625 Mdot
.07625 .61375 Mdot
.88 .64375 Mdot
.31625 .68125 Mdot
.6575 .68625 Mdot
.6275 .66 Mdot
.21625 .6625 Mdot
.67 .6425 Mdot
.28125 .615 Mdot
.7825 .605 Mdot
.36625 .57 Mdot
.0775 .54375 Mdot
.64 .58875 Mdot
.3675 .59375 Mdot
.6725 .6 Mdot
.30125 .57375 Mdot
.49625 .58875 Mdot
.67 .505 Mdot
.39125 .4675 Mdot
.44625 .43875 Mdot
.84 .42375 Mdot
.785 .42625 Mdot
.88625 .4075 Mdot
.60125 .44125 Mdot
.99625 .44625 Mdot
.21375 .445 Mdot
.73875 .425 Mdot
.79125 .3725 Mdot
.145 .345 Mdot
.25125 .34375 Mdot
.325 .3425 Mdot
.50125 .4125 Mdot
.16125 .45125 Mdot
.70625 .46375 Mdot
.49625 .48 Mdot
.565 .4975 Mdot
.59875 .5075 Mdot
.53125 .48875 Mdot
.8425 .46875 Mdot
.5325 .45375 Mdot
.53875 .43125 Mdot
.53875 .43125 Mdot
.59875 .41875 Mdot
.385 .41 Mdot
.29 .42 Mdot
.64375 .43 Mdot
.46375 .44375 Mdot
.6725 .45625 Mdot
.17875 .47875 Mdot
.69125 .48375 Mdot
.5175 .545 Mdot
.3625 .59 Mdot
.72875 .555 Mdot
.54625 .51625 Mdot
.36 .49625 Mdot
.53625 .44 Mdot
.26375 .36375 Mdot
.5975 .4475 Mdot
.7675 .4725 Mdot
.315 .46875 Mdot
.39 .46 Mdot
.43 .52875 Mdot
.67625 .47 Mdot
.6275 .53125 Mdot
.38 .55625 Mdot
.59875 .5725 Mdot
.1875 .53625 Mdot
.92125 .5625 Mdot
.1425 .53875 Mdot
.4175 .56625 Mdot
.37 .5925 Mdot
.21125 .5775 Mdot
.615 .5225 Mdot
.4175 .4825 Mdot
.41875 .41625 Mdot
.475 .365 Mdot
.9475 .40375 Mdot
.19875 .4625 Mdot
.38 .48875 Mdot
.56625 .55875 Mdot
.7525 .63375 Mdot
.4975 .65375 Mdot
.30875 .63375 Mdot
.4725 .6 Mdot
.36125 .57125 Mdot
.78375 .54375 Mdot
.535 .53125 Mdot
.31375 .57375 Mdot
.675 .6475 Mdot
.5175 .6725 Mdot
.5675 .7 Mdot
.2025 .70375 Mdot
.725 .725 Mdot
.29125 .695 Mdot
.39125 .66875 Mdot
.5475 .66 Mdot
.5075 .66875 Mdot
.82125 .67 Mdot
.8225 .6775 Mdot
.15125 .68125 Mdot
.7425 .62125 Mdot
.76375 .5425 Mdot
.58125 .48125 Mdot
.43 .44125 Mdot
.66375 .40375 Mdot
.12125 .395 Mdot
.37875 .38375 Mdot
.4075 .37875 Mdot
.99875 .3875 Mdot
.32125 .42625 Mdot
.51625 .4225 Mdot
.345 .43 Mdot
.86 .44875 Mdot
.52375 .47875 Mdot
.42125 .43625 Mdot
.04125 .45375 Mdot
.93625 .465 Mdot
.335 .42125 Mdot
.6125 .39875 Mdot
.6075 .43125 Mdot
.235 .4275 Mdot
.7175 .4275 Mdot
.1525 .46875 Mdot
.925 .46875 Mdot
.28375 .4975 Mdot
.01125 .53375 Mdot
.0575 .52375 Mdot
.735 .47875 Mdot
.2975 .475 Mdot
.72 .45625 Mdot
.22375 .4725 Mdot
.55375 .47375 Mdot
.5475 .55375 Mdot
.28875 .54 Mdot
.46375 .50125 Mdot
.8975 .4725 Mdot
.64625 .41375 Mdot
.90375 .41 Mdot
.50625 .44375 Mdot
.16875 .475 Mdot
.7925 .51375 Mdot
.76875 .575 Mdot
.16125 .58 Mdot
.27625 .6 Mdot
.28 .6075 Mdot
.47875 .53375 Mdot
.19125 .51125 Mdot
.66625 .4775 Mdot
.55 .46625 Mdot
.55625 .46375 Mdot
.55625 .43 Mdot
.55375 .45375 Mdot
.83 .455 Mdot
.5475 .45 Mdot
.50375 .45125 Mdot
.54875 .47125 Mdot
.64 .4575 Mdot
.33125 .4575 Mdot
.315 .47125 Mdot
.61625 .49125 Mdot
.5075 .47 Mdot
.6725 .49 Mdot
.17875 .4475 Mdot
.68 .41 Mdot
.49625 .4475 Mdot
.375 .48375 Mdot
.7975 .5075 Mdot
.39125 .565 Mdot
.52125 .5775 Mdot
.41375 .51875 Mdot
.32125 .4875 Mdot
.61375 .42625 Mdot
.76125 .41 Mdot
.2675 .4225 Mdot
.33 .435 Mdot
.57125 .37125 Mdot
.6475 .3775 Mdot
.6175 .33375 Mdot
.365 .3475 Mdot
.5875 .3925 Mdot
.18875 .45375 Mdot
.92375 .4825 Mdot
.18625 .41 Mdot
.38375 .40875 Mdot
.35875 .43875 Mdot
.26 .45875 Mdot
.6225 .4875 Mdot
.41 .52875 Mdot
.43125 .58 Mdot
.4475 .61375 Mdot
.9575 .5825 Mdot
.215 .56625 Mdot
.33625 .56625 Mdot
.58875 .53 Mdot
.78125 .5275 Mdot
.465 .5225 Mdot
.26375 .4875 Mdot
.535 .46125 Mdot
.36 .4625 Mdot
.76375 .44875 Mdot
.56375 .45625 Mdot
.27875 .44625 Mdot
.665 .4475 Mdot
.5525 .44375 Mdot
.58125 .42 Mdot
.18125 .39375 Mdot
.6575 .38625 Mdot
.375 .39125 Mdot
.37125 .4225 Mdot
.565 .45625 Mdot
.50375 .46375 Mdot
.7975 .445 Mdot
.8075 .425 Mdot
.00375 .37875 Mdot
.11875 .34625 Mdot
.77125 .41625 Mdot
.72625 .48125 Mdot
.5775 .5375 Mdot
.42375 .615 Mdot
.73 .67625 Mdot
.10625 .67875 Mdot
.3025 .71875 Mdot
.4125 .72 Mdot
.95 .6675 Mdot
.33875 .6375 Mdot
.39625 .61 Mdot
.52875 .57 Mdot
.785 .5525 Mdot
.5275 .51625 Mdot
.39375 .50625 Mdot
.06875 .47625 Mdot
.96375 .45375 Mdot
.28875 .4775 Mdot
.645 .4925 Mdot
.56 .48625 Mdot
.255 .51875 Mdot
.76875 .50875 Mdot
.01 .48625 Mdot
.21 .43125 Mdot
.06375 .37375 Mdot
.05 .33125 Mdot
.79 .33375 Mdot
.29875 .32375 Mdot
.72875 .36 Mdot
.125 .41875 Mdot
.645 .42125 Mdot
.35625 .415 Mdot
.2325 .4575 Mdot
.49375 .5075 Mdot
.9075 .5475 Mdot
.55875 .63125 Mdot
.94375 .6375 Mdot
.45875 .59375 Mdot
.15625 .57 Mdot
.8025 .56 Mdot
.7475 .52375 Mdot
.20125 .52 Mdot
.26875 .49 Mdot
.2825 .47125 Mdot
.45875 .4775 Mdot
.2 .46625 Mdot
.66 .46375 Mdot
.58 .4425 Mdot
.55875 .425 Mdot
.50625 .44625 Mdot
.565 .46 Mdot
.81875 .48875 Mdot
.5575 .515 Mdot
.485 .49375 Mdot
.56125 .45625 Mdot
.6575 .4525 Mdot
.31375 .435 Mdot
.31375 .42 Mdot
.575 .41 Mdot
.575 .4625 Mdot
.66 .48 Mdot
.19625 .53625 Mdot
.625 .58 Mdot
.50125 .4775 Mdot
.43375 .37875 Mdot
.83375 .35625 Mdot
.2625 .3325 Mdot
.58625 .35375 Mdot
.35625 .51625 Mdot
.37375 .60375 Mdot
.65375 .65125 Mdot
.70625 .68125 Mdot
.3075 .67875 Mdot
.21625 .685 Mdot
.67 .70625 Mdot
.62875 .68625 Mdot
.6175 .6025 Mdot
.335 .5275 Mdot
.64625 .42 Mdot
.19125 .38375 Mdot
.87625 .36625 Mdot
.25625 .51375 Mdot
.32875 .52 Mdot
.31 .51625 Mdot
.2675 .545 Mdot
.64375 .52625 Mdot
.4175 .48625 Mdot
.4225 .47875 Mdot
.44125 .4725 Mdot
.965 .47875 Mdot
.2175 .4625 Mdot
.31375 .45 Mdot
.5975 .39125 Mdot
.8 .34375 Mdot
.4925 .33125 Mdot
.18875 .3475 Mdot
.55625 .40625 Mdot
.39125 .48875 Mdot
.7125 .525 Mdot
.60875 .52625 Mdot
.2875 .55 Mdot
.63625 .5175 Mdot
.575 .49375 Mdot
.62375 .50875 Mdot
.1 .5525 Mdot
.63875 .54375 Mdot
.45375 .5375 Mdot
.32375 .5425 Mdot
.58 .53125 Mdot
.515 .5275 Mdot
.76 .5725 Mdot
.80625 .61875 Mdot
.03625 .645 Mdot
.11875 .65375 Mdot
.795 .5825 Mdot
.685 .52625 Mdot
.565 .4725 Mdot
.42625 .3875 Mdot
.7775 .355 Mdot
.1075 .34625 Mdot
.23625 .295 Mdot
.41125 .29875 Mdot
.89875 .3575 Mdot
.34625 .395 Mdot
.31375 .415 Mdot
.7 .45875 Mdot
.655 .44625 Mdot
.5975 .4575 Mdot
.355 .46375 Mdot
.12 .4775 Mdot
.91 .48375 Mdot
.31375 .47625 Mdot
.62625 .45625 Mdot
.54375 .40875 Mdot
.28625 .38125 Mdot
.74125 .38375 Mdot
.155 .41 Mdot
.07375 .4525 Mdot
.06125 .5675 Mdot
.78375 .58 Mdot
.375 .6475 Mdot
.66125 .62125 Mdot
.14125 .5475 Mdot
.6575 .49625 Mdot
.23125 .4475 Mdot
.23625 .4525 Mdot
.485 .4375 Mdot
.92 .425 Mdot
.4275 .3975 Mdot
.505 .47875 Mdot
.99875 .46 Mdot
.16125 .43 Mdot
.81125 .39125 Mdot
.73625 .4075 Mdot
.2175 .43625 Mdot
.2675 .4875 Mdot
.24625 .5175 Mdot
.41125 .54 Mdot
.2525 .53625 Mdot
.615 .5725 Mdot
.6025 .6375 Mdot
.60375 .645 Mdot
.445 .6425 Mdot
.55625 .5825 Mdot
.85375 .53 Mdot
.52875 .54375 Mdot
.49125 .57625 Mdot
.55375 .59125 Mdot
.65875 .64 Mdot
.3125 .67375 Mdot
.345 .65875 Mdot
.52 .64 Mdot
.63 .58375 Mdot
.6425 .53375 Mdot
.20875 .5025 Mdot
.61 .49375 Mdot
.4575 .61375 Mdot
.47 .72 Mdot
.87375 .74125 Mdot
.225 .73125 Mdot
.61375 .67625 Mdot
.325 .52375 Mdot
.365 .43125 Mdot
.67875 .39125 Mdot
.7075 .3275 Mdot
.31125 .32 Mdot
.17 .32 Mdot
.73875 .34125 Mdot
.56625 .36625 Mdot
.565 .49625 Mdot
.41125 .56125 Mdot
.62125 .6 Mdot
.31375 .60375 Mdot
.7525 .575 Mdot
.38375 .53125 Mdot
.235 .47125 Mdot
.2 .3675 Mdot
.29625 .375 Mdot
.63875 .3925 Mdot
.4675 .4325 Mdot
.3775 .4275 Mdot
.44375 .4475 Mdot
.95375 .42625 Mdot
.2375 .4275 Mdot
.31 .48625 Mdot
.5975 .59375 Mdot
.8325 .625 Mdot
.465 .61875 Mdot
.1875 .64875 Mdot
.5175 .58 Mdot
.43375 .48625 Mdot
.68375 .4475 Mdot
.62375 .42375 Mdot
.3275 .3925 Mdot
.57125 .385 Mdot
.6075 .38375 Mdot
.69375 .38 Mdot
.005 .365 Mdot
.6025 .38 Mdot
.57375 .4125 Mdot
.245 .42 Mdot
.62 .44875 Mdot
.545 .47625 Mdot
.6675 .44875 Mdot
.79125 .43125 Mdot
.1075 .44875 Mdot
.15375 .48875 Mdot
.745 .5575 Mdot
.6725 .60375 Mdot
.57 .655 Mdot
.40625 .71125 Mdot
.8375 .6975 Mdot
.09625 .6525 Mdot
.185 .6725 Mdot
.415 .66375 Mdot
.85 .635 Mdot
.325 .60875 Mdot
.2725 .58125 Mdot
.84625 .55875 Mdot
.5425 .55125 Mdot
.64375 .5575 Mdot
.32875 .57875 Mdot
.16125 .58375 Mdot
.88625 .57625 Mdot
.2925 .6025 Mdot
.64375 .61875 Mdot
.56375 .65 Mdot
.225 .67125 Mdot
.7375 .70375 Mdot
.055 .74 Mdot
.15875 .7675 Mdot
.0475 .765 Mdot
.13125 .67875 Mdot
.7475 .67875 Mdot
.44 .61875 Mdot
.57 .625 Mdot
.18 .64875 Mdot
.6925 .68 Mdot
.1775 .63125 Mdot
.25375 .6375 Mdot
.56375 .62 Mdot
.83125 .615 Mdot
.29 .53125 Mdot
.475 .4125 Mdot
.9875 .435 Mdot
.1675 .47625 Mdot
.83625 .49375 Mdot
.72 .47375 Mdot
.19625 .43625 Mdot
.31 .38625 Mdot
.21625 .385 Mdot
.38875 .4025 Mdot
.3025 .4225 Mdot
.5625 .43375 Mdot
.61125 .40125 Mdot
.655 .43125 Mdot
.32625 .445 Mdot
.11875 .45375 Mdot
.45375 .48375 Mdot
.8725 .5225 Mdot
.5125 .5025 Mdot
.51375 .50375 Mdot
.54625 .52375 Mdot
.65375 .5275 Mdot
.3 .5175 Mdot
.36875 .5175 Mdot
.505 .5175 Mdot
.63125 .51875 Mdot
.66625 .48 Mdot
.2075 .4475 Mdot
.605 .45125 Mdot
.42875 .355 Mdot
.46375 .30875 Mdot
.86125 .33375 Mdot
.27125 .37 Mdot
.61875 .39 Mdot
.33875 .4875 Mdot
.37 .53125 Mdot
.6475 .555 Mdot
.6675 .6375 Mdot
.37625 .6625 Mdot
.16375 .62875 Mdot
.78 .56875 Mdot
.43 .5125 Mdot
.595 .3775 Mdot
.45125 .35375 Mdot
.595 .3825 Mdot
.39625 .44875 Mdot
.64375 .5025 Mdot
.48875 .61625 Mdot
.10125 .7175 Mdot
.1025 .84375 Mdot
.32625 .8275 Mdot
.63875 .80875 Mdot
.5175 .74875 Mdot
.275 .74375 Mdot
.52625 .71375 Mdot
.9125 .6925 Mdot
.2275 .64875 Mdot
.3325 .54125 Mdot
.57375 .4675 Mdot
.8725 .4475 Mdot
.43 .4525 Mdot
.24 .47375 Mdot
.47375 .54625 Mdot
.4675 .53375 Mdot
.66125 .54625 Mdot
.595 .585 Mdot
.4075 .56875 Mdot
.46 .6 Mdot
.71 .65125 Mdot
.6775 .67 Mdot
.58 .69625 Mdot
.6825 .6675 Mdot
.1475 .65125 Mdot
.66625 .57625 Mdot
.56125 .48875 Mdot
.64 .43375 Mdot
.73625 .39 Mdot
.18 .35875 Mdot
.15 .35 Mdot
.74375 .335 Mdot
.6425 .375 Mdot
.55125 .37125 Mdot
.46375 .345 Mdot
.785 .3575 Mdot
.10875 .4175 Mdot
.20625 .43125 Mdot
.36625 .46375 Mdot
.7675 .495 Mdot
.35625 .47875 Mdot
.205 .47875 Mdot
.9925 .4775 Mdot
.45625 .50875 Mdot
.64875 .52125 Mdot
.30625 .5125 Mdot
.23375 .54125 Mdot
.83625 .54 Mdot
.2525 .52125 Mdot
.6775 .49375 Mdot
.5925 .42875 Mdot
.20625 .39 Mdot
.6675 .38125 Mdot
.16375 .36875 Mdot
.11 .4 Mdot
.07 .39625 Mdot
.16625 .3525 Mdot
.75 .3225 Mdot
.4575 .34 Mdot
.5325 .3275 Mdot
.16625 .3325 Mdot
.74 .325 Mdot
.19875 .39375 Mdot
.3925 .38375 Mdot
.57125 .41125 Mdot
.74625 .43125 Mdot
.16625 .5375 Mdot
.5325 .565 Mdot
.90875 .56625 Mdot
.185 .635 Mdot
.85125 .665 Mdot
.73 .69 Mdot
.1625 .69625 Mdot
.3725 .69875 Mdot
.17375 .6325 Mdot
.355 .5925 Mdot
.3775 .5775 Mdot
.475 .54625 Mdot
.65125 .555 Mdot
.6975 .52375 Mdot
.21125 .5075 Mdot
.265 .51125 Mdot
.365 .525 Mdot
.8825 .515 Mdot
.49 .49875 Mdot
.5525 .48 Mdot
.54375 .42375 Mdot
.6175 .3875 Mdot
.32875 .37875 Mdot
.385 .39875 Mdot
.51 .42875 Mdot
.555 .47 Mdot
.74375 .5425 Mdot
.18125 .5825 Mdot
.58375 .53 Mdot
.4975 .4875 Mdot
.38625 .47 Mdot
.9075 .38875 Mdot
.25625 .35625 Mdot
.6425 .4075 Mdot
.29625 .4125 Mdot
.3725 .4275 Mdot
.67375 .45 Mdot
.66125 .42125 Mdot
.3575 .44 Mdot
.19625 .515 Mdot
.83375 .56125 Mdot
.285 .61875 Mdot
.62875 .66 Mdot
.51125 .635 Mdot
.5625 .59875 Mdot
.45875 .565 Mdot
.56 .555 Mdot
.555 .29875 Mdot
.01125 .275 Mdot
.07875 .30375 Mdot
.33 .31625 Mdot
.62875 .3 Mdot
.57375 .32125 Mdot
.1825 .26 Mdot
.59625 .22875 Mdot
.865 .2725 Mdot
.25875 .34125 Mdot
.3275 .41875 Mdot
.5525 .4825 Mdot
.9175 .56625 Mdot
.4125 .59375 Mdot
.2375 .55375 Mdot
.45375 .5025 Mdot
.5325 .5275 Mdot
.5825 .50875 Mdot
.55625 .46125 Mdot
.56125 .46875 Mdot
.3075 .4525 Mdot
.7925 .425 Mdot
.6675 .38375 Mdot
.5675 .3875 Mdot
.7775 .4075 Mdot
.05625 .43875 Mdot
.71625 .52 Mdot
.55125 .5775 Mdot
.62 .64875 Mdot
.695 .7225 Mdot
.2475 .72625 Mdot
.14375 .70375 Mdot
.75 .6825 Mdot
.605 .60375 Mdot
.545 .5325 Mdot
.49375 .5125 Mdot
.7625 .4975 Mdot
.10875 .49875 Mdot
.22375 .48625 Mdot
.335 .46375 Mdot
.71 .44625 Mdot
.36625 .46875 Mdot
.18625 .49875 Mdot
.38375 .5 Mdot
.67 .47625 Mdot
.2975 .46375 Mdot
.25125 .405 Mdot
.8225 .41125 Mdot
.205 .415 Mdot
.69 .4225 Mdot
.68 .45875 Mdot
.135 .50125 Mdot
.63375 .4625 Mdot
.23 .415 Mdot
.13875 .33625 Mdot
.03375 .3325 Mdot
.15625 .44625 Mdot
.75375 .485 Mdot
.49 .51 Mdot
.53875 .52625 Mdot
.155 .51625 Mdot
.755 .52375 Mdot
.95 .56875 Mdot
.23125 .61 Mdot
.8825 .65 Mdot
.57 .6375 Mdot
.55875 .59625 Mdot
.65125 .615 Mdot
.00875 .61875 Mdot
.10875 .56125 Mdot
.60375 .54125 Mdot
.79875 .53625 Mdot
.25375 .44625 Mdot
.835 .4225 Mdot
.73625 .43125 Mdot
.1225 .455 Mdot
.425 .47375 Mdot
.1375 .5275 Mdot
.32 .585 Mdot
.4625 .59 Mdot
.34625 .57875 Mdot
.75875 .48625 Mdot
.635 .50625 Mdot
.2025 .49375 Mdot
.37375 .465 Mdot
.315 .475 Mdot
.83625 .5375 Mdot
.49625 .52 Mdot
.55625 .51875 Mdot
.545 .58125 Mdot
.63625 .56375 Mdot
.33 .57625 Mdot
.3875 .5575 Mdot
.50625 .53625 Mdot
.495 .48375 Mdot
.83625 .4925 Mdot
.1525 .46875 Mdot
.51875 .50125 Mdot
.5725 .5575 Mdot
.335 .5625 Mdot
.92375 .55 Mdot
.295 .52125 Mdot
.5875 .4925 Mdot
.35 .4525 Mdot
.385 .41 Mdot
.5925 .39 Mdot
.67125 .42125 Mdot
.39 .415 Mdot
.295 .35375 Mdot
.7625 .39375 Mdot
.15 .44125 Mdot
.72625 .48625 Mdot
.54375 .47375 Mdot
.5025 .49875 Mdot
.58875 .4425 Mdot
.4475 .38125 Mdot
.58375 .6175 Mdot
.05875 .465 Mdot
.32125 .45875 Mdot
.63375 .4825 Mdot
.57125 .5375 Mdot
.175 .63 Mdot
.61875 .65375 Mdot
.8325 .61125 Mdot
.2675 .58875 Mdot
.34125 .51 Mdot
.555 .38125 Mdot
.89125 .3 Mdot
.4375 .2775 Mdot
.2725 .28125 Mdot
.3975 .34 Mdot
.60375 .41125 Mdot
.49 .48125 Mdot
.52 .52125 Mdot
.7275 .5725 Mdot
.16 .56625 Mdot
.85375 .5625 Mdot
.66875 .56875 Mdot
.57625 .51 Mdot
.83625 .5075 Mdot
.775 .46625 Mdot
.55125 .49 Mdot
.55625 .4925 Mdot
.7275 .44375 Mdot
.26125 .47375 Mdot
.14625 .45625 Mdot
.765 .465 Mdot
.56 .53 Mdot
.56625 .59625 Mdot
.50625 .6075 Mdot
.73375 .63 Mdot
.09875 .605 Mdot
.2775 .56125 Mdot
.3175 .55 Mdot
.68625 .51375 Mdot
.34875 .51 Mdot
.19875 .52 Mdot
.32125 .5375 Mdot
.67625 .5575 Mdot
.32875 .57125 Mdot
.255 .55125 Mdot
.76625 .5225 Mdot
.225 .505 Mdot
.665 .5375 Mdot
.77625 .57375 Mdot
.06625 .61625 Mdot
.57125 .69875 Mdot
.34 .7675 Mdot
.12875 .82 Mdot
.01875 .79375 Mdot
.2 .70125 Mdot
.74 .69 Mdot
.49375 .6075 Mdot
.54875 .59625 Mdot
.15875 .57625 Mdot
.76875 .54 Mdot
.87625 .47375 Mdot
.33875 .40375 Mdot
.6825 .385 Mdot
.68875 .375 Mdot
.5675 .34625 Mdot
.58 .3325 Mdot
.13625 .34625 Mdot
.00125 .38 Mdot
.73625 .42375 Mdot
.67875 .40875 Mdot
.32375 .45125 Mdot
.8075 .44625 Mdot
.77625 .43125 Mdot
.04625 .43625 Mdot
.49875 .455 Mdot
.10375 .4575 Mdot
.275 .4275 Mdot
.61875 .41875 Mdot
.15375 .4125 Mdot
.8975 .47875 Mdot
.5575 .44125 Mdot
.195 .47 Mdot
.48625 .48 Mdot
.23625 .465 Mdot
.83 .4025 Mdot
.51125 .43875 Mdot
.53125 .39625 Mdot
.5575 .35125 Mdot
.62125 .3725 Mdot
.36625 .3925 Mdot
.3825 .39875 Mdot
.52125 .43125 Mdot
.445 .48375 Mdot
.89625 .4325 Mdot
.14 .45375 Mdot
.4675 .49125 Mdot
.59875 .51 Mdot
.30125 .52625 Mdot
.94625 .68 Mdot
.3425 .71 Mdot
.53875 .675 Mdot
.38375 .67375 Mdot
.42625 .71 Mdot
.46125 .6325 Mdot
.70375 .56375 Mdot
.43125 .545 Mdot
.38125 .56875 Mdot
.6775 .4875 Mdot
.0825 .44625 Mdot
.8275 .41875 Mdot
.52875 .4575 Mdot
.4425 .46625 Mdot
.64125 .5475 Mdot
.42375 .59125 Mdot
.57 .50125 Mdot
.06375 .5425 Mdot
.3425 .51625 Mdot
.6125 .535 Mdot
.55875 .47125 Mdot
.175 .43 Mdot
.6375 .46625 Mdot
.80875 .53125 Mdot
.25125 .54875 Mdot
.4025 .635 Mdot
.5425 .74125 Mdot
.87875 .745 Mdot
.41625 .7525 Mdot
.315 .77125 Mdot
.37375 .755 Mdot
.59875 .69375 Mdot
.465 .66 Mdot
.5275 .64125 Mdot
.76 .565 Mdot
.13125 .5075 Mdot
.8525 .47625 Mdot
.68375 .46375 Mdot
.5525 .47625 Mdot
.87625 .495 Mdot
.815 .49625 Mdot
.52125 .4775 Mdot
.515 .4825 Mdot
.77375 .5025 Mdot
.255 .4875 Mdot
.13125 .5075 Mdot
.79375 .4825 Mdot
.50375 .40875 Mdot
.5975 .38 Mdot
.53875 .3675 Mdot
.7025 .36875 Mdot
.08 .38875 Mdot
.30625 .42125 Mdot
.34625 .41 Mdot
.66875 .41375 Mdot
.3425 .43125 Mdot
.2025 .42625 Mdot
.2925 .4725 Mdot
.64875 .44625 Mdot
.37625 .44625 Mdot
.24 .50875 Mdot
.72 .52375 Mdot
.22875 .525 Mdot
.6825 .505 Mdot
.85 .48875 Mdot
.00875 .4225 Mdot
.55625 .34625 Mdot
.37 .30125 Mdot
.14625 .2675 Mdot
.0325 .29125 Mdot
.24375 .32 Mdot
.72625 .295 Mdot
.48375 .385 Mdot
.5575 .40625 Mdot
.17625 .44375 Mdot
.74125 .49375 Mdot
.84875 .52 Mdot
.03375 .5075 Mdot
.375 .50875 Mdot
.545 .50875 Mdot
.735 .5225 Mdot
.665 .53 Mdot
.41375 .4925 Mdot
.265 .46875 Mdot
.75875 .46 Mdot
.61625 .50125 Mdot
.3975 .4825 Mdot
.7475 .48625 Mdot
.805 .51 Mdot
.0225 .49 Mdot
.53375 .475 Mdot
.11125 .46125 Mdot
.28375 .42375 Mdot
.6775 .445 Mdot
.0625 .435 Mdot
1 .475 Mdot
.445 .47375 Mdot
.185 .51 Mdot
.7 .5125 Mdot
.09125 .55 Mdot
.81125 .53625 Mdot
.5275 .54875 Mdot
.53 .60125 Mdot
.57875 .63625 Mdot
.58625 .66375 Mdot
.41875 .6575 Mdot
.32375 .67875 Mdot
.55875 .6475 Mdot
.42125 .62125 Mdot
.91375 .6225 Mdot
.1725 .60125 Mdot
.37375 .565 Mdot
.6725 .57 Mdot
.2975 .56625 Mdot
.92625 .4125 Mdot
.35 .40625 Mdot
.4625 .44875 Mdot
.46875 .41125 Mdot
.51125 .31875 Mdot
.295 .39625 Mdot
.7625 .4425 Mdot
.42 .3875 Mdot
.49375 .36625 Mdot
.55375 .47 Mdot
.06875 .49875 Mdot
.95 .505 Mdot
.48125 .54375 Mdot
.41125 .58125 Mdot
.61875 .5325 Mdot
.4525 .53125 Mdot
.53125 .36625 Mdot
.00375 .3575 Mdot
.11375 .37625 Mdot
.3525 .3925 Mdot
.62125 .3975 Mdot
.525 .43875 Mdot
.18625 .45625 Mdot
.63375 .43125 Mdot
.85375 .40875 Mdot
.17375 .39875 Mdot
.41625 .395 Mdot
.57625 .3925 Mdot
.8475 .4225 Mdot
.40625 .4175 Mdot
.365 .405 Mdot
.3675 .36875 Mdot
.61625 .37 Mdot
.39625 .335 Mdot
.56375 .33 Mdot
.75375 .35625 Mdot
.1425 .4075 Mdot
.85625 .43 Mdot
.65125 .4875 Mdot
.51375 .51 Mdot
.91375 .4975 Mdot
.85375 .44875 Mdot
.4975 .45625 Mdot
.47125 .41 Mdot
.825 .38125 Mdot
.24125 .36 Mdot
.10125 .385 Mdot
.89125 .4175 Mdot
.36 .465 Mdot
.68375 .5075 Mdot
.5775 .54625 Mdot
.6475 .54625 Mdot
.05875 .5275 Mdot
.36875 .5375 Mdot
.325 .54 Mdot
.62375 .5575 Mdot
.38 .54125 Mdot
.18625 .52125 Mdot
.28 .41125 Mdot
.61875 .42125 Mdot
.38125 .4 Mdot
.28875 .395 Mdot
.65125 .425 Mdot
.2475 .46 Mdot
.69125 .47 Mdot
.895 .49375 Mdot
.53375 .57875 Mdot
.395 .60375 Mdot
.14625 .58375 Mdot
.05375 .5775 Mdot
.96875 .52 Mdot
.27125 .5525 Mdot
.7125 .57 Mdot
.54875 .53625 Mdot
.53875 .51 Mdot
.16 .49625 Mdot
.725 .45 Mdot
.83 .40875 Mdot
.07125 .44875 Mdot
.4075 .46375 Mdot
.46875 .46125 Mdot
.75125 .4725 Mdot
.74875 .57 Mdot
.29375 .6175 Mdot
.34 .64625 Mdot
.85 .5925 Mdot
.53125 .51375 Mdot
.41 .53 Mdot
.735 .52125 Mdot
.8275 .48375 Mdot
.02875 .48375 Mdot
.50875 .46625 Mdot
.15875 .44625 Mdot
.2825 .4925 Mdot
.70125 .47375 Mdot
.06375 .53 Mdot
.3625 .56 Mdot
.19625 .49625 Mdot
.76625 .4825 Mdot
.07 .435 Mdot
.80375 .4525 Mdot
.49375 .43375 Mdot
.56375 .4375 Mdot
.59375 .4275 Mdot
.545 .395 Mdot
.4525 .36375 Mdot
.31625 .34375 Mdot
.535 .36625 Mdot
.46375 .38875 Mdot
.86875 .42125 Mdot
.22875 .4275 Mdot
.255 .435 Mdot
.78875 .39125 Mdot
.285 .3825 Mdot
.86375 .4575 Mdot
.415 .495 Mdot
.45 .495 Mdot
.44 .5725 Mdot
.58 .6475 Mdot
.175 .62625 Mdot
.81875 .625 Mdot
.42375 .62 Mdot
.5575 .61 Mdot
.40375 .56125 Mdot
.1925 .52625 Mdot
.96 .52875 Mdot
.4225 .5025 Mdot
.4425 .44875 Mdot
.6225 .41375 Mdot
.45875 .38875 Mdot
.47125 .64125 Mdot
.065 .655 Mdot
.17 .66375 Mdot
.3325 .66375 Mdot
.63 .655 Mdot
.47875 .62125 Mdot
.26 .61 Mdot
.54 .58 Mdot
.92625 .545 Mdot
.17125 .5125 Mdot
.4125 .4825 Mdot
.56625 .47 Mdot
.84125 .4675 Mdot
.415 .48625 Mdot
.35125 .47375 Mdot
.37625 .46125 Mdot
.6325 .4425 Mdot
.31625 .41125 Mdot
.64 .41375 Mdot
.71625 .41 Mdot
.19875 .42375 Mdot
.8025 .42 Mdot
.64625 .43875 Mdot
.0175 .425 Mdot
.49875 .44375 Mdot
.95 .46625 Mdot
.8675 .47 Mdot
.47375 .46875 Mdot
.425 .4725 Mdot
.90625 .46125 Mdot
.2125 .48125 Mdot
.12 .4725 Mdot
.8975 .44875 Mdot
.29 .475 Mdot
.73 .4825 Mdot
.61375 .48875 Mdot
.64 .4975 Mdot
.45875 .58625 Mdot
.29875 .61 Mdot
.005 .6225 Mdot
.52 .5875 Mdot
.4575 .5525 Mdot
.195 .5525 Mdot
.28125 .6025 Mdot
.595 .6075 Mdot
.39125 .62 Mdot
.35875 .59125 Mdot
.53625 .5525 Mdot
.345 .50875 Mdot
.59 .4825 Mdot
.9975 .46875 Mdot
.52375 .46875 Mdot
.44 .465 Mdot
.1575 .5075 Mdot
.06375 .50625 Mdot
.91 .5475 Mdot
.3675 .5475 Mdot
.6325 .53625 Mdot
.58625 .545 Mdot
.5275 .51 Mdot
.24 .485 Mdot
.62875 .5275 Mdot
.84 .56 Mdot
.0675 .55625 Mdot
.41 .58875 Mdot
.52375 .62875 Mdot
.6675 .5975 Mdot
.86625 .51875 Mdot
.15375 .4775 Mdot
.4125 .43875 Mdot
.99625 .44875 Mdot
.95625 .52375 Mdot
.405 .595 Mdot
.47625 .56625 Mdot
.6975 .59125 Mdot
.83625 .57625 Mdot
.045 .54375 Mdot
.49375 .5175 Mdot
.23 .54125 Mdot
.93125 .48 Mdot
.34375 .49 Mdot
.655 .4925 Mdot
.1175 .45125 Mdot
.335 .39 Mdot
.19125 .40875 Mdot
.8225 .43125 Mdot
.0325 .46 Mdot
.83125 .5175 Mdot
.41875 .52125 Mdot
.62375 .52625 Mdot
.58625 .53125 Mdot
.5625 .555 Mdot
.42625 .55625 Mdot
.30125 .555 Mdot
.5125 .50875 Mdot
.5375 .46625 Mdot
.825 .4375 Mdot
.275 .45125 Mdot
.1475 .44375 Mdot
.8425 .47875 Mdot
.34 .49375 Mdot
.80625 .4225 Mdot
.4425 .3525 Mdot
.375 .32125 Mdot
.54 .2625 Mdot
.63 .285 Mdot
.02125 .35875 Mdot
.8475 .3925 Mdot
.49 .445 Mdot
.5725 .49625 Mdot
.285 .475 Mdot
.3075 .4975 Mdot
.9725 .52625 Mdot
.3425 .53875 Mdot
.4825 .5675 Mdot
.5875 .60375 Mdot
.5075 .62 Mdot
.41375 .4575 Mdot
.12375 .46 Mdot
.23625 .4375 Mdot
.34375 .42625 Mdot
.61125 .41375 Mdot
.44125 .4275 Mdot
.325 .44875 Mdot
.4925 .4975 Mdot
.9525 .535 Mdot
.1275 .56875 Mdot
.4925 .56875 Mdot
.5275 .51 Mdot
.83375 .4625 Mdot
.3975 .43 Mdot
.38125 .43875 Mdot
.33875 .46625 Mdot
.67125 .5275 Mdot
.2575 .5975 Mdot
.71125 .6275 Mdot
.64875 .67 Mdot
.26875 .69625 Mdot
.7775 .72875 Mdot
.6225 .6875 Mdot
.0525 .705 Mdot
.48375 .67 Mdot
.9475 .62125 Mdot
.86125 .64 Mdot
.46875 .605 Mdot
.38875 .61625 Mdot
.95625 .6475 Mdot
.21 .645 Mdot
.13125 .60125 Mdot
.90875 .5975 Mdot
.18125 .54875 Mdot
.82375 .49625 Mdot
.64 .435 Mdot
.6075 .45375 Mdot
.5075 .39625 Mdot
.3175 .395 Mdot
.115 .38625 Mdot
.40125 .4175 Mdot
.50875 .45875 Mdot
.2525 .475 Mdot
.3325 .455 Mdot
.50125 .42625 Mdot
.45625 .41375 Mdot
.44 .40875 Mdot
.405 .44 Mdot
.42375 .4925 Mdot
.535 .51625 Mdot
.54875 .485 Mdot
.4825 .48375 Mdot
.9925 .4825 Mdot
.16625 .48875 Mdot
.0775 .47875 Mdot
.84625 .445 Mdot
.48 .44375 Mdot
.5375 .46875 Mdot
.67 .47875 Mdot
.455 .5475 Mdot
.30125 .62 Mdot
.5575 .585 Mdot
.87875 .55625 Mdot
.06875 .545 Mdot
.3775 .485 Mdot
.59375 .41125 Mdot
.57875 .4325 Mdot
.97625 .45 Mdot
.0425 .42625 Mdot
.5075 .4525 Mdot
.94875 .4875 Mdot
.33 .46 Mdot
.49 .47 Mdot
.67375 .46375 Mdot
.86625 .46625 Mdot
.04875 .52375 Mdot
.445 .575 Mdot
.3825 .59125 Mdot
.68 .6025 Mdot
.525 .63125 Mdot
.575 .6425 Mdot
.21875 .665 Mdot
.9125 .72125 Mdot
.3825 .69375 Mdot
.2175 .63625 Mdot
.85125 .61625 Mdot
.8475 .50625 Mdot
.385 .51875 Mdot
.68625 .53 Mdot
.56 .52875 Mdot
.53125 .5275 Mdot
.47625 .54125 Mdot
.2825 .56375 Mdot
.4725 .59 Mdot
.6025 .605 Mdot
.7825 .61375 Mdot
.28 .60125 Mdot
.145 .5775 Mdot
.83 .53 Mdot
.395 .5025 Mdot
.7325 .6025 Mdot
.5025 .67125 Mdot
.3675 .70375 Mdot
.53875 .77 Mdot
.665 .7525 Mdot
.8725 .58875 Mdot
.47375 .545 Mdot
.575 .50625 Mdot
.27375 .52375 Mdot
.3525 .4575 Mdot
.9675 .40625 Mdot
.31125 .40375 Mdot
.52875 .38625 Mdot
.4925 .38625 Mdot
.6025 .4325 Mdot
.33875 .4525 Mdot
.175 .475 Mdot
.30875 .52125 Mdot
.3225 .53375 Mdot
.57375 .54875 Mdot
.4375 .53875 Mdot
.37625 .4875 Mdot
.4625 .455 Mdot
.95625 .465 Mdot
.1075 .4625 Mdot
.53875 .4825 Mdot
.50375 .58 Mdot
.80125 .645 Mdot
.41875 .65625 Mdot
.405 .6475 Mdot
.28625 .63625 Mdot
.755 .58375 Mdot
.18125 .555 Mdot
.755 .52875 Mdot
.62 .5075 Mdot
.32 .465 Mdot
.7375 .415 Mdot
.60625 .39625 Mdot
.0875 .38 Mdot
.46375 .39375 Mdot
.9575 .4275 Mdot
.87 .42375 Mdot
.42375 .43375 Mdot
.3925 .41 Mdot
.965 .41 Mdot
.25 .41 Mdot
.15125 .445 Mdot
.87625 .46875 Mdot
.08625 .51 Mdot
.9125 .52125 Mdot
.70625 .565 Mdot
.5 .54 Mdot
.00875 .5275 Mdot
.55125 .51375 Mdot
.29625 .51625 Mdot
.24125 .49125 Mdot
.24375 .49125 Mdot
.6125 .49375 Mdot
.26875 .47625 Mdot
.36375 .50875 Mdot
.42 .535 Mdot
.51 .5425 Mdot
.47875 .57 Mdot
.33 .5325 Mdot
.48625 .48875 Mdot
.46875 .46 Mdot
.58125 .4375 Mdot
.53875 .43375 Mdot
.87125 .41125 Mdot
.24375 .3975 Mdot
.0825 .41875 Mdot
.76625 .45 Mdot
.59125 .4475 Mdot
.46125 .4325 Mdot
.70125 .4275 Mdot
.44625 .39875 Mdot
.35625 .3525 Mdot
.47 .3775 Mdot
.91375 .39875 Mdot
.0625 .405 Mdot
.3625 .42375 Mdot
.65125 .46125 Mdot
.47875 .4625 Mdot
.56625 .51 Mdot
.91 .48125 Mdot
.265 .41875 Mdot
.5325 .4225 Mdot
.64875 .375 Mdot
.885 .4025 Mdot
.05625 .40375 Mdot
.40125 .39125 Mdot
.5025 .415 Mdot
.515 .4675 Mdot
.655 .43 Mdot
.42 .375 Mdot
.37875 .36875 Mdot
.8125 .37125 Mdot
.385 .37875 Mdot
.31875 .46125 Mdot
.8 .53375 Mdot
.795 .5875 Mdot
.39125 .5675 Mdot
.74125 .54125 Mdot
.5375 .52 Mdot
.4975 .505 Mdot
.52125 .5 Mdot
.2825 .47375 Mdot
.43625 .465 Mdot
.62875 .475 Mdot
.765 .475 Mdot
.28375 .47375 Mdot
.15125 .52625 Mdot
.835 .58125 Mdot
.42375 .59375 Mdot
.65625 .54125 Mdot
.53 .51 Mdot
.3925 .48 Mdot
.525 .4225 Mdot
.69125 .41125 Mdot
.8775 .475 Mdot
.45875 .53125 Mdot
.565 .56375 Mdot
.28125 .565 Mdot
.405 .6225 Mdot
.915 .65625 Mdot
.30625 .59625 Mdot
.5775 .5575 Mdot
.44375 .53125 Mdot
.66375 .4625 Mdot
.28625 .54 Mdot
.225 .50375 Mdot
.385 .44 Mdot
.31 .3975 Mdot
.55 .3875 Mdot
.4325 .415 Mdot
.4 .45 Mdot
.4575 .45875 Mdot
.93125 .4725 Mdot
.1275 .50125 Mdot
.5725 .49875 Mdot
.4525 .445 Mdot
.7675 .44125 Mdot
.4 .43125 Mdot
.5625 .43125 Mdot
.19625 .45375 Mdot
.77375 .48875 Mdot
.13375 .5025 Mdot
.7725 .5125 Mdot
.67625 .50875 Mdot
.27 .48875 Mdot
.745 .505 Mdot
.595 .525 Mdot
.10875 .525 Mdot
.425 .50375 Mdot
.845 .45125 Mdot
.44375 .4725 Mdot
.38875 .53375 Mdot
.9275 .565 Mdot
.33 .59375 Mdot
.1325 .565 Mdot
.845 .5475 Mdot
.02375 .48875 Mdot
.96875 .46625 Mdot
.7575 .43875 Mdot
.415 .4475 Mdot
.0625 .46 Mdot
.6075 .4875 Mdot
.25125 .5025 Mdot
.3825 .5175 Mdot
.11875 .51375 Mdot
.7 .48375 Mdot
.27125 .485 Mdot
.39 .46125 Mdot
.30375 .44125 Mdot
.595 .4775 Mdot
.51875 .4725 Mdot
.25875 .54875 Mdot
.54 .56375 Mdot
.43875 .565 Mdot
.5975 .54125 Mdot
.59125 .5475 Mdot
.81125 .59625 Mdot
.29375 .595 Mdot
.07375 .58625 Mdot
.69875 .5975 Mdot
.6625 .6075 Mdot
.42375 .61125 Mdot
.735 .61875 Mdot
.38625 .60375 Mdot
.45125 .6 Mdot
.4175 .57625 Mdot
.89125 .56 Mdot
.055 .535 Mdot
.3925 .54375 Mdot
.66625 .53 Mdot
.4275 .51125 Mdot
.5475 .51875 Mdot
.8575 .49625 Mdot
.19125 .5325 Mdot
.5525 .565 Mdot
.6475 .6575 Mdot
.90625 .67125 Mdot
.06625 .70625 Mdot
.3625 .68625 Mdot
.565 .63 Mdot
.4475 .6 Mdot
.67625 .61 Mdot
.39625 .58875 Mdot
.42375 .56125 Mdot
.775 .59875 Mdot
.3425 .55625 Mdot
.5 .51375 Mdot
.5975 .4375 Mdot
.1075 .45875 Mdot
.725 .42 Mdot
.3925 .42 Mdot
.79 .36875 Mdot
.4825 .39125 Mdot
.525 .41875 Mdot
.525 .43 Mdot
.29875 .4425 Mdot
.44875 .48375 Mdot
.59 .44375 Mdot
.7725 .435 Mdot
.27125 .4225 Mdot
.1975 .38625 Mdot
.79375 .36125 Mdot
.4375 .39875 Mdot
.6575 .39375 Mdot
.4975 .4175 Mdot
.47375 .4425 Mdot
.445 .48125 Mdot
.72125 .5125 Mdot
.8475 .4675 Mdot
.49875 .45875 Mdot
.54125 .41375 Mdot
.26875 .38 Mdot
.445 .3725 Mdot
.88125 .405 Mdot
.3175 .435 Mdot
.5675 .49375 Mdot
.49125 .54 Mdot
.65625 .585 Mdot
.28875 .55125 Mdot
.21125 .5775 Mdot
.42375 .60875 Mdot
.3125 .66125 Mdot
.52 .66375 Mdot
.43125 .63875 Mdot
.43875 .61375 Mdot
.43125 .62625 Mdot
.8875 .57875 Mdot
.205 .53 Mdot
.58375 .47875 Mdot
.43875 .46125 Mdot
.70875 .39375 Mdot
.37625 .3575 Mdot
.64 .35875 Mdot
.165 .36625 Mdot
.77125 .35375 Mdot
.15 .36625 Mdot
.73875 .40625 Mdot
.76 .40875 Mdot
.21375 .4325 Mdot
.74 .45125 Mdot
.56 .455 Mdot
.13625 .45 Mdot
.4475 .46875 Mdot
.78875 .525 Mdot
.4575 .52125 Mdot
.39125 .47625 Mdot
.9175 .4425 Mdot
.385 .42 Mdot
.125 .47 Mdot
.7875 .51125 Mdot
.0425 .585 Mdot
.9625 .605 Mdot
.8125 .64625 Mdot
.315 .6575 Mdot
.15625 .62625 Mdot
.59125 .59 Mdot
.2625 .57375 Mdot
.96625 .55 Mdot
.52125 .535 Mdot
0 .53 Mdot
.7675 .56625 Mdot
.2825 .5725 Mdot
.39375 .61 Mdot
.23875 .6325 Mdot
.715 .58875 Mdot
.46125 .59875 Mdot
.225 .54125 Mdot
.58875 .53375 Mdot
.38875 .56 Mdot
.6175 .53875 Mdot
.615 .50125 Mdot
.7525 .44125 Mdot
.35 .425 Mdot
.08375 .4075 Mdot
.6125 .4025 Mdot
.7425 .38125 Mdot
.3875 .37625 Mdot
.76125 .375 Mdot
.325 .4125 Mdot
.5525 .4275 Mdot
.36125 .46125 Mdot
.8625 .47875 Mdot
.09875 .51625 Mdot
.39125 .5025 Mdot
.63375 .50625 Mdot
.435 .53625 Mdot
.55125 .5475 Mdot
.86625 .5825 Mdot
.08375 .5325 Mdot
.59375 .48375 Mdot
.62125 .41875 Mdot
.92375 .41375 Mdot
.1075 .34 Mdot
.32375 .38625 Mdot
.565 .42875 Mdot
.4525 .43875 Mdot
.675 .39625 Mdot
.40125 .47125 Mdot
.39 .44875 Mdot
.7975 .4125 Mdot
.27875 .4375 Mdot
.71875 .47625 Mdot
.39375 .46625 Mdot
.185 .4425 Mdot
.64375 .45 Mdot
.45125 .4625 Mdot
.8025 .4975 Mdot
.43375 .495 Mdot
.585 .47 Mdot
.45625 .4775 Mdot
.36875 .475 Mdot
.455 .47125 Mdot
.53375 .545 Mdot
.7925 .5875 Mdot
.255 .625 Mdot
.26125 .68875 Mdot
.74875 .71625 Mdot
.4675 .68875 Mdot
.63375 .71625 Mdot
.465 .6825 Mdot
.50625 .62 Mdot
.44625 .58625 Mdot
.69125 .55 Mdot
.815 .5725 Mdot
.49125 .54 Mdot
.57125 .55875 Mdot
.29875 .58125 Mdot
.4025 .55375 Mdot
.85125 .49625 Mdot
.37375 .5375 Mdot
.5275 .52125 Mdot
.525 .50375 Mdot
.65125 .49375 Mdot
.29125 .4475 Mdot
.1925 .40125 Mdot
.44125 .39875 Mdot
.32625 .39875 Mdot
.48875 .4125 Mdot
.43625 .43375 Mdot
.45125 .4625 Mdot
.44625 .44125 Mdot
.84 .44 Mdot
.25 .4375 Mdot
.58 .45 Mdot
.4625 .42 Mdot
.645 .46375 Mdot
.35875 .54875 Mdot
.7125 .555 Mdot
.13125 .53625 Mdot
.7975 .56625 Mdot
.15875 .545 Mdot
.6775 .45875 Mdot
.805 .44 Mdot
.23 .46375 Mdot
.705 .48 Mdot
.54625 .46875 Mdot
.145 .48125 Mdot
.48375 .50875 Mdot
.955 .47625 Mdot
.74375 .50125 Mdot
.52375 .51375 Mdot
.34125 .5325 Mdot
.92875 .53875 Mdot
.4425 .51875 Mdot
.07625 .47875 Mdot
.7675 .41 Mdot
.04 .325 Mdot
.965 .3 Mdot
.875 .25625 Mdot
.19 .19625 Mdot
.30625 .2225 Mdot
.49125 .25625 Mdot
.33625 .255 Mdot
.83 .30875 Mdot
.64375 .37875 Mdot
.74875 .425 Mdot
.31 .49 Mdot
.3975 .455 Mdot
.19 .4375 Mdot
.80375 .42875 Mdot
.39125 .3725 Mdot
.23125 .395 Mdot
.60875 .42125 Mdot
.39875 .43625 Mdot
.66875 .5375 Mdot
.61375 .57375 Mdot
.70375 .60875 Mdot
.41 .6625 Mdot
.0675 .69875 Mdot
.57 .68625 Mdot
.8025 .6925 Mdot
.335 .6375 Mdot
.8375 .57 Mdot
.215 .51625 Mdot
.64875 .45625 Mdot
.31625 .39875 Mdot
.85 .40875 Mdot
.1375 .38375 Mdot
.39 .405 Mdot
.57875 .41875 Mdot
.47 .445 Mdot
.55 .46625 Mdot
.9525 .42375 Mdot
.04875 .44125 Mdot
.6075 .46 Mdot
.5875 .5 Mdot
.975 .48625 Mdot
.1225 .4675 Mdot
.26375 .45375 Mdot
.55125 .4175 Mdot
.50125 .43125 Mdot
.645 .4775 Mdot
.43125 .54 Mdot
.37375 .57125 Mdot
.8125 .6225 Mdot
.155 .6025 Mdot
.9625 .5825 Mdot
.2125 .59625 Mdot
.24625 .60125 Mdot
.5575 .61625 Mdot
.5575 .59375 Mdot
.7675 .6075 Mdot
.4125 .56875 Mdot
.63 .53875 Mdot
.3575 .52 Mdot
.53875 .5425 Mdot
.37625 .5 Mdot
.49625 .4625 Mdot
.80125 .47375 Mdot
.20875 .45375 Mdot
.41625 .37625 Mdot
.6275 .385 Mdot
.52375 .405 Mdot
.62375 .3625 Mdot
.41375 .355 Mdot
.52375 .42125 Mdot
.465 .39625 Mdot
.6825 .40125 Mdot
.78375 .4625 Mdot
.49875 .4875 Mdot
.59625 .49 Mdot
.2875 .48 Mdot
.38375 .51 Mdot
.8325 .4825 Mdot
.41 .46375 Mdot
.53125 .47125 Mdot
.53375 .47 Mdot
.63625 .44875 Mdot
.30375 .5625 Mdot
.19 .59875 Mdot
.39625 .57625 Mdot
.33 .54625 Mdot
.485 .5075 Mdot
.47 .4825 Mdot
.41875 .45625 Mdot
.45375 .48625 Mdot
.80375 .51875 Mdot
.33125 .58375 Mdot
.52125 .67375 Mdot
.48625 .78875 Mdot
.61875 .7675 Mdot
.32375 .72 Mdot
.79125 .65125 Mdot
.1425 .5975 Mdot
.6925 .51375 Mdot
.22625 .53125 Mdot
.71875 .6 Mdot
.75875 .66875 Mdot
.2775 .645 Mdot
.6375 .59625 Mdot
.5775 .58 Mdot
.11125 .5575 Mdot
.5325 .51875 Mdot
.92375 .53375 Mdot
.675 .5425 Mdot
.5375 .5175 Mdot
.3325 .4925 Mdot
.945 .48875 Mdot
.48375 .49625 Mdot
.07375 .5425 Mdot
.69875 .605 Mdot
.13 .6825 Mdot
.87375 .72875 Mdot
.9625 .7925 Mdot
.08375 .82875 Mdot
.41875 .8175 Mdot
.42 .78625 Mdot
.4125 .775 Mdot
.67 .71625 Mdot
.75625 .655 Mdot
.72125 .54875 Mdot
.31375 .44 Mdot
.4 .44375 Mdot
.165 .45 Mdot
.84125 .48 Mdot
.3475 .54625 Mdot
.24375 .535 Mdot
.62625 .4925 Mdot
.385 .475 Mdot
.65875 .47 Mdot
.64375 .4625 Mdot
.6725 .45625 Mdot
.4425 .4075 Mdot
.06875 .36625 Mdot
.525 .3475 Mdot
.82125 .36375 Mdot
.34125 .42625 Mdot
.88125 .49125 Mdot
.14125 .545 Mdot
.71375 .62125 Mdot
.29875 .67125 Mdot
.8175 .6825 Mdot
.1775 .695 Mdot
.40375 .69125 Mdot
.49625 .70625 Mdot
.515 .6525 Mdot
.54 .5425 Mdot
.62375 .57375 Mdot
.58125 .5375 Mdot
.95875 .5225 Mdot
.175 .52625 Mdot
.24625 .51125 Mdot
.49125 .54125 Mdot
.63125 .515 Mdot
.5325 .49625 Mdot
.49625 .4525 Mdot
.31875 .46125 Mdot
.89125 .41625 Mdot
.01125 .4525 Mdot
.0975 .425 Mdot
.27625 .415 Mdot
.52375 .41375 Mdot
.6225 .41125 Mdot
.74 .45625 Mdot
.4075 .5 Mdot
.6675 .53 Mdot
.2475 .53625 Mdot
.65 .52125 Mdot
.38625 .49625 Mdot
.47 .49 Mdot
.7675 .4475 Mdot
.195 .45125 Mdot
.49875 .495 Mdot
.55 .47625 Mdot
.575 .48625 Mdot
.6 .55 Mdot
.36875 .61375 Mdot
.56625 .5775 Mdot
.44 .62875 Mdot
.705 .6225 Mdot
.00125 .5625 Mdot
.77875 .4875 Mdot
.48875 .5075 Mdot
.6325 .5225 Mdot
.24 .53625 Mdot
.42125 .54 Mdot
.785 .59375 Mdot
.435 .55875 Mdot
.50875 .5125 Mdot
.56375 .535 Mdot
.60625 .56375 Mdot
.29 .49 Mdot
.20875 .48625 Mdot
.36625 .50625 Mdot
.35 .5225 Mdot
.49375 .52 Mdot
.46 .5175 Mdot
.4025 .5175 Mdot
.46875 .485 Mdot
.79375 .44875 Mdot
.355 .395 Mdot
.47625 .31625 Mdot
.56875 .26375 Mdot
.54125 .2925 Mdot
.31875 .3125 Mdot
.845 .4075 Mdot
.17 .50375 Mdot
.52 .575 Mdot
.41625 .545 Mdot
.6575 .5325 Mdot
.715 .4725 Mdot
.3775 .455 Mdot
.5425 .445 Mdot
.61 .5 Mdot
.09625 .49125 Mdot
.535 .4675 Mdot
.955 .41625 Mdot
.585 .34 Mdot
.57625 .36625 Mdot
.3475 .4225 Mdot
.965 .47125 Mdot
.46875 .49375 Mdot
.04125 .48125 Mdot
.69125 .465 Mdot
.21625 .45 Mdot
.7475 .43125 Mdot
.52875 .42875 Mdot
.32875 .42125 Mdot
.515 .40875 Mdot
.5025 .42 Mdot
.83375 .44125 Mdot
.0725 .46 Mdot
.64375 .49875 Mdot
.365 .57125 Mdot
.97375 .60125 Mdot
.4225 .585 Mdot
.19125 .58 Mdot
.815 .565 Mdot
.3425 .5325 Mdot
.26625 .5125 Mdot
.59625 .535 Mdot
.43375 .5325 Mdot
.6675 .51 Mdot
.63 .505 Mdot
.6875 .47375 Mdot
.42375 .47875 Mdot
.06875 .51375 Mdot
.53625 .5275 Mdot
.8025 .53625 Mdot
.3225 .55875 Mdot
.95625 .54375 Mdot
.06 .50125 Mdot
.775 .4775 Mdot
.2575 .4475 Mdot
.83125 .415 Mdot
.19375 .405 Mdot
.4225 .39875 Mdot
.405 .35 Mdot
.6 .3425 Mdot
.5425 .39 Mdot
.61 .45125 Mdot
.625 .485 Mdot
.9225 .52125 Mdot
.22625 .55625 Mdot
.19 .55625 Mdot
.455 .5275 Mdot
.75625 .51625 Mdot
.47 .52125 Mdot
.52375 .49875 Mdot
.28125 .505 Mdot
.92375 .49375 Mdot
.0325 .49375 Mdot
.26375 .49875 Mdot
.54125 .515 Mdot
.64875 .5325 Mdot
.7375 .5025 Mdot
.36 .4725 Mdot
.7075 .5 Mdot
.19875 .52125 Mdot
.69625 .52 Mdot
.4125 .55875 Mdot
.43125 .57 Mdot
.7775 .5525 Mdot
.14625 .52125 Mdot
.5575 .505 Mdot
.57375 .515 Mdot
.53875 .51375 Mdot
.63375 .43875 Mdot
.31125 .385 Mdot
.545 .40375 Mdot
.48 .37 Mdot
.725 .38 Mdot
.795 .57 Mdot
.4825 .57125 Mdot
.63 .57875 Mdot
.265 .58875 Mdot
.3825 .56125 Mdot
.785 .54875 Mdot
.46125 .55375 Mdot
.5 .5725 Mdot
.55875 .53375 Mdot
.6075 .50625 Mdot
.2525 .39125 Mdot
.2275 .39125 Mdot
.29375 .4075 Mdot
.38375 .42875 Mdot
.46625 .4525 Mdot
.48125 .47625 Mdot
.4125 .50625 Mdot
.4575 .54875 Mdot
.78 .5725 Mdot
.40875 .56875 Mdot
.3675 .5825 Mdot
.72375 .555 Mdot
.4725 .53 Mdot
.3025 .53875 Mdot
.8375 .475 Mdot
.1725 .375 Mdot
.4925 .3825 Mdot
.52375 .4 Mdot
.5575 .35625 Mdot
.66375 .39875 Mdot
.53375 .4825 Mdot
.44125 .50625 Mdot
.6225 .48875 Mdot
.07375 .5325 Mdot
.56625 .60875 Mdot
.97625 .67 Mdot
.00875 .67375 Mdot
.5175 .67 Mdot
.57875 .61375 Mdot
.3625 .51625 Mdot
.99125 .43 Mdot
.4775 .40125 Mdot
.03875 .395 Mdot
.605 .39375 Mdot
.36875 .38125 Mdot
.6025 .39125 Mdot
.6025 .39375 Mdot
.26125 .44 Mdot
.585 .44625 Mdot
.395 .4725 Mdot
.89125 .4725 Mdot
.135 .47375 Mdot
.55 .44625 Mdot
.45375 .44 Mdot
.8825 .4275 Mdot
.44875 .43125 Mdot
.26 .415 Mdot
.7525 .44625 Mdot
.35 .455 Mdot
.275 .4725 Mdot
.56625 .4725 Mdot
.4575 .48 Mdot
.67875 .43125 Mdot
.61 .43875 Mdot
.67375 .4725 Mdot
.45 .48625 Mdot
.03 .445 Mdot
.5775 .44375 Mdot
.80375 .41 Mdot
.2825 .38 Mdot
.0175 .4325 Mdot
.77 .44875 Mdot
.2425 .49 Mdot
.8725 .51375 Mdot
.165 .525 Mdot
.4575 .5325 Mdot
.3325 .56125 Mdot
.6675 .59375 Mdot
.60375 .62375 Mdot
.6425 .4675 Mdot
.62125 .415 Mdot
.91 .375 Mdot
.27 .385 Mdot
.13125 .37125 Mdot
.4425 .4 Mdot
.83625 .48 Mdot
.465 .505 Mdot
.46 .5075 Mdot
.3225 .515 Mdot
.9025 .55375 Mdot
.255 .49625 Mdot
.535 .47875 Mdot
.7225 .4975 Mdot
.70375 .485 Mdot
.3625 .5275 Mdot
.635 .48625 Mdot
.25625 .45875 Mdot
.70625 .46625 Mdot
.4025 .4975 Mdot
.43375 .48625 Mdot
.765 .54 Mdot
.12 .57 Mdot
.6175 .5325 Mdot
.55375 .46625 Mdot
.5325 .385 Mdot
.64875 .3875 Mdot
.26625 .36375 Mdot
.60125 .3275 Mdot
.44875 .33625 Mdot
.6925 .36875 Mdot
.00375 .3025 Mdot
.8 .28 Mdot
.5025 .29875 Mdot
.5775 .3275 Mdot
.345 .34875 Mdot
.39 .41875 Mdot
.71125 .465 Mdot
.415 .48625 Mdot
.63 .47625 Mdot
.46875 .44375 Mdot
.65 .4125 Mdot
.1675 .5625 Mdot
.29125 .57 Mdot
.23375 .5625 Mdot
.40375 .53875 Mdot
.46625 .5425 Mdot
.465 .53375 Mdot
.425 .52875 Mdot
.46125 .48625 Mdot
.7875 .45 Mdot
.4 .47625 Mdot
.38125 .46 Mdot
.68625 .47 Mdot
.47625 .485 Mdot
.3275 .48875 Mdot
.87625 .4925 Mdot
.11 .6175 Mdot
.48875 .585 Mdot
.60125 .565 Mdot
.48875 .61 Mdot
.59 .59625 Mdot
.67625 .475 Mdot
.36625 .48625 Mdot
.66375 .4675 Mdot
.04 .4425 Mdot
.58625 .41 Mdot
.94125 .4125 Mdot
.07 .42 Mdot
.465 .4925 Mdot
.56625 .58875 Mdot
.43 .665 Mdot
.97 .695 Mdot
.465 .71125 Mdot
.03125 .69625 Mdot
.54875 .62875 Mdot
.49625 .58625 Mdot
.47 .56125 Mdot
.665 .5325 Mdot
.205 .52875 Mdot
.625 .54625 Mdot
.35625 .53875 Mdot
.8525 .53 Mdot
.24 .56875 Mdot
.50125 .5875 Mdot
.52375 .56125 Mdot
.7675 .57375 Mdot
.48375 .55125 Mdot
.30875 .52875 Mdot
.66 .4925 Mdot
.4375 .49625 Mdot
.25375 .4775 Mdot
.5425 .47375 Mdot
.48375 .48 Mdot
.66375 .56625 Mdot
.6225 .5825 Mdot
.65375 .5675 Mdot
.4925 .56625 Mdot
.6475 .6075 Mdot
.79125 .61 Mdot
.24875 .6275 Mdot
.025 .55625 Mdot
.7625 .53625 Mdot
.22125 .50875 Mdot
.90125 .4725 Mdot
.16625 .455 Mdot
.48625 .46625 Mdot
.2525 .45 Mdot
.735 .45125 Mdot
.64375 .48125 Mdot
.69375 .5975 Mdot
.56625 .63875 Mdot
.92 .6575 Mdot
.27875 .6275 Mdot
.1075 .62875 Mdot
.4675 .6225 Mdot
.87 .54625 Mdot
.4275 .5175 Mdot
.43125 .52625 Mdot
.3575 .51125 Mdot
.90125 .4525 Mdot
.29375 .51125 Mdot
.47125 .5425 Mdot
.79625 .5275 Mdot
.68875 .505 Mdot
.35875 .48875 Mdot
.52125 .485 Mdot
.42375 .45875 Mdot
.6275 .4025 Mdot
.425 .40125 Mdot
.4475 .39375 Mdot
.7325 .32625 Mdot
.09125 .355 Mdot
.6775 .4525 Mdot
.53625 .54125 Mdot
.52375 .65125 Mdot
.67 .755 Mdot
.24 .7875 Mdot
.5725 .83 Mdot
.45125 .82625 Mdot
.75125 .75875 Mdot
.83625 .70625 Mdot
.53 .61375 Mdot
.49875 .515 Mdot
.42625 .44375 Mdot
.3675 .3375 Mdot
.6775 .30625 Mdot
.40875 .31375 Mdot
.6975 .3825 Mdot
.3575 .45625 Mdot
.7475 .53625 Mdot
.08125 .5575 Mdot
.36375 .53625 Mdot
.17625 .51 Mdot
.42875 .50625 Mdot
.4775 .4925 Mdot
.4375 .48625 Mdot
.4475 .46 Mdot
.445 .4925 Mdot
.8225 .50125 Mdot
.3725 .46875 Mdot
.3825 .505 Mdot
.6675 .54125 Mdot
.46625 .57 Mdot
.34875 .595 Mdot
.93125 .695 Mdot
.06 .65875 Mdot
.43125 .665 Mdot
.72 .64 Mdot
.42625 .615 Mdot
.55 .53125 Mdot
.7425 .5475 Mdot
.315 .52375 Mdot
.72625 .525 Mdot
0 .52625 Mdot
.59875 .52125 Mdot
.9275 .5 Mdot
.1225 .5125 Mdot
.4125 .475 Mdot
.5025 .4025 Mdot
.52125 .3775 Mdot
.97375 .3975 Mdot
.445 .37 Mdot
.0125 .395 Mdot
.51625 .4775 Mdot
.60125 .55375 Mdot
.35 .59125 Mdot
.69625 .5925 Mdot
.1975 .55375 Mdot
.595 .51375 Mdot
.4 .515 Mdot
.78625 .50875 Mdot
.33125 .48375 Mdot
.455 .46625 Mdot
.59625 .47625 Mdot
.6325 .45875 Mdot
.51125 .49 Mdot
.37125 .55375 Mdot
.6275 .57875 Mdot
.46375 .5725 Mdot
.25125 .5825 Mdot
.50375 .57625 Mdot
.495 .54375 Mdot
.6275 .44 Mdot
.65625 .42 Mdot
.6325 .40375 Mdot
.5125 .40125 Mdot
.63125 .43625 Mdot
.8075 .45625 Mdot
.235 .46 Mdot
.07 .475 Mdot
.74125 .4625 Mdot
.20875 .44625 Mdot
.9125 .45625 Mdot
.16375 .48 Mdot
.49375 .49125 Mdot
.225 .51625 Mdot
.79375 .4975 Mdot
.64875 .34875 Mdot
.95875 .38625 Mdot
.765 .5125 Mdot
.53625 .52125 Mdot
.86875 .52875 Mdot
.345 .5075 Mdot
.05 .525 Mdot
.50625 .5175 Mdot
.88625 .51 Mdot
.43125 .51 Mdot
.395 .49375 Mdot
.35875 .485 Mdot
.88625 .51 Mdot
.37875 .53375 Mdot
.40375 .525 Mdot
.86375 .5725 Mdot
.67875 .58875 Mdot
.33625 .605 Mdot
.435 .625 Mdot
.57875 .655 Mdot
.50125 .68625 Mdot
.50625 .66125 Mdot
.45 .6625 Mdot
.70125 .73 Mdot
.09 .69125 Mdot
.7125 .58375 Mdot
.5125 .54125 Mdot
.51125 .45625 Mdot
.6725 .37125 Mdot
.27625 .3925 Mdot
.55875 .39125 Mdot
.39375 .3775 Mdot
.79625 .415 Mdot
.8425 .37375 Mdot
.51875 .42125 Mdot
.45125 .53 Mdot
.5325 .62125 Mdot
.325 .65125 Mdot
.67 .65875 Mdot
.39875 .6775 Mdot
.72625 .6125 Mdot
.29125 .5525 Mdot
.82125 .53875 Mdot
.02875 .4125 Mdot
.3825 .44625 Mdot
.15375 .4875 Mdot
.445 .4975 Mdot
.50125 .4975 Mdot
.36 .49625 Mdot
.51 .53125 Mdot
.4275 .50375 Mdot
.8625 .615 Mdot
.3125 .65375 Mdot
.40875 .635 Mdot
.65125 .58625 Mdot
.46375 .54625 Mdot
.37375 .39875 Mdot
.94125 .2925 Mdot
.02625 .2525 Mdot
.435 .25125 Mdot
.7975 .2975 Mdot
.3075 .31125 Mdot
.56375 .395 Mdot
.8075 .4525 Mdot
.26375 .4775 Mdot
.7675 .5025 Mdot
.61625 .5125 Mdot
.88125 .51625 Mdot
.18 .51125 Mdot
.3775 .52 Mdot
.4875 .58625 Mdot
.56875 .62 Mdot
.9625 .615 Mdot
.4425 .64875 Mdot
.495 .54625 Mdot
.68625 .4725 Mdot
.29 .43375 Mdot
.75125 .37 Mdot
.19 .415 Mdot
.53125 .4275 Mdot
.48875 .37625 Mdot
.705 .38 Mdot
.3875 .3975 Mdot
.435 .385 Mdot
.67375 .38875 Mdot
.50875 .42125 Mdot
.5375 .38625 Mdot
.40875 .3425 Mdot
.6225 .3225 Mdot
.46125 .34 Mdot
.26125 .37125 Mdot
.47 .4175 Mdot
.525 .46375 Mdot
.60375 .5175 Mdot
.63125 .52125 Mdot
.65125 .54 Mdot
.50375 .5575 Mdot
.63625 .54125 Mdot
.80375 .52 Mdot
.21625 .5 Mdot
.10625 .515 Mdot
.7125 .50375 Mdot
.21625 .54375 Mdot
.89875 .58875 Mdot
.1775 .58875 Mdot
.48125 .57625 Mdot
.23875 .5825 Mdot
.84375 .6 Mdot
.655 .70375 Mdot
.82125 .55375 Mdot
.82 .40875 Mdot
.4875 .40875 Mdot
.87375 .4075 Mdot
.3775 .44375 Mdot
.56875 .49875 Mdot
.8575 .545 Mdot
.49 .5625 Mdot
.28375 .57875 Mdot
.46875 .55625 Mdot
.77875 .555 Mdot
.41875 .51 Mdot
.36125 .4875 Mdot
.90875 .42 Mdot
.68125 .38375 Mdot
.3075 .3675 Mdot
.39 .35375 Mdot
.67625 .35125 Mdot
.43125 .38875 Mdot
.54375 .40875 Mdot
.42375 .41125 Mdot
.70125 .3925 Mdot
.10875 .4125 Mdot
.71 .4625 Mdot
.5475 .4625 Mdot
.4475 .535 Mdot
.7075 .54375 Mdot
.32375 .49375 Mdot
.4775 .46125 Mdot
.42125 .47625 Mdot
.8075 .43 Mdot
.835 .55375 Mdot
.5725 .59375 Mdot
.36 .54625 Mdot
.60875 .48625 Mdot
.32125 .53625 Mdot
.6525 .53125 Mdot
.39875 .45 Mdot
.76125 .46 Mdot
.2225 .50375 Mdot
.8875 .45125 Mdot
.02875 .5575 Mdot
.3875 .52375 Mdot
.12 .4925 Mdot
.4675 .4875 Mdot
.5275 .49 Mdot
.30375 .49375 Mdot
.5425 .48875 Mdot
.40375 .5 Mdot
.9175 .395 Mdot
.2625 .36375 Mdot
.46125 .3475 Mdot
.565 .34625 Mdot
.5325 .34125 Mdot
.32375 .455 Mdot
.98625 .4825 Mdot
.50625 .52375 Mdot
.74875 .54125 Mdot
.2875 .53875 Mdot
.57375 .52625 Mdot
.83375 .515 Mdot
.2525 .5 Mdot
.77375 .48625 Mdot
.6575 .495 Mdot
.805 .49625 Mdot
.22875 .47875 Mdot
.35625 .425 Mdot
.50375 .36625 Mdot
.59 .34375 Mdot
.93125 .32875 Mdot
.45375 .3325 Mdot
.44 .4225 Mdot
.7825 .455 Mdot
.22 .4725 Mdot
.77 .49375 Mdot
.18 .465 Mdot
.4875 .49125 Mdot
.55875 .565 Mdot
.65875 .5925 Mdot
.42125 .6225 Mdot
.41875 .6675 Mdot
.715 .65625 Mdot
.40125 .6025 Mdot
.62625 .635 Mdot
.37125 .64875 Mdot
.65875 .6675 Mdot
.4525 .67875 Mdot
.25 .66125 Mdot
.4675 .59375 Mdot
.52125 .55375 Mdot
.59875 .52375 Mdot
.63375 .51375 Mdot
.65375 .53 Mdot
.51875 .515 Mdot
.59375 .49125 Mdot
.84375 .5175 Mdot
.1925 .50875 Mdot
.11 .52625 Mdot
.70875 .5625 Mdot
.23375 .545 Mdot
.86 .475 Mdot
.23375 .44875 Mdot
.445 .42375 Mdot
.2375 .35 Mdot
.905 .3225 Mdot
.95125 .33375 Mdot
.64875 .34 Mdot
.69875 .5075 Mdot
.83 .56 Mdot
.43625 .54 Mdot
.905 .54 Mdot
.3875 .53125 Mdot
.6275 .4075 Mdot
.805 .3675 Mdot
.5125 .3525 Mdot
.24375 .30875 Mdot
.56 .3825 Mdot
.64375 .41125 Mdot
.12 .40375 Mdot
.465 .44625 Mdot
.33625 .43625 Mdot
.9075 .4475 Mdot
.68125 .50125 Mdot
.3225 .46875 Mdot
.3575 .455 Mdot
.72625 .43625 Mdot
.39875 .38625 Mdot
.54 .32 Mdot
.44875 .3225 Mdot
.62875 .32625 Mdot
.2 .31125 Mdot
.71125 .3275 Mdot
.46125 .34 Mdot
.51625 .325 Mdot
.67625 .345 Mdot
.35625 .41 Mdot
.4375 .4675 Mdot
.44625 .5425 Mdot
.79375 .62625 Mdot
.7825 .57125 Mdot
.62375 .53375 Mdot
.2825 .48625 Mdot
.68875 .4725 Mdot
.31625 .455 Mdot
.60375 .4525 Mdot
.4225 .51 Mdot
.77125 .535 Mdot
.20625 .51625 Mdot
.8825 .53 Mdot
.055 .43875 Mdot
.37375 .44875 Mdot
.10375 .4625 Mdot
.46875 .46125 Mdot
.57375 .47375 Mdot
.23375 .48375 Mdot
.55 .48875 Mdot
.43 .48 Mdot
.97 .5025 Mdot
.16 .50125 Mdot
.57 .52375 Mdot
.445 .54125 Mdot
.57625 .55 Mdot
.32625 .5475 Mdot
.99125 .55875 Mdot
.0075 .51625 Mdot
.45 .49375 Mdot
.81375 .475 Mdot
.27875 .46 Mdot
.55625 .4575 Mdot
.82625 .4625 Mdot
.2525 .46625 Mdot
.765 .48 Mdot
.6925 .4675 Mdot
.71125 .4625 Mdot
.275 .49 Mdot
.3375 .52 Mdot
.51875 .52125 Mdot
.6175 .51625 Mdot
.93375 .52875 Mdot
.42125 .4925 Mdot
.42 .44875 Mdot
.82625 .45 Mdot
.21625 .45125 Mdot
.82125 .5325 Mdot
.14375 .55625 Mdot
.4275 .5575 Mdot
.6325 .52 Mdot
.61875 .47 Mdot
.46 .40125 Mdot
.41625 .3525 Mdot
.74375 .3675 Mdot
.26125 .40125 Mdot
.73125 .42 Mdot
.3575 .4175 Mdot
.6625 .42375 Mdot
.42875 .3825 Mdot
.3125 .3975 Mdot
.43125 .415 Mdot
.5175 .45125 Mdot
.59625 .50375 Mdot
.64 .51375 Mdot
.62875 .495 Mdot
.53375 .475 Mdot
.0225 .45 Mdot
.5375 .44875 Mdot
.86375 .445 Mdot
.1875 .4725 Mdot
.115 .47875 Mdot
.7225 .46875 Mdot
.22125 .4675 Mdot
.81 .48 Mdot
.30625 .49375 Mdot
.38875 .50625 Mdot
.2875 .5375 Mdot
.92875 .55 Mdot
.8075 .57 Mdot
.1475 .585 Mdot
.61625 .59625 Mdot
.535 .53375 Mdot
.79125 .455 Mdot
.4325 .47 Mdot
.9225 .46 Mdot
.36125 .50875 Mdot
.65625 .5725 Mdot
.81375 .5825 Mdot
.4525 .60875 Mdot
.275 .595 Mdot
.6025 .6 Mdot
.5275 .57875 Mdot
.25 .615 Mdot
.51 .55625 Mdot
.3725 .57875 Mdot
.8275 .57875 Mdot
.72 .59375 Mdot
.3025 .63625 Mdot
.3825 .6875 Mdot
.72875 .735 Mdot
.4125 .77 Mdot
.4875 .7975 Mdot
.48375 .78875 Mdot
.595 .735 Mdot
.2625 .715 Mdot
.67 .655 Mdot
.47625 .615 Mdot
.53625 .565 Mdot
.60375 .53375 Mdot
.4625 .49125 Mdot
.32125 .47875 Mdot
.5175 .43 Mdot
.78375 .39125 Mdot
.73125 .4575 Mdot
.62875 .4475 Mdot
.27125 .49625 Mdot
.73125 .53375 Mdot
.30875 .52625 Mdot
.56875 .52125 Mdot
.50875 .525 Mdot
.70875 .48875 Mdot
.19125 .4925 Mdot
.89125 .48375 Mdot
.08625 .59125 Mdot
.3675 .57125 Mdot
.09875 .57 Mdot
.49125 .5825 Mdot
.57875 .5825 Mdot
.17625 .57125 Mdot
.6075 .56 Mdot
.42875 .56 Mdot
.975 .545 Mdot
.11 .56875 Mdot
.60375 .595 Mdot
.46 .60375 Mdot
.555 .61125 Mdot
.36125 .57125 Mdot
.94 .57375 Mdot
.03375 .59125 Mdot
.41125 .57875 Mdot
.85625 .56875 Mdot
.31375 .605 Mdot
.5025 .5975 Mdot
.805 .56875 Mdot
.28 .58375 Mdot
.77 .55625 Mdot
.00375 .55 Mdot
.72 .51 Mdot
.64875 .48875 Mdot
.29375 .45875 Mdot
.32375 .47875 Mdot
.55625 .5 Mdot
.595 .48875 Mdot
.96375 .49625 Mdot
.41125 .5275 Mdot
.36375 .56375 Mdot
.91125 .57125 Mdot
.185 .58375 Mdot
.82625 .525 Mdot
.1625 .52375 Mdot
.34375 .52125 Mdot
.675 .54375 Mdot
.655 .595 Mdot
.46625 .62875 Mdot
.3675 .64625 Mdot
.7775 .63625 Mdot
.16 .62 Mdot
.83625 .56 Mdot
.34 .555 Mdot
.68375 .5525 Mdot
.3775 .56875 Mdot
.35125 .53875 Mdot
.4175 .56875 Mdot
.4775 .535 Mdot
.595 .475 Mdot
.62875 .45875 Mdot
.59125 .47875 Mdot
.55125 .505 Mdot
.02625 .54875 Mdot
.56125 .5675 Mdot
.84 .56125 Mdot
.2075 .535 Mdot
.08 .50125 Mdot
.73875 .48875 Mdot
.22125 .49375 Mdot
.79875 .535 Mdot
.30875 .55125 Mdot
.35625 .5825 Mdot
.35 .6225 Mdot
.95375 .62375 Mdot
.68 .56875 Mdot
.2625 .52375 Mdot
.585 .46625 Mdot
.395 .42375 Mdot
.7525 .5375 Mdot
.45 .51375 Mdot
.92625 .49375 Mdot
.35 .4525 Mdot
.67375 .46125 Mdot
.82875 .48375 Mdot
.4075 .475 Mdot
.29875 .5175 Mdot
.63 .4725 Mdot
.44625 .46375 Mdot
.4275 .4275 Mdot
.5425 .46 Mdot
.485 .46125 Mdot
.69875 .47125 Mdot
.76 .44875 Mdot
.2825 .425 Mdot
.42875 .41125 Mdot
.6875 .39 Mdot
.45625 .38375 Mdot
.43 .4025 Mdot
.4825 .4275 Mdot
.5775 .465 Mdot
.36125 .48875 Mdot
.6125 .575 Mdot
.495 .65125 Mdot
.525 .66875 Mdot
.59 .6675 Mdot
.48 .675 Mdot
.26375 .5975 Mdot
.6275 .5675 Mdot
.71625 .5625 Mdot
.03375 .54125 Mdot
.67125 .5175 Mdot
.64375 .54 Mdot
.285 .50875 Mdot
.6475 .4675 Mdot
.40125 .435 Mdot
.59375 .4325 Mdot
.49125 .445 Mdot
.6475 .47125 Mdot
.27625 .495 Mdot
.8275 .54375 Mdot
.1375 .4625 Mdot
.3325 .51125 Mdot
.095 .53 Mdot
.4875 .515 Mdot
.56625 .47875 Mdot
.23125 .46625 Mdot
.54375 .46 Mdot
.45375 .45875 Mdot
.97125 .445 Mdot
.12125 .4325 Mdot
.575 .37875 Mdot
.46875 .36 Mdot
.5625 .35625 Mdot
.39875 .4275 Mdot
.89875 .42125 Mdot
.04375 .4625 Mdot
.39875 .515 Mdot
.87125 .55625 Mdot
.3125 .53625 Mdot
.52 .5625 Mdot
.775 .57375 Mdot
.30375 .55125 Mdot
.72375 .55375 Mdot
.05875 .56375 Mdot
.7225 .61 Mdot
.6075 .65125 Mdot
.31 .67125 Mdot
.28875 .64875 Mdot
.63875 .64 Mdot
.53625 .66375 Mdot
.96375 .6625 Mdot
.4325 .645 Mdot
.36125 .6 Mdot
.9625 .55125 Mdot
.1675 .50125 Mdot
.815 .4725 Mdot
.145 .45625 Mdot
.32 .44125 Mdot
.6825 .42875 Mdot
.6675 .40375 Mdot
.495 .415 Mdot
.3175 .4175 Mdot
.82375 .41375 Mdot
.08125 .42 Mdot
.92625 .42875 Mdot
.30625 .39125 Mdot
.67 .38 Mdot
.3775 .38375 Mdot
.37125 .385 Mdot
.41375 .37125 Mdot
.465 .42125 Mdot
.59625 .51625 Mdot
.605 .5575 Mdot
.54375 .54625 Mdot
.6275 .5425 Mdot
.63 .47125 Mdot
.7875 .4525 Mdot
.2325 .4525 Mdot
.07 .465 Mdot
.75625 .4675 Mdot
.18625 .44 Mdot
.82875 .3825 Mdot
.285 .35625 Mdot
.38625 .32625 Mdot
.36125 .295 Mdot
.9675 .315 Mdot
.58375 .35875 Mdot
.3425 .40625 Mdot
.58 .4675 Mdot
.31375 .5175 Mdot
.07 .44375 Mdot
.69375 .44375 Mdot
.45375 .475 Mdot
.96375 .50125 Mdot
.29875 .4725 Mdot
.64125 .4875 Mdot
.8125 .5 Mdot
.47125 .5025 Mdot
.32375 .54375 Mdot
.58125 .52375 Mdot
.42375 .535 Mdot
.52125 .495 Mdot
.895 .4825 Mdot
.50625 .45 Mdot
.59375 .45 Mdot
.59875 .4725 Mdot
.7725 .4825 Mdot
.3025 .4675 Mdot
.43625 .4725 Mdot
.685 .455 Mdot
.4675 .44375 Mdot
.3875 .4475 Mdot
.4825 .4475 Mdot
.5775 .42875 Mdot
.38875 .44875 Mdot
.5925 .405 Mdot
.51875 .345 Mdot
.4975 .35125 Mdot
.59625 .395 Mdot
.47375 .40875 Mdot
.20875 .47375 Mdot
.77125 .495 Mdot
.62625 .49375 Mdot
.055 .425 Mdot
.66125 .37875 Mdot
.67875 .325 Mdot
.2725 .345 Mdot
.55125 .35875 Mdot
.53375 .405 Mdot
.53875 .4225 Mdot
.5125 .435 Mdot
.645 .43375 Mdot
.195 .43625 Mdot
.875 .44 Mdot
.145 .475 Mdot
.3425 .4375 Mdot
.09625 .3975 Mdot
.50375 .3575 Mdot
.5275 .38375 Mdot
.30625 .41375 Mdot
.48375 .3975 Mdot
.45875 .4025 Mdot
.9725 .4725 Mdot
.1575 .49 Mdot
.53875 .5075 Mdot
.505 .5775 Mdot
.52125 .6175 Mdot
.41625 .5675 Mdot
.90375 .5525 Mdot
.0225 .50125 Mdot
.4175 .43875 Mdot
.89 .38125 Mdot
.25875 .34375 Mdot
.5675 .3 Mdot
.74875 .31875 Mdot
.3375 .30625 Mdot
.67875 .3025 Mdot
.08125 .32125 Mdot
.74625 .32625 Mdot
.56625 .305 Mdot
.3125 .32375 Mdot
.27875 .35 Mdot
.70875 .3725 Mdot
.49375 .3925 Mdot
.955 .41125 Mdot
.4225 .41125 Mdot
.355 .43125 Mdot
.105 .495 Mdot
.0025 .5075 Mdot
.77125 .54 Mdot
.13125 .55125 Mdot
.31 .56 Mdot
.71 .57625 Mdot
.655 .5775 Mdot
.5425 .5475 Mdot
.28125 .54875 Mdot
.81875 .54125 Mdot
.04375 .5475 Mdot
.96625 .58125 Mdot
.335 .67125 Mdot
.625 .68125 Mdot
.36 .6975 Mdot
.42 .6875 Mdot
.41125 .6225 Mdot
.4225 .53 Mdot
.55875 .39875 Mdot
.68625 .39125 Mdot
.46625 .3475 Mdot
.695 .34625 Mdot
.7075 .4075 Mdot
.73625 .46125 Mdot
.24125 .54125 Mdot
.035 .57125 Mdot
.80375 .585 Mdot
.1275 .6 Mdot
.89 .655 Mdot
.255 .67625 Mdot
.395 .6925 Mdot
.3675 .715 Mdot
.98 .7 Mdot
.52625 .65125 Mdot
.35875 .6375 Mdot
.6125 .6075 Mdot
.27625 .54 Mdot
.15375 .49875 Mdot
.64875 .45375 Mdot
.445 .42125 Mdot
.98625 .40875 Mdot
.27125 .425 Mdot
.0175 .40625 Mdot
.53875 .425 Mdot
.92875 .40375 Mdot
.45 .37 Mdot
.37875 .34875 Mdot
.48875 .415 Mdot
.47875 .445 Mdot
.54 .5175 Mdot
.78875 .57625 Mdot
.51875 .57375 Mdot
.70875 .5675 Mdot
.49 .5475 Mdot
.7975 .565 Mdot
.2975 .5975 Mdot
.45125 .58125 Mdot
.67375 .60625 Mdot
.48 .62 Mdot
.345 .57875 Mdot
.51125 .54375 Mdot
.56 .55375 Mdot
.43625 .5275 Mdot
.54 .52 Mdot
.5525 .57375 Mdot
.5175 .58375 Mdot
.56125 .5225 Mdot
.43125 .485 Mdot
.21625 .46875 Mdot
.8425 .43875 Mdot
.57375 .43875 Mdot
.10875 .5375 Mdot
.6275 .65875 Mdot
.6425 .6875 Mdot
.32125 .6475 Mdot
.51625 .67 Mdot
.59 .655 Mdot
.50125 .5525 Mdot
.51125 .52875 Mdot
.63375 .5625 Mdot
.24125 .52875 Mdot
.84 .49 Mdot
.0825 .4275 Mdot
.38125 .475 Mdot
.105 .495 Mdot
.50125 .605 Mdot
.49875 .6175 Mdot
.33125 .59 Mdot
.49875 .59875 Mdot
.4525 .65375 Mdot
.9475 .535 Mdot
.19 .4625 Mdot
.48375 .4175 Mdot
.5875 .33125 Mdot
.44375 .2425 Mdot
.515 .24625 Mdot
.81 .2875 Mdot
.0625 .35125 Mdot
.3675 .38125 Mdot
.97125 .42875 Mdot
.22875 .4925 Mdot
.565 .5425 Mdot
.7275 .53 Mdot
.3275 .595 Mdot
.70375 .6175 Mdot
.09 .59375 Mdot
.77125 .57875 Mdot
.525 .59125 Mdot
.31625 .57875 Mdot
.25125 .555 Mdot
.77 .50375 Mdot
.46125 .45 Mdot
.94 .38125 Mdot
.46 .37625 Mdot
.36875 .41625 Mdot
.08625 .48 Mdot
.1125 .47125 Mdot
.74625 .44625 Mdot
.11 .4525 Mdot
.295 .4325 Mdot
.73375 .40375 Mdot
.6175 .40875 Mdot
.60875 .42 Mdot
.2525 .4375 Mdot
.80875 .475 Mdot
.05375 .47875 Mdot
.94 .48 Mdot
.3725 .445 Mdot
.62 .41875 Mdot
.31875 .39125 Mdot
.44375 .4175 Mdot
.44375 .5125 Mdot
.37875 .6 Mdot
.4975 .71125 Mdot
.67875 .67625 Mdot
.49 .69875 Mdot
.71625 .685 Mdot
.77 .65625 Mdot
.64125 .585 Mdot
.2975 .49125 Mdot
.02875 .415 Mdot
.82375 .4025 Mdot
.0775 .39875 Mdot
.95625 .37875 Mdot
.20875 .37625 Mdot
.38625 .38375 Mdot
.41875 .36375 Mdot
.95625 .38375 Mdot
.51 .4225 Mdot
.35875 .42125 Mdot
.615 .41375 Mdot
.24625 .4875 Mdot
.2325 .59625 Mdot
.63125 .63875 Mdot
.41875 .6675 Mdot
.2525 .68875 Mdot
.04625 .55 Mdot
.44125 .49375 Mdot
.35375 .48625 Mdot
.45125 .47625 Mdot
.4175 .5175 Mdot
.565 .475 Mdot
.4875 .42 Mdot
.7575 .38625 Mdot
.59125 .39 Mdot
.7325 .40375 Mdot
.44375 .39125 Mdot
.8075 .37 Mdot
.295 .37375 Mdot
.4775 .3675 Mdot
.62 .37625 Mdot
.52375 .37125 Mdot
.30375 .42875 Mdot
.545 .44375 Mdot
.55375 .465 Mdot
.39375 .45375 Mdot
.59875 .4375 Mdot
.52625 .34125 Mdot
.4975 .31375 Mdot
.6 .3075 Mdot
.4475 .32625 Mdot
.16 .3375 Mdot
.91 .3625 Mdot
.4925 .38625 Mdot
.12375 .38 Mdot
.67 .33375 Mdot
.6075 .39125 Mdot
.38625 .51 Mdot
.425 .535 Mdot
.67625 .56125 Mdot
.47625 .71625 Mdot
.50875 .665 Mdot
.60375 .55875 Mdot
.24125 .54125 Mdot
.8975 .51 Mdot
.01125 .6325 Mdot
.44125 .56 Mdot
.18 .50875 Mdot
.48875 .41375 Mdot
.4775 .40625 Mdot
.33375 .42 Mdot
.52375 .42 Mdot
.43625 .37 Mdot
.92625 .4625 Mdot
.25 .55125 Mdot
.3875 .6525 Mdot
.67875 .70125 Mdot
.38125 .76625 Mdot
.605 .775 Mdot
.7075 .72375 Mdot
.075 .65375 Mdot
.39875 .645 Mdot
.95 .60375 Mdot
.235 .5575 Mdot
.59625 .52375 Mdot
.68625 .51875 Mdot
.36125 .47 Mdot
.735 .47625 Mdot
.0225 .4775 Mdot
.80625 .4575 Mdot
.5 .4225 Mdot
.3275 .4225 Mdot
.22875 .43375 Mdot
.8375 .4675 Mdot
.45625 .495 Mdot
.85875 .54875 Mdot
.5175 .5625 Mdot
.39625 .53125 Mdot
.05 .54125 Mdot
.18375 .53875 Mdot
.71875 .5525 Mdot
.1 .5375 Mdot
.29625 .53125 Mdot
.75125 .53 Mdot
.55375 .535 Mdot
.67375 .5225 Mdot
.24875 .495 Mdot
.77 .4625 Mdot
.1075 .4625 Mdot
.8975 .45 Mdot
.395 .41375 Mdot
.63 .4125 Mdot
.2775 .41625 Mdot
.44125 .3925 Mdot
.5125 .35375 Mdot
.32625 .35625 Mdot
.48625 .32625 Mdot
.57125 .35375 Mdot
.69875 .38375 Mdot
.515 .44875 Mdot
.86 .4375 Mdot
.5475 .46625 Mdot
.33 .485 Mdot
.9975 .4875 Mdot
.035 .52625 Mdot
.8325 .5525 Mdot
.06625 .5875 Mdot
.985 .6025 Mdot
.19375 .6025 Mdot
.38 .58375 Mdot
.4075 .58375 Mdot
.975 .51625 Mdot
.5 .5025 Mdot
.34 .5075 Mdot
.61875 .515 Mdot
.26125 .4625 Mdot
.26625 .42625 Mdot
.64375 .43125 Mdot
.40875 .43875 Mdot
.98 .4275 Mdot
.28375 .4275 Mdot
.0525 .54375 Mdot
.3825 .59375 Mdot
.295 .58375 Mdot
.52 .6025 Mdot
.34625 .535 Mdot
.66375 .5675 Mdot
.41125 .59375 Mdot
.72375 .58625 Mdot
.62625 .56 Mdot
.69125 .54125 Mdot
.50625 .565 Mdot
.785 .5975 Mdot
.2375 .59375 Mdot
.55 .60625 Mdot
.5675 .5675 Mdot
.51125 .56125 Mdot
.33375 .51125 Mdot
.565 .5275 Mdot
.48875 .4975 Mdot
.445 .52 Mdot
.59625 .5575 Mdot
.5125 .64375 Mdot
.49 .645 Mdot
.64375 .72 Mdot
.435 .7275 Mdot
.075 .705 Mdot
.41375 .705 Mdot
.1475 .625 Mdot
.6625 .57875 Mdot
.63125 .5425 Mdot
.4075 .445 Mdot
.3675 .3875 Mdot
.645 .36625 Mdot
.5775 .27375 Mdot
.4725 .33625 Mdot
.5575 .4275 Mdot
.27 .46625 Mdot
.94125 .535 Mdot
.49875 .5225 Mdot
.26 .5925 Mdot
.4475 .6075 Mdot
.47375 .61125 Mdot
.37125 .61125 Mdot
.4825 .62625 Mdot
.43125 .6025 Mdot
.94 .5725 Mdot
.30125 .5375 Mdot
.2675 .465 Mdot
.74375 .4675 Mdot
.385 .445 Mdot
.6325 .455 Mdot
.64 .46875 Mdot
.08375 .505 Mdot
.495 .49375 Mdot
.93875 .5325 Mdot
.13 .57375 Mdot
.66625 .57375 Mdot
.6625 .565 Mdot
.36 .555 Mdot
.77125 .5175 Mdot
.81625 .56125 Mdot
.51125 .5975 Mdot
.3075 .58125 Mdot
.2075 .585 Mdot
.88875 .5625 Mdot
.45875 .54375 Mdot
.8075 .52 Mdot
.52625 .51625 Mdot
.4375 .4975 Mdot
.0325 .385 Mdot
.28375 .4175 Mdot
.67375 .43625 Mdot
.0725 .47625 Mdot
.32625 .5125 Mdot
.76625 .52 Mdot
.47875 .5075 Mdot
.75375 .49375 Mdot
.22625 .51 Mdot
.75625 .52875 Mdot
.14125 .5175 Mdot
.855 .51625 Mdot
.4225 .57125 Mdot
.63625 .57 Mdot
.2275 .57875 Mdot
.4675 .615 Mdot
.5775 .62625 Mdot
.2675 .5925 Mdot
.48875 .4775 Mdot
.49 .38375 Mdot
.835 .3275 Mdot
.395 .24 Mdot
.06 .28125 Mdot
.83125 .34125 Mdot
.51375 .4025 Mdot
.32875 .4375 Mdot
.08 .48375 Mdot
.81 .4775 Mdot
.0725 .48125 Mdot
.97625 .46375 Mdot
.21125 .47125 Mdot
.3375 .47625 Mdot
.44875 .50125 Mdot
.9675 .55625 Mdot
.45875 .5525 Mdot
.38625 .53125 Mdot
.6 .5275 Mdot
.275 .525 Mdot
.28375 .53875 Mdot
.66625 .535 Mdot
.39 .50875 Mdot
.9675 .495 Mdot
.3 .53 Mdot
.04125 .5975 Mdot
.36 .59625 Mdot
.2575 .60625 Mdot
.58125 .5725 Mdot
.2875 .47125 Mdot
.74375 .4325 Mdot
.28625 .42875 Mdot
.8025 .47 Mdot
.64375 .525 Mdot
.65 .53125 Mdot
.59875 .53125 Mdot
.72 .47625 Mdot
.19625 .46125 Mdot
.6625 .45625 Mdot
.41875 .4725 Mdot
.5675 .48125 Mdot
.3675 .5175 Mdot
.56375 .48625 Mdot
.4975 .5075 Mdot
.3925 .48375 Mdot
.63125 .4275 Mdot
.47 .3525 Mdot
.53875 .415 Mdot
.635 .385 Mdot
.44875 .42875 Mdot
.01625 .47375 Mdot
.37125 .38875 Mdot
.17375 .39875 Mdot
.66625 .39625 Mdot
.60875 .37875 Mdot
.38375 .42375 Mdot
.465 .47 Mdot
.58375 .485 Mdot
.5225 .525 Mdot
.53125 .51875 Mdot
.55375 .53375 Mdot
.24 .5325 Mdot
.56625 .4925 Mdot
.9775 .5025 Mdot
.3325 .4875 Mdot
.4525 .49375 Mdot
.45375 .50625 Mdot
.32 .5125 Mdot
.5675 .51625 Mdot
.40125 .55 Mdot
.9275 .54625 Mdot
.31875 .54625 Mdot
.2425 .5575 Mdot
.76875 .53625 Mdot
.35 .52125 Mdot
.69 .50625 Mdot
.57125 .52625 Mdot
.055 .49 Mdot
.6475 .46375 Mdot
.86875 .41875 Mdot
.10125 .36875 Mdot
.67125 .35875 Mdot
.64 .42875 Mdot
.36875 .485 Mdot
.83125 .51125 Mdot
.805 .4925 Mdot
.52625 .44 Mdot
.31625 .435 Mdot
.20875 .465 Mdot
.87125 .51 Mdot
.51125 .555 Mdot
.76625 .59125 Mdot
.5075 .60625 Mdot
.42375 .58375 Mdot
.0375 .62625 Mdot
.365 .5925 Mdot
.61 .57875 Mdot
.0725 .5425 Mdot
.35875 .5225 Mdot
.75625 .52125 Mdot
.42625 .5225 Mdot
.82 .53 Mdot
.21375 .4975 Mdot
.72625 .47875 Mdot
.16625 .48625 Mdot
.79625 .47 Mdot
.50375 .42875 Mdot
.61875 .4375 Mdot
.18875 .43625 Mdot
.4775 .42375 Mdot
.6425 .42375 Mdot
.2525 .43875 Mdot
.48375 .64 Mdot
.43375 .70875 Mdot
.9175 .73125 Mdot
.33 .73625 Mdot
.1425 .72375 Mdot
.795 .62125 Mdot
.48 .58625 Mdot
.35 .585 Mdot
1 .5625 Mdot
.0925 .54625 Mdot
.78875 .5125 Mdot
.105 .48375 Mdot
.9625 .49625 Mdot
.25125 .4875 Mdot
.255 .47125 Mdot
.47875 .4575 Mdot
.98875 .44875 Mdot
.44125 .42875 Mdot
.38375 .44625 Mdot
.60875 .445 Mdot
.2725 .50875 Mdot
.3125 .495 Mdot
.6425 .46375 Mdot
.38125 .46125 Mdot
.96375 .47125 Mdot
.30625 .475 Mdot
.03 .44125 Mdot
.395 .4525 Mdot
.0325 .51125 Mdot
.6725 .5275 Mdot
.31125 .58125 Mdot
.79375 .575 Mdot
.1775 .55875 Mdot
.89875 .535 Mdot
.71375 .50875 Mdot
.61875 .585 Mdot
.66375 .58375 Mdot
.6825 .6025 Mdot
.13625 .64625 Mdot
.74875 .62625 Mdot
.30625 .5875 Mdot
.62625 .5975 Mdot
.3725 .56 Mdot
.60625 .59625 Mdot
.43875 .60625 Mdot
.42625 .65 Mdot
.60625 .69625 Mdot
.4575 .79375 Mdot
.59 .75375 Mdot
.5975 .755 Mdot
.47625 .715 Mdot
.31875 .75375 Mdot
.20375 .795 Mdot
.64625 .80875 Mdot
.62125 .82375 Mdot
.3725 .72625 Mdot
.54625 .67625 Mdot
.47875 .6225 Mdot
.55125 .56625 Mdot
.55875 .51625 Mdot
.5075 .505 Mdot
.35 .4975 Mdot
.94 .51625 Mdot
.59875 .49875 Mdot
.92625 .47625 Mdot
.41625 .44 Mdot
.4275 .45125 Mdot
.41 .44 Mdot
.31375 .42625 Mdot
.62875 .41 Mdot
.37875 .4125 Mdot
.90375 .4375 Mdot
.3575 .40875 Mdot
.19625 .40875 Mdot
.7675 .405 Mdot
.33875 .395 Mdot
.8025 .325 Mdot
.45875 .33875 Mdot
.045 .42625 Mdot
.745 .51875 Mdot
.83125 .59375 Mdot
.10375 .68 Mdot
.635 .68875 Mdot
.6325 .575 Mdot
.36875 .5 Mdot
.88125 .46375 Mdot
.76875 .5 Mdot
.57375 .56125 Mdot
.325 .5825 Mdot
.14875 .54625 Mdot
.87375 .5175 Mdot
.5725 .4675 Mdot
.745 .44 Mdot
.4925 .44 Mdot
.42 .48625 Mdot
.09 .51 Mdot
.93125 .49625 Mdot
.445 .47625 Mdot
.5975 .46375 Mdot
.04625 .47 Mdot
.3875 .46125 Mdot
.73875 .47875 Mdot
.38625 .485 Mdot
.8925 .505 Mdot
.17375 .53375 Mdot
.715 .5325 Mdot
.20125 .5275 Mdot
.76375 .5575 Mdot
.56625 .58875 Mdot
.5525 .60375 Mdot
.2175 .6325 Mdot
.445 .625 Mdot
.69625 .5825 Mdot
.25375 .5425 Mdot
.52125 .44 Mdot
.30875 .51125 Mdot
.99625 .58375 Mdot
.29625 .62625 Mdot
.2175 .54625 Mdot
.7575 .6025 Mdot
.47875 .52375 Mdot
.35375 .4525 Mdot
.98875 .4275 Mdot
.12125 .4225 Mdot
.7275 .4575 Mdot
.14375 .48 Mdot
.96375 .46375 Mdot
.2725 .47 Mdot
.19375 .48 Mdot
.53875 .4675 Mdot
.975 .47125 Mdot
.4075 .51 Mdot
.44875 .515 Mdot
.52875 .51875 Mdot
.26875 .4475 Mdot
.28375 .4425 Mdot
.6475 .4775 Mdot
.385 .5 Mdot
.9475 .49375 Mdot
.31625 .485 Mdot
.0025 .47125 Mdot
.46 .4525 Mdot
.725 .37 Mdot
.355 .3775 Mdot
.81875 .41625 Mdot
.0575 .46375 Mdot
.75125 .5225 Mdot
.57375 .4425 Mdot
.755 .41625 Mdot
.62375 .46875 Mdot
.09 .415 Mdot
.85125 .395 Mdot
.18875 .44125 Mdot
.66625 .4225 Mdot
.3925 .43375 Mdot
.60625 .43625 Mdot
.44625 .4425 Mdot
.41375 .3975 Mdot
.59 .4075 Mdot
.4625 .325 Mdot
.61 .2975 Mdot
.6 .25375 Mdot
.515 .22625 Mdot
.2575 .265 Mdot
.23875 .31 Mdot
.64625 .36 Mdot
.65 .3875 Mdot
.37375 .51 Mdot
.53625 .515 Mdot
.45125 .53625 Mdot
.55625 .58375 Mdot
.63125 .615 Mdot
.43375 .55375 Mdot
.3425 .5525 Mdot
.985 .52125 Mdot
.59375 .48 Mdot
.86875 .5275 Mdot
.46625 .5425 Mdot
.42125 .53 Mdot
.35625 .5175 Mdot
.385 .53875 Mdot
.61 .53375 Mdot
.38875 .52125 Mdot
.885 .52375 Mdot
.375 .555 Mdot
.17375 .5275 Mdot
.67875 .52625 Mdot
.455 .57875 Mdot
.8025 .6275 Mdot
.43125 .6225 Mdot
.0525 .585 Mdot
.775 .55375 Mdot
.81375 .5125 Mdot
.06625 .4775 Mdot
.65625 .4725 Mdot
.60625 .53625 Mdot
.39625 .57375 Mdot
.9175 .5725 Mdot
.7675 .46375 Mdot
.59125 .4475 Mdot
.33625 .40625 Mdot
.12 .3925 Mdot
.87875 .4025 Mdot
.6125 .4225 Mdot
.7275 .3975 Mdot
.45625 .39 Mdot
.37125 .4075 Mdot
.1175 .45875 Mdot
.885 .5025 Mdot
.50375 .54 Mdot
.53375 .56 Mdot
.05 .55875 Mdot
.4125 .56 Mdot
.75375 .55375 Mdot
.33875 .56625 Mdot
.94625 .555 Mdot
.15375 .55375 Mdot
.68625 .52625 Mdot
.2175 .49625 Mdot
.73625 .44625 Mdot
.6525 .40375 Mdot
.47875 .3575 Mdot
.245 .3175 Mdot
.43625 .34 Mdot
.71875 .4125 Mdot
.26625 .46625 Mdot
.57125 .505 Mdot
.25375 .43 Mdot
.98875 .3675 Mdot
.255 .35625 Mdot
.29 .395 Mdot
.715 .45625 Mdot
.50375 .52875 Mdot
.33875 .56875 Mdot
.11875 .5625 Mdot
.66625 .53125 Mdot
.2075 .50125 Mdot
.92625 .515 Mdot
.305 .51 Mdot
.1575 .525 Mdot
.57625 .545 Mdot
.9725 .53375 Mdot
.375 .52375 Mdot
.4875 .53125 Mdot
.5025 .5425 Mdot
.25375 .52625 Mdot
.2275 .53 Mdot
.655 .54125 Mdot
.4275 .53 Mdot
.88625 .50375 Mdot
.33875 .4925 Mdot
.5375 .49375 Mdot
.7325 .55625 Mdot
.39 .56875 Mdot
.78625 .56375 Mdot
.03125 .5375 Mdot
.74625 .4825 Mdot
.57 .47375 Mdot
.83625 .49625 Mdot
.5675 .43125 Mdot
.03125 .435 Mdot
.96125 .46375 Mdot
.0925 .44 Mdot
.6675 .435 Mdot
.4525 .45 Mdot
.59125 .4375 Mdot
.4275 .415 Mdot
.46 .435 Mdot
.5225 .40625 Mdot
.52125 .41875 Mdot
.6125 .41875 Mdot
.555 .46 Mdot
.49375 .5025 Mdot
.25125 .44625 Mdot
.28 .36375 Mdot
.5925 .3 Mdot
.6825 .27375 Mdot
.35875 .2275 Mdot
.54375 .28125 Mdot
.46875 .3225 Mdot
.495 .33625 Mdot
.7025 .3575 Mdot
.41625 .40625 Mdot
.32625 .42375 Mdot
.93875 .44625 Mdot
.60875 .46125 Mdot
.84375 .46875 Mdot
.47125 .46625 Mdot
.395 .48625 Mdot
.3325 .5125 Mdot
.45875 .4925 Mdot
.63125 .4825 Mdot
.35125 .50875 Mdot
.7975 .51375 Mdot
.48625 .515 Mdot
.21125 .55875 Mdot
.555 .59 Mdot
.56 .58 Mdot
.72125 .62875 Mdot
.44375 .6075 Mdot
.05375 .58625 Mdot
.8225 .575 Mdot
.84625 .54625 Mdot
.645 .50125 Mdot
.6325 .48625 Mdot
.3625 .46375 Mdot
.94125 .505 Mdot
.7675 .6175 Mdot
.58875 .61875 Mdot
.3275 .65625 Mdot
.1125 .66875 Mdot
.87 .64875 Mdot
.64 .6275 Mdot
.71625 .66 Mdot
.46875 .65625 Mdot
.3175 .63125 Mdot
.1675 .555 Mdot
.765 .535 Mdot
.61875 .51875 Mdot
.4425 .48625 Mdot
.075 .47 Mdot
.43 .48 Mdot
.765 .4625 Mdot
.30125 .435 Mdot
.98875 .415 Mdot
.1325 .40625 Mdot
.6625 .47125 Mdot
.27375 .555 Mdot
.64875 .625 Mdot
.7725 .69125 Mdot
.3725 .7675 Mdot
.33 .77 Mdot
.385 .71125 Mdot
.7125 .6375 Mdot
.31125 .575 Mdot
.57625 .4575 Mdot
.29625 .48 Mdot
.82125 .49125 Mdot
.4025 .48 Mdot
.28375 .48125 Mdot
.63125 .4325 Mdot
.55625 .4375 Mdot
.315 .4825 Mdot
.0875 .53125 Mdot
.6425 .54625 Mdot
.22 .53625 Mdot
.92125 .485 Mdot
.3175 .48 Mdot
.12875 .47375 Mdot
.63875 .44375 Mdot
.92125 .46125 Mdot
.38625 .47 Mdot
.5075 .4525 Mdot
.52125 .445 Mdot
.28875 .5425 Mdot
.2 .5725 Mdot
.6475 .56125 Mdot
.42625 .55375 Mdot
.885 .58125 Mdot
.3475 .57125 Mdot
.55375 .5325 Mdot
.715 .4575 Mdot
.4225 .4475 Mdot
.73125 .42625 Mdot
.0225 .435 Mdot
.70875 .42625 Mdot
.59 .43 Mdot
.84375 .405 Mdot
.55875 .445 Mdot
.01375 .4875 Mdot
.68 .535 Mdot
.495 .5175 Mdot
.58625 .50375 Mdot
.47375 .47125 Mdot
.40625 .4625 Mdot
.47 .4925 Mdot
.59375 .53 Mdot
.6375 .57125 Mdot
.48375 .62375 Mdot
.5 .60625 Mdot
.01625 .59125 Mdot
.27875 .5475 Mdot
.3125 .52625 Mdot
.59125 .56625 Mdot
.67625 .5675 Mdot
.3175 .57875 Mdot
.56125 .55 Mdot
.52875 .5725 Mdot
.40625 .55375 Mdot
.765 .5375 Mdot
.3825 .51125 Mdot
.37875 .49625 Mdot
.875 .45375 Mdot
.64375 .4275 Mdot
.76375 .41125 Mdot
.48375 .4075 Mdot
.4 .38625 Mdot
.30875 .3475 Mdot
.52125 .36875 Mdot
.62 .43625 Mdot
.3575 .44 Mdot
.72375 .425 Mdot
.53125 .3875 Mdot
.2725 .37375 Mdot
.4575 .3125 Mdot
.605 .275 Mdot
.71625 .2725 Mdot
.48875 .325 Mdot
.00875 .335 Mdot
.7925 .32875 Mdot
.87125 .37375 Mdot
.00125 .39 Mdot
.61625 .3825 Mdot
.67375 .3925 Mdot
.34375 .42875 Mdot
.92375 .42625 Mdot
.75 .38625 Mdot
.545 .36625 Mdot
.36875 .36875 Mdot
.11875 .37625 Mdot
.82625 .38875 Mdot
.70875 .40875 Mdot
.66875 .4225 Mdot
.49125 .4175 Mdot
.32375 .3925 Mdot
.2275 .40875 Mdot
.65375 .41 Mdot
.6775 .4025 Mdot
.4075 .4275 Mdot
.065 .4475 Mdot
.48 .4375 Mdot
.7625 .45 Mdot
.25875 .485 Mdot
.17125 .5325 Mdot
.60375 .47875 Mdot
.3475 .39875 Mdot
.5425 .32625 Mdot
.9125 .275 Mdot
.20625 .2275 Mdot
.45625 .25125 Mdot
.34625 .31625 Mdot
.6725 .37125 Mdot
.38875 .415 Mdot
.5425 .55625 Mdot
.32375 .53 Mdot
.7725 .53375 Mdot
.43375 .525 Mdot
.30875 .51875 Mdot
.60625 .48625 Mdot
.56375 .49375 Mdot
.30875 .46125 Mdot
.03875 .4875 Mdot
.64 .50125 Mdot
.23125 .5125 Mdot
.92375 .54125 Mdot
.32 .54125 Mdot
.12125 .5125 Mdot
.675 .54875 Mdot
.88125 .53625 Mdot
.41125 .525 Mdot
.46125 .5275 Mdot
.60625 .53375 Mdot
.35625 .4475 Mdot
.2075 .36625 Mdot
.6125 .36125 Mdot
.475 .34 Mdot
.84625 .32875 Mdot
.37625 .3725 Mdot
.60375 .4025 Mdot
.65 .4725 Mdot
.4775 .49375 Mdot
.64 .51375 Mdot
.03625 .52 Mdot
.6 .5875 Mdot
.61 .58875 Mdot
.845 .59 Mdot
.56875 .54375 Mdot
.00625 .51625 Mdot
.0075 .48875 Mdot
.65375 .52625 Mdot
.4675 .5575 Mdot
.64 .56625 Mdot
.48375 .6325 Mdot
.38875 .67 Mdot
.4425 .6775 Mdot
.59625 .67375 Mdot
.68375 .63875 Mdot
.41375 .58125 Mdot
.5575 .555 Mdot
.0625 .5375 Mdot
.26 .61375 Mdot
.34 .65375 Mdot
.61625 .63125 Mdot
.7075 .58875 Mdot
.2525 .57 Mdot
.55625 .545 Mdot
.55875 .4475 Mdot
.41625 .44625 Mdot
.7625 .47 Mdot
.37 .41875 Mdot
.42375 .40375 Mdot
.805 .45875 Mdot
0 .7675 Mdot
.705 .7925 Mdot
.64125 .71875 Mdot
.53625 .70625 Mdot
.38125 .66875 Mdot
.30375 .6725 Mdot
.56875 .63625 Mdot
.59125 .52875 Mdot
.40375 .4575 Mdot
.63625 .46625 Mdot
.5775 .52875 Mdot
.31375 .59375 Mdot
.41625 .7225 Mdot
.64625 .79375 Mdot
.62125 .74125 Mdot
.545 .6325 Mdot
.04125 .545 Mdot
.69875 .51375 Mdot
.9525 .465 Mdot
.6325 .5125 Mdot
.6925 .49125 Mdot
.3475 .45875 Mdot
.91 .455 Mdot
.76125 .435 Mdot
.51375 .46625 Mdot
.36625 .4725 Mdot
.12375 .48375 Mdot
.84 .4725 Mdot
.735 .51625 Mdot
.61875 .52 Mdot
.51 .5275 Mdot
.31 .595 Mdot
.2575 .56875 Mdot
.5325 .56125 Mdot
.7525 .57 Mdot
.41375 .54125 Mdot
.0175 .5425 Mdot
.5375 .5525 Mdot
.78875 .5575 Mdot
.21625 .52875 Mdot
.9875 .49625 Mdot
.2075 .50875 Mdot
.53875 .5375 Mdot
.44625 .5975 Mdot
.4775 .635 Mdot
.04 .6975 Mdot
.55375 .68 Mdot
.3475 .6425 Mdot
.635 .63375 Mdot
.39875 .60875 Mdot
.01875 .56375 Mdot
.535 .535 Mdot
.33875 .555 Mdot
.77125 .545 Mdot
.3625 .555 Mdot
.37375 .55875 Mdot
.58625 .5675 Mdot
.58375 .5375 Mdot
.295 .51375 Mdot
.02875 .49125 Mdot
.64375 .48 Mdot
.21875 .4775 Mdot
.9025 .5 Mdot
.35375 .495 Mdot
.09375 .4925 Mdot
.7275 .47375 Mdot
.8325 .48 Mdot
.44375 .50375 Mdot
.41875 .49375 Mdot
.645 .47375 Mdot
.3625 .5425 Mdot
.235 .66625 Mdot
.59 .635 Mdot
.56375 .6675 Mdot
.75375 .69625 Mdot
.43625 .64625 Mdot
.66 .6 Mdot
.99875 .5675 Mdot
.0975 .51 Mdot
.535 .5325 Mdot
.575 .54125 Mdot
.54375 .53 Mdot
.06375 .53 Mdot
.515 .53375 Mdot
.62375 .58375 Mdot
.86125 .58375 Mdot
.56125 .57375 Mdot
.005 .50875 Mdot
.6225 .4625 Mdot
.48125 .45625 Mdot
.64375 .47375 Mdot
.52875 .43125 Mdot
.3375 .40625 Mdot
.425 .3825 Mdot
.63 .33875 Mdot
.70125 .3325 Mdot
.37625 .37 Mdot
.60875 .40625 Mdot
.0325 .44 Mdot
.97 .45625 Mdot
.2475 .45625 Mdot
.39 .48125 Mdot
.65125 .49625 Mdot
.66125 .54375 Mdot
.2225 .5225 Mdot
.54 .525 Mdot
.63375 .535 Mdot
.38875 .49125 Mdot
.75125 .4875 Mdot
.38625 .6325 Mdot
.41 .6725 Mdot
.79875 .695 Mdot
.025 .35875 Mdot
.76 .33875 Mdot
.54 .3975 Mdot
.58625 .42875 Mdot
.34375 .48 Mdot
.365 .49625 Mdot
.55875 .53625 Mdot
.56875 .63125 Mdot
.435 .6725 Mdot
.57 .64125 Mdot
.62 .595 Mdot
.36375 .47625 Mdot
.3775 .3275 Mdot
.665 .29875 Mdot
.5425 .3325 Mdot
.58 .41625 Mdot
.08375 .53125 Mdot
.64625 .58125 Mdot
.96125 .56625 Mdot
.61875 .5175 Mdot
.715 .55 Mdot
.3175 .5925 Mdot
.92625 .61125 Mdot
.74375 .6125 Mdot
.5075 .59875 Mdot
.34625 .54625 Mdot
.1675 .51 Mdot
.8475 .53375 Mdot
.735 .48 Mdot
.575 .41 Mdot
.52125 .415 Mdot
.32 .355 Mdot
.255 .43875 Mdot
.48875 .44375 Mdot
.795 .4275 Mdot
.41 .45625 Mdot
.0175 .44875 Mdot
.525 .46875 Mdot
.83375 .4575 Mdot
.1425 .495 Mdot
.23125 .53375 Mdot
.5025 .535 Mdot
.5025 .55875 Mdot
.39875 .555 Mdot
.61125 .4825 Mdot
.32375 .44 Mdot
.64625 .40875 Mdot
.39 .42375 Mdot
.03375 .39625 Mdot
.48875 .4125 Mdot
.40375 .43625 Mdot
.78625 .43875 Mdot
.25125 .4825 Mdot
.47375 .515 Mdot
.545 .5425 Mdot
.595 .54125 Mdot
.29875 .555 Mdot
.0575 .49125 Mdot
.64 .47875 Mdot
.23375 .48375 Mdot
.8575 .4825 Mdot
.365 .50125 Mdot
.09875 .53125 Mdot
.75875 .54125 Mdot
.78625 .5125 Mdot
.505 .47125 Mdot
.3525 .4775 Mdot
.67875 .4625 Mdot
.36125 .46 Mdot
.32875 .38625 Mdot
.55625 .37375 Mdot
.63375 .3725 Mdot
.67 .3575 Mdot
.4575 .4625 Mdot
.69 .575 Mdot
.92375 .6075 Mdot
.17625 .6625 Mdot
.455 .6275 Mdot
.665 .61 Mdot
.455 .53375 Mdot
.11 .5225 Mdot
.39875 .3925 Mdot
.6575 .37375 Mdot
.8825 .35375 Mdot
.5475 .37875 Mdot
.06625 .4775 Mdot
.585 .50125 Mdot
.495 .5075 Mdot
.6825 .48625 Mdot
.51125 .51 Mdot
.32375 .4925 Mdot
.46125 .49 Mdot
.515 .48375 Mdot
.80625 .50875 Mdot
.3275 .445 Mdot
.61625 .46875 Mdot
.05625 .48875 Mdot
.95375 .4975 Mdot
.21875 .495 Mdot
.46125 .505 Mdot
.6475 .49625 Mdot
.67625 .48875 Mdot
.105 .52375 Mdot
.54625 .54125 Mdot
.68 .5425 Mdot
.43625 .5725 Mdot
.6825 .545 Mdot
.435 .4675 Mdot
.445 .44 Mdot
.72125 .42875 Mdot
.79625 .45 Mdot
.47875 .46375 Mdot
.64 .46 Mdot
.31125 .43375 Mdot
.39125 .415 Mdot
.55125 .40125 Mdot
.57125 .36 Mdot
.4175 .35875 Mdot
.52 .38 Mdot
.7 .4525 Mdot
.4 .54875 Mdot
.36375 .615 Mdot
.63375 .59 Mdot
.5075 .58375 Mdot
.62375 .53 Mdot
.035 .4575 Mdot
.6575 .42 Mdot
.98 .485 Mdot
.00625 .5075 Mdot
.57625 .505 Mdot
.7475 .4975 Mdot
.29875 .49125 Mdot
.91125 .4575 Mdot
.6975 .49 Mdot
.5575 .48625 Mdot
.3175 .54125 Mdot
.2025 .5775 Mdot
.83375 .57125 Mdot
.71 .58875 Mdot
.60125 .64625 Mdot
.525 .63375 Mdot
.37375 .65375 Mdot
.27375 .52875 Mdot
.42375 .49875 Mdot
.81625 .45875 Mdot
.4275 .4125 Mdot
.01375 .4175 Mdot
.52625 .43 Mdot
.83125 .45125 Mdot
.1325 .4475 Mdot
.25625 .3975 Mdot
.47625 .36875 Mdot
.52125 .30875 Mdot
.3775 .3225 Mdot
.5975 .39125 Mdot
.34875 .4325 Mdot
.61 .465 Mdot
.39125 .48125 Mdot
.0525 .55375 Mdot
.46125 .575 Mdot
.41625 .545 Mdot
.84375 .54625 Mdot
.16875 .49875 Mdot
.51375 .45625 Mdot
.565 .4375 Mdot
.54375 .42625 Mdot
.35625 .42625 Mdot
.13 .5075 Mdot
.625 .5175 Mdot
.23625 .5575 Mdot
.84625 .5725 Mdot
.365 .5575 Mdot
.095 .55375 Mdot
.785 .57125 Mdot
.73 .6025 Mdot
.5575 .60875 Mdot
.35125 .60125 Mdot
.67125 .6425 Mdot
.40875 .5775 Mdot
.84875 .555 Mdot
.44875 .575 Mdot
.5425 .5725 Mdot
.65125 .5575 Mdot
.615 .51875 Mdot
.49125 .41875 Mdot
.69125 .335 Mdot
.8875 .2925 Mdot
.2275 .28625 Mdot
.4025 .35125 Mdot
.7325 .38625 Mdot
.4 .4925 Mdot
.1075 .515 Mdot
.31125 .59875 Mdot
.64875 .55125 Mdot
.92875 .5925 Mdot
.53375 .58625 Mdot
.95875 .52375 Mdot
.1475 .50625 Mdot
.58375 .5 Mdot
.445 .5 Mdot
.73875 .51 Mdot
.51625 .49875 Mdot
.31 .50875 Mdot
.4875 .5075 Mdot
.4025 .545 Mdot
.90125 .58 Mdot
.315 .62375 Mdot
.66 .595 Mdot
.0225 .57125 Mdot
.9475 .5475 Mdot
.18125 .5275 Mdot
.505 .5025 Mdot
.69125 .50375 Mdot
.63375 .50875 Mdot
.07 .5075 Mdot
.52625 .5 Mdot
.6975 .545 Mdot
.4875 .57625 Mdot
.6325 .56625 Mdot
.4425 .53 Mdot
.50375 .50125 Mdot
.70625 .46625 Mdot
.0275 .49875 Mdot
.77125 .48375 Mdot
.48125 .45375 Mdot
.63 .455 Mdot
.3425 .51 Mdot
.38375 .5625 Mdot
.5275 .5475 Mdot
.57 .55125 Mdot
.42875 .5475 Mdot
.5275 .55 Mdot
.69 .49875 Mdot
.4175 .47625 Mdot
.33625 .49875 Mdot
.645 .51 Mdot
.49875 .51375 Mdot
.67125 .54 Mdot
.0175 .54875 Mdot
.61125 .57875 Mdot
.9775 .56 Mdot
.0425 .57125 Mdot
.58625 .56125 Mdot
.7275 .57625 Mdot
.305 .53625 Mdot
.9225 .53 Mdot
.64875 .49875 Mdot
.62625 .5 Mdot
.3 .495 Mdot
.20375 .49625 Mdot
.8275 .4925 Mdot
.665 .485 Mdot
.67125 .465 Mdot
.49625 .45 Mdot
.4275 .3875 Mdot
.285 .4725 Mdot
.44875 .51875 Mdot
.7775 .63875 Mdot
.45875 .7375 Mdot
.53 .70375 Mdot
.83875 .67625 Mdot
.13625 .59 Mdot
.22875 .5775 Mdot
.53625 .63625 Mdot
.43 .6425 Mdot
.4775 .6575 Mdot
.0025 .62125 Mdot
.56125 .60375 Mdot
.37 .6275 Mdot
.63 .59875 Mdot
.355 .565 Mdot
.04125 .4525 Mdot
.42625 .405 Mdot
.44375 .39875 Mdot
.89125 .405 Mdot
.095 .45125 Mdot
.555 .48875 Mdot
.5925 .51125 Mdot
.4875 .53375 Mdot
.435 .5475 Mdot
.87375 .51125 Mdot
.25625 .4975 Mdot
.55 .4925 Mdot
.2675 .44625 Mdot
.88125 .395 Mdot
.29 .4025 Mdot
.1575 .38125 Mdot
.7475 .33 Mdot
.7075 .34625 Mdot
.62375 .3625 Mdot
.32625 .3775 Mdot
.63625 .38875 Mdot
.4 .45875 Mdot
.68625 .515 Mdot
.55 .5075 Mdot
.56 .57375 Mdot
.68875 .6 Mdot
.51 .645 Mdot
.53 .6275 Mdot
.7275 .60125 Mdot
.84625 .60375 Mdot
.25 .56625 Mdot
.32375 .54875 Mdot
.82375 .50875 Mdot
.37125 .4725 Mdot
.13125 .46875 Mdot
.27375 .43375 Mdot
.68375 .475 Mdot
.99375 .47 Mdot
.4575 .485 Mdot
.01625 .50875 Mdot
.86875 .5275 Mdot
.25875 .51375 Mdot
.57625 .5075 Mdot
.40625 .50875 Mdot
.7325 .53 Mdot
.515 .59375 Mdot
.33375 .60375 Mdot
.5575 .60625 Mdot
.23125 .62375 Mdot
.3325 .46 Mdot
.6125 .435 Mdot
.07125 .4025 Mdot
.92875 .3875 Mdot
.12 .41 Mdot
.58625 .455 Mdot
.6925 .505 Mdot
.58375 .51625 Mdot
.0875 .465 Mdot
.46875 .4625 Mdot
.755 .4125 Mdot
.49625 .34875 Mdot
.58625 .38875 Mdot
.52 .45875 Mdot
.44875 .49625 Mdot
.69625 .47875 Mdot
.08375 .51125 Mdot
.73625 .54625 Mdot
.53 .585 Mdot
.59125 .57125 Mdot
.36625 .5475 Mdot
.36375 .51375 Mdot
.50375 .5075 Mdot
.6175 .48625 Mdot
.405 .4825 Mdot
.5025 .45875 Mdot
.72125 .415 Mdot
.42875 .40375 Mdot
.3375 .38625 Mdot
.665 .4225 Mdot
.39875 .445 Mdot
.73125 .47375 Mdot
.04125 .52125 Mdot
.5825 .51625 Mdot
.9675 .4975 Mdot
.0525 .4925 Mdot
.6075 .52875 Mdot
.72375 .50375 Mdot
.30125 .51125 Mdot
.90625 .485 Mdot
.63 .45125 Mdot
.71 .43875 Mdot
.26125 .42625 Mdot
.21375 .3975 Mdot
.82875 .385 Mdot
.59625 .3825 Mdot
.7375 .38375 Mdot
.5025 .41125 Mdot
.41125 .53875 Mdot
.295 .5525 Mdot
.49125 .52625 Mdot
.73125 .4375 Mdot
.47125 .3575 Mdot
.025 .28125 Mdot
.4975 .2675 Mdot
.8225 .265 Mdot
.1725 .33875 Mdot
.18125 .38875 Mdot
.57375 .34625 Mdot
.36875 .28125 Mdot
.58875 .23875 Mdot
.9425 .22 Mdot
.06 .27625 Mdot
.51125 .3075 Mdot
.38125 .38 Mdot
.65625 .41125 Mdot
.33875 .44625 Mdot
.0025 .51625 Mdot
.4275 .5325 Mdot
.4725 .54375 Mdot
.92875 .54 Mdot
.005 .50375 Mdot
.61875 .49875 Mdot
.59 .50625 Mdot
.44125 .50375 Mdot
.535 .51125 Mdot
.7275 .51 Mdot
.38625 .5225 Mdot
.465 .51625 Mdot
.3 .5375 Mdot
.9325 .56 Mdot
.2075 .5575 Mdot
.21375 .5575 Mdot
.685 .55875 Mdot
.715 .525 Mdot
.6825 .51125 Mdot
.32 .505 Mdot
.59375 .47875 Mdot
.3725 .47875 Mdot
.59375 .46875 Mdot
.62125 .46125 Mdot
.59875 .43 Mdot
.70125 .41125 Mdot
.415 .41125 Mdot
.56125 .44125 Mdot
.7075 .48 Mdot
.9475 .50625 Mdot
.17625 .52625 Mdot
.32625 .515 Mdot
.82375 .515 Mdot
.4025 .5225 Mdot
.18875 .4925 Mdot
.33625 .58 Mdot
.7075 .5925 Mdot
.3575 .61625 Mdot
.06875 .61 Mdot
.76875 .62875 Mdot
.36125 .615 Mdot
.535 .56625 Mdot
.46625 .51375 Mdot
.68875 .4475 Mdot
.505 .34125 Mdot
.35875 .32375 Mdot
.5725 .31375 Mdot
.155 .2925 Mdot
.41125 .47 Mdot
.50625 .525 Mdot
.1275 .605 Mdot
.9275 .64875 Mdot
.07875 .6425 Mdot
.67875 .545 Mdot
.64625 .48125 Mdot
.5325 .4375 Mdot
.14 .50625 Mdot
.415 .5 Mdot
.82125 .5475 Mdot
.45375 .57375 Mdot
.5775 .53125 Mdot
.555 .45375 Mdot
.4325 .45375 Mdot
.665 .47625 Mdot
.13875 .565 Mdot
.64625 .51625 Mdot
.66625 .4925 Mdot
.49 .50375 Mdot
.3825 .4875 Mdot
.39125 .4575 Mdot
.48375 .4775 Mdot
.65375 .49875 Mdot
.3225 .5 Mdot
.56 .53875 Mdot
.69375 .57875 Mdot
.46375 .58375 Mdot
.3025 .55625 Mdot
.67875 .4975 Mdot
.37 .46875 Mdot
.79875 .455 Mdot
.01625 .41 Mdot
.57125 .39 Mdot
.92875 .4075 Mdot
.1025 .38625 Mdot
.61125 .3325 Mdot
.74 .34625 Mdot
.255 .38375 Mdot
.91 .43 Mdot
.59625 .53125 Mdot
.81 .5575 Mdot
.2075 .57125 Mdot
.21375 .58125 Mdot
.83625 .57125 Mdot
.535 .57375 Mdot
.81125 .59 Mdot
.49625 .59125 Mdot
.4025 .52 Mdot
.2625 .47875 Mdot
.63375 .47375 Mdot
.6025 .5125 Mdot
.5075 .55875 Mdot
.06375 .62625 Mdot
.43875 .6825 Mdot
.81 .735 Mdot
.2025 .71 Mdot
.14875 .69875 Mdot
.6175 .71625 Mdot
.2775 .8075 Mdot
.70125 .85625 Mdot
.8225 .87 Mdot
.17375 .81875 Mdot
.4625 .75 Mdot
.3875 .5975 Mdot
.66375 .56625 Mdot
.31625 .52875 Mdot
.38 .52125 Mdot
.51 .495 Mdot
.9925 .46875 Mdot
.6375 .4475 Mdot
.5975 .4475 Mdot
.4025 .4525 Mdot
.63375 .45625 Mdot
.57125 .4825 Mdot
.52625 .465 Mdot
.3575 .48625 Mdot
.3825 .4675 Mdot
.975 .49 Mdot
.05375 .49125 Mdot
.36125 .50375 Mdot
.58375 .51875 Mdot
.70125 .5525 Mdot
.76125 .53625 Mdot
.2925 .54625 Mdot
.59625 .57 Mdot
.42375 .4975 Mdot
.64125 .41875 Mdot
.6225 .40875 Mdot
.6525 .40375 Mdot
.69125 .415 Mdot
.34125 .4375 Mdot
.5675 .44875 Mdot
.6325 .45625 Mdot
.06125 .425 Mdot
.41625 .4225 Mdot
.6975 .465 Mdot
.51625 .5025 Mdot
.27625 .51875 Mdot
.37375 .42625 Mdot
.75 .36375 Mdot
.2725 .31625 Mdot
.06875 .33 Mdot
.78125 .3325 Mdot
.41375 .40375 Mdot
.475 .49 Mdot
.52375 .55 Mdot
.60125 .595 Mdot
.56125 .6375 Mdot
.375 .61875 Mdot
.58875 .62625 Mdot
.0725 .66125 Mdot
.465 .58375 Mdot
.3725 .5575 Mdot
.25875 .4975 Mdot
.88875 .46 Mdot
.03625 .48375 Mdot
.77 .52 Mdot
.61625 .52625 Mdot
.47375 .54875 Mdot
.17875 .49 Mdot
.37625 .48625 Mdot
.8775 .45625 Mdot
.4225 .48 Mdot
.5575 .525 Mdot
.57125 .57375 Mdot
.475 .57 Mdot
.61125 .57375 Mdot
.19875 .37875 Mdot
.61875 .40375 Mdot
.6175 .4325 Mdot
.51875 .4525 Mdot
.4025 .47625 Mdot
.3575 .51875 Mdot
.5175 .54 Mdot
.655 .5525 Mdot
.27625 .5575 Mdot
.62375 .5325 Mdot
.61875 .525 Mdot
.48625 .5075 Mdot
.3325 .495 Mdot
.705 .515 Mdot
.25875 .5075 Mdot
.91125 .4925 Mdot
.6125 .51375 Mdot
.8925 .4875 Mdot
.07125 .51 Mdot
.69 .55375 Mdot
.71 .535 Mdot
.2575 .505 Mdot
.87375 .50375 Mdot
.58375 .4075 Mdot
.8775 .415 Mdot
.1675 .4225 Mdot
.2575 .44875 Mdot
.77125 .49375 Mdot
.49625 .52 Mdot
.915 .5225 Mdot
.46375 .5225 Mdot
.36875 .5175 Mdot
.21 .5425 Mdot
.8 .54625 Mdot
.4325 .53875 Mdot
.5675 .54125 Mdot
.07375 .51125 Mdot
.41375 .47875 Mdot
.795 .44 Mdot
.28625 .45125 Mdot
.13 .405 Mdot
.65 .3925 Mdot
.21125 .38 Mdot
.79 .33125 Mdot
.7425 .35375 Mdot
.23875 .36125 Mdot
.43375 .3975 Mdot
.405 .46 Mdot
.65625 .48625 Mdot
.28625 .505 Mdot
.3925 .53375 Mdot
.51125 .5725 Mdot
.5875 .63875 Mdot
.66375 .6 Mdot
.3425 .575 Mdot
.7275 .53625 Mdot
.4425 .49375 Mdot
.615 .50125 Mdot
.28125 .4975 Mdot
.47375 .52125 Mdot
.515 .54 Mdot
.45375 .54125 Mdot
.70125 .4875 Mdot
.86 .4975 Mdot
.2175 .49 Mdot
.61125 .4525 Mdot
.4425 .455 Mdot
.58375 .50625 Mdot
.67125 .5125 Mdot
.6825 .5325 Mdot
.7 .545 Mdot
.28625 .51375 Mdot
.565 .49125 Mdot
.05 .485 Mdot
.50125 .465 Mdot
.51625 .53 Mdot
.55875 .5475 Mdot
.64125 .5275 Mdot
.36875 .49 Mdot
.79875 .4875 Mdot
.39625 .48 Mdot
.73625 .49 Mdot
.2075 .5175 Mdot
.08625 .48625 Mdot
.85625 .43 Mdot
.3875 .40625 Mdot
.46625 .3925 Mdot
.5125 .405 Mdot
.545 .43625 Mdot
.6225 .4875 Mdot
.36875 .53875 Mdot
.59875 .52625 Mdot
.055 .465 Mdot
.5225 .41125 Mdot
.3 .375 Mdot
.3425 .3975 Mdot
.88 .41375 Mdot
.81 .42 Mdot
.61875 .43625 Mdot
.41 .4525 Mdot
.23125 .505 Mdot
.41875 .53 Mdot
.88375 .55625 Mdot
.34 .53375 Mdot
.56125 .4875 Mdot
.6075 .43 Mdot
.4425 .3975 Mdot
.6275 .37375 Mdot
.265 .57375 Mdot
.64 .5825 Mdot
.5075 .535 Mdot
.56 .4925 Mdot
.44375 .49875 Mdot
.315 .4825 Mdot
.535 .45125 Mdot
.66625 .4875 Mdot
.2475 .49875 Mdot
.6925 .49375 Mdot
.5375 .49625 Mdot
.46875 .4875 Mdot
.43875 .46125 Mdot
.64375 .45125 Mdot
.2 .4475 Mdot
.65875 .49125 Mdot
.80625 .53375 Mdot
.10125 .55375 Mdot
.71625 .53625 Mdot
.6825 .57 Mdot
.26 .6025 Mdot
.88 .58875 Mdot
.54625 .63625 Mdot
.9175 .6 Mdot
.125 .565 Mdot
.3225 .53 Mdot
.725 .48125 Mdot
.4525 .43125 Mdot
.975 .40875 Mdot
.4625 .3825 Mdot
.39125 .3525 Mdot
.18875 .32875 Mdot
.985 .3425 Mdot
.255 .3225 Mdot
.6375 .32375 Mdot
.09375 .34875 Mdot
.35375 .39 Mdot
.81875 .40125 Mdot
.3275 .41625 Mdot
.955 .465 Mdot
.0975 .45875 Mdot
.72625 .445 Mdot
.1075 .39375 Mdot
.90375 .3925 Mdot
.70875 .35625 Mdot
.19 .35875 Mdot
.4725 .37125 Mdot
.39375 .38625 Mdot
.65875 .4075 Mdot
.275 .44875 Mdot
.38875 .455 Mdot
.54625 .45 Mdot
.5575 .38125 Mdot
.7225 .40375 Mdot
.2975 .37875 Mdot
.77875 .38375 Mdot
.3525 .4125 Mdot
.68125 .425 Mdot
.2175 .43875 Mdot
.5425 .43625 Mdot
.665 .47125 Mdot
.3475 .475 Mdot
.69625 .5125 Mdot
.97375 .5 Mdot
.0925 .49375 Mdot
.67625 .50625 Mdot
.43375 .515 Mdot
.5275 .53625 Mdot
.69875 .55625 Mdot
.70375 .59125 Mdot
.73125 .56375 Mdot
.25 .5625 Mdot
.535 .5575 Mdot
.115 .55375 Mdot
.4025 .5425 Mdot
.52625 .45625 Mdot
.5525 .43375 Mdot
.665 .42375 Mdot
.5025 .43 Mdot
.48 .47125 Mdot
.185 .51125 Mdot
.34375 .52375 Mdot
.74125 .5625 Mdot
.11625 .54125 Mdot
.15625 .5625 Mdot
.86625 .60625 Mdot
.41375 .6025 Mdot
.43625 .59875 Mdot
.5625 .5425 Mdot
.42375 .46875 Mdot
.7125 .3875 Mdot
.3275 .34125 Mdot
.62625 .39625 Mdot
.05 .44125 Mdot
.535 .52375 Mdot
.1925 .54875 Mdot
.43875 .515 Mdot
.92875 .49125 Mdot
.895 .5 Mdot
.58 .4875 Mdot
.3675 .48625 Mdot
.25125 .48 Mdot
.45875 .4675 Mdot
.8725 .465 Mdot
.31625 .47875 Mdot
.5475 .49 Mdot
.65625 .53125 Mdot
.44625 .56 Mdot
.5675 .56625 Mdot
.2925 .42875 Mdot
.69625 .42625 Mdot
.345 .46375 Mdot
.68125 .4725 Mdot
.43125 .4075 Mdot
.2675 .46125 Mdot
.5825 .47125 Mdot
.66125 .43625 Mdot
.22 .45 Mdot
.75375 .44 Mdot
.4525 .47125 Mdot
.43375 .55 Mdot
.61375 .615 Mdot
.545 .63625 Mdot
.13125 .66875 Mdot
.7325 .605 Mdot
.72125 .5825 Mdot
.14375 .56125 Mdot
.69 .54625 Mdot
.705 .4925 Mdot
.27375 .445 Mdot
.85375 .43625 Mdot
.56125 .405 Mdot
.92625 .46 Mdot
.12125 .5 Mdot
.35625 .51625 Mdot
.685 .56875 Mdot
.43 .61625 Mdot
.46375 .61375 Mdot
.3925 .615 Mdot
.145 .63875 Mdot
.06125 .6775 Mdot
.72375 .67125 Mdot
.1125 .63375 Mdot
.28875 .61125 Mdot
.835 .6 Mdot
.36625 .56125 Mdot
.8875 .5475 Mdot
.145 .56625 Mdot
.72 .57125 Mdot
.0975 .60625 Mdot
.90625 .62875 Mdot
.7125 .63875 Mdot
.19125 .61375 Mdot
.45 .6 Mdot
.45375 .56 Mdot
.59625 .50875 Mdot
.29125 .435 Mdot
.395 .415 Mdot
.56 .44875 Mdot
.525 .57 Mdot
.8 .57625 Mdot
.225 .6125 Mdot
.84125 .6325 Mdot
.26875 .6 Mdot
.7275 .575 Mdot
.16625 .54875 Mdot
.61125 .51375 Mdot
.73625 .48 Mdot
.2975 .495 Mdot
.67625 .51125 Mdot
.7325 .52625 Mdot
.41625 .575 Mdot
.48125 .565 Mdot
.75375 .54375 Mdot
.67625 .46875 Mdot
.75875 .4875 Mdot
.25 .53 Mdot
.465 .5525 Mdot
.20625 .555 Mdot
.3375 .555 Mdot
.0325 .5275 Mdot
.47625 .54125 Mdot
.6 .54625 Mdot
.63125 .49125 Mdot
.58125 .53625 Mdot
.30375 .5225 Mdot
.29375 .4825 Mdot
.4325 .45625 Mdot
.6375 .47375 Mdot
.0225 .44375 Mdot
.32125 .4375 Mdot
.76375 .4925 Mdot
.425 .51 Mdot
.45625 .535 Mdot
.605 .55625 Mdot
.30625 .60125 Mdot
.8125 .615 Mdot
.27875 .63875 Mdot
.66625 .57625 Mdot
.05125 .54 Mdot
.55875 .495 Mdot
.155 .52375 Mdot
.46375 .58 Mdot
.9225 .54375 Mdot
.565 .5 Mdot
.32875 .48 Mdot
.3025 .47 Mdot
.48625 .5025 Mdot
.83 .51375 Mdot
.3125 .54875 Mdot
.575 .525 Mdot
.66625 .50125 Mdot
.35625 .48375 Mdot
.6175 .5325 Mdot
.3 .7325 Mdot
.72 .705 Mdot
.22375 .6925 Mdot
.8025 .69 Mdot
.4075 .68375 Mdot
.235 .595 Mdot
.63125 .56 Mdot
.62625 .5175 Mdot
.215 .48875 Mdot
.80125 .47875 Mdot
.4125 .45375 Mdot
.36 .385 Mdot
.7725 .37 Mdot
.47 .36625 Mdot
.0975 .39 Mdot
.775 .51 Mdot
.66125 .51375 Mdot
.185 .495 Mdot
.695 .48 Mdot
.69 .50125 Mdot
.26125 .50875 Mdot
.88875 .5175 Mdot
.56625 .56 Mdot
.9275 .51625 Mdot
.11 .48375 Mdot
.38125 .465 Mdot
.6775 .41375 Mdot
.385 .3975 Mdot
.46375 .42625 Mdot
.4075 .46 Mdot
.98125 .4375 Mdot
.10875 .46625 Mdot
.85375 .42875 Mdot
.09 .46125 Mdot
.23625 .4575 Mdot
.855 .46125 Mdot
.41125 .47125 Mdot
.8275 .49125 Mdot
.165 .45125 Mdot
.75375 .44375 Mdot
.065 .43375 Mdot
.885 .42875 Mdot
.7225 .4225 Mdot
.23625 .48875 Mdot
.3975 .50375 Mdot
.50875 .55375 Mdot
.55 .6 Mdot
.285 .6475 Mdot
.4125 .635 Mdot
.575 .55125 Mdot
.45 .45 Mdot
.90625 .455 Mdot
.17875 .4825 Mdot
.8325 .4925 Mdot
.22625 .51375 Mdot
.76375 .50125 Mdot
.125 .49875 Mdot
.65875 .51375 Mdot
.77875 .44875 Mdot
.34625 .44375 Mdot
.5675 .42 Mdot
.7575 .50375 Mdot
.3725 .505 Mdot
.41625 .49 Mdot
.81625 .47875 Mdot
.64875 .5 Mdot
.77125 .465 Mdot
.2575 .4175 Mdot
.425 .4425 Mdot
.25125 .4375 Mdot
.34 .45875 Mdot
.13625 .505 Mdot
.40875 .46875 Mdot
.63375 .4525 Mdot
.62 .46125 Mdot
.5675 .5075 Mdot
.36 .49 Mdot
.225 .5175 Mdot
.5275 .59 Mdot
.5525 .59375 Mdot
.01875 .60375 Mdot
.41875 .58125 Mdot
.70625 .50375 Mdot
.38375 .49 Mdot
.49875 .40625 Mdot
.59875 .435 Mdot
.23375 .4225 Mdot
.88125 .43875 Mdot
.24375 .43 Mdot
.7275 .48625 Mdot
.07375 .51625 Mdot
.93875 .53375 Mdot
.5575 .53625 Mdot
.135 .49875 Mdot
.49875 .42875 Mdot
.92625 .4775 Mdot
.6 .54 Mdot
.26875 .54125 Mdot
.38875 .51 Mdot
.44 .4425 Mdot
.79125 .4 Mdot
.38125 .34625 Mdot
.57125 .42875 Mdot
.6675 .5025 Mdot
.26 .57125 Mdot
.69 .6075 Mdot
.3125 .2875 Mdot
.77375 .32125 Mdot
.10625 .3225 Mdot
.935 .35 Mdot
.3425 .40125 Mdot
.20875 .455 Mdot
.66125 .49125 Mdot
.635 .52375 Mdot
.2 .53 Mdot
.8025 .54375 Mdot
.44875 .5475 Mdot
.24625 .57125 Mdot
.93625 .5675 Mdot
.415 .55875 Mdot
.06375 .5375 Mdot
.77375 .42375 Mdot
.655 .40625 Mdot
.17125 .4225 Mdot
.68875 .4675 Mdot
.68375 .515 Mdot
.3025 .52125 Mdot
.86125 .54875 Mdot
.60375 .52625 Mdot
.895 .5 Mdot
.1375 .51125 Mdot
.39875 .5175 Mdot
.64125 .52125 Mdot
.35875 .485 Mdot
.43625 .5025 Mdot
.4325 .525 Mdot
.91625 .56 Mdot
.0975 .535 Mdot
.93375 .5675 Mdot
.0925 .565 Mdot
.17625 .57 Mdot
.86875 .55625 Mdot
.42375 .555 Mdot
.825 .5275 Mdot
.16875 .57 Mdot
.77625 .59125 Mdot
.06625 .64 Mdot
.83125 .67 Mdot
.76375 .68625 Mdot
.23125 .6275 Mdot
.37125 .6025 Mdot
.54625 .5625 Mdot
.50625 .5125 Mdot
.325 .5 Mdot
.465 .4775 Mdot
.57375 .505 Mdot
.9975 .5125 Mdot
.43375 .51125 Mdot
.995 .525 Mdot
.1225 .52625 Mdot
.8175 .53375 Mdot
.205 .545 Mdot
.77375 .55875 Mdot
.09125 .54375 Mdot
.68125 .545 Mdot
.77 .57875 Mdot
.41625 .57875 Mdot
.46375 .57375 Mdot
.7625 .45375 Mdot
.26125 .415 Mdot
.32625 .44625 Mdot
.9 .4425 Mdot
.595 .4525 Mdot
.78 .46625 Mdot
.315 .45625 Mdot
.37125 .44125 Mdot
.28 .4475 Mdot
.37875 .4775 Mdot
.31125 .5625 Mdot
.28 .59125 Mdot
.77625 .565 Mdot
.485 .6225 Mdot
.57125 .50875 Mdot
.425 .5 Mdot
.22875 .475 Mdot
.5425 .485 Mdot
.4975 .3975 Mdot
.015 .52 Mdot
.54 .525 Mdot
.61 .54125 Mdot
.355 .55625 Mdot
.55875 .5425 Mdot
.5425 .4875 Mdot
.28625 .4975 Mdot
.81 .50875 Mdot
.3 .525 Mdot
.71375 .4925 Mdot
.13 .4875 Mdot
.85375 .48 Mdot
.5875 .48375 Mdot
.09875 .47875 Mdot
.5475 .54 Mdot
.8825 .52 Mdot
.6375 .50875 Mdot
.23 .5125 Mdot
.44375 .5225 Mdot
.49875 .57125 Mdot
.68 .65375 Mdot
.425 .735 Mdot
.595 .6625 Mdot
.6175 .61875 Mdot
.2875 .54125 Mdot
.66375 .4175 Mdot
.30125 .52 Mdot
.7825 .49375 Mdot
.14625 .47875 Mdot
.91375 .46375 Mdot
.3075 .5 Mdot
.23625 .495 Mdot
.63875 .51 Mdot
.69 .50875 Mdot
.15625 .52125 Mdot
.76625 .5325 Mdot
.53625 .51875 Mdot
.13875 .4925 Mdot
.34 .5125 Mdot
.1125 .485 Mdot
.72625 .4625 Mdot
.65 .4725 Mdot
.20625 .47875 Mdot
.65875 .475 Mdot
.715 .4475 Mdot
.2975 .485 Mdot
.875 .48125 Mdot
.6325 .495 Mdot
.8775 .535 Mdot
.15 .53875 Mdot
.39375 .54375 Mdot
.66125 .56125 Mdot
.3175 .59625 Mdot
.4975 .58 Mdot
.46625 .5375 Mdot
.83 .50125 Mdot
.1025 .47375 Mdot
.9575 .385 Mdot
.1025 .35375 Mdot
.14 .345 Mdot
.865 .355 Mdot
.425 .3725 Mdot
.84625 .3775 Mdot
.15375 .39875 Mdot
.80875 .40375 Mdot
.075 .36375 Mdot
.75625 .34375 Mdot
.82375 .36 Mdot
.2175 .36625 Mdot
.365 .4 Mdot
.57625 .44 Mdot
.4425 .4575 Mdot
.405 .4375 Mdot
.51875 .44625 Mdot
.54375 .47625 Mdot
.9775 .50125 Mdot
.46625 .51375 Mdot
.08875 .46625 Mdot
.78125 .45 Mdot
.22375 .44375 Mdot
.78 .42625 Mdot
.0925 .4575 Mdot
.645 .46625 Mdot
.70875 .4625 Mdot
.54875 .46625 Mdot
.36125 .4725 Mdot
.80375 .5475 Mdot
.14125 .54 Mdot
.4275 .51625 Mdot
.8425 .52125 Mdot
.56625 .5 Mdot
.79125 .53 Mdot
.34875 .5225 Mdot
.34125 .515 Mdot
.26 .5225 Mdot
.5525 .51 Mdot
.74375 .4975 Mdot
.51 .46 Mdot
.14125 .45625 Mdot
.9225 .42 Mdot
.29125 .45375 Mdot
.695 .47625 Mdot
.42375 .4725 Mdot
.1925 .455 Mdot
.5875 .43 Mdot
.4625 .4175 Mdot
.65 .42125 Mdot
.54 .46625 Mdot
.30125 .4325 Mdot
.61 .50125 Mdot
.54375 .49 Mdot
.375 .45 Mdot
.6375 .41875 Mdot
.39 .4325 Mdot
.67875 .42375 Mdot
.2675 .4125 Mdot
.71375 .42875 Mdot
.59375 .44875 Mdot
.1075 .45 Mdot
.55375 .43375 Mdot
.7975 .4325 Mdot
.70625 .4725 Mdot
.18375 .49 Mdot
.52 .5225 Mdot
.43 .5325 Mdot
.68375 .50125 Mdot
.44125 .405 Mdot
.65875 .4175 Mdot
.50125 .42875 Mdot
.39625 .44125 Mdot
.60125 .44375 Mdot
.295 .5175 Mdot
.77125 .55 Mdot
.2425 .5575 Mdot
.89 .5675 Mdot
.2475 .54125 Mdot
.285 .51875 Mdot
.59625 .46375 Mdot
.74625 .45625 Mdot
.13125 .44375 Mdot
.7075 .45375 Mdot
.6075 .4575 Mdot
.08375 .465 Mdot
.29375 .4425 Mdot
.1675 .445 Mdot
.7025 .51125 Mdot
.66125 .5525 Mdot
.20125 .5375 Mdot
.6775 .54375 Mdot
.7325 .5075 Mdot
.3 .4575 Mdot
.84875 .43375 Mdot
.6875 .4275 Mdot
.85375 .43875 Mdot
.17 .45375 Mdot
.36125 .47 Mdot
.69125 .5 Mdot
.30625 .48375 Mdot
.5125 .47375 Mdot
.44375 .4725 Mdot
.82625 .475 Mdot
.0925 .51375 Mdot
.98625 .58375 Mdot
.09125 .645 Mdot
.15 .62625 Mdot
.8375 .625 Mdot
.42875 .62 Mdot
.86125 .61 Mdot
.15375 .5725 Mdot
.8175 .585 Mdot
.11125 .5925 Mdot
.67 .5775 Mdot
.8775 .5625 Mdot
.13125 .5525 Mdot
.48125 .51375 Mdot
.56625 .4825 Mdot
.40125 .48125 Mdot
.43875 .48625 Mdot
.535 .48625 Mdot
.54875 .46 Mdot
.9575 .45375 Mdot
.46 .45125 Mdot
.1075 .48 Mdot
.71125 .47875 Mdot
.26625 .49125 Mdot
.76 .51 Mdot
.10375 .4875 Mdot
.62125 .47875 Mdot
.65 .51 Mdot
.66125 .51125 Mdot
.26375 .51875 Mdot
.81125 .4875 Mdot
.11375 .4975 Mdot
.55625 .51375 Mdot
.80375 .50875 Mdot
.515 .55375 Mdot
.775 .53375 Mdot
.4225 .55375 Mdot
.3 .57875 Mdot
.2025 .5975 Mdot
.765 .59 Mdot
.505 .57375 Mdot
.65875 .585 Mdot
.0875 .565 Mdot
.9225 .63375 Mdot
.23 .53375 Mdot
.75125 .5625 Mdot
.48875 .53 Mdot
.0425 .5575 Mdot
.71125 .52625 Mdot
.445 .62375 Mdot
.7025 .52375 Mdot
.55875 .49375 Mdot
.23375 .4825 Mdot
.5875 .52625 Mdot
.5475 .5475 Mdot
.5 .59375 Mdot
.43375 .58375 Mdot
.51625 .57375 Mdot
.6 .55 Mdot
.45125 .56625 Mdot
.5375 .51125 Mdot
.62625 .5075 Mdot
.145 .52125 Mdot
.53375 .5325 Mdot
.6775 .5075 Mdot
.7825 .40125 Mdot
.2025 .39 Mdot
.51625 .405 Mdot
.41875 .395 Mdot
.65625 .3925 Mdot
.525 .4275 Mdot
.6475 .4325 Mdot
.39625 .395 Mdot
.4275 .395 Mdot
.60375 .42625 Mdot
.305 .5475 Mdot
.75375 .52875 Mdot
.31375 .50625 Mdot
.83125 .4875 Mdot
.245 .46875 Mdot
.29625 .49125 Mdot
.59125 .53875 Mdot
.765 .5475 Mdot
.11625 .53875 Mdot
.69 .52 Mdot
.655 .50875 Mdot
.04 .49 Mdot
.2825 .5425 Mdot
.21625 .58375 Mdot
.9725 .60625 Mdot
.67375 .5675 Mdot
.67125 .49125 Mdot
.215 .48125 Mdot
.695 .445 Mdot
.7325 .49375 Mdot
.26 .52875 Mdot
.8575 .55375 Mdot
.7025 .55 Mdot
.81375 .52625 Mdot
.1825 .51125 Mdot
.35875 .50375 Mdot
.68625 .44125 Mdot
.30375 .4525 Mdot
.5075 .46 Mdot
.4275 .51 Mdot
.8175 .51625 Mdot
.10625 .5175 Mdot
.06375 .44875 Mdot
.16 .44875 Mdot
.815 .45 Mdot
.43625 .42875 Mdot
.885 .4275 Mdot
.1175 .43875 Mdot
.84125 .40625 Mdot
.12375 .395 Mdot
.63625 .40625 Mdot
.91 .4125 Mdot
.0675 .4275 Mdot
.56875 .46375 Mdot
.5325 .49 Mdot
.38625 .51375 Mdot
.46 .51625 Mdot
.57875 .535 Mdot
.565 .55125 Mdot
.8975 .575 Mdot
.0425 .5675 Mdot
.445 .54125 Mdot
.99875 .4875 Mdot
.195 .45 Mdot
.58625 .415 Mdot
.35625 .41375 Mdot
.73375 .44 Mdot
.11625 .49 Mdot
.58625 .51125 Mdot
.60625 .455 Mdot
.78125 .455 Mdot
.16625 .44875 Mdot
.8325 .4875 Mdot
.13875 .475 Mdot
.67875 .4825 Mdot
.75625 .50375 Mdot
.47875 .50875 Mdot
.74125 .46625 Mdot
.48375 .43625 Mdot
.29625 .4225 Mdot
.14 .39625 Mdot
.9275 .40125 Mdot
.335 .4275 Mdot
.72125 .45375 Mdot
.13375 .43625 Mdot
.835 .47625 Mdot
.2375 .495 Mdot
.81875 .48875 Mdot
.4375 .51375 Mdot
.06625 .5275 Mdot
.6625 .50125 Mdot
.53 .4875 Mdot
.0225 .48875 Mdot
.66375 .4725 Mdot
.64 .43125 Mdot
.215 .42625 Mdot
.52375 .44875 Mdot
.55625 .46125 Mdot
.61 .47125 Mdot
.26875 .50375 Mdot
.57625 .54 Mdot
.55125 .53375 Mdot
.6075 .50375 Mdot
.4425 .55875 Mdot
.62375 .5675 Mdot
.185 .54 Mdot
.47125 .52875 Mdot
.5675 .52 Mdot
.8325 .62 Mdot
.24875 .57 Mdot
.4475 .5375 Mdot
.5075 .52375 Mdot
.53875 .50625 Mdot
.60625 .4625 Mdot
.6525 .5 Mdot
.26875 .5525 Mdot
.5775 .6 Mdot
.53625 .615 Mdot
.37875 .385 Mdot
.7075 .365 Mdot
.355 .40875 Mdot
.795 .45 Mdot
.22625 .4825 Mdot
.34 .48375 Mdot
.58 .48625 Mdot
.76 .49875 Mdot
.1125 .5075 Mdot
.7075 .53125 Mdot
.63 .55125 Mdot
.06125 .54 Mdot
.25375 .47375 Mdot
.265 .41375 Mdot
.93125 .385 Mdot
.0275 .41375 Mdot
.635 .42375 Mdot
.67125 .45375 Mdot
.20875 .47875 Mdot
.72375 .50875 Mdot
.725 .48 Mdot
.26625 .46625 Mdot
.835 .445 Mdot
.7375 .46 Mdot
.76625 .46375 Mdot
.21375 .46375 Mdot
.35625 .4725 Mdot
.675 .525 Mdot
.2975 .53125 Mdot
.47625 .53 Mdot
.41125 .46875 Mdot
.82625 .46125 Mdot
.11 .45875 Mdot
.06375 .45625 Mdot
.17 .475 Mdot
.825 .4725 Mdot
.40125 .51 Mdot
.9025 .535 Mdot
.1175 .50375 Mdot
.85375 .505 Mdot
.08625 .50875 Mdot
.68 .425 Mdot
.92375 .38375 Mdot
.7125 .40125 Mdot
.4525 .39375 Mdot
.38125 .46375 Mdot
.5075 .51625 Mdot
.62 .4975 Mdot
.5525 .495 Mdot
.90625 .47 Mdot
.04875 .48875 Mdot
.42625 .5475 Mdot
.95375 .61125 Mdot
.2875 .64625 Mdot
.4925 .6775 Mdot
.43625 .67375 Mdot
.68125 .63125 Mdot
.155 .5775 Mdot
.5575 .54 Mdot
.5975 .535 Mdot
.855 .5075 Mdot
.1075 .495 Mdot
.8225 .5 Mdot
.12375 .5575 Mdot
.83875 .54 Mdot
.65125 .51625 Mdot
.48 .5075 Mdot
.72625 .55375 Mdot
.55125 .55 Mdot
.22875 .5325 Mdot
.1575 .5475 Mdot
.985 .51375 Mdot
.27 .48125 Mdot
.715 .45375 Mdot
.17125 .4925 Mdot
.83125 .42625 Mdot
.17875 .46625 Mdot
.9775 .45625 Mdot
.16625 .49375 Mdot
.29375 .49375 Mdot
.5625 .5375 Mdot
.5875 .505 Mdot
.9825 .55 Mdot
.015 .51625 Mdot
.66875 .55875 Mdot
.6125 .635 Mdot
.30625 .6825 Mdot
.44 .61375 Mdot
.59625 .61875 Mdot
.6475 .535 Mdot
.185 .475 Mdot
.6025 .405 Mdot
.53125 .43375 Mdot
.67 .45 Mdot
.39375 .44875 Mdot
.60625 .46625 Mdot
.265 .48625 Mdot
.38375 .475 Mdot
.4825 .47875 Mdot
.85375 .445 Mdot
.30625 .48875 Mdot
.35125 .48625 Mdot
.675 .5525 Mdot
.39 .56125 Mdot
.6425 .655 Mdot
.68375 .6375 Mdot
.195 .61125 Mdot
.7075 .51375 Mdot
.4175 .4575 Mdot
.4525 .6275 Mdot
.67375 .665 Mdot
.35625 .66375 Mdot
.79125 .6125 Mdot
.23125 .5525 Mdot
.34875 .505 Mdot
.58375 .47375 Mdot
.7375 .45375 Mdot
.12125 .47375 Mdot
.70875 .46875 Mdot
.62125 .4825 Mdot
.0975 .56 Mdot
.275 .55875 Mdot
.27625 .57125 Mdot
.955 .57875 Mdot
.02375 .5125 Mdot
.61125 .51375 Mdot
.645 .5275 Mdot
.24 .53375 Mdot
.73875 .50625 Mdot
.72625 .51125 Mdot
.24625 .50125 Mdot
.835 .5225 Mdot
.73875 .53375 Mdot
.76875 .565 Mdot
.1825 .555 Mdot
.385 .50625 Mdot
.68 .4675 Mdot
.26 .4425 Mdot
.505 .45125 Mdot
.41125 .51375 Mdot
.8225 .51125 Mdot
.135 .46875 Mdot
.0525 .4975 Mdot
.19375 .53625 Mdot
.81125 .56 Mdot
.4075 .54375 Mdot
.86125 .53375 Mdot
.16125 .54625 Mdot
.86 .5525 Mdot
.0425 .57125 Mdot
.72 .7025 Mdot
.93375 .76125 Mdot
.86375 .72875 Mdot
.34 .68625 Mdot
.41125 .54375 Mdot
.4925 .465 Mdot
.65 .5375 Mdot
.53 .5575 Mdot
.9225 .585 Mdot
.0825 .555 Mdot
.38625 .48375 Mdot
.91125 .43625 Mdot
.355 .4025 Mdot
.44125 .39125 Mdot
.5025 .41375 Mdot
.64625 .42875 Mdot
.1775 .47 Mdot
.50875 .5025 Mdot
.6125 .5625 Mdot
.9125 .57 Mdot
.07 .57375 Mdot
.78625 .51875 Mdot
.0025 .48125 Mdot
.94875 .48625 Mdot
.58 .50625 Mdot
.47125 .47375 Mdot
.71125 .46125 Mdot
.59375 .50125 Mdot
.1925 .48625 Mdot
.17625 .48125 Mdot
.20125 .5425 Mdot
.7175 .5175 Mdot
.205 .53125 Mdot
.7875 .5425 Mdot
.19125 .54375 Mdot
.01625 .535 Mdot
.4275 .51875 Mdot
.51375 .52 Mdot
.63875 .54375 Mdot
.96375 .52875 Mdot
.78125 .45 Mdot
.47 .39125 Mdot
.48125 .36875 Mdot
.3125 .3375 Mdot
.675 .38125 Mdot
.65125 .44125 Mdot
.13125 .495 Mdot
.5975 .47 Mdot
.57625 .48125 Mdot
.6375 .47375 Mdot
.4075 .49375 Mdot
.5675 .465 Mdot
.36625 .475 Mdot
.27625 .485 Mdot
.36625 .5075 Mdot
.92 .52125 Mdot
.375 .58125 Mdot
.24625 .575 Mdot
.7275 .49875 Mdot
.325 .47625 Mdot
.7075 .42375 Mdot
.7 .3425 Mdot
.18 .33875 Mdot
.73625 .43125 Mdot
.33625 .53 Mdot
.54625 .46375 Mdot
.63 .42 Mdot
.36 .39125 Mdot
.7775 .38875 Mdot
.28625 .4425 Mdot
.3175 .47875 Mdot
.58375 .5025 Mdot
.69 .545 Mdot
.18125 .5175 Mdot
.73125 .5025 Mdot
.53 .49625 Mdot
.16125 .4575 Mdot
.31875 .4925 Mdot
.21875 .515 Mdot
.97625 .54 Mdot
.0375 .6025 Mdot
.64375 .58625 Mdot
.6325 .59125 Mdot
.25875 .5625 Mdot
.725 .5875 Mdot
.68625 .595 Mdot
.28625 .62125 Mdot
.7975 .6075 Mdot
.7275 .53875 Mdot
.78125 .48 Mdot
.16375 .47875 Mdot
.39375 .5 Mdot
.7025 .54125 Mdot
.215 .575 Mdot
.4875 .57 Mdot
.4075 .54 Mdot
.82625 .56375 Mdot
.15125 .62625 Mdot
.02375 .60625 Mdot
.2375 .54375 Mdot
.7675 .51 Mdot
.44625 .5225 Mdot
.79625 .535 Mdot
.22875 .5225 Mdot
.83625 .52375 Mdot
.7925 .45875 Mdot
.9 .445 Mdot
.955 .45125 Mdot
.225 .4825 Mdot
.48625 .54125 Mdot
.42875 .545 Mdot
.6625 .47375 Mdot
.52 .47125 Mdot
.90875 .4475 Mdot
.13375 .45875 Mdot
.3375 .48875 Mdot
.86625 .50125 Mdot
.455 .51 Mdot
.37625 .5125 Mdot
.5575 .495 Mdot
.6375 .5175 Mdot
.13625 .5125 Mdot
.5375 .49125 Mdot
.52375 .46 Mdot
.96875 .46875 Mdot
.03625 .4875 Mdot
.71875 .45625 Mdot
.98375 .43625 Mdot
.5675 .42625 Mdot
.47 .4625 Mdot
.685 .4775 Mdot
.655 .51625 Mdot
.13625 .53875 Mdot
.17875 .56 Mdot
.18875 .5025 Mdot
.6875 .4975 Mdot
.27875 .5075 Mdot
.68375 .51 Mdot
.3325 .48625 Mdot
.935 .49375 Mdot
.46625 .425 Mdot
.5175 .37875 Mdot
.65 .37 Mdot
.9325 .39125 Mdot
.9 .47875 Mdot
.25625 .4875 Mdot
.70125 .49 Mdot
.2125 .475 Mdot
.68 .47375 Mdot
.61875 .50875 Mdot
.18 .595 Mdot
.5875 .67625 Mdot
.555 .7075 Mdot
.64625 .68625 Mdot
.43875 .6475 Mdot
.5025 .58625 Mdot
.4525 .58125 Mdot
.23625 .58 Mdot
.24625 .5675 Mdot
.99625 .5025 Mdot
.45125 .4275 Mdot
.0625 .42375 Mdot
.91875 .41375 Mdot
.17 .405 Mdot
.775 .4125 Mdot
.69125 .4925 Mdot
.2 .495 Mdot
.74 .5125 Mdot
.2625 .50125 Mdot
.63125 .4925 Mdot
.58 .52125 Mdot
.325 .5425 Mdot
.78125 .58 Mdot
.335 .575 Mdot
.2925 .58375 Mdot
.57625 .56125 Mdot
.66375 .49625 Mdot
.19125 .4925 Mdot
.80625 .50625 Mdot
.47125 .46125 Mdot
.17125 .43375 Mdot
.98875 .42875 Mdot
.36875 .39125 Mdot
.14625 .355 Mdot
.0625 .35125 Mdot
.62375 .38875 Mdot
.605 .40875 Mdot
.29875 .43 Mdot
.72625 .4325 Mdot
.67125 .4225 Mdot
.29375 .405 Mdot
.77125 .39125 Mdot
.71375 .4525 Mdot
.78375 .49 Mdot
.155 .5075 Mdot
.415 .52875 Mdot
.67125 .47375 Mdot
.21 .45 Mdot
.46375 .41875 Mdot
.00625 .4075 Mdot
.38125 .43 Mdot
.84875 .4125 Mdot
.125 .38625 Mdot
.30625 .42375 Mdot
.69875 .4175 Mdot
.47375 .40375 Mdot
.77125 .3725 Mdot
.27125 .40125 Mdot
.81125 .4025 Mdot
.00125 .38875 Mdot
.795 .40625 Mdot
.86125 .42375 Mdot
.83125 .45625 Mdot
.1825 .47625 Mdot
.57875 .505 Mdot
.41 .54125 Mdot
.7225 .51625 Mdot
.445 .465 Mdot
.8875 .435 Mdot
.195 .42125 Mdot
.31375 .4 Mdot
.80875 .42125 Mdot
.51625 .43 Mdot
.345 .4475 Mdot
.61125 .4575 Mdot
.65375 .45625 Mdot
.12375 .43 Mdot
.49875 .435 Mdot
.5175 .50875 Mdot
.0225 .52 Mdot
.6025 .5425 Mdot
.56625 .5825 Mdot
.47125 .53125 Mdot
.66625 .50375 Mdot
.6275 .435 Mdot
.155 .44375 Mdot
.1975 .42875 Mdot
.19 .52125 Mdot
.6175 .5475 Mdot
.36875 .53 Mdot
.64 .50625 Mdot
.40125 .4825 Mdot
.875 .45375 Mdot
.6 .495 Mdot
.41625 .6 Mdot
.70625 .5975 Mdot
.93125 .59375 Mdot
.95375 .57375 Mdot
.12875 .54125 Mdot
.81625 .5425 Mdot
.23 .58875 Mdot
.66125 .5575 Mdot
.56125 .525 Mdot
.2275 .47 Mdot
.59875 .44 Mdot
.53 .39875 Mdot
.59375 .445 Mdot
.5125 .44625 Mdot
.48 .49375 Mdot
.51 .51375 Mdot
.15625 .5325 Mdot
.13625 .51 Mdot
.4825 .515 Mdot
.09375 .50625 Mdot
.7625 .4825 Mdot
.68375 .5 Mdot
.25 .52 Mdot
.75875 .485 Mdot
.2 .47125 Mdot
.71125 .44875 Mdot
.5425 .4225 Mdot
.29375 .41625 Mdot
.79875 .4125 Mdot
.35625 .41125 Mdot
.30625 .40375 Mdot
.545 .455 Mdot
.63625 .5125 Mdot
.225 .50375 Mdot
.8225 .4675 Mdot
.42875 .50375 Mdot
.21125 .53125 Mdot
.9525 .49375 Mdot
.40625 .4975 Mdot
.15875 .4925 Mdot
.97125 .45125 Mdot
.0625 .40125 Mdot
.65 .41625 Mdot
.59875 .44125 Mdot
.26875 .49875 Mdot
.76 .54125 Mdot
.64625 .58 Mdot
.3125 .57375 Mdot
.76875 .5625 Mdot
.65375 .52 Mdot
.85125 .49125 Mdot
.12125 .4775 Mdot
.43125 .48 Mdot
.69625 .515 Mdot
.1725 .53 Mdot
.4675 .56875 Mdot
.0125 .56625 Mdot
.39125 .545 Mdot
.855 .54125 Mdot
.09 .5225 Mdot
.385 .52125 Mdot
.59875 .55875 Mdot
.51 .58 Mdot
.765 .5975 Mdot
.305 .61375 Mdot
.77625 .6175 Mdot
.02625 .59875 Mdot
.78125 .61375 Mdot
.78875 .59125 Mdot
.11875 .57125 Mdot
.79625 .54 Mdot
.07 .52 Mdot
.70125 .4475 Mdot
.43875 .41875 Mdot
.755 .5025 Mdot
.335 .56375 Mdot
.94125 .61375 Mdot
.21 .615 Mdot
.31625 .615 Mdot
.75125 .58625 Mdot
.5475 .585 Mdot
.33375 .59375 Mdot
.6675 .60125 Mdot
.6025 .64125 Mdot
.2125 .59625 Mdot
.435 .625 Mdot
.51375 .46125 Mdot
.06625 .49125 Mdot
.05625 .585 Mdot
.47125 .52875 Mdot
.50375 .4325 Mdot
.4925 .48625 Mdot
.695 .51625 Mdot
.59875 .54 Mdot
.14375 .515 Mdot
.18625 .48375 Mdot
.1775 .36375 Mdot
.58375 .33625 Mdot
.41125 .365 Mdot
.59875 .43125 Mdot
.5075 .5075 Mdot
.78625 .545 Mdot
.73 .6025 Mdot
.33875 .49625 Mdot
.72375 .4825 Mdot
.94375 .47125 Mdot
.97 .47 Mdot
.14375 .56125 Mdot
.77875 .55125 Mdot
.23 .53 Mdot
.67 .48875 Mdot
.55375 .5 Mdot
.23625 .38625 Mdot
.66125 .3775 Mdot
.4775 .385 Mdot
.54375 .35 Mdot
.56625 .31875 Mdot
.4325 .37875 Mdot
.56375 .3525 Mdot
.1575 .34375 Mdot
.105 .4575 Mdot
.4825 .56 Mdot
.1875 .68125 Mdot
.6425 .695 Mdot
.7025 .6325 Mdot
.30375 .57125 Mdot
.7575 .5375 Mdot
.1325 .49125 Mdot
.73375 .62625 Mdot
.535 .66625 Mdot
.25875 .675 Mdot
.82375 .66125 Mdot
.37625 .61125 Mdot
.27875 .59 Mdot
.54 .50125 Mdot
.64 .44125 Mdot
.225 .465 Mdot
.82625 .51375 Mdot
.44625 .52625 Mdot
.17625 .56 Mdot
.9625 .64375 Mdot
.4425 .70875 Mdot
.1425 .79375 Mdot
.965 .8475 Mdot
.02375 .88375 Mdot
.695 .80625 Mdot
.6175 .6825 Mdot
.2375 .56 Mdot
.77875 .465 Mdot
.6125 .41125 Mdot
.355 .42875 Mdot
.72 .46125 Mdot
.03125 .4675 Mdot
.57875 .4825 Mdot
.94625 .5125 Mdot
.05 .4875 Mdot
.4525 .4575 Mdot
.70625 .45625 Mdot
.1725 .43625 Mdot
.505 .43875 Mdot
.0025 .47375 Mdot
.4025 .475 Mdot
.85125 .50125 Mdot
.06375 .53875 Mdot
.45 .52625 Mdot
.49875 .50375 Mdot
.5675 .5025 Mdot
.72625 .49375 Mdot
.33 .4825 Mdot
.755 .49875 Mdot
.0975 .4875 Mdot
.725 .49625 Mdot
.70375 .47125 Mdot
.2875 .455 Mdot
.6875 .43125 Mdot
.055 .48 Mdot
.7875 .48375 Mdot
.4175 .52375 Mdot
.9475 .55875 Mdot
.82375 .50875 Mdot
.19375 .4775 Mdot
.2125 .4475 Mdot
.33125 .4425 Mdot
.71375 .435 Mdot
.56 .40875 Mdot
.32375 .35375 Mdot
.74375 .34125 Mdot
.52375 .29375 Mdot
.30375 .43875 Mdot
.4075 .4325 Mdot
.55625 .525 Mdot
.14625 .39375 Mdot
.8725 .37375 Mdot
.25125 .405 Mdot
.3025 .42375 Mdot
.065 .46875 Mdot
.50875 .585 Mdot
.45 .56375 Mdot
.7225 .55125 Mdot
.53625 .5225 Mdot
.18125 .5175 Mdot
.16125 .52125 Mdot
.1 .5425 Mdot
.605 .5825 Mdot
.42 .53375 Mdot
.57 .46875 Mdot
.55875 .42375 Mdot
.7725 .45625 Mdot
.81 .415 Mdot
.31625 .465 Mdot
.72375 .52 Mdot
.93875 .4725 Mdot
.92875 .46625 Mdot
.2475 .4325 Mdot
.6975 .44625 Mdot
.24875 .5025 Mdot
.6775 .53 Mdot
.5175 .5425 Mdot
.255 .625 Mdot
.69625 .59125 Mdot
.41875 .56375 Mdot
.55875 .60375 Mdot
.5925 .66625 Mdot
.4425 .6175 Mdot
.55875 .63625 Mdot
.17125 .6325 Mdot
.01 .5325 Mdot
.145 .4925 Mdot
.49875 .41375 Mdot
.32 .39625 Mdot
.5625 .4275 Mdot
.68 .495 Mdot
.325 .53625 Mdot
.785 .5425 Mdot
.105 .60375 Mdot
.75625 .44875 Mdot
.51875 .4325 Mdot
.22 .4175 Mdot
.8275 .42125 Mdot
.43375 .45 Mdot
.2475 .46 Mdot
.50375 .5325 Mdot
.67125 .5725 Mdot
.24 .56 Mdot
.8375 .53 Mdot
.41625 .5075 Mdot
.13875 .445 Mdot
.4225 .4175 Mdot
.14 .355 Mdot
.9325 .34625 Mdot
.78125 .39875 Mdot
.61875 .4575 Mdot
.215 .535 Mdot
.81 .55 Mdot
.54625 .545 Mdot
.3975 .5375 Mdot
.71875 .5125 Mdot
.0225 .51 Mdot
.555 .53625 Mdot
.99125 .5175 Mdot
.015 .54625 Mdot
.4675 .59625 Mdot
.715 .59125 Mdot
.1875 .60375 Mdot
.515 .58 Mdot
.0425 .5225 Mdot
.38 .52625 Mdot
.86125 .495 Mdot
.02125 .465 Mdot
.51125 .46 Mdot
.41625 .48625 Mdot
.6 .46625 Mdot
.76125 .4525 Mdot
.28875 .43625 Mdot
.735 .4225 Mdot
.18 .4225 Mdot
.69375 .37625 Mdot
.58125 .41125 Mdot
.455 .4225 Mdot
.56625 .4175 Mdot
.09375 .4275 Mdot
.81625 .475 Mdot
.48125 .45625 Mdot
.775 .44375 Mdot
.885 .46625 Mdot
.085 .49125 Mdot
.2475 .53375 Mdot
.34875 .56875 Mdot
.685 .58 Mdot
.55625 .6175 Mdot
.2725 .59625 Mdot
.88 .5875 Mdot
.37875 .58375 Mdot
.4575 .495 Mdot
.3975 .465 Mdot
.92375 .5025 Mdot
.5875 .47875 Mdot
.93875 .58875 Mdot
.2975 .58 Mdot
.65875 .54875 Mdot
.455 .535 Mdot
.10625 .52375 Mdot
.26375 .465 Mdot
.44625 .3575 Mdot
.475 .37375 Mdot
.7925 .3775 Mdot
.405 .4275 Mdot
.23875 .4625 Mdot
.1425 .48 Mdot
.1025 .51125 Mdot
.5875 .46375 Mdot
.415 .4925 Mdot
.625 .51375 Mdot
.49125 .505 Mdot
.85125 .44875 Mdot
.84375 .485 Mdot
.34 .48125 Mdot
.65375 .46 Mdot
.945 .48625 Mdot
.78875 .5675 Mdot
.41625 .545 Mdot
.56125 .51125 Mdot
.31125 .46875 Mdot
.675 .4075 Mdot
.4475 .34625 Mdot
.3425 .37375 Mdot
.68375 .43 Mdot
.34625 .4925 Mdot
.63625 .47625 Mdot
.56625 .4225 Mdot
.45 .4 Mdot
.5625 .3825 Mdot
.18 .33 Mdot
.3125 .425 Mdot
.5325 .47125 Mdot
.42875 .46 Mdot
.47875 .45125 Mdot
.69 .44125 Mdot
.32375 .42875 Mdot
.7825 .46375 Mdot
.1175 .45 Mdot
.76 .48125 Mdot
.51375 .48375 Mdot
.21625 .47875 Mdot
.81875 .45 Mdot
.43875 .46 Mdot
.25375 .475 Mdot
.465 .44875 Mdot
.7325 .4325 Mdot
.18125 .46125 Mdot
.9 .4625 Mdot
.40875 .46375 Mdot
.10375 .4925 Mdot
.42875 .42375 Mdot
.1825 .4275 Mdot
.87375 .395 Mdot
.78625 .37 Mdot
.62 .39125 Mdot
.18625 .3775 Mdot
.88125 .45625 Mdot
.4725 .4825 Mdot
.44875 .4925 Mdot
.71125 .50625 Mdot
.0275 .535 Mdot
.5175 .4825 Mdot
.5 .46 Mdot
.695 .455 Mdot
.20625 .46375 Mdot
.50125 .48625 Mdot
.0725 .5075 Mdot
.385 .50375 Mdot
.84375 .505 Mdot
.54875 .5325 Mdot
.39 .5275 Mdot
.57 .5375 Mdot
.8025 .56375 Mdot
.27 .57625 Mdot
.70375 .575 Mdot
.275 .62125 Mdot
.66875 .6675 Mdot
.50625 .655 Mdot
.50875 .6825 Mdot
.49625 .70625 Mdot
.16625 .6225 Mdot
.80375 .60375 Mdot
.53375 .59875 Mdot
.6125 .55625 Mdot
.09 .50625 Mdot
.84875 .535 Mdot
.005 .49875 Mdot
.2325 .44625 Mdot
.38125 .43375 Mdot
.67125 .43625 Mdot
.51125 .45125 Mdot
.25625 .53 Mdot
.21 .59125 Mdot
.625 .6175 Mdot
.3725 .5925 Mdot
.88375 .55375 Mdot
.7325 .55375 Mdot
.79625 .48875 Mdot
.505 .50625 Mdot
.45 .52125 Mdot
.6325 .48875 Mdot
.51 .51 Mdot
.47625 .64875 Mdot
.42 .63125 Mdot
.93375 .635 Mdot
.18625 .5925 Mdot
.3825 .5575 Mdot
.13875 .5425 Mdot
.14 .565 Mdot
.5775 .605 Mdot
.3875 .55875 Mdot
.705 .55875 Mdot
.36 .5575 Mdot
.89875 .5525 Mdot
.72875 .53125 Mdot
.3825 .52375 Mdot
.62875 .525 Mdot
.95125 .55375 Mdot
.67625 .48125 Mdot
.57875 .4775 Mdot
.465 .51 Mdot
.30625 .50875 Mdot
.75 .6075 Mdot
.36 .64125 Mdot
.40625 .61 Mdot
.66375 .54875 Mdot
.3525 .48375 Mdot
.605 .44625 Mdot
.58375 .495 Mdot
.49 .535 Mdot
.49625 .54625 Mdot
.22125 .5875 Mdot
.59625 .5525 Mdot
.8275 .57125 Mdot
.52625 .5875 Mdot
.985 .57125 Mdot
.53875 .5175 Mdot
.41625 .465 Mdot
.69625 .44625 Mdot
.33625 .4875 Mdot
.76375 .48125 Mdot
.13 .46875 Mdot
.74 .5025 Mdot
.51 .485 Mdot
.235 .48875 Mdot
.81125 .5175 Mdot
.40625 .49375 Mdot
.3275 .47 Mdot
.40125 .47875 Mdot
.75125 .49 Mdot
.1825 .4625 Mdot
.9325 .4825 Mdot
.35125 .51 Mdot
.15125 .5175 Mdot
.39 .54875 Mdot
.26125 .55125 Mdot
.78625 .56125 Mdot
.8 .55625 Mdot
.65125 .57375 Mdot
.1625 .58625 Mdot
.88125 .5275 Mdot
.42875 .54 Mdot
.49625 .51125 Mdot
.71125 .49125 Mdot
.015 .46375 Mdot
.525 .49125 Mdot
.53875 .48625 Mdot
.69625 .49125 Mdot
.19875 .47375 Mdot
.53125 .4775 Mdot
.06625 .4925 Mdot
.4075 .51 Mdot
.7925 .515 Mdot
.0325 .50875 Mdot
.0525 .51 Mdot
.54 .45875 Mdot
.40125 .43375 Mdot
.5625 .43125 Mdot
.81 .41875 Mdot
.225 .42125 Mdot
.705 .465 Mdot
.37625 .43125 Mdot
.60875 .38875 Mdot
.47125 .38 Mdot
.51 .37125 Mdot
.53125 .34625 Mdot
.16875 .3975 Mdot
.77125 .4175 Mdot
.62875 .44 Mdot
.44 .425 Mdot
.24125 .46 Mdot
.7925 .40125 Mdot
.015 .3925 Mdot
.1675 .44375 Mdot
.4675 .44625 Mdot
.65375 .475 Mdot
.4625 .47 Mdot
.26375 .42375 Mdot
.085 .3475 Mdot
.7025 .3325 Mdot
.46375 .37375 Mdot
.72375 .4275 Mdot
.82625 .505 Mdot
.6 .5725 Mdot
.74875 .58 Mdot
.27625 .56125 Mdot
.74375 .6175 Mdot
.7275 .585 Mdot
.50375 .44125 Mdot
.36625 .42125 Mdot
.00375 .47125 Mdot
.45625 .50875 Mdot
.17 .51375 Mdot
.26 .4925 Mdot
.62125 .485 Mdot
.3075 .5125 Mdot
.73875 .485 Mdot
.335 .49625 Mdot
.84875 .525 Mdot
.04875 .5275 Mdot
.52125 .52 Mdot
.5075 .54375 Mdot
.615 .5125 Mdot
.915 .4875 Mdot
.01 .45875 Mdot
.5775 .44375 Mdot
.675 .44625 Mdot
.455 .4225 Mdot
.2825 .42 Mdot
.75375 .39875 Mdot
.30625 .42625 Mdot
.50875 .44875 Mdot
.6025 .52 Mdot
.41875 .58375 Mdot
.56 .62 Mdot
.56625 .58375 Mdot
.5325 .55625 Mdot
.37375 .565 Mdot
.36 .54 Mdot
.88875 .55125 Mdot
.6225 .5175 Mdot
.49125 .51625 Mdot
.925 .51875 Mdot
.5425 .5425 Mdot
.3875 .57 Mdot
.7525 .5575 Mdot
.30875 .52875 Mdot
.765 .5275 Mdot
.14 .5175 Mdot
.71625 .46 Mdot
.47125 .47375 Mdot
.31375 .46625 Mdot
.805 .48 Mdot
.335 .52375 Mdot
.43375 .5525 Mdot
.30875 .53375 Mdot
.77375 .54875 Mdot
.175 .55375 Mdot
.9975 .56375 Mdot
.29 .52375 Mdot
.17875 .52375 Mdot
.3875 .47375 Mdot
.26375 .46875 Mdot
.76625 .4825 Mdot
.04 .4775 Mdot
.745 .48125 Mdot
.685 .46625 Mdot
.17375 .41625 Mdot
.8675 .415 Mdot
.3975 .4025 Mdot
.5625 .4275 Mdot
.67125 .4375 Mdot
.57875 .4625 Mdot
.605 .49125 Mdot
.6475 .5025 Mdot
.24125 .525 Mdot
.995 .5125 Mdot
.51 .51 Mdot
.085 .505 Mdot
.44875 .4775 Mdot
.71625 .4825 Mdot
.08375 .51 Mdot
.96625 .51375 Mdot
.10125 .49875 Mdot
.52 .51125 Mdot
.4175 .51125 Mdot
.55875 .4975 Mdot
.80125 .49 Mdot
.21875 .45375 Mdot
.6725 .39625 Mdot
.48875 .46 Mdot
.53375 .5 Mdot
.505 .52125 Mdot
.44375 .5425 Mdot
.52125 .585 Mdot
.2875 .49 Mdot
.65625 .41125 Mdot
.66 .4175 Mdot
.455 .4375 Mdot
.23125 .43625 Mdot
.7675 .55875 Mdot
.07875 .6625 Mdot
.0875 .67 Mdot
.56875 .65875 Mdot
.635 .60625 Mdot
.4275 .585 Mdot
.28375 .6075 Mdot
.02875 .61125 Mdot
.68125 .59875 Mdot
.6325 .59 Mdot
.54375 .52 Mdot
.94375 .4325 Mdot
.38 .4175 Mdot
.96125 .39125 Mdot
.12 .40375 Mdot
.895 .385 Mdot
.93875 .4275 Mdot
.58 .49125 Mdot
.3125 .45625 Mdot
.46875 .43875 Mdot
.26875 .42875 Mdot
.875 .44125 Mdot
.32875 .48625 Mdot
.66375 .4725 Mdot
.21 .50375 Mdot
.815 .4825 Mdot
.29375 .52875 Mdot
.81375 .5 Mdot
.195 .505 Mdot
.3725 .47 Mdot
.54 .515 Mdot
.67 .4725 Mdot
.865 .48125 Mdot
.05375 .50125 Mdot
.53375 .515 Mdot
.63 .50125 Mdot
.53625 .5125 Mdot
.24375 .52875 Mdot
.78875 .52 Mdot
.26125 .50375 Mdot
.57875 .50625 Mdot
.52125 .49875 Mdot
.50375 .4725 Mdot
.5325 .49625 Mdot
.5125 .4975 Mdot
.625 .50875 Mdot
.22125 .51 Mdot
.50875 .5125 Mdot
.42375 .51375 Mdot
.485 .51875 Mdot
.1075 .5225 Mdot
.80125 .53375 Mdot
.52625 .545 Mdot
.42625 .5475 Mdot
.76125 .5375 Mdot
.305 .5275 Mdot
.745 .5 Mdot
.17125 .47125 Mdot
.67875 .535 Mdot
.4675 .545 Mdot
.38625 .525 Mdot
.78875 .51875 Mdot
.3 .5 Mdot
.4875 .47375 Mdot
.225 .46375 Mdot
.8175 .47 Mdot
.1675 .445 Mdot
.1875 .4925 Mdot
.22375 .4775 Mdot
1 .48875 Mdot
.43375 .5275 Mdot
.25625 .53125 Mdot
.71875 .49 Mdot
.13875 .51875 Mdot
.65125 .54125 Mdot
.69375 .51625 Mdot
.21375 .55 Mdot
.84125 .56625 Mdot
.41 .5625 Mdot
.55 .52625 Mdot
.68625 .57125 Mdot
.6025 .5675 Mdot
.68125 .52875 Mdot
.625 .5 Mdot
.23 .48125 Mdot
.99875 .475 Mdot
.48125 .4675 Mdot
.1125 .44875 Mdot
.505 .46875 Mdot
.6125 .45625 Mdot
.1575 .45125 Mdot
.92125 .4775 Mdot
.1 .47375 Mdot
.54625 .48875 Mdot
.3875 .51875 Mdot
.57625 .525 Mdot
.81625 .545 Mdot
.20375 .59625 Mdot
.5925 .5825 Mdot
.64625 .48125 Mdot
.46 .45 Mdot
.545 .445 Mdot
.345 .41125 Mdot
.53875 .395 Mdot
.395 .5375 Mdot
.52875 .64 Mdot
.76 .6225 Mdot
.41125 .625 Mdot
.23375 .65875 Mdot
.72375 .57 Mdot
.17125 .45125 Mdot
.68375 .41875 Mdot
.6175 .4425 Mdot
.40875 .4475 Mdot
.30125 .4525 Mdot
.105 .4375 Mdot
.5525 .42625 Mdot
.8075 .4425 Mdot
.425 .45375 Mdot
.99375 .50375 Mdot
.165 .50375 Mdot
.05875 .51375 Mdot
.94375 .51 Mdot
.13125 .48875 Mdot
.8825 .50375 Mdot
.6125 .51375 Mdot
.325 .58375 Mdot
.385 .54 Mdot
.3825 .51375 Mdot
.7775 .4475 Mdot
.37375 .39875 Mdot
.6775 .3675 Mdot
.17125 .41 Mdot
.85875 .485 Mdot
.305 .46 Mdot
.69 .47875 Mdot
.36625 .49625 Mdot
.25375 .51 Mdot
.54125 .46625 Mdot
.74625 .54625 Mdot
.81 .5725 Mdot
.00875 .58 Mdot
.68625 .56875 Mdot
.445 .635 Mdot
.62375 .62125 Mdot
.25625 .5875 Mdot
.74875 .585 Mdot
.3075 .5475 Mdot
.5725 .4925 Mdot
.5175 .4775 Mdot
.52875 .495 Mdot
.535 .51375 Mdot
.4575 .53625 Mdot
.6625 .5125 Mdot
.09 .47875 Mdot
.70875 .49125 Mdot
.30375 .44375 Mdot
.465 .41875 Mdot
.26375 .41875 Mdot
.61875 .41375 Mdot
.6225 .39875 Mdot
.3675 .42875 Mdot
.8175 .43625 Mdot
.2825 .46375 Mdot
.74625 .485 Mdot
.17375 .52625 Mdot
.61 .435 Mdot
.47 .44 Mdot
.46125 .46625 Mdot
.79 .47625 Mdot
.26 .50875 Mdot
.515 .52875 Mdot
.18125 .54875 Mdot
.805 .5375 Mdot
.18375 .55625 Mdot
.09 .48875 Mdot
.3125 .50125 Mdot
.9225 .49125 Mdot
.48 .46375 Mdot
.25375 .47125 Mdot
.67875 .5225 Mdot
.25 .495 Mdot
.52875 .48125 Mdot
.71 .49 Mdot
.2575 .4825 Mdot
.7875 .4775 Mdot
.4925 .4975 Mdot
.49 .53 Mdot
.69375 .50375 Mdot
.5775 .445 Mdot
.7325 .3925 Mdot
.59 .42625 Mdot
.255 .43625 Mdot
.975 .44125 Mdot
.50875 .47625 Mdot
.07125 .49 Mdot
.58875 .49125 Mdot
.48625 .52 Mdot
.25625 .50375 Mdot
.85375 .4875 Mdot
.13375 .49 Mdot
.575 .51625 Mdot
.3375 .50875 Mdot
.64375 .52125 Mdot
.7475 .505 Mdot
.24125 .48875 Mdot
.5125 .51625 Mdot
.77875 .61 Mdot
.4025 .63 Mdot
.56125 .62 Mdot
.29 .65625 Mdot
.53875 .66375 Mdot
.48625 .53875 Mdot
.44125 .51625 Mdot
.78 .50875 Mdot
.43625 .45375 Mdot
.23 .39375 Mdot
.68125 .43625 Mdot
.25375 .42875 Mdot
.79 .51125 Mdot
.59375 .54875 Mdot
.4225 .57375 Mdot
.35 .565 Mdot
.90375 .5825 Mdot
.2475 .5625 Mdot
.33625 .52625 Mdot
.32875 .505 Mdot
.9775 .495 Mdot
.05125 .4925 Mdot
.14125 .485 Mdot
.8925 .4875 Mdot
.30625 .57625 Mdot
.7125 .58 Mdot
.65625 .5625 Mdot
.36 .52625 Mdot
.26875 .535 Mdot
.47375 .63375 Mdot
.8025 .685 Mdot
.34 .74125 Mdot
.6425 .77125 Mdot
.2475 .69 Mdot
.755 .66 Mdot
.47125 .60875 Mdot
.54125 .635 Mdot
.425 .6275 Mdot
.22 .6 Mdot
.53 .53875 Mdot
.83125 .51375 Mdot
.73125 .48 Mdot
.87875 .52 Mdot
.2275 .43875 Mdot
.69125 .42375 Mdot
.3275 .41125 Mdot
.645 .395 Mdot
.41125 .41 Mdot
.49 .5 Mdot
.55625 .53375 Mdot
.5525 .5125 Mdot
.52625 .47 Mdot
.43375 .4525 Mdot
.665 .4825 Mdot
.0125 .49375 Mdot
.865 .46625 Mdot
.9225 .49375 Mdot
.25875 .52875 Mdot
.42625 .5775 Mdot
.40875 .59625 Mdot
.4775 .625 Mdot
.6375 .64375 Mdot
.405 .58125 Mdot
.80375 .5625 Mdot
.2875 .52375 Mdot
.70625 .50125 Mdot
.23375 .46 Mdot
.475 .5775 Mdot
.52 .5375 Mdot
.50875 .5475 Mdot
.805 .51625 Mdot
.22125 .47375 Mdot
.5225 .47 Mdot
.17 .47875 Mdot
.75875 .4575 Mdot
.24875 .48875 Mdot
.0275 .4875 Mdot
.34375 .4825 Mdot
.9 .48875 Mdot
.49625 .48375 Mdot
.28875 .5125 Mdot
.63125 .535 Mdot
.30875 .53875 Mdot
.47 .5175 Mdot
.70125 .515 Mdot
.29125 .50625 Mdot
.74625 .49125 Mdot
.5825 .4475 Mdot
.4025 .45 Mdot
.7175 .44125 Mdot
.01875 .45125 Mdot
.59 .46625 Mdot
1 .52125 Mdot
.77625 .5925 Mdot
.5625 .585 Mdot
.26875 .59875 Mdot
.95375 .6125 Mdot
.54375 .5775 Mdot
.035 .57125 Mdot
.6575 .57 Mdot
.37 .53875 Mdot
.37 .5475 Mdot
.82125 .5525 Mdot
.12625 .5575 Mdot
.61 .52875 Mdot
.27875 .5 Mdot
.7275 .5025 Mdot
.6775 .46625 Mdot
.28375 .44625 Mdot
.41375 .44125 Mdot
.91625 .41 Mdot
.3575 .3875 Mdot
.5425 .40125 Mdot
.25625 .38875 Mdot
.57125 .36 Mdot
.54 .40625 Mdot
.38 .41875 Mdot
.79375 .4475 Mdot
.48125 .51875 Mdot
.13 .5675 Mdot
.695 .55 Mdot
.3525 .57375 Mdot
.95 .53125 Mdot
.90875 .46125 Mdot
.565 .44375 Mdot
.44125 .405 Mdot
.4075 .46125 Mdot
.7175 .46875 Mdot
.435 .46375 Mdot
.14625 .47625 Mdot
.26625 .4925 Mdot
.0575 .48875 Mdot
.97125 .4975 Mdot
.24625 .50125 Mdot
.8375 .51375 Mdot
.5075 .43625 Mdot
.6225 .45125 Mdot
.6075 .4225 Mdot
.425 .45625 Mdot
.13 .4475 Mdot
.07375 .39 Mdot
.5675 .37375 Mdot
.87 .33 Mdot
.28625 .3175 Mdot
.6125 .36875 Mdot
.33375 .40375 Mdot
.61875 .42375 Mdot
.6075 .47375 Mdot
.505 .44625 Mdot
.30875 .43375 Mdot
.39125 .45125 Mdot
.415 .48875 Mdot
.89375 .435 Mdot
.65375 .47875 Mdot
.03625 .4525 Mdot
.71625 .53 Mdot
.44 .5325 Mdot
.5325 .54875 Mdot
.50125 .59625 Mdot
.39625 .53 Mdot
.65625 .50375 Mdot
.4575 .49625 Mdot
.6325 .4775 Mdot
.345 .46 Mdot
.6725 .46875 Mdot
.99375 .48375 Mdot
.81375 .4725 Mdot
.30875 .48875 Mdot
.345 .3925 Mdot
.50625 .41 Mdot
.4425 .39 Mdot
.57875 .3625 Mdot
.46625 .36125 Mdot
.79375 .45625 Mdot
.27 .49125 Mdot
.695 .51375 Mdot
.31375 .54 Mdot
.35875 .47 Mdot
.56125 .51625 Mdot
.56125 .5325 Mdot
.79625 .56625 Mdot
.2375 .6 Mdot
.43625 .6 Mdot
.255 .595 Mdot
.685 .56875 Mdot
.315 .5 Mdot
.00875 .49875 Mdot
.34125 .48625 Mdot
.87375 .5025 Mdot
.555 .53 Mdot
.30375 .49375 Mdot
.54875 .4425 Mdot
.4075 .44125 Mdot
.415 .45125 Mdot
.66625 .45375 Mdot
.30375 .48 Mdot
.7625 .485 Mdot
.6425 .51625 Mdot
.31625 .515 Mdot
.7775 .5275 Mdot
0 .52625 Mdot
.5675 .5575 Mdot
.995 .54125 Mdot
.79375 .5 Mdot
.54375 .48 Mdot
.27 .46875 Mdot
.93625 .46875 Mdot
.575 .5025 Mdot
.01875 .5075 Mdot
.71125 .52125 Mdot
.28875 .52625 Mdot
.425 .5275 Mdot
.825 .535 Mdot
.11125 .5275 Mdot
.64875 .52875 Mdot
.2325 .545 Mdot
.78125 .54875 Mdot
.60625 .59875 Mdot
.36625 .62375 Mdot
.28625 .63625 Mdot
.3575 .58375 Mdot
.51125 .5525 Mdot
.22375 .5325 Mdot
.56 .545 Mdot
.62375 .56375 Mdot
.33125 .5325 Mdot
.74375 .51125 Mdot
.5975 .485 Mdot
.02 .45 Mdot
.715 .44 Mdot
.40875 .46625 Mdot
.93125 .48875 Mdot
.94 .4925 Mdot
.57375 .51875 Mdot
.4775 .55 Mdot
.4225 .535 Mdot
.59875 .55625 Mdot
.54875 .58625 Mdot
.0175 .5925 Mdot
.23625 .55375 Mdot
.15375 .5525 Mdot
.91625 .54625 Mdot
.01375 .565 Mdot
.34375 .58125 Mdot
.79625 .53125 Mdot
.8725 .47125 Mdot
.6725 .49625 Mdot
.5725 .50125 Mdot
.58125 .56625 Mdot
.485 .555 Mdot
.93125 .55 Mdot
.28375 .54875 Mdot
.64875 .51 Mdot
.18875 .48375 Mdot
.5325 .4375 Mdot
.4475 .395 Mdot
.52875 .385 Mdot
.69125 .38375 Mdot
.5 .36875 Mdot
.16625 .43 Mdot
.55875 .46875 Mdot
.30375 .44375 Mdot
.95 .4975 Mdot
.62125 .48 Mdot
.7025 .47375 Mdot
.48875 .52125 Mdot
.51 .50875 Mdot
.55125 .495 Mdot
.33875 .4775 Mdot
.74375 .4575 Mdot
.265 .445 Mdot
.79375 .44 Mdot
.2925 .465 Mdot
.68125 .4475 Mdot
.64 .51625 Mdot
.4075 .4825 Mdot
.25375 .55625 Mdot
.595 .5275 Mdot
.3325 .55 Mdot
.6275 .575 Mdot
.48875 .6325 Mdot
.78875 .51625 Mdot
.23625 .53 Mdot
.70875 .50625 Mdot
.37 .4975 Mdot
.2425 .53125 Mdot
.605 .515 Mdot
.59875 .45625 Mdot
.785 .43875 Mdot
.275 .4225 Mdot
.32 .415 Mdot
.38375 .4125 Mdot
.59 .4575 Mdot
.38375 .53 Mdot
.02125 .5375 Mdot
.335 .52375 Mdot
.86625 .50625 Mdot
.55375 .47625 Mdot
.39125 .47875 Mdot
.415 .515 Mdot
.5075 .545 Mdot
.38375 .55 Mdot
.6075 .5575 Mdot
.3525 .55375 Mdot
.76125 .55 Mdot
.67875 .5425 Mdot
.2175 .54125 Mdot
.88 .54 Mdot
.01375 .54625 Mdot
.49625 .5275 Mdot
.80625 .50875 Mdot
.5525 .51625 Mdot
.2425 .50625 Mdot
.915 .48875 Mdot
.66375 .44625 Mdot
.75875 .42875 Mdot
.2225 .41625 Mdot
.4825 .39875 Mdot
.7875 .39 Mdot
.0975 .41375 Mdot
.6925 .4275 Mdot
.195 .41625 Mdot
.80875 .4075 Mdot
.575 .39875 Mdot
.40625 .37375 Mdot
.19875 .37 Mdot
.3825 .4525 Mdot
.435 .4925 Mdot
.2575 .52375 Mdot
.49875 .5575 Mdot
.72625 .52 Mdot
.31 .53875 Mdot
.7 .5425 Mdot
.63125 .53625 Mdot
.73875 .545 Mdot
.43625 .53125 Mdot
.88625 .5275 Mdot
.95125 .5375 Mdot
.57875 .49625 Mdot
.5175 .47 Mdot
.41375 .42875 Mdot
.5575 .41875 Mdot
.58875 .40625 Mdot
.2575 .43125 Mdot
.21875 .42875 Mdot
.8175 .445 Mdot
.16875 .42875 Mdot
.90375 .44 Mdot
.4725 .445 Mdot
.7175 .46875 Mdot
.68 .49875 Mdot
.7325 .52 Mdot
.59375 .50875 Mdot
.5675 .47625 Mdot
.5375 .47875 Mdot
.79375 .48 Mdot
.32375 .475 Mdot
.60375 .50375 Mdot
.105 .61375 Mdot
.4625 .645 Mdot
.5975 .65875 Mdot
.425 .63625 Mdot
.6975 .58125 Mdot
.5475 .57625 Mdot
.07125 .52375 Mdot
.65 .50375 Mdot
.23875 .52375 Mdot
.5725 .48125 Mdot
.64625 .4925 Mdot
.56 .51125 Mdot
.47 .51375 Mdot
.5275 .55875 Mdot
.38 .5725 Mdot
.8025 .5975 Mdot
.06 .6 Mdot
.94125 .62375 Mdot
.2775 .5575 Mdot
.6475 .5675 Mdot
.5 .50625 Mdot
.57125 .53875 Mdot
.21125 .51375 Mdot
.565 .52 Mdot
.315 .47375 Mdot
.65625 .465 Mdot
.52125 .47125 Mdot
.80375 .49375 Mdot
.165 .5 Mdot
.73 .51 Mdot
.43 .5075 Mdot
.12 .465 Mdot
.64875 .44875 Mdot
.6275 .48 Mdot
.76125 .44375 Mdot
.28875 .43375 Mdot
.25875 .42875 Mdot
.49625 .4425 Mdot
.4875 .43375 Mdot
.4525 .4375 Mdot
.08125 .48875 Mdot
.365 .50375 Mdot
.81125 .53375 Mdot
.51 .54375 Mdot
.575 .54 Mdot
.235 .51125 Mdot
.585 .49875 Mdot
.39125 .4725 Mdot
.545 .46375 Mdot
.38625 .44875 Mdot
.7675 .44 Mdot
.59625 .45625 Mdot
.33125 .46625 Mdot
.9075 .46625 Mdot
.49375 .47 Mdot
.965 .44625 Mdot
.79 .45 Mdot
.5375 .455 Mdot
.27875 .44125 Mdot
.86625 .445 Mdot
.7275 .45125 Mdot
.78125 .495 Mdot
.19 .54625 Mdot
.5425 .5675 Mdot
.7525 .5525 Mdot
.12625 .52125 Mdot
.7075 .51625 Mdot
.17 .5325 Mdot
.8275 .5325 Mdot
.56 .54625 Mdot
.43125 .54875 Mdot
.13625 .5225 Mdot
.43625 .48625 Mdot
.33 .46875 Mdot
.3625 .44875 Mdot
.40125 .42625 Mdot
.83125 .4625 Mdot
.29875 .43 Mdot
.60125 .41125 Mdot
.67875 .42875 Mdot
.745 .435 Mdot
.49 .46 Mdot
.82 .4775 Mdot
.96375 .5025 Mdot
.54375 .50875 Mdot
.5475 .52125 Mdot
.43 .54 Mdot
.53875 .54375 Mdot
.56375 .54375 Mdot
.07 .5825 Mdot
.285 .56 Mdot
.29 .55875 Mdot
.69375 .575 Mdot
.41125 .55875 Mdot
.67375 .55125 Mdot
.56375 .53875 Mdot
.64125 .5275 Mdot
.525 .4775 Mdot
.7475 .45875 Mdot
.6175 .48 Mdot
.595 .50375 Mdot
.5475 .515 Mdot
.6975 .5425 Mdot
.27375 .54625 Mdot
.13375 .5175 Mdot
.45375 .47375 Mdot
.03 .3775 Mdot
.44125 .36875 Mdot
.6925 .42875 Mdot
.32625 .45875 Mdot
.7075 .53 Mdot
.59875 .56 Mdot
.0275 .5325 Mdot
.69 .48375 Mdot
.20625 .485 Mdot
.4925 .4875 Mdot
.0075 .56625 Mdot
.55625 .55875 Mdot
.60375 .54 Mdot
.47625 .57125 Mdot
.47875 .50875 Mdot
.41375 .49625 Mdot
.84875 .4325 Mdot
.2875 .47125 Mdot
.62375 .48875 Mdot
.0675 .52875 Mdot
.46 .525 Mdot
.99875 .48 Mdot
.595 .5275 Mdot
.22375 .47375 Mdot
.48875 .47 Mdot
.43125 .47 Mdot
.55375 .4375 Mdot
.6325 .395 Mdot
.73625 .4525 Mdot
.1725 .4275 Mdot
.71125 .44125 Mdot
.52375 .4625 Mdot
.0825 .51125 Mdot
.6325 .525 Mdot
.6975 .52 Mdot
.69375 .54125 Mdot
.3175 .56375 Mdot
.21625 .57875 Mdot
.6025 .57875 Mdot
.4075 .57375 Mdot
.485 .54875 Mdot
.9675 .5225 Mdot
.11375 .5075 Mdot
.38875 .5025 Mdot
.755 .505 Mdot
.4925 .51625 Mdot
.73125 .52 Mdot
.08125 .5225 Mdot
.63 .50625 Mdot
.44 .52875 Mdot
.4675 .54 Mdot
.42875 .54625 Mdot
.7575 .5325 Mdot
.51125 .525 Mdot
.49 .525 Mdot
.83625 .5225 Mdot
.49 .57 Mdot
.9175 .5925 Mdot
.78375 .5975 Mdot
.525 .58875 Mdot
.2925 .63375 Mdot
.86125 .6475 Mdot
.70375 .655 Mdot
.78125 .56375 Mdot
.1775 .48625 Mdot
.61 .46 Mdot
.72125 .5 Mdot
.16375 .53 Mdot
.68125 .51625 Mdot
.20875 .52 Mdot
.7925 .50375 Mdot
.57125 .48625 Mdot
.44375 .48375 Mdot
.07625 .51625 Mdot
.47375 .54 Mdot
.305 .5075 Mdot
.37125 .51625 Mdot
.3125 .52625 Mdot
.9525 .53625 Mdot
.29125 .5625 Mdot
.53875 .60375 Mdot
.685 .60625 Mdot
.78625 .59625 Mdot
.51375 .56 Mdot
.77875 .5625 Mdot
.96 .51 Mdot
.485 .49125 Mdot
.61 .50125 Mdot
.3875 .45125 Mdot
.60125 .46875 Mdot
.47625 .47375 Mdot
.23625 .4875 Mdot
.8775 .4775 Mdot
.3175 .5075 Mdot
.29625 .51625 Mdot
.66125 .48875 Mdot
.60375 .485 Mdot
.495 .4825 Mdot
.57875 .5075 Mdot
.60875 .49 Mdot
.37 .55125 Mdot
.6975 .50375 Mdot
.65 .4725 Mdot
.69 .4425 Mdot
.4775 .39375 Mdot
.65875 .42 Mdot
.26375 .4575 Mdot
.245 .51125 Mdot
.365 .51625 Mdot
.50625 .535 Mdot
.6875 .45625 Mdot
.305 .43375 Mdot
.64875 .40875 Mdot
.6525 .39875 Mdot
.025 .395 Mdot
.7275 .4475 Mdot
.125 .46 Mdot
.3975 .45875 Mdot
.035 .47125 Mdot
.10875 .4225 Mdot
.53 .42125 Mdot
.5725 .40375 Mdot
.53625 .38625 Mdot
.4125 .39125 Mdot
.47375 .46125 Mdot
.84125 .50375 Mdot
.2975 .57625 Mdot
.6225 .545 Mdot
.09875 .55 Mdot
.97625 .5325 Mdot
.385 .565 Mdot
.15 .51875 Mdot
.8275 .535 Mdot
.63 .51125 Mdot
.2475 .53 Mdot
.3725 .52375 Mdot
.54875 .565 Mdot
.5075 .59 Mdot
.68125 .61625 Mdot
.6825 .58375 Mdot
.17125 .58375 Mdot
.755 .585 Mdot
.5275 .54875 Mdot
.12125 .5575 Mdot
.54125 .56875 Mdot
.8275 .5725 Mdot
.565 .56875 Mdot
.38 .53 Mdot
.17375 .51375 Mdot
.70875 .50125 Mdot
.30625 .47875 Mdot
.55125 .46 Mdot
.88375 .4725 Mdot
.1575 .4325 Mdot
.43625 .39125 Mdot
.69 .3925 Mdot
.48625 .4025 Mdot
.82375 .4025 Mdot
.6825 .48625 Mdot
.48125 .47875 Mdot
.4075 .475 Mdot
.4725 .37875 Mdot
.70125 .4 Mdot
.51 .37875 Mdot
.56375 .34875 Mdot
.80125 .345 Mdot
.5 .38 Mdot
.87 .37625 Mdot
.76375 .395 Mdot
.505 .425 Mdot
.35875 .3875 Mdot
.7925 .37625 Mdot
.7025 .375 Mdot
.7725 .41375 Mdot
.1825 .49875 Mdot
.67125 .54 Mdot
.63375 .54875 Mdot
.2275 .5075 Mdot
.64625 .505 Mdot
.2625 .5075 Mdot
.74625 .5325 Mdot
.59125 .52875 Mdot
.4625 .5275 Mdot
.02 .51375 Mdot
.54 .4575 Mdot
.25375 .48375 Mdot
.43875 .50625 Mdot
.2 .51375 Mdot
.25875 .5075 Mdot
.575 .47375 Mdot
.61375 .44 Mdot
.85875 .4175 Mdot
.47875 .445 Mdot
.7625 .44875 Mdot
.92125 .485 Mdot
.44 .5025 Mdot
.6575 .46375 Mdot
.34625 .4725 Mdot
.66875 .46875 Mdot
.3675 .48375 Mdot
.4275 .45375 Mdot
.72 .49 Mdot
.3475 .485 Mdot
.27375 .4625 Mdot
.63375 .47875 Mdot
.7925 .50125 Mdot
.36125 .495 Mdot
.5675 .5075 Mdot
.56875 .53 Mdot
.24125 .53125 Mdot
.5925 .525 Mdot
.67625 .52125 Mdot
.78125 .4725 Mdot
.45875 .44875 Mdot
.6075 .4625 Mdot
.23625 .47875 Mdot
.36625 .49125 Mdot
.2725 .55375 Mdot
.565 .58375 Mdot
.61375 .58125 Mdot
.4 .5625 Mdot
.56375 .5375 Mdot
.7175 .515 Mdot
.73 .575 Mdot
.0975 .59875 Mdot
.28875 .60125 Mdot
.1325 .5475 Mdot
.16 .465 Mdot
.5825 .465 Mdot
.49 .50375 Mdot
.58625 .52125 Mdot
.34375 .5425 Mdot
.55875 .5175 Mdot
.7575 .5075 Mdot
.3875 .4075 Mdot
.57875 .38 Mdot
.17125 .375 Mdot
.90375 .37625 Mdot
.27375 .45 Mdot
.405 .5 Mdot
.6775 .54125 Mdot
.6225 .525 Mdot
.3 .55125 Mdot
.30125 .495 Mdot
.5975 .47875 Mdot
.50625 .42375 Mdot
.6875 .4075 Mdot
.64125 .41125 Mdot
.20625 .42 Mdot
.73 .40625 Mdot
.545 .48625 Mdot
.15375 .41875 Mdot
.46 .39375 Mdot
.9475 .4275 Mdot
.42375 .44 Mdot
.44 .48375 Mdot
.19625 .505 Mdot
.745 .5275 Mdot
.2375 .57 Mdot
.58 .5725 Mdot
.82625 .56375 Mdot
.2225 .58 Mdot
.46625 .62625 Mdot
.61 .575 Mdot
.48625 .55625 Mdot
.90875 .5275 Mdot
.655 .44 Mdot
.56125 .475 Mdot
.32625 .48375 Mdot
.5325 .62375 Mdot
.63125 .68 Mdot
.48125 .6875 Mdot
.7325 .68625 Mdot
.685 .67625 Mdot
.00125 .57125 Mdot
.52625 .535 Mdot
.81375 .55 Mdot
.77875 .5625 Mdot
.48125 .5625 Mdot
.4175 .55875 Mdot
.7575 .5575 Mdot
.66125 .5575 Mdot
.77875 .5625 Mdot
.17875 .5275 Mdot
.7425 .50375 Mdot
.0875 .47125 Mdot
.5025 .44125 Mdot
.29125 .47625 Mdot
.5925 .48125 Mdot
.3325 .47125 Mdot
.69125 .455 Mdot
.61375 .48125 Mdot
.4975 .4875 Mdot
.6225 .5475 Mdot
.23125 .54125 Mdot
.425 .50125 Mdot
.17625 .4875 Mdot
.22125 .46375 Mdot
.62125 .4775 Mdot
.50625 .52125 Mdot
.8975 .52625 Mdot
.42875 .525 Mdot
.7725 .5275 Mdot
.86 .50375 Mdot
.42375 .49125 Mdot
.66125 .5 Mdot
.3475 .49875 Mdot
.70625 .49125 Mdot
.2725 .48125 Mdot
.61125 .51875 Mdot
.60125 .4725 Mdot
.35 .48 Mdot
.2525 .48625 Mdot
.61125 .48625 Mdot
.945 .4725 Mdot
.2425 .51 Mdot
.59125 .47375 Mdot
.49375 .47125 Mdot
.145 .47 Mdot
.48125 .50875 Mdot
.71875 .4925 Mdot
.7725 .5275 Mdot
.54625 .6275 Mdot
.5275 .6 Mdot
.26625 .5825 Mdot
.455 .565 Mdot
.19 .49625 Mdot
.64875 .39375 Mdot
.50625 .4325 Mdot
.51125 .495 Mdot
.42125 .51 Mdot
.86875 .54875 Mdot
.74 .53375 Mdot
.07125 .48375 Mdot
.17 .52375 Mdot
.2425 .525 Mdot
.9925 .55875 Mdot
.135 .59125 Mdot
.64875 .54875 Mdot
.435 .49125 Mdot
.66 .4725 Mdot
.26625 .4125 Mdot
.62 .39 Mdot
.66 .4075 Mdot
.04125 .4425 Mdot
.8675 .47375 Mdot
.46625 .5025 Mdot
.485 .54125 Mdot
.31625 .54375 Mdot
.785 .52625 Mdot
.26625 .4225 Mdot
.5375 .40625 Mdot
.58 .375 Mdot
.565 .4025 Mdot
.40625 .43 Mdot
.22375 .52375 Mdot
.68 .545 Mdot
.4475 .585 Mdot
.7225 .58 Mdot
.59 .55875 Mdot
.23875 .51375 Mdot
.705 .51 Mdot
.56875 .44375 Mdot
.2 .47125 Mdot
.3975 .48875 Mdot
.295 .45875 Mdot
.53 .46625 Mdot
.17625 .4275 Mdot
.775 .42625 Mdot
.205 .42375 Mdot
.62375 .4575 Mdot
.72625 .4725 Mdot
.25875 .52125 Mdot
.5275 .55375 Mdot
.5475 .5925 Mdot
.48 .59625 Mdot
.97875 .62 Mdot
.6175 .615 Mdot
.66375 .60375 Mdot
.2475 .58125 Mdot
.53875 .58 Mdot
.64875 .53 Mdot
.37125 .53 Mdot
.95125 .51375 Mdot
.5175 .52 Mdot
.01375 .4725 Mdot
.5875 .49125 Mdot
.74375 .4625 Mdot
.05 .45875 Mdot
.73375 .46125 Mdot
.5 .4675 Mdot
.46 .5 Mdot
.74875 .515 Mdot
.5425 .51875 Mdot
.03125 .50125 Mdot
.7425 .49625 Mdot
.21125 .4525 Mdot
.80125 .45375 Mdot
.8825 .45875 Mdot
.22 .45375 Mdot
.38375 .465 Mdot
.355 .48 Mdot
.53 .46875 Mdot
.43125 .45875 Mdot
.65875 .47875 Mdot
.5725 .495 Mdot
.555 .48625 Mdot
.6725 .44625 Mdot
.25875 .45 Mdot
.3925 .47 Mdot
.21375 .44375 Mdot
.21125 .47375 Mdot
.6975 .455 Mdot
.36625 .4475 Mdot
.06125 .45625 Mdot
.8625 .455 Mdot
.4175 .44875 Mdot
.77875 .435 Mdot
.04375 .46 Mdot
.75125 .4775 Mdot
.47 .52 Mdot
.57875 .5325 Mdot
.41125 .545 Mdot
.705 .51875 Mdot
.26125 .51125 Mdot
.69125 .46875 Mdot
.5225 .49125 Mdot
.3325 .48375 Mdot
.255 .4775 Mdot
.64 .4725 Mdot
.98375 .475 Mdot
.22 .4575 Mdot
.57875 .47125 Mdot
.43625 .4825 Mdot
.04125 .48375 Mdot
.3925 .5075 Mdot
.78625 .5425 Mdot
.70625 .54125 Mdot
.64625 .4925 Mdot
.42875 .47 Mdot
.36125 .475 Mdot
.415 .44 Mdot
.265 .46375 Mdot
.0375 .485 Mdot
.6975 .4725 Mdot
.38375 .4675 Mdot
.67625 .455 Mdot
.27625 .43875 Mdot
.9625 .4375 Mdot
.62125 .39 Mdot
.1825 .355 Mdot
.09875 .3775 Mdot
.3725 .405 Mdot
.93625 .46875 Mdot
.03625 .5275 Mdot
.765 .57125 Mdot
.4125 .58375 Mdot
.6575 .56875 Mdot
.26625 .5475 Mdot
.6175 .54625 Mdot
.56125 .5375 Mdot
.26625 .5525 Mdot
.69375 .57125 Mdot
.575 .58625 Mdot
.3525 .5925 Mdot
.44375 .575 Mdot
.69375 .575 Mdot
.27125 .61125 Mdot
.6225 .61 Mdot
.53625 .5475 Mdot
.5125 .535 Mdot
.4375 .5225 Mdot
.21875 .50875 Mdot
.74125 .48375 Mdot
.405 .51875 Mdot
.72125 .55125 Mdot
.525 .52125 Mdot
.32375 .51125 Mdot
.6775 .5125 Mdot
.56125 .495 Mdot
.285 .5925 Mdot
.29125 .56625 Mdot
.16125 .52375 Mdot
.60875 .47875 Mdot
.16875 .5 Mdot
.80625 .48125 Mdot
.1575 .475 Mdot
.68 .46125 Mdot
.62125 .4725 Mdot
.295 .44375 Mdot
.58125 .41375 Mdot
.4975 .4125 Mdot
.51375 .4275 Mdot
.9275 .41875 Mdot
.615 .46125 Mdot
.715 .44875 Mdot
.1925 .42125 Mdot
.51875 .33125 Mdot
.68875 .325 Mdot
.35125 .3425 Mdot
.99 .38625 Mdot
.4375 .4225 Mdot
.0225 .555 Mdot
.65375 .57125 Mdot
.67875 .58 Mdot
.08875 .57875 Mdot
.7175 .5375 Mdot
.5325 .5075 Mdot
.47 .48625 Mdot
.7725 .4675 Mdot
.43375 .45625 Mdot
.08375 .5025 Mdot
.73375 .5 Mdot
.2425 .53 Mdot
.79625 .55375 Mdot
.81 .5775 Mdot
.37125 .585 Mdot
.24375 .595 Mdot
.40875 .585 Mdot
.45625 .58125 Mdot
.58125 .56 Mdot
.53375 .52 Mdot
.62 .5225 Mdot
.56 .53125 Mdot
.04 .51375 Mdot
.9325 .53125 Mdot
.6975 .53625 Mdot
.32875 .51 Mdot
.2925 .495 Mdot
.32 .52375 Mdot
.23625 .51875 Mdot
.79875 .5475 Mdot
.19 .55875 Mdot
.19375 .5425 Mdot
.80375 .5525 Mdot
.38375 .5825 Mdot
.80375 .56 Mdot
.11 .5525 Mdot
.67875 .5375 Mdot
.55 .50375 Mdot
.44 .48125 Mdot
.4875 .4925 Mdot
.7375 .46875 Mdot
.18875 .48 Mdot
.7575 .5025 Mdot
.51125 .52 Mdot
.3175 .525 Mdot
.23375 .55 Mdot
.70125 .535 Mdot
.9075 .51625 Mdot
.3225 .4775 Mdot
.49375 .465 Mdot
.38 .46375 Mdot
.39375 .44125 Mdot
.82125 .40625 Mdot
.565 .3875 Mdot
.8075 .39625 Mdot
.355 .39625 Mdot
.4825 .4575 Mdot
.2075 .52 Mdot
.475 .57 Mdot
.8475 .5925 Mdot
.2525 .615 Mdot
.62375 .6175 Mdot
.3025 .57625 Mdot
.81625 .515 Mdot
.20875 .52 Mdot
.9375 .51625 Mdot
.07375 .535 Mdot
.41375 .5925 Mdot
.345 .68875 Mdot
.555 .64625 Mdot
.83875 .56875 Mdot
.885 .43875 Mdot
.34125 .41375 Mdot
.675 .43125 Mdot
.28125 .475 Mdot
.62 .5125 Mdot
.4825 .51875 Mdot
.4825 .52875 Mdot
.54375 .50125 Mdot
.625 .47 Mdot
.265 .43125 Mdot
.49875 .4625 Mdot
.70625 .47 Mdot
.2325 .465 Mdot
.65875 .45 Mdot
.5025 .495 Mdot
.48875 .45625 Mdot
.435 .41625 Mdot
.3325 .3925 Mdot
.685 .4175 Mdot
.38625 .4075 Mdot
.72375 .3975 Mdot
.52 .46375 Mdot
.32 .51875 Mdot
.68375 .53 Mdot
.52875 .57375 Mdot
.40125 .47625 Mdot
.23875 .49 Mdot
.13375 .5625 Mdot
.65125 .56875 Mdot
.1725 .585 Mdot
.8025 .63125 Mdot
.14125 .61625 Mdot
.68125 .5825 Mdot
.685 .53375 Mdot
.2225 .51125 Mdot
.6775 .44875 Mdot
.3925 .405 Mdot
.525 .38625 Mdot
.87875 .3975 Mdot
.045 .39625 Mdot
.55125 .40125 Mdot
.6425 .4075 Mdot
.31375 .51125 Mdot
.50125 .595 Mdot
.605 .615 Mdot
.50125 .60375 Mdot
.7525 .595 Mdot
.5675 .49625 Mdot
.03125 .38875 Mdot
.57125 .37625 Mdot
.78375 .34375 Mdot
.0275 .34375 Mdot
.79625 .395 Mdot
.49 .4575 Mdot
.4875 .47125 Mdot
.84125 .52125 Mdot
.18875 .52875 Mdot
.2325 .4925 Mdot
.69625 .475 Mdot
.4025 .48 Mdot
.74625 .435 Mdot
.67625 .40375 Mdot
.39875 .39875 Mdot
.28625 .39125 Mdot
.4125 .3725 Mdot
.46125 .42 Mdot
.60875 .4725 Mdot
.48875 .49875 Mdot
.56375 .51 Mdot
.5825 .535 Mdot
.18375 .51375 Mdot
.79 .4825 Mdot
.7225 .505 Mdot
.35375 .52 Mdot
.17625 .50875 Mdot
.5625 .5125 Mdot
.8275 .52875 Mdot
.31875 .515 Mdot
.82875 .50375 Mdot
.0425 .47625 Mdot
.43625 .495 Mdot
.6875 .4875 Mdot
.34375 .47 Mdot
.82375 .47125 Mdot
.03375 .5 Mdot
.83 .48125 Mdot
.46375 .48 Mdot
.47625 .485 Mdot
.48125 .5025 Mdot
.6625 .53 Mdot
.265 .53125 Mdot
.7775 .515 Mdot
.4675 .48 Mdot
.27375 .46625 Mdot
.34125 .43125 Mdot
.625 .44 Mdot
.97 .47375 Mdot
.30125 .54 Mdot
.425 .535 Mdot
.39625 .54375 Mdot
.26125 .49875 Mdot
.44 .57625 Mdot
.82375 .62125 Mdot
.4575 .66375 Mdot
.85625 .6625 Mdot
.42 .60625 Mdot
.46 .53625 Mdot
.17 .485 Mdot
.4875 .435 Mdot
.84625 .39125 Mdot
.31625 .415 Mdot
.55875 .41875 Mdot
.28625 .46125 Mdot
.86625 .4675 Mdot
.2525 .53125 Mdot
.7225 .515 Mdot
.22 .50875 Mdot
.405 .43125 Mdot
.445 .3875 Mdot
.54125 .355 Mdot
.79125 .3975 Mdot
.05375 .47 Mdot
.845 .47875 Mdot
.31375 .50125 Mdot
.68875 .51125 Mdot
.2375 .5075 Mdot
.67 .48375 Mdot
.43625 .485 Mdot
.63 .5025 Mdot
.45 .515 Mdot
.595 .53 Mdot
.265 .55375 Mdot
.56125 .55875 Mdot
.645 .52 Mdot
.30125 .5 Mdot
.53875 .515 Mdot
.5975 .50375 Mdot
.45 .53375 Mdot
.35875 .5575 Mdot
.445 .58 Mdot
.71 .55375 Mdot
.3775 .54 Mdot
.70875 .5325 Mdot
.46375 .52375 Mdot
.36125 .49375 Mdot
.6325 .49625 Mdot
.52375 .505 Mdot
.53375 .48 Mdot
.2325 .48125 Mdot
.1925 .43875 Mdot
.67 .4675 Mdot
.135 .47125 Mdot
.82375 .44625 Mdot
.175 .4575 Mdot
.61875 .4925 Mdot
.74875 .5325 Mdot
.1575 .54 Mdot
.7675 .615 Mdot
.31375 .6575 Mdot
.5175 .65625 Mdot
.86875 .67625 Mdot
.1675 .69 Mdot
.4925 .6625 Mdot
.53 .64625 Mdot
.445 .58875 Mdot
.48625 .52 Mdot
.5675 .49375 Mdot
.555 .4675 Mdot
.6425 .45375 Mdot
.63 .5225 Mdot
.0525 .56625 Mdot
.47625 .55375 Mdot
.915 .56375 Mdot
.87 .5 Mdot
.455 .435 Mdot
.45375 .44 Mdot
.94875 .4075 Mdot
.37125 .46 Mdot
.65625 .47 Mdot
.56125 .4775 Mdot
.68 .52625 Mdot
.57875 .5475 Mdot
.38125 .5425 Mdot
.35875 .57625 Mdot
.41375 .6 Mdot
.475 .52375 Mdot
.6075 .5 Mdot
.465 .48125 Mdot
.50875 .45 Mdot
.5825 .41375 Mdot
.35 .48 Mdot
.65125 .4875 Mdot
.725 .475 Mdot
.40875 .475 Mdot
.05 .47 Mdot
.76375 .44875 Mdot
.675 .4275 Mdot
.38 .43375 Mdot
.795 .44125 Mdot
.71625 .4925 Mdot
.50125 .525 Mdot
.3575 .51875 Mdot
.83375 .52625 Mdot
.9575 .5375 Mdot
.39875 .545 Mdot
.5325 .60375 Mdot
.4475 .58875 Mdot
.6075 .55875 Mdot
.33875 .5425 Mdot
.80375 .54875 Mdot
.40125 .56875 Mdot
.23 .62125 Mdot
.49125 .63875 Mdot
.525 .67875 Mdot
.9675 .65 Mdot
.34375 .54875 Mdot
.36125 .5375 Mdot
.3975 .53125 Mdot
.5425 .51875 Mdot
.4875 .4525 Mdot
.85875 .41625 Mdot
.36 .42 Mdot
.86 .4275 Mdot
.51375 .47 Mdot
.40125 .5075 Mdot
.16375 .48 Mdot
.49125 .51375 Mdot
.85625 .50625 Mdot
.36875 .4975 Mdot
.47375 .46125 Mdot
.33 .5375 Mdot
.8425 .50625 Mdot
.3625 .48125 Mdot
.4275 .455 Mdot
.4325 .48 Mdot
.38375 .535 Mdot
.535 .5925 Mdot
.025 .6175 Mdot
.505 .64375 Mdot
.73625 .5825 Mdot
.1675 .50875 Mdot
.77375 .47125 Mdot
.34125 .47375 Mdot
.7225 .43 Mdot
.165 .4325 Mdot
.71625 .455 Mdot
.38875 .50625 Mdot
.73625 .4775 Mdot
.3925 .5125 Mdot
.55875 .48375 Mdot
.3075 .49375 Mdot
.5475 .48625 Mdot
.605 .5325 Mdot
.4175 .57125 Mdot
.39875 .585 Mdot
.67125 .55375 Mdot
.4275 .53125 Mdot
.3075 .5225 Mdot
.50875 .45375 Mdot
.7225 .46375 Mdot
.38875 .50625 Mdot
.6975 .47125 Mdot
.44125 .4725 Mdot
.3725 .49375 Mdot
.6075 .4925 Mdot
.475 .44875 Mdot
.66625 .4575 Mdot
.2125 .47 Mdot
.91 .515 Mdot
.24625 .51875 Mdot
.67625 .4 Mdot
.10375 .35375 Mdot
.85875 .225 Mdot
.20125 .23125 Mdot
.56625 .205 Mdot
.80875 .26125 Mdot
.0925 .3225 Mdot
.85375 .39875 Mdot
.21875 .3125 Mdot
.5575 .33875 Mdot
.77 .28875 Mdot
.31625 .1625 Mdot
.53625 .16 Mdot
.3325 .295 Mdot
.5825 .27 Mdot
.47875 .41875 Mdot
.53875 .5025 Mdot
.6325 .52625 Mdot
.4625 .505 Mdot
.71625 .43125 Mdot
.08375 .30375 Mdot
.37375 .31875 Mdot
.91 .52125 Mdot
.43875 .6 Mdot
.465 .55875 Mdot
.985 .47125 Mdot
.52625 .35125 Mdot
.61 .39625 Mdot
.6775 .5175 Mdot
.645 .47875 Mdot
.495 .53125 Mdot
.32 .5125 Mdot
.47125 .465 Mdot
.41125 .42 Mdot
.5225 .5975 Mdot
.5375 .61625 Mdot
.48375 .595 Mdot
.48 .5225 Mdot
.53875 .5225 Mdot
.49 .46 Mdot
.5625 .4975 Mdot
.7175 .53 Mdot
.43125 .6125 Mdot
.96625 .63625 Mdot
.4675 .5825 Mdot
.4825 .5375 Mdot
.7475 .47125 Mdot
.93625 .45125 Mdot
.32875 .49875 Mdot
.4175 .47875 Mdot
.81125 .49875 Mdot
.30375 .30875 Mdot
.6125 .28625 Mdot
.41125 .25875 Mdot
.55125 .3975 Mdot
.425 .375 Mdot
.815 .305 Mdot
.3125 .35 Mdot
.22 .2675 Mdot
.615 .28875 Mdot
.48 .26 Mdot
.895 .29375 Mdot
.455 .37375 Mdot
.2575 .53875 Mdot
.415 .35375 Mdot
.0575 .395 Mdot
.815 .40875 Mdot
.54 .51 Mdot
.8975 .46375 Mdot
.295 .4725 Mdot
.7875 .425 Mdot
.61125 .46625 Mdot
.37375 .2925 Mdot
.1575 .41625 Mdot
.46625 .35375 Mdot
.87125 .4 Mdot
.45875 .43375 Mdot
.3525 .59375 Mdot
.4175 .5825 Mdot
.785 .6475 Mdot
.5175 .49625 Mdot
.09125 .46375 Mdot
.61375 .4375 Mdot
.41 .2875 Mdot
.59 .29 Mdot
.1175 .32875 Mdot
.405 .345 Mdot
.70625 .4525 Mdot
.28375 .48125 Mdot
.69875 .5825 Mdot
.385 .65125 Mdot
.66875 .6325 Mdot
.17875 .6225 Mdot
.75375 .5475 Mdot
.35 .46625 Mdot
.78125 .40875 Mdot
.3875 .35375 Mdot
.48875 .37 Mdot
.4025 .3525 Mdot
.49875 .37375 Mdot
.60375 .36375 Mdot
.47875 .3325 Mdot
.285 .33 Mdot
.7675 .39125 Mdot
.355 .31875 Mdot
.26375 .36 Mdot
.60375 .44875 Mdot
.745 .46875 Mdot
.36375 .44 Mdot
.6575 .5525 Mdot
.46375 .545 Mdot
.37375 .47625 Mdot
.60625 .425 Mdot
.40125 .49625 Mdot
.78625 .48125 Mdot
.18125 .47875 Mdot
.82 .46625 Mdot
.29875 .48 Mdot
.69875 .56875 Mdot
.04875 .63 Mdot
.90375 .75875 Mdot
.195 .735 Mdot
.51625 .765 Mdot
.93375 .685 Mdot
.00625 .61 Mdot
.9 .5025 Mdot
.13875 .59 Mdot
.635 .5875 Mdot
.64625 .665 Mdot
.47 .785 Mdot
.51625 .785 Mdot
.2025 .63875 Mdot
.6825 .635 Mdot
.5175 .47375 Mdot
.425 .405 Mdot
.81375 .41625 Mdot
.24875 .45375 Mdot
.79375 .5225 Mdot
.12625 .66875 Mdot
.2725 .6925 Mdot
.985 .625 Mdot
.3725 .54875 Mdot
.4775 .57125 Mdot
.615 .7 Mdot
.57875 .67375 Mdot
.81625 .525 Mdot
.5675 .5225 Mdot
.41625 .44625 Mdot
.30625 .46 Mdot
.5625 .49125 Mdot
.36625 .52375 Mdot
.58375 .39 Mdot
.48125 .375 Mdot
.49 .42 Mdot
.45625 .495 Mdot
.51375 .50875 Mdot
.57875 .5375 Mdot
.53 .51125 Mdot
.7225 .4925 Mdot
.4325 .41 Mdot
.29875 .47875 Mdot
.575 .48125 Mdot
.675 .55 Mdot
.185 .43625 Mdot
.45125 .49125 Mdot
.805 .4625 Mdot
.1825 .66 Mdot
.7375 .62625 Mdot
.33375 .65625 Mdot
.48375 .57625 Mdot
.50375 .60875 Mdot
.87125 .67375 Mdot
.255 .6575 Mdot
.14 .73 Mdot
.78375 .66625 Mdot
.39625 .64375 Mdot
.815 .62875 Mdot
.59125 .5925 Mdot
.135 .41875 Mdot
.45875 .6275 Mdot
.185 .62625 Mdot
.58125 .4975 Mdot
.89 .57875 Mdot
.2925 .57875 Mdot
.675 .6375 Mdot
.7375 .625 Mdot
.37 .755 Mdot
.13375 .65875 Mdot
.3675 .685 Mdot
.9675 .6675 Mdot
.505 .6275 Mdot
.2375 .495 Mdot
.54875 .4475 Mdot
.6625 .44 Mdot
.7025 .5575 Mdot
.68125 .6075 Mdot
.56875 .69625 Mdot
.54875 .6125 Mdot
.95625 .51875 Mdot
.20625 .56 Mdot
.29125 .50875 Mdot
.68125 .42875 Mdot
.435 .44625 Mdot
.59125 .40125 Mdot
.37125 .365 Mdot
.69625 .44375 Mdot
.165 .49625 Mdot
.7575 .565 Mdot
.365 .57875 Mdot
.7875 .6125 Mdot
.40875 .6525 Mdot
.38125 .64125 Mdot
.585 .64125 Mdot
.3125 .5975 Mdot
.69625 .61375 Mdot
.48625 .60375 Mdot
.24 .60875 Mdot
.83 .60875 Mdot
.345 .7275 Mdot
.195 .685 Mdot
.65625 .64 Mdot
.74375 .5725 Mdot
.40125 .54 Mdot
.6275 .4525 Mdot
.42 .4275 Mdot
.405 .46625 Mdot
.57125 .52375 Mdot
.37875 .4775 Mdot
0 0 1 r
.3875 .41 Mdot
.4525 .37125 Mdot
.38875 .32375 Mdot
.58625 .3125 Mdot
.23875 .33375 Mdot
.565 .355 Mdot
.0725 .4375 Mdot
.43 .45 Mdot
.5275 .50125 Mdot
.4625 .53875 Mdot
.34125 .55625 Mdot
.3975 .57 Mdot
.99625 .58125 Mdot
.2375 .55 Mdot
.5475 .5275 Mdot
.50125 .5225 Mdot
.54 .53125 Mdot
.55875 .485 Mdot
.1075 .45625 Mdot
.18125 .4225 Mdot
.395 .37875 Mdot
.505 .365 Mdot
.51125 .40875 Mdot
.39 .39125 Mdot
.31 .375 Mdot
.19 .41125 Mdot
.46375 .375 Mdot
.46 .3875 Mdot
.44 .43375 Mdot
.5825 .425 Mdot
.09125 .405 Mdot
.4225 .3825 Mdot
.39875 .36 Mdot
.4675 .41625 Mdot
.50625 .46625 Mdot
.48125 .53375 Mdot
.3675 .54875 Mdot
.24125 .54125 Mdot
.43125 .52875 Mdot
.45875 .5125 Mdot
.53625 .49375 Mdot
.55125 .47375 Mdot
.49375 .475 Mdot
.44625 .465 Mdot
.08375 .48 Mdot
.26 .5 Mdot
.47 .5 Mdot
.45625 .505 Mdot
.51 .51125 Mdot
.205 .58125 Mdot
.485 .59 Mdot
.01375 .58625 Mdot
.45125 .5725 Mdot
.59125 .50875 Mdot
.52125 .49875 Mdot
.165 .4725 Mdot
.49125 .4625 Mdot
.06 .44375 Mdot
.5225 .445 Mdot
.51625 .46 Mdot
.50625 .46375 Mdot
.2025 .49 Mdot
.4925 .5225 Mdot
.97875 .5475 Mdot
.15 .57125 Mdot
.64875 .59875 Mdot
.56375 .58 Mdot
.48375 .52375 Mdot
.29875 .5025 Mdot
.8175 .49625 Mdot
.6825 .48 Mdot
.0975 .47125 Mdot
.5325 .5075 Mdot
.50375 .49875 Mdot
.5 .4975 Mdot
.045 .51375 Mdot
.385 .54125 Mdot
.32625 .53375 Mdot
.52 .55 Mdot
.4725 .5225 Mdot
.45 .5025 Mdot
.15875 .495 Mdot
.115 .475 Mdot
.4425 .49125 Mdot
.53 .47875 Mdot
.4425 .4575 Mdot
.08625 .47 Mdot
.56375 .48375 Mdot
.23375 .50125 Mdot
.53375 .47375 Mdot
.50375 .4325 Mdot
.33125 .39625 Mdot
.6225 .38875 Mdot
.74 .3725 Mdot
.28375 .3975 Mdot
.49375 .42625 Mdot
.50625 .43 Mdot
.49375 .46625 Mdot
0 .51375 Mdot
.37625 .57125 Mdot
.3475 .5825 Mdot
.5075 .535 Mdot
.495 .4825 Mdot
.245 .47125 Mdot
.70875 .4525 Mdot
.8025 .44875 Mdot
.25125 .45 Mdot
.4475 .435 Mdot
.56375 .40625 Mdot
.48875 .41125 Mdot
.175 .4575 Mdot
.485 .48 Mdot
.195 .4675 Mdot
.9975 .43375 Mdot
.81375 .07625 Mdot
.23 .0875 Mdot
.50125 .04625 Mdot
.355 .0575 Mdot
.53125 .05125 Mdot
.4075 .0075 Mdot
.62625 .07875 Mdot
.66 .115 Mdot
.08375 .13125 Mdot
.98375 .1175 Mdot
.3 .10375 Mdot
.42 .04625 Mdot
.43125 .09625 Mdot
.9375 .0975 Mdot
.2775 .01125 Mdot
.32375 .08 Mdot
.7575 .18125 Mdot
.18625 .2375 Mdot
.87125 .305 Mdot
.4725 .2875 Mdot
.40625 .2525 Mdot
.48875 .2425 Mdot
.48375 .305 Mdot
.47375 .25 Mdot
.42875 .19125 Mdot
.8725 .105 Mdot
.30875 .03625 Mdot
.725 .02 Mdot
.485 .0775 Mdot
.38625 .0925 Mdot
.20625 .11 Mdot
.29875 .13 Mdot
.53625 .095 Mdot
.45875 .12 Mdot
.45625 .1825 Mdot
.3225 .14125 Mdot
.445 .15 Mdot
.095 .16375 Mdot
.44625 .12 Mdot
.715 .2075 Mdot
.4175 .2425 Mdot
.24875 .2275 Mdot
.56875 .23125 Mdot
.96625 .22 Mdot
.1675 .19375 Mdot
.4575 .1675 Mdot
.52 .185 Mdot
.57 .21 Mdot
.3275 .125 Mdot
.44625 .12875 Mdot
.84625 .11375 Mdot
.19625 .06875 Mdot
.53125 .03 Mdot
.68125 .18375 Mdot
.52625 .2625 Mdot
.30875 .31625 Mdot
.7225 .39375 Mdot
.62375 .45875 Mdot
.21 .4175 Mdot
.52125 .34875 Mdot
.5025 .3675 Mdot
.495 .33125 Mdot
.1575 .3125 Mdot
.4375 .38375 Mdot
.3325 .4075 Mdot
.4725 .44625 Mdot
.6075 .485 Mdot
.425 .50375 Mdot
.23375 .49375 Mdot
.20125 .49375 Mdot
.44875 .475 Mdot
.54625 .44 Mdot
.42875 .40125 Mdot
.1875 .36875 Mdot
.9925 .3375 Mdot
.56875 .33 Mdot
.29 .34875 Mdot
.505 .37375 Mdot
.49625 .4 Mdot
.47 .45125 Mdot
.5075 .4725 Mdot
.69125 .4925 Mdot
.33125 .53 Mdot
.495 .53875 Mdot
.52125 .535 Mdot
.48625 .48875 Mdot
.09 .4625 Mdot
.41125 .4125 Mdot
.3725 .38625 Mdot
.49875 .41875 Mdot
.49875 .44375 Mdot
.27 .45125 Mdot
.745 .47375 Mdot
.65375 .47625 Mdot
.33375 .4875 Mdot
.46625 .49 Mdot
.56625 .47 Mdot
.5075 .44625 Mdot
.09875 .47 Mdot
.27875 .4575 Mdot
.4825 .36125 Mdot
.39625 .2475 Mdot
.75125 .105 Mdot
.28125 .965 Mdot
.9175 .9325 Mdot
.45 .9525 Mdot
.31625 .965 Mdot
.77875 .92625 Mdot
.3675 .86125 Mdot
.56875 .77 Mdot
.4675 .70125 Mdot
.405 .72625 Mdot
.445 .67125 Mdot
.465 .62625 Mdot
.9575 .59375 Mdot
.1625 .55625 Mdot
.42375 .47 Mdot
.8225 .45125 Mdot
.36375 .51875 Mdot
.33125 .5125 Mdot
.595 .49375 Mdot
.73 .5025 Mdot
.30375 .46875 Mdot
.41375 .3675 Mdot
.51125 .37875 Mdot
.5975 .4125 Mdot
.49 .49375 Mdot
.3825 .57 Mdot
.7125 .65125 Mdot
.29625 .72625 Mdot
.35875 .7725 Mdot
.805 .7075 Mdot
.58125 .63 Mdot
.30375 .495 Mdot
.615 .32875 Mdot
.6 .17625 Mdot
.30375 .13125 Mdot
.5075 .1025 Mdot
.50125 .16 Mdot
.50625 .205 Mdot
.25875 .15625 Mdot
.87625 .05625 Mdot
.39 .005 Mdot
.755 .04375 Mdot
.53125 .11375 Mdot
.38625 .1575 Mdot
.48875 .16625 Mdot
.555 .22125 Mdot
.50875 .1975 Mdot
.20375 .1175 Mdot
.88875 .0375 Mdot
.37625 .28875 Mdot
.47 .56 Mdot
.47625 .90875 Mdot
.4625 .03 Mdot
.0525 .00625 Mdot
.505 .055 Mdot
.20125 .04625 Mdot
.785 .02375 Mdot
.50125 .045 Mdot
.51 .09625 Mdot
.55375 .15625 Mdot
.45 .24125 Mdot
.495 .31625 Mdot
.4775 .35375 Mdot
.07875 .325 Mdot
.1425 .34 Mdot
.485 .29875 Mdot
.57375 .2875 Mdot
.47625 .3275 Mdot
.50625 .3125 Mdot
.4725 .26375 Mdot
.4775 .2625 Mdot
.48 .26375 Mdot
.545 .3375 Mdot
.4825 .5025 Mdot
.55875 .65875 Mdot
.45625 .77 Mdot
.1675 .89 Mdot
.42875 .8275 Mdot
.3475 .82 Mdot
.4175 .88625 Mdot
.5725 .90625 Mdot
.42625 .97125 Mdot
.415 .995 Mdot
.4275 .93875 Mdot
.5175 .82125 Mdot
.53875 .81 Mdot
.50125 .90875 Mdot
.46625 .9675 Mdot
.455 .74375 Mdot
.5375 .4575 Mdot
.4625 .18125 Mdot
.5225 .4325 Mdot
.47375 .43375 Mdot
.10125 .55 Mdot
.515 .52625 Mdot
.62125 .515 Mdot
.425 .47 Mdot
.485 .39875 Mdot
.4825 .35875 Mdot
.5175 .34625 Mdot
.46625 .3375 Mdot
.51125 .32625 Mdot
.51375 .3175 Mdot
.50125 .34375 Mdot
.48875 .37375 Mdot
.13375 .38375 Mdot
.8325 .41 Mdot
.92 .445 Mdot
.11 .4275 Mdot
.5325 .4175 Mdot
.47 .40625 Mdot
.46375 .38375 Mdot
.5175 .35875 Mdot
.5225 .31875 Mdot
.5125 .285 Mdot
.47 .2525 Mdot
.53875 .24 Mdot
.48625 .21375 Mdot
.515 .23375 Mdot
.455 .31375 Mdot
.07 .4925 Mdot
.4325 .52625 Mdot
.6 .4575 Mdot
.4775 .40375 Mdot
.51125 .38 Mdot
.46875 .3675 Mdot
.47125 .36 Mdot
.4975 .3725 Mdot
.47625 .365 Mdot
.52375 .295 Mdot
.58 .27 Mdot
.4525 .2375 Mdot
.04375 .16125 Mdot
.415 .165 Mdot
.3025 .1175 Mdot
.48 .08375 Mdot
.49625 .105 Mdot
.41125 .0725 Mdot
.595 .05875 Mdot
.48875 .0475 Mdot
.41375 .09375 Mdot
.5675 .12375 Mdot
.5075 .19875 Mdot
.53375 .24375 Mdot
.375 .21375 Mdot
.36625 .16125 Mdot
.23875 .06375 Mdot
.5275 .03375 Mdot
.43125 .10125 Mdot
.50125 .1275 Mdot
.13 .14625 Mdot
.2275 .2725 Mdot
.43625 .3625 Mdot
.46125 .47125 Mdot
.46375 .545 Mdot
.57 .505 Mdot
.28875 .415 Mdot
.45625 .4325 Mdot
.7175 .4475 Mdot
.89125 .4975 Mdot
.19625 .59625 Mdot
.41625 .73625 Mdot
.3025 .72375 Mdot
.66875 .7725 Mdot
.765 .83625 Mdot
.28125 .9475 Mdot
.42125 .9575 Mdot
.54875 .87625 Mdot
.53375 .7025 Mdot
.45875 .63375 Mdot
.65375 .58 Mdot
.34875 .505 Mdot
.51375 .55 Mdot
.485 .54625 Mdot
.06875 .54 Mdot
.115 .50375 Mdot
.5525 .505 Mdot
.58875 .51875 Mdot
.4275 .53625 Mdot
.4425 .57375 Mdot
.6075 .58125 Mdot
.475 .58625 Mdot
.465 .5675 Mdot
.5125 .54625 Mdot
.50375 .525 Mdot
.50875 .505 Mdot
.48625 .48625 Mdot
.17 .4975 Mdot
.765 .4925 Mdot
.89 .49125 Mdot
.175 .5025 Mdot
.5 .50125 Mdot
.46375 .49875 Mdot
.46375 .505 Mdot
.58625 .5075 Mdot
.52 .5125 Mdot
.4725 .51625 Mdot
.4775 .51125 Mdot
.5225 .49125 Mdot
.5025 .48 Mdot
.50125 .4825 Mdot
.46875 .4375 Mdot
.0425 .4175 Mdot
.07625 .37875 Mdot
.47 .3425 Mdot
.58625 .38 Mdot
.455 .39125 Mdot
.57875 .3925 Mdot
.47625 .425 Mdot
.425 .46375 Mdot
.49625 .49125 Mdot
.49125 .5 Mdot
.51875 .5025 Mdot
.61 .52625 Mdot
.43375 .51 Mdot
.045 .505 Mdot
.425 .4975 Mdot
.295 .4875 Mdot
.4975 .51125 Mdot
.51375 .5075 Mdot
.43125 .52625 Mdot
.55 .60875 Mdot
.52125 .65375 Mdot
.4175 .66375 Mdot
.5675 .6675 Mdot
.4975 .62625 Mdot
.54875 .53625 Mdot
.35375 .48875 Mdot
.37 .4525 Mdot
.24875 .43875 Mdot
.44625 .45625 Mdot
.66875 .46125 Mdot
.32375 .46125 Mdot
.53125 .475 Mdot
.325 .53625 Mdot
.52 .54625 Mdot
.69125 .5325 Mdot
.735 .53375 Mdot
.24875 .5375 Mdot
.45375 .48375 Mdot
.53125 .47875 Mdot
.67875 .50625 Mdot
.20125 .5125 Mdot
.45375 .52875 Mdot
.53 .54875 Mdot
.51875 .56 Mdot
.51875 .555 Mdot
.48 .56 Mdot
.505 .545 Mdot
.4925 .53 Mdot
.48125 .48875 Mdot
.51875 .465 Mdot
.46375 .44875 Mdot
.13125 .4275 Mdot
.355 .415 Mdot
.35125 .405 Mdot
.4725 .37 Mdot
.53875 .35 Mdot
.5275 .345 Mdot
.50125 .33125 Mdot
.44625 .33 Mdot
.44125 .33625 Mdot
.56875 .345 Mdot
.54875 .315 Mdot
.4575 .3125 Mdot
.48875 .2625 Mdot
.1675 .155 Mdot
.34 .115 Mdot
.455 .0975 Mdot
.51625 .0625 Mdot
.55625 .04 Mdot
.2525 .07 Mdot
.5575 .05 Mdot
.68125 .05375 Mdot
.8575 .07125 Mdot
.24125 .1175 Mdot
.3975 .06625 Mdot
.24625 .06875 Mdot
.795 .06125 Mdot
.7225 .04875 Mdot
.5375 .125 Mdot
.45 .2475 Mdot
.52375 .34125 Mdot
.48875 .43875 Mdot
.51625 .40875 Mdot
.485 .35875 Mdot
.18375 .33125 Mdot
.19875 .325 Mdot
.55 .3 Mdot
.54125 .335 Mdot
.45 .34625 Mdot
.34125 .3425 Mdot
.82125 .37375 Mdot
.38375 .3725 Mdot
.465 .39875 Mdot
.5125 .4075 Mdot
.5075 .41375 Mdot
.50875 .4425 Mdot
.47625 .45875 Mdot
.265 .41875 Mdot
.6825 .39625 Mdot
.79875 .395 Mdot
.26125 .3675 Mdot
.485 .3475 Mdot
.4625 .36375 Mdot
.4 .365 Mdot
.7475 .36625 Mdot
.44875 .355 Mdot
.45375 .365 Mdot
.4775 .37375 Mdot
.53375 .39875 Mdot
.4875 .40125 Mdot
.515 .4425 Mdot
.47 .46 Mdot
.1475 .47875 Mdot
.10375 .52625 Mdot
.4825 .50625 Mdot
.57 .5025 Mdot
.35625 .49625 Mdot
.7625 .49375 Mdot
.405 .46875 Mdot
.4225 .4575 Mdot
.5125 .4475 Mdot
.48875 .43125 Mdot
.50625 .445 Mdot
.605 .43875 Mdot
.42375 .445 Mdot
.16625 .46875 Mdot
.42625 .43875 Mdot
.3575 .44625 Mdot
.49375 .4375 Mdot
.42625 .44125 Mdot
.5925 .4775 Mdot
.50875 .45875 Mdot
.47375 .4575 Mdot
.46 .43875 Mdot
.53625 .3975 Mdot
.55125 .3625 Mdot
.49125 .40375 Mdot
.37125 .40375 Mdot
.39625 .4475 Mdot
.915 .48375 Mdot
.3375 .5075 Mdot
.455 .515 Mdot
.5725 .52375 Mdot
.32875 .5375 Mdot
.6475 .5425 Mdot
.33875 .505 Mdot
.515 .50125 Mdot
.615 .50875 Mdot
.70125 .50125 Mdot
.31 .49375 Mdot
.45625 .53875 Mdot
.525 .55 Mdot
.10625 .55375 Mdot
.9875 .5525 Mdot
.6325 .5525 Mdot
.235 .54 Mdot
.4525 .51 Mdot
.51125 .4825 Mdot
.60125 .46375 Mdot
.49375 .46375 Mdot
.455 .45375 Mdot
.5175 .465 Mdot
.495 .47 Mdot
.49 .47875 Mdot
.51375 .51125 Mdot
.48875 .53625 Mdot
.18875 .54 Mdot
.39125 .54 Mdot
.385 .4975 Mdot
.43375 .47 Mdot
.6075 .465 Mdot
.54375 .46375 Mdot
.465 .46 Mdot
.45125 .43875 Mdot
.435 .4325 Mdot
.57625 .4225 Mdot
.545 .4125 Mdot
.455 .445 Mdot
.50125 .485 Mdot
.01875 .49875 Mdot
.24375 .485 Mdot
.3225 .43875 Mdot
.4175 .40875 Mdot
.5975 .42375 Mdot
.5125 .46125 Mdot
.24625 .55 Mdot
.58125 .57375 Mdot
.66125 .57875 Mdot
.84 .5475 Mdot
.25875 .48625 Mdot
.4 .43875 Mdot
.25375 .4375 Mdot
.80375 .445 Mdot
.63375 .465 Mdot
.3025 .495 Mdot
.46625 .48375 Mdot
.585 .4875 Mdot
.4875 .4975 Mdot
.5025 .4825 Mdot
.4575 .47375 Mdot
.50375 .4725 Mdot
.525 .455 Mdot
.4675 .4425 Mdot
.56375 .43125 Mdot
.43375 .40625 Mdot
.51625 .5675 Mdot
.475 .635 Mdot
.31375 .67375 Mdot
.8625 .675 Mdot
.31375 .67 Mdot
.53125 .57875 Mdot
.52 .43375 Mdot
.47 .3875 Mdot
.2275 .35125 Mdot
.27125 .34125 Mdot
.4675 .39875 Mdot
.505 .40125 Mdot
.5025 .40625 Mdot
.51125 .4425 Mdot
.5 .46125 Mdot
.3475 .51375 Mdot
.59625 .56625 Mdot
.71625 .57 Mdot
.3325 .4775 Mdot
.48 .38625 Mdot
.4675 .3075 Mdot
.31125 .28625 Mdot
.93625 .3 Mdot
.3575 .36875 Mdot
.4475 .42875 Mdot
.4725 .48375 Mdot
.53625 .45 Mdot
.48375 .4475 Mdot
.5125 .49625 Mdot
.48 .42625 Mdot
.2775 .3325 Mdot
.9925 .28 Mdot
.22125 .19625 Mdot
.47875 .04125 Mdot
.5425 .03625 Mdot
.2775 .09375 Mdot
.915 .1525 Mdot
.35125 .21625 Mdot
.40875 .30625 Mdot
.52125 .37375 Mdot
.51125 .40125 Mdot
.4975 .38875 Mdot
.56125 .495 Mdot
.45 .52625 Mdot
.29 .47875 Mdot
.85 .43125 Mdot
.45875 .40625 Mdot
.385 .21875 Mdot
.5 .07125 Mdot
.47375 .05125 Mdot
.38625 .125 Mdot
.4475 .1575 Mdot
.795 .17375 Mdot
.395 .1575 Mdot
.46 .06875 Mdot
.535 .02 Mdot
.745 .005 Mdot
.31875 .0375 Mdot
.52375 .035 Mdot
.5725 .0675 Mdot
.615 .09125 Mdot
.38875 .085 Mdot
.46875 .1075 Mdot
.50875 .1375 Mdot
.22875 .1475 Mdot
.84375 .17375 Mdot
.6025 .185 Mdot
.28625 .14125 Mdot
.45625 .15375 Mdot
.46375 .19625 Mdot
.71125 .2225 Mdot
.43875 .24875 Mdot
.45 .285 Mdot
.5125 .2675 Mdot
.50125 .24625 Mdot
.4925 .25125 Mdot
.5125 .23 Mdot
.49 .215 Mdot
.2775 .25875 Mdot
.88625 .27875 Mdot
.40625 .27125 Mdot
.415 .31625 Mdot
.33625 .355 Mdot
.76375 .37125 Mdot
.545 .385 Mdot
.40875 .43875 Mdot
.4675 .455 Mdot
.4325 .45 Mdot
.56125 .45375 Mdot
.53625 .47 Mdot
.47375 .46375 Mdot
.49625 .45875 Mdot
.10375 .45 Mdot
.33375 .395 Mdot
.325 .35875 Mdot
.32125 .3425 Mdot
.79875 .39125 Mdot
.40625 .485 Mdot
.2775 .5675 Mdot
.59125 .56875 Mdot
.665 .56125 Mdot
.71375 .52125 Mdot
.33 .4975 Mdot
.425 .455 Mdot
.29875 .4725 Mdot
.7275 .50375 Mdot
.605 .5175 Mdot
.36375 .47875 Mdot
.4375 .47875 Mdot
.52875 .485 Mdot
.63125 .48 Mdot
.44375 .48375 Mdot
.45125 .495 Mdot
.50625 .48375 Mdot
.4925 .48375 Mdot
.48875 .46625 Mdot
.6125 .4625 Mdot
.3875 .4825 Mdot
.50875 .7375 Mdot
.475 .72625 Mdot
.43875 .735 Mdot
.6375 .7525 Mdot
.4375 .7675 Mdot
.5225 .91875 Mdot
.475 .98875 Mdot
.51 .97125 Mdot
.49 .92 Mdot
.50875 .93625 Mdot
.46125 .9325 Mdot
.48875 .9075 Mdot
.63 .91875 Mdot
.535 .91625 Mdot
.51625 .8775 Mdot
.52125 .88375 Mdot
.5025 .79375 Mdot
.49125 .7875 Mdot
.37625 .8475 Mdot
.68875 .96125 Mdot
.44625 .9975 Mdot
.405 .925 Mdot
.85125 .8625 Mdot
.37375 .785 Mdot
.45 .7375 Mdot
.5075 .73125 Mdot
.495 .75125 Mdot
.51 .74375 Mdot
.5 .83625 Mdot
.50125 .85875 Mdot
.3625 .75625 Mdot
.72125 .68 Mdot
.44125 .6325 Mdot
.45125 .4725 Mdot
.23625 .415 Mdot
.9075 .39375 Mdot
.56625 .3525 Mdot
.345 .28375 Mdot
.47 .285 Mdot
.445 .27 Mdot
.5325 .245 Mdot
.53875 .22 Mdot
.4875 .36625 Mdot
.4925 .38375 Mdot
.24125 .3825 Mdot
.96375 .42 Mdot
.41 .4775 Mdot
.3575 .42625 Mdot
.21625 .48 Mdot
.99375 .5525 Mdot
.3475 .57875 Mdot
.315 .53 Mdot
.57875 .525 Mdot
.64375 .48375 Mdot
.55875 .41125 Mdot
.42375 .365 Mdot
.45375 .33625 Mdot
.36125 .19375 Mdot
.66125 .0575 Mdot
.4775 .02875 Mdot
.515 .2325 Mdot
.6175 .43125 Mdot
.3725 .63875 Mdot
.525 .21875 Mdot
.48875 .19625 Mdot
.4925 .1675 Mdot
.48125 .1525 Mdot
.51375 .16125 Mdot
.52375 .13875 Mdot
.5 .17875 Mdot
.48375 .19625 Mdot
.01625 .2025 Mdot
.15125 .24625 Mdot
.52625 .20375 Mdot
.465 .16875 Mdot
.47625 .16 Mdot
.49625 .1375 Mdot
.50875 .0875 Mdot
.54625 .07875 Mdot
.43875 .10125 Mdot
.55 .09875 Mdot
.47375 .0825 Mdot
.45375 .14 Mdot
.48625 .1275 Mdot
.18875 .12 Mdot
.22 .13125 Mdot
.44 .085 Mdot
.4875 .08875 Mdot
.53125 .06875 Mdot
.48625 .02125 Mdot
.125 .0475 Mdot
.20125 .17375 Mdot
.41 .14125 Mdot
.525 .19875 Mdot
.525 .20625 Mdot
.5175 .20375 Mdot
.4725 .20625 Mdot
.52875 .2 Mdot
.49 .1775 Mdot
.50875 .1275 Mdot
.50125 .07125 Mdot
.45875 .12875 Mdot
.50125 .11 Mdot
.19 .045 Mdot
.93625 .01375 Mdot
.53375 .02625 Mdot
.46 .10875 Mdot
.46625 .24375 Mdot
.40625 .295 Mdot
.855 .34375 Mdot
.30375 .36875 Mdot
.5175 .325 Mdot
.47875 .3425 Mdot
.51125 .415 Mdot
.505 .485 Mdot
.495 .475 Mdot
.49375 .4075 Mdot
.43375 .36875 Mdot
.57 .35625 Mdot
.5625 .3725 Mdot
.38875 .50125 Mdot
.445 .63125 Mdot
.35 .715 Mdot
.97125 .79875 Mdot
.3075 .86625 Mdot
.45375 .8975 Mdot
.50625 .91 Mdot
.49125 .91 Mdot
.50125 .89375 Mdot
.51875 .77125 Mdot
.495 .7425 Mdot
.43125 .82125 Mdot
.59625 .90125 Mdot
.46875 .9375 Mdot
.34875 .99625 Mdot
.64125 .84125 Mdot
.33625 .51875 Mdot
.51125 .51625 Mdot
.49625 .52625 Mdot
.49875 .52625 Mdot
.5025 .525 Mdot
.51 .52 Mdot
.51625 .52125 Mdot
.51625 .53125 Mdot
.48 .49125 Mdot
.055 .44875 Mdot
.23 .43 Mdot
.48875 .44 Mdot
.4775 .525 Mdot
.48875 .58125 Mdot
.50375 .61375 Mdot
.49625 .62 Mdot
.52625 .595 Mdot
.4975 .545 Mdot
.49625 .53375 Mdot
.4875 .52125 Mdot
.47 .54125 Mdot
.50375 .55375 Mdot
.165 .555 Mdot
.195 .55125 Mdot
.45625 .5275 Mdot
.49875 .5275 Mdot
.5025 .53625 Mdot
.5025 .56875 Mdot
.485 .58625 Mdot
.5375 .58625 Mdot
.4575 .5775 Mdot
.565 .57125 Mdot
.48875 .52875 Mdot
.49125 .49 Mdot
.455 .50375 Mdot
.1625 .50125 Mdot
.16625 .5175 Mdot
.4525 .5375 Mdot
.5075 .52375 Mdot
.5375 .53 Mdot
.51625 .53125 Mdot
.4625 .5025 Mdot
.54625 .49 Mdot
.495 .48375 Mdot
.5 .47625 Mdot
.50875 .4825 Mdot
.47625 .46875 Mdot
.475 .46875 Mdot
.1225 .4575 Mdot
.5125 .4225 Mdot
.32875 .44375 Mdot
.52125 .46 Mdot
.5 .47125 Mdot
.55125 .47875 Mdot
.43875 .4975 Mdot
.52 .51125 Mdot
.495 .51125 Mdot
.495 .51125 Mdot
.48625 .49125 Mdot
.47625 .4525 Mdot
.46125 .39 Mdot
.3975 .33625 Mdot
.94875 .27875 Mdot
.26125 .2575 Mdot
.48625 .245 Mdot
.46 .24125 Mdot
.48875 .23 Mdot
.52125 .2425 Mdot
.53875 .2375 Mdot
.495 .25375 Mdot
.47125 .2825 Mdot
.52375 .30375 Mdot
.50875 .28375 Mdot
.43125 .255 Mdot
.415 .20875 Mdot
.38 .16875 Mdot
.20375 .11 Mdot
.54125 .1125 Mdot
.45375 .1225 Mdot
.4975 .125 Mdot
.53125 .1425 Mdot
.4875 .16625 Mdot
.47625 .155 Mdot
.52 .11625 Mdot
.47125 .08125 Mdot
.51 .09875 Mdot
.495 .05875 Mdot
.08625 .03625 Mdot
.53375 .0425 Mdot
.52125 .02 Mdot
.025 .00375 Mdot
.23 .0225 Mdot
.4625 .0575 Mdot
.56375 .20125 Mdot
.55875 .32 Mdot
.39 .42875 Mdot
.49 .56 Mdot
.4425 .54125 Mdot
.5825 .535 Mdot
.55875 .51875 Mdot
.44625 .48875 Mdot
.52 .46125 Mdot
.515 .43875 Mdot
.46875 .45625 Mdot
.1775 .51875 Mdot
.30625 .59625 Mdot
.4975 .63625 Mdot
.46625 .62125 Mdot
.49875 .57625 Mdot
.49625 .54 Mdot
.48375 .51375 Mdot
.4625 .5175 Mdot
.70125 .53875 Mdot
.38 .54375 Mdot
.49 .55 Mdot
.47125 .51875 Mdot
.5125 .46625 Mdot
.22375 .44375 Mdot
.255 .43625 Mdot
.47375 .4725 Mdot
.5 .515 Mdot
.5025 .52 Mdot
.5175 .52 Mdot
.46625 .52625 Mdot
.46375 .535 Mdot
.6525 .54 Mdot
.47 .5375 Mdot
.4725 .54 Mdot
.48125 .53375 Mdot
.475 .51125 Mdot
.265 .51125 Mdot
.99625 .5425 Mdot
.2525 .56125 Mdot
.45625 .59375 Mdot
.505 .59125 Mdot
.535 .5725 Mdot
.515 .54125 Mdot
.445 .54125 Mdot
.50125 .53125 Mdot
.62125 .5575 Mdot
.44625 .5775 Mdot
.5025 .585 Mdot
.47375 .54875 Mdot
.4775 .52875 Mdot
.20625 .515 Mdot
.9 .51375 Mdot
.52 .51375 Mdot
.3775 .5175 Mdot
.53875 .50875 Mdot
.4875 .4975 Mdot
.54375 .48125 Mdot
.43125 .4725 Mdot
.4625 .46625 Mdot
.59375 .4675 Mdot
.48375 .46875 Mdot
.46625 .4525 Mdot
.48625 .43625 Mdot
.47375 .445 Mdot
.465 .44625 Mdot
.815 .45375 Mdot
.2825 .475 Mdot
.4975 .49875 Mdot
.46625 .52 Mdot
.50125 .5225 Mdot
.5075 .5025 Mdot
.51625 .50375 Mdot
.50625 .49 Mdot
.51375 .45875 Mdot
.4875 .44125 Mdot
.52625 .45625 Mdot
.43875 .48875 Mdot
.43 .49625 Mdot
.39 .50625 Mdot
.935 .52 Mdot
.2825 .52875 Mdot
.52875 .50375 Mdot
.4525 .485 Mdot
.49 .47875 Mdot
.51625 .46875 Mdot
.5275 .45875 Mdot
.46125 .465 Mdot
.49875 .4875 Mdot
.51 .4925 Mdot
.4875 .5075 Mdot
.49875 .54625 Mdot
.14 .5325 Mdot
.49 .5275 Mdot
.28875 .525 Mdot
.505 .4875 Mdot
.46125 .48375 Mdot
.4975 .48875 Mdot
.5025 .49 Mdot
.53875 .47625 Mdot
.4925 .48 Mdot
.50875 .49 Mdot
.50375 .48875 Mdot
.50125 .475 Mdot
.43 .505 Mdot
.085 .50625 Mdot
.24875 .5075 Mdot
.35625 .51625 Mdot
.52625 .49875 Mdot
.53125 .49875 Mdot
.49875 .50375 Mdot
.47875 .50625 Mdot
.5 .50625 Mdot
.48625 .50125 Mdot
.4775 .49625 Mdot
.55125 .495 Mdot
.49125 .515 Mdot
.315 .5025 Mdot
.46625 .505 Mdot
.24125 .50375 Mdot
.4725 .46875 Mdot
.44625 .46 Mdot
.48125 .47375 Mdot
.585 .47375 Mdot
.47625 .48625 Mdot
.4525 .52 Mdot
.5175 .03875 Mdot
.45125 .07 Mdot
.42375 .085 Mdot
.7725 .06625 Mdot
.3925 .03125 Mdot
.48875 .0125 Mdot
.4675 .0775 Mdot
.4825 .1325 Mdot
.26375 .18 Mdot
.81375 .225 Mdot
.50875 .28125 Mdot
.41625 .27125 Mdot
.5325 .24875 Mdot
.4975 .2475 Mdot
.5325 .24625 Mdot
.43375 .22875 Mdot
.35875 .2275 Mdot
.79125 .2275 Mdot
.3925 .21875 Mdot
.46125 .2775 Mdot
.49 .2775 Mdot
.49125 .265 Mdot
.49125 .27375 Mdot
.715 .2725 Mdot
.3325 .19125 Mdot
.5025 .15125 Mdot
.47625 .1025 Mdot
.49 .06875 Mdot
.505 .06375 Mdot
.48125 .0775 Mdot
.47375 .1275 Mdot
.69625 .1925 Mdot
.34875 .24125 Mdot
.585 .215 Mdot
.42875 .21625 Mdot
.425 .22125 Mdot
.4325 .2125 Mdot
.82 .23625 Mdot
.34 .29125 Mdot
.5325 .31375 Mdot
.45 .34375 Mdot
.39625 .38625 Mdot
.5925 .39625 Mdot
.64375 .4125 Mdot
.37 .42 Mdot
.49375 .4275 Mdot
.505 .43125 Mdot
.4825 .435 Mdot
.51 .42875 Mdot
.24625 .45375 Mdot
.95 .46125 Mdot
.47625 .47 Mdot
.355 .47625 Mdot
.4975 .5025 Mdot
.4575 .5025 Mdot
.4125 .49625 Mdot
.62125 .49375 Mdot
.55875 .50625 Mdot
.445 .50125 Mdot
.5025 .495 Mdot
.5225 .4975 Mdot
.49625 .5025 Mdot
.42625 .5125 Mdot
.18375 .5225 Mdot
.335 .55375 Mdot
.3575 .5575 Mdot
.54125 .53875 Mdot
.51375 .5375 Mdot
.43125 .5325 Mdot
.6075 .52125 Mdot
.475 .50125 Mdot
.46125 .4975 Mdot
.5 .5025 Mdot
.53125 .495 Mdot
.4725 .47125 Mdot
.35875 .47625 Mdot
.515 .45 Mdot
.89 .43375 Mdot
.27625 .42125 Mdot
.5075 .4475 Mdot
.45875 .46125 Mdot
.4825 .39 Mdot
.53 .28875 Mdot
.58375 .1675 Mdot
.72375 .99875 Mdot
.495 .94 Mdot
.45 .86875 Mdot
.52625 .8775 Mdot
.49375 .87875 Mdot
.53125 .805 Mdot
.4475 .785 Mdot
.23875 .76 Mdot
.27875 .68125 Mdot
.47625 .71375 Mdot
.4925 .7975 Mdot
.50625 .8 Mdot
.505 .7875 Mdot
.63375 .7575 Mdot
.37625 .76125 Mdot
.50375 .72 Mdot
.48 .75625 Mdot
.4925 .755 Mdot
.50625 .7 Mdot
.445 .65625 Mdot
.45375 .55625 Mdot
.835 .4475 Mdot
.23 .38375 Mdot
.62875 .47125 Mdot
.45 .48125 Mdot
.41 .43125 Mdot
.48875 .44625 Mdot
.6725 .37625 Mdot
.42 .225 Mdot
.5275 .11875 Mdot
.44625 .085 Mdot
.29875 .01 Mdot
.6825 .04 Mdot
.75625 .07 Mdot
.265 .1175 Mdot
.5075 .13375 Mdot
.5025 .1475 Mdot
.4725 .23625 Mdot
.51375 .24375 Mdot
.3525 .17125 Mdot
.79375 .12375 Mdot
.46 .055 Mdot
.41375 .045 Mdot
.42625 .07625 Mdot
.5075 .0875 Mdot
.515 .1225 Mdot
.47625 .12375 Mdot
.39625 .085 Mdot
.54 .0975 Mdot
.745 .10875 Mdot
.355 .10625 Mdot
.52 .1 Mdot
.45125 .1125 Mdot
.48875 .375 Mdot
.46875 .67625 Mdot
.44625 .01125 Mdot
.4625 .02625 Mdot
.495 .05 Mdot
.53 .06625 Mdot
.51375 .13125 Mdot
.495 .085 Mdot
.1025 .04375 Mdot
.54 .0425 Mdot
.425 .095 Mdot
.49125 .1675 Mdot
.485 .21 Mdot
.52125 .27625 Mdot
.48625 .3875 Mdot
.49125 .475 Mdot
.2475 .5675 Mdot
.21875 .72625 Mdot
.46875 .73125 Mdot
.48625 .71375 Mdot
.48625 .7325 Mdot
.4275 .76375 Mdot
.59625 .7975 Mdot
.505 .8325 Mdot
.4725 .92125 Mdot
.51125 .92625 Mdot
.495 .92 Mdot
.52375 .95625 Mdot
.54625 .99125 Mdot
.54125 .9775 Mdot
.45125 .97625 Mdot
.495 .7975 Mdot
.405 .575 Mdot
.77 .3275 Mdot
.33 .13 Mdot
.45 .49625 Mdot
.23625 .4925 Mdot
.9425 .48375 Mdot
.63 .4675 Mdot
.2475 .4725 Mdot
.535 .47625 Mdot
.49375 .45875 Mdot
.44875 .455 Mdot
.52375 .435 Mdot
.50875 .41625 Mdot
.49625 .42875 Mdot
.48625 .44125 Mdot
.4825 .45 Mdot
.4675 .4275 Mdot
.5925 .43625 Mdot
.41875 .4475 Mdot
.17125 .46375 Mdot
.5075 .53125 Mdot
.42875 .5125 Mdot
.52875 .48875 Mdot
.515 .48875 Mdot
.50125 .4675 Mdot
.50375 .48875 Mdot
.4775 .5125 Mdot
.46625 .52125 Mdot
.58 .5025 Mdot
.47625 .4925 Mdot
.52125 .45125 Mdot
.0225 .43 Mdot
.09125 .445 Mdot
.39625 .435 Mdot
.50125 .44625 Mdot
.525 .43875 Mdot
.5375 .415 Mdot
.4775 .41125 Mdot
.4475 .4275 Mdot
.48 .42875 Mdot
.54 .41625 Mdot
.47625 .39125 Mdot
.51125 .37 Mdot
.48 .33625 Mdot
.16875 .275 Mdot
.12375 .18875 Mdot
.465 .1425 Mdot
.48625 .1025 Mdot
.455 .08 Mdot
.5375 .05625 Mdot
.49625 .03 Mdot
.53375 .02125 Mdot
.43625 .00875 Mdot
.5125 .01375 Mdot
.56 .02125 Mdot
.48375 .0575 Mdot
.43875 .03125 Mdot
.09875 .02 Mdot
.075 .0075 Mdot
.52375 .01625 Mdot
.47375 .0225 Mdot
.48875 .025 Mdot
.35 .0275 Mdot
.415 .05 Mdot
.0825 0 Mdot
.57125 .00125 Mdot
.53625 .0025 Mdot
.455 .1475 Mdot
.535 .29875 Mdot
.45 .43 Mdot
.09375 .5175 Mdot
.20375 .69375 Mdot
.38875 .72 Mdot
.51 .7625 Mdot
.46875 .795 Mdot
.495 .755 Mdot
.46875 .7325 Mdot
.55625 .7575 Mdot
.56375 .75375 Mdot
.4525 .73875 Mdot
.52 .75625 Mdot
.46875 .81125 Mdot
.45875 .74125 Mdot
.37125 .66875 Mdot
.93125 .63375 Mdot
.22625 .6025 Mdot
.46125 .46 Mdot
.3125 .4625 Mdot
.85875 .45875 Mdot
.5625 .4675 Mdot
.31875 .47875 Mdot
.53375 .4825 Mdot
.5 .47625 Mdot
.3925 .47375 Mdot
.595 .48 Mdot
.49875 .48625 Mdot
.4975 .4925 Mdot
.4875 .50125 Mdot
.49 .49625 Mdot
.455 .51375 Mdot
.58 .5225 Mdot
.4575 .53 Mdot
.24125 .5225 Mdot
.125 .5325 Mdot
.51125 .5375 Mdot
.42 .535 Mdot
.48875 .5475 Mdot
.545 .54 Mdot
.565 .53 Mdot
.475 .50375 Mdot
.465 .4825 Mdot
.475 .46625 Mdot
.56 .4675 Mdot
.47625 .46125 Mdot
.53375 .4625 Mdot
.08375 .48625 Mdot
.1975 .49375 Mdot
.38875 .52125 Mdot
.5 .5325 Mdot
.52125 .52 Mdot
.4925 .52125 Mdot
.57875 .505 Mdot
.4075 .46875 Mdot
.48625 .46375 Mdot
.5375 .4825 Mdot
.47125 .49625 Mdot
.52375 .4975 Mdot
.48 .4975 Mdot
.23125 .50375 Mdot
.20125 .48125 Mdot
.4675 .48625 Mdot
.48125 .48875 Mdot
.42875 .48 Mdot
.5425 .47625 Mdot
.57 .48375 Mdot
.4975 .48125 Mdot
.41875 .47875 Mdot
.51125 .4775 Mdot
.5575 .4475 Mdot
.47875 .44625 Mdot
.47625 .4475 Mdot
.1375 .46 Mdot
.07125 .47625 Mdot
.49375 .49 Mdot
.60875 .50125 Mdot
.47 .50625 Mdot
.51875 .53375 Mdot
.5 .55 Mdot
.43625 .54625 Mdot
.55375 .5475 Mdot
.46125 .545 Mdot
.4825 .52125 Mdot
.535 .46375 Mdot
.36125 .4425 Mdot
.35875 .4475 Mdot
.11375 .44875 Mdot
.615 .48875 Mdot
.4625 .49125 Mdot
.4525 .4775 Mdot
.50375 .4525 Mdot
.49625 .45875 Mdot
.51625 .4575 Mdot
.49125 .485 Mdot
.48375 .4725 Mdot
.10875 .47375 Mdot
.86 .4975 Mdot
.94125 .51 Mdot
.08875 .49 Mdot
.53 .49875 Mdot
.48125 .50125 Mdot
.505 .48875 Mdot
.49375 .4975 Mdot
.52125 .49125 Mdot
.48875 .4975 Mdot
.50875 .50375 Mdot
.50125 .51 Mdot
.4725 .455 Mdot
.49125 .43625 Mdot
.11375 .4175 Mdot
.62 .385 Mdot
.28375 .42 Mdot
.4525 .44375 Mdot
.61375 .46125 Mdot
.4775 .45 Mdot
.4575 .4575 Mdot
.48625 .43375 Mdot
.45625 .39 Mdot
.55875 .35 Mdot
.45 .3225 Mdot
.55375 .3125 Mdot
.4275 .3 Mdot
.025 .28 Mdot
.18 .21375 Mdot
.34125 .1625 Mdot
.5 .11125 Mdot
.49125 .075 Mdot
.4825 .0525 Mdot
.4925 .04375 Mdot
.56625 .02125 Mdot
.49375 .02625 Mdot
.5 .04625 Mdot
.4975 .06625 Mdot
.49625 .0825 Mdot
.3825 .18375 Mdot
.37875 .27625 Mdot
.98625 .34625 Mdot
.2125 .40125 Mdot
.47875 .2625 Mdot
.36625 .23875 Mdot
.7675 .245 Mdot
.54125 .26875 Mdot
.355 .2375 Mdot
.535 .235 Mdot
.505 .25125 Mdot
.30125 .265 Mdot
.7325 .25875 Mdot
.49375 .24625 Mdot
.44 .2125 Mdot
.53125 .2125 Mdot
.4825 .1825 Mdot
.44875 .1575 Mdot
.56125 .185 Mdot
.45875 .1925 Mdot
.35625 .18375 Mdot
.95 .1975 Mdot
.22625 .205 Mdot
.50875 .1475 Mdot
.44375 .13125 Mdot
.385 .10625 Mdot
.61375 .0825 Mdot
.67 .07625 Mdot
.38875 .08375 Mdot
.47 .08375 Mdot
.5 .08125 Mdot
.52625 .0625 Mdot
.47875 .11125 Mdot
.5275 .09625 Mdot
.18375 .07625 Mdot
.315 .14875 Mdot
.39375 .11375 Mdot
.495 .18875 Mdot
.49 .2475 Mdot
.41875 .26375 Mdot
.8075 .26125 Mdot
.305 .275 Mdot
.46 .25 Mdot
.54 .24125 Mdot
.475 .24125 Mdot
.52 .27 Mdot
.47875 .2825 Mdot
.3275 .3125 Mdot
.9875 .35875 Mdot
.25875 .39125 Mdot
.48 .3775 Mdot
.48375 .3825 Mdot
.42375 .3875 Mdot
.435 .3875 Mdot
.7725 .35875 Mdot
.415 .37125 Mdot
.4075 .41375 Mdot
.52125 .44875 Mdot
.545 .48625 Mdot
.4775 .54 Mdot
.47625 .5775 Mdot
.25875 .56625 Mdot
.16 .52625 Mdot
.4975 .5 Mdot
.61125 .48375 Mdot
.4525 .46625 Mdot
.44375 .45125 Mdot
.66375 .4475 Mdot
.36375 .45125 Mdot
.53875 .47375 Mdot
.475 .4975 Mdot
.49 .50625 Mdot
.52875 .48125 Mdot
.38875 .46375 Mdot
.41125 .445 Mdot
.9275 .44375 Mdot
.265 .4675 Mdot
.54625 .49375 Mdot
.485 .5225 Mdot
.42125 .5225 Mdot
.5275 .515 Mdot
.575 .49625 Mdot
.45625 .48625 Mdot
.49375 .45625 Mdot
.49375 .49 Mdot
.19625 .50125 Mdot
.75875 .49625 Mdot
.845 .49 Mdot
.1825 .50625 Mdot
.5225 .48125 Mdot
.49375 .4725 Mdot
.49875 .47375 Mdot
.4775 .48 Mdot
.45875 .48875 Mdot
.59875 .485 Mdot
.5175 .48 Mdot
.45625 .475 Mdot
.48125 .48875 Mdot
.50375 .49125 Mdot
.2125 .495 Mdot
.885 .50125 Mdot
.58375 .53125 Mdot
.335 .5275 Mdot
.4525 .525 Mdot
.59125 .5225 Mdot
.47625 .53375 Mdot
.4825 .51375 Mdot
.4425 .52 Mdot
.5525 .5225 Mdot
.51625 .52125 Mdot
.46625 .5075 Mdot
.53125 .52375 Mdot
.435 .495 Mdot
.08875 .4775 Mdot
.19875 .4575 Mdot
.37375 .43625 Mdot
.4925 .45875 Mdot
.49625 .465 Mdot
.46875 .4825 Mdot
.4825 .49375 Mdot
.57375 .4975 Mdot
.54 .48375 Mdot
.4825 .485 Mdot
.47375 .4675 Mdot
.49375 .4575 Mdot
.385 .41125 Mdot
.41625 .3625 Mdot
.97125 .29375 Mdot
.1925 .2875 Mdot
.515 .95375 Mdot
.39875 .87875 Mdot
.535 .77625 Mdot
.49875 .73625 Mdot
.22875 .7075 Mdot
.86 .71375 Mdot
.4875 .74125 Mdot
.3775 .82 Mdot
.57375 .855 Mdot
.48 .8975 Mdot
.45 .9225 Mdot
.52625 .935 Mdot
.4975 .8875 Mdot
.4225 .85875 Mdot
.77 .815 Mdot
.31375 .775 Mdot
.5075 .755 Mdot
.46125 .75875 Mdot
.32 .79125 Mdot
.64 .8275 Mdot
.77375 .84625 Mdot
.3125 .88375 Mdot
.47875 .9475 Mdot
.495 .99625 Mdot
.39375 .91 Mdot
.50625 .645 Mdot
.46125 .49 Mdot
.3075 .405 Mdot
.19875 .39125 Mdot
.44875 .4875 Mdot
.53 .5125 Mdot
.495 .52125 Mdot
.52375 .5875 Mdot
.46375 .54875 Mdot
.3975 .4825 Mdot
.83625 .4 Mdot
.3475 .3175 Mdot
.49625 .1775 Mdot
.475 .11125 Mdot
.40625 .0775 Mdot
.31625 .03625 Mdot
.32375 .01375 Mdot
.255 0 Mdot
.52625 .02625 Mdot
.40875 .045 Mdot
.43375 .0575 Mdot
.81375 .06125 Mdot
.36625 .0075 Mdot
.4975 .04125 Mdot
.51125 .05875 Mdot
.29 .04 Mdot
.6475 .0175 Mdot
.435 0 Mdot
.48125 .045 Mdot
.49875 .0325 Mdot
.2725 .04875 Mdot
.8 .06875 Mdot
.56625 .095 Mdot
.36875 .08375 Mdot
.4575 .12125 Mdot
.58125 .1375 Mdot
.4825 .14125 Mdot
.47875 .1425 Mdot
.35375 .15125 Mdot
.7425 .14375 Mdot
.42625 .13625 Mdot
.46625 .13125 Mdot
.53 .165 Mdot
.44125 .14875 Mdot
.195 .18625 Mdot
.26 .26125 Mdot
.40625 .26125 Mdot
.4875 .30625 Mdot
.51 .3425 Mdot
.43875 .345 Mdot
.4825 .34125 Mdot
.565 .34 Mdot
.63125 .3575 Mdot
.43625 .35625 Mdot
.47375 .35625 Mdot
.49625 .38 Mdot
.3775 .49375 Mdot
.4575 .605 Mdot
.89375 .73875 Mdot
.22125 .9075 Mdot
.505 .465 Mdot
.495 .5225 Mdot
.55875 .56875 Mdot
.495 .6175 Mdot
.4625 .71625 Mdot
.52625 .8 Mdot
.48125 .83125 Mdot
.175 .87375 Mdot
.97125 .885 Mdot
.49375 .9 Mdot
.30625 .89375 Mdot
.6175 .875 Mdot
.4625 .865 Mdot
.48 .86625 Mdot
.47125 .7975 Mdot
.53125 .82875 Mdot
.495 .85375 Mdot
.58875 .85125 Mdot
.415 .86625 Mdot
.5075 .91875 Mdot
.46125 .91125 Mdot
.265 .91625 Mdot
.67 .90375 Mdot
.8625 .89125 Mdot
.23625 .87625 Mdot
.51125 .83875 Mdot
.485 .79375 Mdot
.51875 .78125 Mdot
.485 .71 Mdot
.50125 .6975 Mdot
.4375 .685 Mdot
.5875 .705 Mdot
.5475 .75875 Mdot
.42375 .86875 Mdot
.4925 .9725 Mdot
.49875 .97625 Mdot
.46625 .90125 Mdot
.5525 .82375 Mdot
.48625 .72125 Mdot
.5 .7025 Mdot
.255 .6675 Mdot
.9225 .68875 Mdot
.35375 .70375 Mdot
.44375 .775 Mdot
.53125 .83125 Mdot
.45625 .8725 Mdot
.32125 .78875 Mdot
.90875 .71375 Mdot
.37125 .63375 Mdot
.41625 .50875 Mdot
.48875 .385 Mdot
.525 .31125 Mdot
.435 .26625 Mdot
.46875 .26375 Mdot
.5025 .24625 Mdot
.755 .2425 Mdot
.38 .25625 Mdot
.49375 .35375 Mdot
.4875 .39875 Mdot
.385 .4375 Mdot
.49375 .495 Mdot
.815 .57375 Mdot
.245 .50375 Mdot
.51625 .28375 Mdot
.51875 .24625 Mdot
.49125 .2175 Mdot
.495 .2025 Mdot
.5025 .19375 Mdot
.49875 .215 Mdot
.49125 .22125 Mdot
.12625 .19875 Mdot
.46375 .13375 Mdot
.2525 .07125 Mdot
.695 .03375 Mdot
.415 .01375 Mdot
.5 .005 Mdot
.4575 .02 Mdot
.5275 .03 Mdot
.53375 .05125 Mdot
.47125 .08125 Mdot
.5075 .08 Mdot
.48625 .13125 Mdot
.475 .1625 Mdot
.23625 .13625 Mdot
.6375 .14125 Mdot
.99125 .1575 Mdot
.1625 .1 Mdot
.515 .0575 Mdot
.5125 .0525 Mdot
.4825 .02125 Mdot
.49 .01125 Mdot
.52125 .05 Mdot
.5225 .07875 Mdot
.44125 .1325 Mdot
.505 .22875 Mdot
.45625 .21375 Mdot
.0375 .16625 Mdot
.4225 .05 Mdot
.51375 .08875 Mdot
.5425 .16375 Mdot
.46125 .18375 Mdot
.5225 .15875 Mdot
.53625 .1175 Mdot
.48625 .07 Mdot
.51875 .00875 Mdot
.175 .04875 Mdot
.49125 .05375 Mdot
.2925 .0825 Mdot
.69875 .0925 Mdot
.71 .09875 Mdot
.29 .0925 Mdot
.50875 .0125 Mdot
.5625 .02625 Mdot
.4725 .08375 Mdot
.505 .16875 Mdot
.4775 .2725 Mdot
.52 .44 Mdot
.4525 .56 Mdot
.1775 .665 Mdot
.505 .83125 Mdot
.38125 .835 Mdot
.4525 .755 Mdot
.50375 .68375 Mdot
.435 .66 Mdot
.54625 .61375 Mdot
.56875 .5975 Mdot
.4525 .6925 Mdot
.46375 .83375 Mdot
.54 .91125 Mdot
.49125 .9925 Mdot
.52375 .98375 Mdot
.4675 .965 Mdot
.515 .8575 Mdot
.7175 .62625 Mdot
.3 .45 Mdot
.5125 .4575 Mdot
.47625 .44875 Mdot
.5725 .4475 Mdot
.4725 .45875 Mdot
.48375 .4625 Mdot
.49625 .475 Mdot
.4875 .47625 Mdot
.21625 .48125 Mdot
.98625 .49875 Mdot
.44875 .5225 Mdot
.28125 .5325 Mdot
.68625 .55875 Mdot
.41625 .5675 Mdot
.51375 .55625 Mdot
.435 .54625 Mdot
.52 .53 Mdot
.565 .5 Mdot
.4775 .49625 Mdot
.4925 .51125 Mdot
.46625 .4875 Mdot
.4975 .49 Mdot
.2725 .5 Mdot
.60375 .4725 Mdot
.9475 .45625 Mdot
.18125 .49125 Mdot
.5275 .51125 Mdot
.52625 .53125 Mdot
.465 .5675 Mdot
.50625 .56875 Mdot
.49625 .54875 Mdot
.5025 .535 Mdot
.54875 .51125 Mdot
.48 .485 Mdot
.455 .48 Mdot
.5075 .465 Mdot
.4275 .44625 Mdot
.09375 .44375 Mdot
.40125 .4375 Mdot
.49875 .42625 Mdot
.565 .40875 Mdot
.47375 .43 Mdot
.52 .4475 Mdot
.51125 .45625 Mdot
.54 .4775 Mdot
.49125 .49125 Mdot
.49875 .4725 Mdot
.5375 .48 Mdot
.39625 .48375 Mdot
.08375 .49375 Mdot
.19375 .53 Mdot
.43 .505 Mdot
.5325 .50625 Mdot
.5225 .4975 Mdot
.485 .5 Mdot
.47625 .48625 Mdot
.56125 .49875 Mdot
.4575 .48875 Mdot
.46875 .48375 Mdot
.50875 .47375 Mdot
.525 .44625 Mdot
.46625 .42875 Mdot
.1725 .42625 Mdot
.17125 .42375 Mdot
.51125 .4575 Mdot
.5 .46125 Mdot
.51125 .46 Mdot
.485 .47375 Mdot
.51375 .475 Mdot
.49625 .46625 Mdot
.49625 .46875 Mdot
.4975 .47125 Mdot
.50375 .4725 Mdot
.49875 .4825 Mdot
.29125 .4725 Mdot
.7125 .46125 Mdot
.74875 .45875 Mdot
.25375 .43625 Mdot
.4725 .41 Mdot
.53375 .3925 Mdot
.49375 .3875 Mdot
.4775 .3675 Mdot
.52 .34875 Mdot
.49375 .35375 Mdot
.4775 .35625 Mdot
.515 .32 Mdot
.51125 .28625 Mdot
.46 .25875 Mdot
.10125 .2175 Mdot
.4775 .13125 Mdot
.4025 .10125 Mdot
.43625 .0925 Mdot
.5 .09 Mdot
.485 .08375 Mdot
.4775 .125 Mdot
.51875 .14375 Mdot
.49625 .1375 Mdot
.4975 .095 Mdot
.5275 .09125 Mdot
.485 .105 Mdot
.53375 .08125 Mdot
.125 .06625 Mdot
.19125 .05875 Mdot
.4675 .00125 Mdot
.485 .0075 Mdot
.48625 .03125 Mdot
.45625 .07875 Mdot
.545 .13375 Mdot
.495 .18 Mdot
.38875 .20125 Mdot
.45375 .19625 Mdot
.90625 .16 Mdot
.255 .0875 Mdot
.62375 .02625 Mdot
.4375 .06875 Mdot
.48125 .16 Mdot
.54375 .25875 Mdot
.4475 .3575 Mdot
.5 .18875 Mdot
.4 .195 Mdot
.7525 .2125 Mdot
.375 .2225 Mdot
.48625 .2525 Mdot
.50625 .29625 Mdot
.47375 .34 Mdot
.3175 .3575 Mdot
.8475 .3675 Mdot
.4575 .3775 Mdot
.3325 .37125 Mdot
.65625 .355 Mdot
.43 .375 Mdot
.50625 .4075 Mdot
.41875 .4275 Mdot
.45375 .4425 Mdot
.69125 .4725 Mdot
.4575 .4725 Mdot
.53125 .4775 Mdot
.41875 .485 Mdot
.48875 .47 Mdot
.3575 .46 Mdot
.5275 .49 Mdot
.85375 .4925 Mdot
.27 .49 Mdot
.51375 .50625 Mdot
.53625 .50375 Mdot
.46375 .47875 Mdot
.49375 .4725 Mdot
.39625 .49125 Mdot
.73625 .50375 Mdot
.4475 .515 Mdot
.4625 .51125 Mdot
.45875 .50875 Mdot
.50375 .5 Mdot
.46 .5025 Mdot
.15125 .4975 Mdot
.09 .51875 Mdot
.42875 .5125 Mdot
.48625 .5225 Mdot
.56875 .53375 Mdot
.46125 .535 Mdot
.46375 .535 Mdot
.655 .54625 Mdot
.47 .51375 Mdot
.47 .48625 Mdot
.50375 .49625 Mdot
.545 .52625 Mdot
.3975 .5175 Mdot
.1875 .5275 Mdot
.2775 .4975 Mdot
.43375 .45875 Mdot
.54875 .4675 Mdot
.5075 .485 Mdot
.45375 .50375 Mdot
.45 .53125 Mdot
.685 .5425 Mdot
.41125 .53625 Mdot
.45125 .5175 Mdot
.52375 .50875 Mdot
.52 .5025 Mdot
.46125 .485 Mdot
.24625 .48 Mdot
.24 .47375 Mdot
.515 .45 Mdot
.49625 .4625 Mdot
.51 .4675 Mdot
.4725 .475 Mdot
.46375 .4925 Mdot
.585 .515 Mdot
.48875 .5125 Mdot
.47375 .505 Mdot
.5125 .49625 Mdot
.49125 .46 Mdot
.3325 .46125 Mdot
.68625 .46125 Mdot
.6725 .4575 Mdot
.31375 .475 Mdot
.46125 .51375 Mdot
.545 .52625 Mdot
.4975 .52375 Mdot
.43625 .5325 Mdot
.575 .5125 Mdot
.5325 .48875 Mdot
.43125 .46375 Mdot
.505 .46375 Mdot
.53125 .5 Mdot
.475 .5275 Mdot
.15875 .5325 Mdot
.9975 .53875 Mdot
.47625 .5575 Mdot
.46125 .5225 Mdot
.415 .50375 Mdot
.48 .50125 Mdot
.47875 .5125 Mdot
.54375 .4975 Mdot
.49625 .4925 Mdot
.47875 .485 Mdot
.49875 .5 Mdot
.52875 .4775 Mdot
.50375 .48125 Mdot
.52875 .495 Mdot
.1625 .5 Mdot
.2225 .53125 Mdot
.47375 .53625 Mdot
.4525 .5275 Mdot
.5075 .53625 Mdot
.5925 .51625 Mdot
.4775 .505 Mdot
.4575 .47875 Mdot
.50125 .46 Mdot
.44625 .43 Mdot
.54625 .39625 Mdot
.52 .40125 Mdot
.40375 .4075 Mdot
.41625 .40125 Mdot
.8725 .4125 Mdot
.29125 .4625 Mdot
.6325 .45875 Mdot
.43375 .47 Mdot
.4225 .4325 Mdot
.52375 .38625 Mdot
.5575 .3125 Mdot
.41625 .245 Mdot
.485 .5525 Mdot
.3375 .52625 Mdot
.91125 .47 Mdot
.29875 .41875 Mdot
.49 .3775 Mdot
.49125 .3675 Mdot
.47875 .3325 Mdot
.4125 .3075 Mdot
.70375 .3375 Mdot
.485 .33 Mdot
.38375 .26 Mdot
.6075 .225 Mdot
.44 .175 Mdot
.51125 .05375 Mdot
.42125 .0125 Mdot
.495 .05625 Mdot
.385 .07 Mdot
.50625 .06 Mdot
.75 .0475 Mdot
.49125 .04375 Mdot
.505 .07875 Mdot
.22625 .13 Mdot
.20625 .26 Mdot
.43875 .2 Mdot
.51 .23 Mdot
.54375 .23375 Mdot
.465 .22875 Mdot
.37125 .26 Mdot
.8425 .32125 Mdot
.37375 .3375 Mdot
.4575 .33125 Mdot
.49875 .30875 Mdot
.54375 .27 Mdot
.42 .18875 Mdot
.3025 .14 Mdot
.88375 .12875 Mdot
.35375 .125 Mdot
.46875 .13125 Mdot
.565 .12625 Mdot
.48625 .1075 Mdot
.44375 .045 Mdot
.3575 0 Mdot
.525 .03 Mdot
.46625 .095 Mdot
.31125 .15 Mdot
.88125 .23 Mdot
.30625 .31 Mdot
.51625 .32125 Mdot
.5 .32 Mdot
.505 .305 Mdot
.47375 .2675 Mdot
.385 .19625 Mdot
.745 .1525 Mdot
.405 .13625 Mdot
.4725 .1275 Mdot
.51375 .155 Mdot
.49125 .21625 Mdot
.38 .2275 Mdot
.64125 .24875 Mdot
.60875 .26375 Mdot
.37 .24375 Mdot
.46 .235 Mdot
.54 .24625 Mdot
.51625 .25625 Mdot
.275 .2725 Mdot
.82625 .28625 Mdot
.465 .29 Mdot
.39875 .2925 Mdot
.52125 .29125 Mdot
.515 .29375 Mdot
.485 .31 Mdot
.24875 .30125 Mdot
.8625 .28 Mdot
.47625 .24875 Mdot
.485 .23625 Mdot
.41375 .21125 Mdot
.4025 .20125 Mdot
.57375 .18375 Mdot
.6125 .15625 Mdot
.42625 .1525 Mdot
.495 .155 Mdot
.49125 .15125 Mdot
.51875 .17375 Mdot
.49375 .25 Mdot
.54625 .25625 Mdot
.24 .2725 Mdot
.93125 .2925 Mdot
.29375 .275 Mdot
.48875 .2325 Mdot
.43375 .25375 Mdot
.4325 .26125 Mdot
.77 .27125 Mdot
.43125 .30875 Mdot
.42 .3625 Mdot
.5125 .37 Mdot
.455 .3675 Mdot
.5275 .34625 Mdot
.54625 .35625 Mdot
.42 .345 Mdot
.40375 .39 Mdot
.79375 .42875 Mdot
.32625 .485 Mdot
.635 .51 Mdot
.41375 .5225 Mdot
.37375 .52125 Mdot
.69375 .535 Mdot
.47375 .5525 Mdot
.4125 .5375 Mdot
.495 1 Mdot
.51375 .995 Mdot
.4925 .93375 Mdot
.4875 .93375 Mdot
.2925 .97625 Mdot
.91375 .9775 Mdot
.32125 .97 Mdot
.48875 .97875 Mdot
.4225 .91375 Mdot
.57 .82875 Mdot
.60125 .7575 Mdot
.41125 .6925 Mdot
.455 .6125 Mdot
.54875 .515 Mdot
.5125 .45125 Mdot
.13875 .425 Mdot
.36875 .44125 Mdot
.3925 .505 Mdot
.52625 .555 Mdot
.51 .6025 Mdot
.5 .585 Mdot
.35 .61625 Mdot
.70125 .6525 Mdot
.47125 .6775 Mdot
.5225 .61125 Mdot
.43 .59 Mdot
.30125 .6175 Mdot
.6825 .68 Mdot
.675 .7825 Mdot
.3675 .85625 Mdot
.4875 .9225 Mdot
.49875 .935 Mdot
.5025 .9075 Mdot
.5025 .84 Mdot
.52375 .79125 Mdot
.3525 .715 Mdot
.74625 .6025 Mdot
.36125 .54625 Mdot
.5075 .44875 Mdot
.39375 .36625 Mdot
.39375 .3175 Mdot
.94875 .29 Mdot
.35 .21375 Mdot
.4025 .19125 Mdot
.51875 .22875 Mdot
.46 .22875 Mdot
.52 .30625 Mdot
.54625 .35875 Mdot
.4425 .395 Mdot
.44125 .3975 Mdot
.6775 .41125 Mdot
.37875 .305 Mdot
.6125 .205 Mdot
.42125 .13125 Mdot
.31 .29875 Mdot
.85125 .5025 Mdot
.39 .7675 Mdot
.12375 .0325 Mdot
.58125 .00375 Mdot
.46 .05 Mdot
.48375 .08125 Mdot
.47 .14625 Mdot
.5175 .26375 Mdot
.53 .28375 Mdot
.1425 .28 Mdot
.175 .24125 Mdot
.48 .12125 Mdot
.46 .10625 Mdot
.5175 .07625 Mdot
.49875 .03 Mdot
.48375 .01375 Mdot
.555 .1175 Mdot
.48375 .265 Mdot
.43 .3375 Mdot
.14125 .40875 Mdot
.17 .4175 Mdot
.3975 .34125 Mdot
.5775 .3125 Mdot
.49125 .30125 Mdot
.53375 .31625 Mdot
.44375 .3275 Mdot
.58 .35875 Mdot
.4725 .4 Mdot
.475 .41875 Mdot
.5275 .43375 Mdot
.4775 .5175 Mdot
.48125 .605 Mdot
.21875 .6625 Mdot
.2225 .79625 Mdot
.48875 .80125 Mdot
.49625 .7775 Mdot
.49 .8075 Mdot
.47375 .88125 Mdot
.5125 .97125 Mdot
.71625 .97625 Mdot
.28 .9875 Mdot
.49 .99625 Mdot
.97 .8975 Mdot
.355 .56625 Mdot
.3825 .31625 Mdot
.465 .50375 Mdot
.26 .50375 Mdot
.13875 .50625 Mdot
.4775 .515 Mdot
.49 .505 Mdot
.4875 .50375 Mdot
.5225 .50375 Mdot
.5325 .4925 Mdot
.53375 .48875 Mdot
.4675 .495 Mdot
.4825 .495 Mdot
.48 .49 Mdot
.4925 .53 Mdot
.48 .5425 Mdot
.12375 .54 Mdot
.18875 .565 Mdot
.57125 .5125 Mdot
.405 .5 Mdot
.48625 .49125 Mdot
.5025 .4775 Mdot
.48375 .4725 Mdot
.5075 .49375 Mdot
.52 .5025 Mdot
.49 .515 Mdot
.53125 .5025 Mdot
.44 .505 Mdot
.4525 .495 Mdot
.20375 .4925 Mdot
.49125 .48625 Mdot
.48875 .48125 Mdot
.46125 .45625 Mdot
.57625 .44875 Mdot
.46625 .45125 Mdot
.505 .46625 Mdot
.50125 .46 Mdot
.5225 .45875 Mdot
.46125 .43625 Mdot
.505 .43875 Mdot
.51625 .41625 Mdot
.0875 .42375 Mdot
.09375 .43875 Mdot
.47875 .41125 Mdot
.49875 .38875 Mdot
.47375 .365 Mdot
.51375 .34125 Mdot
.495 .38125 Mdot
.4925 .405 Mdot
.50375 .42 Mdot
.52125 .41875 Mdot
.5375 .40625 Mdot
.475 .3675 Mdot
.43 .32875 Mdot
.07 .305 Mdot
.05625 .31375 Mdot
.42375 .28875 Mdot
.5625 .28875 Mdot
.49625 .27625 Mdot
.56875 .28 Mdot
.43625 .285 Mdot
.51875 .3025 Mdot
.51 .30625 Mdot
.4825 .32875 Mdot
.5225 .32 Mdot
.475 .29875 Mdot
.49625 .2425 Mdot
.1375 .1975 Mdot
.15625 .12 Mdot
.48125 .07875 Mdot
.485 .07375 Mdot
.505 .03125 Mdot
.5425 .02375 Mdot
.50625 .065 Mdot
.20625 .125 Mdot
.36125 .02875 Mdot
.51875 .00375 Mdot
.43125 .01625 Mdot
.0825 .065 Mdot
.74125 .12875 Mdot
.21125 .06 Mdot
.27375 .09625 Mdot
.22125 .33125 Mdot
.44375 .3675 Mdot
.60125 .51625 Mdot
.27 .5175 Mdot
.9725 .51875 Mdot
.23875 .49625 Mdot
.455 .4575 Mdot
.41875 .44625 Mdot
.6575 .4525 Mdot
.4875 .46375 Mdot
.49 .47625 Mdot
.51625 .5025 Mdot
.4775 .51125 Mdot
.45625 .51375 Mdot
.44375 .5 Mdot
.6275 .47375 Mdot
.48375 .4425 Mdot
.15125 .43375 Mdot
.20125 .4475 Mdot
.54375 .49125 Mdot
.37625 .525 Mdot
.6375 .54375 Mdot
.4375 .54625 Mdot
.48 .535 Mdot
.50125 .50875 Mdot
.54375 .4975 Mdot
.47625 .505 Mdot
.46625 .5375 Mdot
.5275 .51375 Mdot
.44875 .5225 Mdot
.3125 .52625 Mdot
.065 .4875 Mdot
.45875 .505 Mdot
.52125 .5 Mdot
.55 .485 Mdot
.5325 .4725 Mdot
.44625 .45875 Mdot
.47 .46125 Mdot
.53125 .47625 Mdot
.5225 .49125 Mdot
.3975 .49125 Mdot
.5975 .46375 Mdot
.545 .455 Mdot
.1075 .45 Mdot
.17125 .44875 Mdot
.53 .485 Mdot
.45375 .51375 Mdot
.53875 .53 Mdot
.4725 .57 Mdot
.495 .56375 Mdot
.48625 .5575 Mdot
.52 .53 Mdot
.51875 .50625 Mdot
.5025 .4875 Mdot
.575 .50375 Mdot
.39625 .51125 Mdot
.105 .525 Mdot
.105 .49375 Mdot
.465 .47625 Mdot
.555 .4625 Mdot
.51 .45625 Mdot
.56625 .45125 Mdot
.46 .47375 Mdot
.4825 .48125 Mdot
.50375 .5 Mdot
.495 .49875 Mdot
.5475 .4975 Mdot
.46375 .5075 Mdot
.50375 .51 Mdot
.18 .5075 Mdot
.18125 .50375 Mdot
.49625 .48625 Mdot
.5025 .47875 Mdot
.49125 .51 Mdot
.5 .52875 Mdot
.47875 .5525 Mdot
.48125 .56625 Mdot
.5625 .5675 Mdot
.4875 .5375 Mdot
.51875 .51625 Mdot
.50625 .46 Mdot
.18375 .3725 Mdot
.4125 .36375 Mdot
.50125 .39625 Mdot
.54875 .4125 Mdot
.48125 .45625 Mdot
.5075 .49625 Mdot
.50375 .51625 Mdot
.48375 .51875 Mdot
.5175 .49 Mdot
.46875 .48 Mdot
.055 .46625 Mdot
.685 .44625 Mdot
.24875 .46125 Mdot
.49875 .4525 Mdot
.4875 .44125 Mdot
.51125 .44875 Mdot
.495 .445 Mdot
.49375 .44875 Mdot
.47625 .44375 Mdot
.49375 .4525 Mdot
.46625 .4875 Mdot
.57 .51125 Mdot
.3875 .51 Mdot
.2225 .52375 Mdot
.21375 .46375 Mdot
.44375 .44875 Mdot
.50875 .4325 Mdot
.49375 .42 Mdot
.4725 .4025 Mdot
.525 .385 Mdot
.47375 .37125 Mdot
.51125 .39125 Mdot
.55 .39375 Mdot
.4725 .40875 Mdot
.5 .4375 Mdot
.40875 .45625 Mdot
.27375 .45625 Mdot
.1025 .4975 Mdot
.49625 .51375 Mdot
.42 .0075 Mdot
.98625 .0625 Mdot
.15875 .0875 Mdot
.42375 .12375 Mdot
.44375 .18 Mdot
.7675 .2325 Mdot
.44125 .2825 Mdot
.3975 .3175 Mdot
.48125 .2875 Mdot
.555 .25375 Mdot
.5075 .21 Mdot
.2775 .16375 Mdot
.77875 .17375 Mdot
.54625 .16625 Mdot
.14875 .17625 Mdot
.94375 .19375 Mdot
.265 .2125 Mdot
.5375 .195 Mdot
.32 .20375 Mdot
.76375 .205 Mdot
.3525 .18375 Mdot
.4725 .16625 Mdot
.53 .16 Mdot
.53375 .1825 Mdot
.49875 .20875 Mdot
.48125 .205 Mdot
.73625 .25625 Mdot
.285 .27375 Mdot
.185 .2725 Mdot
.19 .4075 Mdot
.3975 .43375 Mdot
.61875 .475 Mdot
.61 .50625 Mdot
.4975 .49375 Mdot
.4475 .44 Mdot
.4875 .41625 Mdot
.4775 .37375 Mdot
.37875 .34375 Mdot
.76375 .325 Mdot
.435 .33 Mdot
.445 .28875 Mdot
.26125 .25625 Mdot
.975 .235 Mdot
.2375 .20375 Mdot
.3825 .17875 Mdot
.785 .19375 Mdot
.34625 .20375 Mdot
.5025 .20625 Mdot
.4725 .21375 Mdot
.41 .235 Mdot
.6275 .2475 Mdot
.57 .2975 Mdot
.43625 .32625 Mdot
.49 .39125 Mdot
.09125 .465 Mdot
.20375 .57875 Mdot
.61625 .61 Mdot
.4125 .5825 Mdot
.53375 .52125 Mdot
.48875 .45375 Mdot
.49875 .4175 Mdot
.49875 .4125 Mdot
.395 .44125 Mdot
.73 .5025 Mdot
.3675 .525 Mdot
.14875 .52375 Mdot
.9275 .5125 Mdot
.615 .49125 Mdot
.18875 .46125 Mdot
.6625 .4725 Mdot
.51625 .48375 Mdot
.43125 .49 Mdot
.51625 .50125 Mdot
.4925 .49875 Mdot
.48875 .4725 Mdot
.41875 .47125 Mdot
.51125 .4625 Mdot
.6725 .47625 Mdot
.3375 .485 Mdot
.30875 .49125 Mdot
.2375 .50875 Mdot
.415 .4975 Mdot
.66 .5175 Mdot
.4625 .51375 Mdot
.46 .53 Mdot
.51125 .53125 Mdot
.46125 .53 Mdot
.51125 .495 Mdot
.44 .5325 Mdot
.6475 .54375 Mdot
.50125 .5225 Mdot
.3875 .51 Mdot
.3325 .4 Mdot
.94 .2525 Mdot
.18875 .0875 Mdot
.30875 .9875 Mdot
.85875 .96 Mdot
.235 .8625 Mdot
.41 .75875 Mdot
.36375 .72625 Mdot
.9425 .6925 Mdot
.3825 .70875 Mdot
.33375 .76375 Mdot
.4925 .775 Mdot
.5775 .68375 Mdot
.49 .65375 Mdot
.1575 .67125 Mdot
.98875 .71125 Mdot
.51875 .70875 Mdot
.17 .72875 Mdot
.78875 .72375 Mdot
.3525 .64125 Mdot
.5175 .5725 Mdot
.2175 .555 Mdot
.96375 .55625 Mdot
.27375 .54125 Mdot
.43875 .58 Mdot
.52 .53375 Mdot
.54 .46375 Mdot
.5 .4625 Mdot
.5125 .49 Mdot
.8475 .53375 Mdot
.18 .52625 Mdot
.28875 .52875 Mdot
.86625 .4325 Mdot
.285 .32625 Mdot
.32125 .21875 Mdot
.705 .17625 Mdot
.68625 .15625 Mdot
.40625 .17125 Mdot
.46625 .18625 Mdot
.485 .13375 Mdot
.45375 .14 Mdot
.2625 .165 Mdot
.98 .18875 Mdot
.3875 .26375 Mdot
.39375 .31875 Mdot
.36125 .345 Mdot
.81375 .3275 Mdot
.31375 .35125 Mdot
.2775 .31625 Mdot
.995 .30375 Mdot
.24625 .27375 Mdot
.505 .26375 Mdot
.4925 .17875 Mdot
.35375 .0975 Mdot
.5675 .04 Mdot
.5175 .06125 Mdot
.4875 .065 Mdot
.4975 .01625 Mdot
.25125 .065 Mdot
.23875 .11125 Mdot
.8175 .185 Mdot
.56125 .2225 Mdot
.15375 .13125 Mdot
.7675 .0525 Mdot
.55 .0425 Mdot
.39875 .0275 Mdot
.495 .0225 Mdot
.5025 .04 Mdot
.5075 .11875 Mdot
.345 .14 Mdot
.6325 .16375 Mdot
.6725 .18375 Mdot
.32875 .1075 Mdot
.3425 .05375 Mdot
.835 .045 Mdot
.31875 .0075 Mdot
.91875 .03375 Mdot
.37625 .08125 Mdot
.42625 .11 Mdot
.51125 .15375 Mdot
.4475 .18375 Mdot
.5225 .17 Mdot
.3025 .1075 Mdot
.915 .05375 Mdot
.38625 .0325 Mdot
.39375 .23625 Mdot
.785 .47375 Mdot
.25875 .8325 Mdot
.0525 .3775 Mdot
.49 .4075 Mdot
.48 .45125 Mdot
.3675 .49 Mdot
.01625 .42625 Mdot
.2575 .33 Mdot
.3475 .31125 Mdot
.49 .355 Mdot
.48875 .44125 Mdot
.4 .515 Mdot
.075 .50375 Mdot
.22125 .425 Mdot
.31 .42625 Mdot
.52375 .405 Mdot
.43 .4875 Mdot
.4825 .5375 Mdot
.20875 .56375 Mdot
.21625 .61125 Mdot
.355 .6 Mdot
.56125 .63875 Mdot
.51 .73875 Mdot
.4575 .785 Mdot
.19125 .75875 Mdot
.7925 .68875 Mdot
.51125 .665 Mdot
.53875 .62125 Mdot
.69125 .71875 Mdot
.385 .7925 Mdot
.3625 .8975 Mdot
.34 .9225 Mdot
.28 .84375 Mdot
.27 .825 Mdot
.52875 .835 Mdot
.60625 .9 Mdot
.45375 .96625 Mdot
.4775 .9875 Mdot
.3525 .9575 Mdot
.13125 .66625 Mdot
.4275 .0925 Mdot
.52125 .15375 Mdot
.365 .195 Mdot
.2825 .26 Mdot
.25375 .19 Mdot
.4975 .165 Mdot
.525 .23125 Mdot
.36375 .25 Mdot
.18875 .23875 Mdot
.29 .15625 Mdot
.46625 .15625 Mdot
.4475 .175 Mdot
.52 .2025 Mdot
.17125 .245 Mdot
.21625 .35 Mdot
.33875 .37625 Mdot
.525 .42125 Mdot
.52375 .41625 Mdot
.46625 .35625 Mdot
.09 .3175 Mdot
.89625 .28125 Mdot
.485 .22 Mdot
.62125 .175 Mdot
.54875 .145 Mdot
.45875 .20125 Mdot
.3875 .19875 Mdot
.2925 .19875 Mdot
.2475 .2675 Mdot
.22125 .19375 Mdot
.58875 .1975 Mdot
.605 .22125 Mdot
.43375 .2175 Mdot
.035 .205 Mdot
.4825 .14625 Mdot
.25 .06875 Mdot
.4775 0 Mdot
.54 .05375 Mdot
.5025 .05875 Mdot
.0075 .1175 Mdot
.09125 .36 Mdot
.3775 .36375 Mdot
.50375 .4125 Mdot
.54625 .4325 Mdot
.5625 .29375 Mdot
.45375 .18875 Mdot
.25875 .01125 Mdot
.4925 .03875 Mdot
.52125 .125 Mdot
.08625 .15 Mdot
.95625 .2075 Mdot
.6775 .2475 Mdot
.25625 .115 Mdot
.4925 .0525 Mdot
.5225 .15375 Mdot
.5075 .32375 Mdot
.2675 .38625 Mdot
.9175 .44 Mdot
.5475 .4125 Mdot
.31375 .3025 Mdot
.4325 .1625 Mdot
.495 .1975 Mdot
.49625 .23625 Mdot
.1475 .4025 Mdot
.42875 .31875 Mdot
.45125 .25625 Mdot
.47125 .32875 Mdot
.48875 .42875 Mdot
.0075 .44 Mdot
.17125 .36625 Mdot
.41 .245 Mdot
.4725 .14875 Mdot
.525 .1975 Mdot
.49875 .19875 Mdot
.0175 .4825 Mdot
.39625 .46875 Mdot
.6125 .49875 Mdot
.3825 .5075 Mdot
.2775 .53 Mdot
.3175 .5 Mdot
.5175 .45625 Mdot
.52375 .45375 Mdot
.35875 .435 Mdot
.05375 .435 Mdot
.22 .48375 Mdot
.34 .47875 Mdot
.43125 .4725 Mdot
.50625 .505 Mdot
.53875 .5025 Mdot
.2125 .48 Mdot
.27 .39375 Mdot
.37 .33875 Mdot
.505 .29 Mdot
.535 .29875 Mdot
.48125 .37625 Mdot
.12625 .41875 Mdot
.8175 .41375 Mdot
.5025 .3875 Mdot
.59875 .3575 Mdot
.52125 .2675 Mdot
.53625 .2475 Mdot
.45 .27875 Mdot
.23875 .32125 Mdot
.27125 .34125 Mdot
.26625 .35625 Mdot
.5975 .3425 Mdot
.595 .39875 Mdot
.43375 .43375 Mdot
.1125 .435 Mdot
.45875 .4275 Mdot
.305 .38 Mdot
.45875 .3925 Mdot
.5575 .41 Mdot
.51875 .40875 Mdot
.02875 .40875 Mdot
.14875 .415 Mdot
.37625 .445 Mdot
.5075 .49625 Mdot
.5275 .49375 Mdot
.57875 .5175 Mdot
.4575 .50625 Mdot
.025 .42375 Mdot
.47 .43875 Mdot
.5075 .43625 Mdot
.5375 .43 Mdot
.1375 .435 Mdot
.89875 .4575 Mdot
.69875 .4625 Mdot
.27 .44875 Mdot
.4975 .4325 Mdot
.52125 .4125 Mdot
.36625 .39875 Mdot
.10625 .40375 Mdot
.2275 .48125 Mdot
.355 .515 Mdot
.50875 .5 Mdot
.5075 .44625 Mdot
.46 .42375 Mdot
.0775 .40375 Mdot
.09375 .41875 Mdot
.52375 .42 Mdot
.46375 .455 Mdot
.31625 .4825 Mdot
.44625 .49 Mdot
.1725 .58125 Mdot
.51625 .5 Mdot
.5225 .465 Mdot
.45 .43625 Mdot
.22375 .40125 Mdot
.185 .43625 Mdot
.42375 .43875 Mdot
.515 .48375 Mdot
.48625 .48375 Mdot
.4925 .4775 Mdot
.2225 .46625 Mdot
.48375 .43375 Mdot
.48 .39625 Mdot
.52125 .3825 Mdot
.05 .39125 Mdot
.9825 .35625 Mdot
.73875 .35125 Mdot
.22375 .40125 Mdot
.46 .405 Mdot
.53125 .39125 Mdot
.51 .3625 Mdot
.26 .34125 Mdot
.9775 .29875 Mdot
.52 .30125 Mdot
.30875 .2975 Mdot
.45625 .32625 Mdot
.4575 .3475 Mdot
.47875 .33875 Mdot
.11 .28 Mdot
.40125 .26625 Mdot
.44625 .2775 Mdot
.51 .32125 Mdot
.46125 .26875 Mdot
.085 .3075 Mdot
.43875 .29 Mdot
.50875 .36375 Mdot
.4425 .41 Mdot
.49625 .4225 Mdot
.0375 .445 Mdot
.1625 .14875 Mdot
.30375 .16375 Mdot
.83125 .24 Mdot
.32625 .23375 Mdot
.13125 .26 Mdot
.31125 .27875 Mdot
.4025 .24375 Mdot
.5075 .315 Mdot
.52125 .3775 Mdot
.385 .375 Mdot
.1675 .35 Mdot
.2775 .21 Mdot
.425 .125 Mdot
.3575 .16125 Mdot
.61125 .245 Mdot
.59125 .25125 Mdot
.2 .26625 Mdot
.97125 .29 Mdot
.33875 .26375 Mdot
.43 .20125 Mdot
.47 .2275 Mdot
.52625 .3 Mdot
.505 .36 Mdot
.1675 .4775 Mdot
.75 .64375 Mdot
.5175 .8275 Mdot
.575 .90375 Mdot
.425 .9775 Mdot
.665 .93875 Mdot
.49875 .7975 Mdot
.27375 .61125 Mdot
.8475 .52125 Mdot
.335 .42125 Mdot
.34 .3425 Mdot
.57 .325 Mdot
.585 .355 Mdot
.45625 .34 Mdot
.21 .31125 Mdot
.96375 .28875 Mdot
.445 .275 Mdot
.36625 .22625 Mdot
.40375 .19125 Mdot
.60625 .19625 Mdot
.6175 .2725 Mdot
.0725 .30875 Mdot
.26125 .285 Mdot
.415 .23625 Mdot
.46 .20375 Mdot
.52625 .23625 Mdot
.57375 .29625 Mdot
.47125 .3275 Mdot
.87625 .36875 Mdot
.17 .335 Mdot
.46125 .28375 Mdot
.41875 .30625 Mdot
.72125 .29625 Mdot
.1475 .28 Mdot
.815 .275 Mdot
.5875 .2875 Mdot
.34 .285 Mdot
.50375 .29375 Mdot
.5375 .36875 Mdot
.39625 .41 Mdot
.22625 .415 Mdot
.26375 .41875 Mdot
.43 .3875 Mdot
.495 .395 Mdot
.355 .43 Mdot
.625 .40875 Mdot
.30375 .39625 Mdot
.99375 .40625 Mdot
.24875 .40125 Mdot
.51 .385 Mdot
.465 .41625 Mdot
.385 .46125 Mdot
.38625 .48125 Mdot
.935 .4825 Mdot
.23625 .49625 Mdot
.5225 .53125 Mdot
.4625 .51375 Mdot
.6725 .51125 Mdot
.15375 .5275 Mdot
.97375 .53125 Mdot
.25125 .51875 Mdot
.50125 .5625 Mdot
.47125 .54875 Mdot
.51625 .5725 Mdot
.4925 .565 Mdot
.31 .55125 Mdot
.07 .5175 Mdot
.4675 .4925 Mdot
.465 .49 Mdot
.55875 .4825 Mdot
.265 .49625 Mdot
.74125 .5375 Mdot
.6925 .55625 Mdot
.335 .575 Mdot
.4425 .60625 Mdot
.515 .6225 Mdot
.46625 .59125 Mdot
.40375 .57625 Mdot
.92 .58125 Mdot
.3875 .56125 Mdot
.38875 .53 Mdot
.445 .5225 Mdot
.4 .52 Mdot
.6475 .49125 Mdot
.135 .51125 Mdot
.41375 .52375 Mdot
.45125 .5525 Mdot
.55 .5525 Mdot
.50125 .575 Mdot
.04625 .5725 Mdot
.1125 .5475 Mdot
.4875 .55625 Mdot
.49125 .46875 Mdot
.48375 .40125 Mdot
.6125 .34125 Mdot
.03 .25875 Mdot
.9425 .8225 Mdot
.30375 .79625 Mdot
.17375 .71875 Mdot
.25625 .75875 Mdot
.26125 .785 Mdot
.88125 .79 Mdot
.375 .79375 Mdot
.48 .7625 Mdot
.4925 .665 Mdot
.5125 .69875 Mdot
.405 .7075 Mdot
.31625 .70625 Mdot
.92625 .7325 Mdot
.3675 .78875 Mdot
.47 .7925 Mdot
.29375 .795 Mdot
.7275 .7825 Mdot
.62125 .8075 Mdot
.23375 .785 Mdot
.73375 .71875 Mdot
.385 .65 Mdot
.545 .59625 Mdot
.42625 .5 Mdot
.5475 .49375 Mdot
.49375 .515 Mdot
.255 .5675 Mdot
.695 .56 Mdot
.49625 .54375 Mdot
.54875 .5175 Mdot
.3275 .4925 Mdot
.7775 .4925 Mdot
.54125 .56 Mdot
.3 .66875 Mdot
.685 .745 Mdot
.3775 .8 Mdot
.39625 .82625 Mdot
.5675 .82375 Mdot
.5625 .78875 Mdot
.4775 .7375 Mdot
.33125 .69375 Mdot
.7525 .6825 Mdot
.46 .66125 Mdot
.42875 .61125 Mdot
.38125 .5775 Mdot
.63625 .61875 Mdot
.65875 .48375 Mdot
.145 .4075 Mdot
.85 .4575 Mdot
.34375 .48375 Mdot
.45125 .5225 Mdot
.46875 .605 Mdot
.50375 .69375 Mdot
.57625 .6325 Mdot
.43375 .60625 Mdot
.77875 .5375 Mdot
.28 .55125 Mdot
.46125 .5025 Mdot
.29875 .5525 Mdot
.9475 .56125 Mdot
.16125 .545 Mdot
.6775 .52625 Mdot
.53375 .48125 Mdot
.4075 .38 Mdot
.485 .345 Mdot
.555 .37625 Mdot
.42 .3525 Mdot
.37625 .38 Mdot
.9025 .40125 Mdot
.31375 .37 Mdot
.47875 .23 Mdot
.4625 .16875 Mdot
.23375 .1725 Mdot
.8325 .15625 Mdot
.405 .15125 Mdot
.73125 .1325 Mdot
.35125 .10625 Mdot
.5075 .025 Mdot
.4425 .06125 Mdot
.42625 .0175 Mdot
.44875 .015 Mdot
.7775 .03 Mdot
.31125 .02375 Mdot
.40875 .0775 Mdot
.89375 .145 Mdot
.10375 .18125 Mdot
.80125 .22875 Mdot
.32625 .2475 Mdot
.5175 .20375 Mdot
.465 .22375 Mdot
.52125 .285 Mdot
.49125 .3 Mdot
.35 .30125 Mdot
1 .27875 Mdot
.1775 .255 Mdot
.4625 .19 Mdot
.4225 .24625 Mdot
.5625 .32375 Mdot
.47 .3375 Mdot
.565 .3475 Mdot
.6525 .38125 Mdot
.3825 .34 Mdot
.46625 .315 Mdot
.50625 .35625 Mdot
.435 .34375 Mdot
.49125 .2925 Mdot
.7925 .22875 Mdot
.3875 .1675 Mdot
.42125 .09125 Mdot
.4775 .07625 Mdot
.31 .205 Mdot
.80625 .245 Mdot
.04125 .24375 Mdot
.215 .24 Mdot
.4675 .10625 Mdot
.47375 .07125 Mdot
.5325 .15375 Mdot
.4925 .16 Mdot
.185 .1975 Mdot
.24125 .26625 Mdot
.495 .1925 Mdot
.405 .325 Mdot
.55 .51125 Mdot
.71875 .63375 Mdot
.065 .7475 Mdot
.7125 .7475 Mdot
.40375 .8175 Mdot
.065 .9225 Mdot
.18875 .78125 Mdot
.36625 .79125 Mdot
.60375 .77375 Mdot
.46125 .785 Mdot
.52 .89 Mdot
.49375 .98375 Mdot
.51625 .90125 Mdot
.425 .9025 Mdot
.42375 .92 Mdot
.6475 .945 Mdot
.4725 .9275 Mdot
.24125 .98625 Mdot
.83875 .89875 Mdot
.64625 .85125 Mdot
.24375 .875 Mdot
.525 .94 Mdot
.61625 .935 Mdot
.5225 .84 Mdot
.4875 .84 Mdot
.27375 .85125 Mdot
.78 .85 Mdot
.65625 .83375 Mdot
.2575 .85875 Mdot
.5625 .8675 Mdot
.44625 .8725 Mdot
.46625 .92625 Mdot
.5275 .95375 Mdot
.535 .91125 Mdot
.5075 .92875 Mdot
.435 .99125 Mdot
.28875 .98625 Mdot
.45125 .95875 Mdot
.3775 .95875 Mdot
.58 .96625 Mdot
.655 .96625 Mdot
.4625 .97 Mdot
.4925 .935 Mdot
.2175 .9025 Mdot
.98625 .905 Mdot
.1225 .89625 Mdot
.84125 .9075 Mdot
.3125 .865 Mdot
.5175 .81875 Mdot
.52 .7925 Mdot
.49875 .7925 Mdot
.49125 .78 Mdot
.31375 .76 Mdot
.835 .74875 Mdot
.35375 .66375 Mdot
.49875 .58 Mdot
.33625 .5925 Mdot
.62375 .5475 Mdot
.77 .5825 Mdot
.12625 .67125 Mdot
.51375 .2625 Mdot
.49 .25 Mdot
.115 .2 Mdot
.42375 .13375 Mdot
.49125 .1 Mdot
.4375 .08375 Mdot
.6 .0625 Mdot
.48125 .03125 Mdot
.51 .0225 Mdot
.4475 .0275 Mdot
.49875 .05875 Mdot
.47875 .0625 Mdot
.53125 .10625 Mdot
.5125 .13 Mdot
.2 .125 Mdot
.93625 .12125 Mdot
.635 .1325 Mdot
.2475 .07875 Mdot
.45 .0325 Mdot
.55 0 Mdot
.455 .03375 Mdot
.215 .055 Mdot
.83375 .07125 Mdot
.70125 .1025 Mdot
.2475 .08125 Mdot
.4975 .06 Mdot
.48 .06 Mdot
.5 .05625 Mdot
.47625 .0475 Mdot
.53375 .04125 Mdot
.52875 .04375 Mdot
.47625 .03125 Mdot
.5125 .01125 Mdot
.465 .06875 Mdot
.5225 .12625 Mdot
.22625 .085 Mdot
.75125 .04625 Mdot
.84875 .01125 Mdot
.52625 .02875 Mdot
.4575 .01625 Mdot
.0725 .00125 Mdot
.51375 .01125 Mdot
.40875 .15125 Mdot
.02375 .1175 Mdot
.57 .1225 Mdot
.23 .02125 Mdot
.465 .06875 Mdot
.4625 .23125 Mdot
.48375 .27375 Mdot
.31625 .25375 Mdot
.51 .30375 Mdot
.4225 .36375 Mdot
.58375 .445 Mdot
.4375 .425 Mdot
.55875 .2875 Mdot
.40375 .27125 Mdot
.5125 .265 Mdot
.69125 .3075 Mdot
.3875 .43625 Mdot
.4475 .60125 Mdot
.33625 .57625 Mdot
.59125 .50875 Mdot
.84625 .46875 Mdot
.25375 .3675 Mdot
.52875 .2525 Mdot
.51375 .2625 Mdot
.46875 .36625 Mdot
.49375 .33625 Mdot
.43625 .3325 Mdot
.59 .39 Mdot
.52375 .4425 Mdot
.4375 .4375 Mdot
.495 .56875 Mdot
.52875 .645 Mdot
.10375 .5575 Mdot
.2175 .54375 Mdot
.4925 .545 Mdot
.395 .675 Mdot
.57125 .9275 Mdot
.45625 .97 Mdot
.48875 .98875 Mdot
.44375 .9475 Mdot
.56625 .92 Mdot
.47625 .94875 Mdot
.26875 .9275 Mdot
.68 .73 Mdot
.89375 .5375 Mdot
.11625 .3725 Mdot
.5 .45375 Mdot
.5125 .46875 Mdot
.11625 .52875 Mdot
.4325 .53375 Mdot
.49 .54 Mdot
.45125 .54125 Mdot
.57875 .5525 Mdot
.46375 .55875 Mdot
.57125 .54625 Mdot
.465 .53375 Mdot
.4425 .5175 Mdot
.48875 .5075 Mdot
.525 .49875 Mdot
.5025 .4975 Mdot
.245 .51125 Mdot
.91 .5275 Mdot
.60125 .535 Mdot
.29375 .57125 Mdot
.42875 .58 Mdot
.415 .58 Mdot
.69375 .58375 Mdot
.3825 .57875 Mdot
.55625 .55625 Mdot
.50875 .56125 Mdot
.435 .56375 Mdot
.5575 .55875 Mdot
.55 .55625 Mdot
.45625 .51625 Mdot
.2225 .4975 Mdot
.8175 .48625 Mdot
.685 .4875 Mdot
.25375 .46375 Mdot
.5175 .47625 Mdot
.48125 .47625 Mdot
.47375 .47625 Mdot
.4625 .48125 Mdot
.54875 .50125 Mdot
.56875 .505 Mdot
.44125 .51125 Mdot
.5175 .54 Mdot
.46 .48125 Mdot
.51875 .395 Mdot
.255 .39375 Mdot
.73375 .40125 Mdot
.87 .39 Mdot
.16875 .45 Mdot
.4875 .53625 Mdot
.45375 .53 Mdot
.5625 .515 Mdot
.4675 .49375 Mdot
.505 .49 Mdot
.53 .47625 Mdot
.475 .48375 Mdot
.53375 .4875 Mdot
.485 .5275 Mdot
.485 .53125 Mdot
.06125 .53375 Mdot
.15375 .5375 Mdot
.4525 .5025 Mdot
.50625 .50625 Mdot
.51 .52875 Mdot
.445 .53375 Mdot
.56 .52 Mdot
.48625 .505 Mdot
.5825 .48 Mdot
.4125 .47375 Mdot
.51125 .47375 Mdot
.49875 .4925 Mdot
.3975 .46375 Mdot
.02 .4775 Mdot
.57875 .435 Mdot
.185 .41375 Mdot
.51625 .45875 Mdot
.495 .45375 Mdot
.4525 .46125 Mdot
.495 .47 Mdot
.51125 .43875 Mdot
.50375 .43375 Mdot
.48 .43875 Mdot
.4475 .41625 Mdot
.275 .415 Mdot
.4725 .34375 Mdot
.43625 .3225 Mdot
.6 .295 Mdot
.4225 .2925 Mdot
.55375 .36625 Mdot
.4025 .3975 Mdot
.5375 .4225 Mdot
.63125 .41 Mdot
.445 .38125 Mdot
.435 .345 Mdot
.3025 .31625 Mdot
.6 .31 Mdot
.945 .32875 Mdot
.1925 .35875 Mdot
.48125 .35 Mdot
.53125 .34 Mdot
.495 .28875 Mdot
.47375 .2725 Mdot
.4525 .26625 Mdot
.5875 .26125 Mdot
.48875 .2825 Mdot
.4425 .32 Mdot
.49375 .31875 Mdot
.55625 .29875 Mdot
.0575 .31125 Mdot
.225 .3 Mdot
.34 .2725 Mdot
.4475 .20125 Mdot
.59875 .10625 Mdot
.63875 .0575 Mdot
.4425 .0525 Mdot
.49 .0525 Mdot
.4875 .08875 Mdot
.4425 .105 Mdot
.54625 .1325 Mdot
.49125 .15625 Mdot
.215 .215 Mdot
.73875 .29125 Mdot
.8825 .385 Mdot
.12375 .41625 Mdot
.53375 .65375 Mdot
.57375 .63375 Mdot
.06875 .60375 Mdot
.185 .55375 Mdot
.44 .49375 Mdot
.49125 .49 Mdot
.47 .48 Mdot
.545 .4775 Mdot
.37875 .47625 Mdot
.84625 .5025 Mdot
.31375 .5125 Mdot
.435 .5175 Mdot
.495 .5125 Mdot
.53125 .49125 Mdot
.47875 .47 Mdot
.32 .4475 Mdot
.8175 .42875 Mdot
.57125 .415 Mdot
.36375 .425 Mdot
.4 .44625 Mdot
.445 .4675 Mdot
.66875 .5 Mdot
.3175 .51625 Mdot
.71125 .51875 Mdot
.445 .495 Mdot
.4325 .4525 Mdot
.56 .43125 Mdot
.535 .39875 Mdot
.4575 .41375 Mdot
.3 .41375 Mdot
.71 .43625 Mdot
.67 .445 Mdot
.29 .485 Mdot
.52625 .48625 Mdot
.48125 .51125 Mdot
.43 .52125 Mdot
.45625 .52125 Mdot
.695 .51375 Mdot
.4625 .51125 Mdot
.4625 .50125 Mdot
.5 .4675 Mdot
.46125 .45875 Mdot
.52375 .47875 Mdot
.31375 .475 Mdot
.6725 .475 Mdot
.7875 .4975 Mdot
.25875 .50125 Mdot
.49125 .47625 Mdot
.45625 .48 Mdot
.45875 .4725 Mdot
.51 .47875 Mdot
.6625 .475 Mdot
.44 .4875 Mdot
.46125 .48375 Mdot
.54125 .49 Mdot
.47 .4975 Mdot
.49375 .5075 Mdot
.14 .50375 Mdot
.255 .50375 Mdot
.47625 .4975 Mdot
.49875 .49625 Mdot
.49625 .50125 Mdot
.405 .515 Mdot
.575 .52375 Mdot
.575 .53 Mdot
.515 .525 Mdot
.4225 .51375 Mdot
.525 .54375 Mdot
.46875 .56875 Mdot
.405 .5475 Mdot
.16625 .54875 Mdot
.46625 .52625 Mdot
.32875 .49625 Mdot
.49375 .52125 Mdot
.49125 .54125 Mdot
.36875 .5475 Mdot
.6025 .50875 Mdot
.5525 .50375 Mdot
.455 .49125 Mdot
.485 .495 Mdot
.45 .4875 Mdot
.3375 .5025 Mdot
.0875 .465 Mdot
.49875 .42625 Mdot
.46125 .4175 Mdot
.54125 .425 Mdot
.45625 .45875 Mdot
.50125 .5025 Mdot
.35375 .525 Mdot
.6725 .535 Mdot
.6 .5325 Mdot
.44 .52375 Mdot
.4375 .48625 Mdot
.3375 .48125 Mdot
.57125 .4825 Mdot
.845 .48125 Mdot
.25125 .4725 Mdot
.5 .48625 Mdot
.525 .49375 Mdot
.4825 .50375 Mdot
.465 .50125 Mdot
.57625 .505 Mdot
.47625 .49375 Mdot
.495 .47875 Mdot
.4675 .4725 Mdot
.47875 .47875 Mdot
.5675 .48 Mdot
.13625 .48625 Mdot
.28625 .49 Mdot
.39875 .4675 Mdot
.42875 .44375 Mdot
.62125 .42875 Mdot
.615 .415 Mdot
.39875 .40125 Mdot
.5325 .415 Mdot
.44125 .42375 Mdot
.51375 .43125 Mdot
.51625 .4625 Mdot
.49 .48 Mdot
.23125 .5175 Mdot
.7125 .5675 Mdot
.8575 .595 Mdot
.11 .61375 Mdot
.515 .00625 Mdot
.53625 .02375 Mdot
.47875 .065 Mdot
.3775 .07875 Mdot
.7425 .11875 Mdot
.52875 .14375 Mdot
.41625 .08 Mdot
.46 .03375 Mdot
.3875 .0525 Mdot
.6125 .04375 Mdot
.64125 .0725 Mdot
.34 .04375 Mdot
.465 .02625 Mdot
.5275 .105 Mdot
.3275 .13875 Mdot
.62625 .16125 Mdot
.78875 .1625 Mdot
.29375 .04375 Mdot
.25875 .015 Mdot
.91 .06375 Mdot
.36 .1125 Mdot
.495 .13 Mdot
.4975 .13 Mdot
.49 .11 Mdot
.33875 .10125 Mdot
.64875 .0975 Mdot
.61625 .06375 Mdot
.43375 .05125 Mdot
.4525 .03625 Mdot
.45625 .00625 Mdot
.42 .06125 Mdot
.29625 .07375 Mdot
.9525 .09375 Mdot
.47125 .12375 Mdot
.38125 .1075 Mdot
.4975 .05 Mdot
.4975 .02 Mdot
.70125 .055 Mdot
.60875 .10875 Mdot
.38125 .17125 Mdot
.47375 .21125 Mdot
.49375 .22875 Mdot
.3925 .17875 Mdot
.93875 .135 Mdot
.22375 .1 Mdot
.495 .09625 Mdot
.4875 .115 Mdot
.5325 .12 Mdot
.4575 .1175 Mdot
.4775 .10625 Mdot
.2375 .09875 Mdot
.91375 .0925 Mdot
.5175 .1 Mdot
.41625 .1125 Mdot
.4275 .13875 Mdot
.37625 .15 Mdot
.565 .16375 Mdot
.7425 .16875 Mdot
.31 .16 Mdot
.55125 .14875 Mdot
.5025 .14375 Mdot
.4775 .15 Mdot
.3525 .155 Mdot
.745 .16 Mdot
.4575 .1725 Mdot
.44375 .185 Mdot
.4825 .18 Mdot
.48375 .23375 Mdot
.55 .25375 Mdot
.21125 .24125 Mdot
.9225 .21625 Mdot
.43125 .24125 Mdot
.395 .25 Mdot
.41625 .2375 Mdot
.6125 .24625 Mdot
.53 .2725 Mdot
.4725 .2625 Mdot
.615 .20375 Mdot
.37375 .22 Mdot
.5125 .23 Mdot
.50875 .2275 Mdot
.47125 .22875 Mdot
.33 .18375 Mdot
.64875 .09125 Mdot
.74875 .0025 Mdot
.4625 .99 Mdot
.4725 .90125 Mdot
.12 .84375 Mdot
.41125 .7375 Mdot
.385 .79125 Mdot
.44125 .84375 Mdot
.4125 .84625 Mdot
.5575 .8275 Mdot
.675 .78625 Mdot
.36 .7425 Mdot
.5475 .65625 Mdot
.50125 .58125 Mdot
.49 .5625 Mdot
.24375 .60375 Mdot
.905 .615 Mdot
.4225 .6425 Mdot
.41625 .69875 Mdot
.4825 .7275 Mdot
.49625 .74375 Mdot
.53375 .71125 Mdot
.3025 .71 Mdot
.7425 .7675 Mdot
.5175 .80375 Mdot
.41375 .81375 Mdot
.43125 .88875 Mdot
.59 .87875 Mdot
.41375 .83 Mdot
.58375 .78625 Mdot
.68875 .7375 Mdot
.30875 .65875 Mdot
.5175 .65 Mdot
.48125 .6475 Mdot
.4625 .6425 Mdot
.44375 .80125 Mdot
.5625 .97875 Mdot
.52 .0925 Mdot
.61 .05125 Mdot
.56 .08125 Mdot
.56 .2075 Mdot
.41 .1875 Mdot
.06875 .185 Mdot
.5175 .0075 Mdot
.38 .02625 Mdot
.6375 .08125 Mdot
.43375 .05 Mdot
.07875 .0025 Mdot
.48875 .12875 Mdot
.3375 .1075 Mdot
.4825 .11625 Mdot
.91375 .09375 Mdot
.3475 .02375 Mdot
.475 .03875 Mdot
.465 .15625 Mdot
.2675 .17875 Mdot
.5675 .20375 Mdot
.1775 .14875 Mdot
.45 .0075 Mdot
.4425 .05125 Mdot
.55125 .085 Mdot
.52875 .1125 Mdot
.5125 .17875 Mdot
.495 .20125 Mdot
.47125 .28 Mdot
.25 .31 Mdot
.70625 .3375 Mdot
.795 .33 Mdot
.28375 .2775 Mdot
.475 .15 Mdot
.53875 .085 Mdot
.44125 0 Mdot
.525 .0225 Mdot
.55875 .02875 Mdot
.47125 .03 Mdot
.50375 .09125 Mdot
.49625 .18 Mdot
.49625 .19375 Mdot
.12 .21375 Mdot
.9625 .28 Mdot
.63125 .3375 Mdot
.29 .30375 Mdot
.4375 .23 Mdot
.5575 .25 Mdot
.4975 .2625 Mdot
.54375 .27125 Mdot
.44625 .3 Mdot
.485 .39875 Mdot
.56125 .44125 Mdot
.4875 .52125 Mdot
.4725 .59 Mdot
.45875 .6375 Mdot
.00375 .6975 Mdot
.3175 .83125 Mdot
.35375 .8325 Mdot
.445 .80125 Mdot
.445 .7875 Mdot
.57375 .775 Mdot
.585 .8275 Mdot
.40875 .92875 Mdot
.5 .98 Mdot
.5125 .95625 Mdot
.405 .9575 Mdot
.565 .91125 Mdot
.57875 .855 Mdot
.4575 .87125 Mdot
.45625 .82375 Mdot
.56875 .82375 Mdot
.27125 .86875 Mdot
.69375 .945 Mdot
.52875 .90625 Mdot
.5175 .7125 Mdot
.57125 .5425 Mdot
.335 .33375 Mdot
.53875 .42875 Mdot
.57625 .4425 Mdot
.50875 .45 Mdot
.5025 .47625 Mdot
.4825 .48125 Mdot
.38125 .45875 Mdot
.575 .415 Mdot
.54875 .42625 Mdot
.44 .44125 Mdot
.08125 .4375 Mdot
.44 .57 Mdot
.49875 .56125 Mdot
.485 .59625 Mdot
.50125 .58625 Mdot
.54125 .59125 Mdot
.52625 .62625 Mdot
.495 .68625 Mdot
.5125 .65125 Mdot
.3825 .62375 Mdot
.64875 .62 Mdot
.43125 .59 Mdot
.105 .54875 Mdot
.16875 .58 Mdot
.46375 .58125 Mdot
.59 .59875 Mdot
.45125 .5825 Mdot
.42875 .58125 Mdot
.53 .59625 Mdot
.51 .5825 Mdot
.52875 .5625 Mdot
.46125 .5625 Mdot
.47625 .51 Mdot
.5325 .46375 Mdot
.31375 .44125 Mdot
.50875 .4275 Mdot
.895 .41375 Mdot
.33 .44875 Mdot
.44875 .47375 Mdot
.505 .4875 Mdot
.5075 .49625 Mdot
.5 .5225 Mdot
.46875 .525 Mdot
.435 .5325 Mdot
.62875 .53875 Mdot
.5 .52625 Mdot
.475 .4775 Mdot
.48 .455 Mdot
.22875 .42 Mdot
.595 .41125 Mdot
.08625 .42375 Mdot
.49625 .43875 Mdot
.49375 .47375 Mdot
.49375 .475 Mdot
.4975 .4775 Mdot
.47 .46875 Mdot
.48375 .47375 Mdot
.5525 .46 Mdot
.535 .43875 Mdot
.50125 .45125 Mdot
.44125 .41375 Mdot
.2525 .39375 Mdot
.71 .3925 Mdot
.81625 .41 Mdot
.285 .395 Mdot
.505 .45125 Mdot
.4975 .4725 Mdot
.45 .46375 Mdot
.48375 .45 Mdot
.5375 .42625 Mdot
.4825 .41625 Mdot
.48875 .4175 Mdot
.53 .42625 Mdot
.50125 .435 Mdot
.47125 .465 Mdot
.08375 .44 Mdot
.62625 .37 Mdot
.21125 .35125 Mdot
.4475 .31625 Mdot
.595 .31375 Mdot
.53125 .3225 Mdot
.4325 .335 Mdot
.4975 .3275 Mdot
.47 .32125 Mdot
.5875 .30625 Mdot
.46375 .2875 Mdot
.505 .34 Mdot
.42875 .38375 Mdot
.26375 .33875 Mdot
.33375 .245 Mdot
.44625 .18875 Mdot
.4425 .195 Mdot
.6375 .25875 Mdot
.49625 .25875 Mdot
.4475 .225 Mdot
.53875 .14125 Mdot
.515 .115 Mdot
.49375 .06125 Mdot
.0725 .035 Mdot
.3875 .0975 Mdot
.3475 .0675 Mdot
.5 .03875 Mdot
.5 .085 Mdot
.505 .16 Mdot
.4625 .1775 Mdot
.4725 .1825 Mdot
.6275 .19 Mdot
.49125 .17 Mdot
.4275 .1175 Mdot
.55875 .115 Mdot
.21875 .09875 Mdot
.72125 .06875 Mdot
.8475 .0475 Mdot
.63625 .0425 Mdot
.4575 .13375 Mdot
.51125 .2225 Mdot
.385 .3275 Mdot
.52625 .54125 Mdot
.495 .53 Mdot
.46375 .5375 Mdot
.6625 .53375 Mdot
.445 .51625 Mdot
.38875 .4825 Mdot
.56125 .47375 Mdot
.5275 .49125 Mdot
.4725 .4775 Mdot
.175 .4725 Mdot
.075 .57 Mdot
.4525 .5925 Mdot
.485 .62625 Mdot
.49375 .62125 Mdot
.46875 .6 Mdot
.475 .56625 Mdot
.6325 .51625 Mdot
.565 .49625 Mdot
.41375 .49625 Mdot
.3875 .5225 Mdot
.69125 .5325 Mdot
.395 .54375 Mdot
.18 .5075 Mdot
.2325 .51375 Mdot
.4775 .48625 Mdot
.5825 .4625 Mdot
.46125 .47 Mdot
.43625 .44 Mdot
.465 .41125 Mdot
.5475 .42375 Mdot
.60875 .45125 Mdot
.4125 .4675 Mdot
.4475 .5 Mdot
.55 .48875 Mdot
.3725 .455 Mdot
.49625 .4225 Mdot
.76375 .42875 Mdot
.43 .41125 Mdot
.42875 .4325 Mdot
.50375 .4675 Mdot
.53375 .495 Mdot
.47 .4625 Mdot
.42 .47 Mdot
.53875 .47 Mdot
.62625 .465 Mdot
.46375 .465 Mdot
.45875 .5225 Mdot
.4675 .53875 Mdot
.3375 .5325 Mdot
.56 .53 Mdot
.95125 .53625 Mdot
.17125 .51 Mdot
.49875 .4975 Mdot
.4975 .49875 Mdot
.52625 .4925 Mdot
.48 .47125 Mdot
.39 .44875 Mdot
.605 .425 Mdot
.52625 .4125 Mdot
.495 .41125 Mdot
.49875 .4475 Mdot
.47625 .5 Mdot
.31125 .50375 Mdot
.6525 .51 Mdot
.7425 .505 Mdot
.33 .4725 Mdot
.52125 .41625 Mdot
.475 .42 Mdot
.4725 .42375 Mdot
.46875 .425 Mdot
.48875 .4275 Mdot
.63375 .44875 Mdot
.40875 .465 Mdot
.5 .475 Mdot
.51875 .50125 Mdot
.485 .52375 Mdot
.1625 .52375 Mdot
.94625 .52375 Mdot
.58875 .51625 Mdot
.28125 .50875 Mdot
.45375 .4975 Mdot
.59 .49625 Mdot
.46375 .48875 Mdot
.57 .4975 Mdot
.48125 .4925 Mdot
.43 .4875 Mdot
.57375 .4925 Mdot
.4725 .48625 Mdot
.49125 .46125 Mdot
.46125 .445 Mdot
.0125 .4325 Mdot
.30375 .4575 Mdot
.35625 .49125 Mdot
.44875 .53 Mdot
.4275 .54125 Mdot
.57125 .49875 Mdot
.63125 .48125 Mdot
.4325 .47125 Mdot
.515 .455 Mdot
.48375 .455 Mdot
.51625 .49125 Mdot
.10125 .5025 Mdot
.435 .49 Mdot
.3525 .4925 Mdot
.51125 .48875 Mdot
.4925 .47 Mdot
.5025 .44375 Mdot
.405 .42625 Mdot
.5775 .43125 Mdot
.605 .43875 Mdot
.46 .4575 Mdot
.4275 .51375 Mdot
.57125 .545 Mdot
.2475 .55 Mdot
.71875 .55125 Mdot
.7825 .54 Mdot
.2425 .51875 Mdot
.4875 .515 Mdot
.4725 .50125 Mdot
.41375 .4975 Mdot
.64875 .5125 Mdot
.41375 .5025 Mdot
.6 .505 Mdot
.37125 .53875 Mdot
.52625 .06125 Mdot
.4725 .01625 Mdot
.53125 .0125 Mdot
.48875 .075 Mdot
.5075 .07125 Mdot
.31125 .08875 Mdot
.41625 .0375 Mdot
.695 .11125 Mdot
.665 .065 Mdot
.325 .05625 Mdot
.645 .04875 Mdot
.40375 .06125 Mdot
.30375 .1425 Mdot
.9125 .1875 Mdot
.32875 .25375 Mdot
.48625 .21375 Mdot
.5625 .21125 Mdot
.4775 .20625 Mdot
.44125 .2025 Mdot
.39875 .1775 Mdot
.5775 .135 Mdot
.71125 .09125 Mdot
.33 .07625 Mdot
.45125 .115 Mdot
.56 .215 Mdot
.37125 .31625 Mdot
.5425 .385 Mdot
.645 .37125 Mdot
.49375 .33 Mdot
.43875 .225 Mdot
.49625 .14375 Mdot
.52375 .08875 Mdot
.46375 .125 Mdot
.38 .12375 Mdot
.66125 .12875 Mdot
.615 .11375 Mdot
.40125 .115 Mdot
.45875 .0675 Mdot
.43875 .0775 Mdot
.45875 .12375 Mdot
.51875 .13125 Mdot
.8 .14125 Mdot
.275 .17125 Mdot
.49875 .165 Mdot
.49375 .14 Mdot
.53625 .16 Mdot
.48625 .20625 Mdot
.31625 .24625 Mdot
.7475 .27125 Mdot
.45 .3175 Mdot
.48625 .345 Mdot
.49625 .32125 Mdot
.48375 .32625 Mdot
.4 .31875 Mdot
.55875 .29 Mdot
.68875 .27625 Mdot
.39375 .27875 Mdot
.5175 .26625 Mdot
.46875 .27375 Mdot
.48375 .26 Mdot
.45625 .2225 Mdot
.3775 .2025 Mdot
.86875 .15375 Mdot
.28375 .105 Mdot
.50625 .085 Mdot
.53 .09125 Mdot
.47625 .07625 Mdot
.2625 .09375 Mdot
.82625 .1175 Mdot
.53125 .17625 Mdot
.34625 .2025 Mdot
.46 .23 Mdot
.61125 .2375 Mdot
.29375 .25625 Mdot
.83875 .23 Mdot
.42375 .20875 Mdot
.37625 .1875 Mdot
.5575 .175 Mdot
.49 .1425 Mdot
.49 .19125 Mdot
.4775 .20125 Mdot
.13125 .21 Mdot
.33875 .225 Mdot
.39375 .1525 Mdot
.47 .1325 Mdot
.4 .1325 Mdot
.45875 .15 Mdot
.9 .16875 Mdot
.325 .20875 Mdot
.4525 .24 Mdot
.495 .30125 Mdot
.52375 .3075 Mdot
.21625 .305 Mdot
.88375 .29875 Mdot
.46 .29375 Mdot
.4075 .23375 Mdot
.50375 .21875 Mdot
.48625 .2075 Mdot
.49625 .1925 Mdot
.34375 .2075 Mdot
.71875 .2325 Mdot
.56875 .2475 Mdot
.4125 .2525 Mdot
.44375 .27625 Mdot
.56375 .2675 Mdot
.2975 .26875 Mdot
.66125 .2875 Mdot
.72 .30375 Mdot
.3225 .3075 Mdot
.48125 .29875 Mdot
.47375 .31125 Mdot
.4225 .3075 Mdot
.6375 .29 Mdot
.3175 .25375 Mdot
.8075 .2175 Mdot
.2775 .14625 Mdot
.875 .9775 Mdot
.41 .90125 Mdot
.46375 .93375 Mdot
.49125 .99 Mdot
.4975 .98375 Mdot
.4675 .95125 Mdot
.48125 .8575 Mdot
.4425 .90125 Mdot
.3025 .91375 Mdot
.18125 .9975 Mdot
.68875 .94875 Mdot
.49 .84125 Mdot
.41625 .67875 Mdot
.475 .54375 Mdot
.5825 .5425 Mdot
.175 .56625 Mdot
.41125 .72 Mdot
.3125 .88625 Mdot
.53375 .9525 Mdot
.49875 1 Mdot
.275 .96375 Mdot
.9075 .92875 Mdot
.40125 .8825 Mdot
.44375 .86875 Mdot
.46625 .7875 Mdot
.37625 .75875 Mdot
.345 .73625 Mdot
.19625 .58875 Mdot
.46125 .6075 Mdot
.48 .61875 Mdot
.52875 .62 Mdot
.30875 .6225 Mdot
.74375 .625 Mdot
.48 .63875 Mdot
.44625 .635 Mdot
.50125 .64 Mdot
.47 .6125 Mdot
.51375 .58 Mdot
.27 .55 Mdot
.81 .49875 Mdot
.60875 .4375 Mdot
.34625 .4425 Mdot
.455 .48375 Mdot
.5525 .5225 Mdot
.3575 .49875 Mdot
.5775 .4575 Mdot
.6825 .415 Mdot
.39625 .36125 Mdot
.47 .35125 Mdot
.48375 .365 Mdot
.43875 .34125 Mdot
.5975 .52 Mdot
.2475 .70875 Mdot
.9975 .83875 Mdot
.54125 .23875 Mdot
.47375 .2425 Mdot
.04 .2325 Mdot
.38125 .1725 Mdot
.34125 .10875 Mdot
.4725 .0775 Mdot
.48375 .055 Mdot
.5525 .055 Mdot
.51 .06375 Mdot
.525 .0325 Mdot
.455 .01625 Mdot
.50125 .05625 Mdot
.475 .15 Mdot
.19875 .14625 Mdot
.8125 .1925 Mdot
.91125 .23 Mdot
.09375 .1125 Mdot
.5525 .005 Mdot
.52 .01875 Mdot
.4675 .08625 Mdot
.47125 .15625 Mdot
.31375 .1725 Mdot
.60875 .1775 Mdot
.84875 .23625 Mdot
.2375 .27875 Mdot
.44875 .2375 Mdot
.5275 .26125 Mdot
.4675 .2575 Mdot
.57 .22875 Mdot
.4925 .14875 Mdot
.4725 .1575 Mdot
.52125 .10875 Mdot
.49625 .10875 Mdot
.45875 .17375 Mdot
.49125 .22125 Mdot
.26875 .235 Mdot
.965 .2475 Mdot
.55875 .2475 Mdot
.26625 .19625 Mdot
.48125 .1825 Mdot
.40125 .18125 Mdot
.65125 .2525 Mdot
.4325 .30375 Mdot
.56625 .365 Mdot
.4175 .4075 Mdot
.52875 .40125 Mdot
.51875 .3425 Mdot
.50625 .39375 Mdot
.4825 .45 Mdot
.185 .4625 Mdot
.39875 .6275 Mdot
.40375 .6125 Mdot
.495 .5375 Mdot
.50625 .5275 Mdot
.5025 .49875 Mdot
.47375 .46375 Mdot
.565 .47625 Mdot
.47875 .55 Mdot
.51875 .605 Mdot
.46375 .69875 Mdot
.495 .7725 Mdot
.395 .76875 Mdot
.25625 .755 Mdot
.07875 .69125 Mdot
.50125 .62875 Mdot
.51625 .565 Mdot
.5 .58375 Mdot
.46375 .68625 Mdot
.54875 .7775 Mdot
.4875 .8675 Mdot
.115 .9725 Mdot
.43875 .76625 Mdot
.24 .655 Mdot
.5075 .5975 Mdot
.51375 .5825 Mdot
.50625 .505 Mdot
.46625 .51875 Mdot
.43 .5825 Mdot
.64125 .62375 Mdot
.47125 .67375 Mdot
.48375 .77 Mdot
.48125 .80875 Mdot
.38375 .84875 Mdot
.17375 .8625 Mdot
.0675 .95875 Mdot
.4925 .95 Mdot
.50875 .945 Mdot
.41375 .96125 Mdot
.59125 .97875 Mdot
.5075 .97625 Mdot
.165 .84375 Mdot
.0625 .4175 Mdot
.51875 .4125 Mdot
.49125 .41375 Mdot
.01 .41125 Mdot
.36625 .38125 Mdot
.315 .35 Mdot
.47625 .31625 Mdot
.5025 .29875 Mdot
.52875 .30625 Mdot
.495 .325 Mdot
.515 .3775 Mdot
.46 .425 Mdot
.465 .45375 Mdot
.51625 .48375 Mdot
.535 .51 Mdot
.45125 .50375 Mdot
.1875 .52125 Mdot
.82375 .5475 Mdot
.985 .54375 Mdot
.02375 .54125 Mdot
.4525 .565 Mdot
.6325 .5625 Mdot
.38 .5675 Mdot
.51125 .55875 Mdot
.5225 .55625 Mdot
.53125 .54625 Mdot
.52125 .52625 Mdot
.52625 .49875 Mdot
.475 .49 Mdot
.50625 .4825 Mdot
.2375 .445 Mdot
.67875 .43375 Mdot
.8625 .42375 Mdot
.1775 .38625 Mdot
.47875 .35625 Mdot
.4825 .35125 Mdot
.52375 .34625 Mdot
.56 .3475 Mdot
.49875 .3825 Mdot
.42 .3925 Mdot
.56875 .4175 Mdot
.485 .43125 Mdot
.43625 .43375 Mdot
.47875 .4325 Mdot
.27875 .41625 Mdot
.54375 .375 Mdot
.235 .3675 Mdot
.47 .3525 Mdot
.4125 .35375 Mdot
.66375 .345 Mdot
.435 .35 Mdot
.48875 .33625 Mdot
.47125 .345 Mdot
.5175 .38 Mdot
.54125 .4075 Mdot
.4925 .40125 Mdot
.485 .35375 Mdot
.15625 .32 Mdot
.4125 .22125 Mdot
.3975 .195 Mdot
.47 .2325 Mdot
.50625 .225 Mdot
.52125 .225 Mdot
.45375 .23375 Mdot
.6025 .2375 Mdot
.44 .21625 Mdot
.505 .21 Mdot
.4725 .16875 Mdot
.4975 .19875 Mdot
.3325 .18125 Mdot
.32375 .19 Mdot
.53875 .205 Mdot
.48375 .21125 Mdot
.53 .18625 Mdot
.50875 .1325 Mdot
.43875 .10625 Mdot
.5125 .095 Mdot
.47875 .055 Mdot
.4625 .13125 Mdot
.56625 .16 Mdot
.065 .19625 Mdot
.44375 .30125 Mdot
.21375 .2675 Mdot
.47875 .29125 Mdot
.5375 .2875 Mdot
.4775 .29125 Mdot
.46625 .27375 Mdot
.50375 .25625 Mdot
.525 .24875 Mdot
.49375 .22625 Mdot
.5275 .19 Mdot
.4675 .23875 Mdot
.40125 .21625 Mdot
.03375 .19125 Mdot
.01375 .17625 Mdot
.40375 .0825 Mdot
.51875 .0625 Mdot
.50625 .06875 Mdot
.48375 .06375 Mdot
.5025 .06875 Mdot
.51125 .07125 Mdot
.5075 .07375 Mdot
.505 .06875 Mdot
.45875 .10375 Mdot
.525 .1125 Mdot
.14375 .075 Mdot
.85875 .045 Mdot
.4925 .06125 Mdot
.48 .14375 Mdot
.1 .225 Mdot
.0075 .395 Mdot
.49875 .545 Mdot
.5075 .52375 Mdot
.09875 .50875 Mdot
.4 .49875 Mdot
.34375 .44 Mdot
.5075 .45625 Mdot
.505 .45625 Mdot
.5 .4525 Mdot
.405 .4325 Mdot
.61375 .4425 Mdot
.50125 .44875 Mdot
.41 .4575 Mdot
.51125 .45 Mdot
.5475 .45125 Mdot
.48625 .45375 Mdot
.2525 .4375 Mdot
.71625 .42375 Mdot
.895 .42625 Mdot
.12625 .4525 Mdot
.4725 .44875 Mdot
.57 .465 Mdot
.41 .49875 Mdot
.47 .5325 Mdot
.54375 .50875 Mdot
.61 .47375 Mdot
.47125 .44625 Mdot
.52625 .42875 Mdot
.48125 .40125 Mdot
.48875 .42375 Mdot
.295 .4625 Mdot
.65375 .48875 Mdot
.795 .48375 Mdot
.22 .505 Mdot
.50625 .5425 Mdot
.46625 .55375 Mdot
.495 .56125 Mdot
.55125 .5925 Mdot
.55 .57875 Mdot
.4 .535 Mdot
.57375 .5325 Mdot
.4775 .5425 Mdot
.4375 .545 Mdot
.49375 .5625 Mdot
.3425 .56375 Mdot
.9175 .55125 Mdot
.5425 .52875 Mdot
.2575 .5125 Mdot
.48 .48375 Mdot
.45125 .4825 Mdot
.62 .49 Mdot
.41625 .4825 Mdot
.57 .4675 Mdot
.4275 .4675 Mdot
.5125 .45625 Mdot
.54375 .4425 Mdot
.46125 .44125 Mdot
.515 .44875 Mdot
.25375 .4725 Mdot
.94125 .4825 Mdot
.39625 .48875 Mdot
.45 .4975 Mdot
.46875 .475 Mdot
.48625 .435 Mdot
.4625 .44 Mdot
.50625 .43875 Mdot
.6625 .4375 Mdot
.41125 .45 Mdot
.4825 .4825 Mdot
.4775 .4825 Mdot
.50125 .47375 Mdot
.35 .48125 Mdot
.37625 .49375 Mdot
.06125 .49875 Mdot
.5325 .5 Mdot
.47 .4875 Mdot
.52625 .47875 Mdot
.50375 .47625 Mdot
.515 .4825 Mdot
.4775 .45625 Mdot
.455 .46 Mdot
.48 .4825 Mdot
.5625 .485 Mdot
.115 .47625 Mdot
.4625 .50875 Mdot
.2575 .49375 Mdot
.48875 .49 Mdot
.525 .4975 Mdot
.49125 .49375 Mdot
.42125 .5075 Mdot
.5225 .49875 Mdot
.57875 .475 Mdot
.485 .4575 Mdot
.50625 .49 Mdot
.49 .5 Mdot
.39 .51625 Mdot
.11125 .55625 Mdot
.0475 .57 Mdot
.40875 .5725 Mdot
.54625 .595 Mdot
.48625 .59 Mdot
.47625 .5925 Mdot
.5175 .57375 Mdot
.56 .5725 Mdot
.47 .56875 Mdot
.49125 .57 Mdot
.46625 .56875 Mdot
.51625 .5675 Mdot
.215 .555 Mdot
.77875 .54125 Mdot
.77125 .5375 Mdot
.26625 .54 Mdot
.48 .55125 Mdot
.48875 .58875 Mdot
.4725 .59125 Mdot
.44625 .58375 Mdot
.5875 .57625 Mdot
.57125 .56875 Mdot
.43875 .53125 Mdot
.50125 .51625 Mdot
.48875 .4975 Mdot
.48625 .5 Mdot
.135 .49 Mdot
.0925 .4825 Mdot
.5 .13625 Mdot
.51 .1975 Mdot
.215 .20375 Mdot
.975 .205 Mdot
.44 .235 Mdot
.37375 .245 Mdot
.52125 .19 Mdot
.50375 .1725 Mdot
.50375 .165 Mdot
.2925 .165 Mdot
.7575 .1425 Mdot
.52375 .1125 Mdot
.36375 .11 Mdot
.49625 .08875 Mdot
.53 .08125 Mdot
.54125 .1225 Mdot
.30125 .15375 Mdot
.6425 .19625 Mdot
.79625 .24875 Mdot
.22125 .265 Mdot
.48875 .2625 Mdot
.5325 .28875 Mdot
.4325 .27875 Mdot
.39125 .29125 Mdot
.6025 .3175 Mdot
.6875 .335 Mdot
.39375 .3475 Mdot
.54375 .35375 Mdot
.47375 .325 Mdot
.49 .29375 Mdot
.3625 .26 Mdot
.61375 .2125 Mdot
.69625 .18625 Mdot
.29625 .1825 Mdot
.5125 .15375 Mdot
.4525 .12 Mdot
.52 .11 Mdot
.4275 .0825 Mdot
.69875 .07125 Mdot
.41 .07625 Mdot
.5225 .07625 Mdot
.47125 .07625 Mdot
.44 .12625 Mdot
.50875 .1325 Mdot
.39125 .14625 Mdot
.80875 .17 Mdot
.51625 .18875 Mdot
.325 .17125 Mdot
.49 .17375 Mdot
.46875 .18125 Mdot
.56875 .17375 Mdot
.37 .175 Mdot
.7275 .1625 Mdot
.34375 .1425 Mdot
.4975 .11 Mdot
.555 .08125 Mdot
.4575 .0975 Mdot
.5375 .10875 Mdot
.315 .08375 Mdot
.8 .085 Mdot
.45125 .1125 Mdot
.46625 .07625 Mdot
.4575 .0775 Mdot
.49125 .14375 Mdot
.3925 .14625 Mdot
.54875 .145 Mdot
.785 .1525 Mdot
.32 .1425 Mdot
.48125 .1125 Mdot
.47 .1125 Mdot
.50375 .155 Mdot
.37375 .175 Mdot
.46125 .1825 Mdot
.9675 .20625 Mdot
.18375 .25875 Mdot
.5325 .2775 Mdot
.4425 .29625 Mdot
.5325 .31625 Mdot
.4575 .3325 Mdot
.62375 .31375 Mdot
.4425 .31625 Mdot
.46 .36 Mdot
.4725 .3975 Mdot
.5375 .44625 Mdot
.2675 .4775 Mdot
.91625 .46875 Mdot
.535 .43625 Mdot
.32125 .42625 Mdot
.47875 .38875 Mdot
.5075 .36875 Mdot
.4975 .32 Mdot
.33625 .29375 Mdot
.61 .27 Mdot
.61375 .285 Mdot
.4475 .3075 Mdot
.545 .3025 Mdot
.45125 .32875 Mdot
.4025 .30625 Mdot
.20875 .29375 Mdot
.24625 .3075 Mdot
.4 .285 Mdot
.53125 .31125 Mdot
.48 .3025 Mdot
.43625 .31125 Mdot
.55375 .32875 Mdot
.67875 .3375 Mdot
.36875 .33875 Mdot
.48125 .34 Mdot
.48125 .34875 Mdot
.515 .35625 Mdot
.2875 .3675 Mdot
.65375 .38625 Mdot
.7525 .405 Mdot
.3275 .4 Mdot
.48625 .41375 Mdot
.4725 .41 Mdot
.48625 .405 Mdot
.30875 .41 Mdot
.82375 .40125 Mdot
.4825 .38125 Mdot
.425 .38375 Mdot
.50625 .39375 Mdot
.49 .40375 Mdot
.47625 .35875 Mdot
.23125 .32375 Mdot
.18125 .2 Mdot
.3275 .985 Mdot
.495 .90625 Mdot
.51875 .8325 Mdot
.43 .76625 Mdot
.33125 .73625 Mdot
.65375 .7275 Mdot
.7725 .715 Mdot
.30125 .7425 Mdot
.53875 .79375 Mdot
.50625 .8725 Mdot
.47625 .87875 Mdot
.41875 .85875 Mdot
.58375 .8575 Mdot
.615 .86875 Mdot
.3525 .8275 Mdot
.50875 .83375 Mdot
.46875 .82625 Mdot
.54 .81375 Mdot
.3025 .83625 Mdot
.81625 .85625 Mdot
.45375 .86625 Mdot
.44125 .945 Mdot
.5025 .9625 Mdot
.3925 .89125 Mdot
.4925 .8425 Mdot
.5 .7575 Mdot
.49375 .74625 Mdot
.33375 .75875 Mdot
.91625 .79125 Mdot
.2325 .83875 Mdot
.49 .9625 Mdot
.46375 .995 Mdot
.47875 .88875 Mdot
.31875 .83375 Mdot
.62125 .79375 Mdot
.87375 .72125 Mdot
.24 .70875 Mdot
.48 .72125 Mdot
.46 .81125 Mdot
.51875 .87 Mdot
.4 .85875 Mdot
.52125 .86125 Mdot
.7725 .8275 Mdot
.30375 .70375 Mdot
.525 .58625 Mdot
.4275 .5575 Mdot
.51125 .55 Mdot
.43625 .54625 Mdot
.71 .55375 Mdot
.43125 .6175 Mdot
.45125 .655 Mdot
.45625 .6825 Mdot
.55125 .705 Mdot
.37375 .66375 Mdot
.69625 .575 Mdot
.5725 .5125 Mdot
.3875 .395 Mdot
.47875 .31125 Mdot
.505 .25375 Mdot
.48375 .23625 Mdot
.25375 .185 Mdot
.7575 .185 Mdot
.59375 .1475 Mdot
.37375 .1575 Mdot
.59875 .19375 Mdot
.42375 .3225 Mdot
.45625 .38 Mdot
.27625 .40125 Mdot
.90875 .40375 Mdot
.525 .37125 Mdot
.3375 .26875 Mdot
.52625 .19 Mdot
.46625 .16 Mdot
.38375 .15 Mdot
.5725 .13875 Mdot
.81125 .1325 Mdot
.26 .1375 Mdot
.4975 .15375 Mdot
.495 .1775 Mdot
.5025 .26 Mdot
.35375 .2775 Mdot
.53625 .28375 Mdot
.74625 .27875 Mdot
.41625 .23625 Mdot
.4525 .1075 Mdot
.45875 .02125 Mdot
.19875 .01 Mdot
.97875 .02875 Mdot
.43875 .07625 Mdot
.4025 .13 Mdot
.51375 .15 Mdot
.48875 .21125 Mdot
.47375 .39125 Mdot
.31625 .57 Mdot
.92125 .7825 Mdot
.4825 .3975 Mdot
.51875 .36875 Mdot
.47625 .405 Mdot
.5725 .435 Mdot
.47375 .42375 Mdot
.47875 .46375 Mdot
.54625 .445 Mdot
.48125 .43875 Mdot
.50375 .44875 Mdot
.1275 .45125 Mdot
.965 .465 Mdot
.5825 .48625 Mdot
.265 .42375 Mdot
.45375 .34875 Mdot
.565 .26375 Mdot
.56875 .1925 Mdot
.45875 .19125 Mdot
.53375 .23625 Mdot
.515 .30375 Mdot
.47125 .425 Mdot
.47375 .53125 Mdot
.50625 .57875 Mdot
.43875 .64375 Mdot
.2675 .68 Mdot
.70625 .69625 Mdot
.84625 .7325 Mdot
.2375 .74875 Mdot
.54125 .73875 Mdot
.5 .7325 Mdot
.4525 .7675 Mdot
.48375 .81375 Mdot
.5475 .8575 Mdot
.58 .87375 Mdot
.38375 .89 Mdot
.50625 .8975 Mdot
.48875 .87875 Mdot
.535 .8625 Mdot
.19875 .8675 Mdot
.935 .88 Mdot
.46125 .89875 Mdot
.43125 .87125 Mdot
.46875 .82375 Mdot
.44 .70625 Mdot
.525 .65375 Mdot
.5225 .61375 Mdot
.55 .6325 Mdot
.49625 .705 Mdot
.45 .8125 Mdot
.49 .88875 Mdot
.51375 .94125 Mdot
.4425 .95625 Mdot
.30125 .92 Mdot
.145 .8325 Mdot
.4975 .75375 Mdot
.50625 .7025 Mdot
.52875 .62125 Mdot
.58875 .57125 Mdot
.41125 .57625 Mdot
.5275 .58875 Mdot
.50375 .60375 Mdot
.52625 .6675 Mdot
.47375 .755 Mdot
.46625 .8075 Mdot
.25875 .87625 Mdot
.70875 .935 Mdot
.52875 .94 Mdot
.435 .9425 Mdot
.5775 .91875 Mdot
.5675 .925 Mdot
.42375 .985 Mdot
.42 .965 Mdot
.48875 .87625 Mdot
.53 .8075 Mdot
.4325 .8075 Mdot
.55875 .88625 Mdot
.5675 .985 Mdot
.75 .8 Mdot
.3375 .59375 Mdot
.5 .26375 Mdot
.52625 .26625 Mdot
.5175 .2475 Mdot
.47 .24125 Mdot
.4975 .265 Mdot
.50625 .2825 Mdot
.54625 .3 Mdot
.47625 .3625 Mdot
.50875 .40375 Mdot
.07625 .40625 Mdot
.58125 .39125 Mdot
.2375 .36125 Mdot
.45125 .3425 Mdot
.505 .3475 Mdot
.645 .345 Mdot
.47 .36 Mdot
.51375 .35875 Mdot
.435 .34875 Mdot
.515 .3275 Mdot
.505 .30625 Mdot
.515 .30875 Mdot
.4225 .305 Mdot
.20375 .28875 Mdot
.7975 .29375 Mdot
.8475 .28375 Mdot
.215 .25375 Mdot
.52625 .2175 Mdot
.49375 .17125 Mdot
.44 .11 Mdot
.54625 .09125 Mdot
.4725 .06375 Mdot
.59 .0475 Mdot
.4425 .0625 Mdot
.46875 .06 Mdot
.5075 .1225 Mdot
.5175 .15 Mdot
.15 .14125 Mdot
.45875 .11375 Mdot
.42125 .04125 Mdot
.43 .0075 Mdot
.4525 .03875 Mdot
.51375 .07375 Mdot
.55625 .11875 Mdot
.525 .1425 Mdot
.47125 .1325 Mdot
.47375 .11625 Mdot
.49625 .09625 Mdot
.5225 .09625 Mdot
.43625 .09 Mdot
.23 .12125 Mdot
.10875 .16375 Mdot
.51375 .1775 Mdot
.4725 .19625 Mdot
.53625 .20125 Mdot
.60375 .1925 Mdot
.42 .18625 Mdot
.47625 .175 Mdot
.52875 .18125 Mdot
.5125 .1825 Mdot
.48 .19625 Mdot
.47125 .2325 Mdot
.24375 .2125 Mdot
.76625 .18375 Mdot
.7825 .15375 Mdot
.26125 .105 Mdot
.49375 .05125 Mdot
.455 .035 Mdot
.51125 .03125 Mdot
.54375 .01875 Mdot
.49125 .0375 Mdot
.46125 .04375 Mdot
.53125 .06625 Mdot
.4725 .0575 Mdot
.48125 .10375 Mdot
.47125 .105 Mdot
.3825 .10125 Mdot
.78625 .08 Mdot
.495 .0825 Mdot
.39875 .05875 Mdot
.4975 .06 Mdot
.5 .06625 Mdot
.49 .08625 Mdot
.46875 .07375 Mdot
.55625 .04625 Mdot
.475 .0225 Mdot
.455 .06625 Mdot
.16 .12875 Mdot
.46875 .16375 Mdot
.36625 .11875 Mdot
.6175 .06125 Mdot
.38375 .07625 Mdot
.53125 .12625 Mdot
.44625 .24 Mdot
.35875 .3375 Mdot
.96625 .39875 Mdot
.2875 .40375 Mdot
.47 .40875 Mdot
.49 .4125 Mdot
.24 .36125 Mdot
.6375 .28 Mdot
.99375 .2 Mdot
.10375 .095 Mdot
.47125 .0075 Mdot
.50625 .02375 Mdot
.10875 .065 Mdot
.42125 .14125 Mdot
.35 .01 Mdot
.50875 .00875 Mdot
.48125 .07 Mdot
.58 .14125 Mdot
.39875 .1975 Mdot
.50875 .4575 Mdot
.5075 .47125 Mdot
.51375 .4825 Mdot
.59125 .4825 Mdot
.4275 .48125 Mdot
.49125 .5 Mdot
.52875 .49875 Mdot
.4925 .5 Mdot
.51125 .485 Mdot
.1625 .4725 Mdot
.93875 .455 Mdot
.54375 .40875 Mdot
.29375 .365 Mdot
.4875 .3475 Mdot
.47 .3675 Mdot
.6 .395 Mdot
.46375 .42875 Mdot
.62625 .46875 Mdot
.39625 .49625 Mdot
.505 .485 Mdot
.49875 .46875 Mdot
.505 .4725 Mdot
.43875 .47625 Mdot
.24875 .46125 Mdot
.78125 .43625 Mdot
.7625 .44125 Mdot
.25625 .43875 Mdot
.53125 .4275 Mdot
.48875 .42625 Mdot
.415 .435 Mdot
.565 .41875 Mdot
.555 .4225 Mdot
.53875 .43375 Mdot
.41875 .46375 Mdot
.47125 .49875 Mdot
.50875 .49 Mdot
.52625 .4975 Mdot
.19125 .4675 Mdot
.9475 .45875 Mdot
.47 .4525 Mdot
.4425 .48875 Mdot
.43 .4925 Mdot
.43625 .5025 Mdot
.495 .4925 Mdot
.5475 .48 Mdot
.63 .46625 Mdot
.40875 .47125 Mdot
.47375 .49125 Mdot
.51625 .5025 Mdot
.48875 .54375 Mdot
.46625 .5375 Mdot
.245 .50875 Mdot
.17 .52 Mdot
.5125 .4775 Mdot
.45625 .47125 Mdot
.54375 .4875 Mdot
.56625 .51375 Mdot
.43625 .5 Mdot
.52375 .5075 Mdot
.53125 .515 Mdot
.47 .52375 Mdot
.4975 .51875 Mdot
.50125 .53375 Mdot
.27375 .5275 Mdot
.725 .525 Mdot
.70875 .51 Mdot
.30625 .48875 Mdot
.5125 .465 Mdot
.45375 .465 Mdot
.48625 .47125 Mdot
.5175 .48 Mdot
.54125 .4725 Mdot
.50375 .46125 Mdot
.48875 .45375 Mdot
.4575 .46375 Mdot
.48375 .46375 Mdot
.51125 .4775 Mdot
.37 .50125 Mdot
.73125 .51375 Mdot
.5375 .50625 Mdot
.39125 .5125 Mdot
.48875 .51125 Mdot
.50625 .505 Mdot
.48 .50375 Mdot
.40875 .5025 Mdot
.66625 .4925 Mdot
.46 .4825 Mdot
.4925 .4725 Mdot
.47875 .47875 Mdot
.49375 .40875 Mdot
.18 .34625 Mdot
.9875 .33625 Mdot
.42125 .3375 Mdot
.37625 .33625 Mdot
.60875 .38 Mdot
.3725 .44 Mdot
.53625 .47 Mdot
.45375 .43875 Mdot
.38875 .38125 Mdot
.9475 .35625 Mdot
.335 .31125 Mdot
.44 .27625 Mdot
.5125 .29125 Mdot
.22375 .33625 Mdot
.63375 .385 Mdot
.94 .4525 Mdot
.15125 .48375 Mdot
.56875 .51125 Mdot
.4325 .525 Mdot
.50625 .575 Mdot
.4375 .61625 Mdot
.44125 .61375 Mdot
.78375 .6125 Mdot
.3625 .61875 Mdot
.47 .57 Mdot
.46875 .5075 Mdot
.5125 .51375 Mdot
.1425 .5 Mdot
.41625 .48 Mdot
.37875 .48125 Mdot
.45875 .47375 Mdot
.5125 .48625 Mdot
.47 .4825 Mdot
.48125 .47 Mdot
.55625 .4775 Mdot
.42 .47375 Mdot
.51875 .2225 Mdot
.5275 .19375 Mdot
.44375 .18 Mdot
.80125 .16125 Mdot
.29 .135 Mdot
.50125 .10125 Mdot
.50875 .09375 Mdot
.49875 .0725 Mdot
.50125 .115 Mdot
.28625 .16125 Mdot
.7875 .24375 Mdot
.5275 .38375 Mdot
.34125 .4775 Mdot
.5125 .51375 Mdot
.455 .47875 Mdot
.545 .42 Mdot
.46875 .3375 Mdot
.76875 .275 Mdot
.30375 .2225 Mdot
.5 .2625 Mdot
.5 .31 Mdot
.49875 .31625 Mdot
.45625 .39125 Mdot
.31 .4525 Mdot
.7175 .48375 Mdot
.67 .47375 Mdot
.36375 .46125 Mdot
.50125 .42875 Mdot
.49 .3975 Mdot
.35125 .355 Mdot
.55625 .325 Mdot
.775 .31 Mdot
.39 .2875 Mdot
.42875 .265 Mdot
.46 .24 Mdot
.51375 .2675 Mdot
.525 .2925 Mdot
.29125 .33625 Mdot
.81 .36625 Mdot
.4675 .38125 Mdot
.47125 .35 Mdot
.425 .31 Mdot
.46375 .2475 Mdot
.4725 .2125 Mdot
.48 .21875 Mdot
.8075 .22125 Mdot
.34625 .2175 Mdot
.4575 .22625 Mdot
.50125 .2525 Mdot
.5 .265 Mdot
.46625 .26875 Mdot
.3075 .30125 Mdot
.9375 .32125 Mdot
.2675 .3175 Mdot
.50625 .32 Mdot
.44 .3125 Mdot
.56625 .26 Mdot
.4375 .2 Mdot
.50875 .16 Mdot
.625 .12125 Mdot
.48125 .1075 Mdot
.45375 .095 Mdot
.50875 .135 Mdot
.53 .1475 Mdot
.3125 .1425 Mdot
.665 .1475 Mdot
.5875 .18875 Mdot
.43 .20125 Mdot
.495 .205 Mdot
.445 .265 Mdot
.50375 .295 Mdot
.44375 .3075 Mdot
.685 .3075 Mdot
.46 .3125 Mdot
.465 .27125 Mdot
.44875 .27 Mdot
.49125 .2825 Mdot
.51 .2675 Mdot
.4225 .26875 Mdot
.62875 .28625 Mdot
.57375 .29375 Mdot
.3875 .28875 Mdot
.49625 .325 Mdot
.5125 .37 Mdot
.4775 .39875 Mdot
.26125 .4125 Mdot
.9325 .42125 Mdot
.37125 .4175 Mdot
.46625 .39625 Mdot
.49625 .40375 Mdot
.45875 .42875 Mdot
.295 .4325 Mdot
.89125 .4375 Mdot
.3875 .43375 Mdot
.4125 .4125 Mdot
.56625 .39875 Mdot
.3975 .365 Mdot
.55 .36125 Mdot
.33 .37 Mdot
.57 .38875 Mdot
.93125 .375 Mdot
.325 .41875 Mdot
.41 .4175 Mdot
.5175 .46125 Mdot
.26875 .4075 Mdot
.60375 .4 Mdot
.805 .3875 Mdot
.245 .4 Mdot
.57875 .36 Mdot
.43375 .39625 Mdot
.49625 .37375 Mdot
.4425 .36125 Mdot
.41625 .34375 Mdot
.88125 .31875 Mdot
.29875 .275 Mdot
.4475 .23875 Mdot
.49875 .21875 Mdot
.5325 .16875 Mdot
.26625 .2 Mdot
.8875 .26 Mdot
.48875 .34 Mdot
.41 .39 Mdot
.4475 .46625 Mdot
.5275 .49 Mdot
.46 .45125 Mdot
.37375 .4025 Mdot
.705 .34 Mdot
.34875 .2875 Mdot
.50125 .6575 Mdot
.585 .6875 Mdot
.3875 .71125 Mdot
.96375 .76125 Mdot
.1675 .85625 Mdot
.505 .985 Mdot
.68125 .93375 Mdot
.4575 .8025 Mdot
.43875 .7225 Mdot
.55125 .665 Mdot
.42125 .63625 Mdot
.51625 .675 Mdot
.42625 .70375 Mdot
.925 .6575 Mdot
.21 .665 Mdot
.49625 .64 Mdot
.49625 .59125 Mdot
.505 .63 Mdot
.47375 .56625 Mdot
.355 .505 Mdot
.675 .49375 Mdot
.56125 .4875 Mdot
.455 .4225 Mdot
.51 .405 Mdot
.46375 .41125 Mdot
.325 .515 Mdot
.50875 .61875 Mdot
1 .65625 Mdot
.25 .72 Mdot
.43 .77 Mdot
.46125 .74875 Mdot
.5175 .73625 Mdot
.51375 .71625 Mdot
.37375 .6775 Mdot
.715 .63 Mdot
.4375 .5875 Mdot
.52375 .54875 Mdot
.42125 .58 Mdot
.4825 .62375 Mdot
.4175 .68125 Mdot
.4275 .69125 Mdot
.24125 .69125 Mdot
.4575 .67875 Mdot
.495 .63875 Mdot
.4975 .65625 Mdot
.475 .665 Mdot
.39375 .65625 Mdot
.73875 .6375 Mdot
.3775 .635 Mdot
.5075 .60625 Mdot
.4475 .56375 Mdot
.5475 .5425 Mdot
.3375 .5725 Mdot
.57625 .59625 Mdot
.71125 .5975 Mdot
.41125 .62 Mdot
.46625 .68 Mdot
.5075 .695 Mdot
.5575 .68375 Mdot
.3525 .73375 Mdot
.605 .7775 Mdot
.4975 .7325 Mdot
.53875 .6925 Mdot
.49375 .71125 Mdot
.4275 .57625 Mdot
.505 .47375 Mdot
.38125 .4425 Mdot
.805 .4275 Mdot
.4525 .4225 Mdot
.41 .515 Mdot
.4475 .57125 Mdot
.4775 .595 Mdot
.5425 .66625 Mdot
.4775 .65625 Mdot
.5325 .64375 Mdot
.58375 .63125 Mdot
.3925 .61 Mdot
.51375 .52 Mdot
.5075 .39625 Mdot
.47 .30375 Mdot
.1375 .265 Mdot
.28375 .1875 Mdot
.435 .28 Mdot
.5125 .36875 Mdot
.455 .35125 Mdot
.39625 .3575 Mdot
.73125 .385 Mdot
.41125 .36375 Mdot
.48 .32625 Mdot
.50875 .2925 Mdot
.435 .2625 Mdot
.52375 .27 Mdot
.225 .21875 Mdot
.805 .15625 Mdot
.8 .17375 Mdot
.3025 .15 Mdot
.41625 .17875 Mdot
.55375 .2425 Mdot
.34875 .36875 Mdot
.55625 .4575 Mdot
.665 .49125 Mdot
.35375 .43125 Mdot
.56 .38125 Mdot
.435 .2625 Mdot
.4925 .17 Mdot
.4575 .1075 Mdot
.3825 .06625 Mdot
.97875 .07875 Mdot
.195 .135 Mdot
.47625 .23375 Mdot
.51125 .35375 Mdot
.53125 .4975 Mdot
.37375 .51625 Mdot
.71 .48125 Mdot
.53125 .405 Mdot
.425 .36 Mdot
.46 .25625 Mdot
.5275 .19125 Mdot
.45875 .3025 Mdot
.2775 .41125 Mdot
.85375 .49625 Mdot
.2675 .56125 Mdot
.47625 .85 Mdot
.60375 .86 Mdot
.42625 .88 Mdot
.075 .82375 Mdot
.48875 .745 Mdot
.51875 .675 Mdot
.50125 .55875 Mdot
.50375 .50375 Mdot
.43 .52875 Mdot
.5975 .59125 Mdot
.36 .6475 Mdot
.5975 .70125 Mdot
.61625 .76375 Mdot
.31375 .80875 Mdot
.46625 .85 Mdot
.39125 .89875 Mdot
.0825 .9825 Mdot
.43625 .96625 Mdot
.49125 .9525 Mdot
.49375 .92875 Mdot
.53 .91125 Mdot
.445 .945 Mdot
.6125 .97125 Mdot
.4375 .98125 Mdot
.4975 .96125 Mdot
.38125 .91375 Mdot
.35375 .91875 Mdot
.11375 .9725 Mdot
.49875 .9975 Mdot
.56125 .965 Mdot
.4175 .90125 Mdot
.50625 .85875 Mdot
.47625 .8675 Mdot
.61 .89375 Mdot
.50375 .9075 Mdot
.41 .9875 Mdot
.995 .935 Mdot
.18875 .87375 Mdot
.44 .37375 Mdot
.59125 .35 Mdot
.475 .30125 Mdot
.4775 .18375 Mdot
.53375 .20625 Mdot
.51875 .21125 Mdot
.4675 .24375 Mdot
.51375 .19625 Mdot
.4925 .15375 Mdot
.32 .1175 Mdot
.685 .1125 Mdot
.65125 .125 Mdot
.33625 .18375 Mdot
.3375 .1825 Mdot
.4225 .17375 Mdot
.07625 .09625 Mdot
.4975 .05125 Mdot
.5 .05 Mdot
.49875 .03125 Mdot
.51875 .0375 Mdot
.43375 .06625 Mdot
.54 .06 Mdot
.4475 .0575 Mdot
.5975 .0525 Mdot
.4475 .06625 Mdot
.5175 .0925 Mdot
.27375 .07625 Mdot
.50375 .1075 Mdot
.42625 .0625 Mdot
.5175 .09 Mdot
.485 .085 Mdot
.5375 .09375 Mdot
.4875 .075 Mdot
.51375 .07625 Mdot
.51 .12375 Mdot
.45625 .1675 Mdot
.5025 .1775 Mdot
.5025 .2675 Mdot
.375 .3175 Mdot
.30125 .285 Mdot
.035 .19375 Mdot
.4725 .09 Mdot
.49375 .015 Mdot
.54875 .11875 Mdot
.1575 .16625 Mdot
.65375 .1825 Mdot
.83625 .21875 Mdot
.3475 .17125 Mdot
.49875 .07875 Mdot
.49125 .02 Mdot
.5025 .01 Mdot
.61875 .08 Mdot
.46375 .1225 Mdot
.45375 .16 Mdot
.4825 .14375 Mdot
.29875 .1225 Mdot
.4075 .055 Mdot
.52125 .01625 Mdot
.46375 .0525 Mdot
.4675 .08375 Mdot
.52375 .095 Mdot
.5125 .1975 Mdot
.44375 .21375 Mdot
.245 .03625 Mdot
.455 .04875 Mdot
.05875 .1425 Mdot
.5825 .14 Mdot
.435 .06625 Mdot
.1275 .16625 Mdot
.06625 .33 Mdot
.47 .46125 Mdot
.5875 .4725 Mdot
.465 .48625 Mdot
.985 .46 Mdot
.0725 .4925 Mdot
.44 .525 Mdot
.60375 .545 Mdot
.50875 .56875 Mdot
.43875 .56875 Mdot
.54 .5775 Mdot
.4975 .5975 Mdot
.31375 .625 Mdot
.63375 .6275 Mdot
.7075 .60375 Mdot
.37125 .59375 Mdot
.3275 .55625 Mdot
.455 .50625 Mdot
.11875 .49 Mdot
.48 .48125 Mdot
.53125 .47875 Mdot
.49625 .47625 Mdot
.54125 .465 Mdot
.43125 .46 Mdot
.5225 .465 Mdot
.445 .44375 Mdot
.56125 .44 Mdot
.475 .43125 Mdot
.555 .43875 Mdot
.30125 .4525 Mdot
.48875 .47375 Mdot
.4825 .525 Mdot
.55625 .53625 Mdot
.4775 .55125 Mdot
.52375 .56625 Mdot
.485 .56875 Mdot
.515 .5625 Mdot
.49 .52 Mdot
.43625 .48 Mdot
.5575 .46875 Mdot
.53125 .43125 Mdot
.35875 .4075 Mdot
.29625 .40625 Mdot
.105 .41375 Mdot
.40875 .4425 Mdot
.585 .48125 Mdot
.55 .50125 Mdot
.4275 .51875 Mdot
.50125 .52875 Mdot
.47875 .52875 Mdot
.525 .5175 Mdot
.4175 .52 Mdot
.57125 .49625 Mdot
.54375 .44125 Mdot
.18125 .41375 Mdot
.62625 .41875 Mdot
.77875 .425 Mdot
.35625 .465 Mdot
.47875 .53125 Mdot
.56 .59875 Mdot
.5725 .61875 Mdot
.37875 .6225 Mdot
.5 .6075 Mdot
.50125 .575 Mdot
.55875 .51625 Mdot
.47875 .47625 Mdot
.54125 .45375 Mdot
.4625 .46125 Mdot
.30375 .46875 Mdot
.9475 .475 Mdot
.395 .485 Mdot
.34375 .52625 Mdot
.445 .55375 Mdot
.535 .54625 Mdot
.5025 .5575 Mdot
.52 .57 Mdot
.5475 .5425 Mdot
.44625 .50125 Mdot
.465 .52125 Mdot
.47375 .53375 Mdot
.61 .52 Mdot
.44875 .5075 Mdot
.2475 .5275 Mdot
.3425 .545 Mdot
.5475 .56125 Mdot
.48375 .55625 Mdot
.5125 .54625 Mdot
.47625 .55 Mdot
.47125 .5525 Mdot
.55875 .5525 Mdot
.40125 .5375 Mdot
.60125 .51625 Mdot
.445 .44375 Mdot
.02 .3775 Mdot
.6225 .44375 Mdot
.235 .505 Mdot
.42625 .58125 Mdot
.595 .65 Mdot
.51625 .6475 Mdot
.45625 .5975 Mdot
.49125 .55375 Mdot
.48125 .53875 Mdot
.4775 .5225 Mdot
.54625 .49875 Mdot
.47125 .495 Mdot
.46875 .47625 Mdot
.31375 .46375 Mdot
.1775 .43875 Mdot
.4525 .4375 Mdot
.55875 .45875 Mdot
.5525 .46875 Mdot
.45375 .4825 Mdot
.51 .51 Mdot
.4925 .52375 Mdot
.48375 .52375 Mdot
.50625 .53 Mdot
.54875 .545 Mdot
.425 .52125 Mdot
.13625 .50125 Mdot
.12875 .4825 Mdot
.58875 .38125 Mdot
.47125 .35375 Mdot
.53875 .31375 Mdot
.7875 .27 Mdot
.2025 .185 Mdot
.315 .16375 Mdot
.765 .12875 Mdot
.4925 .11125 Mdot
.4075 .12 Mdot
.55625 .2075 Mdot
.50375 .25375 Mdot
.28125 .265 Mdot
.52625 .28625 Mdot
.86375 .2925 Mdot
.43375 .24375 Mdot
.28 .21375 Mdot
.44625 .23 Mdot
.915 .23125 Mdot
.23125 .2275 Mdot
.3525 .22 Mdot
.6625 .22875 Mdot
.54125 .27875 Mdot
.47375 .3275 Mdot
.4325 .3175 Mdot
.5275 .3125 Mdot
.42875 .32375 Mdot
.47125 .2975 Mdot
.56875 .2825 Mdot
.61125 .34625 Mdot
.34 .3375 Mdot
.42375 .33 Mdot
.1 .3375 Mdot
.3425 .30125 Mdot
.745 .28625 Mdot
.4475 .25875 Mdot
.46 .19625 Mdot
.50125 .195 Mdot
.51875 .18 Mdot
.4325 .185 Mdot
.39125 .19 Mdot
.72 .2325 Mdot
.51375 .29875 Mdot
.33875 .31125 Mdot
.34875 .35625 Mdot
.18625 .38625 Mdot
.315 .32125 Mdot
.765 .325 Mdot
.57 .3075 Mdot
.33875 .28875 Mdot
.48 .25875 Mdot
.51125 .23625 Mdot
.5525 .2 Mdot
.2925 .1575 Mdot
.73 .16875 Mdot
.55 .23875 Mdot
.2 .26 Mdot
.58125 .27125 Mdot
.67 .29 Mdot
.42125 .26875 Mdot
.37375 .235 Mdot
.755 .23625 Mdot
.495 .28875 Mdot
.36625 .355 Mdot
.52 .42875 Mdot
.5125 .425 Mdot
.4825 .4475 Mdot
.36625 .43125 Mdot
.8475 .44125 Mdot
.35625 .4325 Mdot
.32875 .43375 Mdot
.8125 .41875 Mdot
.435 .41875 Mdot
.37875 .36 Mdot
.27375 .3275 Mdot
.835 .345 Mdot
.4125 .335 Mdot
.46 .30625 Mdot
.555 .31125 Mdot
.44875 .3025 Mdot
.45875 .2725 Mdot
.35375 .25875 Mdot
.85 .3125 Mdot
.35 .28 Mdot
.115 .27125 Mdot
.3075 .28875 Mdot
.35375 .22 Mdot
.5725 .22 Mdot
.58 .1925 Mdot
.41875 .16875 Mdot
.49375 .115 Mdot
.4675 .0875 Mdot
.55875 .05125 Mdot
.2825 .05 Mdot
.7975 .08 Mdot
.39625 .12625 Mdot
.14875 .20375 Mdot
.985 .30875 Mdot
.555 .39125 Mdot
.2075 .42 Mdot
.43625 .45875 Mdot
.83625 .46625 Mdot
.4225 .46375 Mdot
.405 .45125 Mdot
.4925 .45 Mdot
.47875 .4525 Mdot
.385 .44375 Mdot
.61 .3875 Mdot
.64875 .39125 Mdot
.3425 .3775 Mdot
.34875 .35125 Mdot
.92 .34 Mdot
.24625 .3675 Mdot
.38875 .34 Mdot
.67125 .33875 Mdot
.5425 .34 Mdot
.4675 .34625 Mdot
.47 .36 Mdot
.49875 .37875 Mdot
.44625 .40125 Mdot
.41375 .4 Mdot
.79625 .38125 Mdot
.315 .36875 Mdot
.23625 .355 Mdot
.91 .34375 Mdot
.26125 .3875 Mdot
.7125 .47375 Mdot
.345 .54625 Mdot
.585 .62125 Mdot
.65375 .6225 Mdot
.3075 .58625 Mdot
.1975 .525 Mdot
.86375 .55 Mdot
.59875 .56875 Mdot
.28375 .58375 Mdot
.605 .5775 Mdot
.48625 .51375 Mdot
.33125 .44625 Mdot
.3525 .40375 Mdot
.96 .42375 Mdot
.52875 .47125 Mdot
.22875 .54375 Mdot
.48375 .62375 Mdot
.75375 .6425 Mdot
.34375 .5925 Mdot
.265 .485 Mdot
.75375 .43375 Mdot
.6 .3575 Mdot
.39875 .31625 Mdot
.43125 .36875 Mdot
.51125 .385 Mdot
.45 .40125 Mdot
.39125 .44 Mdot
.64 .51875 Mdot
.6675 .5075 Mdot
.38 .51625 Mdot
.37625 .455 Mdot
.9175 .335 Mdot
.2275 .225 Mdot
.26125 .1625 Mdot
.875 .18625 Mdot
.42375 .275 Mdot
.4275 .42625 Mdot
.4875 .4475 Mdot
.5425 .4625 Mdot
.38625 .46875 Mdot
.33375 .515 Mdot
.85 .53125 Mdot
.5275 .65125 Mdot
.34 .6775 Mdot
.35875 .6775 Mdot
.855 .58375 Mdot
.305 .45 Mdot
.2175 .3575 Mdot
.91125 .33125 Mdot
.60125 .31 Mdot
.26375 .35 Mdot
.46125 .45125 Mdot
.53 .4525 Mdot
.5475 .4875 Mdot
.20375 .545 Mdot
.875 .60625 Mdot
.5675 .66875 Mdot
.205 .8075 Mdot
.53875 .9175 Mdot
.58875 .93125 Mdot
.48375 .94375 Mdot
.2575 .9325 Mdot
.96125 .88625 Mdot
.42 .83 Mdot
.34875 .8425 Mdot
.52125 .775 Mdot
.51625 .725 Mdot
.435 .69 Mdot
.2525 .7075 Mdot
.28 .65 Mdot
.3575 .6025 Mdot
.7025 .545 Mdot
.45125 .38 Mdot
.4175 .32625 Mdot
.12125 .34125 Mdot
.29125 .36 Mdot
.38625 .445 Mdot
.57625 .43125 Mdot
.45875 .3625 Mdot
.43625 .32 Mdot
.25 .3425 Mdot
.28125 .5125 Mdot
.2325 .60125 Mdot
.89875 .6225 Mdot
.37625 .5725 Mdot
.3625 .55125 Mdot
.60875 .5025 Mdot
.66875 .5325 Mdot
.3275 .57875 Mdot
.50125 .66 Mdot
.48 .6525 Mdot
.5375 .67625 Mdot
.15375 .6875 Mdot
.99 .74375 Mdot
.375 .7075 Mdot
.25375 .60375 Mdot
.78625 .4 Mdot
.53625 .18625 Mdot
.7025 .04125 Mdot
.2575 .11625 Mdot
.42875 .19375 Mdot
.7675 .19875 Mdot
.32375 .1275 Mdot
.27625 .09875 Mdot
.8525 .0825 Mdot
.50875 .0975 Mdot
.4525 .13 Mdot
.45625 .1125 Mdot
.49875 .0525 Mdot
.4525 .0425 Mdot
.27625 .05375 Mdot
.2075 .18875 Mdot
.32625 .2525 Mdot
.67875 .33 Mdot
.38875 .43125 Mdot
.8325 .9825 Mdot
.2575 .95125 Mdot
.55875 .995 Mdot
.61375 1 Mdot
.6075 .9525 Mdot
.46 .95875 Mdot
.715 .96625 Mdot
.67625 .8675 Mdot
.40875 .89 Mdot
.5175 .82625 Mdot
.3225 .83375 Mdot
.42125 .8175 Mdot
.60625 .86875 Mdot
.23125 .90625 Mdot
.515 .83875 Mdot
.49375 .73625 Mdot
.50125 .75375 Mdot
.16375 .81375 Mdot
.35125 .91625 Mdot
.30875 .93125 Mdot
.54 .98625 Mdot
.50875 .93875 Mdot
.39625 .9175 Mdot
.12375 .8925 Mdot
.2075 .8725 Mdot
.21 .94875 Mdot
.35625 .9175 Mdot
.64125 .89 Mdot
.47875 .9475 Mdot
.9825 .1925 Mdot
.1925 .15375 Mdot
.515 .05375 Mdot
.50625 .1025 Mdot
.455 .0775 Mdot
.01375 .10875 Mdot
.72125 .16875 Mdot
.155 .13125 Mdot
.6625 .17875 Mdot
.4425 .2575 Mdot
.41125 .29875 Mdot
.67625 .265 Mdot
.12125 .1425 Mdot
.525 .05125 Mdot
.50875 .1375 Mdot
.56 .18625 Mdot
.0075 .14125 Mdot
.9425 .12875 Mdot
.77375 .15125 Mdot
.215 .0575 Mdot
.44 .03625 Mdot
.53125 .1275 Mdot
.46875 .19875 Mdot
.24125 .23125 Mdot
.82125 .28 Mdot
.6775 .355 Mdot
.4025 .32125 Mdot
.33875 .2175 Mdot
.63 .2575 Mdot
.52875 .2125 Mdot
.08 .07 Mdot
.35875 .0275 Mdot
.51375 .05875 Mdot
.3375 .12625 Mdot
.20625 .20625 Mdot
.5725 .30125 Mdot
.235 .24875 Mdot
.45375 .2425 Mdot
.45125 .285 Mdot
.60625 .245 Mdot
.045 .1925 Mdot
.65375 .17 Mdot
.15375 .13 Mdot
.43625 .1175 Mdot
.53875 .19625 Mdot
.565 .22875 Mdot
.05125 .15 Mdot
.56 .11875 Mdot
.195 .07125 Mdot
.5275 .02375 Mdot
.49375 .10125 Mdot
.48 .09375 Mdot
.07875 .08125 Mdot
.29875 .04625 Mdot
.495 .1075 Mdot
.35625 .16375 Mdot
.09125 .1825 Mdot
.1375 .1875 Mdot
.3825 .02125 Mdot
.52125 .04875 Mdot
.48375 .0725 Mdot
.0675 .08125 Mdot
.51625 .07625 Mdot
.395 .1175 Mdot
.03375 .1775 Mdot
.22875 .2375 Mdot
.42875 .16375 Mdot
.51625 .16 Mdot
.4375 .12 Mdot
.3375 .08625 Mdot
.70375 .0725 Mdot
.82125 .075 Mdot
.19125 .06375 Mdot
.47125 .045 Mdot
.50875 .0875 Mdot
.52 .0725 Mdot
.03375 .06625 Mdot
.28375 .02875 Mdot
.505 .085 Mdot
.24 .08625 Mdot
.5325 .025 Mdot
.11625 .045 Mdot
.915 .08875 Mdot
.83125 .095 Mdot
.14125 .035 Mdot
.43875 .05125 Mdot
.02375 .09875 Mdot
.44125 .0275 Mdot
.38875 .00875 Mdot
.27625 .00375 Mdot
.46625 .0475 Mdot
.26625 .075 Mdot
.58375 .13125 Mdot
.96 .50375 Mdot
.20625 .52625 Mdot
.52125 .53875 Mdot
.5425 .50375 Mdot
.45625 .575 Mdot
.0475 .545 Mdot
.99875 .52875 Mdot
.7325 .53 Mdot
.17625 .55375 Mdot
.63625 .44625 Mdot
.45125 .4175 Mdot
.41625 .4475 Mdot
.64875 .49875 Mdot
.13875 .56375 Mdot
.52 .57625 Mdot
.55125 .5275 Mdot
.55125 .5375 Mdot
.03875 .51625 Mdot
.90375 .4625 Mdot
.79125 .39875 Mdot
.18125 .4225 Mdot
.45 .4025 Mdot
.525 .4175 Mdot
.47375 .45375 Mdot
.27875 .475 Mdot
.79125 .415 Mdot
.66625 .39875 Mdot
.36375 .37875 Mdot
.38375 .37 Mdot
.68125 .34375 Mdot
.5075 .41125 Mdot
.0625 .46375 Mdot
.35375 .555 Mdot
.4075 .59875 Mdot
.45375 .59625 Mdot
.515 .55 Mdot
.3475 .5375 Mdot
.20375 .4875 Mdot
.51875 .42 Mdot
.22875 .40625 Mdot
.56125 .37625 Mdot
.4325 .365 Mdot
.54875 .4025 Mdot
.14875 .41375 Mdot
.625 .42625 Mdot
.17875 .40125 Mdot
.43875 .4075 Mdot
.48375 .41125 Mdot
.61625 .4275 Mdot
.0925 .45375 Mdot
.55625 .48 Mdot
.1975 .5 Mdot
.6075 .49375 Mdot
.4775 .49 Mdot
.47625 .49375 Mdot
.10125 .485 Mdot
.3025 .45625 Mdot
.33375 .46 Mdot
.5125 .44375 Mdot
.47625 .39125 Mdot
.42 .3725 Mdot
.07375 .37 Mdot
.16 .40625 Mdot
.38125 .45875 Mdot
.58125 .48375 Mdot
.49875 .4875 Mdot
.4725 .475 Mdot
.0825 .4775 Mdot
.34625 .4875 Mdot
.50125 .5175 Mdot
.52 .52 Mdot
.4 .53625 Mdot
.09 .525 Mdot
.22375 .465 Mdot
.47125 .4875 Mdot
.55 .50875 Mdot
.44 .54875 Mdot
.31625 .57125 Mdot
.7075 .59 Mdot
.8 .55375 Mdot
.20875 .49875 Mdot
.45875 .45375 Mdot
.5475 .46125 Mdot
.505 .51125 Mdot
.0875 .53625 Mdot
.3025 .595 Mdot
.40125 .59375 Mdot
.57625 .5375 Mdot
.47 .525 Mdot
.24125 .48125 Mdot
.54 .4875 Mdot
.435 .475 Mdot
.51625 .5125 Mdot
.48625 .4325 Mdot
.08375 .4225 Mdot
.95125 .42 Mdot
.8075 .43375 Mdot
.13375 .4225 Mdot
.545 .4775 Mdot
.51875 .4775 Mdot
.4375 .4525 Mdot
.02625 .43625 Mdot
.42125 .4825 Mdot
.3675 .47375 Mdot
.43 .37625 Mdot
.5025 .36875 Mdot
.3725 .345 Mdot
.2975 .33875 Mdot
.46625 .4675 Mdot
.29 .49 Mdot
.52875 .48875 Mdot
.82125 .38375 Mdot
.25 .34875 Mdot
.50625 .3375 Mdot
.71375 .365 Mdot
.37375 .28375 Mdot
.15 .2675 Mdot
.855 .32375 Mdot
.7325 .37125 Mdot
.215 .355 Mdot
.61125 .43375 Mdot
.45625 .46875 Mdot
.4375 .41125 Mdot
.115 .40125 Mdot
.59625 .4475 Mdot
.16375 .45875 Mdot
.5725 .48125 Mdot
.6125 .48875 Mdot
.485 .40125 Mdot
.1925 .4 Mdot
.715 .45 Mdot
.785 .5175 Mdot
.26625 .56 Mdot
.43875 .69625 Mdot
.5125 .73 Mdot
.48625 .7225 Mdot
.3225 .73875 Mdot
.76 .78125 Mdot
.5975 .7475 Mdot
.33125 .72875 Mdot
.4975 .72375 Mdot
.6825 .695 Mdot
.44375 .6225 Mdot
.19625 .59 Mdot
.94125 .57125 Mdot
.38 .5275 Mdot
.47 .495 Mdot
.4475 .48875 Mdot
.5025 .49875 Mdot
.4025 .45 Mdot
.255 .46375 Mdot
.97875 .49375 Mdot
.52375 .50125 Mdot
.1325 .5175 Mdot
.78875 .56125 Mdot
.39 .55375 Mdot
.49375 .5 Mdot
.2725 .4675 Mdot
.86125 .43875 Mdot
.63375 .43375 Mdot
.25375 .43625 Mdot
.455 .40875 Mdot
.44875 .42375 Mdot
.58375 .4325 Mdot
.24375 .44375 Mdot
.88625 .41 Mdot
.5425 .42 Mdot
.15 .39375 Mdot
.85375 .40875 Mdot
.36625 .46625 Mdot
.46 .50125 Mdot
.20375 .53375 Mdot
.35125 .5475 Mdot
.38125 .4775 Mdot
.5 .435 Mdot
.47625 .43625 Mdot
.45625 .45 Mdot
.20625 .4525 Mdot
.25 .52875 Mdot
.27875 .55 Mdot
.83875 .545 Mdot
.39375 .56625 Mdot
.46875 .55125 Mdot
.00375 .5275 Mdot
.1825 .4775 Mdot
.37625 .41875 Mdot
.51125 .385 Mdot
.505 .38 Mdot
.41375 .32 Mdot
.22375 .2975 Mdot
.295 .405 Mdot
.4575 .4075 Mdot
.6425 .455 Mdot
.40375 .45625 Mdot
.3175 .4075 Mdot
.68125 .3225 Mdot
.75625 .28625 Mdot
.26 .26 Mdot
.47375 .28 Mdot
.5275 .4 Mdot
.51375 .43625 Mdot
.19625 .48125 Mdot
.925 .53625 Mdot
.36875 .56625 Mdot
.30125 .50375 Mdot
.7925 .5325 Mdot
.38125 .54125 Mdot
.30375 .53625 Mdot
.56125 .53875 Mdot
.06625 .54 Mdot
.49125 .5475 Mdot
.51625 .53375 Mdot
.49 .54125 Mdot
.16875 .52375 Mdot
.89 .51375 Mdot
.6575 .5 Mdot
.175 .50625 Mdot
.60875 .485 Mdot
.58875 .5125 Mdot
.4075 .51125 Mdot
.10875 .54375 Mdot
.40125 .55125 Mdot
.3675 .53875 Mdot
.4725 .66625 Mdot
.4975 .65125 Mdot
.40375 .6525 Mdot
.3925 .64625 Mdot
.11 .49875 Mdot
.39125 .4425 Mdot
.555 .41125 Mdot
.395 .41375 Mdot
.73875 .16375 Mdot
.21375 .09625 Mdot
.79625 .05375 Mdot
.28125 .215 Mdot
.255 .2975 Mdot
.79875 .30375 Mdot
.6225 .26 Mdot
.3175 .1675 Mdot
.57125 .03375 Mdot
.4675 .11625 Mdot
.43875 .2275 Mdot
.24375 .25625 Mdot
.9025 .26375 Mdot
.5275 .2375 Mdot
.19625 .10375 Mdot
.58125 .01125 Mdot
.71125 .1375 Mdot
.4075 .355 Mdot
.2925 .40625 Mdot
.59125 .40875 Mdot
.745 .4525 Mdot
.35125 .35375 Mdot
.45875 .13875 Mdot
.49125 .1425 Mdot
.49 .13625 Mdot
.38125 .05875 Mdot
.53125 .0125 Mdot
.29125 .05625 Mdot
.6575 .05625 Mdot
.63125 .1375 Mdot
.415 .18875 Mdot
.27625 .18125 Mdot
.81375 .1 Mdot
.4 .08625 Mdot
.5025 .05 Mdot
.46125 .04625 Mdot
.475 .165 Mdot
.45875 .29125 Mdot
.30875 .285 Mdot
.85125 .20625 Mdot
.5175 .22375 Mdot
.06875 .155 Mdot
.96875 .05375 Mdot
.34625 .145 Mdot
.45 .25875 Mdot
.3775 .29375 Mdot
.715 .2975 Mdot
.64625 .3475 Mdot
.31 .3125 Mdot
.4525 .36 Mdot
.445 .43 Mdot
.5625 .415 Mdot
.37625 .315 Mdot
.72 .28125 Mdot
.52125 .2475 Mdot
.1375 .15375 Mdot
.30125 .18125 Mdot
.44125 .18375 Mdot
.30625 .12125 Mdot
.8475 .09375 Mdot
.4425 .08 Mdot
.42625 .06125 Mdot
.47875 .11875 Mdot
.48 .22875 Mdot
.47 .21875 Mdot
.32375 .20625 Mdot
.9375 .13375 Mdot
.31625 .02375 Mdot
.4825 .0675 Mdot
.16 .12875 Mdot
.28625 .21875 Mdot
.40125 .17 Mdot
.52125 .18875 Mdot
.52 .31875 Mdot
.43125 .47375 Mdot
.32375 .5525 Mdot
.865 .56375 Mdot
.34875 .52625 Mdot
.46375 .42 Mdot
.7375 .325 Mdot
.36375 .3225 Mdot
.3225 .345 Mdot
.64375 .39 Mdot
.7025 .3975 Mdot
.31375 .385 Mdot
.49 .3375 Mdot
.505 .26375 Mdot
.54625 .215 Mdot
.31375 .1625 Mdot
.725 .04125 Mdot
.99875 .02375 Mdot
.29875 .09125 Mdot
.35 .1775 Mdot
.58375 .22625 Mdot
.8175 .24 Mdot
.22625 .1875 Mdot
.4875 .1275 Mdot
.5175 .1575 Mdot
.4725 .1575 Mdot
.275 .12625 Mdot
.78125 .09625 Mdot
.6225 .07625 Mdot
.16125 .015 Mdot
.64375 .07375 Mdot
.36375 .15 Mdot
.21375 .13375 Mdot
.96875 .1325 Mdot
.425 .14875 Mdot
.385 .08875 Mdot
.48875 .0225 Mdot
.48625 .1075 Mdot
.41375 .07875 Mdot
.52375 .05375 Mdot
.8725 .00625 Mdot
.23 .06625 Mdot
.30625 .12 Mdot
.78625 .16875 Mdot
.28 .16625 Mdot
.5275 .215 Mdot
.165 .2225 Mdot
.66875 .19875 Mdot
.08125 .03 Mdot
.4575 .0475 Mdot
.325 .10125 Mdot
.53 .15875 Mdot
.9325 .18125 Mdot
.25 .16875 Mdot
.52375 .15625 Mdot
.37875 .1325 Mdot
.57 .10625 Mdot
.525 .1 Mdot
.505 .07125 Mdot
.45375 .07875 Mdot
.4475 .085 Mdot
.495 .07875 Mdot
.6325 .10375 Mdot
.5025 .16375 Mdot
.19625 .1125 Mdot
.865 .09 Mdot
.62125 .045 Mdot
.58125 .025 Mdot
.43 .06875 Mdot
.05 .10375 Mdot
.21125 .095 Mdot
.675 .0225 Mdot
.3825 .0375 Mdot
.4875 .05125 Mdot
.44625 .0325 Mdot
.51125 .00625 Mdot
.43 .06 Mdot
.5125 .04375 Mdot
.10125 .04375 Mdot
.1025 .0675 Mdot
.04625 .0675 Mdot
.50875 .01 Mdot
.4675 .00625 Mdot
.54125 .01125 Mdot
.4675 .015 Mdot
.5175 .025 Mdot
.4825 .02125 Mdot
.4725 .01625 Mdot
.57125 .0525 Mdot
.4525 .09875 Mdot
.4525 .1925 Mdot
.49625 .1825 Mdot
.09 .15375 Mdot
.16375 .08125 Mdot
.4975 .03125 Mdot
.49125 .07 Mdot
.505 .09875 Mdot
.47625 .145 Mdot
.475 .1725 Mdot
.505 .1375 Mdot
.44875 .11625 Mdot
.4625 .09 Mdot
.63 .1275 Mdot
.525 .20125 Mdot
.0775 .28125 Mdot
.88375 .3175 Mdot
.75625 .31 Mdot
.2375 .24 Mdot
.4825 .13 Mdot
.54625 .04 Mdot
.22375 .0475 Mdot
.12125 .16125 Mdot
.50625 .41375 Mdot
.1625 .37 Mdot
.6575 .35875 Mdot
.07875 .415 Mdot
.42375 .51125 Mdot
.6 .575 Mdot
.4625 .605 Mdot
.45875 .59375 Mdot
.54125 .59125 Mdot
.505 .5925 Mdot
.49 .5825 Mdot
.47625 .56125 Mdot
.49125 .52375 Mdot
.50625 .50625 Mdot
.36 .4925 Mdot
.50625 .47125 Mdot
.91 .46 Mdot
.275 .49 Mdot
.52 .515 Mdot
.3975 .52625 Mdot
.52375 .52 Mdot
.51875 .54375 Mdot
.51125 .515 Mdot
.4925 .4475 Mdot
.44125 .4025 Mdot
.5375 .40625 Mdot
.57625 .37875 Mdot
.51125 .3525 Mdot
.18375 .4 Mdot
.89125 .41375 Mdot
.575 .42125 Mdot
.28 .43 Mdot
.5 .47125 Mdot
.47625 .46125 Mdot
.50625 .475 Mdot
.46625 .49125 Mdot
.56625 .5025 Mdot
.53 .50375 Mdot
.49625 .5225 Mdot
.47 .5225 Mdot
.545 .47625 Mdot
.41875 .46 Mdot
.11375 .4575 Mdot
.23 .49375 Mdot
.3725 .54625 Mdot
.57375 .55125 Mdot
.45 .5475 Mdot
.645 .54375 Mdot
.37 .5175 Mdot
.5075 .52 Mdot
.53 .5225 Mdot
.43625 .53 Mdot
.58 .5175 Mdot
.44625 .4725 Mdot
.50875 .46 Mdot
.10125 .455 Mdot
.155 .45125 Mdot
.4575 .52875 Mdot
.51625 .5325 Mdot
.455 .5275 Mdot
.58125 .51625 Mdot
.475 .52875 Mdot
.51 .5075 Mdot
.53375 .4975 Mdot
.49375 .50375 Mdot
.46 .525 Mdot
.5125 .5425 Mdot
.48375 .52625 Mdot
.03625 .49125 Mdot
.52125 .4625 Mdot
.48375 .48375 Mdot
.45625 .50875 Mdot
.525 .54375 Mdot
.41 .5625 Mdot
.59125 .5625 Mdot
.52125 .52875 Mdot
.49875 .5 Mdot
.485 .4675 Mdot
.49 .455 Mdot
.41875 .45625 Mdot
.4675 .48 Mdot
.86 .49375 Mdot
.26875 .495 Mdot
.41 .4825 Mdot
.52875 .48 Mdot
.6025 .47 Mdot
.42375 .4675 Mdot
.54625 .46625 Mdot
.48625 .47375 Mdot
.51625 .475 Mdot
.4725 .47875 Mdot
.46875 .49 Mdot
.50875 .49625 Mdot
.11625 .50125 Mdot
.185 .515 Mdot
.5225 .49875 Mdot
.46 .48875 Mdot
.485 .48125 Mdot
.5 .46 Mdot
.5125 .45375 Mdot
.47 .45375 Mdot
.4575 .46125 Mdot
.49375 .46125 Mdot
.61125 .4475 Mdot
.51375 .42375 Mdot
.045 .385 Mdot
.8775 .355 Mdot
.80875 .36125 Mdot
.225 .385 Mdot
.49 .41375 Mdot
.51 .455 Mdot
.48375 .4775 Mdot
.48875 .4875 Mdot
.52875 .49375 Mdot
.48 .5075 Mdot
.51625 .515 Mdot
.49375 .51875 Mdot
.4975 .52875 Mdot
.47875 .5275 Mdot
.21625 .52875 Mdot
.11375 .51375 Mdot
.52125 .59125 Mdot
.20625 .57875 Mdot
.66875 .57 Mdot
.96875 .58 Mdot
.16125 .57375 Mdot
.42875 .54 Mdot
.6025 .52625 Mdot
.465 .50875 Mdot
.38875 .49 Mdot
.62875 .48125 Mdot
.59125 .50875 Mdot
.38875 .525 Mdot
.47625 .53375 Mdot
.505 .5175 Mdot
.4975 .49625 Mdot
.42625 .45 Mdot
.46625 .4425 Mdot
.83 .445 Mdot
.34375 .4425 Mdot
.49 .42875 Mdot
.445 .48375 Mdot
.4875 .53375 Mdot
.37875 .525 Mdot
.65625 .56625 Mdot
.57625 .60125 Mdot
.3725 .57875 Mdot
.55 .56 Mdot
.53875 .565 Mdot
.52625 .54125 Mdot
.245 .51875 Mdot
.825 .5325 Mdot
.47875 .515 Mdot
.36375 .52375 Mdot
.5075 .54 Mdot
.49875 .575 Mdot
.48125 .575 Mdot
.3875 .54125 Mdot
.62125 .515 Mdot
.6775 .49125 Mdot
.37 .45625 Mdot
.47625 .41625 Mdot
.55875 .39875 Mdot
.41 .41125 Mdot
.2325 .4 Mdot
.28875 .3475 Mdot
.4175 .40375 Mdot
.56875 .43 Mdot
.45125 .46875 Mdot
.61375 .51875 Mdot
.32125 .53875 Mdot
.4775 .51375 Mdot
.74125 .4925 Mdot
.34 .46375 Mdot
.56625 .46375 Mdot
.45875 .4475 Mdot
.49875 .42125 Mdot
.2175 .40625 Mdot
.27375 .3625 Mdot
.4725 .34875 Mdot
.51375 .365 Mdot
.47625 .38125 Mdot
.54 .4375 Mdot
.375 .46125 Mdot
.6725 .49625 Mdot
.49375 .53 Mdot
.49625 .54125 Mdot
.45375 .50375 Mdot
.5225 .48625 Mdot
.4925 .48375 Mdot
.0925 .48125 Mdot
.125 .49875 Mdot
.5175 .52125 Mdot
.50625 .515 Mdot
.4825 .49625 Mdot
.4225 .46125 Mdot
.46625 .42125 Mdot
.73875 .39125 Mdot
.40625 .395 Mdot
.49375 .39375 Mdot
.465 .37125 Mdot
.50875 .39375 Mdot
.44375 .41 Mdot
.46875 .40125 Mdot
.77 .39375 Mdot
.32875 .41625 Mdot
.41125 .43125 Mdot
.49375 .44375 Mdot
.58625 .455 Mdot
.43375 .46875 Mdot
.625 .47625 Mdot
.54125 .47625 Mdot
.4 .46625 Mdot
.48875 .465 Mdot
.4775 .45625 Mdot
.50625 .44125 Mdot
.2275 .4225 Mdot
.285 .4025 Mdot
.53125 .4175 Mdot
.465 .44 Mdot
.44125 .4475 Mdot
.49 .45625 Mdot
.6525 .47375 Mdot
.38875 .47125 Mdot
.45875 .46625 Mdot
.48625 .4725 Mdot
.6125 .48125 Mdot
.505 .475 Mdot
.1325 .505 Mdot
.805 .52 Mdot
.7425 .51375 Mdot
.2725 .51125 Mdot
.485 .52375 Mdot
.45875 .50875 Mdot
.455 .52125 Mdot
.7175 .5375 Mdot
.38625 .53625 Mdot
.48875 .52125 Mdot
.5375 .52625 Mdot
.47375 .505 Mdot
.48875 .49125 Mdot
.49125 .5 Mdot
.3075 .5225 Mdot
.97625 .51875 Mdot
.21 .56 Mdot
.5125 .095 Mdot
.29 .1225 Mdot
.5975 .14875 Mdot
.87875 .15375 Mdot
.28375 .12 Mdot
.41125 .0425 Mdot
.55875 .02375 Mdot
.735 .00375 Mdot
.4 .0025 Mdot
.265 .0475 Mdot
.5825 .11625 Mdot
.57125 .20125 Mdot
.5075 .25875 Mdot
.2825 .22 Mdot
.7325 .19125 Mdot
.48125 .1925 Mdot
.38125 .13 Mdot
.53875 .05 Mdot
.48875 .00625 Mdot
.34 .0425 Mdot
.6125 .09875 Mdot
.85 .18 Mdot
.26 .1975 Mdot
.45625 .19 Mdot
.57125 .23 Mdot
.405 .1675 Mdot
.325 .1275 Mdot
.90125 .175 Mdot
.30125 .16625 Mdot
.5125 .03 Mdot
.53875 .00875 Mdot
.475 .05875 Mdot
.49375 .11 Mdot
.305 .15875 Mdot
.86125 .21 Mdot
.345 .27375 Mdot
.47875 .21125 Mdot
.4825 .19125 Mdot
.5625 .1525 Mdot
.4825 .08125 Mdot
.2675 .02 Mdot
.4975 .0225 Mdot
.49375 .00875 Mdot
.25625 .03 Mdot
.99625 .0375 Mdot
.23375 .0525 Mdot
.46125 .01625 Mdot
.895 .0675 Mdot
.2875 .08875 Mdot
.48375 .15 Mdot
.44875 .255 Mdot
.5425 .32125 Mdot
.45625 .295 Mdot
.47625 .2825 Mdot
.67625 .26375 Mdot
.39125 .14625 Mdot
.42 .01 Mdot
.33 .0325 Mdot
.815 .0625 Mdot
.3875 .0775 Mdot
.53 .0175 Mdot
.74625 .02375 Mdot
.3 .06875 Mdot
.47125 .12125 Mdot
.48625 .125 Mdot
.60125 .2125 Mdot
.4825 .24 Mdot
.23375 .17375 Mdot
.7175 .12625 Mdot
.6825 .09 Mdot
.2775 .0325 Mdot
.49625 .07 Mdot
.5475 .05125 Mdot
.45125 .04375 Mdot
.49 .035 Mdot
.4 .015 Mdot
.53 .13375 Mdot
.47875 .2025 Mdot
.25375 .165 Mdot
.78625 .1325 Mdot
.8575 .1 Mdot
.49875 .02 Mdot
.42375 .14875 Mdot
.215 .18 Mdot
.76875 .145 Mdot
.7875 .1575 Mdot
.215 .0225 Mdot
.4575 .04125 Mdot
.55 .03 Mdot
.47625 .0475 Mdot
.28625 .155 Mdot
.33625 .235 Mdot
.02625 .27875 Mdot
.50625 .13125 Mdot
.46625 .0625 Mdot
.49875 .0125 Mdot
.47875 .00625 Mdot
.69 .0025 Mdot
.4475 .0725 Mdot
.075 .1675 Mdot
.99375 .2975 Mdot
.515 .3825 Mdot
.4425 .335 Mdot
.43375 .28375 Mdot
.4675 .165 Mdot
.52125 .0575 Mdot
.50625 .08625 Mdot
.49 .14125 Mdot
.37625 .06125 Mdot
.465 .05375 Mdot
.44625 .1575 Mdot
.52875 .21 Mdot
.21125 .14875 Mdot
.875 .0025 Mdot
.10125 .0225 Mdot
.50875 .095 Mdot
.4175 .10375 Mdot
.23125 .15125 Mdot
.09375 .1375 Mdot
.50125 .595 Mdot
.49375 .60625 Mdot
.52875 .59 Mdot
.50875 .58 Mdot
.56875 .57 Mdot
.41375 .53125 Mdot
.5125 .51125 Mdot
.49125 .495 Mdot
.25625 .4875 Mdot
.79625 .4675 Mdot
.9 .47375 Mdot
.085 .47875 Mdot
.45125 .49625 Mdot
.53625 .49125 Mdot
.4675 .5075 Mdot
.485 .50125 Mdot
.56875 .505 Mdot
.48625 .49375 Mdot
.51625 .4925 Mdot
.505 .47875 Mdot
.47875 .43 Mdot
.4475 .40375 Mdot
.21625 .40125 Mdot
.8 .445 Mdot
.7575 .5 Mdot
.225 .5375 Mdot
.5175 .5425 Mdot
.60125 .5925 Mdot
.44875 .6025 Mdot
.5675 .58875 Mdot
.41875 .66625 Mdot
.48 .7325 Mdot
.49375 .7675 Mdot
.53125 .765 Mdot
.485 .7325 Mdot
.42 .68375 Mdot
.29125 .66125 Mdot
.57375 .6025 Mdot
.0225 .60375 Mdot
.42875 .61 Mdot
.51875 .59875 Mdot
.485 .595 Mdot
.47125 .61375 Mdot
.525 .58625 Mdot
.45375 .575 Mdot
.62125 .56625 Mdot
.4725 .56125 Mdot
.47625 .52375 Mdot
.4425 .49375 Mdot
.36625 .44125 Mdot
.30625 .4225 Mdot
.0175 .3975 Mdot
.4975 .41 Mdot
.45375 .4375 Mdot
.5275 .42375 Mdot
.45875 .40625 Mdot
.55125 .39375 Mdot
.5 .405 Mdot
.51 .42375 Mdot
.37 .42625 Mdot
.705 .4175 Mdot
.44125 .435 Mdot
.08125 .43875 Mdot
.9675 .4525 Mdot
.52875 .455 Mdot
.42375 .48625 Mdot
.46625 .5325 Mdot
.43625 .5625 Mdot
.53125 .56625 Mdot
.58125 .6075 Mdot
.4725 .63875 Mdot
.50875 .6125 Mdot
.44125 .6225 Mdot
.51875 .6175 Mdot
.51625 .61625 Mdot
.33 .57625 Mdot
.54 .50875 Mdot
.10125 .31875 Mdot
.48625 .28875 Mdot
.44 .3025 Mdot
.6775 .365 Mdot
.40875 .445 Mdot
.50875 .50875 Mdot
.5075 .515 Mdot
.4775 .46625 Mdot
.485 .37625 Mdot
.44875 .335 Mdot
.51375 .30875 Mdot
.21625 .3225 Mdot
.485 .4525 Mdot
.23 .485 Mdot
.52125 .5025 Mdot
.49375 .49125 Mdot
.5175 .48875 Mdot
.465 .47625 Mdot
.55 .4775 Mdot
.4825 .49125 Mdot
.5025 .51625 Mdot
.5025 .53375 Mdot
.2325 .57 Mdot
.77625 .6 Mdot
.86375 .605 Mdot
.1275 .5775 Mdot
.49 .5475 Mdot
.475 .52375 Mdot
.505 .50125 Mdot
.52125 .48875 Mdot
.47875 .49625 Mdot
.5525 .5175 Mdot
.485 .52625 Mdot
.465 .50875 Mdot
.5225 .4925 Mdot
.4275 .4875 Mdot
.22125 .4675 Mdot
.0925 .465 Mdot
.5325 .48 Mdot
.505 .48 Mdot
.44625 .48875 Mdot
.48625 .4825 Mdot
.51 .49625 Mdot
.55625 .50875 Mdot
.4375 .52875 Mdot
.47875 .5525 Mdot
.50125 .4675 Mdot
.41125 .5 Mdot
.66125 .515 Mdot
.48875 .51625 Mdot
.505 .51625 Mdot
.47375 .56 Mdot
.5275 .54 Mdot
.46125 .52625 Mdot
.35 .5425 Mdot
.69 .53 Mdot
.77625 .49875 Mdot
.25875 .50875 Mdot
.4175 .52 Mdot
.51375 .52875 Mdot
.485 .52375 Mdot
.34375 .53125 Mdot
.76375 .5225 Mdot
.4675 .52875 Mdot
.50125 .51875 Mdot
.49125 .525 Mdot
.47125 .4875 Mdot
.4475 .49 Mdot
.32875 .475 Mdot
.67875 .47875 Mdot
.68 .4475 Mdot
.3025 .4875 Mdot
.52375 .48875 Mdot
.585 .45875 Mdot
.46875 .4325 Mdot
.45125 .43625 Mdot
.5725 .38875 Mdot
.51125 .3375 Mdot
.43 .3375 Mdot
.53 .3525 Mdot
.4525 .37125 Mdot
.46125 .425 Mdot
.3475 .4575 Mdot
.5325 .49125 Mdot
.13125 .5 Mdot
.44625 .48375 Mdot
.505 .495 Mdot
.4625 .50125 Mdot
.3925 .515 Mdot
.68 .5275 Mdot
.42625 .52125 Mdot
.6075 .5075 Mdot
.4675 .4925 Mdot
.4675 .4925 Mdot
.44875 .47375 Mdot
.4225 .47125 Mdot
.35375 .4375 Mdot
.11125 .39 Mdot
.4875 .405 Mdot
.4725 .385 Mdot
.51625 .42 Mdot
.38375 .44875 Mdot
.745 .46875 Mdot
.41875 .49875 Mdot
.47875 .505 Mdot
.39125 .50375 Mdot
.6875 .52125 Mdot
.4525 .5325 Mdot
.175 .525 Mdot
.82 .545 Mdot
.57125 .56625 Mdot
.41625 .5425 Mdot
.4825 .48875 Mdot
.42125 .455 Mdot
.48375 .46 Mdot
.56625 .455 Mdot
.61125 .47 Mdot
.46375 .49125 Mdot
.4275 .51875 Mdot
.52 .52 Mdot
.49125 .55875 Mdot
.41875 .6275 Mdot
.49875 .745 Mdot
.8575 .88 Mdot
.22875 .94125 Mdot
.49125 .875 Mdot
.445 .77125 Mdot
.66625 .655 Mdot
.27 .50375 Mdot
.68375 .42125 Mdot
.5875 .42625 Mdot
.365 .43375 Mdot
.5 .4125 Mdot
.46125 .3875 Mdot
.52875 .38125 Mdot
.2275 .3825 Mdot
.98125 .385 Mdot
.4375 .3925 Mdot
.33875 .40375 Mdot
.51375 .42125 Mdot
.4925 .4275 Mdot
.49125 .4425 Mdot
.35125 .47 Mdot
.8475 .48375 Mdot
.31625 .47875 Mdot
.505 .52375 Mdot
.50375 .49625 Mdot
.27 .4525 Mdot
.78375 .42375 Mdot
.72875 .4225 Mdot
.20875 .3875 Mdot
.49875 .41375 Mdot
.4875 .4425 Mdot
.4875 .445 Mdot
.51 .43125 Mdot
.415 .42125 Mdot
.71125 .3975 Mdot
.435 .3775 Mdot
.42875 .37125 Mdot
.53625 .37 Mdot
.47125 .38125 Mdot
.26 .41125 Mdot
.225 .475 Mdot
.51875 .50125 Mdot
.5 .5025 Mdot
.4575 .49375 Mdot
.5025 .495 Mdot
.435 .485 Mdot
.68 .4775 Mdot
.40875 .4575 Mdot
.4425 .47625 Mdot
.495 .00125 Mdot
.49375 .00625 Mdot
.37875 .0475 Mdot
.61125 .025 Mdot
.51 .03625 Mdot
.41375 .07625 Mdot
.46 .04875 Mdot
.585 .08 Mdot
.6475 .14875 Mdot
.47125 .17625 Mdot
.3625 .15875 Mdot
.4975 .14625 Mdot
.4875 .10625 Mdot
.20125 .0575 Mdot
.975 .0025 Mdot
.45375 .01625 Mdot
.39 .0475 Mdot
.645 .07875 Mdot
.58375 .15125 Mdot
.40875 .135 Mdot
.485 .14875 Mdot
.5475 .14625 Mdot
.5225 .1325 Mdot
.35375 .06875 Mdot
.70375 .02 Mdot
.4575 .0775 Mdot
.385 .0675 Mdot
.55375 .0425 Mdot
.93125 .0675 Mdot
.2375 .02375 Mdot
.37125 .03375 Mdot
.95625 .0775 Mdot
.24875 .09 Mdot
.635 .0225 Mdot
.45625 .05125 Mdot
.28625 .005 Mdot
.4575 .05875 Mdot
.44875 .10125 Mdot
.51375 .10375 Mdot
.73625 .04125 Mdot
.41875 .00875 Mdot
.64125 .01375 Mdot
.15375 .07375 Mdot
.875 .02375 Mdot
.4875 .05625 Mdot
.4525 .215 Mdot
.545 .2525 Mdot
.32625 .265 Mdot
.8325 .2625 Mdot
.44 .24125 Mdot
.38875 .12875 Mdot
.51 .0725 Mdot
.48625 .01875 Mdot
.51875 .005 Mdot
.50625 .07875 Mdot
.33625 .06 Mdot
.69375 .03625 Mdot
.54625 .055 Mdot
.49125 .10875 Mdot
.33 .13375 Mdot
.8625 .1575 Mdot
.30375 .155 Mdot
.52375 .04125 Mdot
.5025 .02375 Mdot
.4675 .00125 Mdot
.36 .00875 Mdot
.8075 .03125 Mdot
.36375 .0425 Mdot
.4375 .01375 Mdot
.515 .065 Mdot
.18875 .07375 Mdot
.9525 .09 Mdot
.525 .1325 Mdot
.155 .04625 Mdot
.26375 .06 Mdot
.485 .17375 Mdot
.49125 .2225 Mdot
.4375 .0775 Mdot
.50625 .07875 Mdot
.12625 .1125 Mdot
.48625 .1625 Mdot
.31 .07625 Mdot
.455 .11375 Mdot
.47125 .1725 Mdot
.095 .2275 Mdot
.50875 .26125 Mdot
.3575 .1425 Mdot
.52 .04875 Mdot
.44125 .01125 Mdot
.54625 .0475 Mdot
.49875 .05 Mdot
.4625 .105 Mdot
.515 .11 Mdot
.2075 .0825 Mdot
.255 .065 Mdot
.41875 .08 Mdot
.53625 .455 Mdot
.165 .44125 Mdot
.95625 .4725 Mdot
.53625 .505 Mdot
.12125 .55375 Mdot
.91125 .59125 Mdot
.38 .63 Mdot
.4025 .61125 Mdot
.62125 .6425 Mdot
.335 .6275 Mdot
.4675 .59875 Mdot
.8375 .57875 Mdot
.2575 .59 Mdot
.50625 .56375 Mdot
.49125 .54625 Mdot
.45375 .59375 Mdot
.375 .595 Mdot
.56 .63125 Mdot
.39375 .63125 Mdot
.49 .59375 Mdot
.47875 .5825 Mdot
.4775 .565 Mdot
.555 .55375 Mdot
.52625 .5425 Mdot
.47125 .5225 Mdot
.5125 .47 Mdot
.46875 .415 Mdot
.115 .37875 Mdot
.48 .38625 Mdot
.2625 .42125 Mdot
.50375 .46375 Mdot
.46625 .47375 Mdot
.545 .47625 Mdot
.4325 .47125 Mdot
.55125 .46875 Mdot
.4925 .465 Mdot
.51 .47 Mdot
.5525 .45 Mdot
.465 .41 Mdot
.4525 .38875 Mdot
.06875 .36375 Mdot
.51 .37875 Mdot
.3475 .40625 Mdot
.50125 .4025 Mdot
.4575 .4 Mdot
.4725 .39875 Mdot
.5025 .41 Mdot
.50375 .43875 Mdot
.5075 .49125 Mdot
.5075 .53375 Mdot
.515 .56125 Mdot
.48625 .56875 Mdot
.4675 .5425 Mdot
.1625 .5125 Mdot
.1375 .4525 Mdot
.42875 .435 Mdot
.46875 .44875 Mdot
.5825 .4525 Mdot
.41625 .465 Mdot
.4725 .47 Mdot
.525 .45875 Mdot
.50125 .4625 Mdot
.505 .4675 Mdot
.54125 .4925 Mdot
.48375 .4925 Mdot
.39375 .50125 Mdot
.325 .49625 Mdot
.1675 .45125 Mdot
.53 .44875 Mdot
.52875 .45375 Mdot
.445 .4475 Mdot
.54 .4525 Mdot
.49125 .465 Mdot
.44125 .475 Mdot
.51375 .47375 Mdot
.50875 .48375 Mdot
.5175 .48625 Mdot
.48875 .46625 Mdot
.0075 .46125 Mdot
.535 .44 Mdot
.2125 .45125 Mdot
.4925 .47875 Mdot
.46 .4725 Mdot
.535 .49 Mdot
.52125 .49 Mdot
.495 .4775 Mdot
.52 .45375 Mdot
.445 .45375 Mdot
.5175 .45 Mdot
.4975 .4525 Mdot
.41875 .47 Mdot
.08625 .50125 Mdot
.51375 .54 Mdot
.5275 .55125 Mdot
.46625 .5525 Mdot
.42 .54125 Mdot
.57625 .505 Mdot
.51 .485 Mdot
.51 .45625 Mdot
.48875 .435 Mdot
.5375 .435 Mdot
.445 .445 Mdot
.16 .45625 Mdot
.17625 .4825 Mdot
.42625 .48125 Mdot
.5425 .49375 Mdot
.48 .485 Mdot
.4675 .48 Mdot
.56375 .48125 Mdot
.4575 .4775 Mdot
.53125 .46875 Mdot
.50625 .46875 Mdot
.47125 .45625 Mdot
.49125 .43625 Mdot
.21625 .4425 Mdot
.3375 .445 Mdot
.36125 .4375 Mdot
.5425 .5475 Mdot
.24375 .555 Mdot
.825 .5875 Mdot
.55125 .59375 Mdot
.185 .5775 Mdot
.86875 .6025 Mdot
.365 .60375 Mdot
.4375 .58375 Mdot
.60125 .6025 Mdot
.23375 .61375 Mdot
.64375 .6025 Mdot
.78125 .59625 Mdot
.27125 .555 Mdot
.4825 .53 Mdot
.50375 .525 Mdot
.1075 .52125 Mdot
.495 .55375 Mdot
.3725 .5575 Mdot
.57625 .5575 Mdot
.395 .56375 Mdot
.50125 .57875 Mdot
.4775 .60375 Mdot
.4 .6 Mdot
.7575 .585 Mdot
.425 .5725 Mdot
.44625 .5275 Mdot
.5325 .49375 Mdot
.46125 .52 Mdot
.22125 .53375 Mdot
.98625 .52875 Mdot
.48 .5275 Mdot
.32125 .5325 Mdot
.49125 .50875 Mdot
.47125 .51875 Mdot
.5525 .51875 Mdot
.4275 .5225 Mdot
.44375 .54375 Mdot
.655 .535 Mdot
.51 .51125 Mdot
.5075 .51125 Mdot
.4425 .5325 Mdot
.4775 .53125 Mdot
.1675 .51375 Mdot
.98 .51125 Mdot
.525 .4975 Mdot
.38125 .47375 Mdot
.4975 .49125 Mdot
.46375 .53125 Mdot
.4725 .54875 Mdot
.52375 .565 Mdot
.39875 .57 Mdot
.67125 .5275 Mdot
.43375 .5075 Mdot
.51125 .4775 Mdot
.505 .47125 Mdot
.46 .4525 Mdot
.26125 .4525 Mdot
.23 .465 Mdot
.44125 .455 Mdot
.47 .45875 Mdot
.56375 .4675 Mdot
.435 .455 Mdot
.4425 .4575 Mdot
.5475 .46 Mdot
.55375 .465 Mdot
.44375 .45875 Mdot
.5575 .43875 Mdot
.49 .44125 Mdot
.4175 .47 Mdot
.35 .46875 Mdot
.95 .465 Mdot
.235 .495 Mdot
.5675 .51 Mdot
.50125 .475 Mdot
.43875 .47125 Mdot
.4575 .47375 Mdot
.61875 .46375 Mdot
.43875 .44875 Mdot
.4725 .45875 Mdot
.5125 .45125 Mdot
.52625 .44 Mdot
.48625 .42 Mdot
.14875 .395 Mdot
.46625 .3625 Mdot
.315 .36 Mdot
.49125 .3725 Mdot
.4775 .385 Mdot
.46375 .37375 Mdot
.545 .36 Mdot
.58375 .34625 Mdot
.47375 .3475 Mdot
.4525 .35625 Mdot
.50625 .36375 Mdot
.47625 .39875 Mdot
.46375 .39 Mdot
.16625 .36125 Mdot
.16 .355 Mdot
.49125 .34375 Mdot
.5175 .365 Mdot
.52125 .3875 Mdot
.29125 .4175 Mdot
.74125 .44375 Mdot
.38875 .43875 Mdot
.59875 .44625 Mdot
.48375 .4625 Mdot
.525 .4875 Mdot
.4275 .4675 Mdot
.1825 .46625 Mdot
.21875 .475 Mdot
.46875 .45375 Mdot
.54375 .44125 Mdot
.4575 .44 Mdot
.3875 .42125 Mdot
.68375 .4075 Mdot
.46375 .385 Mdot
.495 .37625 Mdot
.49375 .37 Mdot
.4775 .3725 Mdot
.47875 .37 Mdot
.28125 .40625 Mdot
.91125 .45125 Mdot
.4175 .47625 Mdot
.36625 .5225 Mdot
.55875 .08375 Mdot
.3225 .0825 Mdot
.71375 .08875 Mdot
.55625 .04375 Mdot
.49125 .0275 Mdot
.24625 .0475 Mdot
.84125 .04125 Mdot
.5725 .015 Mdot
.31875 .005 Mdot
.4275 .085 Mdot
.53375 .21375 Mdot
.43875 .2325 Mdot
.33625 .2275 Mdot
.85125 .22875 Mdot
.47875 .22125 Mdot
.36625 .14 Mdot
.48125 .1075 Mdot
.465 .085 Mdot
.5675 .0925 Mdot
.435 .09625 Mdot
.3525 .07 Mdot
.84 .08625 Mdot
.40125 .10375 Mdot
.5175 .085 Mdot
.44 .09 Mdot
.4825 .13875 Mdot
.26 .16125 Mdot
.8325 .165 Mdot
.52625 .17625 Mdot
.41125 .15625 Mdot
.51125 .12 Mdot
.44375 .12125 Mdot
.5075 .13875 Mdot
.5475 .16 Mdot
.25 .1725 Mdot
.905 .18375 Mdot
.3175 .145 Mdot
.51125 .1475 Mdot
.49625 .1625 Mdot
.4925 .1375 Mdot
.33625 .09 Mdot
.87625 .04625 Mdot
.37875 .05 Mdot
.82375 .0925 Mdot
.29125 .10625 Mdot
.575 .05125 Mdot
.49375 .0625 Mdot
.45125 .03875 Mdot
.33125 .00625 Mdot
.83125 .01 Mdot
.36375 .0075 Mdot
.51125 .01625 Mdot
.5 .015 Mdot
.89375 .00125 Mdot
.47 .00375 Mdot
.495 .03125 Mdot
.45625 .1225 Mdot
.5275 .16125 Mdot
.2125 .1925 Mdot
.2975 .10375 Mdot
.75625 0 Mdot
.345 .02 Mdot
.785 .03375 Mdot
.49125 .0525 Mdot
.33875 .03 Mdot
.56625 .28125 Mdot
.46625 .31625 Mdot
.51625 .3575 Mdot
.53125 .4 Mdot
.49875 .44 Mdot
.505 .4625 Mdot
.4625 .43375 Mdot
.49875 .46625 Mdot
.55125 .5525 Mdot
.0375 .58375 Mdot
.35125 .61625 Mdot
.4 .54875 Mdot
.49125 .365 Mdot
.45625 .27 Mdot
.4725 .245 Mdot
.5375 .2125 Mdot
.59 .215 Mdot
.47625 .2825 Mdot
.41125 .34 Mdot
.45125 .35375 Mdot
.56 .41125 Mdot
.515 .3825 Mdot
.135 .3575 Mdot
.14 .2975 Mdot
.40875 .1525 Mdot
.49625 .04625 Mdot
.4475 .01 Mdot
.51875 .04375 Mdot
.5 .15625 Mdot
.35625 .17625 Mdot
.47625 .17625 Mdot
.62 .31625 Mdot
.43875 .42875 Mdot
.25125 .44625 Mdot
.20375 .50125 Mdot
.4975 .4275 Mdot
.44375 .325 Mdot
.48 .3375 Mdot
.45125 .41125 Mdot
.5625 .4425 Mdot
.4675 .44375 Mdot
.49875 .47875 Mdot
.5825 .49375 Mdot
.4475 .4625 Mdot
.5425 .485 Mdot
.515 .4725 Mdot
0 .465 Mdot
.08125 .43125 Mdot
.4775 .365 Mdot
.4925 .2975 Mdot
.56125 .23 Mdot
.45 .12625 Mdot
.505 .05625 Mdot
.42875 .00875 Mdot
.285 .065 Mdot
.41375 .03875 Mdot
.505 .03125 Mdot
.6475 .145 Mdot
.3 .23875 Mdot
.56625 .315 Mdot
.4775 .2675 Mdot
.48875 .22 Mdot
.5225 .19125 Mdot
.53375 .16625 Mdot
.485 .1475 Mdot
.4375 .15625 Mdot
.525 .21375 Mdot
.56625 .15125 Mdot
.3625 .13875 Mdot
.39625 .0975 Mdot
.48625 .17625 Mdot
.4625 .215 Mdot
.5025 .22375 Mdot
.47875 .24 Mdot
.57125 .22875 Mdot
.52 .215 Mdot
.4125 .19 Mdot
.415 .20375 Mdot
.58 .24875 Mdot
.54375 .29 Mdot
.08625 .3125 Mdot
.0825 .3575 Mdot
.42625 .33125 Mdot
.48 .30875 Mdot
.48875 .28625 Mdot
.53375 .275 Mdot
.47125 .29125 Mdot
.55125 .28875 Mdot
.53 .29625 Mdot
.33625 .33125 Mdot
.48 .33625 Mdot
.61625 .3025 Mdot
.4425 .2475 Mdot
.25125 .27875 Mdot
.1525 .29 Mdot
.48125 .28375 Mdot
.465 .32 Mdot
.47125 .28 Mdot
.4775 .23 Mdot
.5 .21 Mdot
.49375 .235 Mdot
.485 .2875 Mdot
.60625 .33375 Mdot
.45125 .37 Mdot
.54375 .41625 Mdot
.49375 .43875 Mdot
.485 .41 Mdot
.48625 .3725 Mdot
.555 .34375 Mdot
.475 .345 Mdot
.4775 .3375 Mdot
.56625 .35625 Mdot
.4075 .38875 Mdot
.62875 .425 Mdot
.4175 .42875 Mdot
.42375 .49625 Mdot
.395 .55125 Mdot
.56625 .57125 Mdot
.8525 .58375 Mdot
.2375 .6075 Mdot
.55 .5425 Mdot
.49 .4925 Mdot
.46875 .45625 Mdot
.55 .43 Mdot
.46625 .41625 Mdot
.53 .435 Mdot
.53625 .455 Mdot
.45375 .54625 Mdot
.3875 .53625 Mdot
.24 .52375 Mdot
.37375 .5025 Mdot
.36375 .435 Mdot
.51625 .43 Mdot
.46875 .425 Mdot
.53625 .4125 Mdot
.50125 .40875 Mdot
.445 .40125 Mdot
.54 .40875 Mdot
.5475 .42875 Mdot
.4075 .4475 Mdot
.51625 .49 Mdot
.345 .4875 Mdot
.51875 .505 Mdot
.9575 .5175 Mdot
.185 .5 Mdot
.6175 .535 Mdot
.395 .56 Mdot
.4625 .5975 Mdot
.54125 .61 Mdot
.38875 .64125 Mdot
.625 .6075 Mdot
.53375 .62 Mdot
.43875 .60125 Mdot
.475 .53625 Mdot
.6075 .45625 Mdot
.245 .37125 Mdot
.845 .3875 Mdot
.27375 .43375 Mdot
.4775 .37 Mdot
.425 .41875 Mdot
.36375 .4475 Mdot
.745 .51125 Mdot
.41625 .55375 Mdot
.67 .5625 Mdot
.49875 .515 Mdot
.4075 .52375 Mdot
.12375 .48 Mdot
.995 .4525 Mdot
.48125 .4675 Mdot
.43 .50875 Mdot
.4125 .49125 Mdot
.5275 .4825 Mdot
.54 .44 Mdot
.43625 .40625 Mdot
.49875 .37375 Mdot
.63 .35 Mdot
.32 .32 Mdot
.55375 .51125 Mdot
.49375 .54625 Mdot
.4575 .56 Mdot
.595 .5525 Mdot
.5575 .55625 Mdot
.39 .57375 Mdot
.485 .58875 Mdot
.5125 .58875 Mdot
.55 .65125 Mdot
.135 .67875 Mdot
.32875 .61 Mdot
.42875 .6075 Mdot
.5125 .56375 Mdot
.445 .54625 Mdot
.5025 .54 Mdot
.48625 .545 Mdot
.57125 .5475 Mdot
.58 .515 Mdot
.3475 .49625 Mdot
.42625 .5 Mdot
.57875 .50125 Mdot
.55125 .5075 Mdot
.16875 .54375 Mdot
.18125 .5675 Mdot
.4575 .59875 Mdot
.4375 .63625 Mdot
.50375 .655 Mdot
.52375 .65875 Mdot
.45125 .665 Mdot
.63375 .68375 Mdot
.495 .6625 Mdot
.32625 .62875 Mdot
.49625 .6025 Mdot
.58875 .58875 Mdot
.475 .53875 Mdot
.34 .4625 Mdot
.17125 .4125 Mdot
.50625 .3925 Mdot
.4775 .36875 Mdot
.49625 .4 Mdot
.44875 .41125 Mdot
.47375 .46 Mdot
.58875 .47875 Mdot
.415 .52125 Mdot
.60375 .5225 Mdot
.43375 .505 Mdot
.57125 .50375 Mdot
.50625 .47375 Mdot
.06625 .425 Mdot
.0825 .39 Mdot
.51125 .3525 Mdot
.46125 .38 Mdot
.56875 .43625 Mdot
.40875 .51375 Mdot
.54375 .57875 Mdot
.6075 .59125 Mdot
.37625 .5725 Mdot
.60125 .5375 Mdot
.435 .5075 Mdot
.42375 .44125 Mdot
.41875 .365 Mdot
.55 .3225 Mdot
.78375 .255 Mdot
.2925 .18875 Mdot
.5475 .1925 Mdot
.48875 .2425 Mdot
.47875 .29 Mdot
.46125 .3225 Mdot
.59875 .35625 Mdot
.5175 .35 Mdot
.49875 .31125 Mdot
.45 .2725 Mdot
.4075 .2675 Mdot
.32625 .28125 Mdot
.97 .28125 Mdot
.3825 .33 Mdot
.41125 .37125 Mdot
.485 .42125 Mdot
.4825 .43625 Mdot
.54375 .4675 Mdot
.46625 .4675 Mdot
.38625 .48125 Mdot
.72 .47 Mdot
.46375 .45875 Mdot
.42125 .4375 Mdot
.47625 .45625 Mdot
.41875 .45 Mdot
.515 .4425 Mdot
.835 .45125 Mdot
.2525 .54 Mdot
.595 .5025 Mdot
.41625 .50625 Mdot
.47875 .55625 Mdot
.5175 .54125 Mdot
.30375 .4675 Mdot
.79875 .49125 Mdot
.46375 .485 Mdot
.45125 .4525 Mdot
.48625 .4975 Mdot
.5425 .58125 Mdot
.12375 .60375 Mdot
.95625 .64 Mdot
.35875 .66875 Mdot
.74625 .675 Mdot
.2825 .5725 Mdot
.48875 .56375 Mdot
.44875 .525 Mdot
.35875 .51875 Mdot
.755 .4875 Mdot
.445 .48 Mdot
.6125 .44625 Mdot
.4825 .4425 Mdot
.4425 .395 Mdot
.1675 .44375 Mdot
.925 .50125 Mdot
.51125 .53375 Mdot
.43875 .5225 Mdot
.39375 .55375 Mdot
.535 .51125 Mdot
.5525 .48875 Mdot
.4275 .4775 Mdot
.47625 .50125 Mdot
.63875 .5 Mdot
.32375 .4975 Mdot
.5375 .1325 Mdot
.4775 .14125 Mdot
.34 .1525 Mdot
.75375 .16625 Mdot
.595 .1725 Mdot
.2475 .19125 Mdot
.565 .19375 Mdot
.57 .23875 Mdot
.48875 .22125 Mdot
.27375 .20625 Mdot
.85625 .21375 Mdot
.42375 .21875 Mdot
.42 .17875 Mdot
.52625 .19625 Mdot
.4525 .195 Mdot
.50125 .185 Mdot
.455 .15 Mdot
.64 .1475 Mdot
.605 .18125 Mdot
.28625 .24 Mdot
.44375 .245 Mdot
.56 .3075 Mdot
.56625 .3 Mdot
.26 .255 Mdot
.98125 .19875 Mdot
.27375 .2125 Mdot
.49125 .215 Mdot
.42 .25625 Mdot
.5175 .30375 Mdot
.50625 .34125 Mdot
.36125 .29375 Mdot
.78 .24375 Mdot
.4625 .2475 Mdot
.31375 .25625 Mdot
.505 .29 Mdot
.57375 .38875 Mdot
.48375 .42125 Mdot
.415 .41625 Mdot
.875 .38 Mdot
.29 .33375 Mdot
.48875 .27375 Mdot
.4775 .255 Mdot
.5075 .2175 Mdot
.4525 .245 Mdot
.4325 .2325 Mdot
.705 .215 Mdot
.34125 .15375 Mdot
.59125 .12125 Mdot
.46875 .07875 Mdot
.53125 .07875 Mdot
.4825 .0925 Mdot
.22 .145 Mdot
.1925 .25625 Mdot
.515 .275 Mdot
.4675 .27625 Mdot
.54875 .27375 Mdot
.34875 .21875 Mdot
.61875 .15375 Mdot
.6825 .14375 Mdot
.305 .155 Mdot
.5775 .13625 Mdot
.45125 .17 Mdot
.4375 .23625 Mdot
.44375 .3125 Mdot
.5575 .3725 Mdot
.67 .46625 Mdot
.36 .50375 Mdot
.54125 .5 Mdot
.485 .4575 Mdot
.49 .43375 Mdot
.32625 .425 Mdot
.80875 .40125 Mdot
.5 .3825 Mdot
.435 .37125 Mdot
.46 .34875 Mdot
.40625 .2725 Mdot
.44 .2325 Mdot
.755 .22625 Mdot
.46625 .17625 Mdot
.44125 .08875 Mdot
.44125 .0525 Mdot
.52 .02 Mdot
.4 .00375 Mdot
.4725 .08625 Mdot
.325 .155 Mdot
.8275 .19 Mdot
.44 .14375 Mdot
.55375 .11 Mdot
.43125 .1775 Mdot
.495 .1775 Mdot
.26375 .1225 Mdot
.825 .05625 Mdot
.46625 .00625 Mdot
.73125 .04375 Mdot
.2825 .09625 Mdot
.5275 .6275 Mdot
.47 .56 Mdot
.22625 .56375 Mdot
.90875 .5625 Mdot
.60375 .62 Mdot
.1175 .69125 Mdot
.68 .72125 Mdot
.6075 .72375 Mdot
.41625 .80375 Mdot
.3825 .81375 Mdot
.6875 .8375 Mdot
.45875 .8925 Mdot
.44 .91125 Mdot
.51125 .87875 Mdot
.49625 .87 Mdot
.48125 .88125 Mdot
.4175 .95375 Mdot
.73375 .99375 Mdot
.375 .9675 Mdot
.50625 .8925 Mdot
.40625 .83625 Mdot
.5675 .74125 Mdot
.4725 .69125 Mdot
.26625 .71375 Mdot
.88125 .72375 Mdot
.45 .73375 Mdot
.35375 .8 Mdot
.44625 .84625 Mdot
.60375 .83 Mdot
.46875 .84125 Mdot
.47625 .85875 Mdot
.71125 .87625 Mdot
.3675 .85375 Mdot
.52 .865 Mdot
.4875 .90625 Mdot
.5 .92 Mdot
.46125 .9125 Mdot
.41125 .9475 Mdot
.80875 .97 Mdot
.29375 .9525 Mdot
.51875 .965 Mdot
.3825 .99 Mdot
.76875 .9325 Mdot
.31875 .85 Mdot
.535 .78 Mdot
.48 .76125 Mdot
.53375 .73125 Mdot
.27125 .765 Mdot
.72 .84625 Mdot
.7275 .865 Mdot
.24375 .9275 Mdot
.5025 .96375 Mdot
.1925 .92125 Mdot
.44625 .86625 Mdot
.23 .805 Mdot
.6375 .92 Mdot
.79625 .81875 Mdot
.63 .75625 Mdot
.335 .69 Mdot
.49 .725 Mdot
.53125 .7025 Mdot
.48125 .645 Mdot
.50375 .66375 Mdot
.48125 .69625 Mdot
.5075 .66875 Mdot
.48 .69 Mdot
.3525 .675 Mdot
.87375 .6875 Mdot
.55125 .6875 Mdot
.235 .70875 Mdot
.4525 .69625 Mdot
.54375 .66625 Mdot
.53125 .6775 Mdot
.44625 .69875 Mdot
.58 .70625 Mdot
.4575 .7275 Mdot
.5375 .795 Mdot
.41375 .8075 Mdot
.60125 .82 Mdot
.43125 .81125 Mdot
.2175 .7725 Mdot
.92375 .74125 Mdot
.45125 .6725 Mdot
.38875 .59625 Mdot
.43125 .51875 Mdot
.605 .43 Mdot
.48125 .39 Mdot
.51375 .38125 Mdot
.555 .3875 Mdot
.45625 .45125 Mdot
.51125 .5225 Mdot
.48125 .5475 Mdot
.5025 .58875 Mdot
.48375 .62875 Mdot
.375 .62 Mdot
.9275 .63875 Mdot
.2175 .735 Mdot
.49 .8125 Mdot
.5125 .8225 Mdot
.51 .7775 Mdot
.5025 .83875 Mdot
.4625 .8325 Mdot
.55625 .825 Mdot
.4175 .86125 Mdot
.5575 .9575 Mdot
.49125 .965 Mdot
.52375 .94 Mdot
.1925 .89875 Mdot
.81 .81625 Mdot
.76 .78 Mdot
.205 .70125 Mdot
.5275 .6125 Mdot
.4575 .54 Mdot
.4725 .50625 Mdot
.53625 .48 Mdot
.495 .5 Mdot
.52375 .52875 Mdot
.5 .53125 Mdot
.49 .56125 Mdot
.48625 .60375 Mdot
.50875 .62125 Mdot
.05875 .65125 Mdot
.445 .7025 Mdot
.39875 .6 Mdot
.43125 .455 Mdot
.43625 .31375 Mdot
.5375 .2625 Mdot
.5175 .2 Mdot
.55625 .24 Mdot
.455 .3 Mdot
.3275 .35125 Mdot
.69125 .355 Mdot
.48125 .45875 Mdot
.365 .43125 Mdot
.42 .4325 Mdot
.2 .34375 Mdot
.44375 .1575 Mdot
.47625 .0325 Mdot
.1575 .0325 Mdot
.11375 .09 Mdot
.4925 .0075 Mdot
.4775 .045 Mdot
.47875 .15 Mdot
.48 .14 Mdot
.625 .12125 Mdot
.39375 .075 Mdot
.55875 .0325 Mdot
.29125 .26625 Mdot
.485 .535 Mdot
.9325 .81875 Mdot
.1025 .0225 Mdot
.635 .26875 Mdot
.88625 .2225 Mdot
.5675 .22125 Mdot
.3475 .19625 Mdot
.565 .1275 Mdot
.41625 .13375 Mdot
.48375 .15625 Mdot
.5675 .1925 Mdot
.45875 .2075 Mdot
.49375 .2625 Mdot
.4675 .25375 Mdot
.34625 .23 Mdot
.94875 .18 Mdot
.58 .115 Mdot
.15375 .0275 Mdot
.4325 .01 Mdot
.57625 .08125 Mdot
.4475 .1275 Mdot
.215 .20375 Mdot
.915 .28125 Mdot
.5325 .3375 Mdot
.32875 .3575 Mdot
.44875 .3925 Mdot
.61125 .41625 Mdot
.475 .4225 Mdot
.54 .4375 Mdot
.4475 .4075 Mdot
.51875 .3825 Mdot
.53 .34375 Mdot
.43875 .2875 Mdot
.52875 .27125 Mdot
.50375 .23625 Mdot
.31125 .23 Mdot
.20625 .175 Mdot
.45625 .09625 Mdot
.53875 .0775 Mdot
.49625 .04875 Mdot
.4925 .02125 Mdot
.52375 .0325 Mdot
.425 .05875 Mdot
.48625 .0575 Mdot
.54 .0375 Mdot
.5125 .03375 Mdot
.54875 .085 Mdot
.14125 .11 Mdot
.845 .145 Mdot
.79125 .1725 Mdot
.18375 .195 Mdot
.47875 .18875 Mdot
.4975 .1925 Mdot
.4875 .18875 Mdot
.535 .18625 Mdot
.46625 .16875 Mdot
.4975 .15125 Mdot
.5575 .155 Mdot
.49 .14375 Mdot
.47125 .1975 Mdot
.48875 .2275 Mdot
.47375 .215 Mdot
.37625 .17125 Mdot
.44375 .17125 Mdot
.4775 .2225 Mdot
.48 .24375 Mdot
.5275 .2725 Mdot
.49 .27875 Mdot
.4775 .3 Mdot
.3225 .31125 Mdot
.755 .30875 Mdot
.4225 .2975 Mdot
.3725 .3175 Mdot
.49125 .30375 Mdot
.155 .35375 Mdot
.475 .38875 Mdot
.49375 .42 Mdot
.525 .45 Mdot
.49375 .42625 Mdot
.4625 .42375 Mdot
.4625 .4375 Mdot
.5775 .4125 Mdot
.53125 .37875 Mdot
.38875 .4 Mdot
.4475 .36 Mdot
.155 .32875 Mdot
.0775 .34375 Mdot
.49625 .34 Mdot
.44875 .39875 Mdot
.46875 .43625 Mdot
.5275 .455 Mdot
.49375 .4675 Mdot
.47625 .48875 Mdot
.5 .48875 Mdot
.5 .4625 Mdot
.4925 .47625 Mdot
.46 .465 Mdot
.2575 .4325 Mdot
.455 .46125 Mdot
.325 .4325 Mdot
.52125 .37125 Mdot
.45875 .34625 Mdot
.48875 .36875 Mdot
.6175 .335 Mdot
.375 .36375 Mdot
.55125 .48125 Mdot
.575 .53125 Mdot
.45875 .525 Mdot
.52875 .50625 Mdot
.2875 .4175 Mdot
.5225 .2725 Mdot
.96375 .12625 Mdot
.54 .44125 Mdot
.5825 .4375 Mdot
.085 .4475 Mdot
.98375 .4625 Mdot
.60875 .4925 Mdot
.02 .51625 Mdot
.7975 .55375 Mdot
.63125 .5675 Mdot
.41375 .5825 Mdot
.4775 .5825 Mdot
.41375 .5625 Mdot
.51125 .56 Mdot
.53875 .545 Mdot
.44875 .53375 Mdot
.5075 .525 Mdot
.58 .51 Mdot
.2825 .49125 Mdot
.93375 .47875 Mdot
.5025 .45125 Mdot
.23 .45125 Mdot
.42875 .46125 Mdot
.51 .46625 Mdot
.595 .49625 Mdot
.47125 .5 Mdot
.48375 .495 Mdot
.5025 .5 Mdot
.5275 .48375 Mdot
.4175 .455 Mdot
.55 .4675 Mdot
.56 .47625 Mdot
.19875 .475 Mdot
.82375 .46875 Mdot
.5575 .5075 Mdot
.35375 .49375 Mdot
.40625 .5125 Mdot
.605 .565 Mdot
.565 .65125 Mdot
.50625 .7225 Mdot
.435 .8375 Mdot
.51125 .87875 Mdot
.53625 .87875 Mdot
.36625 .85 Mdot
.55 .76375 Mdot
.62125 .66125 Mdot
.2725 .57125 Mdot
.9375 .50125 Mdot
.2475 .45875 Mdot
.4475 .4425 Mdot
.50875 .44 Mdot
.5475 .45 Mdot
.50875 .45 Mdot
.49 .44375 Mdot
.46625 .42125 Mdot
.44375 .40375 Mdot
.5325 .41 Mdot
.4275 .4325 Mdot
.635 .44125 Mdot
.235 .46 Mdot
.75125 .475 Mdot
.76 .47375 Mdot
.21 .465 Mdot
.4325 .45625 Mdot
.56625 .45625 Mdot
.55625 .45375 Mdot
.47375 .45 Mdot
.4275 .46 Mdot
.53125 .46875 Mdot
.56 .4725 Mdot
.4325 .49 Mdot
.52125 .49375 Mdot
.5225 .45625 Mdot
.02625 .455 Mdot
.48125 .4375 Mdot
.35375 .44 Mdot
.46875 .48375 Mdot
.5475 .485 Mdot
.47 .49625 Mdot
.505 .49875 Mdot
.5025 .50375 Mdot
.46625 .46 Mdot
.25 .41 Mdot
.8625 .425 Mdot
.43375 .445 Mdot
.36 .4625 Mdot
.5475 .515 Mdot
.82 .57375 Mdot
.2325 .55875 Mdot
.42125 .53125 Mdot
.68 .52375 Mdot
.4525 .495 Mdot
.45 .4825 Mdot
.4975 .4525 Mdot
.44375 .42125 Mdot
.50875 .3825 Mdot
.59375 .44625 Mdot
.45625 .5025 Mdot
.4275 .54375 Mdot
.25 .5775 Mdot
.08125 .54875 Mdot
.455 .48125 Mdot
.61 .44875 Mdot
.465 .435 Mdot
.4625 .44 Mdot
.4925 .45875 Mdot
.5525 .4625 Mdot
.435 .49 Mdot
.44125 .51375 Mdot
.6675 .49375 Mdot
.3925 .49625 Mdot
.29375 .50625 Mdot
.9275 .4825 Mdot
.415 .43375 Mdot
.32 .4475 Mdot
.565 .44125 Mdot
.54875 .4175 Mdot
.45375 .40875 Mdot
.57 .47 Mdot
.3575 .49125 Mdot
.56625 .45125 Mdot
.51375 .46125 Mdot
.5775 .47625 Mdot
.50875 .45375 Mdot
.2875 .4225 Mdot
.55125 .44875 Mdot
.83875 .45625 Mdot
.1425 .44375 Mdot
.61625 .23125 Mdot
.7325 .3175 Mdot
.0725 .37375 Mdot
.82125 .49 Mdot
.59875 .54875 Mdot
.17375 .49375 Mdot
.59625 .4275 Mdot
.7125 .43875 Mdot
.535 .39 Mdot
.39125 .36625 Mdot
.43375 .41375 Mdot
.48625 .4275 Mdot
.52875 .40375 Mdot
.3575 .38625 Mdot
.57 .3925 Mdot
.79875 .365 Mdot
.1475 .35625 Mdot
.83625 .37 Mdot
.49125 .43 Mdot
.29625 .4275 Mdot
.35 .445 Mdot
.47125 .4275 Mdot
.865 .39875 Mdot
.33625 .3875 Mdot
.455 .37625 Mdot
.51625 .38625 Mdot
.52 .36875 Mdot
.3825 .33375 Mdot
.50125 .2625 Mdot
.75375 .20125 Mdot
.19375 .15125 Mdot
.6625 .1475 Mdot
.62125 .17 Mdot
.35875 .20375 Mdot
.3575 .215 Mdot
.63625 .19 Mdot
.655 .12875 Mdot
.44 .03375 Mdot
.56625 .07 Mdot
.80625 .1275 Mdot
.17625 .1725 Mdot
.82125 .1775 Mdot
.35125 .175 Mdot
.42625 .18875 Mdot
.39875 .185 Mdot
.66625 .18625 Mdot
.5875 .2175 Mdot
.4025 .24625 Mdot
.47875 .27 Mdot
.43625 .3 Mdot
.4975 .30875 Mdot
.3525 .325 Mdot
.8125 .32125 Mdot
.24875 .3025 Mdot
.675 .295 Mdot
.6825 .28375 Mdot
.2575 .2525 Mdot
.44375 .2325 Mdot
.5275 .22125 Mdot
.715 .2025 Mdot
.36125 .2075 Mdot
.44 .17375 Mdot
.525 .15875 Mdot
.51125 .15125 Mdot
.4325 .1475 Mdot
.5925 .20625 Mdot
.55 .295 Mdot
.09125 .34125 Mdot
.9325 .345 Mdot
.54 .35625 Mdot
.3925 .325 Mdot
.34625 .2775 Mdot
.77875 .255 Mdot
.35625 .2575 Mdot
.50125 .25625 Mdot
.52375 .28 Mdot
.44375 .30125 Mdot
.19375 .33125 Mdot
.96375 .32375 Mdot
.435 .32375 Mdot
.36125 .22 Mdot
.5625 .14 Mdot
.68 .0525 Mdot
.2825 .025 Mdot
.8975 .0275 Mdot
.37 .065 Mdot
.425 .17 Mdot
.485 .25875 Mdot
.45625 .33125 Mdot
.41375 .4125 Mdot
.72125 .4275 Mdot
.495 .36 Mdot
.3825 .27375 Mdot
.3475 .20375 Mdot
.9875 .10875 Mdot
.14375 .0625 Mdot
.36875 .04 Mdot
.87875 .05 Mdot
.40875 .06 Mdot
.4025 .0725 Mdot
.49 .0725 Mdot
.55875 .0875 Mdot
.39875 .05875 Mdot
.3375 .05875 Mdot
.945 .14125 Mdot
.25125 .1725 Mdot
.36875 .18625 Mdot
.81875 .23 Mdot
.41875 .23875 Mdot
.2575 .19125 Mdot
.63375 .21625 Mdot
.6825 .21875 Mdot
.3425 .2525 Mdot
.58375 .255 Mdot
.37375 .1725 Mdot
.53125 .10625 Mdot
.3775 .0525 Mdot
.42625 .00875 Mdot
.315 .09 Mdot
.55 .125 Mdot
.73625 .13625 Mdot
.10375 .1775 Mdot
.69875 .7125 Mdot
.87375 .675 Mdot
.08875 .645 Mdot
.65125 .54125 Mdot
.56125 .365 Mdot
.3025 .29625 Mdot
.43125 .31875 Mdot
.8075 .30375 Mdot
.6675 .32625 Mdot
.25875 .43625 Mdot
.455 .41375 Mdot
.495 .32125 Mdot
.50625 .27375 Mdot
.275 .32125 Mdot
.59875 .3775 Mdot
.02875 .57 Mdot
.71 .6325 Mdot
.495 .51125 Mdot
.36 .3425 Mdot
.27 .21375 Mdot
.455 .23625 Mdot
.18375 .325 Mdot
.43125 .4575 Mdot
.52375 .50625 Mdot
.5275 .54625 Mdot
.36 .6775 Mdot
.42125 .805 Mdot
.9725 .9375 Mdot
.605 .97625 Mdot
.36625 .8475 Mdot
.35875 .7475 Mdot
.61375 .72125 Mdot
.79875 .725 Mdot
.3825 .78625 Mdot
.41 .87625 Mdot
.46625 .84625 Mdot
.55375 .79 Mdot
.18875 .7575 Mdot
.61625 .7875 Mdot
.99125 .8075 Mdot
.0725 .8625 Mdot
.70375 .95625 Mdot
.42375 .88375 Mdot
.45 .75 Mdot
.29 .74 Mdot
.7875 .7425 Mdot
.64125 .73 Mdot
.3225 .8125 Mdot
.4925 .905 Mdot
.43125 .84 Mdot
.4725 .7575 Mdot
.2725 .7225 Mdot
.97375 .68 Mdot
.27125 .59375 Mdot
.61375 .59375 Mdot
.59 .57875 Mdot
.28 .52625 Mdot
.445 .57125 Mdot
.5975 .645 Mdot
.77125 .7125 Mdot
.28875 .82125 Mdot
.45125 .9125 Mdot
.51875 .855 Mdot
.49375 .8025 Mdot
.33375 .78625 Mdot
.73875 .765 Mdot
.55375 .7675 Mdot
.14375 .81375 Mdot
.77 .83 Mdot
.5775 .72375 Mdot
.3825 .63625 Mdot
.31625 .59 Mdot
.95125 .5625 Mdot
.26375 .575 Mdot
.4575 .6925 Mdot
.54125 .695 Mdot
.48125 .7025 Mdot
.1375 .8175 Mdot
.4825 .88 Mdot
.2875 .82 Mdot
.835 .79875 Mdot
.56375 .8875 Mdot
.21125 .98875 Mdot
.27625 .91125 Mdot
.3625 .73 Mdot
.3425 .84125 Mdot
.49125 .8775 Mdot
.5675 .7925 Mdot
.3775 .8725 Mdot
.17125 .99625 Mdot
.71875 .9375 Mdot
.855 .91875 Mdot
.19625 .94875 Mdot
.62 .99125 Mdot
.07 .85 Mdot
.07125 .945 Mdot
.535 .97125 Mdot
.49875 .985 Mdot
.3375 .92375 Mdot
.36625 .79125 Mdot
.13 .58 Mdot
.4525 .5275 Mdot
.6175 .51875 Mdot
.3975 .60875 Mdot
.3175 .695 Mdot
.59375 .7 Mdot
.94375 .705 Mdot
.3 .68875 Mdot
.3975 .60125 Mdot
.45375 .615 Mdot
.56625 .6525 Mdot
.14875 .71375 Mdot
.6175 .72875 Mdot
.6 .78625 Mdot
.4625 .84625 Mdot
.49875 .95 Mdot
.18 .97375 Mdot
.88875 .96125 Mdot
.7075 .91 Mdot
.25375 .81625 Mdot
.49875 .70625 Mdot
.41375 .705 Mdot
.46375 .8175 Mdot
.1725 .87125 Mdot
.22625 .91625 Mdot
.465 .84625 Mdot
.5225 .87375 Mdot
.43375 .91125 Mdot
.3 .89125 Mdot
.86375 .8075 Mdot
.5275 .74625 Mdot
.2325 .7025 Mdot
.62 .76 Mdot
.56875 .83625 Mdot
.415 .945 Mdot
.535 .8775 Mdot
.5325 .8675 Mdot
.10625 .755 Mdot
.5525 .51625 Mdot
.29375 .4275 Mdot
.5325 .39875 Mdot
.445 .4975 Mdot
.45875 .6 Mdot
.16 .65625 Mdot
.145 .5725 Mdot
.4125 .485 Mdot
.47625 .495 Mdot
.51125 .5975 Mdot
.13 .6625 Mdot
.9925 .6775 Mdot
.605 .605 Mdot
.315 .5325 Mdot
.415 .4725 Mdot
.57125 .5425 Mdot
.27125 .6875 Mdot
.2375 .88375 Mdot
.3525 .9425 Mdot
.04375 .7075 Mdot
.085 .3725 Mdot
.46 .285 Mdot
.5375 .28 Mdot
.45375 .36625 Mdot
.13 .4975 Mdot
.7925 .595 Mdot
.99125 .64375 Mdot
.0775 .6375 Mdot
.5 .5975 Mdot
.485 .595 Mdot
.5025 .58375 Mdot
.09125 .525 Mdot
.31375 .385 Mdot
.35125 .5175 Mdot
.5325 .64125 Mdot
.52125 .75375 Mdot
.04375 .9325 Mdot
.8675 .075 Mdot
.01375 .16125 Mdot
.51625 .10125 Mdot
.4825 .17375 Mdot
.46 .17375 Mdot
.1525 .14125 Mdot
.95875 .1075 Mdot
.885 .0825 Mdot
.14625 .0025 Mdot
.66625 .04375 Mdot
.43 .01 Mdot
.4475 .12625 Mdot
.2575 .11625 Mdot
.3525 .10875 Mdot
.51 .0925 Mdot
.26875 .15375 Mdot
.435 .225 Mdot
.11125 .38 Mdot
.445 .37 Mdot
.54625 .3925 Mdot
.4625 .37 Mdot
.235 .285 Mdot
.62625 .27125 Mdot
.23375 .27 Mdot
.42125 .31375 Mdot
.43375 .35 Mdot
.545 .3575 Mdot
.10125 .29875 Mdot
.65125 .25125 Mdot
.48 .0975 Mdot
.5 .135 Mdot
.5425 .16375 Mdot
.05625 .145 Mdot
.9775 .16375 Mdot
.76625 .20375 Mdot
.21 .18875 Mdot
.47375 .1975 Mdot
.44375 .26 Mdot
.44875 .21625 Mdot
.105 .16 Mdot
.26 .12875 Mdot
.3725 .07125 Mdot
.51375 .01 Mdot
.3925 .075 Mdot
.46875 .0525 Mdot
.61375 .04125 Mdot
.925 .0175 Mdot
.15375 .0975 Mdot
.47 .13125 Mdot
.53125 .17 Mdot
.3925 .1975 Mdot
.245 .2125 Mdot
.9825 .21875 Mdot
.52375 .18 Mdot
.27375 .15375 Mdot
.52375 .05 Mdot
.5675 .1025 Mdot
.39875 .08 Mdot
.15 .06375 Mdot
.30125 .13 Mdot
.35125 .0975 Mdot
.5225 .15125 Mdot
.56375 .15875 Mdot
.05125 .19625 Mdot
.9825 .25875 Mdot
.66625 .28625 Mdot
.3125 .2675 Mdot
.4175 .25125 Mdot
.44625 .2825 Mdot
.4675 .30125 Mdot
.135 .29875 Mdot
.11375 .3875 Mdot
.40375 .36875 Mdot
.47125 .39125 Mdot
.51125 .37625 Mdot
.105 .32375 Mdot
.5875 .26875 Mdot
.31375 .215 Mdot
.4425 .22 Mdot
.4625 .28 Mdot
.2525 .2325 Mdot
.26125 .16375 Mdot
.27 .02 Mdot
.50625 .0075 Mdot
.54875 .10875 Mdot
.3575 .15875 Mdot
.06625 .4 Mdot
.4625 .3475 Mdot
.46625 .37625 Mdot
.47625 .41 Mdot
.09375 .37375 Mdot
.775 .33875 Mdot
.47625 .17 Mdot
.49375 .18875 Mdot
.51375 .18 Mdot
.05375 .21 Mdot
.25875 .275 Mdot
.37375 .1725 Mdot
.49375 .15375 Mdot
.495 .13875 Mdot
.04125 .07375 Mdot
.80875 .51625 Mdot
.92 .4925 Mdot
.10125 .4775 Mdot
.57625 .48375 Mdot
.46 .49625 Mdot
.48875 .52375 Mdot
.15625 .52875 Mdot
.90625 .53375 Mdot
.8075 .52625 Mdot
.24625 .505 Mdot
.44375 .49 Mdot
.51 .5075 Mdot
.445 .5025 Mdot
.15375 .48875 Mdot
.655 .47875 Mdot
.0875 .4725 Mdot
.48375 .47 Mdot
.45625 .47875 Mdot
.42625 .485 Mdot
.31625 .4825 Mdot
.33875 .48375 Mdot
.4225 .555 Mdot
.545 .57625 Mdot
.49125 .60125 Mdot
.3125 .57625 Mdot
.43625 .5425 Mdot
.18125 .42875 Mdot
.54125 .43375 Mdot
.48875 .475 Mdot
.44125 .5125 Mdot
.2675 .62375 Mdot
.63125 .6675 Mdot
.9675 .65625 Mdot
.25875 .62875 Mdot
.435 .595 Mdot
.4325 .59875 Mdot
.54 .62375 Mdot
.19 .62 Mdot
.6025 .59375 Mdot
.02125 .5375 Mdot
.55 .495 Mdot
.49125 .5 Mdot
.53375 .49875 Mdot
.12375 .50125 Mdot
.89875 .5125 Mdot
.73 .52125 Mdot
.22625 .51875 Mdot
.46375 .52375 Mdot
.48 .505 Mdot
.46125 .535 Mdot
.20875 .59 Mdot
.18 .545 Mdot
.43625 .56875 Mdot
.56 .57 Mdot
.35375 .4725 Mdot
.5525 .46625 Mdot
.51125 .47 Mdot
.88 .43125 Mdot
.2225 .36 Mdot
.49875 .3075 Mdot
.49875 .3275 Mdot
.4075 .35 Mdot
.295 .38375 Mdot
.91375 .44 Mdot
.48875 .5275 Mdot
.24375 .535 Mdot
.63625 .585 Mdot
.565 .56125 Mdot
.4275 .515 Mdot
.14625 .505 Mdot
.30125 .50375 Mdot
.3825 .54 Mdot
.4975 .57 Mdot
.5725 .555 Mdot
.18125 .51375 Mdot
.8375 .4675 Mdot
.64625 .4475 Mdot
.305 .4625 Mdot
.41 .49875 Mdot
.5875 .4925 Mdot
.395 .49125 Mdot
.23125 .49625 Mdot
.16375 .4425 Mdot
.4225 .46125 Mdot
.465 .43375 Mdot
.50125 .44875 Mdot
.23125 .4725 Mdot
.50625 .485 Mdot
.29125 .50375 Mdot
.4325 .48 Mdot
.59125 .54 Mdot
.3225 .57625 Mdot
.25875 .59625 Mdot
.2625 .62375 Mdot
.3425 .55125 Mdot
.5075 .48 Mdot
.47125 .47625 Mdot
.41625 .50125 Mdot
.075 .49125 Mdot
.1125 .51125 Mdot
.4425 .53 Mdot
.54625 .545 Mdot
.51625 .57125 Mdot
.11 .5675 Mdot
.755 .55125 Mdot
.05375 .4075 Mdot
.4625 .35625 Mdot
.46625 .36 Mdot
.53875 .38375 Mdot
.19625 .40625 Mdot
.22 .48375 Mdot
.30375 .49125 Mdot
.6275 .5 Mdot
.55625 .52625 Mdot
.0125 .53375 Mdot
.74375 .365 Mdot
.6875 .4025 Mdot
.31875 .42 Mdot
.625 .43375 Mdot
.38625 .44625 Mdot
.55 .425 Mdot
.22375 .33625 Mdot
.765 .3275 Mdot
.695 .30875 Mdot
.33875 .28625 Mdot
.49625 .30625 Mdot
.50875 .38875 Mdot
.49625 .39875 Mdot
.2025 .2775 Mdot
.5825 .21875 Mdot
.865 .23 Mdot
.31875 .23625 Mdot
.72125 .15375 Mdot
.29875 .2525 Mdot
.41 .32875 Mdot
.39875 .3275 Mdot
.375 .3125 Mdot
.04625 .3575 Mdot
.4425 .32125 Mdot
.5425 .28875 Mdot
.52375 .28625 Mdot
.3275 .2375 Mdot
.4875 .18875 Mdot
.83 .215 Mdot
.26125 .25125 Mdot
.83625 .24375 Mdot
.26875 .28875 Mdot
.45875 .38 Mdot
.30625 .33875 Mdot
.58625 .305 Mdot
.92 .29375 Mdot
.33625 .29375 Mdot
.40375 .25625 Mdot
.45375 .21125 Mdot
.51875 .19625 Mdot
.2725 .17875 Mdot
.5775 .17375 Mdot
.92125 .155 Mdot
.045 .24 Mdot
.84875 .29 Mdot
.3325 .33 Mdot
.52 .35375 Mdot
.22625 .3375 Mdot
.79 .285 Mdot
.68625 .2275 Mdot
.29375 .205 Mdot
.455 .185 Mdot
.45625 .25125 Mdot
.54125 .26125 Mdot
.30625 .26 Mdot
.99125 .25875 Mdot
.175 .25875 Mdot
.44875 .24125 Mdot
.73125 .34 Mdot
.24125 .42625 Mdot
.55625 .49625 Mdot
.52875 .55375 Mdot
.76625 .56375 Mdot
.3325 .505 Mdot
.47625 .49625 Mdot
.5125 .445 Mdot
.445 .375 Mdot
.3075 .34625 Mdot
.835 .33875 Mdot
.45 .3 Mdot
.19125 .2975 Mdot
.805 .28875 Mdot
.5375 .2775 Mdot
.38875 .1475 Mdot
.29375 .06875 Mdot
.8925 .00625 Mdot
.415 .005 Mdot
.475 .11 Mdot
.58 .145 Mdot
.28875 .115 Mdot
.69125 .11375 Mdot
.64375 .105 Mdot
.3425 .08125 Mdot
.35 .08875 Mdot
.7175 .2175 Mdot
.32125 .16125 Mdot
.36375 .1025 Mdot
.43625 .0225 Mdot
.25375 .02375 Mdot
.33625 .05625 Mdot
.32875 .08625 Mdot
.4 .1225 Mdot
.505 .125 Mdot
.4575 .1925 Mdot
.46125 .1725 Mdot
.18125 .18375 Mdot
.2675 .1925 Mdot
.355 .10625 Mdot
.65125 .13375 Mdot
.50625 .09 Mdot
.1775 .0725 Mdot
.70125 .08125 Mdot
.8925 .13375 Mdot
.15 .1925 Mdot
.445 .295 Mdot
.44625 .395 Mdot
.53375 .41125 Mdot
.4475 .37375 Mdot
.965 .29375 Mdot
.26125 .2225 Mdot
.17625 .16 Mdot
.82125 .17875 Mdot
.57875 .24375 Mdot
.0375 .315 Mdot
.675 .265 Mdot
.46125 .125 Mdot
.63375 .165 Mdot
.25125 .37625 Mdot
.6475 .42125 Mdot
.58875 .425 Mdot
.44 .3675 Mdot
.55375 .22875 Mdot
.48625 .1625 Mdot
.52375 .3375 Mdot
.2725 .52125 Mdot
.54125 .5475 Mdot
.51875 .47625 Mdot
.56375 .33875 Mdot
.8925 .29125 Mdot
.17875 .18375 Mdot
.3975 .255 Mdot
.49 .30375 Mdot
.39125 .36 Mdot
.96875 .255 Mdot
.2025 .22875 Mdot
.4625 .17375 Mdot
.52 .32 Mdot
.55875 .4425 Mdot
.34375 .5575 Mdot
.54125 .59625 Mdot
.5625 .62875 Mdot
.335 .53 Mdot
.1225 .3575 Mdot
.4625 .32875 Mdot
.34625 .28875 Mdot
.5225 .26 Mdot
.85125 .2725 Mdot
.42 .22375 Mdot
.385 .215 Mdot
.48125 .335 Mdot
.49375 .4875 Mdot
.3675 .5475 Mdot
.5425 .54 Mdot
.7075 .54875 Mdot
.04875 .43 Mdot
.1825 .245 Mdot
.51875 .3375 Mdot
.305 .42375 Mdot
.66375 .4725 Mdot
.6825 .55 Mdot
.35125 .52 Mdot
.45125 .48625 Mdot
.45375 .5075 Mdot
.5575 .49125 Mdot
.42125 .4175 Mdot
.80875 .4175 Mdot
.1775 .4775 Mdot
.405 .4525 Mdot
.94 .4525 Mdot
.175 .565 Mdot
.515 .57375 Mdot
.4925 .505 Mdot
.7175 .4925 Mdot
.41375 .52375 Mdot
.47375 .50625 Mdot
.515 .64125 Mdot
.45 .75 Mdot
.4175 .7775 Mdot
.68125 .705 Mdot
.445 .67875 Mdot
.1375 .58375 Mdot
.93875 .5575 Mdot
.52 .6875 Mdot
.2875 .9275 Mdot
.8575 .77125 Mdot
.22375 .8375 Mdot
.445 .975 Mdot
.39875 .9875 Mdot
.3825 .99625 Mdot
.4475 .88625 Mdot
.52625 .86375 Mdot
.4525 .8975 Mdot
.46625 .975 Mdot
.3475 .99 Mdot
.8825 .91625 Mdot
.365 .8725 Mdot
.2625 .8425 Mdot
.83625 .8025 Mdot
.4675 .9225 Mdot
.435 .95875 Mdot
.425 .90875 Mdot
.5075 .91 Mdot
.6875 .9325 Mdot
.72375 .8875 Mdot
.28125 .90125 Mdot
.09125 .83375 Mdot
.98875 .76625 Mdot
.575 .6325 Mdot
.09375 .455 Mdot
.48125 .94625 Mdot
.46625 .92125 Mdot
.56375 .91 Mdot
.4625 .88 Mdot
.06875 .945 Mdot
.5375 .75125 Mdot
.38625 .48875 Mdot
.41125 .3275 Mdot
.5 .20125 Mdot
.60625 .17125 Mdot
.46 .28375 Mdot
.4625 .38 Mdot
.535 .3575 Mdot
.4825 .3225 Mdot
.4625 .39625 Mdot
.58125 .49625 Mdot
.4725 .6175 Mdot
.25875 .79 Mdot
.98125 .845 Mdot
.14375 .81875 Mdot
.51875 .725 Mdot
.695 .68375 Mdot
.37875 .62 Mdot
.51875 .69 Mdot
.41875 .59875 Mdot
.50625 .5675 Mdot
.5675 .54875 Mdot
.65125 .63625 Mdot
.36625 .69 Mdot
.44875 .86375 Mdot
.0675 .8125 Mdot
.1675 .56875 Mdot
.4575 .52875 Mdot
.605 .46625 Mdot
.4125 .57125 Mdot
.48125 .735 Mdot
.525 .8225 Mdot
.46625 .7 Mdot
.4825 .61 Mdot
.465 .6025 Mdot
.61125 .64875 Mdot
.485 .68625 Mdot
.1825 .81875 Mdot
.40125 .67625 Mdot
.315 .5725 Mdot
.52375 .47375 Mdot
.69 .41875 Mdot
.36625 .44625 Mdot
.45875 .565 Mdot
.3775 .53625 Mdot
.475 .49375 Mdot
.8775 .47625 Mdot
.50625 .50625 Mdot
.325 .54125 Mdot
.02 .71375 Mdot
.55875 .93125 Mdot
.51875 .08875 Mdot
.0925 .13 Mdot
.9725 .1475 Mdot
.76625 .13625 Mdot
.06125 .06 Mdot
.49 .1025 Mdot
.78 .07 Mdot
.48625 .04 Mdot
.27625 .03 Mdot
.3175 .02875 Mdot
.48625 .04 Mdot
.37875 .02375 Mdot
.0825 .00375 Mdot
.0375 .0375 Mdot
.4375 .0025 Mdot
.50125 .045 Mdot
.65625 .0525 Mdot
.40125 .08875 Mdot
.47375 .08875 Mdot
.42625 .05875 Mdot
.60125 .0275 Mdot
.63875 .0175 Mdot
.3825 .01125 Mdot
.0675 .0075 Mdot
.48125 .02625 Mdot
.53125 .04 Mdot
.48 .11875 Mdot
.46125 .19 Mdot
.04 .21125 Mdot
.5475 .30125 Mdot
.39125 .2875 Mdot
.52125 .28125 Mdot
.3975 .30875 Mdot
.47375 .27375 Mdot
.55125 .26625 Mdot
.45625 .255 Mdot
.5125 .245 Mdot
.56375 .23 Mdot
.45 .2075 Mdot
.49875 .20375 Mdot
.5175 .2025 Mdot
.21 .21125 Mdot
.09125 .23375 Mdot
.53125 .21875 Mdot
.63625 .1975 Mdot
.39125 .1925 Mdot
.54 .1575 Mdot
.4 .2 Mdot
.505 .20625 Mdot
.63875 .20375 Mdot
.52625 .14625 Mdot
.4275 .18875 Mdot
.4425 .08375 Mdot
.15875 .2075 Mdot
.41375 .1725 Mdot
.49 .245 Mdot
.4325 .24125 Mdot
.56125 .20625 Mdot
.51625 .1625 Mdot
.46125 .1825 Mdot
.49375 .23 Mdot
.495 .225 Mdot
.4875 .2025 Mdot
.5475 .2075 Mdot
.2025 .1775 Mdot
.40125 .16875 Mdot
.3775 .205 Mdot
.50375 .2325 Mdot
.545 .25625 Mdot
.45875 .28875 Mdot
.475 .31375 Mdot
.3625 .32375 Mdot
.465 .3525 Mdot
.92875 .35375 Mdot
.42875 .39625 Mdot
.3475 .39375 Mdot
.0075 .3325 Mdot
.625 .1925 Mdot
.12375 .115 Mdot
.5375 .55125 Mdot
.1325 .50625 Mdot
.945 .47 Mdot
.72375 .47 Mdot
.09 .495 Mdot
.79125 .55125 Mdot
.34625 .59 Mdot
.46125 .615 Mdot
.44375 .63375 Mdot
.42125 .60125 Mdot
.7925 .5825 Mdot
.395 .58375 Mdot
.5825 .5575 Mdot
.41375 .5225 Mdot
.4975 .45875 Mdot
.055 .445 Mdot
.71 .4375 Mdot
.45625 .50625 Mdot
.4925 .515 Mdot
.4925 .5075 Mdot
.45375 .50125 Mdot
.57125 .5025 Mdot
.4175 .51375 Mdot
.48875 .5125 Mdot
.625 .50625 Mdot
.45875 .525 Mdot
.485 .51875 Mdot
.33125 .52125 Mdot
.3025 .5125 Mdot
.49375 .5225 Mdot
.47875 .5225 Mdot
.42 .5375 Mdot
.58375 .55125 Mdot
.71125 .5475 Mdot
.3175 .53125 Mdot
.48875 .5275 Mdot
.50875 .52 Mdot
.49375 .49625 Mdot
.48625 .49875 Mdot
.4275 .5025 Mdot
.1075 .51625 Mdot
.03375 .55625 Mdot
.48 .57875 Mdot
.44625 .60375 Mdot
.465 .60375 Mdot
.6775 .615 Mdot
.4575 .57 Mdot
.4325 .535 Mdot
.43 .52375 Mdot
.59625 .5025 Mdot
.625 .48875 Mdot
.405 .52625 Mdot
.28375 .51375 Mdot
.50625 .48625 Mdot
.10875 .5225 Mdot
.4475 .52625 Mdot
.4775 .5725 Mdot
.575 .60875 Mdot
.56375 .59875 Mdot
.51625 .605 Mdot
.46375 .5825 Mdot
.49375 .55 Mdot
.50625 .5225 Mdot
.4775 .50375 Mdot
.47375 .45625 Mdot
.1 .4525 Mdot
.5275 .4775 Mdot
.43 .5 Mdot
.485 .54 Mdot
.39375 .53875 Mdot
.495 .54375 Mdot
.625 .53125 Mdot
.41125 .52375 Mdot
.51 .515 Mdot
.53375 .5575 Mdot
.4825 .56 Mdot
.48875 .5375 Mdot
.55875 .505 Mdot
.21875 .47875 Mdot
.98125 .42125 Mdot
.18625 .43125 Mdot
.51625 .46375 Mdot
.635 .505 Mdot
.34625 .5125 Mdot
.6325 .525 Mdot
.3925 .5125 Mdot
.49625 .505 Mdot
.5875 .5025 Mdot
.52125 .5175 Mdot
.46625 .505 Mdot
.465 .5425 Mdot
.03125 .545 Mdot
.14875 .52875 Mdot
.4575 .5575 Mdot
.51375 .5475 Mdot
.38875 .5425 Mdot
.63875 .55625 Mdot
.505 .57125 Mdot
.45375 .55625 Mdot
.49375 .50125 Mdot
.45625 .46875 Mdot
.50625 .49875 Mdot
.585 .49125 Mdot
.205 .4975 Mdot
.935 .55 Mdot
.3825 .61875 Mdot
.4225 .60125 Mdot
.51 .60125 Mdot
.48375 .61625 Mdot
.4775 .5825 Mdot
.59625 .5475 Mdot
.33375 .535 Mdot
.4375 .525 Mdot
.8775 .515 Mdot
.4325 .53125 Mdot
.38125 .51875 Mdot
.1 .53625 Mdot
.5225 .58 Mdot
.2525 .58625 Mdot
.53625 .32 Mdot
.21375 .32125 Mdot
.8675 .35 Mdot
.6575 .36 Mdot
.1525 .39375 Mdot
.7125 .3875 Mdot
.395 .3875 Mdot
.38625 .36625 Mdot
.47875 .3325 Mdot
.6325 .32125 Mdot
.62 .3125 Mdot
.4 .2975 Mdot
.5525 .31625 Mdot
.47 .35125 Mdot
.50375 .365 Mdot
.1525 .3575 Mdot
.66 .3575 Mdot
.115 .29 Mdot
.46125 .27375 Mdot
.50125 .255 Mdot
.4825 .2475 Mdot
.32 .2625 Mdot
.8525 .2925 Mdot
.28 .28375 Mdot
.4925 .29 Mdot
.57125 .285 Mdot
.4925 .24625 Mdot
.4925 .255 Mdot
.41375 .25625 Mdot
.33375 .2625 Mdot
.0875 .2825 Mdot
.49625 .26125 Mdot
.47375 .29 Mdot
.39625 .29125 Mdot
.48 .2725 Mdot
.92875 .2775 Mdot
.21875 .2375 Mdot
.4975 .185 Mdot
.50375 .14875 Mdot
.48125 .12125 Mdot
.45 .15 Mdot
.535 .1475 Mdot
.2 .1625 Mdot
.17125 .16875 Mdot
.4875 .14125 Mdot
.46625 .15875 Mdot
.39 .15875 Mdot
.7 .1425 Mdot
.56875 .19375 Mdot
.35875 .1975 Mdot
.455 .17625 Mdot
.53875 .19 Mdot
.62 .18125 Mdot
.42625 .195 Mdot
.355 .23 Mdot
.50625 .2525 Mdot
.8775 .275 Mdot
.24625 .33625 Mdot
.4375 .345 Mdot
.4675 .30625 Mdot
.475 .285 Mdot
.70125 .24125 Mdot
.52625 .1675 Mdot
.4075 .09875 Mdot
.50125 .0725 Mdot
.48625 .06875 Mdot
.51 .1175 Mdot
.46 .195 Mdot
.21 .24875 Mdot
.90625 .26375 Mdot
.49375 .28375 Mdot
.50375 .28375 Mdot
.45625 .27375 Mdot
.37625 .31375 Mdot
.44625 .37875 Mdot
.80125 .37875 Mdot
.30375 .325 Mdot
.51375 .26375 Mdot
.52875 .11625 Mdot
.495 .0575 Mdot
.47875 .02 Mdot
.84625 .07375 Mdot
.295 .0625 Mdot
.475 .07125 Mdot
.6 .08125 Mdot
.28125 .1 Mdot
.82 .0875 Mdot
.36 .085 Mdot
.4375 .07625 Mdot
.5925 .07125 Mdot
.4825 .07125 Mdot
.505 .125 Mdot
.46625 .125 Mdot
.165 .1475 Mdot
.28375 .1525 Mdot
.49125 .05875 Mdot
.53875 .03625 Mdot
.24375 .0325 Mdot
.79875 .02125 Mdot
.50375 .01125 Mdot
.405 .04875 Mdot
.485 .05125 Mdot
.4575 .0425 Mdot
.4975 .12125 Mdot
.59625 .12375 Mdot
.26625 .1275 Mdot
.835 .14 Mdot
.39 .125 Mdot
.42875 .05625 Mdot
.58625 .0675 Mdot
.3525 .04125 Mdot
.5025 .05375 Mdot
.755 .1025 Mdot
.2475 .08875 Mdot
.49 .065 Mdot
.7575 .0575 Mdot
.46125 .06375 Mdot
.3925 .00875 Mdot
.2475 .07625 Mdot
.855 .14 Mdot
.46875 .21375 Mdot
.38 .2175 Mdot
.5675 .25 Mdot
.3075 .24625 Mdot
.7475 .28 Mdot
.62125 .26625 Mdot
.24625 .12125 Mdot
.6325 .0025 Mdot
.52 .16875 Mdot
.265 .21375 Mdot
.58375 .23625 Mdot
.92125 .3075 Mdot
.2325 .26375 Mdot
.475 .13 Mdot
.48375 .13125 Mdot
.48625 .175 Mdot
.2125 .18375 Mdot
.2075 .25 Mdot
.46375 .30875 Mdot
.53125 .34375 Mdot
.48625 .40625 Mdot
.51 .4975 Mdot
.505 .46375 Mdot
.36125 .4475 Mdot
.9225 .405 Mdot
.255 .35 Mdot
.49875 .225 Mdot
.5 .205 Mdot
.37875 .18375 Mdot
.35375 .1975 Mdot
.19875 .2675 Mdot
.495 .32 Mdot
.4875 .385 Mdot
.51625 .47 Mdot
.425 .565 Mdot
.57625 .6075 Mdot
.3075 .595 Mdot
.88375 .54125 Mdot
.2925 .5075 Mdot
.4925 .425 Mdot
.485 .32625 Mdot
.34875 .31875 Mdot
.6375 .34625 Mdot
.7075 .3025 Mdot
.31375 .34125 Mdot
.445 .4225 Mdot
.5475 .45375 Mdot
.5825 .56625 Mdot
.4525 .62625 Mdot
.41625 .59125 Mdot
.51125 .53 Mdot
.6925 .44625 Mdot
.37125 .2725 Mdot
.47 .15625 Mdot
.45 .1625 Mdot
.39125 .2 Mdot
.75875 .2725 Mdot
.57375 .40625 Mdot
.36 .5725 Mdot
.5225 .6475 Mdot
.44625 .69 Mdot
.53 .69875 Mdot
.45875 .69125 Mdot
.33125 .63625 Mdot
.76625 .645 Mdot
.49875 .5925 Mdot
.515 .5275 Mdot
.4825 .45625 Mdot
.33625 .43 Mdot
.42375 .38875 Mdot
.925 .47625 Mdot
.23125 .63875 Mdot
.50375 .825 Mdot
.395 .9325 Mdot
.46 .7525 Mdot
.56625 .7075 Mdot
.215 .74875 Mdot
.99875 .7875 Mdot
.27625 .82 Mdot
.4325 .9025 Mdot
.575 .95125 Mdot
.4875 .9225 Mdot
.52 .93125 Mdot
.4575 .925 Mdot
.295 .875 Mdot
.84375 .835 Mdot
.3775 .8175 Mdot
.50875 .7475 Mdot
.54625 .71875 Mdot
.14875 .7325 Mdot
.94625 .775 Mdot
.485 .8175 Mdot
.3625 .90125 Mdot
.44625 .9975 Mdot
.45 .985 Mdot
.6325 .87875 Mdot
.2175 .87875 Mdot
.56125 .925 Mdot
.8575 .93625 Mdot
.67375 .9225 Mdot
.4475 .63375 Mdot
.43125 .49625 Mdot
.54125 .89125 Mdot
.50375 .81875 Mdot
.4825 .73625 Mdot
.5675 .78 Mdot
.37875 .91125 Mdot
.39875 .995 Mdot
.5575 .945 Mdot
.48375 .95625 Mdot
.54125 .89375 Mdot
.44375 .8725 Mdot
.445 .8475 Mdot
.58 .8475 Mdot
.47 .8725 Mdot
.5425 .9875 Mdot
.30375 .89625 Mdot
.49875 .7375 Mdot
.4575 .5625 Mdot
.47 .4575 Mdot
.63 .40125 Mdot
.435 .43375 Mdot
.495 .495 Mdot
.51 .56375 Mdot
.45375 .6475 Mdot
.66875 .73 Mdot
.13125 .7375 Mdot
.585 .68625 Mdot
.925 .63875 Mdot
.17875 .54375 Mdot
.59875 .39875 Mdot
.4875 .27625 Mdot
.53625 .1925 Mdot
.485 .1275 Mdot
.4425 .3975 Mdot
.51375 .69625 Mdot
.4825 .06125 Mdot
.36875 .10375 Mdot
.24125 .14625 Mdot
.1075 .10875 Mdot
.0275 .02 Mdot
.04375 .00875 Mdot
.45875 .00375 Mdot
.06 .03 Mdot
.20375 .06875 Mdot
.3525 .02 Mdot
.5425 .015 Mdot
.485 .045 Mdot
.54 .06875 Mdot
.41 .125 Mdot
.58125 .21125 Mdot
.4175 .27625 Mdot
.50125 .2525 Mdot
.575 .28 Mdot
.53625 .26 Mdot
.0125 .1675 Mdot
.51375 .1275 Mdot
.275 .115 Mdot
.48375 .14625 Mdot
.4825 .2075 Mdot
.47625 .2625 Mdot
.57625 .27875 Mdot
.4425 .26875 Mdot
.515 .285 Mdot
.49125 .2775 Mdot
.45875 .2625 Mdot
.66 .30875 Mdot
.115 .305 Mdot
.6325 .2925 Mdot
.9425 .29 Mdot
.17125 .2725 Mdot
.6 .22625 Mdot
.4675 .2475 Mdot
.53875 .24 Mdot
.505 .26 Mdot
.45125 .22875 Mdot
.46625 .13625 Mdot
.41125 .01 Mdot
.61875 .54625 Mdot
.5075 .56875 Mdot
.42375 .53875 Mdot
.55875 .50625 Mdot
.49125 .48875 Mdot
.45875 .4025 Mdot
.4825 .39625 Mdot
.40125 .3875 Mdot
.23375 .38125 Mdot
.1 .41 Mdot
.45375 .42125 Mdot
.4775 .45375 Mdot
.45625 .48 Mdot
.545 .49875 Mdot
.4425 .52375 Mdot
.5175 .53625 Mdot
.5725 .5225 Mdot
.51625 .5275 Mdot
.47375 .5275 Mdot
.43125 .5175 Mdot
.47 .51375 Mdot
.2275 .48 Mdot
.075 .455 Mdot
.4825 .46875 Mdot
.47625 .4575 Mdot
.435 .50625 Mdot
.54125 .53375 Mdot
.59375 .56 Mdot
.47875 .56875 Mdot
.47375 .5925 Mdot
.50125 .57 Mdot
.47125 .51625 Mdot
.53125 .50125 Mdot
.35875 .59875 Mdot
.23 .67125 Mdot
.07375 .92 Mdot
.525 .95375 Mdot
.45 .8475 Mdot
.45625 .74875 Mdot
.5025 .64 Mdot
.63 .5025 Mdot
.3775 .4675 Mdot
.545 .44875 Mdot
.5075 .4425 Mdot
.53 .43625 Mdot
.475 .4925 Mdot
.28125 .55375 Mdot
.54 .60375 Mdot
.925 .6575 Mdot
.235 .685 Mdot
.48375 .6875 Mdot
.49125 .6525 Mdot
.50875 .6225 Mdot
.51875 .59 Mdot
.565 .58875 Mdot
.435 .57875 Mdot
.4825 .57375 Mdot
.5525 .54125 Mdot
.44 .47875 Mdot
.49375 .50625 Mdot
.255 .5125 Mdot
.9025 .52 Mdot
.56 .54 Mdot
.32 .60375 Mdot
.515 .595 Mdot
.47125 .59125 Mdot
.47875 .59375 Mdot
.47875 .625 Mdot
.515 .60375 Mdot
.615 .57625 Mdot
.42375 .55125 Mdot
.52375 .53625 Mdot
.515 .4725 Mdot
.315 .48 Mdot
.3925 .4775 Mdot
.095 .4875 Mdot
.4675 .53375 Mdot
.53875 .52625 Mdot
.48625 .54125 Mdot
.48125 .55 Mdot
.54375 .54125 Mdot
.5075 .5275 Mdot
.455 .5275 Mdot
.5675 .51375 Mdot
.42625 .4675 Mdot
.5075 .42875 Mdot
.1 .44 Mdot
.22875 .47875 Mdot
.36375 .53125 Mdot
.55125 .57875 Mdot
.4925 .56625 Mdot
.46375 .555 Mdot
.51 .52375 Mdot
.58625 .48 Mdot
.3925 .4375 Mdot
.48625 .44875 Mdot
.585 .42625 Mdot
.52625 .41125 Mdot
.08375 .44125 Mdot
.5075 .47 Mdot
.30125 .49125 Mdot
.49375 .5025 Mdot
.4875 .50625 Mdot
.46 .50625 Mdot
.5225 .52375 Mdot
.58625 .53375 Mdot
.46375 .535 Mdot
.49 .54375 Mdot
.4425 .56875 Mdot
.6225 .54125 Mdot
.19375 .52125 Mdot
.62875 .50625 Mdot
.8275 .4825 Mdot
.23 .45125 Mdot
.61375 .46375 Mdot
.46125 .4875 Mdot
.5275 .5025 Mdot
.40875 .5 Mdot
.6375 .49 Mdot
.44625 .51625 Mdot
.355 .525 Mdot
.51375 .52875 Mdot
.60125 .56125 Mdot
.47 .54125 Mdot
.6025 .535 Mdot
.44 .51 Mdot
.45 .4925 Mdot
.51375 .50375 Mdot
.50125 .48 Mdot
.485 .46375 Mdot
.22 .45875 Mdot
.22625 .4425 Mdot
.4425 .49625 Mdot
.5025 .5175 Mdot
.415 .56 Mdot
.48375 .63125 Mdot
.46375 .61625 Mdot
.6825 .58125 Mdot
.48125 .54875 Mdot
.5 .47 Mdot
.48875 .38 Mdot
.4025 .39375 Mdot
.49625 .41625 Mdot
.3475 .44125 Mdot
.2175 .4775 Mdot
.4825 .4675 Mdot
.50625 .47375 Mdot
.445 .43875 Mdot
.3775 .43 Mdot
.75625 .42 Mdot
.50125 .4 Mdot
.4425 .35375 Mdot
.48125 .35 Mdot
.43625 .3675 Mdot
.55375 .37875 Mdot
.40375 .335 Mdot
.27625 .31125 Mdot
.20625 .24625 Mdot
.54125 .27 Mdot
.43875 .30875 Mdot
.4525 .34375 Mdot
.40125 .4025 Mdot
.81 .4425 Mdot
.3175 .41375 Mdot
.51625 .43625 Mdot
.52375 .425 Mdot
.54125 .3675 Mdot
.46125 .36125 Mdot
.35375 .35125 Mdot
.48 .34625 Mdot
.8325 .3675 Mdot
.31625 .44375 Mdot
.47875 .4375 Mdot
.50375 .44875 Mdot
.43125 .46125 Mdot
.52125 .44 Mdot
.76 .40875 Mdot
.30625 .40625 Mdot
.485 .4275 Mdot
.54 .46125 Mdot
.4275 .5125 Mdot
.5475 .49125 Mdot
.3275 .46875 Mdot
.745 .44125 Mdot
.56625 .395 Mdot
.36625 .3225 Mdot
.51375 .32 Mdot
.4775 .3575 Mdot
.35875 .3375 Mdot
.6375 .31875 Mdot
.545 .3425 Mdot
.52375 .3625 Mdot
.44 .32875 Mdot
.525 .31 Mdot
.5075 .30875 Mdot
.355 .285 Mdot
.44 .25875 Mdot
.96625 .24875 Mdot
.19875 .255 Mdot
.46875 .2375 Mdot
.4825 .24375 Mdot
.56375 .22875 Mdot
.365 .21125 Mdot
.7475 .1975 Mdot
.435 .195 Mdot
.4325 .185 Mdot
.5425 .18375 Mdot
.43625 .2375 Mdot
.515 .25 Mdot
.2 .24875 Mdot
.285 .255 Mdot
.3975 .20125 Mdot
.54625 .18625 Mdot
.4925 .165 Mdot
.30375 .13625 Mdot
.725 .11875 Mdot
.59625 .115 Mdot
.35625 .10125 Mdot
.46625 .095 Mdot
.55875 .14375 Mdot
.4925 .15 Mdot
.23 .13875 Mdot
.89875 .1475 Mdot
.49375 .16 Mdot
.34 .12625 Mdot
.53 .11625 Mdot
.49625 .08625 Mdot
.43625 .0475 Mdot
.44375 .0125 Mdot
.675 .0375 Mdot
.36125 .13125 Mdot
.56625 .18625 Mdot
.47375 .19125 Mdot
.51375 .17625 Mdot
.2975 .17125 Mdot
.88875 .225 Mdot
.35125 .27125 Mdot
.3325 .3725 Mdot
.49375 .47625 Mdot
.40375 .02625 Mdot
.5075 .02875 Mdot
.46125 .0275 Mdot
.45875 .00625 Mdot
.25 .11125 Mdot
.49625 .115 Mdot
.55 .1425 Mdot
.54 .21625 Mdot
.46125 .27625 Mdot
.37 .275 Mdot
.52 .295 Mdot
.69625 .26 Mdot
.395 .13625 Mdot
.48375 .0725 Mdot
.47625 .05 Mdot
.36125 .0675 Mdot
.54 .13875 Mdot
.94 .20625 Mdot
.19 .21875 Mdot
.48 .23 Mdot
.54 .19125 Mdot
.4325 .1975 Mdot
.535 .225 Mdot
.4 .25375 Mdot
.67625 .25875 Mdot
.51875 .2975 Mdot
.40625 .25875 Mdot
.51875 .165 Mdot
.51375 .06 Mdot
.24875 .0425 Mdot
.74 .02 Mdot
.5825 .015 Mdot
.4575 .07125 Mdot
.44625 .185 Mdot
.5025 .305 Mdot
.5225 .4975 Mdot
.41625 .53375 Mdot
.43 .5125 Mdot
.83375 .46375 Mdot
.2825 .34625 Mdot
.47875 .1925 Mdot
.48125 .1525 Mdot
.545 .17125 Mdot
.30625 .19875 Mdot
.96375 .2125 Mdot
.30625 .215 Mdot
.41625 .2325 Mdot
.53375 .26375 Mdot
.45125 .375 Mdot
.5325 .46625 Mdot
.26875 .505 Mdot
.91625 .54375 Mdot
.38625 .5275 Mdot
.405 .4375 Mdot
.5525 .33625 Mdot
.46875 .35125 Mdot
.1825 .41 Mdot
.89 .475 Mdot
.61 .53125 Mdot
.32625 .66375 Mdot
.43375 .73375 Mdot
.56 .80875 Mdot
.4925 .90625 Mdot
.325 .94125 Mdot
.7625 .94625 Mdot
.49625 .93625 Mdot
.3425 .89375 Mdot
.57125 .84625 Mdot
.5175 .85 Mdot
.42 .92125 Mdot
.39 .98375 Mdot
.24875 .46375 Mdot
.34375 .27875 Mdot
.49875 .0075 Mdot
.50375 .89375 Mdot
.4275 .85125 Mdot
.60625 .79625 Mdot
.50125 .75625 Mdot
.37125 .79375 Mdot
.58625 .80625 Mdot
.5275 .775 Mdot
.4125 .72 Mdot
.36125 .65125 Mdot
.22625 .50125 Mdot
.49125 .4025 Mdot
.48375 .32375 Mdot
.47625 .27125 Mdot
.45375 .2725 Mdot
.59375 .27625 Mdot
.49625 .29125 Mdot
.495 .34625 Mdot
.53375 .395 Mdot
.52125 .51625 Mdot
.47 .6075 Mdot
.5275 .0125 Mdot
.52875 .03 Mdot
.495 .00875 Mdot
.48625 .0275 Mdot
.39375 .03625 Mdot
.60875 .06625 Mdot
.52 .13 Mdot
.41125 .16625 Mdot
.38875 .22625 Mdot
.1775 .32125 Mdot
.49625 .31 Mdot
.4675 .315 Mdot
.48125 .30125 Mdot
.49125 .28 Mdot
.56 .25 Mdot
.485 .22375 Mdot
.505 .19875 Mdot
.53625 .2025 Mdot
.51 .22 Mdot
.44125 .21625 Mdot
.085 .09375 Mdot
.3325 .0225 Mdot
.51 .025 Mdot
.52125 .415 Mdot
.11625 .43375 Mdot
.005 .46625 Mdot
.43375 .445 Mdot
.56625 .435 Mdot
.5 .42375 Mdot
.53625 .43 Mdot
.44375 .43125 Mdot
.5225 .42875 Mdot
.51 .45125 Mdot
.55 .4725 Mdot
.47375 .45375 Mdot
.46 .46375 Mdot
.325 .48 Mdot
.32 .4775 Mdot
.14625 .58625 Mdot
.4325 .635 Mdot
.495 .66875 Mdot
.46125 .69 Mdot
.51375 .695 Mdot
.5175 .65875 Mdot
.4525 .61625 Mdot
.48125 .61125 Mdot
.495 .58 Mdot
.58 .5175 Mdot
.48 .48 Mdot
.02375 .47125 Mdot
.55 .43 Mdot
.2275 .4625 Mdot
.53 .51625 Mdot
.3825 .53 Mdot
.51125 .5325 Mdot
.55625 .53625 Mdot
.4875 .51125 Mdot
.49875 .475 Mdot
.5325 .47 Mdot
.58875 .4875 Mdot
.4675 .5075 Mdot
.40625 .54875 Mdot
.02 .6125 Mdot
.17625 .67625 Mdot
.4875 .64875 Mdot
.49375 .63 Mdot
.46625 .63 Mdot
.58625 .60625 Mdot
.42625 .5975 Mdot
.4875 .58625 Mdot
.5025 .56125 Mdot
.5225 .49125 Mdot
.515 .39625 Mdot
.4375 .37625 Mdot
.16125 .3975 Mdot
.765 .4275 Mdot
.46625 .525 Mdot
.49375 .505 Mdot
.48 .50875 Mdot
.4875 .50875 Mdot
.525 .53 Mdot
.46875 .6 Mdot
.62625 .64625 Mdot
.44625 .6375 Mdot
.495 .6125 Mdot
.5075 .575 Mdot
.14 .5175 Mdot
.8275 .48125 Mdot
.74125 .47125 Mdot
.31 .53625 Mdot
.5175 .59625 Mdot
.46625 .62875 Mdot
.49375 .6675 Mdot
.46125 .72625 Mdot
.4925 .735 Mdot
.51 .7275 Mdot
.5125 .68125 Mdot
.46875 .7 Mdot
.475 .65375 Mdot
.63625 .56875 Mdot
.06375 .52375 Mdot
.09375 .49875 Mdot
.465 .5 Mdot
.495 .51125 Mdot
.45125 .51 Mdot
.515 .50625 Mdot
.44875 .4875 Mdot
.545 .4725 Mdot
.55375 .48625 Mdot
.46375 .505 Mdot
.52875 .48375 Mdot
.51375 .48875 Mdot
.51375 .49375 Mdot
.30625 .5175 Mdot
.4825 .5325 Mdot
.52375 .5375 Mdot
.5025 .54625 Mdot
.4925 .53625 Mdot
.44375 .5775 Mdot
.5925 .61875 Mdot
.3925 .6425 Mdot
.56375 .65125 Mdot
.51375 .66125 Mdot
.445 .655 Mdot
.41 .64625 Mdot
.9175 .63125 Mdot
.26125 .6375 Mdot
.49875 .63625 Mdot
.44375 .60375 Mdot
.4975 .5875 Mdot
.46625 .58125 Mdot
.5275 .58875 Mdot
.6325 .6025 Mdot
.39625 .61875 Mdot
.5475 .6025 Mdot
.51125 .5775 Mdot
.44375 .525 Mdot
.07875 .4875 Mdot
.12375 .40125 Mdot
.49375 .375 Mdot
.3925 .4025 Mdot
.535 .51625 Mdot
.1725 .50625 Mdot
.12625 .47875 Mdot
.45625 .48375 Mdot
.55 .4675 Mdot
.48 .44 Mdot
.5275 .46375 Mdot
.4425 .46875 Mdot
.39 .455 Mdot
.735 .43375 Mdot
.52 .42375 Mdot
.40625 .395 Mdot
.50625 .405 Mdot
.37125 .41125 Mdot
.3125 .43875 Mdot
.245 .46625 Mdot
.455 .4525 Mdot
.51 .465 Mdot
.46875 .4575 Mdot
.50375 .4375 Mdot
.5075 .43125 Mdot
.32625 .4675 Mdot
.685 .46125 Mdot
.46125 .46125 Mdot
.53 .45625 Mdot
.465 .49625 Mdot
.20375 .465 Mdot
1 .43625 Mdot
.50875 .44375 Mdot
.31875 .47 Mdot
.50625 .40875 Mdot
.41875 .39375 Mdot
.5025 .42625 Mdot
.54375 .4225 Mdot
.4675 .4525 Mdot
.4325 .51125 Mdot
.725 .53625 Mdot
.48625 .53625 Mdot
.46125 .5325 Mdot
.42 .52375 Mdot
.15875 .505 Mdot
.275 .47 Mdot
.5075 .48125 Mdot
.485 .44875 Mdot
.4725 .41875 Mdot
.575 .43 Mdot
.4275 .41625 Mdot
.35625 .4075 Mdot
.735 .42875 Mdot
.4225 .465 Mdot
.52875 .6275 Mdot
.41875 .64 Mdot
.22 .63875 Mdot
.7925 .63375 Mdot
.9575 .63375 Mdot
.10625 .49125 Mdot
.45125 .50625 Mdot
.505 .525 Mdot
.4725 .5125 Mdot
.48625 .47625 Mdot
.495 .4525 Mdot
.4225 .4125 Mdot
.79375 .38125 Mdot
.37125 .37875 Mdot
.5 .4075 Mdot
.50125 .43375 Mdot
.2375 .47375 Mdot
.68 .505 Mdot
.7175 .535 Mdot
.37125 .53 Mdot
.54 .51375 Mdot
.42625 .47375 Mdot
.515 .455 Mdot
.44875 .41625 Mdot
.4025 .37 Mdot
.6575 .35625 Mdot
.5275 .3675 Mdot
.40875 .34125 Mdot
.52125 .37625 Mdot
.5625 .405 Mdot
.1825 .37875 Mdot
.17125 .425 Mdot
.50375 .41375 Mdot
.4775 .42625 Mdot
.42 .45875 Mdot
.56125 .47625 Mdot
.445 .4675 Mdot
.5025 .455 Mdot
.72125 .41 Mdot
.33 .3625 Mdot
.5225 .325 Mdot
.53625 .3 Mdot
.14 .26875 Mdot
.9275 .28125 Mdot
.485 .31625 Mdot
.3675 .31875 Mdot
.4925 .3075 Mdot
.56625 .33125 Mdot
.47625 .3475 Mdot
.485 .35 Mdot
.34375 .33125 Mdot
.8025 .32375 Mdot
.30625 .3075 Mdot
.5175 .285 Mdot
.5125 .26625 Mdot
.48625 .2175 Mdot
.48375 .165 Mdot
.7375 .1375 Mdot
.36 .125 Mdot
.5175 .09875 Mdot
.415 .13875 Mdot
.4975 .1575 Mdot
.43375 .17 Mdot
.48375 .16625 Mdot
.84125 .1675 Mdot
.2525 .1375 Mdot
.55375 .11 Mdot
.51125 .16875 Mdot
.46125 .20375 Mdot
.16375 .245 Mdot
.21875 .47 Mdot
.6025 .4475 Mdot
.325 .47625 Mdot
.49625 .02 Mdot
.38375 .06 Mdot
.38875 .07625 Mdot
.9675 .03375 Mdot
.46625 .04125 Mdot
.3925 .0075 Mdot
.5125 .02875 Mdot
.3275 .0875 Mdot
.58 .1025 Mdot
.6925 .0875 Mdot
.39625 .04625 Mdot
.4925 .05875 Mdot
.6025 .06875 Mdot
.24375 .10375 Mdot
.92 .0575 Mdot
.3 .01625 Mdot
.48 .00125 Mdot
.88375 .0575 Mdot
.2025 .09625 Mdot
.52 .27875 Mdot
.535 .335 Mdot
.27 .38625 Mdot
.775 .41375 Mdot
.4575 .42875 Mdot
.42375 .385 Mdot
.505 .41375 Mdot
.5575 .41125 Mdot
.47625 .3475 Mdot
.48 .36125 Mdot
.24375 .4175 Mdot
.2225 .57 Mdot
.48625 .7625 Mdot
.49125 .89875 Mdot
.51375 .935 Mdot
.5425 .97 Mdot
.6025 .98125 Mdot
.43125 .9575 Mdot
.54125 .98875 Mdot
.49375 .98875 Mdot
.90125 .8825 Mdot
.355 .57375 Mdot
.67 .31875 Mdot
.25875 .185 Mdot
.10875 .99125 Mdot
.41875 .7625 Mdot
.4975 .53 Mdot
.5425 .4775 Mdot
.55125 .43125 Mdot
.5175 .41625 Mdot
.495 .46125 Mdot
.60875 .46375 Mdot
.38 .4175 Mdot
.47625 .43375 Mdot
.33875 .42375 Mdot
.39 .4175 Mdot
.03 .44375 Mdot
.52875 .38625 Mdot
.50625 .265 Mdot
.51 .25625 Mdot
.35875 .27625 Mdot
.64375 .47125 Mdot
.4725 .72875 Mdot
.545 .1025 Mdot
.4775 .05 Mdot
.56875 .0375 Mdot
.46875 .02375 Mdot
.45875 .015 Mdot
.50875 .0675 Mdot
.435 .12625 Mdot
.0025 .16875 Mdot
.17625 .1975 Mdot
.38625 .0275 Mdot
.455 .05 Mdot
.47125 .1375 Mdot
.56375 .1025 Mdot
.495 .045 Mdot
.48375 .15 Mdot
.44625 .25125 Mdot
.1525 .285 Mdot
.42375 .05625 Mdot
.47375 .03125 Mdot
.48875 .04875 Mdot
.22125 .03375 Mdot
.395 .02 Mdot
.45 .095 Mdot
.595 .15875 Mdot
.3875 .0975 Mdot
.0425 .09125 Mdot
.37 .155 Mdot
.495 .2425 Mdot
.55375 .3075 Mdot
.55125 .3425 Mdot
.4775 .345 Mdot
.5175 .32125 Mdot
.6525 .3525 Mdot
.3875 .37125 Mdot
.46625 .39875 Mdot
.29625 .385 Mdot
.3725 .37 Mdot
.03375 .2875 Mdot
.505 .2525 Mdot
.49375 .30125 Mdot
.55125 .33375 Mdot
.41125 .38875 Mdot
.5 .4025 Mdot
.5225 .37625 Mdot
.72625 .29125 Mdot
.23 .19875 Mdot
.56125 .3475 Mdot
.4425 .36 Mdot
.5425 .36875 Mdot
.47625 .38125 Mdot
.49375 .41125 Mdot
.53875 .43125 Mdot
.48875 .405 Mdot
.5025 .39375 Mdot
.43625 .355 Mdot
.0025 .30625 Mdot
.1 .29375 Mdot
.395 .335 Mdot
.4825 .415 Mdot
.43 .445 Mdot
.53 .42125 Mdot
.5825 .42375 Mdot
.48375 .43125 Mdot
.4825 .38375 Mdot
.57625 .39625 Mdot
.4925 .4675 Mdot
.47625 .47375 Mdot
.4275 .41875 Mdot
.1 .32875 Mdot
.38875 .3175 Mdot
.6075 .35875 Mdot
.4525 .415 Mdot
.5 .4675 Mdot
.41375 .55125 Mdot
.56375 .56625 Mdot
.43375 .555 Mdot
.61625 .55125 Mdot
.48375 .5325 Mdot
.42875 .47875 Mdot
.44625 .49625 Mdot
.30375 .50625 Mdot
.1775 .47375 Mdot
.38375 .49625 Mdot
.5175 .48375 Mdot
.505 .49625 Mdot
.495 .54 Mdot
.48125 .5825 Mdot
.48875 .58375 Mdot
.49625 .58125 Mdot
.58125 .565 Mdot
.505 .5075 Mdot
.42875 .50625 Mdot
.0025 .4875 Mdot
.29375 .52 Mdot
.50125 .53 Mdot
.44375 .49375 Mdot
.44625 .53375 Mdot
.5475 .555 Mdot
.6025 .5725 Mdot
.45375 .60625 Mdot
.45625 .6375 Mdot
.49 .63375 Mdot
.54125 .58875 Mdot
.45875 .5425 Mdot
.495 .50125 Mdot
.245 .475 Mdot
.22375 .49625 Mdot
.5075 .5325 Mdot
.53 .5625 Mdot
.4875 .54125 Mdot
.4525 .52375 Mdot
.54875 .505 Mdot
.54125 .48125 Mdot
.48125 .45375 Mdot
.49125 .46625 Mdot
.465 .47 Mdot
.525 .4725 Mdot
.155 .475 Mdot
.955 .48625 Mdot
.53375 .5475 Mdot
.2925 .59875 Mdot
.51125 .67125 Mdot
.515 .7275 Mdot
.5 .75875 Mdot
.49 .73375 Mdot
.56875 .6725 Mdot
.5125 .60125 Mdot
.38 .5525 Mdot
.455 .53875 Mdot
.58125 .55 Mdot
.4375 .565 Mdot
.49125 .57625 Mdot
.02375 .56125 Mdot
.52375 .555 Mdot
.47125 .555 Mdot
.5625 .55875 Mdot
.42375 .555 Mdot
.50625 .5175 Mdot
.55 .48625 Mdot
.45125 .48 Mdot
.5825 .465 Mdot
.45375 .44125 Mdot
.4325 .46875 Mdot
.14875 .5175 Mdot
.0275 .52875 Mdot
.43125 .5575 Mdot
.4775 .53125 Mdot
.56 .47 Mdot
.5175 .45875 Mdot
.59625 .485 Mdot
.4325 .50125 Mdot
.66875 .50375 Mdot
.39875 .51625 Mdot
.4425 .5525 Mdot
.34 .575 Mdot
.37625 .59625 Mdot
.1275 .71625 Mdot
.52 .70125 Mdot
.47375 .70125 Mdot
.5325 .7225 Mdot
.3425 .695 Mdot
.7025 .6125 Mdot
.4425 .55625 Mdot
.6625 .485 Mdot
.28125 .3975 Mdot
.58 .48875 Mdot
.33625 .485 Mdot
.6675 .47125 Mdot
.5325 .4725 Mdot
.405 .45875 Mdot
.53125 .445 Mdot
.46625 .4775 Mdot
.54375 .53625 Mdot
.4475 .565 Mdot
.1425 .5825 Mdot
.12 .56875 Mdot
.44 .53375 Mdot
.47625 .5075 Mdot
.44125 .5075 Mdot
.38875 .53375 Mdot
.7475 .57875 Mdot
.5425 .57625 Mdot
.3875 .5875 Mdot
.5725 .585 Mdot
.49375 .55125 Mdot
.47875 .5275 Mdot
.4425 .5 Mdot
.115 .49625 Mdot
.10125 .53875 Mdot
.45 .56125 Mdot
.605 .58875 Mdot
.40625 .56 Mdot
.45875 .5475 Mdot
.5075 .51 Mdot
.56125 .485 Mdot
.49125 .4575 Mdot
.56 .46875 Mdot
.475 .455 Mdot
.435 .4875 Mdot
.45375 .47125 Mdot
.3875 .47625 Mdot
.25 .46375 Mdot
.405 .465 Mdot
.4925 .48 Mdot
.5625 .49625 Mdot
.3325 .50125 Mdot
.6675 .50875 Mdot
.49875 .5025 Mdot
.40375 .4925 Mdot
.59875 .4775 Mdot
.53125 .525 Mdot
.4225 .54625 Mdot
.1375 .5425 Mdot
.40625 .5225 Mdot
.49 .5275 Mdot
.4825 .52375 Mdot
.4325 .52625 Mdot
.51625 .5275 Mdot
.46 .535 Mdot
.73875 .465 Mdot
.3825 .42375 Mdot
.43375 .38125 Mdot
.57875 .37 Mdot
.40375 .39 Mdot
.55625 .39 Mdot
.28875 .40375 Mdot
.8825 .43875 Mdot
.255 .4475 Mdot
.55625 .43625 Mdot
.53125 .4575 Mdot
.5175 .4975 Mdot
.37375 .505 Mdot
.5625 .54875 Mdot
.67625 .56875 Mdot
.3275 .6025 Mdot
.58625 .55875 Mdot
.43125 .53125 Mdot
.53125 .4975 Mdot
.2375 .45375 Mdot
.80625 .37875 Mdot
.53 .35125 Mdot
.3475 .35 Mdot
.50875 .305 Mdot
.525 .32875 Mdot
.5025 .38 Mdot
.37 .39 Mdot
.7875 .40375 Mdot
.44875 .40125 Mdot
.355 .3625 Mdot
.485 .32375 Mdot
.53125 .3275 Mdot
.45 .30375 Mdot
.53 .30625 Mdot
.88 .30625 Mdot
.15875 .29375 Mdot
.5325 .27125 Mdot
.43625 .26375 Mdot
.55625 .2425 Mdot
.3375 .24125 Mdot
.665 .25 Mdot
.55125 .25875 Mdot
.4075 .26125 Mdot
.545 .27875 Mdot
.47375 .35875 Mdot
.445 .34375 Mdot
.245 .3 Mdot
.12625 .30125 Mdot
.445 .225 Mdot
.47 .27125 Mdot
.5475 .32375 Mdot
.3775 .32 Mdot
.83625 .2575 Mdot
.36 .21875 Mdot
.6125 .155 Mdot
.41875 .11875 Mdot
.44625 .1025 Mdot
.385 .05125 Mdot
.41875 .015 Mdot
.3725 .13625 Mdot
.56125 .27125 Mdot
.35125 .38875 Mdot
.49 .005 Mdot
.47 .05875 Mdot
.4775 .10375 Mdot
.26875 .15125 Mdot
.80125 .1125 Mdot
.615 .07875 Mdot
.3375 .03875 Mdot
.50125 0 Mdot
.4525 .01125 Mdot
.23625 .01875 Mdot
.43 .02875 Mdot
.99125 .08625 Mdot
.2825 .09625 Mdot
.40875 .12625 Mdot
.58125 .12625 Mdot
.38625 .1575 Mdot
.57125 .20125 Mdot
.375 .25375 Mdot
.715 .28 Mdot
.28375 .3 Mdot
.615 .26875 Mdot
.525 .2225 Mdot
.5625 .16625 Mdot
.305 .17 Mdot
.4975 .15875 Mdot
.84125 .1575 Mdot
.23875 .10875 Mdot
.5975 .08125 Mdot
.425 .06875 Mdot
.5275 .055 Mdot
.34375 .07375 Mdot
.66 .17 Mdot
.535 .22125 Mdot
.395 .17375 Mdot
.5225 .17 Mdot
.52625 .0725 Mdot
.3125 .13375 Mdot
.35875 .2925 Mdot
.515 .47625 Mdot
.50875 .565 Mdot
.47375 .57375 Mdot
.54 .5425 Mdot
.71125 .515 Mdot
.2925 .43 Mdot
.52 .3625 Mdot
.455 .3175 Mdot
.5375 .29125 Mdot
.23 .2825 Mdot
.82125 .29 Mdot
.55625 .31125 Mdot
.37 .36375 Mdot
.52 .45 Mdot
.48375 .57 Mdot
.44875 .6275 Mdot
.365 .64875 Mdot
.9625 .68125 Mdot
.26625 .67875 Mdot
.405 .66625 Mdot
.48875 .67375 Mdot
.53375 .7675 Mdot
.2575 .88875 Mdot
.29375 .5775 Mdot
.5025 .40625 Mdot
.41625 .18125 Mdot
.50375 .99625 Mdot
.19875 .835 Mdot
.2225 .5075 Mdot
.4975 .4 Mdot
.47875 .28 Mdot
.4475 .15625 Mdot
.5025 .115 Mdot
.4825 .12125 Mdot
.55125 .10625 Mdot
.49875 .14 Mdot
.50375 .21375 Mdot
.4725 .34 Mdot
.41625 .3675 Mdot
.24625 .4025 Mdot
.19375 .8325 Mdot
.485 .92375 Mdot
.52375 .5725 Mdot
.65375 .25 Mdot
.21375 .145 Mdot
.48875 .04125 Mdot
.455 .04125 Mdot
.48 .14125 Mdot
.52625 .31625 Mdot
.0025 .365 Mdot
.90625 .42 Mdot
.84625 .45375 Mdot
.17625 .29375 Mdot
.56 .14125 Mdot
.45375 .07375 Mdot
.525 .0625 Mdot
.15875 .11 Mdot
.81375 .08 Mdot
.51375 .03125 Mdot
.76625 .04375 Mdot
.505 .045 Mdot
.4975 .06 Mdot
.47625 .0775 Mdot
.1575 .0475 Mdot
.41375 .0325 Mdot
.01875 .0125 Mdot
.12 .01875 Mdot
.18625 .01 Mdot
.22375 .1975 Mdot
.46375 .21375 Mdot
.4625 .25 Mdot
.4825 .3175 Mdot
.52125 .345 Mdot
.495 .34375 Mdot
.49375 .34125 Mdot
.505 .315 Mdot
.50875 .29375 Mdot
.49375 .3 Mdot
.37 .2975 Mdot
.24125 .29375 Mdot
.21625 .405 Mdot
.50125 .44875 Mdot
.395 .53375 Mdot
.4775 .25875 Mdot
.72 .41625 Mdot
.14 .435 Mdot
.48 .4725 Mdot
.46 .48625 Mdot
.56875 .4825 Mdot
.52 .46 Mdot
.49875 .4475 Mdot
.5175 .4125 Mdot
.4075 .405 Mdot
.6025 .40625 Mdot
.47 .36 Mdot
.52875 .31125 Mdot
.95 .29625 Mdot
.89375 .3275 Mdot
.16 .40125 Mdot
.52375 .47375 Mdot
.48125 .555 Mdot
.4625 .57625 Mdot
.54875 .595 Mdot
.47625 .59625 Mdot
.57125 .61375 Mdot
.42875 .59875 Mdot
.50125 .55125 Mdot
.5275 .5325 Mdot
.5375 .50125 Mdot
.13875 .46625 Mdot
.82625 .4575 Mdot
.5375 .46875 Mdot
.6775 .44625 Mdot
.36125 .46625 Mdot
.37375 .49125 Mdot
.51625 .505 Mdot
.3725 .52625 Mdot
.73125 .53625 Mdot
.4475 .52875 Mdot
.53 .49 Mdot
.415 .465 Mdot
.37 .43875 Mdot
.76 .41625 Mdot
.5275 .45375 Mdot
.20875 .47125 Mdot
.55875 .5 Mdot
.53375 .5175 Mdot
.47875 .51375 Mdot
.525 .515 Mdot
.465 .50125 Mdot
.50125 .49375 Mdot
.46375 .46375 Mdot
.535 .45 Mdot
.53 .4575 Mdot
.4375 .45375 Mdot
.10625 .4325 Mdot
.10375 .43 Mdot
.4325 .41875 Mdot
.50875 .43875 Mdot
.435 .455 Mdot
.56625 .48 Mdot
.51 .5325 Mdot
.50125 .5775 Mdot
.30625 .59375 Mdot
.64125 .59 Mdot
.51875 .54375 Mdot
.5825 .4825 Mdot
.24 .47125 Mdot
.4175 .43375 Mdot
.04125 .51875 Mdot
.56 .56125 Mdot
.52375 .5475 Mdot
.50125 .58625 Mdot
.4725 .58375 Mdot
.46625 .545 Mdot
.525 .53625 Mdot
.405 .51125 Mdot
.605 .49875 Mdot
.5075 .49125 Mdot
.4675 .4625 Mdot
.1025 .4475 Mdot
.115 .4475 Mdot
.33375 .43875 Mdot
.575 .4625 Mdot
.51375 .45375 Mdot
.46375 .43625 Mdot
.51 .4225 Mdot
.525 .43375 Mdot
.4375 .4375 Mdot
.55375 .44 Mdot
.4825 .4425 Mdot
.49375 .46375 Mdot
.14 .46 Mdot
.355 .4225 Mdot
.3875 .4125 Mdot
.53625 .4325 Mdot
.525 .45375 Mdot
.5125 .43125 Mdot
.49875 .46125 Mdot
.42875 .47375 Mdot
.5775 .43375 Mdot
.51 .3975 Mdot
.48125 .445 Mdot
.43875 .4175 Mdot
.24375 .4375 Mdot
.215 .4875 Mdot
.51875 .48375 Mdot
.54125 .50625 Mdot
.4475 .49125 Mdot
.50875 .47625 Mdot
.51375 .47625 Mdot
.4725 .48375 Mdot
.40375 .49125 Mdot
.705 .48625 Mdot
.40125 .465 Mdot
.39875 .4825 Mdot
.3225 .4875 Mdot
.22125 .37875 Mdot
.685 .34 Mdot
.32125 .2975 Mdot
.55375 .505 Mdot
.04125 .51125 Mdot
.6825 .51 Mdot
.235 .5225 Mdot
.35875 .5475 Mdot
.58375 .5625 Mdot
.6125 .61 Mdot
.45875 .6375 Mdot
.4725 .62625 Mdot
.5375 .61375 Mdot
.4125 .585 Mdot
.48 .54375 Mdot
.625 .50875 Mdot
.585 .5025 Mdot
.81125 .48125 Mdot
.80875 .455 Mdot
.2125 .45 Mdot
.43375 .46125 Mdot
.65875 .465 Mdot
.45375 .5275 Mdot
.4975 .54125 Mdot
.47375 .55 Mdot
.54875 .56375 Mdot
.43 .5775 Mdot
.41375 .57125 Mdot
.76375 .56875 Mdot
.44125 .5425 Mdot
.19375 .54875 Mdot
.735 .5425 Mdot
.52625 .505 Mdot
.5275 .49875 Mdot
.46 .52125 Mdot
.56125 .49625 Mdot
.40125 .43125 Mdot
.3775 .41875 Mdot
.705 .4225 Mdot
.46125 .4075 Mdot
.4475 .4075 Mdot
.4625 .3875 Mdot
.4775 .4 Mdot
.685 .38375 Mdot
.0625 .41875 Mdot
.52 .5025 Mdot
.18875 .53 Mdot
.6175 .575 Mdot
.585 .5775 Mdot
.41125 .57875 Mdot
.55375 .58375 Mdot
.47 .5675 Mdot
.4875 .54125 Mdot
.39125 .515 Mdot
.58625 .48375 Mdot
.62125 .47 Mdot
.3925 .46625 Mdot
.20125 .50125 Mdot
.18375 .5225 Mdot
.435 .50125 Mdot
.63 .49375 Mdot
.4225 .455 Mdot
.4825 .4625 Mdot
.555 .46125 Mdot
.50625 .49 Mdot
.25375 .4975 Mdot
.57 .48625 Mdot
.76 .4225 Mdot
.45 .37125 Mdot
.28875 .3275 Mdot
.40375 .32 Mdot
.10375 .3275 Mdot
.45375 .35 Mdot
.77375 .355 Mdot
.3675 .335 Mdot
.475 .33625 Mdot
.46125 .3825 Mdot
.5225 .39375 Mdot
.2725 .40875 Mdot
.85 .4125 Mdot
.46375 .44 Mdot
.40375 .38875 Mdot
.22125 .355 Mdot
.14875 .2775 Mdot
.22125 .225 Mdot
.895 .215 Mdot
.395 .19375 Mdot
.42375 .21375 Mdot
.51125 .24 Mdot
.51625 .2625 Mdot
.3275 .29375 Mdot
.7575 .3175 Mdot
.44 .35875 Mdot
.45375 .3975 Mdot
.24125 .37125 Mdot
.91625 .34625 Mdot
.305 .37375 Mdot
.46875 .3675 Mdot
.62125 .305 Mdot
.47125 .27375 Mdot
.5 .3725 Mdot
.49375 .2875 Mdot
.4125 .2125 Mdot
.45625 .2 Mdot
.7975 .215 Mdot
.35 .12375 Mdot
.42625 .14375 Mdot
.36125 .12375 Mdot
.87625 .11 Mdot
.135 .09875 Mdot
.73375 .0625 Mdot
.5675 .05625 Mdot
.39 .075 Mdot
.49 .0825 Mdot
.50875 .065 Mdot
.45 .03125 Mdot
.265 .04375 Mdot
.4 .02125 Mdot
.44375 .01875 Mdot
.86125 .14875 Mdot
.24125 .255 Mdot
.85625 .26625 Mdot
.18 .395 Mdot
.7525 .2075 Mdot
.06375 .225 Mdot
.85375 .2325 Mdot
.67125 .2175 Mdot
.3 .13125 Mdot
.26125 .06375 Mdot
.7125 .025 Mdot
.46125 .07625 Mdot
.54375 .13875 Mdot
.4275 .19375 Mdot
.2925 .22875 Mdot
.86125 .28375 Mdot
.615 .33875 Mdot
.0125 .33125 Mdot
.71625 .35125 Mdot
.71875 .34875 Mdot
.3175 .2925 Mdot
.265 .16625 Mdot
.87875 .08 Mdot
.29375 .02625 Mdot
.3025 .055 Mdot
.61625 .05625 Mdot
.54875 .07875 Mdot
.3875 .03625 Mdot
.4775 .01375 Mdot
.34125 .0325 Mdot
.53125 .0825 Mdot
.59375 .17625 Mdot
.59125 .2675 Mdot
.22 .27125 Mdot
.81125 .2375 Mdot
.535 .17625 Mdot
.1825 .145 Mdot
.665 .095 Mdot
.66125 .11375 Mdot
.32875 .1375 Mdot
.55875 .14875 Mdot
.45125 .11 Mdot
.5 .11625 Mdot
.32 .17125 Mdot
.67 .23 Mdot
.665 .2375 Mdot
.36375 .1925 Mdot
.3025 .12125 Mdot
.885 .0575 Mdot
.295 .00625 Mdot
.38 .00875 Mdot
.7975 .0225 Mdot
.38 .03625 Mdot
.32375 .23625 Mdot
.32 .31 Mdot
.44625 .31 Mdot
.90875 .3125 Mdot
.11875 .225 Mdot
.4925 .04625 Mdot
.9075 .04375 Mdot
.255 .1 Mdot
.46 .16 Mdot
.47125 .11625 Mdot
.51375 .07125 Mdot
.165 .07125 Mdot
.40625 .11375 Mdot
.3575 .1825 Mdot
.3325 .22625 Mdot
.945 .20375 Mdot
.25625 .19875 Mdot
.08875 .165 Mdot
.24625 .29875 Mdot
.4 .36 Mdot
.52 .36125 Mdot
.51 .36375 Mdot
.2075 .34375 Mdot
.9775 .3775 Mdot
.3775 .51 Mdot
.42875 .6225 Mdot
.3425 .76 Mdot
.77 .88875 Mdot
.23375 .99125 Mdot
.10375 .97875 Mdot
.945 .99375 Mdot
.21 .9225 Mdot
.0225 .38375 Mdot
.6375 .9775 Mdot
.36125 .90375 Mdot
.18 .8775 Mdot
.87125 .8925 Mdot
.67875 .9125 Mdot
.53375 .95 Mdot
.43875 .88625 Mdot
.1375 .91625 Mdot
.6525 .9975 Mdot
.24875 .9925 Mdot
.77 .99375 Mdot
.445 .86875 Mdot
.6175 .69375 Mdot
.185 .56625 Mdot
.6275 .59875 Mdot
.84875 .62625 Mdot
.29625 .645 Mdot
.47375 .66125 Mdot
.4675 .7275 Mdot
.485 .69875 Mdot
.11 .665 Mdot
.05125 .60375 Mdot
.41875 .58375 Mdot
.51625 .65375 Mdot
.53625 .78 Mdot
.04625 .83125 Mdot
.51875 .84375 Mdot
.27 .77375 Mdot
.49375 .64375 Mdot
.50375 .63875 Mdot
.4175 .5375 Mdot
.4525 .07375 Mdot
.235 .26125 Mdot
.12375 .55 Mdot
.5175 .53375 Mdot
.585 .61375 Mdot
.435 .75375 Mdot
.09125 .82625 Mdot
.6975 .85125 Mdot
.20375 .75125 Mdot
.47625 .635 Mdot
.545 .67375 Mdot
.4625 .67 Mdot
.65875 .35 Mdot
.1725 .14 Mdot
.565 .05 Mdot
.48 .1075 Mdot
.4325 .17625 Mdot
.00125 .21625 Mdot
.35125 .175 Mdot
.3 .09375 Mdot
.4775 .04875 Mdot
.5375 .145 Mdot
.31625 .12 Mdot
.24375 .06625 Mdot
.16 .04125 Mdot
.6925 .08125 Mdot
.08875 .0775 Mdot
.5075 .03625 Mdot
.49625 .1975 Mdot
.12875 .29875 Mdot
.75125 .33625 Mdot
.73125 .3625 Mdot
.44875 .245 Mdot
.39875 .075 Mdot
.5725 .06 Mdot
.5725 .1225 Mdot
.1575 .1725 Mdot
.7725 .2675 Mdot
.79625 .35625 Mdot
.13 .3275 Mdot
.5325 .26875 Mdot
.4625 .28875 Mdot
.5075 .3225 Mdot
.195 .30875 Mdot
.85875 .27375 Mdot
.71625 .2 Mdot
.30125 .09375 Mdot
.42875 .00875 Mdot
.51875 .0575 Mdot
.5125 .0875 Mdot
.25125 .1275 Mdot
.175 .1075 Mdot
.34 .0075 Mdot
.57625 .0425 Mdot
.6 .18875 Mdot
.105 .18625 Mdot
.40625 .15875 Mdot
.03375 .07375 Mdot
.5175 .01 Mdot
.26125 .0475 Mdot
.38625 .04875 Mdot
.4975 .12 Mdot
.4675 .21125 Mdot
.235 .25375 Mdot
.695 .23 Mdot
.8625 .17 Mdot
.22625 .1 Mdot
.4825 .0475 Mdot
.47375 .095 Mdot
.475 .11125 Mdot
.06125 .13875 Mdot
.43 .105 Mdot
.505 .15125 Mdot
.485 .1725 Mdot
.0475 .17 Mdot
.52 .175 Mdot
.23875 .135 Mdot
.49 .1275 Mdot
.4975 .205 Mdot
.40375 .28875 Mdot
0 .3625 Mdot
.54 .6625 Mdot
.61625 .69875 Mdot
.4175 .71625 Mdot
.205 .7175 Mdot
.165 .21125 Mdot
.46125 .1325 Mdot
.4875 .1325 Mdot
.40875 .145 Mdot
.17125 .135 Mdot
.54125 .14875 Mdot
.20125 .15375 Mdot
.47 .14875 Mdot
.5375 .235 Mdot
.4075 .29 Mdot
.52375 .40875 Mdot
.25375 .38875 Mdot
.5225 .35875 Mdot
.4475 .3725 Mdot
.44375 .38 Mdot
.25625 .355 Mdot
.2725 .33625 Mdot
.49375 .36875 Mdot
.51625 .45 Mdot
.30875 .5 Mdot
.105 .55875 Mdot
.45 .595 Mdot
.4725 .56125 Mdot
.49 .48625 Mdot
.13875 .42375 Mdot
.57625 .37875 Mdot
.04375 .3125 Mdot
.43875 .31625 Mdot
.505 .33 Mdot
.49375 .32875 Mdot
.10125 .32625 Mdot
.7175 .3425 Mdot
.8825 .345 Mdot
.39 .33625 Mdot
.38625 .39 Mdot
.555 .4425 Mdot
.54875 .49125 Mdot
.17625 .54375 Mdot
.775 .58375 Mdot
.77 .565 Mdot
.0525 .5625 Mdot
.71875 .56125 Mdot
.39875 .55625 Mdot
.485 .555 Mdot
.2225 .5575 Mdot
.83375 .53375 Mdot
.61625 .50875 Mdot
.3425 .50125 Mdot
.6625 .49375 Mdot
.35 .5075 Mdot
.50125 .5375 Mdot
.235 .57375 Mdot
.10875 .64 Mdot
.365 .6375 Mdot
.7225 .61 Mdot
.48625 .5775 Mdot
.155 .5825 Mdot
.40125 .56875 Mdot
.3325 .5875 Mdot
.60875 .58625 Mdot
.49125 .53875 Mdot
.27875 .525 Mdot
.61 .52875 Mdot
.00875 .55125 Mdot
.54375 .6375 Mdot
.54 .65875 Mdot
.4075 .67375 Mdot
.3525 .555 Mdot
.19125 .53875 Mdot
.78625 .53625 Mdot
.40125 .54125 Mdot
.39 .51875 Mdot
.3775 .49875 Mdot
.6875 .50625 Mdot
.38 .52125 Mdot
.07 .5225 Mdot
.28375 .505 Mdot
.25125 .48875 Mdot
.66375 .485 Mdot
.4825 .47875 Mdot
.235 .45125 Mdot
.69125 .44375 Mdot
.7875 .45 Mdot
.21 .43375 Mdot
.54375 .395 Mdot
.525 .4075 Mdot
.42375 .42625 Mdot
.135 .43 Mdot
.04875 .48625 Mdot
.34625 .505 Mdot
.66875 .50125 Mdot
.45875 .4725 Mdot
.08625 .4525 Mdot
.445 .44125 Mdot
.25 .43875 Mdot
.53 .49 Mdot
.5875 .53375 Mdot
.34875 .57125 Mdot
.08875 .5875 Mdot
.43875 .56 Mdot
.825 .50375 Mdot
.34625 .45125 Mdot
.26375 .41625 Mdot
.9525 .51375 Mdot
.2275 .53375 Mdot
.44375 .5575 Mdot
.46 .57 Mdot
.34 .55 Mdot
.2825 .535 Mdot
.3375 .45625 Mdot
.25 .4275 Mdot
.48125 .4425 Mdot
.51 .44375 Mdot
.36125 .4525 Mdot
.0175 .43375 Mdot
.395 .35875 Mdot
.36 .34125 Mdot
.51625 .3175 Mdot
.46125 .34125 Mdot
.46875 .39125 Mdot
.1375 .48875 Mdot
.30875 .4925 Mdot
.495 .445 Mdot
.53875 .41625 Mdot
.28875 .39 Mdot
.0725 .36125 Mdot
.46625 .38 Mdot
.46875 .40625 Mdot
.47375 .49625 Mdot
.2375 .54 Mdot
.40625 .55875 Mdot
.1075 .57875 Mdot
.4275 .52125 Mdot
.47125 .51125 Mdot
.50875 .59375 Mdot
.17375 .6175 Mdot
.64625 .655 Mdot
.945 .66625 Mdot
.33125 .72 Mdot
.395 .65625 Mdot
.525 .66 Mdot
.56 .6525 Mdot
.28 .6425 Mdot
.69875 .5725 Mdot
.69 .54875 Mdot
.0025 .53125 Mdot
.9125 .50625 Mdot
.3325 .51 Mdot
.4775 .5075 Mdot
.29375 .49375 Mdot
.76125 .49625 Mdot
.46375 .47875 Mdot
.37875 .43375 Mdot
.89 .40125 Mdot
.275 .4025 Mdot
.47375 .40875 Mdot
.3 .4175 Mdot
.075 .4875 Mdot
.42125 .49875 Mdot
.88625 .47125 Mdot
.34375 .49375 Mdot
.26625 .47375 Mdot
.42375 .42625 Mdot
.36 .35875 Mdot
.735 .39 Mdot
.36875 .39875 Mdot
.40875 .4 Mdot
.65625 .40125 Mdot
.83125 .40375 Mdot
.08875 .35 Mdot
.65375 .33375 Mdot
.57625 .34875 Mdot
.31375 .32 Mdot
.12 .28 Mdot
.37375 .2825 Mdot
.14875 .285 Mdot
.98375 .3175 Mdot
.34375 .3775 Mdot
.37 .39 Mdot
.0475 .34625 Mdot
.04375 .20375 Mdot
.34625 .1225 Mdot
.8575 .15125 Mdot
.295 .1625 Mdot
.19125 .15875 Mdot
.34625 .1925 Mdot
.185 .15 Mdot
.81375 .10375 Mdot
.4825 .13875 Mdot
.2325 .16875 Mdot
.6775 .19125 Mdot
.68625 .22875 Mdot
.24375 .28375 Mdot
.57 .32125 Mdot
.57 .355 Mdot
.3925 .3025 Mdot
.275 .26125 Mdot
.18375 .115 Mdot
.26 .01 Mdot
.82125 .07125 Mdot
.435 .0875 Mdot
.19875 .07125 Mdot
.9775 .06 Mdot
.43375 .04625 Mdot
.28375 .045 Mdot
.32 .19 Mdot
.8075 .345 Mdot
.255 .46125 Mdot
.7175 .45375 Mdot
.31 .51125 Mdot
.44625 .35875 Mdot
.45 .3425 Mdot
.27 .4325 Mdot
.39625 .44375 Mdot
.1625 .61625 Mdot
.30375 .66875 Mdot
.49 .52 Mdot
.49875 .44 Mdot
.3325 .44875 Mdot
.13125 .45625 Mdot
.31 .52875 Mdot
.46 .58125 Mdot
.5275 .5475 Mdot
.4775 .56375 Mdot
.46125 .58375 Mdot
.08875 .615 Mdot
.34875 .575 Mdot
.49 .5725 Mdot
.5175 .52375 Mdot
.295 .4675 Mdot
.1625 .43875 Mdot
.46875 .41 Mdot
.455 .53875 Mdot
.46625 .45125 Mdot
.30625 .3675 Mdot
.28375 .29625 Mdot
.2125 .0225 Mdot
.38375 .0425 Mdot
.47375 .1675 Mdot
.50125 .1175 Mdot
.2725 .21375 Mdot
.56125 .31625 Mdot
.27375 .545 Mdot
.385 .74125 Mdot
.50375 .7925 Mdot
.58625 .81 Mdot
.3475 .7 Mdot
.62375 .53625 Mdot
.6075 .50375 Mdot
.29 .7025 Mdot
.44625 .97125 Mdot
.67875 .9775 Mdot
.41875 .99625 Mdot
.855 .6825 Mdot
.0475 .47375 Mdot
.46375 .25375 Mdot
.18125 .5375 Mdot
.36875 .68875 Mdot
.46125 .65625 Mdot
.99875 .5225 Mdot
.0125 .31875 Mdot
.40625 .0925 Mdot
.89625 .03 Mdot
.19375 .14 Mdot
.56 .27375 Mdot
.61625 .2875 Mdot
.68875 .30875 Mdot
.135 .39125 Mdot
.765 .37625 Mdot
.64625 .54875 Mdot
.18875 .765 Mdot
.25 .9675 Mdot
.95625 .9625 Mdot
.4 .92875 Mdot
.09 .80125 Mdot
.3 .72125 Mdot
.34625 .8175 Mdot
.20375 .95125 Mdot
.575 .96375 Mdot
.5725 .6825 Mdot
.545 .6225 Mdot
.38 .5825 Mdot
.4625 .76125 Mdot
.46 .75875 Mdot
.25125 .64 Mdot
.5025 .62875 Mdot
.12125 .42625 Mdot
.36125 .38875 Mdot
.52625 .545 Mdot
.48125 .61 Mdot
.33125 .57875 Mdot
.27 .58875 Mdot
.2525 .55875 Mdot
.5275 .535 Mdot
.5375 .62125 Mdot
.485 .5725 Mdot
.46625 .505 Mdot
.0675 .47 Mdot
.1275 .4 Mdot
.345 .44625 Mdot
.515 .475 Mdot
.5075 .5275 Mdot
.3325 .60375 Mdot
.2775 .65125 Mdot
.075 .76375 Mdot
.47 .7175 Mdot
.455 .5675 Mdot
.48 .58 Mdot
.4125 .64375 Mdot
.19375 .73125 Mdot
.47875 .85125 Mdot
.50375 .77375 Mdot
.3775 .63 Mdot
.49125 .5025 Mdot
.98 .33875 Mdot
.2775 .31125 Mdot
.3975 .19375 Mdot
.51375 .12875 Mdot
.5425 .085 Mdot
.42875 .155 Mdot
.56875 .32125 Mdot
.51125 .3625 Mdot
.0025 .38125 Mdot
.29125 .2225 Mdot
.5925 .03375 Mdot
.4525 .0075 Mdot
.515 .015 Mdot
.70125 .285 Mdot
.055 .485 Mdot
.46375 .72 Mdot
.055 .50375 Mdot
.4525 .36 Mdot
.5225 .4075 Mdot
.71125 .55 Mdot
.085 .76875 Mdot
.14375 .93875 Mdot
.63375 .7875 Mdot
.5575 .7375 Mdot
.60125 .7275 Mdot
.225 .67125 Mdot
.81 .67125 Mdot
.67125 .47375 Mdot
.11125 .28625 Mdot
.39875 .13125 Mdot
.6975 .20125 Mdot
.47375 .24125 Mdot
.0275 .38 Mdot
.3175 .34125 Mdot
.3025 .2325 Mdot
.3675 .14125 Mdot
.755 .2075 Mdot
.33625 .16625 Mdot
.18375 .26125 Mdot
.12375 .15875 Mdot
.3975 .04 Mdot
.67375 .16375 Mdot
.4075 .25375 Mdot
.06875 .3375 Mdot
.53125 .22375 Mdot
.2325 .0725 Mdot
.60125 .06875 Mdot
.51375 .14 Mdot
.315 .18375 Mdot
.61625 .20625 Mdot
.69125 .14125 Mdot
.305 .0475 Mdot
.62375 .1075 Mdot
.44125 .15125 Mdot
.06 .17625 Mdot
.34875 .025 Mdot
.175 .065 Mdot
.46875 .03125 Mdot
.26375 .22625 Mdot
.885 .43125 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`03ooooo`;o003o1_ooool2o`00o`;o
oooo1ol00?l@ooooo`;o003o8oooool2o`00o`04ooooool00?oo003oooooo`;o003o1?ooool2o`00
o`;ooooo1?l00?l5ooooo`?o003o1Oooool:o`00o`03ooooool00?oo003o00;o003o0_oooolFo`00
o`?ooooo0_l00?l2ooooo`;o003o1?ooool2o`00o`03ooooool00?oo003o00cooooo0_l00?l?oooo
o`;o003o2oooool2o`00o`04ooooool00?oo003oo`00ob7ooooo0ol00?l3ooooo`;o003o5_ooool2
o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool4o`00o`;ooooo0_l00?l00ooo
oooo003oo`00o`0Mooooo`;o003o0_ooool2o`00o`oooooo0ol00?l3ooooo`Co003o00Coooooo`00
ool00?oo003o0oooool2o`00o`;ooooo1?l00?l01?oooooo003oo`00ooooool4o`00o`;ooooo1_l0
0?l2ooooob;o003o0oooool3o`00o`03ooooool00?oo003o00Oooooo0_l00?l]ooooo`;o003o5_oo
ool2o`00o`?ooooo0_l00?l5ooooo`;o003o1?ooool2o`00oagooooo0Ol00001ooooo`0000Co0000
oooooooooooooooo0_l00?l6ooooo`;o003o9_ooool2o`00o`;ooooo0_l00?l?ooooo`?o003o0ooo
ool2o`00o`Cooooo0_l00?l5ooooo`;o003o1Oooool2o`00o`03ooooool00?oo003o00Cooooo1_l0
0?l3ooooo`ko003o1OoooolDo`00o`[ooooo0_l00?l?ooooo`;o003o=?ooool2o`00o`?ooooo0_l0
0?lGooooo`;o003o4Oooool1o`00007ooooo00001?l0003oooooooooooooool2o`00obOooooo0_l0
0?lJooooo`;o003o2_ooool2o`00o`Gooooo0_l00?lDooooo`;o003o0_oooolJo`00o`03ooooool0
0?oo003o00Ko003o0_ooool2o`00o`Kooooo0_l00?l00ooooooo003oo`00o`0>ooooo`Go003oCOoo
ool2o`00o`03ooooool00?oo003o017ooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool2
o`00oa;ooooo0_l00?l4ooooo`;o003o2_ooool2o`00oa;ooooo1?l00?l4ooooo`;o003o00?ooooo
o`00ool00?l01oooool2o`00o`_ooooo1?l00?l7ooooo`;o003o00?oooooo`00ool00?l00_l00?l3
ooooo`Ko003o00?oooooo`00ool00?l04?l00?l2ooooo`So003o00?oooooo`00ool00?l00oooool5
o`00o`03ooooool00?oo003o00kooooo0_l00?l00ooooooo003oo`00o`0>ooooo`;o003o1?ooool2
o`00o`;ooooo0_l00?l?ooooo`;o003o8_ooool2o`00oaCooooo0Ol00001ooooo`0000?o0000oooo
ooooool01?ooool2o`00oa;ooooo0ol00?l3ooooo`;o003o6Oooool3o`00o`;ooooo1?l00?l3oooo
o`;o003o0_ooool2o`00o`;ooooo0_l00?l6ooooo`Co003o0_ooool2o`00o`;ooooo1?l00?l6oooo
o`?o003o00?oooooo`00ool00?l00_l00?l8ooooo`Co003o0_oooolKo`00o`;ooooo1?l00?l3oooo
o`;o003o1_ooool2o`00o`Gooooo0_l00?l:ooooo`;o003o1_ooool4o`00o`;ooooo0_l00?l2oooo
o`Co003o2Oooool2o`00o`;ooooo0_l00?lDooooo`;o003o8Oooool1o`00o`7o00000Oooool00003
o`000?oooooooooo01Wooooo0_l00?l=ooooo`;o003o3oooool3o`00o`;ooooo1?l00?l3ooooo`;o
003o1_ooool2o`00o`03ooooool00?oo003o00?ooooo1?l00?l2ooooo`;o003o0oooool2o`00o`04
ooooool00?oo003oo`00o`?ooooo1?l00?l00ooooooo003oo`00o`02o`00o`Gooooo1ol00?l2oooo
oa;o003o00?oooooo`00ool00?l01Ol00?l2ooooo`?o003o1?ooool2o`00o`?ooooo0_l00?l00ooo
oooo003oo`00o`02ooooo`;o003o00?oooooo`00ool00?l02_ooool2o`00o`Sooooo0_l00?l8oooo
o`;o003o2Oooool2o`00o`;ooooo0_l00?lDooooo`;o003o1?ooool2o`00oaKooooo0_l00?l3oooo
o`7o003o0Ol00001ooooo`0000?o0000ooooooooool03Oooool2o`00o`Cooooo0_l00?lCooooo`;o
003o6oooool2o`00o`Cooooo1?l00?l00ooooooo003oo`00o`05ooooo`;o003o1?ooool2o`00o`04
ooooool00?oo003oooooo`?o003o0oooool9o`00o`Gooooo0_l00?l00ooooooo003oo`00o`03o`00
o`03ooooool00?oo003o00oo003o0_ooool4o`00o`?ooooo1Ol00?l9ooooo`;o003o1Oooool2o`00
ob[ooooo0_l00?l7ooooo`;o003o5oooool2o`00oaKooooo0_l00?l4ooooo`7o00000Oooool00003
o`000?oooooooooo00gooooo0_l00?l2ooooo`Co003o2_ooool2o`00o`Cooooo0_l00?l2ooooo`;o
003o4?ooool2o`00o`Gooooo0_l00?l00ooooooo003oo`00o`04ooooo`?o003o3Oooool5o`00o`Ko
oooo0_l00?l3ooooo`Co003o1?ooool2o`00o`Gooooo5ol00?l00ooooooo003oo`00o`02o`00o`Co
oooo1?l00?l2ooooo`;o003o1?ooool2o`00oa_ooooo0_l00?lFooooo`Co003o1Oooool2o`00oaOo
oooo0_l00?l4ooooo`;o003o3?ooool2o`00o`Sooooo0Ol00001ooooo`0000?o0000ooooooooool0
1oooool2o`00o`Sooooo0_l00?l2ooooo`;o003o2?ooool2o`00o`Cooooo0_l00?l2ooooo`;o003o
4?ooool2o`00o`Gooooo0_l00?l8ooooo`;o003o1oooool4o`00o`;ooooo1Ol00?l6ooooo`;o003o
00?oooooo`00ool00?l01?l00?l4ooooo`;o003o1Oooool8o`00o`;ooooo0ol00?l2ooooo`Co003o
00?oooooo`00ool00?l01Ol00?l00ooooooo003oo`00o`02o`00o`;ooooo0_l00?l01?oooooo003o
o`00ool00?l4ooooo`;o003o5_ooool2o`00o`?ooooo0_l00?lHooooo`;o003o7?ooool2o`00o`Ko
oooo0_l00?l<ooooo`;o003o1oooool1o`00o`7o00000Oooool00003o`000?oooooooooo00Oooooo
0_l00?l<ooooo`;o003o4oooool2o`00oaKooooo0ol00?l:ooooo`;o003o1?ooool4o`00o`Cooooo
0_l00?l2ooooo`;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`05o`00o`;ooooo
1Ol00?l3ooooo`;o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`0Jo`00o`03oooo
ool00?oo003o00;o003o2Oooool2o`00o`Cooooo0_l00?l:ooooo`Co003o00?oooooo`00ool00?l0
0_l00?l5ooooo`;o003o00?oooooo`00ool00?l07?ooool2o`00o`cooooo0_l00?lMooooo`7o003o
0Ol00001ooooo`0000?o0000ooooooooool06Oooool2o`00o`;ooooo0_l00?l;ooooo`;o003o1_oo
ool2o`00o`oooooo0_l00?l3ooooo`;o003o0oooool5o`00o`_ooooo0_l00?l2ooooo`;o003o00?o
ooooo`00ool00?l00_l00?l2ooooo`;o003o0_ooool2o`00o`03ooooool00?oo003o00Co003o1?oo
oolSo`00o`03ooooool00?oo003o00;o003o2Oooool4o`00o`;ooooo0_l00?l7ooooo`;o003o0ooo
ool2o`00o`?ooooo0_l00?l5ooooo`Go003o0oooool2o`00o`;ooooo0_l00?lAooooo`Co003o0ooo
ool2o`00o`cooooo0_l00?lIooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0_l00?l2
ooooo`;o003o00?oooooo`00ool00?l01_ooool3o`00o`?ooooo0_l00?l2ooooo`;o003o0_ooool2
o`00o`Cooooo0_l00?l5ooooo`;o003o0_ooool5o`00o`04ooooool00?oo003oooooo`Go003o2?oo
ool2o`00o`[ooooo3Ol00?l2oooooa_o003o00?oooooo`00ool00?l00oooool2o`00o`03ooooool0
0?oo003o00Oooooo0_l00?l5ooooo`Co003o1Oooool2o`00o`Cooooo0_l00?l>ooooo`;o003o00?o
ooooo`00ool00?l00oooool3o`00o`;ooooo0_l00?lAooooo`;o003o0_ooool2o`00o`03ooooool0
0?oo003o00?ooooo0_l00?l7ooooo`;o003o6Oooool1o`00007ooooo00000ol0003oooooooooo`0P
ooooo`;o003o1_ooool3o`00o`?ooooo0_l00?l6ooooo`;o003o1?ooool2o`00o`03ooooool00?oo
003o00;ooooo0_l00?l2ooooo`Go003o00?oooooo`00ool00?l00oooool3o`00oa?ooooo2_l00?l0
0ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l03_l00?l0
0ooooooo003oo`00o`07o`00o`04ooooool00?oo003oooooo`Oo003o0_ooool4o`00o`;ooooo0_l0
0?l8ooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`[ooooo0_l00?l6ooooo`;o003o0ooo
ool2o`00oaGooooo0_l00?l6ooooo`?o003o8Oooool1o`00007ooooo00000ol0003oooooooooo`0j
ooooo`;o003o0oooool2o`00o`[ooooo1?l00?l01?oooooo003oo`00ooooool2o`00o`Cooooo0_l0
0?l00ooooooo003oo`00o`02o`00o`Sooooo1Ol00?l4ooooo`co003o00?oooooo`00ool00?l08ol0
0?l4ooooo`;o003o0_ooool4o`00o`Wooooo0ol00?l4ooooo`;o003o1?ooool2o`00oa7ooooo0_l0
0?l6ooooo`;o003o1oooool2o`00o`cooooo0ol00?l8ooooo`;o003o3_ooool2o`00o`Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool03_ooool2o`00ob?ooooo0_l00?l01?oooooo003oo`00oooo
ool3o`00o`cooooo0_l00?l00ooooooo003oo`00o`03ooooo`;o003o00?oooooo`00ool00?l01?oo
ool2o`00o`03ooooool00?oo003o00;o003o0_ooool2o`00o`Gooooo0ol00?l2ooooo`;o003o00?o
ooooo`00ool00?l00oooool4o`00o`;ooooo0_l00?l00ooooooo003oo`00o`0Do`00o`03ooooool0
0?oo003o00Co003o0oooool3o`00o`Gooooo0_l00?l4ooooo`;o003o1?ooool2o`00o`Cooooo0ol0
0?l3ooooo`;o003o1?ooool2o`00o`kooooo0_l00?l9ooooo`;o003o1oooool2o`00o`cooooo1Ol0
0?l6ooooo`Co003o3?ooool4o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool2
o`00oaGooooo0_l00?l<ooooo`;o003o00Coooooo`00ool00?oooooo0ol00?l<ooooo`;o003o1ooo
ool2o`00o`Wooooo0ol00?l3ooooo`;o003o1?ooool4o`00o`;ooooo1Ol00?l00ooooooo003oo`00
o`04o`00o`05ooooool00?oo003oo`00ooooool05_l00?l2ooooo`;o003o1oooool2o`00o`Gooooo
0ol00?l3ooooo`;o003o1?ooool2o`00o`Gooooo0_l00?lBooooo`;o003o1Oooool2o`00o`Wooooo
0_l00?l3ooooo`?o003o4Oooool3o`00o`Sooooo0_l00?l>ooooo`;o003o00?oooooo`00ool00?l0
0_ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`;o003o3?ooool2o`00o`Gooooo0_l0
0?l3ooooo`;o003o0oooool4o`00o`Gooooo0_l00?l3ooooo`;o003o2Oooool;o`00o`Gooooo0_l0
0?l00ooooooo003oo`00o`0Cooooo`Ko003o0_ooool4o`00o`;ooooo8_l00?lBooooo`;o003o00?o
ooooo`00ool00?l00_l00?l<ooooo`;o003o4Oooool2o`00o`[ooooo0_l00?l4ooooo`;o003o0ooo
ool3o`00oaWooooo0_l00?lDooooo`;o003o0_ooool1o`00007ooooo00000ol0003oooooooooo`06
ooooo`;o003o00?oooooo`00ool00?l02?ooool3o`00o`?ooooo1?l00?l3ooooo`;o003o1Oooool2
o`00o`Gooooo0_l00?l3ooooo`Go003o1_ooool;o`00o`Gooooo1_l00?l<ooooo`?o003o00?ooooo
o`00ool00?l00_l00?l2ooooo`;o003o0_ooool2o`00o`Kooooo1Ol00?l00ooooooo003oo`00o`0D
o`00o`;ooooo0_l00?l00ooooooo003oo`00o`05ooooo`Co003o0_ooool2o`00o`;ooooo1ol00?l<
ooooo`;o003o3_ooool2o`00o`Sooooo0_l00?l3ooooo`Co003o0oooool2o`00oa[ooooo0_l00?l2
ooooo`;o003o1?ooool2o`00oa;ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00
o`Sooooo0_l00?l4ooooo`;o003o3Oooool2o`00o`03ooooool00?oo003o00;ooooo0_l00?l00ooo
oooo003oo`00o`04o`00o`Oooooo0_l00?l2ooooo`?o003o2_ooool4o`00o`_ooooo1?l00?l01?oo
oooo003oo`00ooooool2o`00o`03ooooool00?oo003o00?ooooo0_l00?l00ooooooo003oo`00o`02
ooooo`Go003o00?oooooo`00ool00?l06?l00?l00ooooooo003oo`00o`05ooooo`Co003o0_ooool7
o`00o`Wooooo0ol00?l=ooooo`Co003o0oooool2o`00o`Sooooo0_l00?l5ooooo`;o003o0oooool2
o`00o`Cooooo0_l00?l2ooooo`;o003o0_ooool2o`00o`03ooooool00?oo003o00Wooooo0_l00?l8
ooooo`;o003o4_ooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`Co003o2oooool2o`00
o`kooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo2?l00?l8ooooo`;o003o0_ooool3
o`00o`;ooooo0_l00?l00ooooooo003oo`00o`04ooooo`;o003o0_ooool2o`00o`Cooooo0_l00?l2
ooooo`;o003o1_ooool2o`00o`03ooooool00?oo003o00Wo003o00Coooooo`00ool00?oooooo7?l0
0?l00ooooooo003oo`00o`0>ooooo`;o003o1oooool2o`00o`?ooooo0ol00?l5ooooo`;o003o1_oo
ool4o`00oagooooo1?l00?l2ooooo`;o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o
5oooool2o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool05Oooool2o`00o`kooooo0_l0
0?l:ooooo`;o003o4?ooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`08ooooo`;o003o0_oo
ool4o`00o`Kooooo0_oo0003oooooa3o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00
o`0Ho`00o`03ooooool00?oo003o00Wooooo0_l00?l6ooooo`Ko003o0oooool2o`00o`Gooooo0_l0
0?lOooooo`;o003o0_ooool2o`00o`;ooooo1?l00?l<ooooo`;o003o00?oooooo`00ool00?l05?oo
ool2o`00o`Gooooo0_l00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00oooooo0_l00?l2
ooooo`;o003o5_ooool2o`00o`_ooooo0_l00?l9ooooo`;o003o2oooool2o`00o`Cooooo1Ol00?l3
ooooo`;o003o0oooool2ool00003ooooool00?oo003o00;o003o00Coooooo`00ool00?oooooo1?l0
0?l01Ooooooo003oo`00ool00?oooooo00Ko003o00Goooooo`00ool00?oo003oooooo`0>o`00o`;o
oooo1Ol00?l2ooooo`Ko003o0_ooool2o`00o`04ooooool00?oo003oooooo`?o003o0_ooool3o`00
o`04ooooool00?oo003oooooo`Co003o3?ooool4o`00oaKooooo0_l00?l2ooooo`;o003o0_ooool2
o`00o`Wooooo0_l00?l6ooooo`Co003o6Oooool2o`00o`Cooooo0Ol00001ooooo`0000?o0000oooo
ooooool03oooool2o`00o`;ooooo0_l00?lEooooo`?o003o1Oooool2o`00o`Cooooo0_l00?l3oooo
o`?o003o00?oooooo`00ool00?l01?l00?l9ooooo`;o003o1?ooool6o`00o`04ooooool00?oo003o
o`00o`?ooooo0_l00?l00ooooooo003oo`00o`02o`00o`04ooooool00?oo003oooooo`Co003o1?oo
ool8o`00o`?ooooo4Ol00?l2ooooo`_o003o0_ooool2o`00o`Cooooo0ol00?l2ooooo`;o003o1Ooo
ool2o`00o`kooooo1?l00?lJooooo`;o003o1?ooool2o`00o`Cooooo0_l00?l00ooooooo003oo`00
o`08ooooo`;o003o7?ooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool02?ooool2
o`00oa?ooooo0_l00?l;ooooo`;o003o1_ooool2o`00o`Wooooo0ol00?l00ooooooo003oo`00o`04
o`00o`Oooooo0_l00?l2ooooo`;o003o00Coooooo`00ool00?oo003o0_ooool5o`00o`04ooooool0
0?oo003oooooo`;o003o1Oooool3o`00o`04ooooool00?oo003oo`00o`Cooooo2Ol00?l3ooooo`Go
003o00?oooooo`00ool00?l05Ol00?l>ooooo`;o003o2?ooool2o`00o`Sooooo0_l00?l00ooooooo
003oo`00o`03ooooo`?o003o5_ooool2o`00o`Cooooo0_l00?l4ooooo`;o003o1Oooool2o`00o`co
oooo0_l00?l9ooooo`;o003o2Oooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
2?ooool2o`00o`[ooooo0_l00?l4ooooo`;o003o00?oooooo`00ool00?l06_ooool2o`00o`Sooooo
0_l00?l2ooooo`;o003o0oooool5o`00o`04ooooool00?oo003oooooo`?o003o1?ooool2o`00o`;o
oooo0_l00?l8ooooo`?o003o0_ooool3o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool0
0?l05Ol00?l00ooooooo003oo`00o`03ooooo`?o003o2oooool2o`00o`Sooooo0_l00?l3ooooo`;o
003o0oooool2o`00o`;ooooo0_l00?l2ooooo`?o003o7Oooool4o`00o`?ooooo0_l00?l3ooooo`;o
003o3?ooool2o`00o`Wooooo0_l00?l<ooooo`7o00000Oooool00003o`000?oooooooooo01;ooooo
1?l00?l4ooooo`;o003o3?ooool2o`00o`cooooo0_l00?l00ooooooo003oo`00o`0<ooooo`;o003o
0_ooool6o`00o`03ooooool00?oo003o00gooooo0_l00?l8ooooo`;o003o00?oooooo`00ool00?l0
0_l00?l01?oooooo003oo`00ooooool5o`00o`;ooooo1?l00?l00ooooooo003oo`00o`04o`00o`;o
oooo0ol00?l00ooooooo003oo`00o`05o`00o`04ooooool00?oo003oo`00o`Gooooo0ol00?lEoooo
o`;o003o0oooool2o`00o`Oooooo0_l00?lFooooo`;o003o2_ooool4o`00o`?ooooo0_l00?lAoooo
o`;o003o1Oooool2o`00o`;ooooo0_l00?l<ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo0_l00?l=ooooo`;o003o3oooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`09ooooo`;o
003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00o`03ooooo`;o003o1?ooool4o`00o`[o
oooo0_l00?l2ooooo`;o003o0_ooool3o`00o`Kooooo0ol00?l00ooooooo003oo`00o`03o`00o`Go
oooo1?l00?l00ooooooo003oo`00o`02o`00o`Gooooo0_l00?l00ooooooo003oo`00o`0:o`00o`;o
oooo0_l00?l00ooooooo003oo`00o`0@ooooo`;o003o2?ooool2o`00oa3ooooo0_l00?lBooooo`;o
003o1oooool2o`00o`_ooooo0_l00?lEooooo`;o003o4?ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooo`;o003o1Oooool2o`00oaOooooo0_l00?l6ooooo`;o003o1oooool2o`00o`Gooooo
1?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;o003o0_ooool4o`00o`;ooooo
0ol00?l5ooooo`;o003o0_ooool2o`00o`?ooooo1_l00?l2ooooo`;o003o0oooool4o`00o`04oooo
ool00?oo003ooooooako003o0oooool4o`00o`;ooooo0ol00?l00ooooooo003oo`00o`08ooooo`;o
003o0oooool2o`00o`;ooooo0_l00?l>ooooo`;o003o00?oooooo`00ool00?l02Oooool3o`00o`oo
oooo0_l00?l;ooooo`;o003o0_ooool2o`00ob?ooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_l00?l8ooooo`;o003o3oooool2o`00o`;oo`003oooool2o`00o`Cooooo0_l00?l:ooooo`Co003o
0oooool2o`00o`Cooooo0_l00?l00ooooooo003oo`00o`03o`00o`Gooooo0_l00?l01Ooooooo003o
o`00ool00?oooooo00Oo003o00Coooooo`00ool00?oo003o0oooool2o`00o`?ooooo0_l00?l01?oo
oooo003oo`00oooooolRo`00o`;ooooo0ol00?l00ooooooo003oo`00o`04ooooo`;o003o00?ooooo
o`00ool00?l00_ooool4o`00o`;ooooo0_l00?l>ooooo`;o003o2oooool4o`00o`oooooo0_l00?l?
ooooo`;o003o5oooool2o`00o`Kooooo0_l00?l2ooooo`7o00000Oooool00003o`000?oooooooooo
00;o003o6Oooool2o`00o`;oo`001_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o1_ooool3o`00
o`Oooooo0_l00?l2ooooo`;o003o2_ooool2o`00o`03ooooool00?oo003o00Gooooo0_l00?l01Ooo
oooo003oo`00ool00?oooooo00Go003o0oooool3o`00o`[ooooo0_l00?l2ooooo`;o003o00?ooooo
o`00ool00?l03ol00?l2ooooo`?o003o00?oooooo`00ool00?l00_l00?l00ooooooo003oo`00o`02
o`00o`;ooooo0_l00?l7ooooo`;o003o00?oooooo`00ool00?l00_ooool2o`00oa;ooooo0_l00?l=
ooooo`;o003o8oooool2o`00oaKooooo0_l00?l6ooooo`;o003o0_ooool1o`00007ooooo00000ol0
003oooooooooo`0Gooooo`;o003o1_ooool3o`00o`?ooooo0_l00?l3ooooo`;o003o1Oooool2o`00
o`03ooooool00?oo003o00?o003o1oooool2o`00o`;ooooo0ol00?l4ooooo`;o003o0_ooool2o`00
o`cooooo0_l00?l4ooooo`?o003o1oooool5o`00o`04ooooool00?oo003oooooo`;o003o0_ooool2
o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l02Ol00?l2ooooo`Ko003o00?ooooo
o`00ool00?l00_ooool3o`00o`Cooooo0_l00?l3ooooo`;o003o0oooool2o`00o`_ooooo0ol00?l4
ooooo`Go003o7Oooool2o`00o`_ooooo0_l00?l6ooooo`;o003o8_ooool1o`00007ooooo00000ol0
003o003oo`00o`03ooooo`;o003o4_ooool2o`00o`Kooooo0ol00?l?ooooo`;o003o00?oooooo`00
ool00?l00_l00?l9ooooo`;o003o0_ooool5o`00o`03ooooool00?oo003o00;ooooo0_l00?l2oooo
o`;o003o0oooool2o`00o`?ooooo0_l00?l4ooooo`Co003o1_ooool5o`00o`05ooooool00?oo003o
o`00ooooool01?l00?l2ooooob;o003o0oooool3o`00o`;ooooo0_l00?l3ooooo`;o003o2oooool3
o`00o`Cooooo1?l00?l8ooooo`;o003o0oooool2o`00o`oooooo0_l00?l5ooooo`;o003o1?ooool2
o`00obGooooo0_l00?l3ooooo`7o00000Oooool00003o`000?l00?oo003o00?ooooo0_l00?lToooo
o`;o003o1oooool2o`00o`;ooooo0_l00?l6ooooo`;o003o00?oooooo`00ool00?l00_l00?l00ooo
oooo003oo`00o`02o`00o`?ooooo1?l00?l00ooooooo003oo`00o`02o`00o`04ooooool00?oo003o
o`00o`Gooooo0_l00?l2ool000;ooooo0_l00?l6ooooo`Ko003o00Coooooo`00ool00?oooooo4Ol0
0?l3oooooaOo003o00Coooooo`00ool00?oooooo0_l00?l7ooooo`;o003o6oooool2o`00o`?ooooo
0_l00?lFooooo`;o003o1_ooool2ool001Gooooo0_l00?l<ooooo`;o003o0oooool1o`00007ooooo
00000ol0003oooooooooo`0Yooooo`;o003o1oooool2o`00o`03ooooool00?oo003o00;o003o1Ooo
ool2o`00o`?ooooo0_l00?l3ooooo`;o003o00?oooooo`00ool00?l01?l00?l00ooooooo003oo`00
o`02o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l01ol00?l3ooooo`_o003o
0_ooool2o`00o`03ooooool00?oo003o00ko003o0_ooool>o`00o`03ooooool00?oo003o00;ooooo
1?l00?l01?oooooo003oo`00ooooool3o`00o`Kooooo0_l00?l6ooooo`;o003o4Oooool2o`00oaCo
oooo0_l00?l?ooooo`;oo`005Oooool2o`00o`Kooooo0_l00?l9ooooo`7o00000Oooool00003o`00
0?oooooooooo02[ooooo0_l00?l9ooooo`Co003o2oooool2o`00o`05ooooool00?oo003oo`00oooo
ool00_l00?l<ooooo`?o003o00Coooooo`00ool00?oooooo1_l00?l3ooooo`Oo003o00Coooooo`00
ool00?oo003o0_ooool2o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l05_l00?l2
ooooo`;o003o0_ooool3o`00o`;ooooo0_l00?l2ooooo`;o003o2?ooool2o`00o`Cooooo1Ol00?l>
ooooo`;o003o1Oooool2o`00o`Cooooo0_l00?l7ooooo`;o003o00?oooooo`00ool00?l05?ooool2
o`00o`oooooo0_l00?l4ooooo`;o003o2Oooool1o`00007ooooo00000ol0003oooooooooo`0Doooo
o`;o003o00?oooooo`00ool00?l03oooool4o`00o`oooooo1?l00?l5ooooo`;o003o00Coooooo`00
ool00?oo003o2?ooool3o`00o`Cooooo1?l00?l7ooooo`;o003o0oooool4o`00o`04ooooool00?oo
003oo`00o`Cooooo0_l00?l4oooooago003o00?oooooo`00ool00?l00oooool2o`00o`?ooooo0_l0
0?l<ooooo`?o003o1?ooool4o`00oa;ooooo0_l00?l00ooooooo003oo`00o`04ooooo`;o003o1?oo
ool2o`00o`Cooooo1?l00?lBooooo`;o003o3oooool2o`00o`Kooooo0_l00?l7ooooo`7o00000Ooo
ool00003o`000?oooooooooo01Cooooo0_l00?l00ooooooo003oo`00o`0?ooooo`;o003o0oooool2
o`00o`Gooooo0_l00?l3ooooo`Ko003o00?oooooo`00ool00?l03Oooool2o`00o`05ooooool00?oo
003oo`00ooooool00_l00?l3ooooo`;o003o1oooool2o`00o`03ooooool00?oo003o00;o003o0_oo
ool;o`00o`?ooooo0_l00?l00ooooooo003oo`00o`0Ko`00o`Oooooo0ol00?l=ooooo`;o003o0ooo
ool2o`00oaGooooo0ol00?l7ooooo`;o003o0oooool2o`00o`Kooooo0_l00?lEooooo`;o003o2ooo
ool2o`00o`Oooooo0_l00?l7ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo0_l00?l7
ooooo`;o003o5?ooool2o`00o`Gooooo0_l00?l3ooooo`;o003o0oooool4o`00o`;ooooo0_l00?l0
0ooooooo003oo`00o`06ooooo`;o003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo0ol00?l2
ooooo`;o003o0oooool5o`00o`Cooooo0_l00?l00ooooooo003oo`00o`03o`00o`04ooooool00?oo
003oo`00o`Gooooo1ol00?l00ooooooo003oo`00o`09o`00o`03ooooool00?oo003o00;o003o00Co
ooooo`00ool00?oo003o0oooool2o`00o`03ooooool00?oo003o00?o003o3?ooool2o`00o`Cooooo
0_l00?l?ooooo`;o003o1Oooool2o`00o`Oooooo0_l00?lAooooo`;o003o1?ooool2o`00o`Wooooo
0_l00?l;ooooo`;o003o4?ooool1o`00007ooooo00000ol0003o003oo`00o`0=ooooo`?o003o1ooo
ool2o`00o`Kooooo0_l00?l6ooooo`?o003o0oooool2o`00o`Gooooo0_l00?l8ooooo`;o003o1?oo
ool2o`00o`03ooooool00?oo003o00Gooooo0_l00?l3ooooo`;o003o00?oooooo`00ool00?l01?l0
0?l3ooooo`;o003o0_ooool4o`00o`_ooooo1ol00?l00ooooooo003oo`00o`02ooooob7o003o00?o
ooooo`00ool00?l00ol00?l<ooooo`Co003o2oooool4o`00o`04ooooool00?oo003oooooo`;o003o
1Oooool4o`00o`;ooooo0_l00?l:ooooo`;o003o2?ooool2o`00o`Cooooo0_l00?l?ooooo`;oo`00
1oooool2o`00o`kooooo0Ol00001ooooo`0000?o0000o`00ool00?l03?ooool3o`00oa3ooooo1?l0
0?l4ooooo`?o003o1_ooool2o`00o`?ooooo0_l00?l2ooooo`Co003o1?ooool2o`00o`Wooooo1?l0
0?l3ooooo`;o003o00?oooooo`00ool00?l00_l00?l5ooooo`;o003o0_ooool4o`00o`Gooooo0ol0
0?l2ooooo`?o003o00Coooooo`00ool00?oo003o0_ooool2o`00o`Gooooo3Ol00?l3ooooo`Oo003o
00?oooooo`00ool00?l01?l00?l3ooooo`;o003o3oooool2o`00o`03ooooool00?oo003o00Sooooo
1?l00?l00ooooooo003oo`00o`0:ooooo`;o003o0_ooool2o`00o`03ooooool00?oo003o00Oooooo
0_l00?l;ooooo`;o003o3?ooool2o`00o`Cooooo0_oo0007ooooo`;o003o3_ooool1o`00007ooooo
00000ol0003oooooooooo`0;ooooo`?o003o1oooool2o`00o`[ooooo0_l00?l8ooooo`;o003o0_oo
ool4o`00o`;ooooo0_l00?l2ooooo`Co003o00Coooooo`00ool00?oooooo0_l00?l9ooooo`;o003o
1Oooool6o`00o`Kooooo0_l00?l3ooooo`;o003o0_ooool7o`00o`;ooooo0_l00?l00oooooooo`00
ool00004o`00o`03ooooool00?oo003o00Go003o00?oooooo`00ool00?l03Ol00?l00ooooooo003o
o`00o`09o`00o`Cooooo0_l00?l2ooooo`?o003o2oooool4o`00o`;ooooo0ol00?lKooooo`;o003o
5?ooool2o`00o`?ooooo0_l00?l7ooooo`Co003o4oooool2o`00o`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool02oooool2o`00o`Sooooo0ol00?l;ooooo`;o003o1_ooool2o`00o`;ooooo2Ol0
0?l00ooooooo003oo`00o`03ooooo`;o003o2Oooool6o`00o`?ooooo1_l00?l5ooooo`?o003o00Co
ooooo`00ool00?oooooo0_l00?l2ooooo`Oo003o00Goooooo`00ool00?oo003oooooo`02ool000Co
003o00?oooooo`00ool00?l01Ol00?l00ooooooo003oo`00o`0Do`00o`03ooooool00?oo003o00Co
003o0oooool2o`00o`04ooooool00?oo003oo`00o`Cooooo0_l00?l5ooooo`Co003o0_ooool3o`00
o`kooooo0_l00?l5ooooo`;o003o1_ooool5o`00oa?ooooo1Ol00?l00ooooooo003oo`00o`04oooo
o`;o003o0_ooool2o`00o`oooooo0_l00?l6ooooo`7o00000Oooool00003o`000?oooooooooo013o
oooo0_l00?l4ooooo`;o003o2oooool2o`00o`Oooooo0_l00?l5ooooo`Go003o1_ooool2o`00o`Ko
oooo0_l00?l00ooooooo003oo`00o`0:o`00o`Cooooo0_l00?l2ooooo`?o003o00?oooooo`00ool0
0?l00oooool3o`00o`;ooooo1?l00?l00ooooooo003oo`00o`02o`00o`;ooooo7_l00?l00ooooooo
003oo`00o`02o`00o`;ooooo1Ol00?l3ooooo`;o003o1oooool3o`00oa;ooooo0_l00?l8ooooo`;o
003o1Oooool2o`00o`Kooooo1_l00?l3ooooo`;o003o1_ooool4o`00o`?ooooo1Ol00?l00ooooooo
003oo`00o`08ooooo`Co003o4_ooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool0
0_l00?l7ooooo`;o003o1Oooool2o`00o`Sooooo0_l00?l3ooooo`;o003o2oooool2o`00o`03oooo
ool00?oo003o00;ooooo0_l00?lAooooo`?o003o1Oooool4o`00o`03ooooool00?oo003o00;o003o
00Coooooo`00ool00?oo003o1_ooool8o`00o`;ooooo1?l00?l00ooooooo003oo`00o`02o`00o`?o
oooo:Ol00?l7ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l?ooooo`;o003o3oooool2o`00o`[o
oooo0_l00?l2ooooo`?o003o1_ooool4o`00o`Cooooo0_l00?l;ooooo`;o003o0_ooool2o`00oa;o
oooo0_l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00;o003o1oooool2o`00o`cooooo
0_l00?l01?oooooo003oo`00ool00?l2ooooo`;o003o3_ooool2o`00o`;ooooo1?l00?l@ooooo`;o
003o0oooool4o`00o`03ooooool00?oo003o00Oo003o1?ooool2o`00o`;ooooo1Ol00?l5ooooo`;o
003o0_ooool2o`00o`Gooooo0ol00?l3oooooako003o0oooool2o`00o`Oooooo0_l00?l7ooooo`?o
003o2_ooool2o`00o`kooooo0_l00?l00ooooooo003oo`00o`02o`00o`[ooooo0_l00?l2ooooo`;o
003o7?ooool2o`00oa;ooooo0_l00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00;o003o
1Oooool2o`00o`Wooooo0_l00?l00ooooooo003oo`00o`02o`00o`;ooooo0_l00?l4ooooo`;o003o
1_ooool2o`00o`[ooooo0_l00?l>ooooo`Go003o0_ooool2o`00o`;ooooo1Ol00?l01?oooooo003o
o`00ool00?l3ooooo`Co003o0_ooool2o`00o`Oooooo0_l00?l3ooooo`Go003o0_ooool3o`00o`?o
oooo1?l00?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00Go003o0_ooool7o`00o`04
ooooool00?oo003oo`00o`;ooooo0ol00?l3ooooo`;o003o3?ooool3o`00o`Wooooo0_l00?l>oooo
o`;o003o00?oooooo`00ool00?l00_ooool2o`00o`Sooooo0_l00?l;ooooo`Co003o9Oooool2o`00
o`Gooooo0Ol00001ooooo`0000?o003oooooooooool00_l00?l5ooooo`;o003o00?oooooo`00ool0
0?l01_ooool2o`00o`03ooooool00?oo003o00[ooooo0_l00?l6ooooo`;o003o0_ooool2o`00oa3o
oooo0_l00?l3ooooo`Ko003o00Coooooo`00ool00?oo003o0_ooool5o`00o`;ooooo1?l00?l00ooo
oooo003oo`00o`02ooooo`?o003o1Oooool5o`00o`;ooooo2ol00?l00ooooooo003oo`00o`0Jo`00
o`04ooooool00?oo003oo`00o`;ooooo0_l00?l4ooooo`;o003o1Oooool2o`00o`;ooooo0_l00?l2
ooooo`;o003o0oooool4o`00oa3ooooo1?l00?l2ooooo`;o003o00?oooooo`00ool00?l01oooool2
o`00o`Gooooo0_l00?l5ooooo`Co003o1?ooool2o`00o`Wooooo0_l00?lKooooo`7o00000Oooool0
0003o`00oooooooooooo00[ooooo0_l00?lMooooo`;o003o0_ooool4o`00o`Gooooo0ol00?l6oooo
o`;o003o0oooool2o`00o`Gooooo0_l00?l4ooooo`Co003o00?oooooo`00ool00?l00ol00?l5oooo
o`?o003o0oooool5o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`0Ro`00o`03ooooool00?oo003o
00;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`02
ooooo`;o003o1oooool4o`00oa3ooooo1?l00?l2ooooo`;o003o2?ooool8o`00o`03ooooool00?oo
003o00Sooooo0_l00?l3ooooo`;o003o2Oooool2o`00oa_ooooo0Ol00001ooooo`0000?o0000oooo
ooooool00_l00?l4ooooo`;o003o1Oooool2o`00o`_ooooo0_l00?l;ooooo`Co003o1?ooool2o`00
o`Gooooo0ol00?l6ooooo`;o003o0oooool2o`00oa3ooooo0_l00?l8ooooo`Co003o0_ooool5o`00
o`;ooooo0ol00?l3ooooo`Co003o00?oooooo`00ool00?l05?l00?l00ooooooo003oo`00o`06o`00
o`Gooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`;ooooo1?l00?l01?oooooo003oo`00oooo
ool2o`00oaKooooo0_l00?lCooooo`;o003o0_ooool4o`00o`Cooooo0_l00?l5ooooo`;o003o3_oo
ool2o`00oa_ooooo0Ol00001ooooo`0000?o0000ooooooooool00_l00?l2ool000;ooooo0_l00?l5
ooooo`;o003o2oooool2o`00o`_ooooo0_l00?l=ooooo`;o003o0_ooool2o`00o`cooooo1Ol00?l5
ooooo`;o003o1oooool2o`00o`?ooooo1?l00?l6ooooo`;o003o00?oooooo`00ool00?l00_l00?l2
ooooo`?o003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o00?oooooo`00ool00?l02ol0
0?l00ooooooo003oo`00o`06o`00o`oooooo1ol00?l00ooooooo003oo`00o`0:ooooo`;o003o2_oo
ool2o`00o`gooooo0_l00?l<ooooo`;oo`000_ooool2o`00o`Oooooo0_l00?lEooooo`;o003o0ooo
ool2o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00_ooool2ool000cooooo0_l00?l4
ooooo`;o003o0_ooool2o`00oa?ooooo0ol00?l4ooooo`;o003o00Coooooo`00ool00?oo003o2Ooo
ool8o`00o`Cooooo0ol00?l2ooooo`;o003o0oooool4o`00o`;ooooo1?l00?l4ooooo`?o003o00?o
ooooo`00ool00?l00_l00?l2ooooo`?o003o0_ooool2o`00o`03ooooool00?oo003o00_o003o00?o
ooooo`00ool00?l00ol00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o00?ooooo0_l0
0?l2ooooo`;o003o1_ooool2o`00o`?ooooo0_l00?l7ooooo`;o003o00Coooooo`00ool00?oooooo
1?l00?lDooooo`;o003o00?oooooo`00ool00?l02Oooool2ool00004ooooool00?oo003oo`00o`Oo
oooo0_l00?l>ooooo`;o003o1Oooool2o`00o`?ooooo0_l00?l=ooooo`7o00000Oooool00003o`00
0?oooooooooo013ooooo0_l00?l4ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o
2_ooool3o`00o`;ooooo1ol00?l2ooooo`;o003o1_ooool3o`00o`Gooooo0_l00?l01?oooooo003o
o`00ool00?l3ooooo`;o003o0oooool4o`00o`;ooooo1?l00?l00ooooooo003oo`00o`04o`00o`;o
oooo0_l00?l2ooooo`So003o00?oooooo`00ool00?l04Ol00?l00ooooooo003oo`00o`02o`00o`03
ooooool00?oo003o00Go003o0_ooool3o`00o`04ooooool00?oo003oooooo`;o003o0_ooool3o`00
o`cooooo0_l00?l2ooooo`Ko003o0oooool2o`00o`oooooo0_l00?l00ooooooo003oo`00o`0<oooo
o`;o003o3oooool2o`00o`Oooooo1?l00?lAooooo`;o003o1?ooool1o`00007ooooo00000ol0003o
ooooooooo`06ooooo`;o003o00?oooooo`00ool00?l03oooool2o`00o`?ooooo0_l00?l2ooooo`;o
003o0_ooool2o`00o`_ooooo0_l00?l2ooooo`?o003o0_ooool2o`00o`Cooooo1Ol00?l00ooooooo
003oo`00o`02ooooo`;o003o00?oooooo`00ool00?l01_ooool5o`00o`;ooooo0_l00?l3ooooo`Ko
003o0_ooool2o`00o`03ooooool00?oo003o00So003o0ooooolAo`00o`?ooooo2ol00?l2ooooo`Co
003o00?oooooo`00ool00?l00_l00?l2ooooo`?o003o1?ooool5o`00o`Oooooo0_l00?l00ooooooo
003oo`00o`04ooooo`;o003o2?ooool2o`00oaGooooo0_l00?l2ooooo`;o003o3?ooool2o`00o`Wo
oooo0_l00?lAooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`06ooooo`;o003o
00?oooooo`00ool00?l07?ooool2o`00o`?ooooo0_l00?l3ooooo`;o003o1_ooool4o`00o`Kooooo
1Ol00?l00ooooooo003oo`00o`0=ooooo`Go003o0_ooool2o`00o`?ooooo0ol00?l5ooooo`So003o
0_ooool7o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l00_l00?l00ooooooo003o
o`00o`03o`00o`?ooooo1?l00?l00ooooooo003oo`00o`03o`00o`?ooooo0ol00?l00ooooooo003o
o`00o`04ooooo`?o003o1?ooool5o`00o`[ooooo0_l00?l4ooooo`;o003o2?ooool2o`00o`gooooo
0_l00?l6ooooo`;o003o0_ooool2o`00ob3ooooo0_l00?l9ooooo`;o003o0oooool1o`00007ooooo
00000ol0003oooooooooo`06ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l?ooooo`;o003o00?o
ooooo`00ool00?l01oooool2o`00o`03ooooool00?oo003o00;o003o00?oo`00ooooooooool01Ooo
ool5o`00o`Gooooo1Ol00?l6ooooo`;o003o0_ooool2o`00o`[ooooo1ol00?l3ooooo`Oo003o1Ooo
ool7o`00o`03ooooool00?oo003o01Go003o00?oooooo`00ool00?l01_ooool3o`00o`Cooooo0_l0
0?l00ooooooo003oo`00o`02o`00o`Kooooo1?l00?l6ooooo`;o003o5?ooool2o`00o`Cooooo0_l0
0?l3ooooo`;o003o;?ooool3o`00o`Oooooo0_l00?l4ooooo`7o00000Oooool00004o`000?oooooo
ooooooooo`;o003o2?ooool2o`00o`;ooooo0_l00?l<ooooo`;o003o00Coooooo`00ool00?oooooo
0_l00?l:ooooo`Co003o00?oo`00ooooooooool01Oooool5o`00o`Gooooo1Ol00?l6ooooo`;o003o
0_ooool2o`00o`Wooooo1_l00?l3ooooo`Wo003o1_oooolQo`00o`;ooooo0_l00?l2ooooo`Co003o
0oooool2o`00o`?ooooo0_l00?l6ooooo`Co003o1_ooool2o`00o`Kooooo0_l00?l3ooooo`;o003o
1oooool4o`00o`;ooooo0_l00?l7ooooo`;oo`00:Oooool2o`00o`Oooooo0_l00?l2ooooo`;o003o
0Ol00001ooooo`0000Co0000oooooooooooooooo0_l00?l3ooooo`;o003o00?oooooo`00ool00?l0
4_ooool2o`00o`Sooooo0_l00?l7ooooo`;o003o1Oooool2o`00o`04ooooool00?oo003oooooo`;o
003o00?oooooo`00ool00?l01_ooool2o`00o`03ooooool00?oo003o00?ooooo0_l00?l3ooooo`;o
003o00Coooooo`00ool00?oo003o1?ooool3o`00o`03ooooool00?oo003o00?ooooo0_l00?l00ooo
oooo003oo`00o`04o`00o`;ooooo0_l00?l2ooooo`Oo003o00Goooooo`00ool00?oo003oooooo`0<
o`00o`03ooooool00?oo003o00Ko003o0_ooool2o`00o`03ooooool00?oo003o00?o003o1?ooool2
o`00o`Cooooo0ol00?l4ooooo`;o003o3oooool2o`00o`?ooooo0_l00?l9ooooo`;o003o00Cooooo
o`00ool00?oo003o1oooool2ool000gooooo0_l00?lHooooo`?o003o1?ooool2o`00o`03ooooool0
0?oo003o00?ooooo0_l00?l1o`00007ooooo00000ol0003oooooooooo`06ooooo`;o003o00?ooooo
o`00ool00?l00_l00?lEooooo`;o003o0oooool2o`00o`03ooooool00?oo003o00_ooooo0_l00?l0
1?oooooo003oo`00ooooool2o`00o`03ooooool00?oo003o00Wooooo0ol00?l2ooooo`;o003o0ooo
ool2o`00o`04ooooool00?oo003oo`00o`Cooooo0ol00?l01?oooooo003oo`00ool00?l2ooooo`;o
003o2Oooool2o`00o`03ooooool00?oo003o00Gooooo0_l00?l01?oooooo003oo`00ooooool6o`00
o`03ooooool00?oo003o00Ko003o00?oooooo`00ool00?l00ol00?l01?oooooo003oo`00ooooool5
o`00o`Gooooo0_l00?l4ooooo`?o003o1?ooool2o`00oaCooooo0_l00?l9ooooo`;o003o00Cooooo
o`00ool00?oo003o5_ooool2o`00o`03ooooool00?oo003o01Gooooo0ol00?l01?oooooo003oo`00
ooooool2o`00o`03ooooool00?oo003o00Gooooo0Ol00001ooooo`0000?o0000ooooooooool01ooo
ool2o`00o`;ooooo0_l00?lEooooo`;o003o1_ooool3o`00o`_ooooo0_l00?l8ooooo`;o003o1?oo
ool2o`00o`04ooooool00?oo003oo`00o`_ooooo0_l00?l4ooooo`;o003o0oooool3o`00o`_ooooo
0ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00_o003o00?oooooo`00ool00?l0
0ol00?l01?oooooo003oo`00ooooool4o`00o`04ooooool00?oo003oooooo`Go003o0_ooool2o`00
o`?ooooo0_l00?l2ooooo`;o003o1?ooool2ool001Gooooo0_l00?l9ooooo`;o003o7Oooool2o`00
oaWooooo1?l00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo0_l00?lEooooo`;o
003o2oooool2o`00o`?ooooo0_l00?l6ooooo`Co003o1_ooool2o`00o`;ooooo0_oo0007o`00o`Go
oooo1?l00?l8ooooo`Oo003o00?oooooo`00ool00?l00_l00?l3ooooo`;o003o00Goooooo`00ool0
0?oo003oooooo`0Ho`00o`?ooooo2_l00?l2ooooo`;o003o1?ooool4o`00o`03ooooool00?oo003o
00;ooooo0_l00?l4ooooo`;o003o4_ooool2o`00o`cooooo0_l00?l00oooooooo`00ool00008oooo
o`;o003o1oooool2o`00o`Kooooo0_l00?l9ooooo`;o003o1_ooool2o`00o`Wooooo0_l00?l9oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo0_oo000Dooooo`;o003o0oooool2o`00oa3o
oooo1?l00?l6ooooo`;o003o00?oooooo`00ool00?l01oooool2ool000So003o1?ooool6o`00o`?o
oooo2Ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00;o003o1OoooolJo`00o`03
ooooool00?oo003o00So003o0_ooool2o`00o`04ooooool00?oo003oooooo`Co003o2oooool2o`00
o`Sooooo0_l00?l2ooooo`;o003o1?ooool2o`00o`;ooooo0_l00?l5ooooo`;oo`001?ooool2ool0
00Sooooo0_l00?l00ooooooo003oo`00o`04ooooo`Co003o1?ooool2o`00o`Wooooo0_l00?l6oooo
o`;o003o0oooool2ool000Gooooo0_l00?l3ooooo`;o003o0oooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooo`;oo`005?ooool2o`00oa3ooooo0_l00?l5ooooo`;o003o2Oooool2o`00o`So
oooo0_l00?l2ool000;ooooo1Ol00?l01?oooooo003oo`00oooo0002ooooo`;o003o0oooool9o`00
o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l00oooool8o`00o`03ooooool00?oo003o
00;ooooo6Ol00?l3ooooo`Oo003o00Coooooo`00ool00?oo003o0oooool2o`00oa7ooooo0_l00?l2
ooooo`;o003o1_ooool4o`00o`Gooooo0_oo000Aooooo`;o003o1_ooool2o`00o`cooooo0_l00?l>
ooooo`;oo`001Oooool2o`00o`?ooooo0_l00?l3ooooo`7o00000Oooool00003o`000?oooooooooo
00kooooo0_l00?l7ooooo`Co003o0oooool2o`00o`_ooooo0_l00?l:ooooo`;oo`000_ooool5o`00
o`?ooooo0_l00?l2ooooo`?o003o00?oo`00ooooooooool00oooool2o`00o`04ooooool00?oo003o
ool000Gooooo1?l00?l4ooooo`Co003o00?oooooo`00ool00?l00ol00?l3ooooo`;oo`001_l00?l0
0ooooooo003oo`00o`03o`00o`03ooooool00?oo003o01Ko003o1?ooool6o`00o`;ooooo0_l00?l3
ooooo`Co003o5Oooool2o`00o`Gooooo0_l00?l:ooooo`;o003o2Oooool2o`00o`?ooooo0ol00?l7
ooooo`;oo`000_ooool2ool000Kooooo0ol00?lNooooo`7o00000Oooool00003o`000?oooooooooo
00kooooo0_l00?l7ooooo`Co003o0oooool2o`00oaKooooo0_l00?l00ooo003oooooooooo`05o`00
o`?ooooo0_l00?l3ooooo`;o003o1_ooool2o`00o`?ooooo0_l00?l4ooooo`Ko003o00?oooooo`00
ool00?l00ol00?l2ooooo`Co003o0oooool2ool000;ooooo0_l00?l2oooooa_o003o0_ooool2o`00
o`Cooooo1ol00?l00ooooooo003oo`00o`02ooooo`03ool00?l00?oo003o00;o003o3_ooool4o`00
o`?ooooo1?l00?l?ooooo`;o003o2Oooool2o`00o`04ooooool00?oo003oooooo`Co003o1?ooool2
o`00o`03ool00?l00?oo003o00;oo`000_l00?l3ooooo`Co003o1?ooool2o`00oaSooooo0Ol00001
ooooo`0000?o0000ooooooooool01oooool2o`00o`gooooo0_l00?lNooooo`;o003o2Oooool2o`00
o`03ooooool00?oo003o00[ooooo0_l00?l00ooooooo003oo`00o`02o`00o`?ooooo0_l00?l3oooo
o`;o003o00?oooooo`00ool00?l03Oooool4o`00o`?ooooo7Ol00?l3ooooo`;o003o00?oooooo`00
ool00?l01Ol00?l5ooooo`;oo`001?ooool2o`00o`_ooooo1?l00?l3ooooo`Co003o1Oooool2o`00
o`cooooo0_l00?l5ooooo`;o003o00?oooooo`00ool00?l00oooool2o`00o`Cooooo0_l00?l01Ooo
oooo003oo`00ool00?oooooo00;o003o0oooool2o`00o`Kooooo0ol00?lGooooo`7o00000Oooool0
0003o`000?oooooooooo00Oooooo0_l00?l=ooooo`;o003o6Oooool2o`00o`?ooooo0_oo0003oooo
o`;o003o00Coooooo`00ool00?oooooo0_l00?l00ooooooo003oo`00o`03ooooo`;o003o2?ooool2
o`00o`;ooooo1ol00?l4ooooo`;o003o0oooool2o`00o`Cooooo0_l00?l2ooooo`Co003o0ooooolF
o`00o`05ooooool00?oo003oo`00ooooool01ol00?l5ooooo`;o003o0_ooool2o`00o`Cooooo1_l0
0?l<ooooo`;o003o3Oooool2o`00o`Sooooo0_l00?l2ooooo`;o003o2oooool4o`00o`Kooooo1?l0
0?l?ooooo`;o003o4?ooool2o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool2
o`00ob?ooooo0_l00?l01?oooooo003oo`00ool00?l5ooooo`Co003o00?oooooo`00ool00?l00_l0
0?l2ooooo`;oo`000oooool2o`00o`?ooooo0_l00?l2ooooo`;o003o0oooool8o`00o`03ooooool0
0?oo003o00;o003o00?oooooo`00ool00?l00_l00?l4ooooo`;o003o0oooool4o`00o`;ooooo4Ol0
0?l00ooooooo003oo`00o`02o`00o`03ooooool00?oo003o00;ooooo1_l00?l00ooooooo003oo`00
o`02o`00o`03ooooool00?oo003o00;ooooo0_l00?l2ool000;ooooo1?l00?l>ooooo`;o003o2?oo
ool2o`00o`gooooo0_l00?l?ooooo`Co003o00?oooooo`00ool00?l00oooool2o`00ob?ooooo0_l0
0?l5ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo0ol00?lSooooo`;o003o0_ooool2
o`00o`Gooooo0ol00?l4ooooo`;o003o0_ooool2ool000Sooooo0_l00?l2ooooo`;o003o2Oooool2
o`00o`03ooooool00?oo003o00?ooooo0ol00?l5ooooo`;oo`000_l00?l3ooooo`;o003o0_oooolD
o`00o`?ooooo1?l00?l2ooooo`Co003o00?oooooo`00ool00?l00_l00?l01?oooooo003oo`00oooo
ool2o`00o`03oooooooo003oo`0001kooooo0_l00?l=ooooo`;o003o1_ooool4o`00o`Kooooo0_l0
0?l2ooooo`Co003o;Oooool1o`00007ooooo00000ol0003oooooooooo`08ooooo`;o003o7Oooool2
o`00o`;ooooo1?l00?l00ooooooo003oo`00o`05ooooo`;o003o6oooool2o`00o`04ooooool00?oo
003oooooo`Co003o2?ooool3o`00o`Gooooo0ol00?l00ooooooo003oo`00o`03o`00o`04ooooool0
0?oo003oool000Go003o00?oooooo`00ool00?l02ol00?l00ooooooo003oo`00o`02o`00o`;ooooo
1?l00?l2ooooo`?o003o00Coooooo`00ool00?oooooo0_l00?l6ooooo`Co003o0_ooool2o`00o`co
oooo0_l00?lDooooo`;o003o0_ooool2o`00o`;ooooo1?l00?l00ooo003oooooooooo`02o`00o`Oo
oooo0_l00?lSooooo`;o003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Wooooo`;o003o
0_ooool4o`00o`03ooooool00?oo003o00?ooooo1Ol00?l5ooooo`;o003o1_ooool2o`00o`_ooooo
0_l00?l01?oooooo003oo`00ooooool4o`00o`Kooooo0_l00?l00ooooooo003oo`00o`04ooooo`Co
003o00?oooooo`00ool00?l00ol00?l2ooooo`03ool00?l00?oo003o01go003o0oooool5o`00o`03
ooooool00?oo003o00;ooooo0_l00?l2ooooo`Co003o0_ooool2o`00o`;ooooo0_l00?l00ooooooo
003oo`00o`02ooooo`;o003o00?oooooo`00ool00?l06?ooool2o`00o`Gooooo00Coo`00o`00ool0
0?oooooo0_l00?l/ooooo`;o003o2?ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`;o
o`00:Oooool2o`00o`Cooooo0_l00?l00ooooooo003oo`00o`02o`00o`?ooooo1?l00?l3ooooo`?o
003o1Oooool2o`00o`;ooooo0_l00?l3ooooo`;o003o00?oooooo`00ool00?l00_oo0002o`00o`Co
oooo0_l00?l2ooooo`;o003o0oooool9o`00o`;ooooo5ol00?l01?oooooo003oo`00ooooool4o`00
o`03ooooool00?oo003o00Oo003o00Goooooo`00ool00?oo003oooooo`02o`00o`;oo`002_ooool2
o`00o`03ooooool00?oo003o00;ooooo0_l00?l00oooooooo`00ool0000Kooooo`Co003o00?ooooo
o`00ool00?l0:?ooool2o`00o`Gooooo0ol00?l7ooooo`7o00000Oooool00003o`000?oooooooooo
00Cooooo00?oo`00o`00ool00?l03Oooool2ool001Sooooo2Ol00?l3ooooo`;o003o0oooool5o`00
o`;ooooo0ol00?l3ooooo`So003o0_ooool3o`00o`03ooooool00?oo003o00;oo`000_l00?l01?oo
oooo003oo`00ool00?l4ooooo`?o003o0oooool8o`00o`;ooooo6_l00?l2ooooo`;o003o0_ooool5
o`00o`Cooooo0_oo0002o`00o`?ooooo0_oo0007ooooo`Co003o0_ooool2o`00o`Gooooo0_l00?l>
ooooo`?o003o2_ooool4o`00o`gooooo0_l00?l9ooooo`;oo`004Oooool2o`00o`Kooooo0_l00?l2
ooooo`Co003o0Oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`;o003o3Oooool2ool0
00cooooo0_l00?l:ooooo`;o003o00?oo`00o`00ool00?l01_l00?l6ooooo`;o003o00?oooooo`00
ool00?l00oooool2o`00o`;ooooo1?l00?l00ooooooo003oo`00o`02ooooo`Co003o2Oooool7o`00
o`04ooooool00?oo003oo`00o`Cooooo1_l00?l2ooooo`Oo003o00?oooooo`00ool00?l00_l00?l0
0ooooooo003oo`00o`02o`00o`03ool00?l00?oo003o00Wo003o00?oooooo`00ool00?l01?l00?l2
ooooo`;o003o00Coooooool00?oo003ooooo0_l00?l9ooooo`Ko003o2Oooool2o`00o`Cooooo0_l0
0?l8ooooo`?o003o4oooool2o`00o`Kooooo0_l00?l9ooooo`;oo`0000?oooooo`00ool00?l06_oo
ool4o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool08_ooool3o`00o`Sooooo0_oo0000
1?ooooooo`00o`00ool00?l2ooooo`Co003o0_ooool2o`00o`;ooooo0_l00?l5ooooo`03ool00?l0
0?oo003o00;ooooo1?l00?l3ooooo`Co003o0_ooool7o`00o`Gooooo1?l00?l2ooooo`?o003o0ooo
ool3o`00o`04ooooool00?oo003oooooo`Oo003o0_oooolIo`00o`Gooooo0_l00?l01?oo003ooooo
ooooooooool2o`00o`;oo`000oooool2o`00o`;ooooo0_l00?l=ooooo`;o003o1?ooool2o`00oako
oooo0_l00?l2ooooo`?oo`000_l00?l=ooooo`;o003o0oooool3o`00oaWooooo0Ol00001ooooo`00
00?o0000ool00?oo00008oooool3o`00o`03ool00?l00?oo003o00Cooooo0_oo0006ooooo`;o003o
0_ooool4o`00o`;ooooo1_l00?l00oooooooo`00ool00005ooooo`;o003o00?oooooo`00ool00?l0
0_l00?l2ooooo`Wo003o1Oooool2ool000Gooooo0_l00?l2ooooo`Co003o00?oooooo`00ool00?l0
8ol00?l00ooooooo003oo`00o`02ooooo`;o003o00Coo`00oooooooooooooooo1?l00?l3ooooo`Go
003o0_ooool2o`00o`03oooooooo003oo`0000Oooooo0_l00?lJooooo`;o003o3?ooool3ool000;o
003o1Oooool2o`00o`_ooooo0ol00?lIooooo`7o00000Oooool00003o`000?oo003oo`0001Sooooo
0_oo0003ooooo`;o003o1Oooool2o`00o`03ool00?l00?oo003o00?ooooo00?oo`00o`00ool00?l0
0_ooool2o`00o`;ooooo0_l00?l2ooooo`co003o1_ooool2o`00o`?ooooo0ol00?l3ooooo`;o003o
1Oooool2o`00o`;ooooo0_l00?l00oooooooo`00ool00002o`00o`Oooooo2?l00?l2ooooo`oo003o
0oooool00ooo003o003oo`00o`0>o`00o`04ooooool00?oo003oo`00o`;ooooo1_l00?l00ooooooo
o`00ool00009o`00o`03oooooooo003oo`0001;ooooo0_l00?l5ooooo`;oo`000_l00?l2ooooo`;o
003o00Coooooo`00ool00?oo003o0_ooool2o`00oa3ooooo1?l00?l2ool002Gooooo0Ol00001oooo
o`0000Co0000oooooooo003oo`003?ooool2ool000Wooooo0_oo0003ooooo`;o003o3Oooool3o`00
o`;ooooo0_l00?l8ooooo`[o003o00?oooooo`00ool00?l00oooool2o`00o`03ooooool00?oo003o
00Go003o2?ooool8o`00o`04ooooool00?oo003oooooo`?o003o1?ooool2o`00o`03ooooool00?oo
003o00?o003o00?oo`00ooooool00?l04Ol00?l01?oooooo003oo`00ooooool;o`00o`;ooooo0_l0
0?l3ooooo`?o003o00Coooooo`00ool00?oooooo0_oo0004o`00o`03ooooool00?oo003o00kooooo
0_oo0002o`00o`Gooooo0_l00?l5ooooo`;oo`000_l00?l2ooooo`Go003o0oooool2o`00o`Kooooo
0_l00?l8ooooo`Co003o0_oo0002ooooo`;o003o00?oo`00ooooooooool01Oooool2ool001Oooooo
0Ol00001ooooo`0000Co0000oooooooo003oo`000oooool2o`00o`Oooooo0_oo000Hooooo`;o003o
0oooool2o`00o`Sooooo0_l00?l8ooooo`;o003o00?oooooo`00ool00?l00ol00?l5ooooo`[o003o
2?ooool6o`00o`04ooooool00?oo003oooooo`?o003o00?oooooo`00ool00?l01OoooolBo`00o`03
ooooool00?oo003o00?o003o00Coooooo`00ool00?oooooo0ol00?l00ooo003oooooo`00o`05o`00
o`;ooooo0_l00?l2ooooo`;o003o00?oo`00ooooooooool00_l00?l00oooooooo`00ool0000Eoooo
o`;oo`000_l00?l>ooooo`;o003o1?ooool2o`00o`;oo`002_ooool2o`00o`[ooooo0_l00?l4oooo
o`Co003o1_ooool2ool000;ooooo0_l00?l4ooooo`;o003o3Oooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooo`?o003o1oooool2ool000?ooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o
o`0000?oooooo`00ool00?l00_l00?l5ooooo`Co003o3Oooool2o`00o`Kooooo1?l00?l2ooooo`;o
003o1?ooool2ool00003ooooool00?oo003o00;ooooo0_oo0002ooooo`;o003o0oooool2o`00o`03
ool00?oooooooooo00Co003o0oooool00ooo003o003oo`00o`04ooooo`;o003o2Oooool7o`00o`03
ooooool00?oo003o00Go003o00Koooooo`00ool00?oo003oool00?ooool3o`00o`05ooooool00?oo
003oo`00ooooool01Ol00?l4ooooo`Go003o4?ooool2o`00o`kooooo0_oo0004ooooo`?o003o0ooo
0003ooooo`;o003o1_ooool2ool000Gooooo0_oo0004ooooo`;o003o2_ooool2o`00o`Gooooo0_l0
0?l00ooooooo003oo`00o`03ooooo`;o003o00Coooooool00?l00?oo003o1?ooool2o`00o`;ooooo
1?l00?l5ooooo`;o003o0Ol00001ooooo`0000?o0000ooooooooool00oooool2o`00o`Sooooo0_oo
0003ooooo`;o003o00?oooooo`00ool00?l00_ooool2ool00003ooooool00?oo003o00;o003o1Ooo
ool5o`00oa?ooooo00Goo`00o`00ool00?oo003oooooo`02o`00o`?ooooo0_l00?l00oooooooo`00
ool00002o`00o`?ooooo00Coo`00o`00ool00?oooooo0_l00?l3ooooo`;o003o00?oo`00o`00ool0
0?l01Ol00?l2ooooo`03ool00?l00?oo003o00Kooooo0_l00?l7ooooo`Oo003o00?oooooo`00ool0
0?l05_l00?l2ool000Cooooo1Ol00?l9ooooo`;o003o0_ooool2o`00o`04ool00?l00?oo003ooooo
o`;oo`000oooool2o`00o`?ooooo0_l00?l00oooooooo`00ool00002o`00o`;ooooo0ol00?l3ool0
00?ooooo0_l00?l00ooooooo003oo`00o`08ooooo`;o003o0_oo0004ooooo`Co003o1?ooool2o`00
o`;ooooo0_l00?l8ooooo`;o003o0oooool2o`00o`04oooooooo003o003oo`00o`Oooooo00?oo`00
o`00ool00?l00_l00?l5ooooo`;o003o0Ol00001ooooo`0000?o0000ooooooooool01_ooool2o`00
oaCooooo0ol00?l00ooo003oooooooooo`05ooooo`?o003o2Oooool2o`00o`03ooooool00?oo003o
00Gooooo0_oo0002o`00o`03ooooool00?oo003o00?ooooo1?l00?l00ooooooo003oo`00o`04oooo
o`Go003o00?oo`00ooooooooool00oooool7o`00o`?ooooo0ol00?l01Ooooooo003oo`00ool00?oo
oooo00Co003o0ooo0009o`00o`03ooooool00?oo003o01go003o00Goooooo`00ool00?oo003ooooo
o`02o`00o`03ool00?oooooooooo00?ooooo0ol00?l01?oooooo003oo`00oooo0002o`00o`03oooo
oooo003oo`0000;ooooo1?l00?l2ooooo`;o003o0oooool2o`00o`?ooooo0_oo0006ooooo`;o003o
00?oooooo`00ool00?l00_ooool2ool000Cooooo0_l00?l2ooooo`;o003o00?oo`00ooooool00?l0
0ol00?l4ooooo`;o003o0_ooool2o`00oaGooooo1?l00?l01Oooooooo`00o`00ool00?oooooo00;o
003o1_ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`03ool00?l00?oo003o017ooooo
0_l00?l2ooooo`;o003o00?oo`00ooooooooool01_ooool4o`00o`?ooooo0_l00?l01Oooooooo`00
o`00ool00?oooooo00Co003o1oooool2o`00o`Gooooo00?oo`00o`00ool00?l02?ooool01?oo003o
003oo`00oooo0002o`00o`03ooooool00?oo003o00Ko003o00Koooooo`00ool00?oo003ooooooooo
0002o`00o`03ooooool00?oo003o00Ko003o0_oo0003o`00o`03oooooooo003o003o00?o003o0_oo
oolOo`00o`;ooooo0_l00?l01?oooooo003oo`00oooo0005ooooo`03ool00?l00?oo003o00;ooooo
1?l00?l5ooooo`Co003o3_ooool2o`00o`04ool00?oooooo003oo`00o`Kooooo0ooo0006ooooo`Co
003o00Coo`00ooooool00?oo003o1_ooool3o`00o`;ooooo0_l00?l4ooooo`;oo`000_l00?l00ooo
003oooooooooo`03ooooo`;o003o00Coooooo`00ool00?oooooo1?l00?l2ooooo`Go003o1_ooool1
o`00007ooooo00000ol0003oooooooooo`05ooooo`;oo`004_ooool2o`00o`gooooo0_oo0002o`00
o`?ooooo0_l00?l00oooooooo`00ool00004ooooo`;o003o1_ooool00ooo003o003oo`00o`0:oooo
o`;o003o1?ooool2o`00o`;ooooo0_l00?l00ooooooo003oo`00o`03o`00o`Cooooo0ol00?l01?oo
ooooo`00o`00ool00?l2ooooo`Ko003o0oooool2o`00o`;ooooo0_oo0003o`00o`05ooooool00?oo
003oo`00ooooool01?l00?l00oooooooo`00o`00o`0>o`00o`05ool00?oooooo003oo`00ooooool0
0_l00?l2ooooo`;o003o1Oooool2o`00o`Oooooo0_l00?l;ooooo`;o003o2oooool3o`00o`04ool0
0?oooooo003oo`00o`Kooooo0_oo0007ooooo`;o003o3Oooool2o`00o`;ooooo0_l00?l4ooooo`;o
o`000_l00?l00ooo003oooooooooo`03ooooo`;o003o00Coooooo`00ool00?oooooo0_oo0002o`00
o`?ooooo1?l00?l6ooooo`7o00000Oooool00003o`000?oooooooooo01Wooooo0_l00?l6ooooo`Go
003o3Oooool2o`00o`Oooooo0ol00?l00oooooooo`00ool00005o`00o`Kooooo0_l00?l4ooooo`Co
003o00Coooooo`00ool00?oooooo0_oo0007ooooo`;oo`000_l00?l7ooooo`Go003o00?oooooo`00
ool00?l02_l00?l2oooooaGo003o00?oooooo`00ool00?l02?l00?l3ooooo`;oo`000_l00?l00ooo
ooooo`00ool00003ooooo`;oo`001Oooool2ool000;ooooo0_oo00000ooooooo003oo`00o`08oooo
o`03ool00?l00?oo003o00;o003o00?oo`00ooooooooool04Oooool2ool00003oooooooo003oo`00
00oooooo0_oo0002ooooo`;o003o00?oooooool00?oo00002_ooool2o`00o`;ooooo0_l00?l3oooo
o`;oo`0000?oooooo`00ool00?l00oooool2o`00o`7o00000Oooool000;oo`005?ooool3ool000?o
oooo0_l00?l00oooooooo`00ool00002ooooo`Ko003o3Oooool2o`00o`Oooooo0ol00?l3ooooo`Go
003o1?ooool2ool000Co003o0oooool6o`00o`Cooooo1?l00?l4ooooo`;o003o1Oooool4o`00o`04
ooooool00?oo003oooooobgo003o1?ooool2ool000?ooooo0_oo0002o`00o`03oooooooo003oo`00
00Gooooo0_oo0002ooooo`;oo`000_ooool2ool000Kooooo1Ol00?lEooooo`;o003o00?oooooo`00
ool00?l03oooool2ool000;ooooo0_l00?l00oooooooo`00ool0000:ooooo`;o003o1oooool2ool0
0003ooooool00?oo003o00?ooooo0_l00?l1o`00007ooooo00000ol00?ooo`00ooooo`0@ooooo`;o
003o00Coooooool00?l00?oo003o1_ooool01?oo003o003oo`00ooooool2o`00oaSooooo0_l00?l7
ooooo`;o003o1_ooool2ool000;ooooo0_l00?l2ooooo`03ool00?l00?oo003o00Co003o00Cooooo
ool00?oo003oo`001?l00?l4ooooo`;oo`0000?oooooo`00ool00?l00_ooool:o`00o`03ool00?l0
0?oo003o00Go003o00?oo`00o`00ool00?l05?l00?l2ooooo`[o003o0_ooool2o`00o`;ooooo0_oo
0003ooooo`?o003o1Oooool2ool000Oooooo0_oo0004o`00o`?ooooo0_l00?l00ooo003o003oo`00
o`0>ooooo`;oo`001Oooool2o`00o`03ooooool00?oo003o00;oo`003_ooool4o`00o`[ooooo0_l0
0?lCooooo`;o003o0Ol00001ooooo`0000?o003oooooooooool03?ooool2o`00o`;ooooo0ol00?l0
0ooooooo003oo`00o`03ooooo`;oo`000_ooool2o`00oaGooooo0_l00?l00ooo003oooooo`00o`03
o`00o`Cooooo0ooo0003o`00o`Gooooo0ol00?l5ooooo`03ool00?l00?oo003o00;ooooo0_l00?l0
0oooooooo`00o`00o`02o`00o`03ool00?l00?oo003o00Oooooo0_l00?l3oooooa3o003o0_oo000F
o`00o`;ooooo0_oo00000ooooooo003oo`00o`04o`00o`?ooooo0_l00?l2ooooo`;o003o1?ooool2
o`00o`Gooooo0_oo0002ooooo`;o003o0oooool2ool000Go003o1?ooool2ool000Wooooo0ol00?l3
ooooo`;o003o2_ooool2ool000;ooooo0_oo0004ooooo`;oo`001?ooool4o`00o`[ooooo0_l00?l@
ooooo`;o003o0oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`;o003o00?oooooo`00
ool00?l00oooool2o`00o`;ooooo0_l00?l2ooooo`;oo`003_ooool2o`00o`Wooooo0_l00?l01Ooo
003oooooo`00ool00?oooooo00;oo`000oooool4ool000;o003o0_ooool2ool00004ooooool00?oo
003oo`00o`Gooooo00Goo`00o`00ool00?oo003oool00007o`00o`03ooooool00?oo003o00Kooooo
0_l00?l4ooooo`;o003o0ooo0002ooooo`ko003o00?oo`00o`00ool00?l00ol00?l00ooooooo003o
o`00o`06o`00o`03ool00?l00?oo003o00?o003o0_oo00001Ooooooo003oo`00ool00?oooooo00?o
o`001?l00?l01?oooooo003oo`00ool00?l2ooooo`;oo`000ol00?l8ooooo`;o003o1oooool3o`00
o`?ooooo0_oo000:ooooo`?o003o0oooool2o`00o`Gooooo0_oo0007ooooo`;oo`001?ooool2o`00
o`Kooooo0_oo0007ooooo`;o003o4oooool2o`00o`?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool01oooool4o`00o`03ooooool00?oo003o00;oo`001Oooool3o`00o`?ooooo0_oo0006ooooo`;o
o`001?ooool2o`00oa3ooooo0_oo0005ooooo`;oo`000oooool2ool000;o003o00?oo`00o`00ool0
0?l00_oo0003ooooo`Co003o0_oo00001?oooooo003oo`00oooo0002ooooo`03ool00?l00?oo003o
00Cooooo2_l00?l00oooooooo`00ool00004o`00o`03ooooool00?oo003o00oo003o00?oooooo`00
ool00?l01_l00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00Go003o0_oo0004o`00
o`03ooooool00?oo003o00;o003o0ooo0003o`00o`Kooooo0_oo0005ooooo`;oo`002?ooool2ool0
00Cooooo0_l00?l5ooooo`;o003o0_ooool2ool00003oooooooo003oo`0000?ooooo0_oo000=oooo
o`;o003o1oooool2o`00o`Kooooo0_l00?l>ooooo`;oo`000oooool2o`00o`?ooooo0Ol00001oooo
o`0000?o0000ooooooooool00_l00?l5ooooo`;o003o1Oooool4ool00004oooooooo003oo`00oooo
o`;o003o00?oooooo`00ool00?l00_oo0006ooooo`;oo`001?ooool2o`00o`;ooooo0_oo0002o`00
o`Sooooo0_l00?l2ool000?ooooo0_l00?l2ool000?ooooo0_oo0005o`00o`;oo`000oooool7o`00
o`04oooooooo003oo`00ooooo`;oo`000_l00?l2ool00003ooooool00?oo003o00_o003o00Gooooo
o`00ool00?ooooooool00009o`00o`03ool00?l00?oo003o00Ko003o00?oooooo`00ool00?l05Ol0
0?l2ool000Kooooo0_l00?l2ool00004ooooool00?oo003oooooo`Co003o0_ooool2ool000?ooooo
0_l00?l2ool000kooooo0_l00?l3ooooo`;oo`000_l00?l2ooooo`Goo`001oooool2o`00o`Oooooo
0_l00?l9ooooo`;o003o3_ooool2o`00o`Kooooo0_oo0003ooooo`;o003o0oooool1o`00007ooooo
00000ol0003oooooooooo`02o`00o`Gooooo0_oo0007ooooo`;oo`0000?oooooo`00ool00?l00_oo
ool2ool000?o003o3Oooool2o`00o`;ooooo0_oo0004o`00o`;ooooo0_l00?l2ooooo`?o003o0_oo
ool4o`00o`;oo`0000?oooooool00?oo00001?ooool2o`00o`Gooooo00Coo`00o`00ool00?ooo`00
1?l00?l4ooooo`;oo`000ol00?l01Ooo003o003oo`00ool00?ooo`0000;o003o00?oooooo`00ool0
0?l01Ol00?l01?oooooo003oo`00ooooool9o`00o`03ooooool00?oo003o00Oo003o00?oo`00o`00
ool00?l05Ol00?l2ool000cooooo0_oo0004o`00o`Oooooo0_l00?l01?oooooo003oo`00ooooool2
ool000_ooooo0_l00?l00ooo003oooooool00002ool00004ooooool00?oo003oooooo`;oo`001_oo
ool2o`00o`03ooooool00?oo003o00Oooooo0_l00?l00ooooooo003oo`00o`06ooooo`;o003o1Ooo
ool2ool000Oooooo0_l00?l01Ooo003oooooool00?oo003ooooo00;o003o00?oo`00ooooooooool0
1_ooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`;oo`002_ooool2o`00o`;ooooo0_oo
0003o`00o`Gooooo0_l00?l>ooooo`;o003o0_ooool2o`00o`?ooooo0_l00?l2ooooo`;o003o00?o
o`00ooooooooool00_ooool2ool000Cooooo0_l00?l01_oooooo003oo`00ool00?ooooooool000;o
003o1?oo0002ooooo`;oo`001?ooool2o`00o`05ool00?l00?oo003oo`00ooooool00_oo000Ho`00
o`03ool00?l00?oo003o00Co003o00Goo`00o`00ool00?oo003oooooo`08o`00o`03ool00?oooooo
o`0000So003o0ooo0004ooooo`;oo`001Oooool3ool00003oooooooo003oo`0000Kooooo0_l00?l2
ooooo`;o003o00?oooooool00?oo00000oooool3ool000Cooooo00?oo`00o`00ool00?l01Ooo0000
0ooooooo003oo`00o`02o`00o`Oooooo0_l00?l00ooooooo003oo`00o`04ooooo`;oo`001?ooool2
o`00o`Kooooo0_oo00000ooooooo003oo`00o`02ooooo`;oo`002?ooool2ool00004oooooooo003o
o`00ooooo`;o003o00?oo`00ooooooooool01_ooool1o`00007ooooo00000ol0003oooooooooo`02
o`00o`Sooooo0_oo0003ooooo`;o003o00?oo`00ooooooooool01Oooool3o`00o`;ooooo0_oo0000
0ooooooo003oo`00o`05ooooo`;o003o1?ooool3ool000;o003o00?oo`00o`00ool00?l01Oooool2
o`00o`;ooooo0_oo0005ooooo`;o003o00?oo`00ooooooooool00_l00?l01?oooooo003oo`00ool0
0?l3ooooo`;oo`001Oooool3o`00o`03ooooool00?oo003o00Oooooo0_oo0002o`00o`;oo`000_l0
0?l00ooo003oooooo`00o`0Fo`00o`03ool00?l00?oo003o00Ko003o00Koo`00o`00ool00?oo003o
ool00?ooool2ool00004ooooool00?oo003oool000?o003o1Ooo0002ooooo`;oo`000_ooool2o`00
o`;ooooo1?oo0004ooooo`;oo`0000?oooooo`00ool00?l00_ooool2o`00o`Kooooo0ooo0004oooo
o`Koo`000oooool4o`00o`;ooooo0ooo0002o`00o`?ooooo0_l00?l4ooooo`;oo`000_ooool2ool0
00Cooooo0_oo0005ooooo`;o003o0oooool2o`00o`Cooooo0_oo0002ooooo`;o003o0_oo000<oooo
o`7o00000Oooool00003o`000?l00?oo003o00;o003o1?ooool2ool000;ooooo0_oo0003ooooo`;o
003o00?oo`00ooooooooool01Oooool2o`00o`03oooooooo003oo`0000;oo`002?ooool2o`00o`;o
oooo00?oo`00o`00ool00?l00_oo0002o`00o`03ool00?l00?oo003o00Gooooo0_l00?l3ooooo`;o
003o0_oo0002ooooo`;o003o00Coo`00oooooooooooooooo0_l00?l01?oo003o003oo`00ooooool4
ool000Gooooo0ol00?l00ooooooo003oo`00o`02ooooo`;oo`000_l00?l3ooooo`;o003o00Cooooo
o`00ool00?ooo`001?l00?l2oooooa?o003o00?oo`00o`00ool00?l00ol00?l2ooooo`;oo`001_l0
0?l01Ooo003o003oo`00ool00?ooo`0000?o003o00?oooooool00?oo00000_oo0004ooooo`Go003o
0oooool2ool000?ooooo0_l00?l00ooo003oooooooooo`02ool00003ooooool00?oo003o00;o003o
00Goo`00oooooooo003oo`00ooooo`04ool000Gooooo1?oo0007ooooo`Coo`000_l00?l5ooooo`;o
o`000_ooool2ool000;ooooo0_oo0002ooooo`Coo`002_ooool4o`00o`;ooooo0_oo0002ooooo`;o
003o0_oo000<ooooo`7o00000Oooool00004o`000?l00?oo003oool000Gooooo0_oo0008ooooo`;o
003o1oooool2o`00o`03oooooooo003oo`0000Kooooo0_oo0004ooooo`?oo`000_l00?l00ooooooo
o`00ool0000:ooooo`?o003o00Coooooo`00ool00?ooo`000_l00?l2ooooo`03ool00?l00?oo003o
00Co003o00?oooooo`00ool00?l00_l00?l00ooo003o003oo`00o`02ool000Cooooo0ol00?l2ool0
00;ooooo4Ol00?l00ooooooo003oo`00o`0:o`00o`03ool00?l00?oo003o00So003o00?oooooo`00
ool00?l01Ol00?l00ooooooo003oo`00o`05o`00o`;oo`000_l00?l2ooooo`?oo`001Oooool5o`00
o`;ooooo0_l00?l4ooooo`;o003o0oooool2o`00o`03ooooool00?oo003o00;o003o00?oo`00oooo
oooo00000ol00?l00oooooooo`00ool00005ooooo`;oo`000_l00?l00oooooooo`00ool00002oooo
o`;o003o0_oo00000oooooooo`00ool00006ooooo`;oo`000_ooool2o`00o`Kooooo0_oo000>oooo
o`;o003o2?ooool2ool000Kooooo1_l00?l1o`00007ooooo00000ol0003oooooooooo`0@ooooo`;o
003o1?ooool2o`00o`03ooooool00?oo003o00;oo`000_ooool2o`00o`?ooooo00?oo`00o`00ool0
0?l00oooool2ool00004oooooooo003oo`00ooooo`;oo`001?ooool2ool000Cooooo0ol00?l01?oo
ooooo`00ool00?ooool3o`00o`03ool00?l00?oo003o00?o003o1?ooool3o`00o`03ooooool00?oo
003o00Co003o0ooo0003o`00o`03oooooooo003oo`0000;o003o00?oo`00o`00ool00?l02?l00?l0
1Ooooooo003oo`00ool00?oooooo00Co003o00?oo`00o`00ool00?l04?l00?l00ooooooo003oo`00
o`08o`00o`03ooooool00?oo003o00;o003o0_oo0002o`00o`?ooooo0ooo00001?oooooo003oo`00
oooo0002ooooo`;o003o0oooool2o`00o`;oo`0000Coooooool00?oo003oo`000oooool2o`00o`04
ooooool00?oo003oo`00o`?ooooo00Goo`00o`00ool00?oo003oooooo`02o`00o`;ooooo0_l00?l3
ool000;o003o00?oooooool00?oo00000_ooool2o`00o`?oo`002oooool01?oo003o003oo`00oooo
000;ooooo`;oo`002Oooool2o`00o`Gooooo0_oo0006ooooo`;oo`001_l00?l1o`00007ooooo0000
0ol0003oooooooooo`04ooooo`;oo`003?ooool2o`00o`;ooooo0_l00?l3ooooo`;oo`000_ooool2
o`00o`?ooooo00Goo`00o`00ool00?ooo`00ooooo`02ool000Cooooo0_oo0004ooooo`;o003o00?o
o`00o`00ool00?l01_ooool2ool000;ooooo0_l00?l01?oo003o003oo`00ooooool2o`00o`Gooooo
0_oo0003ooooo`Co003o0ooo0003o`00o`03oooooooo003oo`0000?o003o00?oooooo`00ool00?l0
1?l00?l01?oooooo003oo`00oooo0005o`00o`;oo`0000?oooooo`00ool00?l01ol00?l00ooo003o
003oo`00o`0Ao`00o`03ool00?oooooo003o00Co003o00Coooooo`00ool00?oo003o0oooool3ool0
00;o003o00?oo`00ooooooooool00_l00?l4ooooo`?oo`000_l00?l00ooo003oooooooooo`02o`00
o`;ooooo00Coo`00o`00ool00?oo003o0oooool01Ooo003o003oo`00oooo003ooooo00;o003o0_oo
ool2o`00o`?oo`000_ooool2ool000Gooooo0ooo0002ooooo`?oo`000_l00?l4ooooo`04ool00?l0
0?oo003oool000?ooooo0_l00?l6ooooo`;o003o1_ooool2o`00o`04ooooool00?oo003oooooo`;o
003o0_ooool2ool000Kooooo0_oo00000oooooooo`00ool00003ooooo`7o00000Oooool00003o`00
0?oooooooooo00Cooooo0_oo0004ooooo`;o003o1_ooool2o`00o`;oo`0000?oooooool00?oo0000
0_ooool2ool00003oooooooo003oo`0000?ooooo1Ooo00000oooooooo`00ool00004ooooo`03ool0
0?l00?oo003o00;oo`0000Coooooo`00ool00?oooooo0_l00?l9ooooo`03ool00?l00?oo003o00Ko
o`0000?oooooo`00ool00?l00_l00?l2ool00003ooooool00?oo003o00;oo`000_l00?l2ool000?o
oooo0ooo0002ooooo`;o003o00?oo`00o`00ool00?l00_l00?l01?oo003oooooo`00ool00?l3ool0
0004ooooool00?oo003oo`00o`;oo`0000?oooooo`00ool00?l05?l00?l00ooooooo003oo`00o`04
o`00o`;oo`000oooool:o`00o`;oo`0000Coooooool00?oo003ooooo0_l00?l00ooo003ooooooooo
o`03ooooo`Co003o00?oo`00oooooooo00000_l00?l2ooooo`03ool00?l00?oo003o00;ooooo0_oo
0002ooooo`;oo`0000?oooooo`00ool00?l01?ooool2ool000?ooooo1?oo0003ooooo`?oo`000_oo
ool3ool000;o003o1Oooool2o`00o`Cooooo0_l00?l6ooooo`;o003o1_ooool4o`00o`04ool00?oo
oooo003oo`00o`;ooooo0_oo00000oooooooo`00ool00007ooooo`;o003o0_ooool1o`00007ooooo
00001?l0003oooooooooooooool2ool000Oooooo0_l00?l2ooooo`;oo`001?ooool00ooo003o003o
o`00o`02ool000;ooooo0_oo00000oooooooo`00ool00003ooooo`;oo`000_ooool2ool000?ooooo
0_l00?l2ooooo`;o003o0_oo00000oooooooo`00ool00002ooooo`?o003o00Coooooo`00ool00?oo
oooo0_oo00000oooooooo`00o`00o`02o`00o`03ooooool00?oo003o00;ooooo00?oo`00o`00ool0
0?l00_l00?l00oooooooo`00ool00004o`00o`;ooooo0_l00?l01?ooooooo`00ool00?oo0003o`00
o`05ool00?ooooooo`00ool00?ooool01Ooo0002o`00o`;oo`000_l00?l00ooo003o003oo`00o`02
ool000?o003o0_oo000?o`00o`03ool00?l00?oo003o00Wo003o0_oo0002ooooo`Co003o00?oo`00
o`00ool00?l00_l00?l00ooooooo003oo`00o`02ool00004ooooool00?oo003oool000;ooooo00?o
o`00o`00ool00?l02?l00?l3ooooo`?oo`000_ooool2ool000;ooooo0_oo0003o`00o`?oo`0000?o
ooooo`00ool00?l01Oooool2ool000[ooooo0_oo000@ooooo`;o003o0_ooool3ool000Oooooo0_l0
0?l00ooo003oooooool00002ool00003oooooooo003oo`0000?oo`001oooool2o`00o`;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooo000;ooooo`;oo`001Oooool2o`00o`03ool00?oooooo
o`0000;oo`000_ooool2ool000Cooooo0_oo0008o`00o`;ooooo0_oo0007ooooo`Ko003o00?ooooo
o`00ool00?l00oooool2o`00o`03ooooool00?oo003o00;ooooo1?oo00000oooooooo`00ool00003
ool000;o003o0_oo0004o`00o`;oo`000ol00?l01Ooo003oooooo`00ool00?oooooo00;oo`0000?o
ooooool00?oo00001?oo0005o`00o`;oo`002?l00?l00ooooooo003oo`00o`09o`00o`03ool00?l0
0?oo003o00Co003o00?oo`00o`00ool00?l01Ol00?l00ooooooo003oo`00o`03o`00o`;oo`0000?o
ooooo`00ool00?l01?l00?l6ooooo`03ool00?l00?oo003o00Cooooo1?l00?l00oooooooo`00ool0
0002o`00o`;oo`000_l00?l00ooo003oooooooooo`02ool000;o003o1Ooo0002o`00o`04ool00?oo
ooooo`00ool000?ooooo00Coo`00o`00ool00?ooo`000oooool2o`00o`Wooooo1_oo0003ooooo`04
ool00?l00?oo003oooooo`;o003o0_oo000:ooooo`;o003o0_oo0002ooooo`;o003o00?oo`00oooo
ooooool01Oooool2o`00o`04oooooooo003oo`00o`00007ooooo0002ool00003oooooooo003oo`00
00?oo`001?ooool2o`00o`Wooooo1?l00?l01?ooooooo`00ool00?oo0002ooooo`03ool00?l00?oo
003o00;ooooo0_l00?l00ooo003o003oo`00o`04o`00o`Cooooo0ooo0002o`00o`Gooooo1?l00?l2
ooooo`;o003o00?oo`00ooooooooool00_l00?l01?oooooo003oo`00ooooool5ool000;o003o0_oo
0002ooooo`So003o0_ooool7o`00o`;oo`000_l00?l00ooo003o003oo`00o`06o`00o`;oo`000_l0
0?l00ooo003o003oo`00o`0Ao`00o`03ool00?l00?oo003o00Go003o00?oooooo`00ool00?l01?l0
0?l3ool000?o003o00?oo`00o`00ool00?l00_l00?l2ooooo`Co003o0_oo00000oooooooo`00ool0
0002o`00o`05oooooooo003oo`00ool00?ooool00ol00?l00oooooooo`00ool00002o`00o`;oo`00
0_l00?l5ool000Cooooo1_oo00000oooooooo`00ool00003ooooo`03ool00?l00?oo003o00?oo`00
00?oooooo`00ool00?l01_ooool2ool00003oooooooo003oo`0000Coo`000oooool2ool000;ooooo
0_l00?l00ooo003oooooooooo`03ool000Kooooo0_l00?l4ooooo`;o003o2?ooool3o`00o`;oo`00
0Ol00001ooooo`000_oo0003ooooo`?oo`001?ooool2o`00o`Kooooo0_l00?l00ooooooo003oo`00
o`02o`00o`Oooooo0_l00?l2ooooo`;o003o0oooool2o`00o`06ool00?oooooo003oo`00oooo003o
oooo0ooo0002o`00o`Gooooo1?l00?l2ooooo`?o003o1Oooool2ool00003ooooool00?oo003o00?o
o`000_l00?l4ooooo`Oo003o1Oooool3o`00o`;ooooo0_oo0002o`00o`03ool00?l00?oo003o00?o
003o0_ooool5o`00o`03ooooool00?oo003o00ko003o00Coo`00o`00ool00?ooo`001ol00?l01?oo
oooo003oo`00ooooool4o`00o`;oo`000_ooool2ool000;o003o00Coo`00oooooooooooooooo1?l0
0?l2ool00003oooooooo003oo`0000;o003o00Coooooool00?oo003oo`000_ooool2o`00o`05oooo
oooo003oo`00ool00?ooool00ooo0002ooooo`?oo`001Oooool00ooo003o003oo`00o`0:ooooo`;o
003o00Coooooool00?oo003ooooo0_oo0002ooooo`;o003o0_ooool2ool000;ooooo0_oo000=oooo
o`Goo`0000?oooooool00?oo00005?ooool2o`00o`;oo`000Ol00001ooooo`0000?o003oool00?oo
ool04?ooool3o`00o`03ool00?oooooooooo017ooooo0_oo0002ooooo`04ool00?l00?oo003oo`00
o`Goo`000oooool5ool000Cooooo0ol00?l4ooooo`?oo`0000Coooooo`00ool00?ooo`000_ooool2
o`00o`03ool00?oooooooooo00Kooooo0_l00?l2ooooo`;oo`0000Goooooo`00ool00?ooo`00oooo
o`04o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool00?l02Ol00?l00ooo003o003oo`00
o`0;o`00o`03ool00?l00?oo003o00Ko003o0ooo00000oooooooo`00ool00006o`00o`04oooooooo
003oo`00ool000Cooooo0ooo00001?ooooooo`00ool00?ooool8ool000;ooooo0_oo0003ooooo`;o
003o00Coooooool00?oo003ooooo1Ooo0002o`00o`03oooooooo003oo`0000;o003o00Koooooo`00
ool00?oo003oool00?ooool2ool000Sooooo00Coo`00o`00ool00?oooooo0_l00?l00oooooooo`00
ool00003ooooo`;oo`002Oooool2ool000;ooooo0_oo0004ooooo`;oo`005_ooool2ool0007o0000
0Oooool00003o`00oooo003ooooo013ooooo0ol00?l00ooo003oooooooooo`03ooooo`;oo`003?oo
ool2ool000;ooooo1?l00?l3ool000;o003o2?oo0003ooooo`;o003o0_oo0006o`00o`Goo`001?l0
0?l00ooo003o003oo`00o`03o`00o`03ool00?ooooooo`0000;o003o0_ooool01?oo003o003oo`00
oooo0002o`00o`03ool00?l00?oo003o01So003o00?oo`00o`00ool00?l04_l00?l00ooo003o003o
o`00o`02o`00o`03ool00?l00?oo003o00?o003o00Coooooool00?l00?oo003o1?ooool3ool00003
oooooooo003oo`0000;oo`000_l00?l6ool00003oooooooo003oo`0000?ooooo0_l00?l3ooooo`Ko
o`000_l00?l00oooooooo`00ool00003ooooo`?o003o00Coo`00oooooooo003oo`000_ooool7ool0
00;o003o00Coo`00o`00ool00?oooooo0_oo0002ooooo`?o003o00?oo`00o`00ool00?l01_ooool2
o`00o`;ooooo0_oo000Hooooo`;oo`0000Goooooool00?oo003oooooo`000001ooooo`0000?o0000
ool00?oo00001?ooool2ool000Sooooo0_oo00001?oooooo003oo`00oooo0002o`00o`03ooooool0
0?oo003o00;oo`000_ooool2o`00o`;oo`0000?oooooool00?oo00001oooool2o`00o`04oooooooo
003oo`00ool000?o003o1?oo00000oooooooo`00ool00004ooooo`[o003o0ooo0002ooooo`;o003o
0ooo0005o`00o`03ool00?ooooooo`0000;o003o00?oooooool00?oo00000_l00?l00ooo003o003o
o`00o`02ool000;o003o00Koo`00o`00ool00?oo003oool00?ooool7o`00o`03ool00?l00?oo003o
00Oo003o00?oo`00o`00ool00?l04_l00?l00ooooooo003oo`00o`02o`00o`;oo`000ol00?l3ool0
00;o003o0_oo0003ooooo`;oo`0000?oooooool00?oo00000_oo0002o`00o`;oo`0000Goooooo`00
ool00?ooo`00ooooo`02ool000;ooooo0ooo0002ooooo`Ooo`000oooool2ool000Co003o1?oo0000
0ooooooo003oo`00o`0>ool000;o003o0_ooool3o`00o`03ool00?l00?oo003o00Gooooo00?oo`00
o`00ool00?l00_ooool2ool000Sooooo0_oo000>ooooo`;oo`0000Goooooool00?oo003oooooo`00
0001ooooo`0000?o0000ool00?oo00000_ooool2o`00o`?oo`001?ooool2o`00o`04oooooooo003o
o`00ooooo`;o003o00Coo`00o`00ool00?oooooo0_l00?l01?oo003oooooooooooooool2o`00o`Ko
o`002?ooool4ool000;o003o0_oo00000oooooooo`00ool00002ool000Cooooo0ooo0005o`00o`Oo
o`001?ooool2ool000Co003o0_ooool2ool000Ko003o0ooo0004ooooo`;oo`000ol00?l2ool00003
oooooooo003oo`0000Co003o00?oo`00o`00ool00?l07?l00?l00ooo003oooooooooo`02o`00o`03
ool00?l00?oo003o00;o003o1ooo00001_ooooooo`00o`00ool00?ooo`00ooooo`Woo`000_l00?l0
0ooo003oooooool00003ool000;o003o0oooool7ool00003oooooooo003oo`0000;ooooo1?l00?l5
ool000;o003o0ooo0003ooooo`?oo`000oooool2ool000;o003o1Oooool3ool000Cooooo0ooo0007
ooooo`Coo`000_ooool2ool000;o003o00?oooooool00?oo00002?ooool2o`00o`Cooooo0Ooo0001
o`00007ooooo0003ool000;ooooo1?l00?l00ooo003oooooooooo`02ooooo`;o003o1Oooool2o`00
o`03oooooooo003oo`0000?oo`000_ooool3o`00o`Koo`002?ooool3ool000;o003o00?oo`00oooo
ooooool00_oo00001?ooooooo`00ool00?oo0002o`00o`?oo`000_ooool2ool000;o003o0_oo0000
0oooooooo`00ool00004ool00004oooooooo003oo`00ool000Co003o0_ooool4ool000Co003o00?o
ooooool00?oo00002?l00?l01Ooo003o003oo`00ooooooooo`0000;o003o1?oo000=o`00o`;oo`00
4?l00?l01Ooo003oooooo`00ool00?ooo`0000Co003o0_oo0002o`00o`05ool00?l00?oo003ooooo
oooo00000_l00?l01?oo003o003oo`00ooooool2ool000;ooooo1ooo00001?ooooooo`00ool00?oo
0002o`00o`?ooooo1_oo0002ooooo`Coo`002?ooool00ooo003o003oo`00o`02ooooo`;oo`000_oo
ool3ool000?o003o2_ooool2ool000Cooooo0_oo0002o`00o`Kooooo1?oo0004ooooo`;o003o00?o
ooooool00?oo00001?oo0004ooooo`;o003o1?ooool1ool0007o00000Oooool00003o`00oooo003o
oooo00;ooooo1?l00?l<ooooo`;o003o00?oooooool00?oo00000_oo00000oooooooo`00ool00003
o`00o`;oo`0000?oooooo`00ool00?l00_oo0003ooooo`?oo`001?ooool2o`00o`Goo`000_ooool2
ool000So003o0_ooool2ool000;ooooo0_oo00000oooooooo`00ool00003ool000Co003o0oooool8
ool000Cooooo1_l00?l00ooo003o003oo`00o`02o`00o`;oo`000_l00?l00oooooooo`00o`00o`0R
o`00o`?oo`001?l00?l2ool000;o003o00Coo`00o`00ool00?oo003o1?oo0002o`00o`;oo`001Ooo
ool3ool000;o003o00?oooooool00?oo00001?oo0002o`00o`Koo`001?ooool7ool000Cooooo0_oo
0002ooooo`;oo`000oooool5o`00o`;ooooo0_l00?l3ool00003oooooooo003oo`0000Sooooo0_l0
0?l4ool000Sooooo0_oo0003ooooo`Koo`000oooool2ool000Kooooo0Ol00001ooooo`0000?o003o
ooooooooool00_ooool2o`00o`05oooooooo003oo`00oooooooo00000_l00?l6ooooo`Coo`000_oo
ool5ool00004ooooool00?oo003oooooo`;oo`000_l00?l2ool000?ooooo0ooo0003ooooo`Co003o
1?oo00000ooooooo003oo`00o`03ool000Ko003o0_ooool2ool000Co003o00?oooooool00?oo0000
0_oo00000ooooooo003oo`00o`02ooooo`03ool00?l00?oo003o00Coo`000_l00?l2ool00003oooo
oooo003oo`0000Ko003o0_oo0006o`00o`Coo`001_l00?l00ooo003o003oo`00o`02ool001[o003o
00?oo`00o`00ool00?l00_l00?l5ool00003ooooool00?oo003o00Coo`000_l00?l00ooo003o003o
o`00o`02ool000;o003o00?oooooool00?oo00000_l00?l4ool00003oooooooo003oo`0000;o003o
1Ooo00000ooooooo003oo`00o`03ooooo`03ool00?l00?oo003o00Woo`0000?oooooool00?oo0000
0ooo00001?oooooo003oo`00ooooool2o`00o`;oo`000_l00?l5ool000;o003o0_oo0006ooooo`03
ool00?l00?oo003o00Coo`001_ooool4ool00003oooooooo003oo`0000;ooooo0ooo0002ooooo`;o
o`000_l00?l4ool0007o00000Oooool00003o`000?oooooooooo00Gooooo0_oo00000oooooooo`00
o`00o`02o`00o`Gooooo0ooo0002o`00o`03oooooooo003oo`0000;oo`0000Goooooo`00ool00?oo
003oooooo`03ool000;o003o1_ooool2ool000;ooooo1?l00?l2ooooo`;o003o00?oo`00o`00ool0
0?l00ooo0002o`00o`?oo`000_ooool00ooo003o003oo`00o`04o`00o`Coo`001?l00?l00ooooooo
o`00ool00002o`00o`Coo`000_l00?l00ooo003oooooool00008o`00o`;oo`002Ol00?l2ool000Go
003o0ooo000Io`00o`04ool00?l00?oo003oool000?o003o00?oo`00o`00ool00?l01_l00?l4ool0
00;o003o00Goo`00o`00ool00?oo003oool00002o`00o`03ooooool00?oo003o00;o003o0ooo0000
0oooooooo`00ool00004ool000;ooooo0_oo00000ooooooo003oo`00o`04ooooo`Co003o3ooo0004
o`00o`?oo`0000?oooooool00?oo00000ooo0002o`00o`;oo`000oooool2o`00o`;ooooo0_l00?l0
1Ooo003oooooool00?oo003ooooo00;oo`000_ooool5ool000Kooooo0ooo0003ooooo`;o003o1?oo
0001o`00007ooooo00000ol0003oooooooooo`02ool000?ooooo0_oo0003ooooo`;o003o1Oooool3
ool000;o003o0_ooool2ool00004oooooooo003o003oo`00o`;oo`000oooool2o`00o`03oooooooo
003o003o00;o003o00?oooooool00?oo00000oooool2ool000?ooooo0_l00?l2ool00004oooooooo
003oo`00ooooo`Coo`000oooool4o`00o`03ool00?l00?oo003o00Coo`000_l00?l2ool00003oooo
oooo003oo`0000Soo`0000?oooooool00?l00?l00_l00?l00ooo003o003oo`00o`02o`00o`?oo`00
0ol00?l00ooo003o003oo`00o`07o`00o`03ool00?l00?oo003o00;oo`002ol00?l00ooooooo003o
o`00o`06o`00o`03ooooool00?oo003o00?o003o00?oooooool00?l00?l01?l00?l00ooooooo003o
o`00o`06o`00o`Soo`000_l00?l01?ooooooo`00ool00?oo0003o`00o`?oo`000_ooool7ool00004
oooooooo003oo`00ool000;o003o00Goooooo`00ool00?ooooooool00003o`00o`03ool00?oooooo
oooo00;ooooo0_oo0002o`00o`Goo`0000Goooooo`00ool00?ooo`00ooooo`03ool00003oooooooo
003oo`0000;oo`000_ooool2ool000Cooooo0_l00?l8ooooo`04ool00?l00?oo003oooooo`?oo`00
00?oooooool00?oo00001oooool2ool000Gooooo0_oo00000oooooooo`00o`000001ooooo`0000Co
0000o`00ool00?ooo`000_l00?l2ool00003oooooooo003oo`0000Koo`000_ooool2ool000Kooooo
0_oo00001?ooooooo`00ool00?ooool3ool000?ooooo0ooo0005o`00o`;oo`000_ooool2o`00o`?o
oooo0_oo0002ooooo`Ooo`0000Coooooool00?oo003oo`000ol00?l2ool000;o003o0_oo0003o`00
o`?oo`000_l00?l6ool000?o003o0_oo0002o`00o`Goo`000oooool00ooo003o003oo`00o`02ool0
00?o003o00Goooooool00?l00?oo003oool0000>o`00o`04ool00?l00?oo003oool000_o003o00?o
o`00o`00ool00?l01Ol00?l2ooooo`Ko003o0_oo0004o`00oaKoo`000_l00?l2ool00004ooooool0
0?oo003oool000;o003o00?oo`00o`00ool00?l01_oo0004ooooo`;oo`000_l00?l3ooooo`?oo`00
0_l00?l4ool000Cooooo0_oo0002ooooo`?oo`001Oooool4ool00005oooooooo003oo`00oooooooo
00000_l00?l00oooooooo`00ool0000;ooooo`;oo`0000?oooooool00?oo00001_ooool1o`00007o
oooo00001?l0003o003oo`00oooo0002o`00o`;oo`0000?oooooool00?oo00000ooo00001?oooooo
o`00ool00?oo0002o`00o`?oo`001?ooool2ool000;ooooo00?oo`00o`00ool00?l01?l00?l01?oo
ooooo`00ool00?oo0002o`00o`03ool00?l00?oo003o00?oo`001_l00?l3ooooo`03ool00?l00?oo
003o00?o003o00Coo`00o`00ool00?ooo`000ol00?l6ool000Go003o0ooo0002o`00o`Goo`001?l0
0?l7ool000?o003o0ooo0002o`00o`03ool00?l00?oo003o00Go003o0_oo0003o`00o`03ool00?l0
0?oo003o01ko003o00?oo`00o`00ool00?l00_l00?l01?oooooo003oo`00ooooool2ool000Go003o
1_oo0002o`00o`Goo`000_l00?l00ooo003o003oo`00o`03ool000;o003o0ooo0002o`00o`03ool0
0?l00?oo003o00Coo`000_l00?l4ooooo`;oo`0000?oooooool00?oo00000oooool00ooo003o003o
o`00o`04o`00o`03ooooool00?oo003o00;oo`000_l00?l01?ooooooo`00o`00ool00?l2ooooo`?o
o`0000?oooooo`00ool00?l01Ooo0002o`00o`05ool00?oooooo003oo`00ooooool00ooo00001?oo
ooooo`00ool00?ooool2ool000Gooooo00?oo`00o`00ool00?l00_oo0006ooooo`7o00000Oooool0
0003o`000?oooooooooo00Wooooo0_oo00001?ooooooo`00ool00?oo0002o`00o`03ool00?l00?oo
003o00;oo`000_l00?l2ooooo`;o003o00?oo`00o`00ool00?l01?l00?l2ooooo`03ool00?l00?oo
003o00;oo`000_l00?l3ool000Ko003o00Coo`00ooooooooooooo`001Ol00?l01?oo003o003oo`00
oooo0003o`00o`Coo`0000Goooooool00?l00?oo003oool00005o`00o`03ooooool00?oo003o00?o
o`0000?oooooo`00ool00?l00ol00?l2ool000;o003o00?oo`00ooooool00?l00ol00?l2ool000_o
003o00?oo`00o`00ool00?l00_oo000Lo`00o`;oo`000_l00?l00ooo003o003oo`00o`02o`00o`Oo
o`001?l00?l6ool000;o003o1Ooo0002o`00o`03ool00?l00?oo003o00Coo`000_l00?l00ooooooo
o`00ool00007ool00003ooooool00?oo003o00?ooooo00?oo`00o`00ool00?l00_ooool2ool000;o
oooo00?oo`00o`00ool00?l00_l00?l2ool00003ooooool00?oo003o00;oo`001_l00?l6ool000;o
003o1Ooo0002o`00o`;oo`001?l00?l2ool000;o003o00Goo`00oooooooo003oo`00ooooo`02ool0
0003oooooooo003oo`0000;o003o2?ooool1o`00007ooooo00001?l0003oo`00ool00?ooool2ool0
0003ooooool00?oo003o00?ooooo0_oo0002o`00o`Goo`000_l00?l2ool000;o003o0_ooool2o`00
o`;ooooo1_oo00001?oooooo003oo`00ool00?l2ooooo`;o003o1Ooo00000ooooooo003oo`00o`02
o`00o`Cooooo0_l00?l01Oooooooo`00o`00ool00?ooo`0000;ooooo0_l00?l3ool00003ooooool0
0?oo003o00So003o00Coooooo`00ool00?ooo`000_l00?l2ooooo`Co003o00?oo`00o`00ool00?l0
0ol00?l01?oo003o003oo`00ool00?l4ool000Ko003o00?oo`00o`00ool00?l00_oo000So`00o`;o
o`000ol00?l00ooo003o003oo`00o`03ool000;o003o00?oooooo`00ool00?l01?oo0002o`00o`oo
o`000ol00?l00ooo003oooooool0000>ool000Co003o0_oo00001?ooooooo`00ool00?oo0002o`00
o`[oo`000_l00?l5ool000;o003o00?oo`00oooooooo00002Ooo0002ooooo`;o003o0_ooool2o`00
o`03ool00?oooooooooo00;ooooo0_oo00000oooooooo`00ool00002ool00004oooooooo003oo`00
ooooo`;oo`000_l00?l1o`00007ooooo00001?l0003oo`00o`00ool00?l2ool00003ooooool00?oo
003o00Gooooo0_l00?l3ooooo`;oo`000_l00?l2ool00003oooooooo003oo`0000;o003o0oooool6
ool00004ooooool00?oo003oo`00o`;oo`000_l00?l01?ooooooo`00ool00?ooool6o`00o`;ooooo
0_oo0002o`00o`05oooooooo003o003oo`00oooo00000_ooool01?oo003o003oo`00oooo0008o`00
o`05ooooool00?oo003oo`00ooooool01Ol00?l01?ooooooo`00o`00ool00?l3ool000Go003o00?o
o`00o`00ool00?l00_oo0003o`00o`03ool00?l00?oo003o00Ko003o00?oo`00o`00ool00?l08Ol0
0?l00ooooooo003oo`00o`03o`00o`03ool00?l00?oo003o00?oo`001Ol00?l4ool000Co003o2?oo
0002ooooo`03ool00?l00?oo003o00;o003o0_oo00000oooooooo`00ool00004ool000;o003o2Ooo
0002o`00o`;oo`0000Coooooool00?oo003oo`000_ooool6ool000;o003o0ooo0002o`00o`Coo`00
0_l00?l2ooooo`Coo`0000?oooooo`00ool00?l00oooool2ool000;ooooo0_oo00000oooooooo`00
ool00004ooooo`Coo`0000Coooooool00?oo003ooooo0_oo00000oooooooo`00ool00002o`00o`7o
00000Oooool00004o`000?oooooo003oo`00o`;oo`0000?oooooool00?oo00003Oooool2o`00o`Co
o`000ol00?l00ooo003oooooool00002ool000Kooooo0_l00?l01?oo003oooooooooooooool2o`00
o`03ooooool00?oo003o00;o003o00?oooooool00?oo00000ooo0003ooooo`;o003o00Goo`00o`00
ool00?ooooooool00002o`00o`03ooooool00?oo003o00;oo`000ol00?l01?oooooo003oo`00oooo
0002o`00o`03ool00?l00?oo003o00;o003o2Ooo0002o`00o`;ooooo0_l00?l2ool000Ko003o00?o
o`00o`00ool00?l0;?l00?l00ooo003o003oo`00o`02o`00o`?oo`000_l00?l3ool000;o003o0ooo
0002o`00o`;oo`000_l00?l3ool000;ooooo0_oo0004o`00o`Woo`000_l00?l2ooooo`;oo`000_oo
ool7ool000;o003o0ooo0002o`00o`Goo`000_l00?l3ool000;o003o0ooo0002o`00o`;ooooo0_oo
0002o`00o`;oo`001Ol00?l9ool000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00001?oo
ool3ool0007ooooo0Ol00001ooooo`0000?o0000ooooooooool00_oo0002ooooo`;oo`000_ooool2
o`00o`Cooooo0_l00?l3ooooo`;o003o0_oo0002o`00o`04ool00?l00?oo003oool000Go003o0ooo
0002ooooo`;o003o1?oo0002o`00o`04ool00?l00?oo003oo`00o`Goo`000_l00?l00oooooooo`00
ool00002o`00o`03ool00?l00?oo003o00;o003o00?oo`00oooooooo00000ol00?l00ooo003o003o
o`00o`07o`00o`?oo`001Ol00?l4ool00006oooooooo003o003oo`00oooo003ooooo2Ol00?l2ool0
02[o003o0_oo0007o`00o`?oo`000_l00?l2ool000?o003o0_oo0002o`00o`?oo`000_l00?l9ool0
00Co003o0_oo0002o`00o`;oo`000_l00?l:ool000;o003o0_oo0002o`00o`?oo`000_l00?l3ool0
00Co003o2?oo0002o`00o`Coo`000_l00?l2ool000;ooooo0ol00?l2ooooo`Ooo`000_ooool6ool0
00Oooooo0ooo0001ooooo`7o00000Oooool00003o`000?ooooooo`0000?oo`001Oooool2o`00o`;o
oooo0_oo0002o`00o`;oo`0000Goooooool00?l00?oo003oooooo`02o`00o`04ool00?ooooooo`00
ool000Oo003o00Coo`00oooooooooooooooo1Ooo0002o`00o`04ool00?l00?oo003oooooo`Goo`00
0_l00?l00oooooooo`00ool00003o`00o`04ool00?oooooo003oo`00o`?oo`000ol00?l00ooo003o
003oo`00o`09o`00o`03ool00?l00?oo003o00Go003o0_ooool2ool000;o003o0_oo0008o`00o`Co
o`00:ol00?l00ooo003o003oo`00o`03o`00o`?oo`0000?oooooool00?oo00000_oo0002o`00o`?o
o`000_l00?l4ool000;o003o2?oo0004o`00o`;oo`000_l00?l2ooooo`;o003o00?oo`00o`00ool0
0?l01_oo0003o`00o`Goo`000_ooool5ool000?o003o3Ooo00001Oooooooo`00ool00?oo003ooooo
00;oo`0000?oooooool00?oo00000_oo0002o`00o`Goo`000_l00?l2ooooo`;oo`000_l00?l00ooo
003o003oo`00o`03ooooo`;o003o1?ooool1o`00007ooooo00001?l0003oooooool00?oo0004o`00
o`?ooooo0ooo00001?ooooooo`00ool00?oo0002o`00o`03ool00?ooooooo`0000?o003o00?ooooo
ool00?oo00000ooo0002ooooo`;o003o00?oooooo`00ool00?l00_l00?l6ooooo`04ool00?l00?oo
003oooooo`;o003o00?oooooool00?oo00000ooo0002o`00o`03ool00?l00?oo003o00?o003o00?o
o`00o`00ool00?l01?oo0003o`00o`03ool00?l00?oo003o00?o003o0ooo000<o`00o`?oo`001_l0
0?l2ool000?o003o0ooo0002o`00o`04ool00?l00?oo003oool002Oo003o1?oo000:o`00o`Coo`00
0ol00?l4ool000;o003o1_oo00001?ooooooo`00o`00ool00?l4ool000;o003o00?oo`00o`00ool0
0?l00_oo0002o`00o`Koo`000ol00?l00ooo003oooooool00004o`00oaCoo`000_l00?l3ool00003
oooooooo003oo`0000;ooooo0_l00?l01Ooo003o003oo`00oooo003ooooo00?oo`000_l00?l4oooo
o`Go003o00?oooooool00?oo00000_l00?l4ooooo`7o00000Oooool00004o`000?oooooooooooooo
o`Co003o0oooool3ool00004oooooooo003oo`00ool000;o003o0_oo00001?ooooooo`00o`00ool0
0?l5ool000;o003o00Coooooo`00ool00?oooooo1?l00?l00oooooooo`00ool00003ooooo`04ool0
0?l00?oo003oool000;o003o0oooool6ool000;o003o1?oo0002o`00o`03ooooool00?oo003o00;o
o`000_l00?l6ool000Oo003o00?oo`00o`00ool00?l00_l00?l00ooo003o003oo`00o`04ool000Go
003o0_oo0004o`00o`;oo`000_l00?l2ool002So003o1ooo0008o`00o`;oo`001Ol00?lGool000Co
003o0_oo0002o`00o`06ool00?ooooooo`00ool00?ooooooo`000_l00?l00oooooooo`00o`00o`03
o`00o`04ool00?l00?oo003oool000;o003o00?oo`00o`00ool00?l01?oo00001Oooooooo`00ool0
0?oo003ooooo00;oo`000_l00?l2ool000;ooooo0ooo00000ooooooo003oo`00o`03ool00003oooo
oooo003oo`0000?oo`0000Coooooool00?oo003ooooo0ooo0002o`00o`;ooooo1?oo00001Ooooooo
o`00ool00?oooooo0000007ooooo00000ol0003oo`00ool00004o`00o`Kooooo0_l00?l3ooooo`Co
o`000_l00?l01Ooo003oooooool00?oo003ooooo00Co003o00Coooooool00?oo003ooooo0ol00?l;
ool000?o003o2_oo00000ooooooo003oo`00o`04ool000Co003o00Coo`00o`00ool00?ooo`000_l0
0?l2ool000?o003o1_oo0002o`00o`03ooooool00?oo003o00?oo`000ol00?l01?oo003o003oo`00
oooo0002o`00o`05ool00?l00?oo003oo`00oooo0000:Ol00?l01Ooo003o003oo`00ool00?ooo`00
00So003o0_oo0004o`00o`03ool00?oooooo003o00;o003o2_oo0004ooooo`goo`000_l00?l2ool0
00;o003o0ooo0002ooooo`03ool00?l00?oo003o00;ooooo1Ooo0002o`00o`04ool00?l00?oo003o
ool000;o003o0_oo0004ooooo`;oo`000_l00?l2ool000;o003o00?oo`00ooooool00?l00ol00?l0
1Oooooooo`00ool00?oo003ooooo00Ooo`0000?oooooool00?oo00001_oo0002ooooo`Coo`0000Go
ooooool00?oo003oo`00o`000001ooooo`0000?o0000ool00?oo00001_l00?l01?oo003ooooooooo
oooo0003o`00o`03oooooooo003oo`0000;oo`0000?oooooo`00ool00?l00oooool2ool000Go003o
1?oo0003o`00o`03ool00?l00?oo003o00Soo`000_l00?l5ool000;o003o1?oo0002o`00o`Goo`00
0ol00?l00ooo003o003oo`00o`03o`00o`;oo`000ol00?l6ool000Go003o0ooo000<o`00o`03ool0
0?l00?oo003o03Go003o00Coo`00o`00ool00?ooo`002?l00?l00ooo003o003oo`00o`0;ool000;o
003o1Ooo00001?ooooooo`00o`00ool00?l5ool000;o003o0ooo0002o`00o`;oo`0000Coooooool0
0?oo003oo`000_l00?l6ool000;o003o1?oo0003ooooo`?oo`000_l00?l2ool000;o003o00?oo`00
ooooool00?l01?l00?l2ool000;ooooo0ooo00000oooooooo`00ool00004ooooo`?oo`0000?ooooo
ool00?oo00001?ooool5ool0007o003o0Ol00001ooooo`0000Co0000o`00ool00?ooo`000_l00?l0
0ooo003o003oo`00o`02ool00003oooooooo003oo`0000;o003o1?oo0005o`00o`03ooooool00?oo
003o00;o003o00Coo`00o`00ool00?oo003o1?oo0003o`00o`03ooooool00?oo003o00;ooooo0_l0
0?l2ool000Co003o0ooo00001?ooooooo`00o`00ool00?l8ool000Ko003o0ooo0002o`00o`Woo`00
2?l00?l00ooo003o003oo`00o`14o`00o`04ool00?l00?oo003oool000Co003o0_oo0002o`00o`03
ool00?l00?oo003o00Koo`000_l00?l3ool000;o003o00?oo`00oooooooo00000_oo00001_oooooo
o`00o`00ool00?ooo`00ooooo`?oo`000_l00?l00oooooooo`00ool00002o`00o`Koo`000_l00?l6
ool000;o003o1Ooo0002ooooo`Koo`000_l00?l4ool000Go003o1?oo0003o`00o`03oooooooo003o
o`0000Oooooo0ooo0003ooooo`Goo`000Ol00?l1o`00007ooooo00001Ol0003o003oo`00oooo003o
oooo00;oo`0000?oooooo`00ool00?l01_oo0002o`00o`03oooooooo003o003o00Co003o00?ooooo
o`00ool00?l00_l00?l00ooo003oooooooooo`07ool000;o003o1?oo0003o`00o`03ooooool00?oo
003o00Goo`0000Coooooool00?oo003oo`001Ol00?l3ool000Go003o3_oo00000ooooooo003oo`00
o`06o`00o`03ool00?l00?oo003o00;o003o00?oo`00o`00ool00?l03Ol00?l2ool002_o003o00?o
o`00o`00ool00?l00_l00?l4ool000Go003o00Coo`00o`00ool00?ooo`000_l00?l6ool000;o003o
1_oo0002o`00o`;oo`0000Coooooool00?l00?oo003o0_oo00000oooooooo`00ool00002ool000?o
003o0ooo0002o`00o`Koo`0000?oooooool00?oo00000_oo0002o`00o`03oooooooo003oo`0000Ko
o`000_l00?l2ool000;o003o1?oo0002o`00o`03ool00?l00?oo003o00Coo`000ol00?l00ooooooo
003oo`00o`02ooooo`;oo`001?ooool7ool000;ooooo0_oo0001o`00007ooooo00000ol0003ooooo
ooooo`02ooooo`;oo`0000?oooooo`00ool00?l00_l00?l3ool000?o003o00?oooooool00?oo0000
0_ooool5o`00o`Wooooo0ooo0002o`00o`Coo`000ol00?l00oooooooo`00ool00003ool000?ooooo
0ooo0005o`00o`03ool00?l00?oo003o00Co003o3ooo00001Ooooooo003oo`00ool00?ooo`0000So
003o00?oo`00o`00ool00?l0>ol00?l00ooo003o003oo`00o`02o`00o`03ool00?l00?oo003o00;o
003o0_oo0002o`00o`04ool00?l00?oo003oool000;o003o2?oo0009o`00o`03ool00?oooooooooo
00Woo`000ol00?l3ool000;o003o1Ooo0002ooooo`03ool00?l00?oo003o00?o003o1?oo0002o`00
o`?oo`000_l00?l:ool000?ooooo0_oo00001?ooooooo`00ool00?oo0004o`00o`04oooooooo003o
o`00ool000Gooooo1Ooo0004ooooo`7oo`000Ol00001ooooo`0000Co0000oooooooooooooooo1_oo
0002o`00o`?oo`000_l00?l4ool000;ooooo1?l00?l00ooo003o003oo`00o`04o`00o`Ooo`0000?o
ooooool00?oo00000ooo0003o`00o`Coo`0000?oooooool00?oo00000_l00?l00ooo003o003oo`00
o`05ool000;o003o0_oo0003o`00o`;oo`000_l00?l7ool000?o003o00?oooooool00?oo00000_l0
0?l00ooo003o003oo`00o`05o`00o`03ool00?l00?oo003o00;o003o00?oo`00o`00ool00?l0=?l0
0?l2ool000Go003o00?oo`00o`00ool00?l01_l00?l4ool000;o003o00?oo`00o`00ool00?l00ooo
0008o`00o`03ool00?l00?oo003o00Coo`000ol00?lBool000;o003o00Coo`00o`00ool00?oo003o
1_oo0003o`00o`03oooooooo003oo`0000Woo`001?ooool7ool000;o003o1Ooo0006ooooo`Goo`00
0_ooool3ool0007o00000Oooool00003o`000?ooooooo`0000coo`000_l00?l5ool00003ooooool0
0?oo003o00Wo003o00?oo`00o`00ool00?l00ol00?l00ooo003oooooooooo`02o`00o`;oo`000ol0
0?l7ool000Go003o0ooo0004o`00o`03ool00?l00?oo003o00Ko003o1ooo0005o`00o`04ool00?l0
0?oo003oool000;o003o0_oo0002o`00o`;oo`001Ol00?l2ool003_o003o0_oo0006o`00o`Goo`00
0_l00?l00ooo003o003oo`00o`02ool000?o003o0ooo0002o`00o`?oo`0000?oooooool00?oo0000
1Ol00?l6ool000;o003o2_oo0002o`00o`;oo`000_l00?l2ool000Co003o00Goo`00o`00ool00?oo
ooooool00002o`00o`Soo`0000?oooooool00?oo00001Ooo0002o`00o`Ooo`000_l00?l2ooooo`?o
o`000_l00?l3ool000;ooooo00Coo`00o`00ool00?oo00000Oooool000Koo`0000?oooooo`00ool0
0?l01?oo0002ooooo`Koo`000_l00?l00ooo003o003oo`00o`0>o`00o`?oo`002?l00?l00ooooooo
o`00ool00002ool000Ko003o0ooo0004o`00o`03ool00?l00?oo003o00;oo`001ol00?l4ool000Go
003o1_oo0005o`00o`;oo`001_l00?l2ool000;o003o0_oo000[o`00o`03ool00?l00?oo003o00;o
003o0_oo0004o`00o`;oo`001Ol00?l7ool000;o003o0ooo0002o`00o`;oo`000_l00?l8ool000;o
003o00?oo`00o`00ool00?l01_oo0002o`00oa3oo`003_l00?l<ool000;o003o00?oo`00o`00ool0
0?l01?oo00000oooooooo`00o`00o`04o`00o`?oo`000_l00?l3ool000;ooooo00Coo`00o`00ool0
0?oo00000Oooool000Coo`000oooool2o`00o`;oo`0000?oooooool00?oo00001ooo0002o`00o`03
ool00?oooooooooo00[o003o00?oo`00o`00ool00?l00_l00?l2ool00003oooooooo003o003o00;o
003o00Coo`00o`00ool00?oooooo1?oo0002o`00o`04oooooooo003oo`00ool000;o003o0_oo0002
o`00o`;oo`000_l00?l6ool000?o003o1Ooo0002o`00o`Ooo`000ol00?l01?oo003o003oo`00oooo
0002o`00o`03ool00?l00?oo003o00?o003o00?oo`00o`00ool00?l00_oo000`o`00o`;oo`001?l0
0?l2ool000Co003o0ooo0004o`00o`03ool00?l00?oo003o00Ooo`000_l00?l=ool00003oooooooo
003oo`0000Coo`000_l00?l?ool000;o003o0_oo00000ooooooo003oo`00o`02ool000;o003o00?o
o`00o`00ool00?l00_l00?l3ool00003oooooooo003oo`0000Coo`000_l00?l01Ooo003o003oo`00
oooo003ooooo00Coo`000_l00?l01?oo003o003oo`00ooooool7ool000;o003o0ooo0001o`00007o
oooo00000ol0003o003oo`00o`02ool000?ooooo0_oo0002ooooo`Goo`000_l00?l3ool00003oooo
oooo003oo`0000;o003o2ooo0003o`00o`;oo`0000?oooooool00?oo00001?l00?l00oooooooo`00
o`00o`02o`00o`Goo`002?l00?l2ool000Co003o2Ooo0005o`00o`04ool00?l00?oo003oool000Ko
003o1?oo0003o`00o`;oo`001Ol00?l00ooo003o003oo`00o`02o`00o`;oo`00;?l00?l00ooo003o
003oo`00o`03o`00o`05ooooool00?oo003oo`00oooo00002?l00?l9ool000;o003o0_oo0003o`00
o`03ool00?l00?oo003o00;oo`000_l00?l9ool000;o003o00?oooooool00?oo00003Ooo00001?oo
ooooo`00ool00?ooool2ool000;o003o00?oooooool00?oo00000_oo0002o`00o`?oo`000_ooool6
ool000Co003o1Ooo0002ooooo`;oo`000_l00?l4ool000;ooooo0_oo0002o`00o`04ool00?oooooo
o`00o`00007ooooo0003o`00o`Ooo`000_ooool3ool000Co003o0_oo00000oooooooo`00ool00004
o`00o`Soo`000_ooool00ooo003o003oo`00o`07ool000;o003o00?oo`00o`00ool00?l03_l00?l2
ool000Go003o00?oo`00o`00ool00?l00_l00?l4ool000Go003o00Coo`00o`00ool00?ooo`001_l0
0?l3ool000Go003o00?oo`00o`00ool00?l04?l00?l2ool002Wo003o00?oo`00o`00ool00?l01ol0
0?l00ooo003o003oo`00o`02o`00o`Goo`000_l00?l00ooo003o003oo`00o`02ool000?o003o00?o
o`00o`00ool00?l00_oo0002o`00o`Koo`000_l00?l2ool00003oooooooo003oo`0000Woo`000_l0
0?l4ool00003oooooooo003oo`0000;oo`000ol00?l:ool00005oooooooo003oo`00ool00?ooool0
0_oo0002o`00o`Woo`000_ooool2o`00o`?oo`000_l00?l3ool000;o003o00Coo`00oooooooooooo
00000Oooool000;o003o0oooool00ooo003o003oo`00o`03ool00004oooooooo003oo`00ool000;o
003o00?oo`00o`00ool00?l01?oo0005o`00o`[oo`000_l00?l6ool000;o003o0_oo0002o`00o`03
ooooool00?oo003o00Go003o00?oo`00o`00ool00?l00ol00?l01?oo003o003oo`00ool00?l4ool0
00Go003o1?oo0004o`00o`;oo`000_l00?l00ooo003o003oo`00o`04ool000Oo003o00Coo`00o`00
ool00?ooo`00=_l00?l2ool000;o003o00Coo`00o`00ool00?ooo`001?l00?l00ooo003o003oo`00
o`04o`00o`03ool00?l00?oo003o00;oo`001Ol00?l<ool000Co003o00?oooooool00?l00?l00ol0
0?l<ool000;o003o1_oo0002o`00o`;oo`000_l00?l00ooo003o003oo`00o`09ool000;o003o0_oo
ool3ool000Co003o1_oo0003o`00o`?oo`000_l00?l8ool0007o00000Oooool000Koo`000_l00?l0
1Oooooooo`00ool00?ooooooo`0000;o003o00?oo`00ooooooooool00_l00?l3ool00004ooooool0
0?oo003oooooo`;o003o00?oo`00o`00ool00?l00_l00?l9ool000;o003o00?oo`00o`00ool00?l0
1?l00?l4ool000;o003o00Coooooo`00ool00?ooo`003?l00?l01?oo003o003oo`00oooo0004o`00
o`03ool00?l00?oo003o00?o003o00Goo`00o`00ool00?oo003oool00003o`00o`?oo`000ol00?l2
ool000;o003o0_oo000ho`00o`03ool00?l00?oo003o00;o003o0ooo0009o`00o`?oo`001?l00?l0
0ooo003o003oo`00o`03o`00o`?oo`000_l00?l4ool000Ko003o0ooo0004o`00o`03ool00?l00?oo
003o00Goo`000_l00?l9ool000;o003o1Ooo0002o`00o`Woo`000ol00?l01?oo003o003oo`00oooo
0004o`00o`Koo`001Ol00?l;ool0007o00000Oooool00003ool00?ooooooo`0000;oo`000_l00?l6
ool000;o003o0oooool00ooo003o003oo`00o`02ool000?o003o00?oooooool00?l00?l01Ol00?l9
ool000;o003o00?oo`00o`00ool00?l01Ol00?l3ool000;o003o00?oooooool00?oo00003Ol00?l0
1Ooo003o003oo`00ool00?ooo`0000?o003o00?oo`00o`00ool00?l00_l00?l2ool000Oo003o00Co
o`00o`00ool00?ooo`001_l00?l2ool000Ko003o0ooo000^o`00o`;oo`004?l00?l5ool000;o003o
00?oo`00o`00ool00?l01Ol00?l00ooo003o003oo`00o`04ool000;o003o2?oo0003o`00o`03ool0
0?l00?oo003o00Goo`000_l00?lIool000;o003o00Coo`00o`00ool00?ooo`000_l00?l2ooooo`?o
o`000_l00?l5ool000Co003o0_ooool6ool00004oooooooo003oo`00o`00007ooooo00001Ooo003o
ooooooooooooooooo`0000;o003o0_oo00000oooooooo`00ool00007ool000;o003o0_oo0007o`00
o`;oo`001Ol00?l01?ooooooo`00ool00?oo0002o`00o`Coo`000_l00?l01?oo003o003oo`00ool0
0?l2ool000Co003o00?oo`00o`00ool00?l01Ol00?l00ooo003o003oo`00o`02o`00o`Coo`000_l0
0?l4ool000;o003o1Ooo000@o`00o`?oo`001_l00?l3ool003So003o0_oo0002o`00o`03ool00?l0
0?oo003o00;o003o1?oo0003o`00o`?oo`001Ol00?l6ool000;o003o3ooo00000oooooooo`00ool0
0009ool000;o003o0_oo0002o`00o`?oo`000_l00?l6ool00004oooooooo003o003oo`00o`;oo`00
00?oooooool00?oo00001_oo0002o`00o`03ool00?l00?oo003o00;oo`000_ooool8ool000?ooooo
0_oo0001o`00007ooooo00001?oo003oooooooooooooool2o`00o`03oooooooo003oo`0000Koo`00
0_l00?l6ool000;o003o00?oo`00o`00ool00?l00_l00?l4ool000Co003o0ooo0003o`00o`;ooooo
1?oo0002o`00o`?oo`001?l00?l00ooo003o003oo`00o`05o`00o`03ool00?l00?oo003o00;o003o
0ooo0002o`00o`Goo`000_l00?l5ool000co003o0_oo0002o`00o`?oo`00AOl00?l2ool000?o003o
0_oo0002o`00o`03ool00?l00?oo003o00;o003o0ooo0003o`00o`Koo`001?l00?lDool000;o003o
0ooo0002o`00o`04ool00?oooooo003oo`00o`?oo`000ol00?l5ool00004oooooooo003oo`00oooo
o`Soo`000_l00?l2ool000Ko003o00Coooooool00?oo003ooooo2ooo0001o`00007ooooo00001?l0
0?ooo`00ool00?oo0002o`00o`Ooo`001?l00?l01?oo003o003oo`00oooo0004o`00o`03ool00?l0
0?oo003o00;o003o1_oo0004o`00o`;oo`000ol00?l5ool000;o003o1Ooo0002o`00o`;oo`000ol0
0?l00ooo003o003oo`00o`02ool000So003o1Ooo0007o`00o`03ool00?l00?oo003o00[o003o2?oo
0013o`00o`03ool00?l00?oo003o00Coo`001ol00?l4ool000;o003o1?oo0002o`00o`;oo`000_l0
0?l8ool000;o003o2_oo0002o`00o`;oo`0000Goooooool00?l00?oo003oool00002o`00o`;oo`00
00Coooooool00?l00?oo003o2?oo0003ooooo`Koo`000_l00?l2ool000Ko003o0_oo0002o`00o`_o
o`000Ol00001ooooo`0000?o003oool00?oo00001_oo0002o`00o`;oo`000_l00?l3ool000[o003o
00?oo`00o`00ool00?l00_oo0002o`00o`?oo`000_l00?l3ool000;o003o1_oo0002o`00o`Coo`00
0_l00?l2ool000;o003o1?oo0002o`00o`;oo`001?l00?l00ooo003o003oo`00o`0<o`00o`03ool0
0?l00?oo003o00Co003o00?oo`00o`00ool00?l02?l00?l2ool000Wo003o0_oo000ao`00o`Coo`00
1_l00?l2ool000;o003o00Coo`00o`00ool00?oo003o0_oo0002o`00o`03ool00?l00?oo003o00Co
003o0_oo0002o`00o`;oo`000_l00?l5ool000;o003o00Coo`00o`00ool00?ooo`000_l00?l2ool0
00;o003o1?oo0002o`00o`?oo`000ol00?l5ool000;o003o00?oo`00o`00ool00?l02?oo0002o`00
o`?oo`0000Coooooool00?oo003oo`000_l00?l8ool000;o003o2?oo0002ooooo`7oo`000Ol00001
ooooo`0000?o0000ooooooooool01_oo0002o`00o`03ool00?oooooooooo00Goo`002?l00?l2ool0
00;o003o0_oo0002o`00o`;ooooo00?oo`00o`00ool00?l01Ooo0002o`00o`;oo`001?l00?l3ool0
00?o003o00?oo`00o`00ool00?l00ooo0004o`00o`Coo`000_l00?l00ooo003o003oo`00o`0<o`00
o`?oo`000_l00?l3ool000_o003o00?oo`00o`00ool00?l01ol00?l3ool002So003o0_oo0005o`00
o`04ool00?l00?oo003oool000Ko003o00?oo`00o`00ool00?l00_l00?l00ooo003o003oo`00o`02
ool000?o003o00?oo`00o`00ool00?l00_oo0002o`00o`Koo`000_l00?l5ool000;o003o1?oo0002
o`00o`;oo`000_l00?l4ool000;o003o0_oo00001?ooooooo`00o`00ool00?l5ool000;o003o00?o
o`00o`00ool00?l00_l00?l2ooooo`Coo`000_l00?l2ool000;ooooo0_oo00000ooooooo003oo`00
o`09ool00006oooooooo003oo`00ool00?ooooooo`000_l00?l2ooooo`;oo`000Ol00001ooooo`00
1?oo0002o`00o`03oooooooo003oo`0000Coo`0000Coooooool00?oo003ooooo0_l00?l3ool00003
ooooool00?oo003o00Wo003o00Coooooo`00ool00?oo003o1?oo0002o`00o`04ool00?l00?oo003o
ool000?o003o1Ooo0006o`00o`03ool00?l00?oo003o00Co003o0ooo0006o`00o`03ool00?l00?oo
003o00;oo`000_l00?l00ooo003o003oo`00o`02o`00o`;oo`001?l00?l2ool000Ko003o0ooo0004
o`00o`03ool00?l00?oo003o00;o003o00?oo`00o`00ool00?l0??l00?l01?oo003o003oo`00oooo
ool2ool000;o003o0_oo0006o`00o`Soo`000_ooool6ool00003oooooooo003oo`0000?oo`000ol0
0?l2ool000;o003o00?oo`00o`00ool00?l01?oo0004o`00o`Koo`0000?oooooool00?oo00001?l0
0?l2ooooo`?oo`000_ooool2o`00o`;oo`0000?oooooool00?oo00001ooo00000oooooooo`00ool0
0002ool00003oooooooo003oo`0000?oo`001?l00?l2ool0007o00000Oooool000Coo`000_l00?l;
ool000;o003o1Ooo0006o`00o`03ool00?l00?oo003o00_o003o0_oo0005o`00o`04ool00?l00?oo
003oool000Ko003o0_oo0006o`00o`?oo`002Ol00?l4ool000;o003o00?oo`00o`00ool00?l03_l0
0?l00ooo003o003oo`00o`16o`00o`;oo`001Ol00?l01?oo003o003oo`00oooo0002o`00o`04ool0
0?l00?oo003oo`00o`Koo`000_l00?l6ool000;o003o1_oo0003o`00o`?oo`000_l00?l00ooo003o
003oo`00o`04ool000Co003o1ooo0006o`00o`Goo`001?l00?l7ool000;o003o0_oo0002o`00o`Co
o`0000?oooooool00?oo00001Ooo0002o`00o`03oooooooo003o0000007ooooo0004ool00004oooo
oooo003oo`00ooooo`?oo`0000Coooooo`00ool00?ooo`000_l00?l2ool000;ooooo1Ol00?l2ool0
00;o003o0_oo0004o`00o`03ool00?l00?oo003o00Co003o0_ooool9o`00o`03ool00?l00?oo003o
00;o003o0ooo000Ao`00o`04ool00?l00?oo003oool000Wo003o0_oo000:o`00o`04ool00?l00?oo
003oo`00o`;oo`001?l00?l00ooo003o003oo`00o`03o`00o`03ool00?l00?oo003o02ko003o00?o
o`00o`00ool00?l01?l00?l2ool000Ko003o1?oo0002o`00o`04ool00?l00?oo003oool000Co003o
0_oo0002o`00o`?oo`0000?oooooool00?oo00001_l00?l2ool000;o003o4_oo0002o`00o`Coo`00
0ol00?l8ool000;o003o1Ooo00001?oooooo003oo`00oooo0002o`00o`;oo`000_l00?l4ool000;o
003o1ooo00001?ooooooo`00ool00?l00001ooooo`001ooo00000oooooooo`00ool00002ool000;o
003o00?oo`00o`00ool00?l01?oo0004o`00o`;oo`000_l00?l00oooooooo`00ool00002o`00o`03
ool00?ooooooo`0000Ko003o0_oo0002o`00o`03ool00?l00?oo003o00?o003o2Ooo000@o`00o`;o
o`000_l00?l00ooo003o003oo`00o`05o`00o`Coo`002_l00?l2ool000So003o1?oo000[o`00o`03
ool00?l00?oo003o01?o003o0ooo0002o`00o`;oo`000ol00?l00ooo003o003oo`00o`02o`00o`Co
o`000_l00?l4ool000Ko003o4ooo00000oooooooo`00ool00002o`00oaCoo`0000?oooooool00?oo
00000_l00?l2ool00004oooooooo003oo`00ooooo`;o003o0ooo0002o`00o`03ool00?oooooooooo
00Ooo`000Ol00001ooooo`002ooo0002o`00o`?oo`000_ooool9ool000;o003o0_oo0002o`00o`Go
o`000_l00?l00ooo003oooooooooo`03ool000Co003o00?oo`00o`00ool00?l01?oo0002o`00o`Co
o`000_l00?l2ool000co003o00Coo`00o`00ool00?ooo`000_l00?l00ooo003o003oo`00o`03o`00
o`?oo`001ol00?l6ool003Ko003o00?oo`00o`00ool00?l01ol00?l00ooo003o003oo`00o`06o`00
o`03ool00?l00?oo003o00;oo`000ol00?l2ool000Co003o00?oo`00o`00ool00?l01Ooo0002o`00
o`Woo`000_l00?l00oooooooo`00ool0000Wool000;o003o0_oo0004ooooo`;o003o0_ooool2o`00
o`Goo`001?ooool2o`00o`Coo`000Ol00001ooooo`001Ooo0002o`00o`?oo`001?l00?l01Ooo003o
ooooool00?oo003ooooo00_oo`001?l00?l2ool000;ooooo0_l00?l2ool00004oooooooo003oo`00
ool000?o003o0_oo0003o`00o`?oo`000ol00?l6ool000;o003o00Coo`00o`00ool00?ooo`001ol0
0?l00ooo003o003oo`00o`04ool000_o003o00?oo`00o`00ool00?l00ol00?l3ool000Co003o00?o
o`00o`00ool00?l03?l00?l00ooo003o003oo`00o`0]o`00o`Coo`000_l00?l00ooo003o003oo`00
o`03ool000;o003o0_oo0002o`00o`03ool00?l00?oo003o00Coo`000_l00?l3ool000;o003o1?oo
0002o`00o`04ool00?l00?oo003oo`00oa3oo`000_l00?l=ool000;ooooo0ooo0002o`00o`04ool0
0?l00?oo003oool000;o003o1?oo0002ooooo`;o003o00?oooooool00?oo00000_oo0002o`00o`;o
oooo0_oo00001?ooooooo`00o`00ool00?l4ool0007o00000Oooool000Goo`000_l00?l2ooooo`03
ool00?l00?oo003o00;o003o1Ooo0002o`00o`?oo`0000Coooooo`00ool00?oo003o0_oo0004o`00
o`?oo`001?l00?l00ooo003o003oo`00o`03ool000Oo003o00Coooooool00?oo003oo`000_l00?l4
ool000Co003o00?oo`00o`00ool00?l00_l00?l3ool000;o003o0_oo0002o`00o`03ool00?l00?oo
003o00;oo`000_l00?l00ooo003o003oo`00o`02o`00o`03ool00?l00?oo003o00;oo`002ol00?l0
0ooo003o003oo`00o`0co`00o`03ool00?l00?oo003o00co003o00Coo`00o`00ool00?ooo`000_l0
0?l3ool000?o003o1ooo0002o`00o`?oo`000_l00?l4ool000;o003o00?oo`00o`00ool00?l02_oo
0002o`00o`Coo`000ol00?l=ool00003oooooooo003oo`0000;oo`000_l00?l01?oo003o003oo`00
oooo0003o`00o`?oo`0000Coooooool00?oo003oo`000_l00?l3ool000Co003o0_oo0003o`00o`Co
o`000Oooool1o`00007ooooo00000ol0003oooooooooo`08ool000;o003o1?oo0004o`00o`04oooo
oooo003oo`00ooooo`?o003o00Koooooool00?l00?oo003oool00?ooool3ool000Co003o00?oo`00
o`00ool00?l00_oo000;o`00o`Goo`0000?oooooo`00ool00?l02?l00?l3ool000?o003o1?oo0002
o`00o`;oo`000_l00?l5ool000?o003o0ooo000fo`00o`;oo`001_l00?l00ooo003o003oo`00o`02
o`00o`03ool00?l00?oo003o00So003o1Ooo0002o`00o`?oo`000_l00?l4ool000Co003o1Ooo0003
o`00o`;oo`000_l00?l8ool000;o003o0_oo00001?ooooooo`00o`00ool00?l4ool000;o003o2_oo
0002o`00o`koo`000_l00?l6ool00004ooooool00?oo003oooooo`;o003o0_oo0002o`00o`;oo`00
0ol00?l4ool0007o003o0Ol00001ooooo`0000?o0000ooooooooool01?ooool:ool000Co003o0ooo
00000ooooooo003oo`00o`02ooooo`?o003o1Ooo00000oooooooo`00ool00002ool000;o003o00?o
o`00o`00ool00?l03Ol00?l3ooooo`;o003o00?oo`00o`00ool00?l00_l00?l6ool00003ooooool0
0?oo003o00;o003o00?oo`00o`00ool00?l00ooo0004o`00o`?oo`004_l00?l00ooo003o003oo`00
o`0^o`00o`;oo`001?l00?l2ool000;o003o00?oo`00o`00ool00?l00_l00?l4ool000;o003o2ooo
0005o`00o`03oooooooo003oo`0000?oo`000_l00?l01?oo003o003oo`00ool00?l8ool000;o003o
2ooo0002o`00o`Woo`000_l00?l4ool00005oooooooo003oo`00ool00?ooool00_oo00000ooooooo
o`00ool0000<ool000;o003o2?oo00001oooooooo`00ool00?ooooooo`00o`00ool000000Oooool0
00;o003o0_oo0003ooooo`;o003o0ooo00001?ooooooo`00ool00?ooool4ool00003oooooooo003o
o`0000;oo`000_l00?l01Ooo003oooooo`00ool00?ooo`0000;o003o0_oo0002ooooo`Coo`001Ol0
0?l2ool000_o003o00?oooooo`00ool00?l01ooo0003o`00o`?oo`000_ooool6o`00o`Coo`000ol0
0?l3ool000Wo003o00?oo`00o`00ool00?l01_l00?l00ooo003o003oo`00o`02o`00o`Goo`00:Ol0
0?l01?oo003o003oo`00ool00?l5ool000Co003o1?oo0002o`00o`Woo`001Ol00?l00ooo003o003o
o`00o`08ool000Co003o4_oo00001?ooooooo`00o`00ool00?l8ool00003oooooooo003oo`0000oo
o`0000?oooooo`00ool00?l02_oo0002ooooo`?oo`0000Goooooool00?oo003oooooool00002o`00
o`03ool00?l00?oo0000007ooooo0002o`00o`03ool00?l00?oo003o00;ooooo0_l00?l3ool00005
oooooooo003oo`00oooooooo00000_l00?l=ool000;o003o00Goooooo`00ool00?ooooooool00002
o`00o`03ool00?l00?oo003o00?o003o1_oo0006o`00o`;oo`001Ol00?l4ool000?o003o1?oo0000
0ooooooo003oo`00o`04o`00o`Coo`003?l00?l3ool000Co003o00?oo`00o`00ool00?l01?l00?l4
ool002;o003o00?oo`00o`00ool00?l01?l00?l00ooo003o003oo`00o`07o`00o`;oo`000_l00?l0
0ooo003o003oo`00o`02ool000;o003o00?oo`00oooooooo00001_oo0004o`00o`04ool00?l00?oo
003oool000;o003o2_oo0003o`00o`koo`000_l00?l8ool000Co003o0_oo0003o`00o`Goo`0000?o
ooooool00?oo00000ooo00000oooooooo`00ool00003o`00o`ooo`0000Goooooo`00ool00?ooo`00
ooooo`02o`00o`03ooooool00?oo0000007ooooo00000ol00?ooooooool00004o`00o`?oo`000_oo
ool5ool000;o003o00?oooooool00?oo00000_oo0002o`00o`;oo`000_l00?l4ool00003ooooool0
0?oo003o00;oo`000_l00?l00ooo003oooooo`00o`03o`00o`Coo`000_l00?l4ool000;o003o0ooo
0004o`00o`03ool00?ooooooo`0000?o003o0_oo00001?ooooooo`00ool00?oo0002ooooo`;o003o
1?oo000?o`00o`;oo`000_l00?l2ool000;o003o00?oo`00o`00ool00?l01?l00?l00ooo003o003o
o`00o`0Qo`00o`;oo`001ol00?l00ooo003o003oo`00o`05o`00o`;oo`002Ol00?l7ool000Oo003o
0ooo0003o`00o`Goo`002Ol00?l6ool000So003o2?oo0004o`00o`;oo`000ol00?l9ool00003oooo
ool00?oo003o00;oo`000_l00?l3ool000;o003o1_oo0002o`00o`;oo`000_ooool2o`00o`03ool0
0?oooooooooo00?ooooo0Ol00001ooooo`0000Go0000ooooooooooooooooool00003o`00o`?oo`00
00?oooooool00?oo00001?oo0003o`00o`03ool00?oooooooooo00;o003o0_oo0002o`00o`Coo`00
0_l00?l7ool000;o003o1?oo0002ooooo`Go003o2?oo0009o`00o`;oo`000_l00?l00ooo003o003o
o`00o`02o`00o`Coo`001?l00?l00ooo003o003oo`00o`04o`00o`;oo`000_l00?l3ool000co003o
00?oo`00o`00ool00?l01_l00?l00ooo003o003oo`00o`0Ho`00o`;oo`002?l00?l2ool000Co003o
00?oo`00o`00ool00?l00ol00?l2ool000Go003o1Ooo0003o`00o`03oooooooo003oo`0000;o003o
1?oo0004o`00o`?oo`001_l00?l00ooo003o003oo`00o`06ool000Ko003o3?oo00000oooooooo`00
ool0000;ool000;o003o00?oooooo`00ool00?l01ooo0002o`00o`Koo`000_l00?l2ool000?ooooo
1?oo00001?ooooooo`00o`00ool00001ooooo`0000Co0000oooooooooooooooo0_oo0002o`00o`?o
o`0000?oooooool00?oo00001?oo0003o`00o`;oo`000_ooool2ool00003ooooool00?oo003o00;o
003o0_oo0002o`00o`;oo`000_l00?l7ool000;o003o00Coooooo`00ool00?ooo`000ol00?l5ool0
00;o003o0_oo0005o`00o`03ool00?l00?oo003o00;oo`000_l00?l00ooo003o003oo`00o`04ool0
0003oooooooo003oo`0000Coo`000ol00?l5ool000;o003o0ooo0003o`00o`03ool00?l00?oo003o
00Ko003o0_oo000Ro`00o`;oo`001Ol00?l01?oo003o003oo`00oooo0002o`00o`04ool00?l00?oo
003oool000;o003o1ooo0003o`00o`03ool00?l00?oo003o00Co003o1ooo0002o`00o`?oo`000_l0
0?l8ool000;o003o2_oo0003o`00o`goo`0000Coooooool00?oo003oo`000_ooool2ool00003oooo
oooo003oo`0000;ooooo00?oo`00o`00ool00?l01Oooool3ool000;o003o1Ooo0004ooooo`;oo`00
1?ooool2ool000;o003o00Coooooool00?l00?oo00000Oooool00003o`000?oooooooooo00?oo`00
00Goooooool00?l00?oo003oooooo`02ool000;o003o00?oo`00oooooooo00003?oo0003o`00o`?o
oooo0_oo0002o`00o`Goo`001?l00?l01?oooooo003oo`00ool00?l4ool000;o003o0_oo0002o`00
o`;oo`000_l00?l2ool00003oooooooo003oo`0000Koo`000_l00?l5ool00003oooooooo003oo`00
00Woo`004Ol00?l01?oo003o003oo`00oooo000Zo`00o`?oo`000_l00?l00ooo003o003oo`00o`02
ool000Co003o0_oo0004o`00o`;oo`001ol00?l6ool000;o003o0ooo0002o`00o`03ool00?l00?oo
003o00Goo`000_l00?l?ool00003oooooooo003oo`0000Coo`000ol00?l00ooo003oooooooooo`02
o`00o`Goo`0000?oooooool00?oo00001Ooo0003ooooo`Coo`000_l00?l3ool000Cooooo1?oo0004
ooooo`04ool00?l00?oo003oo`00o`;ooooo0Ol00?l1o`00007ooooo0002ool000;o003o0_oo0000
1Oooooooo`00o`00ool00?oooooo00;oo`000_l00?l2ooooo`Goo`000_l00?l4ool000Go003o00Co
ooooo`00ool00?oooooo2?oo0004o`00o`;ooooo0_l00?l2ool000Co003o2?oo0002o`00o`03oooo
ool00?oo003o00Coo`001Ol00?l7ool000;o003o1_oo000<o`00o`Coo`001Ol00?l00ooo003o003o
o`00o`03o`00o`03ool00?l00?oo003o02[o003o0_oo0004o`00o`;oo`001?l00?l4ool000;o003o
00?oo`00o`00ool00?l00_oo00001?ooooooo`00ool00?oo0004o`00o`03ool00?l00?oo003o00Go
003o2?oo0002o`00o`Woo`000_l00?l6ool000?o003o0oooool2o`00o`Goo`000_l00?l3ool00003
oooooooo003oo`0000;oo`0000?oooooool00?oo00000_oo0002o`00o`?oo`000_l00?l2ooooo`;o
o`000_ooool5ool000;o003o00Goo`00ooooooooooooooooo`000001ooooo`000_oo0002o`00o`Go
o`000_ooool5ool00003oooooooo003oo`0000?oo`000_l00?l4ool000?o003o0ooo0002o`00o`?o
o`000_ooool4ool00005ooooool00?oo003oo`00oooo00001?l00?l00ooo003o003oo`00o`04ool0
00;o003o00Coo`00oooooooo003oo`001Ol00?l4ool000Ko003o0ooo0002o`00o`03ool00?l00?oo
003o00;oo`000_l00?l00ooo003o003oo`00o`02o`00o`04ool00?l00?oo003oool000?o003o0_oo
0002o`00o`03ool00?l00?oo003o00Co003o00?oo`00o`00ool00?l02_l00?l2ool000go003o00?o
o`00o`00ool00?l01ol00?l00ooo003o003oo`00o`0:o`00o`03oooooooo003o003o00;o003o00?o
o`00oooooooo00000_l00?l2ool000;o003o0_oo0002o`00o`Woo`001?l00?l3ool000Go003o1?oo
00001?ooooooo`00ool00?oo0002o`00o`Woo`001?l00?l7ool00004oooooooo003oo`00ooooo`Ko
o`000_l00?l00ooo003oooooool00009ool00003ooooool00?oo003o00?oo`000_l00?l00ooooooo
o`00ool00007ool00003oooooooo003oo`0000Co003o0Ol00001ooooo`0000?o0000ool00?oo0000
1_oo0002o`00o`Woo`0000?oooooool00?oo00000_oo00001?ooooooo`00ool00?oo0004o`00o`03
ool00?l00?oo003o00?oo`0000?oooooool00?oo00000ooo00000ooooooo003oo`00o`02ool000Co
003o1ooo0004o`00o`04ool00?l00?oo003oool000Co003o00Coo`00oooooooo003oo`000_l00?l0
0ooo003o003oo`00o`03ool000;o003o1Ooo000<o`00o`;oo`001?l00?l00ooo003o003oo`00o`04
o`00o`03ool00?l00?oo003o00Go003o00?oo`00o`00ool00?l04Ol00?l00ooo003o003oo`00o`06
o`00o`;oo`001_l00?l00ooo003o003oo`00o`04o`00o`03ool00?l00?oo003o00Goo`000_l00?l0
0ooo003o003oo`00o`02o`00o`coo`001?l00?l3ool000;o003o5ooo0002o`00o`Ooo`0000Cooooo
ool00?oo003ooooo3Ooo0003ooooo`Coo`001Oooool2ool000;o003o1Ooo0002o`00o`03ool00?oo
oooooooo00;ooooo1?l00?l1o`00007ooooo00000ol0003oo`00ool00002ool00004ooooool00?oo
003oool000;o003o2Ooo0002ooooo`?oo`0000Coooooool00?oo003oo`001?l00?l01?ooooooo`00
ool00?oo0003ooooo`;oo`000oooool01?oo003o003oo`00ooooool:ool000;o003o0_oo0002o`00
o`03ool00?l00?oo003o00?oo`000_l00?l00ooo003oooooo`00o`02o`00o`Ooo`0000?oooooool0
0?oo00000_oo00000oooooooo`00ool00002o`00o`03ool00?oooooo003o00;o003o0_oo0002o`00
o`;oo`000_l00?l2ool000Oo003o00?oo`00o`00ool00?l00_oo000Mo`00o`03ool00?l00?oo003o
00Wo003o00?oo`00o`00ool00?l01ol00?l4ool000;o003o0ooo0002o`00o`Koo`000_l00?l4ool0
00Co003o1Ooo0002o`00o`;ooooo4?oo0002o`00o`Soo`0000?oooooool00?oo00002Ooo00000ooo
ooooo`00ool00004ool00003oooooooo003oo`0000;ooooo0_oo00000oooooooo`00ool00002oooo
o`;oo`000_l00?l00ooooooo003oo`00o`02ooooo`;o003o00Coo`00oooooooo003oo`000_ooool3
ool0007o00000Oooool00003o`000?ooooooo`0000?oo`000_l00?l01?oo003oooooooooooooool2
ool000;o003o0_oo0006ooooo`Soo`0000?oooooool00?oo00001?oo0002o`00o`03ool00?oooooo
oooo00Goo`000_l00?l01?oo003oooooo`00ool00?l4ool000;o003o0_oo00000ooooooo003oo`00
o`05ool000;o003o0_oo0003o`00oa?oo`000_l00?l9ool00003oooooooo003o003o00?o003o00?o
o`00o`00ool00?l00ol00?l01?oo003o003oo`00oooo0009o`00o`03ool00?l00?oo003o01Oo003o
00Goo`00o`00ool00?oo003oooooo`02ool000;o003o00?oo`00o`00ool00?l00ol00?l3ool00003
oooooooo003oo`0000;o003o00?oo`00ooooooooool01Ooo0003o`00o`Goo`000_l00?l5ool000;o
003o0_ooool:ool000?o003o0ooo0002o`00oa3oo`0000Coooooool00?oo003oo`000_l00?l4ool0
0004oooooooo003oo`00ool000?ooooo0_l00?l7ool000;ooooo0ol00?l5ooooo`;oo`001?ooool1
ool0007o00000Oooool00003o`000?oo003oo`0000?oo`001Oooool3ool000;o003o0ooo0005oooo
o`Coo`000oooool4o`00o`Coo`000_l00?l2ool00004oooooooo003oo`00ool000So003o0_oo0000
1?ooooooo`00o`00ool00?l2ool00003ooooool00?oo003o00Coo`001Ol00?l2ooooo`;oo`000_l0
0?l@ool000;o003o0_oo0002o`00o`;oo`000_l00?l00ooo003o003oo`00o`02ool000Co003o00Go
o`00o`00ool00?oo003oool00002o`00o`03ool00?l00?oo003o01go003o00Coo`00o`00ool00?oo
o`001_l00?l01?oo003o003oo`00oooo0005o`00o`?oo`000_l00?l01?oo003o003oo`00ool00?l4
ool000;o003o0_oo0004o`00o`Soo`000_l00?l3ool00003oooooooo003oo`0000Ooo`001?l00?lE
ool00004oooooooo003oo`00ool000;o003o00?oooooool00?oo00001?oo00001?ooooooo`00ool0
0?ooool2o`00o`Ooo`000_ooool01?oo003o003oo`00ooooool2ool000Sooooo0Ooo0001o`00007o
oooo00000ol0003oo`00ool00004ool000;o003o0ooo0003o`00o`Coo`000_ooool2o`00o`04oooo
oooo003oo`00ooooo`Coo`001?l00?l01_ooooooo`00ool00?oo003oooooool000?o003o0ooo0007
o`00o`Woo`000_l00?l00ooo003o003oo`00o`02ool000Go003o0_oo0005o`00o`03ool00?l00?oo
003o00Coo`000ol00?l4ool000;o003o00?oo`00o`00ool00?l00ol00?l00ooo003o003oo`00o`04
o`00o`03ool00?l00?oo003o00Ko003o00Coo`00o`00ool00?ooo`007_l00?l5ool000Ko003o00?o
o`00o`00ool00?l01_l00?l00oooooooo`00ool00002o`00o`04ool00?l00?oo003oo`00o`Coo`00
0_l00?l2ool000Co003o1?oo0002o`00o`;oo`000ol00?l<ool000;o003o3ooo00000oooooooo`00
ool00006ool00003oooooooo003oo`0000;oo`0000Coooooool00?oo003ooooo0ooo00001?oooooo
o`00ool00?ooool4ool000;ooooo0ooo0002o`00o`;oo`000_ooool2ool00004oooooooo003oo`00
ooooo`;oo`000_ooool1ool0007o00000Oooool00003o`000?oooooooooo00;ooooo0_oo0002o`00
o`?oo`000ol00?l4ooooo`;oo`000_l00?l00oooooooo`00ool00005ool000;ooooo0_oo00001_oo
ooooo`00ool00?oo003oooooool000?o003o00?oo`00o`00ool00?l01Ooo0002ooooo`Woo`000_l0
0?l01Ooo003o003oo`00oooo003ooooo00Goo`001?l00?l01?oo003o003oo`00oooo0002o`00o`Co
o`001?l00?l00ooo003o003oo`00o`02o`00o`03ool00?l00?oo003o00?o003o0ooo000=o`00o`05
ool00?l00?oo003oo`00oooo00006_l00?l01?oo003o003oo`00oooo0002o`00o`?oo`001?l00?l2
ool000Co003o00Goo`00o`00ool00?oo003oool00003o`00o`Ooo`0000?oooooool00?oo00000ooo
0002o`00o`Koo`000_l00?l3ool000;o003o1Ooo00000oooooooo`00ool0000@ool00003oooooooo
003oo`0000?o003o2?oo0002ooooo`?oo`001?ooool5ool000;ooooo1?oo0005ooooo`;o003o00?o
ooooool00?oo00001?ooool2ool00003oooooooo003oo`0000?ooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool2ool00003oooooooo003oo`0000;ooooo0_oo0003ooooo`;oo`000oooool6
ool000;o003o1?ooool2o`00o`?ooooo1?oo0002o`00o`;ooooo0ooo0002o`00o`?ooooo0ol00?l3
ool00003oooooooo003oo`0000;o003o00?oo`00oooooooo00000_l00?l2ool000;o003o00?oo`00
ooooooooool00ooo0002o`00o`Coo`002Ol00?l00ooo003o003oo`00o`02o`00o`?oo`001ol00?l2
ool000Co003o0ooo000<o`00o`03ooooool00?oo003o00go003o00Coo`00o`00ool00?ooo`001Ol0
0?l7ool000Co003o00Goo`00o`00ool00?oo003oool00003o`00o`Coo`0000Coooooool00?oo003o
oooo0ooo0002o`00o`;oo`001?ooool2ool000;o003o2Ooo0003ooooo`;o003o0_oo0002ooooo`_o
o`0000?oooooool00?oo00000ol00?l2ool00003ooooool00?oo003o00;oo`000oooool2ool000Go
oooo1Ooo00000oooooooo`00ool00008ooooo`;oo`0000Coooooool00?oo003oo`001_ooool2ool0
00?ooooo0Ol00001ooooo`0000?o0000oooooooo00000_oo0005ooooo`;oo`000_ooool4ool00003
oooooooo003oo`0000?ooooo1_oo0002o`00o`;ooooo0_oo0002o`00o`;ooooo0_l00?l00ooo003o
003oo`00o`02ool000?o003o0_oo0002o`00o`;oo`0000Coooooo`00ool00?oo003o2Ooo00001?oo
ooooo`00o`00ool00?l2ooooo`Soo`000_l00?l8ool000?o003o00?oo`00oooooooo00000_l00?l2
ool00003oooooooo003oo`0000Go003o00?oooooool00?oo00000ooo000Bo`00o`03ool00?l00?oo
003o00[o003o00?oo`00o`00ool00?l00_l00?l00ooo003o003oo`00o`03o`00o`;oo`000_l00?l4
ool000?o003o0_oo0003o`00o`;oo`0000?oooooool00?oo00001_oo0002o`00o`03ool00?l00?oo
003o00Coo`000_l00?l4ool000;ooooo1_oo00001?ooooooo`00ool00?ooool2o`00o`?oo`000_oo
ool2o`00o`Coo`000_l00?l;ool000;o003o1_ooool2ool000Cooooo2?oo0002ooooo`;o003o00?o
o`00ooooooooool01Oooool4ool000;o003o1?ooool2ool0007o003o0Ol00001ooooo`0000?o0000
oooooooo00000_l00?l5ooooo`;o003o1_oo00001?ooooooo`00ool00?oo0002ooooo`Goo`001Ooo
ool2ool000Wo003o0_oo0003o`00o`03oooooooo003oo`0000Goo`000_l00?l5ool00006oooooooo
003oo`00ool00?ooooooo`000_l00?l7ool000;o003o00?oooooool00?oo00000_oo0002o`00o`03
ool00?ooooooo`0000Ooo`000_l00?l7ool000;o003o0_oo0002o`00o`?oo`003Ol00?l00ooo003o
003oo`00o`0?o`00o`05ool00?l00?oo003oo`00oooo00001?l00?l01?oo003o003oo`00oooo0004
o`00o`Soo`000ol00?l5ool000;o003o0ooo0002o`00o`Ooo`000_l00?l01?oo003o003oo`00oooo
0002ooooo`goo`000_l00?l2ooooo`?o003o0ooo0002o`00o`?oo`0000Coooooool00?oo003oo`00
0oooool2ool000?ooooo0ol00?l3ool000;ooooo1?oo00000oooooooo`00ool00002ool000?ooooo
0_l00?l00ooo003oooooooooo`02ooooo`;oo`000_ooool3ool000;o003o00?oo`00ooooooooool0
0ooo0001o`00o`7o00000Oooool00003o`000?oooooooooo00;o003o1Oooool2o`00o`Goo`0000?o
ooooool00?oo00000_oo0002ooooo`;o003o1?oo0004ooooo`;oo`000_ooool2o`00o`03ool00?l0
0?oo003o00_oo`0000Goooooo`00ool00?ooo`00ooooo`02o`00o`Ooo`000_ooool00ooo003o003o
o`00o`02o`00o`05ool00?l00?oo003ooooooooo00000_l00?l4ool00004ooooool00?oo003oool0
00;o003o0_oo0002o`00o`;oo`000_l00?l7ool00003oooooooo003oo`0000Co003o0ooo0004o`00
o`03ool00?l00?oo003o00;o003o00?oo`00o`00ool00?l00_oo0002o`00o`05ool00?l00?oo003o
o`00oooo00000ol00?l01Ooo003o003oo`00ool00?ooo`0000[o003o0_oo0002o`00o`03ool00?l0
0?oo003o00;o003o00?oo`00ooooooooool00_l00?l2ool000Co003o1Ooo0004o`00o`Soo`0000?o
ooooool00?oo00000_oo0002o`00o`;ooooo0_l00?l2ool00003oooooooo003oo`0000Coo`0000?o
ooooool00?oo00000_l00?l2ool00005ooooool00?oo003oool00?ooool02_oo00000ooooooo003o
o`00o`02ooooo`?oo`000ol00?l7ool000?ooooo1Ooo0003ooooo`;oo`000_ooool6ool000Cooooo
0_oo0002ooooo`;oo`0000?oooooool00?l000000Oooool00004o`000?ooooooooooooooo`;oo`00
0oooool2ool00003oooooooo003oo`0000Cooooo0_oo0004ooooo`;o003o00Goooooool00?oo003o
o`00ooooo`03ool000Cooooo0ooo00000oooooooo`00ool00006ooooo`Coo`0000?oooooo`00ool0
0?l00_ooool2o`00o`Koo`001Oooool01?oo003o003oo`00oooo0002o`00o`Soo`0000Coooooool0
0?oo003ooooo0_l00?l2ool000?o003o00?oo`00o`00ool00?l02?oo00001?ooooooo`00o`00ool0
0?l4ool00006oooooooo003o003oo`00ooooooooo`001?l00?l3ool000;o003o00?oooooool00?l0
0?l04ol00?l01?oo003o003oo`00oooo0002o`00o`03ool00?oooooo003o00;o003o0_oo0002oooo
o`Oo003o0_oo0002ooooo`Coo`000_l00?l00oooooooo`00ool00005ool00004oooooooo003oo`00
ool000;ooooo0ooo0002o`00o`;oo`0000?oooooool00?oo00000_oo0003ooooo`;oo`000_ooool3
ool00004oooooooo003oo`00ooooo`Woo`000_ooool2o`00o`;ooooo3Ooo0003ooooo`Coo`000_l0
0?l2ool00003oooooooo003oo`0000?oo`000_ooool2ool000_ooooo0Ooo0001o`00007ooooo0000
1?l0003oooooooooooooool2ool000?ooooo0_oo00000oooooooo`00ool00008ooooo`Ooo`000_oo
ool3ool000;ooooo1?oo0002ooooo`;oo`000_ooool4ool00005oooooooo003oo`00ool00?ooool0
0_l00?l7ool000;ooooo1ooo0002o`00o`;oo`000_l00?l7ool000?o003o0ooo00000oooooooo`00
ool00005o`00o`Goo`001?l00?l01Ooo003o003oo`00ooooooooo`0000;o003o0_oo0002o`00o`04
oooooooo003oo`00ooooo`;o003o0_oo000Io`00o`03ool00?l00?oo003o00?o003o1Ooo0002o`00
o`;ooooo0_oo0007o`00o`Soo`000_ooool5ool000Cooooo2ooo0008ooooo`;oo`000_ooool2ool0
0005oooooooo003o003oo`00oooo00000_l00?l4ooooo`;oo`0000?oooooool00?oo00000_oo0003
ooooo`?oo`000_l00?l00oooooooo`00ool0000:ooooo`;o003o0_oo00001?ooooooo`00ool00?oo
0006ooooo`;o003o2Oooool1ool0007o00000Oooool00003o`000?oooooooooo00Cooooo0_oo0002
ooooo`;oo`000oooool2ool000Cooooo0_oo00000oooooooo`00ool00002ool000;ooooo1?oo0000
0oooooooo`00ool00002ooooo`;oo`001?ooool4ool00003oooooooo003oo`0000;oo`000_l00?l2
ool00003oooooooo003oo`0000;oo`000_ooool7ool000;o003o0_oo0002o`00o`Coo`000_l00?l0
1?oo003o003oo`00ool00?l7ool000;o003o00?oooooool00?oo00000ol00?l00ooo003o003oo`00
o`02o`00o`04ool00?l00?oo003oooooo`Go003o00?oo`00o`00ool00?l01Ol00?l2ool000Oo003o
00?oo`00o`00ool00?l03ol00?l00ooo003o003oo`00o`03o`00o`03ool00?l00?oo003o00Co003o
0_oo0002o`00o`;oo`000_l00?l00ooo003o003oo`00o`02ool000;o003o1?oo0002o`00oa3oo`00
0_l00?l2ool000Cooooo0_oo0002ooooo`;oo`0000Goooooool00?oo003oooooool00003o`00o`04
ool00?l00?oo003oooooo`;oo`0000Coooooool00?oo003ooooo1Ooo00000oooooooo`00ool00002
ooooo`;o003o00Coooooool00?oo003oo`001oooool6ool000;ooooo0_oo0006ooooo`;o003o2_oo
ool1o`00007ooooo00001Ol0003oooooooooooooooooo`0000;o003o0_oo00001Oooooooo`00ool0
0?oo003ooooo00;o003o0_oo00000ooooooo003oo`00o`06ooooo`Coo`000_ooool00ooo003o003o
o`00o`03ool00004oooooooo003oo`00ooooo`;oo`000oooool2ool000?ooooo1_oo0003ooooo`;o
o`001?l00?l01?oo003o003oo`00oooo0002o`00o`Woo`000_l00?l6ool000Go003o00Goo`00oooo
ooooooooooooool00005o`00o`Ooo`001Ol00?l00ooo003o003oo`00o`0>o`00o`03ool00?l00?oo
003o00co003o1?oo0004o`00o`;oo`001_l00?l2ool000;o003o00?oo`00o`00ool00?l00_oo0000
1?ooooooo`00ool00?oo0003o`00o`;ooooo0ol00?l00oooooooo`00ool0000<ool000?o003o0_oo
00000oooooooo`00ool00003ool000;o003o00?oooooool00?oo00001?oo0002o`00o`?oo`000_oo
ool2ool000;ooooo0_oo0003ooooo`;oo`0000Coooooool00?oo003oo`001?ooool2o`00o`03ool0
0?oooooooooo00?ooooo2?oo0007ooooo`;oo`001Oooool5ool00004oooooooo003oo`00o`00007o
oooo00001Ol0003oooooooooooooooooo`0000;o003o00?oo`00ooooooooool00_oo0002ooooo`;o
003o00?oo`00ooooooooool00_l00?l6ooooo`Koo`0000?oooooo`00ool00?l01?oo0003ooooo`Co
o`0000?oooooool00?oo00000oooool4ool000Gooooo0_oo0007o`00o`03ool00?l00?oo003o00Co
o`0000?oooooool00?oo00002_oo0005o`00o`Koo`001?l00?l2ool000;ooooo0ooo0002o`00o`03
ool00?ooooooo`0000;oo`007_l00?l4ool000Co003o1_oo0005o`00o`;oo`000ol00?l01?oooooo
o`00ool00?oo0004o`00o`05ool00?oooooo003oo`00oooo00000_ooool=ool000;o003o1?ooool5
ool000;o003o0ooo00000oooooooo`00ool00002ooooo`Coo`0000Coooooool00?oo003oo`000_oo
ool2ool000?ooooo0_oo0002ooooo`;oo`000oooool5o`00o`Cooooo0ooo0005ooooo`;oo`001Ooo
ool2ool000;ooooo2?oo00001?ooooooo`00ool00?l00001ooooo`0000?o0000ool00?oo00000ooo
ool2ool000;ooooo0_oo0003ooooo`;oo`000_ooool2ool000Kooooo0_oo0002ooooo`;oo`000ooo
ool4ool000Gooooo0_oo00001?ooooooo`00ool00?oo000;ooooo`;oo`0000?oooooool00?oo0000
0_l00?l01?oo003oooooooooooooool3ool00003oooooooo003oo`0000Goo`0000?oooooool00?oo
00000_ooool2ool00004oooooooo003o003oo`00o`Koo`001Oooool2ool000;ooooo0_oo0003o`00
o`Ooo`000ol00?l01?oo003o003oo`00oooo0007o`00o`03ooooool00?oo003o00;oo`000ol00?l0
0ooo003o003oo`00o`03o`00o`;oo`0000Goooooool00?l00?oo003oooooo`02o`00o`Coo`0000?o
ooooo`00ool00?l00ol00?l00oooooooo`00ool00002o`00o`03ool00?l00?oo003o00?o003o0ooo
00000oooooooo`00ool0000Cool00003ooooool00?oo003o00Soo`0000?oooooool00?oo00000_oo
00000oooooooo`00ool00006ool000?ooooo0_oo00001?ooooooo`00ool00?oo0007ooooo`04ool0
0?l00?oo003oooooo`;o003o3?ooool2ool000Oooooo1ooo00000oooooooo`00ool00003ooooo`7o
00000Oooool00003o`000?oo003oo`0000;ooooo0_l00?l2ool00003oooooooo003oo`0000Oooooo
1?oo0002ooooo`;oo`000_ooool2ool000;o003o00?oooooool00?oo00000_ooool2ool000Sooooo
1Ooo00001?ooooooo`00ool00?oo0004ooooo`;o003o0ooo0002o`00o`;oo`000_ooool6ool000;o
003o00Goo`00oooooooo003oo`00ooooo`03ool000;ooooo0ooo0002o`00o`04oooooooo003oo`00
ooooo`;oo`001?ooool4ool000?ooooo1Ol00?l2ooooo`?oo`000_l00?l2ool000;o003o00?oo`00
o`00ool00?l00ooo0002o`00o`03ool00?l00?oo003o00;oo`001_l00?l2ooooo`?o003o00?oo`00
o`00ool00?l01?l00?l4ool000?o003o00?oo`00o`00ool00?l00ooo00000oooooooo`00ool00003
o`00o`;oo`0000?oooooool00?oo00001?ooool=ool000;o003o0ooo00001?oooooo003oo`00oooo
0002ooooo`Coo`000_ooool2ool000?ooooo0_oo0002o`00o`Coo`001_ooool4ool000Kooooo0_oo
000>ooooo`;oo`0000?oooooool00?oo00000_ooool2ool00004oooooooo003oo`00ool000;ooooo
0_oo0007ooooo`7o00000Oooool00005o`000?ooooooo`00ool00?ooool00_l00?l2ool000Wooooo
0_oo00001?ooooooo`00ool00?ooool2o`00o`03ool00?oooooooooo00;oo`000_l00?l00ooooooo
o`00ool00002ooooo`Coo`001?ooool2o`00o`03ool00?l00?oo003o00;oo`0000Coooooool00?oo
003oo`000_ooool2ool000;o003o0ooo0002o`00o`?ooooo1ooo0002o`00o`Goo`000_l00?l00ooo
003oooooooooo`03ool000Gooooo00Coo`00o`00ool00?oo003o1ooo00000oooooooo`00ool00002
ool000?o003o00?oooooool00?oo00000_oo0006o`00o`03ool00?l00?oo003o00Go003o00Goo`00
o`00ool00?oo003oool0000;o`00o`04ool00?l00?oo003oool000;o003o1Ooo0002o`00o`;oo`00
0_l00?l=ool000Cooooo1?oo00000oooooooo`00ool00002o`00o`03ool00?ooooooo`0000;oo`00
0_l00?l2ool000?ooooo0_oo0003ooooo`;oo`001Oooool2ool00003oooooooo003oo`0000;o003o
1?oo0002ooooo`;oo`000oooool3ool000;ooooo0ooo00000oooooooo`00ool00007ooooo`;oo`00
0_ooool2o`00o`04oooooooo003oo`00ooooo`Koo`0000Coooooool00?oo003ooooo1?oo0007oooo
o`7o00000Oooool00004ool00?ooooooo`00ool000;ooooo0_oo000:ooooo`;oo`001?ooool2o`00
o`;oo`000oooool2ool00003oooooooo003oo`0000?ooooo1ooo0002o`00o`03ool00?l00?oo003o
00;ooooo0_l00?l4ooooo`Coo`000_ooool2ool000Cooooo0_oo00000oooooooo`00ool00009ool0
00;o003o0oooool3ool000Gooooo00Goo`00o`00ool00?oo003oool00002o`00o`03ool00?oooooo
003o00?o003o0_oo0002o`00o`04ool00?oooooo003oo`00o`Coo`000ol00?l3ool000Oo003o00Go
o`00o`00ool00?oo003oool00002o`00o`;oo`001Ol00?l00ooo003o003oo`00o`02o`00o`Cooooo
1?oo0002o`00o`;oo`001?l00?l00ooo003o003oo`00o`07ool000;o003o0_oo0002o`00o`Coo`00
0_ooool2o`00o`03ool00?oooooooooo00?ooooo0_oo00000oooooooo`00ool00002ool000;ooooo
1?oo0005ooooo`;oo`0000Coooooool00?oo003ooooo1?oo00000oooooooo`00ool00002ool00003
oooooooo003oo`0000?oo`000_ooool3ool00003oooooooo003oo`0000;oo`001Oooool3ool00003
ooooool00?oo003o00Cooooo1?oo0002ooooo`;oo`000_ooool2ool000?ooooo0_oo0004ooooo`7o
00000Oooool000Coo`001?ooool2ool000Oooooo0_oo0002ooooo`;oo`000oooool2ool000Kooooo
0_oo0003ooooo`[oo`0000Coooooool00?oo003ooooo0_l00?l5ooooo`?oo`000_ooool2ool000Co
oooo0ooo0004o`00o`Goo`000_ooool2ool00004ooooool00?oo003oo`00o`Sooooo0ooo00001Ooo
oooo003oo`00oooo003ooooo00Co003o0_oo0002o`00o`;oo`000_l00?l3ool000;o003o0_oo0002
o`00o`;oo`000_ooool01?oo003o003oo`00oooo0004o`00o`05ooooool00?oo003ooooooooo0000
1?l00?l00oooooooo`00o`00o`05o`00o`?ooooo0ooo0002o`00o`;oo`001?l00?l00ooo003o003o
o`00o`02ooooo`Goo`001ol00?l00oooooooo`00ool0000:ooooo`;oo`0000?oooooool00?oo0000
0_oo0002ooooo`;oo`000_l00?l3ooooo`;oo`0000?oooooool00?oo00000_oo0003ooooo`;oo`00
00?oooooool00?oo00002Ooo00000oooooooo`00ool00004ooooo`;oo`001_ooool00ooo003o003o
o`00o`02ooooo`;oo`000_ooool2ool000;ooooo1Ooo0006ooooo`?oo`000oooool1o`00007ooooo
0002ool000Kooooo1?oo0005ooooo`;oo`000_ooool2ool001;ooooo1Ooo00000oooooooo`00ool0
0005ool00003oooooooo003oo`0000Kooooo1?oo0003ooooo`Coo`001?l00?l00oooooooo`00ool0
0002ooooo`?oo`000_ooool3o`00o`?oo`0000?oooooo`00ool00?l00_ooool2ool000?ooooo0ooo
00001_oooooo003oo`00ool00?ooooooool000;o003o1?oo0002o`00o`03ool00?l00?oo003o00;o
o`001Ol00?l00ooo003o003oo`00o`06o`00o`05oooooooo003o003oo`00oooo00001?l00?l01Ooo
003o003oo`00ool00?ooo`0000?o003o00?oo`00ooooooooool00_ooool2ool00003oooooooo003o
o`0000Coo`0000?oooooool00?oo00000_ooool2ool000?ooooo1?l00?l00ooo003o003oo`00o`04
ooooo`;oo`001oooool4ool000;o003o0_ooool3ool000;o003o0_oo00001?ooooooo`00ool00?oo
ool2ool000?ooooo1_oo00000oooooooo`00ool00007ool00003ooooool00?oo003o00;oo`002ooo
ool2o`00o`;ooooo0_oo0006ooooo`Goo`000_ooool2ool000?ooooo0_oo0003ooooo`7o00000Ooo
ool00003o`000?oooooooooo00Kooooo0ooo00000oooooooo`00ool00004ool000[ooooo0ooo000:
ooooo`Koo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00002ool000Cooooo1Ooo0002
ooooo`;oo`0000?oooooo`00ool00?l00_oo0002ooooo`Ooo`001?ooool3ool000Co003o0oooool2
ool000?ooooo0_oo0003o`00o`03ool00?oooooo003o00;o003o00Coo`00oooooooooooooooo0_l0
0?l6ool000Co003o00?oo`00o`00ool00?l00_l00?l01Oooooooo`00o`00ool00?ooo`0000Go003o
1?oo0003o`00o`?ooooo0_oo00001?ooooooo`00o`00ool00?l2ool00004oooooooo003o003oo`00
o`;oo`001_ooool2ool000?ooooo0_l00?l7ool000;ooooo1?oo0002ooooo`;oo`000_ooool2ool0
00?o003o00?oo`00oooooooo00001_oo00000oooooooo`00ool00002ool000Cooooo2_oo0004oooo
o`;oo`0000?oooooo`00ool00?l00_oo000=ooooo`;oo`0000?oooooo`00ool00?l02?ooool2ool0
00;ooooo0_oo0008ooooo`7o00000Oooool00004o`000?ooooooo`00ool000Gooooo0ooo00000ooo
ooooo`00ool00002ool000_ooooo1_oo000<ooooo`Soo`000oooool2ool000;ooooo0_oo0003oooo
o`?oo`001?ooool2o`00o`?oo`000_ooool7ool00003oooooooo003oo`0000;oo`0000?oooooo`00
ool00?l01Oooool2ool000?ooooo1Ol00?l2ool000;o003o2Ooo0002o`00o`04ool00?l00?oo003o
o`00o`;ooooo3ol00?l6ool000;ooooo0ooo0002o`00o`03ool00?l00?oo003o00;oo`001?l00?l2
ool000;ooooo2ooo0005ooooo`;oo`0000Coooooool00?oo003ooooo2Ooo0004o`00o`03ool00?oo
ooooo`0000Coo`0000?oooooool00?oo00001?oo0005ooooo`;o003o2?oo0002ooooo`Coo`0000?o
ooooool00?oo00002_ooool2ool000;ooooo0_oo00000ooooooo003oo`00o`02ool000;o003o00?o
o`00ooooooooool00oooool2o`00o`[ooooo0Ol00001ooooo`0000Co0000oooooooo003oo`001_oo
ool2ool000Wooooo0_l00?l4ooooo`?oo`0000Coooooool00?oo003oo`001oooool2ool000Gooooo
0ooo00000oooooooo`00ool00003ooooo`;oo`0000?oooooool00?oo00000_l00?l00ooooooo003o
o`00o`02ool000?ooooo0_oo0002o`00o`;oo`0000?oooooool00?oo00002_oo0003ooooo`;o003o
0_oo0004ooooo`;oo`001ol00?l00ooo003oooooooooo`05ool00004ooooool00?oo003oool000Ko
003o00Goooooo`00ool00?oo003oooooo`05o`00o`03ool00?l00?oo003o00?o003o1ooo00000ooo
ooooo`00ool00004o`00o`03ool00?l00?oo003o00;oo`000_l00?l4ool000;ooooo1Ooo00000ooo
ooooo`00ool00005ool00003ooooool00?oo003o00_oo`0000Coooooool00?oo003ooooo1?l00?l4
ooooo`;o003o0_ooool4ool000?ooooo1?oo0002o`00o`Kooooo0_oo0002ooooo`Coo`0000?ooooo
ool00?oo00002_ooool2ool00004oooooooo003oo`00ool000?ooooo1?l00?l01?oo003oooooool0
0?oo0002ooooo`;o003o0_oo00001?ooooooo`00ool00?oo0004ooooo`7o00000Oooool00003o`00
0?oooooooooo00Oooooo0_oo0006ooooo`?oo`000_l00?l01?oo003oooooooooooooool2ool00003
ooooool00?oo003o00Wooooo0_oo0005ooooo`;oo`001oooool2ool00003oooooooo003oo`0000;o
003o00?oooooo`00ool00?l01?ooool2o`00o`03ool00?l00?oo003o00;ooooo00?oo`00o`00ool0
0?l00_oo00000oooooooo`00ool00004ool000?ooooo00?oo`00o`00ool00?l00_oo00001?oooooo
o`00o`00ool00?l2ool000Co003o00?oo`00o`00ool00?l00ol00?l00oooooooo`00ool00002oooo
o`?o003o0_oo0002o`00o`04ooooool00?oo003oooooo`Ko003o00?oo`00o`00ool00?l00_oo0004
o`00o`;oo`000_l00?l3ool000;o003o00?oo`00o`00ool00?l00ooo0002o`00o`Ooo`0000?ooooo
ool00?oo00001?oo00000ooooooo003oo`00o`06ool00003ooooool00?oo003o00_oo`001?ooool4
ool000Cooooo0_l00?l2ooooo`;o003o0_oo0003ooooo`Coo`003Oooool2ool000Gooooo0_oo0005
ooooo`;oo`000oooool2ool000Cooooo0ol00?l3ooooo`;oo`0000Coooooo`00ool00?oooooo0_oo
00001?ooooooo`00ool00?oo0004ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo0_oo
0007ooooo`?oo`0000?oooooool00?oo00000_l00?l01?oo003oooooooooooooool2o`00oa_ooooo
1?oo0003ooooo`;oo`000oooool2o`00o`;ooooo0_oo00001?ooooooo`00o`00ool00?l3ooooo`;o
003o1oooool2ool000Cooooo00?oo`00o`00ool00?l00_oo0004ooooo`;oo`001?l00?l00ooo003o
ooooooooo`05o`00o`?oo`000_l00?l2ool00003oooooooo003oo`0000;o003o0_oo00000ooooooo
003oo`00o`02ool000Go003o00?oo`00o`00ool00?l00_oo0003o`00o`03ool00?oooooooooo00;o
o`000oooool4ool00004oooooooo003oo`00ooooo`;o003o1?oo00000ooooooo003oo`00o`03oooo
o`;oo`000oooool3ool00004oooooooo003oo`00ooooo`;oo`0000?oooooool00?oo00001_ooool2
ool000Oooooo0ol00?l2ooooo`;o003o2?ooool2ool000oooooo1?oo00000oooooooo`00ool00002
ool000Sooooo0_oo0008ooooo`;o003o0_oo0006ooooo`;o003o0Oooool1o`00007ooooo00000ol0
003oooooooooo`06ooooo`;oo`003Oooool2o`00o`03ool00?oooooooooo00Wooooo0_oo000;oooo
o`Coo`001?ooool4ool00003oooooooo003oo`0000;oo`0000Coooooool00?oo003oo`000oooool2
ool00003oooooooo003oo`0000Coo`000_l00?l5ooooo`;oo`000oooool2ool000Cooooo1?l00?l4
ool000;ooooo0_l00?l3ool000;o003o1?ooool2ool000;o003o00Goo`00ooooool00?oo003ooooo
o`05ool000Ko003o00Coooooo`00ool00?ooo`001ol00?l01?oo003oooooooooooooool3ool00003
oooooooo003oo`0000?oo`000oooool2o`00o`;oo`000_l00?l00oooooooo`00ool00002o`00o`04
oooooooo003oo`00ooooo`;oo`001_ooool2ool000;ooooo0_oo0008ooooo`Goo`000_ooool2o`00
o`;ooooo00?oo`00o`00ool00?l00oooool2ool000?ooooo0_oo00000oooooooo`00ool00004oooo
o`;oo`000oooool:ool000[ooooo1?oo0006ooooo`Coo`001_ooool2o`00o`7ooooo0Ol00001oooo
o`0000?o0000ooooooooool02oooool2ool000;o003o2Oooool2ool000Wooooo0_oo00000ooooooo
o`00ool00002ool000Kooooo1?oo0009ooooo`;oo`000oooool4ool000Kooooo0_l00?l5ool000Go
oooo1ooo00001?ooooooo`00ool00?ooool4o`00o`?oo`000_l00?l01?oo003o003oo`00oooo0004
o`00o`;ooooo0_oo00000oooooooo`00ool00003ool000;o003o0oooool3ool000Oo003o0_ooool6
o`00o`;oo`000oooool2o`00o`04ool00?l00?oo003oo`00o`Coo`000oooool2o`00o`;oo`000_l0
0?l00oooooooo`00ool00002o`00o`04ool00?ooooooooooooooo`?oo`001Oooool2ool000Gooooo
0_l00?l01?oooooo003oo`00ooooool6ool000Kooooo0_oo0004ooooo`Coo`001?ooool2ool000Co
oooo0_oo0003ooooo`_oo`002oooool2ool000Kooooo0_oo00000oooooooo`00ool00008ooooo`7o
00000Oooool00003o`000?oooooooooo00_ooooo0_oo0002o`00o`;oo`0000?oooooool00?oo0000
1?ooool4ool000;ooooo0ooo0005ooooo`Coo`000_l00?l:ooooo`;oo`002Oooool2o`00o`?oo`00
0_ooool2ool000;ooooo0_l00?l5ool000?ooooo0_oo00000oooooooo`00ool00004ool00003oooo
oooo003oo`0000;ooooo0_l00?l4ool000;o003o00Coo`00o`00ool00?ooo`000_l00?l00ooo003o
ooooool00003ool00004oooooooo003oo`00ool000?o003o00?oo`00o`00ool00?l00_oo0004o`00
o`03ool00?l00?oo003o00?o003o00?oo`00o`00ool00?l01_l00?l2ooooo`?o003o00Coooooo`00
ool00?oo003o1?oo00000oooooooo`00ool00002o`00o`?oo`0000Coooooool00?oo003ooooo0ooo
00001?ooooooo`00o`00ool00?l2ool000;ooooo0_l00?l01?oo003oooooool00?oo0004ooooo`;o
003o00?oo`00o`00ool00?l00ooo0008ooooo`;oo`0000Coooooool00?oo003oo`001?ooool2ool0
00_ooooo0_oo000;ooooo`Coo`001Oooool2ool000gooooo0_l00?l8ooooo`7o00000Oooool00003
o`000?oooooooooo00gooooo1?oo00000oooooooo`00ool00006ooooo`;oo`000_ooool3ool00004
oooooooo003oo`00ool000Gooooo0_l00?l:ooooo`;oo`001Oooool4ool000;o003o0_ooool2ool0
0003oooooooo003oo`0000Gooooo0_oo0004ooooo`;o003o2_oo0003ooooo`;oo`0000?oooooool0
0?oo00001?ooool2o`00o`Gooooo0_oo0003ooooo`?oo`000ol00?l00ooo003o003oo`00o`02ool0
00?o003o0_oo0005o`00o`03ool00?oooooo003o00[o003o00?oo`00o`00ool00?l00ooo00001?oo
ooooo`00ool00?ooool4ool000Cooooo0_oo00001_ooooooo`00ool00?oo003oooooool000;o003o
0_oo0002ooooo`;o003o1?oo0005ooooo`Goo`001_ooool2ool000;ooooo0_oo00001?ooooooo`00
ool00?oo000;ooooo`Coo`000_ooool2ool000gooooo0_oo0005ooooo`?oo`000_l00?l:ooooo`;o
003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`;oo`000_ooool4ool000cooooo
0_l00?l2ool000[ooooo0ooo0008ooooo`03ool00?l00?oo003o00Coo`000_ooool4ool000Wooooo
0_l00?l3ooooo`;o003o0ooo00000oooooooo`00ool00002ooooo`;oo`000_ooool3ool000;ooooo
0_oo0002ooooo`;oo`0000?oooooool00?oo00001Ooo0003ooooo`;o003o1?oo00001Ooooooo003o
o`00oooo003ooooo00;o003o1?oo0004o`00o`03ool00?l00?oo003o00Co003o0_ooool2o`00o`?o
o`000_l00?l3ool000?ooooo0_oo00000oooooooo`00ool00005ooooo`;o003o0_oo0003ooooo`Co
o`000oooool5ool000Sooooo0_oo0005ooooo`?oo`0000?oooooool00?oo00003Oooool2ool00003
oooooooo003oo`0000;oo`002?ooool2ool0013ooooo00?oo`00o`00ool00?l02Oooool2ool000Wo
oooo0Ol00001ooooo`0000?o0000ooooooooool04Oooool4ool000Cooooo0_oo00000ooooooo003o
o`00o`03ooooo`?o003o00?oooooool00?oo00001_ooool2ool000;o003o00?oo`00ooooooooool0
1?ooool2o`00o`03ool00?l00?oo003o00;ooooo0_oo0002ooooo`Goo`002?ooool2o`00o`Cooooo
1?oo0002o`00o`03ool00?oooooooooo00;ooooo0_l00?l4ool000;o003o00?oo`00ooooooooool0
1?oo0002o`00o`;oo`000_l00?l00oooooooo`00ool00002o`00o`;ooooo0_l00?l01?oo003o003o
o`00oooo0003o`00o`?ooooo1Ol00?l00ooo003o003oo`00o`02ool000;o003o0_oo0005o`00o`03
oooooooo003oo`0000Gooooo1Ooo0002ooooo`;oo`0000?oooooo`00ool00?l00_oo0002ooooo`?o
o`001_ooool3ool000Wooooo0_oo0002ooooo`Goo`000_ooool2ool000Oooooo0_oo0004ooooo`;o
o`000oooool2ool000Kooooo1?oo000>ooooo`;oo`001oooool2o`00o`;ooooo0ooo0009ooooo`7o
00000Oooool00003o`000?oooooooooo00gooooo0_oo0004ooooo`Coo`000_ooool2ool00003oooo
ool00?oo003o00;ooooo0_oo0002o`00o`03oooooooo003oo`0000Kooooo0_oo0002o`00o`Kooooo
00Coo`00o`00ool00?oooooo0_oo0002ooooo`;oo`001?ooool2o`00o`03ool00?oooooooooo00Ko
oooo0_oo0003o`00o`05ooooool00?oo003oool00?ooool00_l00?l00ooo003oooooooooo`02oooo
o`Co003o00Coo`00o`00ool00?oo003o1ooo0002o`00o`05oooooooo003o003oo`00ooooool00ooo
0003ooooo`;o003o0_oo0005o`00o`?oo`002?l00?l2ool000;o003o0ooo0004o`00o`;ooooo00?o
o`00o`00ool00?l00oooool4ool00003oooooooo003oo`0000;oo`001?ooool2o`00o`Goo`0000Co
ooooool00?oo003ooooo1_oo0007ooooo`;oo`000_ooool4ool000Gooooo0_oo0005ooooo`;oo`00
2?ooool2ool00003oooooooo003oo`0000Cooooo0_oo000;ooooo`;oo`000oooool2ool000Oooooo
0_l00?l00ooo003oooooool00003ool00003oooooooo003oo`0000Gooooo0Ol00001ooooo`0000Co
0000oooooooo003oo`003?ooool2ool000Cooooo1?oo0005ooooo`;oo`000_ooool2o`00o`;oo`00
1Oooool2o`00o`?ooooo0_oo00000oooooooo`00ool00004ooooo`;oo`000oooool01?oo003o003o
o`00ool00?l5ooooo`;o003o0ooo0008ooooo`?o003o00Coo`00o`00ool00?ooo`000oooool2ool0
00Gooooo0_l00?l01?oooooo003oo`00ooooool5ool00003oooooooo003oo`0000;o003o0ooo0000
0oooooooo`00ool00003ool000?o003o0_ooool4o`00o`?oo`001?l00?l2ool000?o003o0_oo0002
o`00o`03ool00?oooooooooo00;o003o1?ooool01?oo003o003oo`00ooooool;ool000?ooooo00?o
o`00o`00ool00?l01Ooo00001?ooooooo`00ool00?ooool7ool000Wooooo0_oo0008ooooo`;oo`00
3?ooool2o`00o`?oo`0000?oooooool00?oo00001?ooool2ool000?ooooo0ooo0005ooooo`;oo`00
00?oooooool00?oo00002_ooool2ool000?ooooo0_oo00000oooooooo`00ool00005ooooo`7o0000
0Oooool00004o`000?ooooooo`00ool001oooooo0_l00?l7ooooo`;o003o0oooool00ooo003o003o
o`00o`02ool000Oooooo0ooo0003o`00o`Gooooo1Ooo0008ooooo`Coo`000_l00?l4ooooo`;oo`00
0oooool2o`00o`Oooooo0ooo0006o`00o`03ool00?oooooooooo00?ooooo0ooo0003o`00o`?ooooo
0ol00?l00oooooooo`00ool00002o`00o`;ooooo0_oo00000ooooooo003oo`00o`02o`00o`?oo`00
1?l00?l00ooo003oooooooooo`02ooooo`;o003o00?oooooool00?oo00000_oo00000oooooooo`00
ool00003ooooo`;oo`000_ooool2ool000gooooo1Ooo0008ooooo`?oo`000oooool2o`00o`Cooooo
0_oo000:ooooo`;o003o0_oo0005ooooo`;oo`001?ooool2o`00o`;oo`000_l00?l7ooooo`;oo`00
6Oooool1o`00007ooooo00000ol0003oooooooooo`0>ooooo`;oo`001Oooool2ool000?ooooo0_oo
0006ooooo`03ool00?l00?oo003o00Wooooo00?oo`00o`00ool00?l01oooool4ool000Wooooo0ooo
0003o`00o`Wooooo0_oo0003ooooo`;oo`000_ooool2o`00o`;ooooo1?l00?l2ooooo`;o003o1?oo
ool4o`00o`;ooooo0_l00?l00oooooooo`00ool00003ooooo`04ool00?l00?oo003oool000;o003o
00Goooooo`00ool00?oo003oooooo`02ool00003oooooooo003oo`0000Gooooo0ol00?l00ooo003o
003oo`00o`02o`00o`03oooooooo003oo`0000?oo`000oooool2ool00003oooooooo003oo`0000Ko
oooo0_oo0003ooooo`Coo`002_ooool00ooo003o003oo`00o`03ool000Kooooo0_l00?l2ool000?o
oooo0_l00?l4ooooo`;oo`002Oooool2ool000?ooooo0_oo0003ooooo`;oo`001?ooool2o`00o`;o
o`000_l00?lBooooo`;oo`001_ooool2o`00o`Cooooo0_l00?l1o`00007ooooo00000ol0003ooooo
ooooo`0>ooooo`;oo`001Oooool2ool000?ooooo0_oo0005ooooo`;oo`000_l00?l2ooooo`;oo`00
2Oooool2ool000Cooooo0ooo000=ooooo`?o003o00?oooooo`00ool00?l01_ooool2ool00003oooo
oooo003oo`0000;oo`000_ooool2o`00o`Cooooo0_l00?l2ooooo`;o003o1Oooool5ool000?o003o
0_oo0002ooooo`;oo`000_l00?l01?oo003o003oo`00oooo0003o`00o`Cooooo0_oo00001?oooooo
003oo`00oooo0002o`00o`;ooooo00?oo`00o`00ool00?l01?ooool2ool000;o003o0_ooool4o`00
o`Oooooo1ooo0002o`00o`?oo`002Oooool2o`00o`03ooooool00?oo003o00;ooooo0_oo0002oooo
o`;o003o0_ooool2ool00003oooooooo003oo`0000;o003o3Oooool2ool00003oooooooo003oo`00
00;oo`001oooool2o`00o`?oo`004_ooool2ool00003oooooooo003oo`0000?ooooo0_l00?l00ooo
oooo003oo`00o`04ooooo`;o003o0Ol00001ooooo`0000?o0000ooooooooool02_ooool2ool001Go
oooo0_oo0004ooooo`03ool00?l00?oo003o00Sooooo1?oo0004ooooo`;oo`000oooool2o`00o`Wo
oooo1?l00?l6ooooo`;oo`0000?oooooool00?oo00001?ooool2ool000Cooooo1?oo0003ooooo`;o
o`001?ooool3ool00003ooooool00?oo003o00?ooooo0_l00?l01?oo003oooooool00?oo0004o`00
o`?ooooo00Coo`00o`00ool00?oooooo1?l00?l00ooo003o003oo`00o`02o`00o`;oo`001Oooool4
o`00o`03oooooooo003o003o00Go003o1Oooool7ool000;o003o0ooo0002ooooo`;oo`002?ooool2
o`00o`;ooooo1?oo0003ooooo`?oo`000_ooool01?oo003o003oo`00ooooool2ool000Kooooo0_oo
00000oooooooo`00ool00002ooooo`;oo`002Oooool2o`00o`Cooooo0_l00?l?ooooo`;oo`0000?o
ooooool00?oo00000oooool2o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool2
ool000Oooooo0_l00?l00oooooooo`00ool00006ooooo`;o003o2?ooool2o`00o`;ooooo0_oo0005
ooooo`?oo`001?ooool2ool000?ooooo1?l00?l3ool00004oooooooo003oo`00ool000;o003o0_oo
ool2ool000;ooooo0_l00?l8ooooo`;o003o0ooo0003ooooo`06ool00?l00?oo003oo`00oooo003o
oooo0_oo0004ooooo`;oo`000_ooool2ool00003ooooool00?oo003o00;o003o00?oooooo`00ool0
0?l00_ooool5o`00o`05ooooool00?oo003oo`00ooooool00_l00?l2ool000;ooooo00?oo`00o`00
ool00?l00_oo0005ooooo`;o003o0_oo00001_ooooooo`00ool00?oo003oooooool000;o003o00?o
o`00ooooooooool00_ooool2ool000;ooooo2?oo0002ooooo`;oo`003_ooool2ool000;ooooo1Ooo
00001?ooooooo`00ool00?ooool3ool00004oooooooo003oo`00ool000;ooooo0_l00?l00ooooooo
o`00ool00007ooooo`Coo`002?ooool2o`00o`cooooo0_l00?l01?ooooooo`00ool00?ooool2ool0
00kooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool2o`00o`03oooooooo003oo`0000Ko
oooo0_l00?l;ooooo`?oo`002?ooool2o`00o`Cooooo0ooo0002ooooo`;o003o0ooo00000ooooooo
o`00ool00007ool000;ooooo0_l00?l7ooooo`?o003o00?oooooool00?oo00001?ooool3o`00o`05
ool00?ooooooo`00ool00?ooool00_oo00000oooooooo`00ool00002o`00o`?ooooo1?l00?l00ooo
oooo003oo`00o`04o`00o`04ool00?l00?oo003oooooo`;o003o00Coo`00ooooooooooooo`000_l0
0?l2ooooo`03ool00?l00?oo003o00?ooooo0_l00?l2ooooo`Coo`000_ooool2ool00003oooooooo
003oo`0000;oo`0000Coooooool00?oo003ooooo0_oo0002o`00o`?ooooo0_oo000Iooooo`;oo`00
00?oooooool00?oo00001?ooool2ool000;ooooo1?oo00001?oooooo003oo`00ooooool4ool000Go
oooo1?oo000;ooooo`;oo`001_ooool2ool00003ooooool00?oo003o00?ooooo0_l00?l?ooooo`7o
00000Oooool000;o003o1_ooool4ool002;ooooo0_oo0002ooooo`;oo`001Oooool2o`00o`Cooooo
0ooo0005ooooo`;oo`000oooool5ool000;ooooo0_oo0005ooooo`;o003o0_ooool2o`00o`03ool0
0?l00?oo003o00?ooooo0_oo0005ooooo`;oo`0000?oooooool00?oo00000oooool2o`00o`Gooooo
00?oo`00o`00ool00?l00_ooool3o`00o`;ooooo0_oo00001?oooooo003oo`00oooo0002ooooo`03
ool00?l00?oo003o00?o003o0oooool2ool000?o003o1_ooool2ool00003oooooooo003oo`0000Co
oooo1Ooo0002o`00o`Gooooo0_oo0006ooooo`;oo`000_ooool2o`00o`Gooooo0_l00?l;ooooo`;o
o`001_ooool2ool000?ooooo1Ooo0006ooooo`?oo`002oooool2ool000Kooooo0_oo0003ooooo`;o
o`0000?oooooo`00ool00?l01_ooool2ool000Oooooo0Ol00001ooooo`000_l00?l6ooooo`Coo`00
1_ooool2ool000_ooooo0_oo0009ooooo`;oo`000_ooool2ool000;ooooo0_oo0004ooooo`;oo`00
0_l00?l;ooooo`;oo`000oooool2ool000Gooooo0_oo0005ooooo`;o003o1Oooool4o`00o`03oooo
oooo003oo`0000;ooooo0_oo0002ooooo`;oo`0000?oooooool00?oo00000oooool2o`00o`05ool0
0?oooooooooooooooooo00001_l00?l00ooooooo003oo`00o`06o`00o`;oo`0000?oooooo`00ool0
0?l01Ol00?l01?oooooo003oo`00oooo0002o`00o`Kooooo1Ooo0002ooooo`?o003o00Coooooool0
0?oo003oo`000_l00?l5ooooo`;oo`001_ooool4ool000;o003o1Oooool2o`00o`03oooooooo003o
o`0000Sooooo0_oo000;ooooo`;oo`0000?oooooool00?oo00001_ooool3ool001Sooooo0_oo0009
ooooo`;oo`0000?oooooool00?oo00001?ooool1o`00007ooooo00000ol0003oooooooooo`0;oooo
o`;oo`000_ooool2ool00003oooooooo003oo`0000Sooooo0_oo0007ooooo`Coo`003?ooool2ool0
00;o003o1_ooool2o`00o`_ooooo0_oo00001Ooooooo003oo`00ooooooooo`0000;o003o1?ooool2
ool000Gooooo0ol00?l6ool000;ooooo0_oo00001?ooooooo`00ool00?ooool2ool000;o003o00?o
o`00o`00ool00?l00oooool00ooo003o003oo`00o`03ooooo`So003o00?oo`00o`00ool00?l01ol0
0?l01?oooooo003oo`00ool00?l2ool00003ooooool00?oo003o00?ooooo0ooo0002ooooo`Go003o
00Coooooool00?oo003oo`000_l00?l4ool000Gooooo0_oo0003ooooo`;oo`000_l00?l9ooooo`;o
o`000oooool2ool001?ooooo0_oo000Fooooo`;oo`003Oooool2o`00o`Sooooo0_oo0004ooooo`7o
00000Oooool00003o`000?oooooooooo00Wooooo0_l00?l2ool000;ooooo0_oo00000oooooooo`00
ool0000Aooooo`;oo`003oooool2ool000Kooooo2?l00?l6ooooo`;oo`0000Goooooo`00ool00?oo
ooooool00002o`00o`;ooooo0_l00?l2ool000Kooooo0_l00?l4ool00003ooooool00?oo003o00;o
003o1?ooool2o`00o`04ool00?l00?oo003oooooo`;o003o0_oo0004o`00o`Sooooo0_l00?l2oooo
o`Go003o0_ooool2o`00o`04ooooool00?oo003oo`00o`?oo`000_l00?l01?oo003oooooo`00ool0
0?l2ooooo`Co003o2Oooool4ool000Gooooo0_oo0002ooooo`;oo`0000?oooooo`00ool00?l02Ooo
ool2ool000?ooooo0_oo000Booooo`;o003o1oooool2ool000kooooo0_oo000=ooooo`;o003o3_oo
ool1o`00007ooooo00000ol0003oooooooooo`09ooooo`;o003o1?ooool2ool002Gooooo0_oo0006
ooooo`So003o3?ooool00ooo003o003oo`00o`02ooooo`;o003o1Oooool2ool000Sooooo1Ol00?l0
0ooo003oooooooooo`02o`00o`Cooooo1?oo0002o`00o`03ool00?oooooooooo00;ooooo0_oo0004
ooooo`;o003o00Coooooo`00ool00?oo003o1?ooool2o`00o`;ooooo0_l00?l3ool00004oooooooo
003oo`00ooooo`;o003o0_ooool2o`00o`;oo`005_ooool2ool001Sooooo0_oo000;ooooo`;o003o
1oooool2ool002[ooooo0_l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00;ooooo0_l0
0?lSooooo`;o003o3Oooool2ool000oooooo00?oo`00o`00ool00?l02Oooool2o`00o`Wooooo0_oo
0003o`00o`;ooooo0_oo00001?ooooooo`00ool00?oo0002o`00o`03ool00?oooooooooo00Coo`00
0_ooool2ool00004oooooooo003oo`00ooooo`;oo`000oooool2ool000;ooooo1?l00?l00ooooooo
003oo`00o`02ool000;ooooo0_l00?l00oooooooo`00ool00002o`00oa3ooooo0ooo000Jooooo`;o
003o0oooool2ool000_ooooo0_oo00001?oooooo003oo`00ool00?l9ooooo`;oo`003?ooool2o`00
o`cooooo0_l00?lEooooo`;o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`;o
003o5Oooool2ool000Kooooo0_l00?l4ooooo`;o003o1Oooool2o`00o`Kooooo00?oo`00o`00ool0
0?l03_ooool00ooo003o003oo`00o`09ooooo`;oo`002oooool3o`00o`;ooooo0_oo000;ooooo`;o
o`000_l00?l3ooooo`;oo`0000?oooooool00?oo00000oooool8o`00o`03oooooooo003oo`0000;o
o`0000Goooooo`00ool00?oo003oooooo`02ool000Cooooo0_l00?l<ooooo`?oo`000oooool3ool0
00;ooooo1?oo0006ooooo`;oo`001?ooool4o`00o`?ooooo0_oo0003ooooo`;o003o0oooool2ool0
00Cooooo0ol00?l9ooooo`;oo`000_ooool2ool000Sooooo0_l00?l<ooooo`;o003o6?ooool1o`00
007ooooo00000ol0003oooooooooo`0Iooooo`;oo`0000?oooooool00?oo00000oooool2o`00o`_o
oooo0_l00?l6ooooo`04ool00?l00?oo003oooooo`?oo`001oooool2o`00o`Cooooo0_l00?l2oooo
o`;oo`000_ooool2o`00o`03ool00?oooooooooo00;ooooo0_oo0002o`00o`_ooooo0_oo00000ooo
oooo003oo`00o`05ooooo`Co003o1?ooool2o`00o`Gooooo1?l00?l01Ooo003o003oo`00ool00?oo
oooo00;oo`001Ol00?l4ooooo`;o003o0_ooool2o`00oa7ooooo0_l00?l2ool000;ooooo1Ooo0005
ooooo`;oo`0000Coooooo`00ool00?oooooo0_l00?l00ooo003oooooooooo`07ooooo`;o003o0ooo
ool2ool001Cooooo0_oo000<ooooo`;o003o2Oooool2ool00003oooooooo003oo`0001Cooooo0Ol0
0001ooooo`0000?o0000ooooooooool07?ooool2ool000Oooooo0_oo000Cooooo`03ool00?l00?oo
003o00Kooooo00?oo`00o`00ool00?l01?ooool2o`00o`;ooooo0_oo00000ooooooo003oo`00o`02
o`00o`Cooooo0_oo0002o`00o`Oooooo0_l00?l01Oooooooo`00ool00?oo003ooooo00;o003o0ooo
ool4o`00o`03ool00?oooooooooo00?ooooo0_l00?l4ooooo`?o003o00?oo`00o`00ool00?l02Ol0
0?l01?oooooo003oo`00ool00?l2ooooo`;o003o2oooool2o`00o`Kooooo1?l00?l7ooooo`;oo`00
2?ooool2o`00o`;ooooo0_oo0002ooooo`;oo`000oooool2ool000gooooo0_oo00001?oooooo003o
o`00ooooool2o`00oaCooooo1?l00?l7ooooo`;oo`0000?oooooool00?oo00005?ooool1o`00007o
oooo00000ol0003oooooooooo`0Uooooo`;oo`001_ooool2o`00o`cooooo0_l00?l6ooooo`;oo`00
3?ooool4o`00o`Kooooo0_l00?l2ooooo`;oo`000oooool2o`00o`03oooooooo003oo`0000Oooooo
0_l00?l00ooo003oooooooooo`04ooooo`;oo`001?ooool9o`00o`03ooooool00?oo003o00;o003o
00?oooooo`00ool00?l00ol00?l?ooooo`;o003o1?ooool4o`00o`03ooooool00?oo003o00Sooooo
0_l00?l>ooooo`;oo`000oooool2ool000gooooo0_oo00001?oooooo003oo`00ooooool2o`00oa7o
oooo0_oo00000oooooooo`00ool00002o`00ob3ooooo0Ol00001ooooo`0000?o0000ooooooooool0
9?ooool2ool00003ooooool00?oo003o00Cooooo0_l00?l5ooooo`;o003o1oooool2ool001?ooooo
0_oo0007ooooo`;o003o0_ooool2ool000?ooooo0_l00?l00oooooooo`00ool00008ooooo`;oo`00
1_ooool2ool000Cooooo0_l00?l01Ooooooo003oo`00ool00?oooooo00?o003o0_ooool2o`00o`03
ooooool00?oo003o00;o003o0oooool2o`00oa7ooooo0_l00?l3ooooo`;o003o1Oooool2o`00o`03
ooooool00?oo003o00?ooooo0_l00?l00ooooooo003oo`00o`04ooooo`;oo`005?ooool2ool001;o
oooo0_l00?l3ooooo`;oo`0000?oooooool00?oo00002_ooool2ool00003ooooool00?oo003o01?o
oooo0Ol00001ooooo`0000?o0000ooooooooool09?ooool2ool00003ooooool00?oo003o00_ooooo
0_l00?l4ooooo`;o003o00?oooooool00?oo00004oooool2ool000Oooooo0_l00?l2ooooo`Co003o
00?oooooo`00ool00?l03Oooool2o`00o`03oooooooo003oo`0000Co003o00?oooooo`00ool00?l0
0oooool2o`00o`;ooooo1ol00?l00ooooooo003oo`00o`02o`00o`?ooooo0_l00?l@ooooo`;oo`00
2oooool2o`00o`Kooooo0_l00?l00ooooooo003oo`00o`04ooooo`;oo`001_ooool2ool001Gooooo
0_oo0009ooooo`;o003o4_ooool2ool00003ooooool00?oo003o01?ooooo0Ol00001ooooo`0000?o
0000ooooooooool01_ooool2ool000Cooooo0_oo000Dooooo`;o003o4?ooool2ool000Cooooo0_l0
0?lCooooo`;o003o1oooool2o`00o`05ooooool00?oo003oool00?ooool01?l00?l?ooooo`?o003o
0ooo0004o`00o`04ooooool00?oo003oo`00o`;oo`000oooool3o`00o`03ooooool00?oo003o00;o
003o00?oooooo`00ool00?l00_l00?l5ooooo`;o003o0oooool2o`00o`Wooooo0_oo000Cooooo`;o
o`001?ooool2o`00o`Wooooo0_oo000Eooooo`;oo`005_ooool2o`00oagooooo0Ol00001ooooo`00
00?o0000ooooooooool01_ooool2ool000Cooooo0_oo000Dooooo`;o003o:oooool2o`00o`03oooo
ool00?oo003o00Cooooo0_l00?l2ooooo`?oo`001?ooool2o`00o`Gooooo0_l00?l6ooooo`;o003o
0_oo0004ooooo`;oo`0000?oooooo`00ool00?l00ol00?l3ooooo`;o003o00?oooooo`00ool00?l0
0ol00?l00ooooooo003oo`00o`07ooooo`;o003o00?oo`00ooooooooool00_l00?l01?oooooo003o
o`00ooooool2ool000Gooooo0_oo0003ooooo`;oo`003?ooool2ool000Cooooo0_l00?lJooooo`;o
003o5oooool2ool000?ooooo0_l00?l7ooooo`;o003o5?ooool1o`00007ooooo00000ol0003ooooo
ooooo`1;ooooo`;oo`001Oooool2o`00o`Oooooo1?oo0004ooooo`;o003o1Oooool2o`00oa;ooooo
1?l00?l6ooooo`Go003o00?oooooo`00ool00?l00oooool2o`00o`?ooooo0_oo0005ooooo`;o003o
00?oooooool00?oo00001?ooool3ool000?ooooo0_oo000@ooooo`;o003o7?ooool2o`00oaOooooo
0ooo000;ooooo`;o003o4Oooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool03ooo
ool2o`00obWooooo0_l00?l4ooooo`;o003o2Oooool2ool000kooooo0_oo0006ooooo`;o003o6?oo
ool5o`00o`03ool00?oooooooooo00?ooooo1Ol00?l00ooooooo003oo`00o`02ool00003ooooool0
0?oo003o00Wooooo0_oo0007ooooo`;o003o00?oo`00ooooooooool05?ooool2o`00o`Kooooo0_l0
0?lQooooo`;o003o2oooool2ool001kooooo0_l00?l1ooooo`7o00000Oooool00003o`000?oooooo
oooo00oooooo0_l00?lUooooo`;o003o0_ooool2o`00o`Cooooo0_l00?lEooooo`;oo`002_ooool2
o`00o`kooooo0_oo0004ooooo`;o003o0_ooool5o`00o`03ool00?oooooooooo00Gooooo1_l00?l0
0ooo003o003oo`00o`03ooooo`;o003o1_ooool2o`00o`Gooooo0_oo0002o`00o`[ooooo0_l00?l6
ooooo`;oo`002oooool2o`00o`?ooooo0_oo000Looooo`;o003o;_ooool1o`00007ooooo00000ol0
003oooooooooo`0Jooooo`;o003o5_ooool2o`00o`;ooooo0_l00?l=ooooo`;o003o4?ooool2ool0
00_ooooo0_l00?l3ool000[ooooo0_oo0004ooooo`;o003o0oooool4o`00o`03ooooool00?oo003o
00?o003o00?oooooo`00ool00?l01Ol00?l00ooooooo003oo`00o`03ooooo`;o003o1?ooool4o`00
o`Gooooo0ooo0002o`00o`Oooooo1?l00?l6ooooo`Coo`003_ooool2ool004cooooo0Ol00001oooo
o`0000?o0000ooooooooool06_ooool2o`00oaKooooo0ol00?l;ooooo`;o003o0oooool2o`00o`03
oooooooo003oo`0000cooooo0_l00?l4ooooo`Co003o1?ooool2o`00o`;oo`000_l00?l8ooooo`;o
003o2_ooool4o`00o`03ooooool00?oo003o00?o003o00?oooooo`00ool00?l01Ol00?l00ooooooo
003oo`00o`06ooooo`;o003o00?oooooo`00ool00?l01oooool3ool000;o003o1?ooool2o`00o`04
ooooool00?oo003oo`00o`Sooooo0ooo000Dooooo`;oo`00:_ooool2ool001[ooooo0Ol00001oooo
o`0000?o0000ooooooooool04_ooool2o`00oaWooooo0_oo0004ooooo`;o003o2oooool2o`00o`?o
oooo0_l00?l00oooooooo`00ool0000<ooooo`;o003o1?ooool4o`00o`Sooooo0_l00?l8ooooo`Co
003o00?oooooo`00ool00?l01oooool3o`00o`?ooooo0ol00?l2ooooo`;o003o00?oooooo`00ool0
0?l02Oooool3o`00oa7ooooo0ol00?lSooooo`;oo`002_ooool2ool001kooooo0_oo0007ooooo`;o
o`001_ooool2o`00o`Wooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool2ool000Cooooo
0_oo0006ooooo`;o003o5_ooool2ool00003oooooooo003oo`0000?ooooo0_l00?lEooooo`03ool0
0?l00?oo003o013ooooo0_l00?l00ooo003oooooooooo`06ooooo`05ool00?l00?oo003oool00?oo
ool00_l00?l6ooooo`;o003o00?oooooo`00ool00?l00ol00?l2ooooo`;o003o00?oooooo`00ool0
0?l00oooool3o`00o`03ooooool00?oo003o00;ooooo0_l00?l2ool000;ooooo0ol00?l3ooooo`?o
003o4?ooool2o`00ob7ooooo0ol00?l<ooooo`;oo`009oooool2ool000Kooooo0_l00?l6ooooo`;o
003o0Oooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`;oo`001?ooool2ool000Sooooo
0_l00?lDooooo`;oo`001_ooool2o`00o`kooooo0_oo0005ooooo`03ool00?l00?oo003o00[ooooo
0_oo0003ooooo`Coo`002?ooool4ool00004ooooool00?oo003oo`00o`?ooooo0_oo0003ooooo`[o
003o1_ooool2o`00o`03ooooool00?oo003o00Cooooo00Coo`00o`00ool00?oooooo0ol00?l01?oo
003oooooooooooooool2o`00o`;ooooo0_l00?l<ooooo`;oo`001Oooool2ool001[ooooo0ol00?lO
ooooo`;o003o9?ooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool05?ooool2o`00
obCooooo0_l00?l6ooooo`;oo`001Oooool2o`00o`_ooooo0_l00?l3ooooo`;oo`001_ooool2o`00
o`Sooooo0_l00?l3ooooo`;oo`000oooool2o`00o`;ooooo0ol00?l00ooooooo003oo`00o`06oooo
o`Oo003o0oooool4o`00o`03oooooooo003oo`0000Oooooo1?l00?l6ooooo`;o003o2Oooool2ool0
00Kooooo0_l00?l8ooooo`;oo`00:_ooool2o`00oaOooooo0_l00?l>ooooo`7o00000Oooool00003
o`000?oooooooooo03[ooooo0_l00?l=ooooo`;o003o2oooool2o`00o`_ooooo0_l00?l=ooooo`;o
o`000_l00?l5ooooo`;o003o3?ooool7o`00o`03ooooool00?oo003o00Co003o00Coooooool00?l0
0?oo003o1_ooool2o`00o`Kooooo0_l00?lAooooo`;o003o2?ooool2ool004?ooooo0_l00?l3oooo
o`;oo`002Oooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`;oo`00;?ooool2o`00od3o
oooo0_l00?lCooooo`?o003o0_ooool2o`00o`03ooooool00?oo003o00;ooooo0ol00?l00ooo003o
003oo`00o`04ooooo`;o003o2?ooool2o`00ob_ooooo0_l00?lhooooo`;oo`002Oooool1o`00007o
oooo00000ol0003oooooooooo`04ooooo`;oo`00;?ooool2o`00o`_ooooo0_l00?l6ooooo`;o003o
7_ooool2o`00oa?ooooo0_l00?l01Ooooooo003oo`00ool00?oooooo00;oo`001?ooool2o`00o`Go
oooo00?oo`00o`00ool00?l00_ooool3o`00o`Oooooo0_l00?lMooooo`;o003o3Oooool2o`00o`Oo
oooo0_l00?l/ooooo`;o003o5Oooool1o`00007ooooo00000ol0003oooooooooo`0oooooo`;o003o
0_oo0004ooooo`;o003o3oooool2o`00o`;ooooo0_l00?l7ooooo`Co003o00?oooooo`00ool00?l0
0oooool2ool000?ooooo0_oo0006ooooo`;o003o00?oooooo`00ool00?l00ol00?l00ooo003ooooo
ooooo`02ool000;o003o0_ooool2o`00o`03oooooooo003oo`0000_ooooo0_l00?l4ooooo`;o003o
0oooool2o`00o`?ooooo0_l00?l3ooooo`;o003o2_ooool2o`00o`Sooooo0_oo00000oooooooo`00
ool00002o`00oa_ooooo0_oo000Hooooo`;o003o5?ooool1o`00o`7o00000Oooool00003o`000?oo
oooooooo047ooooo0_oo0003ooooo`;o003o4?ooool2o`00o`;ooooo0_l00?l7ooooo`;o003o0ooo
ool2o`00o`?ooooo0_oo0003ooooo`;oo`001_ooool2o`00o`Cooooo0ol00?l2ooooo`;oo`001_l0
0?l2ooooo`?o003o1oooool6o`00o`;ooooo0_l00?l3ooooo`;o003o0oooool2o`00o`?ooooo0_l0
0?l:ooooo`;o003o1_ooool4ool00003oooooooo003oo`0000Oooooo0_oo000Dooooo`;oo`003Ooo
ool2o`00o`Sooooo0_l00?l;ooooo`;oo`002?ooool1o`00o`7o00000Oooool00004o`000?oooooo
ooooooooo`;oo`008_ooool2ool000oooooo0_oo000>ooooo`;o003o2?ooool2o`00o`Kooooo0_l0
0?l;ooooo`Oo003o4oooool2ool00004ooooool00?oo003oo`00o`;ooooo0_l00?l2ooooo`?o003o
0oooool3o`00o`;ooooo0_l00?l3ooooo`;o003o0_ooool2o`00o`gooooo0_l00?l5ooooo`;oo`00
3oooool2ool000cooooo0_oo000Sooooo`;o003o2?ooool2o`00o`_ooooo0_oo0009ooooo`7o0000
0Oooool00004o`000?ooooooooooooooo`;oo`008_ooool2ool000oooooo0_oo0004ooooo`;o003o
4_ooool2o`00o`03ooooool00?oo003o017ooooo1?l00?lEooooo`;oo`0000Coooooo`00ool00?oo
003o0_ooool7o`00o`Sooooo0_l00?l?ooooo`;o003o00?oooooo`00ool00?l00_ooool2o`00o`Go
oooo0_oo000dooooo`;o003o9_ooool2o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
5_ooool2o`00obCooooo0_l00?lEooooo`;o003o2oooool00ooo003o003oo`00o`05ooooo`;o003o
1_ooool2ool000Wooooo0ol00?l00ooooooo003oo`00o`02ooooo`;o003o0oooool7o`00o`Cooooo
0_l00?lBooooo`;o003o00?oooooo`00ool00?l09oooool2o`00oaKooooo0ol00?lUooooo`;o003o
1_ooool1o`00007ooooo00000ol0003oooooooooo`0Fooooo`;o003o9_ooool2o`00ob3ooooo00?o
o`00o`00ool00?l01Oooool2o`00o`Kooooo0_oo00000ooooooo003oo`00o`02o`00o`Cooooo0ol0
0?l00ooooooo003oo`00o`07ooooo`Co003o00Coooooo`00ool00?oooooo0_l00?l01?oooooo003o
o`00ool00?l>ooooo`;o003o7Oooool2ool000kooooo0_l00?lGooooo`;o003o;Oooool1o`00007o
oooo00000ol0003oooooooooo`0gooooo`;o003o1Oooool2o`00o`cooooo0_oo0008ooooo`;o003o
6oooool4o`00o`03ooooool00?oo003o00Sooooo0_l00?l2ooooo`;o003o00?oooooo`00ool00?l0
1Oooool2o`00o`;ooooo0_l00?l7ooooo`;o003o1Oooool2o`00o`Sooooo0_l00?l3ooooo`Coo`00
3?ooool2ool002oooooo0_l00?lRooooo`;o003o0Oooool1o`00007ooooo00000ol0003ooooooooo
o`0<ooooo`;oo`0000?oooooo`00ool00?l09_ooool2o`00oa?ooooo0_oo0008ooooo`Co003o6Ooo
ool2o`00o`?ooooo0_l00?l3ooooo`;o003o00?oooooo`00ool00?l00_l00?l2ooooo`;o003o00?o
ooooo`00ool00?l02Oooool4o`00o`Gooooo0_l00?l5ooooo`;o003o2?ooool2o`00o`?ooooo1?oo
000mooooo`;o003o8_ooool2o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool2
ool00003ooooool00?oo003o01Cooooo0_l00?l4ooooo`;o003o6?ooool2o`00oa7ooooo0_l00?l>
ooooo`;oo`000_l00?l7ooooo`;o003o0oooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`02
o`00o`?ooooo1?l00?l;ooooo`?o003o2oooool2o`00o`gooooo0_oo000Tooooo`;o003o00?oo`00
ooooooooool01_ooool2o`00ocGooooo0Ol00001ooooo`0000?o0000ooooooooool08?ooool3ool0
00Co003o1?ooool2o`00o`03oooooooo003oo`0000;o003o4oooool2o`00o`Cooooo0_l00?l00ooo
oooo003oo`00o`0?ooooo`?o003o1_ooool4o`00o`Cooooo0_l00?l00ooooooo003oo`00o`02o`00
o`[ooooo0_l00?l4ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l5ooooo`;o003o3oooool2o`00
oboooooo0_l00?l00ooo003oooooooooo`02ooooo`;o003o0_ooool2o`00ob7ooooo0_l00?lBoooo
o`7o00000Oooool00003o`000?oooooooooo01;ooooo0_l00?l<ooooo`?oo`001?l00?l7ooooo`;o
o`000_l00?lIooooo`;o003o00Coooooo`00ool00?oo003o3_ooool3o`00o`Kooooo0_l00?l6oooo
o`;o003o0_ooool01?oo003o003oo`00ooooool2o`00o`;oo`000oooool5o`00o`?ooooo0_l00?l3
ooooo`;o003o00Goooooo`00ool00?oo003oooooo`02o`00o`Gooooo0_l00?l3ooooo`;o003o1ooo
ool2o`00o`Cooooo0_oo000`ooooo`;o003o9Oooool2o`00o`03ooooool00?oo003o00oooooo0Ol0
0001ooooo`0000?o0000ooooooooool04_ooool2o`00o`;ooooo0_l00?l8ooooo`;oo`009oooool2
o`00o`Cooooo0_l00?lMooooo`;o003o2?ooool2o`00o`;oo`0000?oooooool00?oo00000_l00?l0
0ooooooo003oo`00o`05ooooo`;oo`0000Coooooo`00ool00?oooooo0ol00?l00ooooooo003oo`00
o`05ooooo`Co003o00?oooooo`00ool00?l03Oooool2ool005[ooooo0_l00?l?ooooo`7o00000Ooo
ool00003o`000?oooooooooo01Cooooo0_oo0002o`00o`Sooooo0_oo000Uooooo`;oo`000_l00?l?
ooooo`;oo`001Oooool2o`00o`_ooooo0_l00?l3ooooo`?o003o00?oooooo`00ool00?l01?ooool2
ool000?ooooo0_l00?l5ooooo`;oo`0000?oooooo`00ool00?l00_ooool2o`00o`;ooooo0_l00?l6
ooooo`;o003o00Coooooo`00ool00?ooo`000_ooool2o`00o`?ooooo0_l00?l9ooooo`;o003o8ooo
ool3o`00ocoooooo0Ol00001ooooo`0000?o0000ooooooooool02Oooool2o`00o`Wooooo0_oo0002
o`00o`kooooo0_l00?l<ooooo`;o003o4?ooool2o`00o`03ool00?oooooooooo00cooooo0ol00?l2
ool000Gooooo0_l00?l@ooooo`?o003o00?oooooo`00ool00?l02?ooool2o`00o`?ooooo0_l00?l5
ooooo`Ko003o00?oooooo`00ool00?l01_ooool2o`00o`04ooooool00?oo003oool000;ooooo0_l0
0?l3ooooo`;o003o2Oooool2o`00o`;ooooo0_l00?lOooooo`?o003o?oooool1o`00007ooooo0000
0ol0003oooooooooo`09ooooo`;o003o2oooool2o`00o`kooooo0_l00?l<ooooo`?o003o1Oooool2
o`00o`Sooooo0_l00?l;ooooo`;o003o0_ooool3o`00o`Oooooo0_l00?l6ooooo`;o003o1Oooool2
o`00o`Oooooo0_l00?l6ooooo`;o003o0oooool2o`00o`?ooooo1Ol00?l01?oooooo003oo`00oooo
ool2o`00o`Wooooo0_l00?lGooooo`;o003o1oooool2o`00oaCooooo0_l00?lEooooo`;o003o:ooo
ool1o`00007ooooo00000ol0003oooooooooo`0eooooo`;o003o1Oooool2o`00o`03ooooool00?oo
003o01;ooooo0_l00?l9ooooo`;o003o2Oooool2o`00o`Gooooo0_l00?l6ooooo`?o003o1oooool2
o`00o`Cooooo1_l00?l00ooooooo003oo`00o`05o`00o`Wooooo0_l00?lCooooo`;o003o2oooool2
o`00oaCooooo0_l00?lEooooo`;o003o:_ooool1o`00o`7o00000Oooool00003o`000?oooooooooo
01Wooooo0_oo0003ooooo`;o003o2oooool2o`00oa;ooooo0_l00?l6ooooo`;o003o0oooool2o`00
oa3ooooo1?l00?lFooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`Cooooo0ol00?l01?oo
oooo003oo`00ooooool5o`00ob3ooooo0_l00?mTooooo`7o003o0Ol00001ooooo`0000?o0000oooo
ooooool06Oooool2ool000?ooooo0_l00?l;ooooo`;o003o6_ooool2o`00o`?ooooo0_l00?l2oooo
o`;oo`003_ooool2o`00o`?ooooo0_l00?l00ooooooo003oo`00o`08ooooo`;o003o1oooool4o`00
o`;ooooo0ol00?l5ooooo`;o003o1_ooool2o`00o`gooooo1?l00?lVooooo`;o003o3_ooool2o`00
ocGooooo0_oo0002ooooo`;o003o1?ooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`;o
003o>Oooool2o`00o`?ooooo0_oo0005ooooo`;o003o3?ooool2o`00o`03ooooool00?oo003o00;o
003o1_ooool2o`00o`?ooooo0_l00?l3ooooo`?o003o0_ooool3o`00o`03ooooool00?oo003o00Wo
oooo0_l00?l>ooooo`Co003o00?oooooo`00ool00?l03_ooool2o`00o`gooooo0_l00?l4ooooo`;o
003o3_ooool4o`00oc?ooooo0_oo0002ooooo`;o003o1?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0@ooooo`;o003o>Oooool2o`00o`[ooooo0_l00?l<ooooo`;o003o0oooool2o`00o`_ooooo
0_l00?l7ooooo`;oo`000_l00?l00ooooooo003oo`00o`03ooooo`;o003o1?ooool3o`00o`kooooo
0ol00?l00ooooooo003oo`00o`0>ooooo`;o003o3Oooool2o`00oaKooooo0_l00?lmooooo`7o0000
0Oooool00003o`000?oooooooooo02cooooo0_l00?lHooooo`;o003o7Oooool2o`00o`Sooooo0_l0
0?l3ooooo`?o003o2Oooool2ool000?ooooo0ol00?l2ooooo`Go003o00Coooooo`00ool00?oo003o
1_ooool2o`00o`Kooooo1?l00?lPooooo`;oo`007oooool2o`00oc?ooooo0Ol00001ooooo`0000?o
0000ooooooooool0;?ooool2o`00oaSooooo0_l00?lMooooo`;o003o2?ooool2o`00o`?ooooo0ol0
0?l>ooooo`?o003o1?ooool3o`00o`04ooooool00?oo003oo`00o`Kooooo0_l00?l8ooooo`;o003o
1?ooool2o`00oa[ooooo0_oo000Oooooo`;o003o<oooool1o`00007ooooo00000ol0003ooooooooo
o`0Aooooo`;o003o6oooool2o`00o`oooooo0_l00?lEooooo`;o003o3Oooool2o`00o`gooooo0_l0
0?l7ooooo`;o003o0_ooool2o`00o`kooooo1_l00?lBooooo`;o003o8_ooool2o`00ob7ooooo0_l0
0?lYooooo`7o00000Oooool00003o`000?oooooooooo017ooooo0_l00?lKooooo`;o003o1Oooool2
o`00o`Sooooo0_l00?l9ooooo`;o003o2?ooool4o`00oa_ooooo0_l00?l00ooooooo003oo`00o`03
ooooo`Go003o00?oooooo`00ool00?l00_ooool5o`00o`Oooooo1_l00?l6ooooo`;o003o2oooool4
o`00oa3ooooo0_l00?l=ooooo`;o003o8Oooool2o`00obWooooo0Ol00001ooooo`0000?o0000oooo
ooooool0;Oooool2o`00o`Kooooo0_l00?l00ooooooo003oo`00o`0@ooooo`;o003o2?ooool2o`00
o`oooooo0_l00?l00ooooooo003oo`00o`09ooooo`;o003o00?oooooo`00ool00?l00_l00?l00ooo
oooo003oo`00o`04o`00o`;ooooo2Ol00?l00ooooooo003oo`00o`02ooooo`;o003o0_ooool2o`00
o`Kooooo0_l00?l;ooooo`Co003o4?ooool2o`00obSooooo0_oo000aooooo`7o00000Oooool00003
o`000?oooooooooo02gooooo0ol00?l2ooooo`;o003o1?ooool2o`00o`Sooooo0_l00?l=ooooo`;o
003o4_ooool2o`00o`03ooooool00?oo003o00kooooo0_l00?l01Ooooooo003oo`00ool00?oooooo
00;o003o0_ooool2o`00o`Cooooo0ol00?l00ooooooo003oo`00o`02ooooo`?o003o3_ooool2o`00
o`Wooooo0_l00?liooooo`;oo`00<Oooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`Ko
003o1_ooool2o`00o`Cooooo1?l00?l2ooooo`;o003o2Oooool2o`00oa_ooooo0_l00?l2ooooo`;o
003o4Oooool2o`00o`03ooooool00?oo003o00;o003o0oooool9o`00o`03ooooool00?oo003o00Oo
oooo0_l00?l00ooooooo003oo`00o`06ooooo`;o003o0_ooool2o`00oaGooooo0_l00?mAooooo`7o
00000Oooool00003o`000?oooooooooo033ooooo0_l00?l8ooooo`;o003o1?ooool2o`00o`Cooooo
0_l00?lVooooo`?o003o00?oooooo`00ool00?l00_ooool2o`00o`Wooooo0_l00?l00ooooooo003o
o`00o`06o`00o`?ooooo0ol00?l00ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00[ooooo
0_l00?l:ooooo`;o003o5Oooool2o`00obSooooo0_l00?l:ooooo`;o003o2?ooool2o`00oa7ooooo
0Ol00001ooooo`0000?o0000ooooooooool00oooool2ool003_ooooo0_l00?lDooooo`;o003o5ooo
ool2o`00o`?ooooo1?l00?l2ooooo`Co003o0oooool2o`00o`03ooooool00?oo003o00;o003o2Ooo
ool2o`00o`Wooooo0_l00?mDooooo`;o003o2_ooool2o`00o`Sooooo0_l00?l6ooooo`;o003o00?o
ooooo`00ool00?l01_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`;oo`009oooool2
o`00oa;ooooo0_l00?l4ooooo`;o003o3_ooool2o`00oa;ooooo0_l00?l5ooooo`;o003o00?ooooo
o`00ool00?l02?l00?l7ooooo`;o003o0_ooool4o`00o`Cooooo0_l00?l9ooooo`Co003o5?ooool2
o`00oaKooooo0_l00?l;ooooo`;o003o=Oooool2o`00o`03ooooool00?oo003o00Kooooo0Ol00001
ooooo`0000?o0000ooooooooool07oooool2o`00o`_ooooo0_l00?lHooooo`;o003o2_ooool2o`00
oaKooooo0_l00?l00ooooooo003oo`00o`02ooooo`;o003o1Oooool2o`00o`Kooooo0_l00?l3oooo
o`;o003o0_ooool6o`00o`;ooooo0_l00?l4ooooo`;o003o1Oooool2o`00oaCooooo0_l00?lFoooo
o`;o003o2oooool2o`00oaSooooo0_l00?l00ooooooo003oo`00o`0Sooooo`7o00000Oooool00003
o`000?oooooooooo01oooooo0_l00?laooooo`Co003o2?ooool2o`00o`gooooo0_l00?lAooooo`;o
003o2_ooool3o`00o`Sooooo0_l00?lBooooo`;o003oA_ooool2o`00o`03ooooool00?oo003o02?o
oooo0Ol00001ooooo`0000?o0000ooooooooool07oooool2o`00oa;ooooo0_l00?lNooooo`?o003o
2?ooool2o`00o`Cooooo0_l00?l6ooooo`;o003o4?ooool4o`00o`Cooooo0_l00?l00ooooooo003o
o`00o`04o`00o`Sooooo0_l00?lAooooo`?o003o@?ooool2o`00oaSooooo0_oo0009ooooo`;o003o
1oooool1o`00007ooooo00000ol0003oooooooooo`0cooooo`;o003o1Oooool2o`00oa7ooooo0_l0
0?lEooooo`;o003o1_ooool2o`00o`Cooooo2?l00?l01?oooooo003oo`00ooooool7o`00o`04oooo
ool00?oo003oooooo`?o003o00Coooooo`00ool00?oooooo0_l00?l?ooooo`;o003o1?ooool2o`00
o`03ooooool00?oo003o013ooooo0_l00?l_ooooo`;o003o6?ooool2ool000Wooooo0_l00?l7oooo
o`7o00000Oooool00003o`000?oooooooooo03[ooooo0ol00?l00ooooooo003oo`00o`0=ooooo`;o
003o5Oooool2o`00o`cooooo2?l00?l00ooooooo003oo`00o`05ooooo`?o003o0oooool6o`00o`;o
oooo0_l00?l2ooooo`;o003o2_ooool3o`00o`Cooooo0_l00?lCooooo`;o003o;oooool2o`00obSo
oooo0_l00?l2ooooo`7o00000Oooool00003o`000?oooooooooo03_ooooo0_l00?l00ooooooo003o
o`00o`0]ooooo`;o003o1oooool2o`00o`gooooo0_l00?l00ooooooo003oo`00o`06o`00o`Cooooo
0_l00?l8ooooo`Co003o9Oooool2o`00obCooooo0_l00?lXooooo`;o003o0_ooool1o`00007ooooo
00000ol0003oooooooooo`1;ooooo`;o003o1_ooool2o`00oaCooooo0_l00?l2ooooo`;o003o1_oo
ool7o`00o`04ooooool00?oo003oooooo`;o003o0oooool2o`00o`;ooooo0_l00?l00ooooooo003o
o`00o`02o`00o`Cooooo1Ol00?l5ooooo`;o003o7oooool2o`00o`Kooooo0_l00?mBooooo`7o0000
0Oooool00003o`000?oooooooooo02?ooooo0_l00?lHooooo`;o003o2Oooool2o`00o`03ooooool0
0?oo003o00Kooooo0_l00?l<ooooo`?o003o1Oooool2o`00o`?ooooo0_l00?l5ooooo`;o003o00?o
ooooo`00ool00?l00_l00?l01?oooooo003oo`00ooooool2o`00oa;ooooo1Ol00?l5ooooo`;o003o
7oooool2o`00ocSooooo0_l00?lPooooo`7o00000Oooool00003o`000?oooooooooo017ooooo0_l0
0?l@ooooo`;o003o3_ooool2o`00o`Sooooo0_l00?l9ooooo`;o003o2?ooool2o`00o`gooooo0ol0
0?l:ooooo`;o003o1?ooool4o`00o`[ooooo0ol00?l4ooooo`Co003o00?oooooo`00ool00?l00_oo
ool2o`00o`04ooooool00?oo003oo`00o`Kooooo0_l00?l2ooooo`;o003o3Oooool4o`00occooooo
0_l00?l6ooooo`;o003o8?ooool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`Co003o8?oo
ool2o`00o`?ooooo0_l00?lHooooo`;o003o2Oooool2o`00o`;ooooo0_l00?l=ooooo`;o003o0_oo
ool4o`00o`Gooooo1?l00?l01?oooooo003oo`00ool00?l2ooooo`Ko003o00?oooooo`00ool00?l0
0_ooool2o`00o`Wooooo1?l00?l00ooooooo003oo`00o`0=ooooo`Co003o2?ooool2o`00oc;ooooo
0_l00?lXooooo`7o00000Oooool00003o`000?oooooooooo00oooooo0_l00?lWooooo`;o003o2?oo
ool2o`00o`Gooooo0_l00?l3ooooo`;o003o3Oooool2o`00oa7ooooo0_l00?l;ooooo`Co003o00Co
ooooo`00ool00?oo003o0_ooool3o`00o`Gooooo0_l00?l<ooooo`Go003o6oooool2o`00oacooooo
0_l00?lnooooo`7o00000Oooool00003o`000?oooooooooo04;ooooo0_l00?l5ooooo`;o003o0ooo
ool2o`00o`Gooooo0_l00?lHooooo`Co003o3oooool3o`00o`Gooooo0_l00?l2ooooo`Go003o2Ooo
ool2o`00o`;ooooo0_l00?l3ooooo`;o003o=?ooool2o`00ob?ooooo0_l00?lIooooo`7o00000Ooo
ool00003o`000?oooooooooo00Wooooo0_l00?lkooooo`;o003o3Oooool2o`00oaKooooo1_l00?l=
ooooo`?o003o1Oooool5o`00o`03ooooool00?oo003o00Go003o1oooool2o`00o`Oooooo0_l00?l6
ooooo`;o003o4?ooool4o`00o`Cooooo0_l00?l?ooooo`;o003o9_ooool2o`00o`03ooooool00?oo
003o01Cooooo0_l00?l1o`00007ooooo00000ol0003oooooooooo`09ooooo`;o003o6_ooool2o`00
oaoooooo0_l00?lUooooo`;o003o2?ooool2o`00o`Oooooo1?l00?l4ooooo`Go003o00Coooooo`00
ool00?oo003o0_ooool2o`00oaSooooo0_l00?l<ooooo`;o003o0_ooool4o`00o`Cooooo0_l00?l0
0ooooooo003oo`00o`0<ooooo`;o003o6?ooool2o`00o`oooooo0_l00?l>ooooo`;o003o1?ooool2
o`00o`7o00000Oooool00003o`000?oooooooooo02Gooooo0_l00?lGooooo`;o003o6Oooool2o`00
oacooooo0_l00?l9ooooo`;o003o1_ooool2o`00o`;ooooo0ol00?l00ooooooo003oo`00o`02o`00
obGooooo0_l00?l=ooooo`;o003o3?ooool2ool001Sooooo0_l00?lOooooo`;o003o1_ooool1o`00
007ooooo00000ol0003oooooooooo`0@ooooo`;o003o;?ooool2o`00oaWooooo0_l00?l6ooooo`;o
003o4?ooool2o`00o`Cooooo1Ol00?l9ooooo`;o003o00?oooooo`00ool00?l00_ooool3o`00o`03
ooooool00?oo003o00;o003o1_ooool2o`00oaSooooo0_l00?l;ooooo`;o003oE_ooool1o`00007o
oooo00000ol0003oooooooooo`0@ooooo`;o003o8_ooool2o`00o`;ooooo0_l00?lCooooo`;o003o
4_ooool2o`00o`oooooo0ol00?l4ooooo`Go003o1oooool4o`00o`Gooooo0_l00?l<ooooo`;o003o
6?ooool2o`00o`[ooooo0ol00?lBooooo`;o003o@_ooool1o`00007ooooo00000ol0003ooooooooo
o`0dooooo`Ko003o3?ooool2o`00o`Gooooo0_l00?l00ooooooo003oo`00o`0Pooooo`;o003o1ooo
ool4o`00o`?ooooo0_l00?l01Ooooooo003oo`00ool00?oooooo00Co003o2?ooool2o`00o`[ooooo
0_l00?l7ooooo`;o003o5_ooool2o`00oa?ooooo0_l00?m2ooooo`7o00000Oooool00003o`000?oo
oooooooo03Kooooo0_l00?l>ooooo`;o003o2?ooool2o`00ob;ooooo0_l00?l5ooooo`Co003o0ooo
ool2o`00o`?ooooo1_l00?l2ooooo`So003o2_ooool2o`00o`Oooooo0_l00?lJooooo`;o003oDooo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`;o003oD?ooool2o`00o`Gooooo0_l00?l6
ooooo`;o003o0_ooool3o`00o`03ooooool00?oo003o00Go003o00?oooooo`00ool00?l01Oooool2
o`00o`Kooooo1_l00?l7ooooo`;o003o:?ooool2o`00oe?ooooo0Ol00001ooooo`0000?o0000oooo
ooooool03oooool2o`00oe3ooooo0_l00?l5ooooo`;o003o1_ooool2o`00o`03ooooool00?oo003o
00;o003o00Coooooo`00ool00?oo003o0_ooool2o`00o`03ooooool00?oo003o00Oooooo1Ol00?l>
ooooo`;o003o9?ooool2o`00obkooooo0_l00?l7ooooo`;o003o4Oooool2o`00o`_ooooo0Ol00001
ooooo`0000?o0000ooooooooool0Boooool4o`00o`Sooooo0_l00?lJooooo`?o003o0oooool2o`00
o`?ooooo0_l00?l2ooooo`;o003o1Oooool5o`00o`?ooooo0_l00?l:ooooo`;o003o0_ooool3o`00
oaCooooo0_l00?l8ooooo`;o003o1Oooool2o`00obOooooo0_l00?l7ooooo`;o003o4Oooool2o`00
o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool0A?ooool2o`00o`Gooooo1?l00?l8ooooo`?o
003o3_ooool2o`00o`[ooooo0_l00?l3ooooo`;o003o0oooool6o`00o`Gooooo0_l00?l00ooooooo
003oo`00o`03ooooo`;o003o1Oooool2o`00o`?ooooo0_l00?l2ooooo`?o003o5?ooool2o`00o`oo
oooo0_l00?lIooooo`;o003o=Oooool1o`00007ooooo00000ol0003oooooooooo`0Mooooo`;o003o
4Oooool2o`00oa;ooooo0_l00?lBooooo`;o003o3_ooool2o`00o`cooooo0_l00?l4ooooo`;o003o
00?oooooo`00ool00?l00ol00?l5ooooo`;o003o0oooool3o`00o`Cooooo0_l00?l00ooooooo003o
o`00o`0Booooo`;o003o=_ooool2o`00ocGooooo0Ol00001ooooo`0000?o0000ooooooooool07Ooo
ool2o`00oa7ooooo0_l00?lNooooo`;o003o9?ooool2o`00o`Cooooo0ol00?l3ooooo`;o003o1Ooo
ool4o`00o`04ooooool00?oo003oo`00o`Cooooo0_l00?lBooooo`;o003o00?oooooo`00ool00?l0
6oooool2o`00oe3ooooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool2o`00ocCooooo0_l0
0?lTooooo`;o003o1?ooool3o`00o`?ooooo0_l00?l4ooooo`;o003o00Coooooo`00ool00?oooooo
0_l00?l7ooooo`;o003o1?ooool2o`00o`Oooooo0_l00?l00ooooooo003oo`00o`08ooooo`;o003o
2_ooool2o`00o`Sooooo0_l00?l/ooooo`;o003o2Oooool2o`00oaOooooo0Ol00001ooooo`0000?o
0000ooooooooool05?ooool2o`00o`Cooooo0_l00?m@ooooo`;o003o2?ooool2o`00o`03ooooool0
0?oo003o00gooooo1Ol00?l5ooooo`;o003o0oooool2o`00o`Cooooo0_l00?l7ooooo`;o003o00?o
ooooo`00ool00?l02?ooool2o`00o`[ooooo0_l00?lZooooo`;o003o2_ooool2o`00o`Wooooo0_l0
0?lGooooo`7o00000Oooool00003o`000?oooooooooo01Cooooo0_l00?l[ooooo`;o003o2Oooool2
o`00o`03ooooool00?oo003o00Cooooo0_l00?l3ooooo`;o003o4?ooool4o`00o`;ooooo0_l00?l2
ooooo`;o003o00?oooooo`00ool00?l00_ooool2o`00o`Kooooo0_l00?l3ooooo`Go003o0oooool2
o`00o`?ooooo0ol00?l5ooooo`;o003o2?ooool2o`00od3ooooo0_l00?l^ooooo`7o00000Oooool0
0003o`000?oooooooooo01_ooooo0_l00?lLooooo`;o003o1?ooool4o`00o`Wooooo0_l00?l00ooo
oooo003oo`00o`04ooooo`;o003o0oooool2o`00o`Cooooo0_l00?l8ooooo`;o003o0_ooool2o`00
o`;ooooo0_l00?l2ooooo`;o003o00?oooooo`00ool00?l00_ooool2o`00o`;ooooo0_l00?l01Ooo
oooo003oo`00ool00?oooooo00Oo003o2?ooool4o`00o`Cooooo0_l00?l=ooooo`;o003oJoooool1
o`00007ooooo00000ol0003oooooooooo`0Kooooo`;o003o7?ooool2o`00o`Cooooo0_l00?l2oooo
o`;o003o6oooool2o`00o`Sooooo0_l00?l=ooooo`;o003o1_ooool2o`00o`03ooooool00?oo003o
00;ooooo1?l00?l;ooooo`Co003o4oooool2o`00oakooooo0_l00?l9ooooo`;o003o<?ooool2o`00
o`kooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool2o`00oaCooooo0_l00?lKooooo`;o
003o2?ooool2o`00o`;ooooo0_l00?l3ooooo`?o003o2oooool2o`00o`Kooooo1Ol00?l00ooooooo
003oo`00o`0;ooooo`;o003o<?ooool2o`00o`Wooooo0_l00?l`ooooo`;o003o3_ooool1o`00007o
oooo000`o`0000;o003o00?o0000o`00ool00?l0;_l00002o`00o`So00000_l00?l2o`0000;o003o
0ol00003o`00o`Ko00000_l00?l3o`0000;o003o1_l00005o`00o`03o`000?l00?oo003o00_o0000
0_l00?lIo`0000;o003oHol00001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-100.088, -100.088, 0.697479, \
0.697479}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute two-dimensional pdfs", "Subsection"],

Cell[BoxData[{
    \(\(p1 = gaussian[brick3\  // N, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(p2 = gaussian[wood3 // N, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show two-dimensional pdfs", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[p1, p2, pr, x, y, \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00480769 0.5 0.00480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.10751 .98077 m
.1007 .95611 L
.09434 .93146 L
.0932 .92683 L
.08845 .9068 L
.08297 .88215 L
.07789 .8575 L
.0732 .83284 L
.06888 .80819 L
.06854 .80614 L
.06495 .78353 L
.06138 .75888 L
.05815 .73422 L
.05526 .70957 L
.0527 .68491 L
.05046 .66026 L
.04855 .6356 L
.04696 .61095 L
.04569 .58629 L
.04473 .56164 L
.04409 .53698 L
.04389 .52486 L
.04376 .51233 L
.04373 .48767 L
.04389 .47181 L
.04402 .46302 L
.04463 .43836 L
.04554 .41371 L
.04677 .38905 L
.04832 .3644 L
.05019 .33974 L
.05238 .31509 L
.0549 .29043 L
.05775 .26578 L
.06094 .24112 L
.06447 .21647 L
.06836 .19181 L
.06854 .19071 L
.07263 .16716 L
.07728 .1425 L
.08232 .11785 L
.08776 .0932 L
.0932 .0702 L
.0936 .06854 L
.09992 .04389 L
.10669 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10751 .98077 m
.1007 .95611 L
.09434 .93146 L
.0932 .92683 L
.08845 .9068 L
.08297 .88215 L
.07789 .8575 L
.0732 .83284 L
.06888 .80819 L
.06854 .80614 L
.06495 .78353 L
.06138 .75888 L
.05815 .73422 L
.05526 .70957 L
.0527 .68491 L
.05046 .66026 L
.04855 .6356 L
.04696 .61095 L
.04569 .58629 L
.04473 .56164 L
.04409 .53698 L
.04389 .52486 L
.04376 .51233 L
.04373 .48767 L
.04389 .47181 L
.04402 .46302 L
.04463 .43836 L
.04554 .41371 L
.04677 .38905 L
.04832 .3644 L
.05019 .33974 L
.05238 .31509 L
.0549 .29043 L
.05775 .26578 L
.06094 .24112 L
.06447 .21647 L
.06836 .19181 L
.06854 .19071 L
.07263 .16716 L
.07728 .1425 L
.08232 .11785 L
.08776 .0932 L
.0932 .0702 L
.0936 .06854 L
.09992 .04389 L
.10669 .01923 L
s
.2 g
.18441 .98077 m
.17599 .95611 L
.16821 .93146 L
.16716 .92799 L
.16103 .9068 L
.1544 .88215 L
.14829 .8575 L
.14268 .83284 L
.1425 .83204 L
.13756 .80819 L
.13289 .78353 L
.12865 .75888 L
.12484 .73422 L
.12144 .70957 L
.11843 .68491 L
.11785 .67973 L
.11583 .66026 L
.11361 .6356 L
.11177 .61095 L
.11029 .58629 L
.10918 .56164 L
.10844 .53698 L
.10806 .51233 L
.10804 .48767 L
.10838 .46302 L
.10908 .43836 L
.11014 .41371 L
.11158 .38905 L
.11338 .3644 L
.11556 .33974 L
.11785 .31749 L
.11812 .31509 L
.12108 .29043 L
.12444 .26578 L
.12821 .24112 L
.13241 .21647 L
.13703 .19181 L
.14211 .16716 L
.1425 .16534 L
.14768 .1425 L
.15375 .11785 L
.16033 .0932 L
.16716 .06957 L
.16747 .06854 L
.17522 .04389 L
.18359 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18441 .98077 m
.17599 .95611 L
.16821 .93146 L
.16716 .92799 L
.16103 .9068 L
.1544 .88215 L
.14829 .8575 L
.14268 .83284 L
.1425 .83204 L
.13756 .80819 L
.13289 .78353 L
.12865 .75888 L
.12484 .73422 L
.12144 .70957 L
.11843 .68491 L
.11785 .67973 L
.11583 .66026 L
.11361 .6356 L
.11177 .61095 L
.11029 .58629 L
.10918 .56164 L
.10844 .53698 L
.10806 .51233 L
.10804 .48767 L
.10838 .46302 L
.10908 .43836 L
.11014 .41371 L
.11158 .38905 L
.11338 .3644 L
.11556 .33974 L
.11785 .31749 L
.11812 .31509 L
.12108 .29043 L
.12444 .26578 L
.12821 .24112 L
.13241 .21647 L
.13703 .19181 L
.14211 .16716 L
.1425 .16534 L
.14768 .1425 L
.15375 .11785 L
.16033 .0932 L
.16716 .06957 L
.16747 .06854 L
.17522 .04389 L
.18359 .01923 L
s
.3 g
.24573 .98077 m
.24112 .9701 L
.23536 .95611 L
.2259 .93146 L
.21724 .9068 L
.21647 .90449 L
.20934 .88215 L
.20211 .8575 L
.19551 .83284 L
.19181 .81793 L
.18951 .80819 L
.18408 .78353 L
.17917 .75888 L
.17477 .73422 L
.17086 .70957 L
.16741 .68491 L
.16716 .68296 L
.16443 .66026 L
.16189 .6356 L
.15979 .61095 L
.15811 .58629 L
.15685 .56164 L
.156 .53698 L
.15557 .51233 L
.15555 .48767 L
.15594 .46302 L
.15674 .43836 L
.15796 .41371 L
.1596 .38905 L
.16166 .3644 L
.16416 .33974 L
.1671 .31509 L
.16716 .31461 L
.1705 .29043 L
.17437 .26578 L
.17873 .24112 L
.1836 .21647 L
.18899 .19181 L
.19181 .17981 L
.19495 .16716 L
.2015 .1425 L
.20869 .11785 L
.21647 .09343 L
.21655 .0932 L
.22516 .06854 L
.23458 .04389 L
.24112 .028 L
.24491 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.24573 .98077 m
.24112 .9701 L
.23536 .95611 L
.2259 .93146 L
.21724 .9068 L
.21647 .90449 L
.20934 .88215 L
.20211 .8575 L
.19551 .83284 L
.19181 .81793 L
.18951 .80819 L
.18408 .78353 L
.17917 .75888 L
.17477 .73422 L
.17086 .70957 L
.16741 .68491 L
.16716 .68296 L
.16443 .66026 L
.16189 .6356 L
.15979 .61095 L
.15811 .58629 L
.15685 .56164 L
.156 .53698 L
.15557 .51233 L
.15555 .48767 L
.15594 .46302 L
.15674 .43836 L
.15796 .41371 L
.1596 .38905 L
.16166 .3644 L
.16416 .33974 L
.1671 .31509 L
.16716 .31461 L
.1705 .29043 L
.17437 .26578 L
.17873 .24112 L
.1836 .21647 L
.18899 .19181 L
.19181 .17981 L
.19495 .16716 L
.2015 .1425 L
.20869 .11785 L
.21647 .09343 L
.21655 .0932 L
.22516 .06854 L
.23458 .04389 L
.24112 .028 L
.24491 .01923 L
s
.4 g
.30282 .98077 m
.29043 .9577 L
.28963 .95611 L
.27785 .93146 L
.26727 .9068 L
.26578 .90312 L
.25773 .88215 L
.24911 .8575 L
.24132 .83284 L
.24112 .83219 L
.23429 .80819 L
.22796 .78353 L
.22228 .75888 L
.21721 .73422 L
.21647 .73037 L
.21272 .70957 L
.20879 .68491 L
.20539 .66026 L
.2025 .6356 L
.20011 .61095 L
.19821 .58629 L
.19679 .56164 L
.19583 .53698 L
.19535 .51233 L
.19533 .48767 L
.19577 .46302 L
.19668 .43836 L
.19806 .41371 L
.19993 .38905 L
.20227 .3644 L
.20512 .33974 L
.20848 .31509 L
.21237 .29043 L
.21647 .26756 L
.21681 .26578 L
.22184 .24112 L
.22748 .21647 L
.23376 .19181 L
.24075 .16716 L
.24112 .16591 L
.2485 .1425 L
.25708 .11785 L
.26578 .09517 L
.26658 .0932 L
.27712 .06854 L
.28886 .04389 L
.29043 .04077 L
.302 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30282 .98077 m
.29043 .9577 L
.28963 .95611 L
.27785 .93146 L
.26727 .9068 L
.26578 .90312 L
.25773 .88215 L
.24911 .8575 L
.24132 .83284 L
.24112 .83219 L
.23429 .80819 L
.22796 .78353 L
.22228 .75888 L
.21721 .73422 L
.21647 .73037 L
.21272 .70957 L
.20879 .68491 L
.20539 .66026 L
.2025 .6356 L
.20011 .61095 L
.19821 .58629 L
.19679 .56164 L
.19583 .53698 L
.19535 .51233 L
.19533 .48767 L
.19577 .46302 L
.19668 .43836 L
.19806 .41371 L
.19993 .38905 L
.20227 .3644 L
.20512 .33974 L
.20848 .31509 L
.21237 .29043 L
.21647 .26756 L
.21681 .26578 L
.22184 .24112 L
.22748 .21647 L
.23376 .19181 L
.24075 .16716 L
.24112 .16591 L
.2485 .1425 L
.25708 .11785 L
.26578 .09517 L
.26658 .0932 L
.27712 .06854 L
.28886 .04389 L
.29043 .04077 L
.302 .01923 L
s
.5 g
.36415 .98077 m
.34563 .95611 L
.33974 .94727 L
.32995 .93146 L
.31636 .9068 L
.31509 .90433 L
.30441 .88215 L
.29384 .8575 L
.29043 .84889 L
.28444 .83284 L
.27605 .80819 L
.26858 .78353 L
.26578 .77349 L
.26194 .75888 L
.25605 .73422 L
.25087 .70957 L
.24634 .68491 L
.24245 .66026 L
.24112 .65091 L
.23915 .6356 L
.23644 .61095 L
.23428 .58629 L
.23266 .56164 L
.23159 .53698 L
.23104 .51233 L
.23102 .48767 L
.23152 .46302 L
.23256 .43836 L
.23413 .41371 L
.23625 .38905 L
.23892 .3644 L
.24112 .3472 L
.24217 .33974 L
.24603 .31509 L
.25051 .29043 L
.25565 .26578 L
.2615 .24112 L
.26578 .2248 L
.2681 .21647 L
.27553 .19181 L
.28387 .16716 L
.29043 .14958 L
.29323 .1425 L
.30376 .11785 L
.31509 .09432 L
.31567 .0932 L
.32921 .06854 L
.33974 .05156 L
.34486 .04389 L
.36333 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.36415 .98077 m
.34563 .95611 L
.33974 .94727 L
.32995 .93146 L
.31636 .9068 L
.31509 .90433 L
.30441 .88215 L
.29384 .8575 L
.29043 .84889 L
.28444 .83284 L
.27605 .80819 L
.26858 .78353 L
.26578 .77349 L
.26194 .75888 L
.25605 .73422 L
.25087 .70957 L
.24634 .68491 L
.24245 .66026 L
.24112 .65091 L
.23915 .6356 L
.23644 .61095 L
.23428 .58629 L
.23266 .56164 L
.23159 .53698 L
.23104 .51233 L
.23102 .48767 L
.23152 .46302 L
.23256 .43836 L
.23413 .41371 L
.23625 .38905 L
.23892 .3644 L
.24112 .3472 L
.24217 .33974 L
.24603 .31509 L
.25051 .29043 L
.25565 .26578 L
.2615 .24112 L
.26578 .2248 L
.2681 .21647 L
.27553 .19181 L
.28387 .16716 L
.29043 .14958 L
.29323 .1425 L
.30376 .11785 L
.31509 .09432 L
.31567 .0932 L
.32921 .06854 L
.33974 .05156 L
.34486 .04389 L
.36333 .01923 L
Mistroke
Mfstroke
.6 g
.45996 .98077 m
.43836 .97062 L
.41671 .95611 L
.41371 .95359 L
.39046 .93146 L
.38905 .92988 L
.37036 .9068 L
.3644 .89831 L
.35396 .88215 L
.34011 .8575 L
.33974 .85679 L
.32815 .83284 L
.31776 .80819 L
.31509 .80126 L
.30866 .78353 L
.30068 .75888 L
.29369 .73422 L
.29043 .72149 L
.28759 .70957 L
.28231 .68491 L
.27779 .66026 L
.27398 .6356 L
.27085 .61095 L
.26837 .58629 L
.26653 .56164 L
.26578 .54949 L
.2653 .53698 L
.26467 .51233 L
.26465 .48767 L
.26524 .46302 L
.26578 .44856 L
.26642 .43836 L
.26823 .41371 L
.27066 .38905 L
.27375 .3644 L
.27751 .33974 L
.28199 .31509 L
.28723 .29043 L
.29043 .27698 L
.29329 .26578 L
.30024 .24112 L
.30818 .21647 L
.31509 .19739 L
.31724 .19181 L
.32759 .16716 L
.3395 .1425 L
.33974 .14204 L
.35331 .11785 L
.3644 .1007 L
.36967 .0932 L
.38905 .0693 L
.38974 .06854 L
.41371 .04577 L
.41596 .04389 L
.43836 .02893 L
.45898 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.45996 .98077 m
.43836 .97062 L
.41671 .95611 L
.41371 .95359 L
.39046 .93146 L
.38905 .92988 L
.37036 .9068 L
.3644 .89831 L
.35396 .88215 L
.34011 .8575 L
.33974 .85679 L
.32815 .83284 L
.31776 .80819 L
.31509 .80126 L
.30866 .78353 L
.30068 .75888 L
.29369 .73422 L
.29043 .72149 L
.28759 .70957 L
.28231 .68491 L
.27779 .66026 L
.27398 .6356 L
.27085 .61095 L
.26837 .58629 L
.26653 .56164 L
.26578 .54949 L
.2653 .53698 L
.26467 .51233 L
.26465 .48767 L
.26524 .46302 L
.26578 .44856 L
.26642 .43836 L
.26823 .41371 L
.27066 .38905 L
.27375 .3644 L
.27751 .33974 L
.28199 .31509 L
.28723 .29043 L
.29043 .27698 L
.29329 .26578 L
.30024 .24112 L
.30818 .21647 L
.31509 .19739 L
.31724 .19181 L
.32759 .16716 L
.3395 .1425 L
.33974 .14204 L
.35331 .11785 L
.3644 .1007 L
.36967 .0932 L
Mistroke
.38905 .0693 L
.38974 .06854 L
.41371 .04577 L
.41596 .04389 L
.43836 .02893 L
.45898 .01923 L
Mfstroke
.7 g
.46302 .08764 m
.48767 .08144 L
.51233 .08153 L
.53698 .08791 L
.55003 .0932 L
.56164 .10086 L
.58308 .11785 L
.58629 .12107 L
.60549 .1425 L
.61095 .14978 L
.62281 .16716 L
.6356 .18932 L
.63693 .19181 L
.64883 .21647 L
.65894 .24112 L
.66026 .24465 L
.66762 .26578 L
.67507 .29043 L
.68143 .31509 L
.68491 .3305 L
.68683 .33974 L
.69134 .3644 L
.69502 .38905 L
.69792 .41371 L
.70008 .43836 L
.70151 .46302 L
.70223 .48767 L
.70225 .51233 L
.70157 .53698 L
.70018 .56164 L
.69807 .58629 L
.69521 .61095 L
.69157 .6356 L
.6871 .66026 L
.68491 .67086 L
.68175 .68491 L
.67543 .70957 L
.66802 .73422 L
.66026 .75653 L
.65938 .75888 L
.64932 .78353 L
.63745 .80819 L
.6356 .81168 L
.62338 .83284 L
.61095 .85103 L
.6061 .8575 L
.58629 .87956 L
.5837 .88215 L
.56164 .89959 L
.55081 .9068 L
.53698 .91236 L
.51233 .91856 L
.48767 .91847 L
.46302 .91209 L
.44997 .9068 L
.43836 .89914 L
.41692 .88215 L
.41371 .87893 L
.39451 .8575 L
.38905 .85022 L
.37719 .83284 L
.3644 .81068 L
.36307 .80819 L
.35117 .78353 L
.34106 .75888 L
.33974 .75535 L
.33238 .73422 L
.32493 .70957 L
.31857 .68491 L
.31509 .6695 L
.31317 .66026 L
.30866 .6356 L
.30498 .61095 L
.30208 .58629 L
.29992 .56164 L
.29849 .53698 L
.29777 .51233 L
.29775 .48767 L
.29843 .46302 L
.29982 .43836 L
.30193 .41371 L
.30479 .38905 L
.30843 .3644 L
.3129 .33974 L
.31509 .32914 L
.31825 .31509 L
.32457 .29043 L
.33198 .26578 L
.33974 .24347 L
.34062 .24112 L
.35068 .21647 L
.36255 .19181 L
.3644 .18832 L
.37662 .16716 L
.38905 .14897 L
.3939 .1425 L
.41371 .12044 L
.4163 .11785 L
.43836 .10041 L
.44919 .0932 L
F
0 g
.46302 .08764 m
.48767 .08144 L
.51233 .08153 L
.53698 .08791 L
.55003 .0932 L
.56164 .10086 L
.58308 .11785 L
.58629 .12107 L
.60549 .1425 L
.61095 .14978 L
.62281 .16716 L
.6356 .18932 L
.63693 .19181 L
.64883 .21647 L
.65894 .24112 L
.66026 .24465 L
.66762 .26578 L
.67507 .29043 L
.68143 .31509 L
.68491 .3305 L
.68683 .33974 L
.69134 .3644 L
.69502 .38905 L
.69792 .41371 L
.70008 .43836 L
.70151 .46302 L
.70223 .48767 L
.70225 .51233 L
.70157 .53698 L
.70018 .56164 L
.69807 .58629 L
.69521 .61095 L
.69157 .6356 L
.6871 .66026 L
.68491 .67086 L
.68175 .68491 L
.67543 .70957 L
.66802 .73422 L
.66026 .75653 L
.65938 .75888 L
.64932 .78353 L
.63745 .80819 L
.6356 .81168 L
.62338 .83284 L
.61095 .85103 L
.6061 .8575 L
.58629 .87956 L
.5837 .88215 L
.56164 .89959 L
.55081 .9068 L
Mistroke
.53698 .91236 L
.51233 .91856 L
.48767 .91847 L
.46302 .91209 L
.44997 .9068 L
.43836 .89914 L
.41692 .88215 L
.41371 .87893 L
.39451 .8575 L
.38905 .85022 L
.37719 .83284 L
.3644 .81068 L
.36307 .80819 L
.35117 .78353 L
.34106 .75888 L
.33974 .75535 L
.33238 .73422 L
.32493 .70957 L
.31857 .68491 L
.31509 .6695 L
.31317 .66026 L
.30866 .6356 L
.30498 .61095 L
.30208 .58629 L
.29992 .56164 L
.29849 .53698 L
.29777 .51233 L
.29775 .48767 L
.29843 .46302 L
.29982 .43836 L
.30193 .41371 L
.30479 .38905 L
.30843 .3644 L
.3129 .33974 L
.31509 .32914 L
.31825 .31509 L
.32457 .29043 L
.33198 .26578 L
.33974 .24347 L
.34062 .24112 L
.35068 .21647 L
.36255 .19181 L
.3644 .18832 L
.37662 .16716 L
.38905 .14897 L
.3939 .1425 L
.41371 .12044 L
.4163 .11785 L
.43836 .10041 L
.44919 .0932 L
Mistroke
.46302 .08764 L
Mfstroke
.8 g
.46302 .15978 m
.48767 .15228 L
.51233 .15237 L
.53698 .16006 L
.55113 .16716 L
.56164 .17586 L
.57864 .19181 L
.58629 .20107 L
.59774 .21647 L
.61095 .23837 L
.61245 .24112 L
.62444 .26578 L
.63426 .29043 L
.6356 .2942 L
.64246 .31509 L
.64927 .33974 L
.65487 .3644 L
.65938 .38905 L
.66026 .39454 L
.66291 .41371 L
.66552 .43836 L
.66724 .46302 L
.66811 .48767 L
.66813 .51233 L
.66731 .53698 L
.66562 .56164 L
.66306 .58629 L
.66026 .60662 L
.65956 .61095 L
.6551 .6356 L
.64955 .66026 L
.64278 .68491 L
.6356 .70679 L
.63461 .70957 L
.62484 .73422 L
.61289 .75888 L
.61095 .76244 L
.59823 .78353 L
.58629 .79956 L
.57916 .80819 L
.56164 .82459 L
.55176 .83284 L
.53698 .84022 L
.51233 .84772 L
.48767 .84763 L
.46302 .83994 L
.44887 .83284 L
.43836 .82414 L
.42136 .80819 L
.41371 .79893 L
.40226 .78353 L
.38905 .76163 L
.38755 .75888 L
.37556 .73422 L
.36574 .70957 L
.3644 .7058 L
.35754 .68491 L
.35073 .66026 L
.34513 .6356 L
.34062 .61095 L
.33974 .60546 L
.33709 .58629 L
.33448 .56164 L
.33276 .53698 L
.33189 .51233 L
.33187 .48767 L
.33269 .46302 L
.33438 .43836 L
.33694 .41371 L
.33974 .39338 L
.34044 .38905 L
.3449 .3644 L
.35045 .33974 L
.35722 .31509 L
.3644 .29321 L
.36539 .29043 L
.37516 .26578 L
.38711 .24112 L
.38905 .23756 L
.40177 .21647 L
.41371 .20044 L
.42084 .19181 L
.43836 .17541 L
.44824 .16716 L
F
0 g
.46302 .15978 m
.48767 .15228 L
.51233 .15237 L
.53698 .16006 L
.55113 .16716 L
.56164 .17586 L
.57864 .19181 L
.58629 .20107 L
.59774 .21647 L
.61095 .23837 L
.61245 .24112 L
.62444 .26578 L
.63426 .29043 L
.6356 .2942 L
.64246 .31509 L
.64927 .33974 L
.65487 .3644 L
.65938 .38905 L
.66026 .39454 L
.66291 .41371 L
.66552 .43836 L
.66724 .46302 L
.66811 .48767 L
.66813 .51233 L
.66731 .53698 L
.66562 .56164 L
.66306 .58629 L
.66026 .60662 L
.65956 .61095 L
.6551 .6356 L
.64955 .66026 L
.64278 .68491 L
.6356 .70679 L
.63461 .70957 L
.62484 .73422 L
.61289 .75888 L
.61095 .76244 L
.59823 .78353 L
.58629 .79956 L
.57916 .80819 L
.56164 .82459 L
.55176 .83284 L
.53698 .84022 L
.51233 .84772 L
.48767 .84763 L
.46302 .83994 L
.44887 .83284 L
.43836 .82414 L
.42136 .80819 L
.41371 .79893 L
Mistroke
.40226 .78353 L
.38905 .76163 L
.38755 .75888 L
.37556 .73422 L
.36574 .70957 L
.3644 .7058 L
.35754 .68491 L
.35073 .66026 L
.34513 .6356 L
.34062 .61095 L
.33974 .60546 L
.33709 .58629 L
.33448 .56164 L
.33276 .53698 L
.33189 .51233 L
.33187 .48767 L
.33269 .46302 L
.33438 .43836 L
.33694 .41371 L
.33974 .39338 L
.34044 .38905 L
.3449 .3644 L
.35045 .33974 L
.35722 .31509 L
.3644 .29321 L
.36539 .29043 L
.37516 .26578 L
.38711 .24112 L
.38905 .23756 L
.40177 .21647 L
.41371 .20044 L
.42084 .19181 L
.43836 .17541 L
.44824 .16716 L
.46302 .15978 L
Mfstroke
.9 g
.46302 .24003 m
.48767 .23026 L
.51233 .23035 L
.53698 .24031 L
.53851 .24112 L
.56164 .26133 L
.56563 .26578 L
.58281 .29043 L
.58629 .29682 L
.59548 .31509 L
.60533 .33974 L
.61095 .35713 L
.61306 .3644 L
.6192 .38905 L
.62388 .41371 L
.62728 .43836 L
.6295 .46302 L
.6306 .48767 L
.63062 .51233 L
.62956 .53698 L
.62738 .56164 L
.62403 .58629 L
.61939 .61095 L
.61329 .6356 L
.61095 .64368 L
.6056 .66026 L
.59579 .68491 L
.58629 .70381 L
.58316 .70957 L
.56605 .73422 L
.56164 .73912 L
.53904 .75888 L
.53698 .75997 L
.51233 .76974 L
.48767 .76965 L
.46302 .75969 L
.46149 .75888 L
.43836 .73867 L
.43437 .73422 L
.41719 .70957 L
.41371 .70318 L
.40452 .68491 L
.39467 .66026 L
.38905 .64287 L
.38694 .6356 L
.3808 .61095 L
.37612 .58629 L
.37272 .56164 L
.3705 .53698 L
.3694 .51233 L
.36938 .48767 L
.37044 .46302 L
.37262 .43836 L
.37597 .41371 L
.38061 .38905 L
.38671 .3644 L
.38905 .35632 L
.3944 .33974 L
.40421 .31509 L
.41371 .29619 L
.41684 .29043 L
.43395 .26578 L
.43836 .26088 L
.46096 .24112 L
F
0 g
.46302 .24003 m
.48767 .23026 L
.51233 .23035 L
.53698 .24031 L
.53851 .24112 L
.56164 .26133 L
.56563 .26578 L
.58281 .29043 L
.58629 .29682 L
.59548 .31509 L
.60533 .33974 L
.61095 .35713 L
.61306 .3644 L
.6192 .38905 L
.62388 .41371 L
.62728 .43836 L
.6295 .46302 L
.6306 .48767 L
.63062 .51233 L
.62956 .53698 L
.62738 .56164 L
.62403 .58629 L
.61939 .61095 L
.61329 .6356 L
.61095 .64368 L
.6056 .66026 L
.59579 .68491 L
.58629 .70381 L
.58316 .70957 L
.56605 .73422 L
.56164 .73912 L
.53904 .75888 L
.53698 .75997 L
.51233 .76974 L
.48767 .76965 L
.46302 .75969 L
.46149 .75888 L
.43836 .73867 L
.43437 .73422 L
.41719 .70957 L
.41371 .70318 L
.40452 .68491 L
.39467 .66026 L
.38905 .64287 L
.38694 .6356 L
.3808 .61095 L
.37612 .58629 L
.37272 .56164 L
.3705 .53698 L
.3694 .51233 L
Mistroke
.36938 .48767 L
.37044 .46302 L
.37262 .43836 L
.37597 .41371 L
.38061 .38905 L
.38671 .3644 L
.38905 .35632 L
.3944 .33974 L
.40421 .31509 L
.41371 .29619 L
.41684 .29043 L
.43395 .26578 L
.43836 .26088 L
.46096 .24112 L
.46302 .24003 L
Mfstroke
1 g
.48767 .32824 m
.51233 .32833 L
.53204 .33974 L
.53698 .34437 L
.55354 .3644 L
.56164 .38264 L
.56443 .38905 L
.57292 .41371 L
.57853 .43836 L
.582 .46302 L
.58366 .48767 L
.58368 .51233 L
.58206 .53698 L
.57864 .56164 L
.57307 .58629 L
.56463 .61095 L
.56164 .61781 L
.55378 .6356 L
.53698 .6559 L
.53231 .66026 L
.51233 .67176 L
.48767 .67167 L
.46796 .66026 L
.46302 .65563 L
.44646 .6356 L
.43836 .61736 L
.43557 .61095 L
.42708 .58629 L
.42147 .56164 L
.418 .53698 L
.41634 .51233 L
.41632 .48767 L
.41794 .46302 L
.42136 .43836 L
.42693 .41371 L
.43537 .38905 L
.43836 .38219 L
.44622 .3644 L
.46302 .3441 L
.46769 .33974 L
F
0 g
.48767 .32824 m
.51233 .32833 L
.53204 .33974 L
.53698 .34437 L
.55354 .3644 L
.56164 .38264 L
.56443 .38905 L
.57292 .41371 L
.57853 .43836 L
.582 .46302 L
.58366 .48767 L
.58368 .51233 L
.58206 .53698 L
.57864 .56164 L
.57307 .58629 L
.56463 .61095 L
.56164 .61781 L
.55378 .6356 L
.53698 .6559 L
.53231 .66026 L
.51233 .67176 L
.48767 .67167 L
.46796 .66026 L
.46302 .65563 L
.44646 .6356 L
.43836 .61736 L
.43557 .61095 L
.42708 .58629 L
.42147 .56164 L
.418 .53698 L
.41634 .51233 L
.41632 .48767 L
.41794 .46302 L
.42136 .43836 L
.42693 .41371 L
.43537 .38905 L
.43836 .38219 L
.44622 .3644 L
.46302 .3441 L
.46769 .33974 L
.48767 .32824 L
s
.5 g
.54102 .98077 m
.56164 .97107 L
.58404 .95611 L
.58629 .95423 L
.61026 .93146 L
.61095 .9307 L
.63033 .9068 L
.6356 .8993 L
.64669 .88215 L
.66026 .85796 L
.6605 .8575 L
.67241 .83284 L
.68276 .80819 L
.68491 .80261 L
.69182 .78353 L
.69976 .75888 L
.70671 .73422 L
.70957 .72302 L
.71277 .70957 L
.71801 .68491 L
.72249 .66026 L
.72625 .6356 L
.72934 .61095 L
.73177 .58629 L
.73358 .56164 L
.73422 .55144 L
.73476 .53698 L
.73535 .51233 L
.73533 .48767 L
.7347 .46302 L
.73422 .45051 L
.73347 .43836 L
.73163 .41371 L
.72915 .38905 L
.72602 .3644 L
.72221 .33974 L
.71769 .31509 L
.71241 .29043 L
.70957 .27851 L
.70631 .26578 L
.69932 .24112 L
.69134 .21647 L
.68491 .19874 L
.68224 .19181 L
.67185 .16716 L
.66026 .14321 L
.65989 .1425 L
.64604 .11785 L
.6356 .10169 L
.62964 .0932 L
.61095 .07012 L
.60954 .06854 L
.58629 .04641 L
.58329 .04389 L
.56164 .02938 L
.54004 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.54102 .98077 m
.56164 .97107 L
.58404 .95611 L
.58629 .95423 L
.61026 .93146 L
.61095 .9307 L
.63033 .9068 L
.6356 .8993 L
.64669 .88215 L
.66026 .85796 L
.6605 .8575 L
.67241 .83284 L
.68276 .80819 L
.68491 .80261 L
.69182 .78353 L
.69976 .75888 L
.70671 .73422 L
.70957 .72302 L
.71277 .70957 L
.71801 .68491 L
.72249 .66026 L
.72625 .6356 L
.72934 .61095 L
.73177 .58629 L
.73358 .56164 L
.73422 .55144 L
.73476 .53698 L
.73535 .51233 L
.73533 .48767 L
.7347 .46302 L
.73422 .45051 L
.73347 .43836 L
.73163 .41371 L
.72915 .38905 L
.72602 .3644 L
.72221 .33974 L
.71769 .31509 L
.71241 .29043 L
.70957 .27851 L
.70631 .26578 L
.69932 .24112 L
.69134 .21647 L
.68491 .19874 L
.68224 .19181 L
.67185 .16716 L
.66026 .14321 L
.65989 .1425 L
.64604 .11785 L
.6356 .10169 L
.62964 .0932 L
Mistroke
.61095 .07012 L
.60954 .06854 L
.58629 .04641 L
.58329 .04389 L
.56164 .02938 L
.54004 .01923 L
Mfstroke
.4 g
.63667 .98077 m
.65514 .95611 L
.66026 .94844 L
.67079 .93146 L
.68433 .9068 L
.68491 .90568 L
.69624 .88215 L
.70677 .8575 L
.70957 .85042 L
.71613 .83284 L
.72447 .80819 L
.7319 .78353 L
.73422 .7752 L
.7385 .75888 L
.74435 .73422 L
.74949 .70957 L
.75397 .68491 L
.75783 .66026 L
.75888 .6528 L
.76108 .6356 L
.76375 .61095 L
.76587 .58629 L
.76744 .56164 L
.76848 .53698 L
.76898 .51233 L
.76896 .48767 L
.76841 .46302 L
.76734 .43836 L
.76572 .41371 L
.76356 .38905 L
.76085 .3644 L
.75888 .34909 L
.75755 .33974 L
.75366 .31509 L
.74913 .29043 L
.74395 .26578 L
.73806 .24112 L
.73422 .22651 L
.73142 .21647 L
.72395 .19181 L
.71556 .16716 L
.70957 .15111 L
.70616 .1425 L
.69559 .11785 L
.68491 .09567 L
.68364 .0932 L
.67005 .06854 L
.66026 .05273 L
.65437 .04389 L
.63585 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63667 .98077 m
.65514 .95611 L
.66026 .94844 L
.67079 .93146 L
.68433 .9068 L
.68491 .90568 L
.69624 .88215 L
.70677 .8575 L
.70957 .85042 L
.71613 .83284 L
.72447 .80819 L
.7319 .78353 L
.73422 .7752 L
.7385 .75888 L
.74435 .73422 L
.74949 .70957 L
.75397 .68491 L
.75783 .66026 L
.75888 .6528 L
.76108 .6356 L
.76375 .61095 L
.76587 .58629 L
.76744 .56164 L
.76848 .53698 L
.76898 .51233 L
.76896 .48767 L
.76841 .46302 L
.76734 .43836 L
.76572 .41371 L
.76356 .38905 L
.76085 .3644 L
.75888 .34909 L
.75755 .33974 L
.75366 .31509 L
.74913 .29043 L
.74395 .26578 L
.73806 .24112 L
.73422 .22651 L
.73142 .21647 L
.72395 .19181 L
.71556 .16716 L
.70957 .15111 L
.70616 .1425 L
.69559 .11785 L
.68491 .09567 L
.68364 .0932 L
.67005 .06854 L
.66026 .05273 L
.65437 .04389 L
.63585 .01923 L
Mistroke
Mfstroke
.3 g
.698 .98077 m
.70957 .95923 L
.71114 .95611 L
.72288 .93146 L
.73342 .9068 L
.73422 .90483 L
.74292 .88215 L
.7515 .8575 L
.75888 .83409 L
.75925 .83284 L
.76624 .80819 L
.77252 .78353 L
.77816 .75888 L
.78319 .73422 L
.78353 .73244 L
.78763 .70957 L
.79152 .68491 L
.79488 .66026 L
.79773 .6356 L
.80007 .61095 L
.80194 .58629 L
.80332 .56164 L
.80423 .53698 L
.80467 .51233 L
.80465 .48767 L
.80417 .46302 L
.80321 .43836 L
.80179 .41371 L
.79989 .38905 L
.7975 .3644 L
.79461 .33974 L
.79121 .31509 L
.78728 .29043 L
.78353 .26963 L
.78279 .26578 L
.77772 .24112 L
.77204 .21647 L
.76571 .19181 L
.75888 .16781 L
.75868 .16716 L
.75089 .1425 L
.74227 .11785 L
.73422 .09688 L
.73273 .0932 L
.72215 .06854 L
.71037 .04389 L
.70957 .0423 L
.69718 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.698 .98077 m
.70957 .95923 L
.71114 .95611 L
.72288 .93146 L
.73342 .9068 L
.73422 .90483 L
.74292 .88215 L
.7515 .8575 L
.75888 .83409 L
.75925 .83284 L
.76624 .80819 L
.77252 .78353 L
.77816 .75888 L
.78319 .73422 L
.78353 .73244 L
.78763 .70957 L
.79152 .68491 L
.79488 .66026 L
.79773 .6356 L
.80007 .61095 L
.80194 .58629 L
.80332 .56164 L
.80423 .53698 L
.80467 .51233 L
.80465 .48767 L
.80417 .46302 L
.80321 .43836 L
.80179 .41371 L
.79989 .38905 L
.7975 .3644 L
.79461 .33974 L
.79121 .31509 L
.78728 .29043 L
.78353 .26963 L
.78279 .26578 L
.77772 .24112 L
.77204 .21647 L
.76571 .19181 L
.75888 .16781 L
.75868 .16716 L
.75089 .1425 L
.74227 .11785 L
.73422 .09688 L
.73273 .0932 L
.72215 .06854 L
.71037 .04389 L
.70957 .0423 L
.69718 .01923 L
s
.2 g
.75509 .98077 m
.75888 .972 L
.76542 .95611 L
.77484 .93146 L
.78345 .9068 L
.78353 .90657 L
.79131 .88215 L
.7985 .8575 L
.80505 .83284 L
.80819 .82019 L
.81101 .80819 L
.8164 .78353 L
.82127 .75888 L
.82563 .73422 L
.8295 .70957 L
.83284 .68539 L
.8329 .68491 L
.83584 .66026 L
.83834 .6356 L
.8404 .61095 L
.84204 .58629 L
.84326 .56164 L
.84406 .53698 L
.84445 .51233 L
.84443 .48767 L
.844 .46302 L
.84315 .43836 L
.84189 .41371 L
.84021 .38905 L
.83811 .3644 L
.83557 .33974 L
.83284 .31704 L
.83259 .31509 L
.82914 .29043 L
.82523 .26578 L
.82083 .24112 L
.81592 .21647 L
.81049 .19181 L
.80819 .18207 L
.80449 .16716 L
.79789 .1425 L
.79066 .11785 L
.78353 .09551 L
.78276 .0932 L
.7741 .06854 L
.76464 .04389 L
.75888 .0299 L
.75427 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.75509 .98077 m
.75888 .972 L
.76542 .95611 L
.77484 .93146 L
.78345 .9068 L
.78353 .90657 L
.79131 .88215 L
.7985 .8575 L
.80505 .83284 L
.80819 .82019 L
.81101 .80819 L
.8164 .78353 L
.82127 .75888 L
.82563 .73422 L
.8295 .70957 L
.83284 .68539 L
.8329 .68491 L
.83584 .66026 L
.83834 .6356 L
.8404 .61095 L
.84204 .58629 L
.84326 .56164 L
.84406 .53698 L
.84445 .51233 L
.84443 .48767 L
.844 .46302 L
.84315 .43836 L
.84189 .41371 L
.84021 .38905 L
.83811 .3644 L
.83557 .33974 L
.83284 .31704 L
.83259 .31509 L
.82914 .29043 L
.82523 .26578 L
.82083 .24112 L
.81592 .21647 L
.81049 .19181 L
.80819 .18207 L
.80449 .16716 L
.79789 .1425 L
.79066 .11785 L
.78353 .09551 L
.78276 .0932 L
.7741 .06854 L
.76464 .04389 L
.75888 .0299 L
.75427 .01923 L
s
.1 g
.81641 .98077 m
.82478 .95611 L
.83253 .93146 L
.83284 .93043 L
.83967 .9068 L
.84625 .88215 L
.85232 .8575 L
.8575 .83466 L
.85789 .83284 L
.86297 .80819 L
.86759 .78353 L
.87179 .75888 L
.87556 .73422 L
.87892 .70957 L
.88188 .68491 L
.88215 .68251 L
.88444 .66026 L
.88662 .6356 L
.88842 .61095 L
.88986 .58629 L
.89092 .56164 L
.89162 .53698 L
.89196 .51233 L
.89194 .48767 L
.89156 .46302 L
.89082 .43836 L
.88971 .41371 L
.88823 .38905 L
.88639 .3644 L
.88417 .33974 L
.88215 .32027 L
.88157 .31509 L
.87856 .29043 L
.87516 .26578 L
.87135 .24112 L
.86711 .21647 L
.86244 .19181 L
.8575 .16796 L
.85732 .16716 L
.85171 .1425 L
.8456 .11785 L
.83897 .0932 L
.83284 .07201 L
.83179 .06854 L
.82401 .04389 L
.81559 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.81641 .98077 m
.82478 .95611 L
.83253 .93146 L
.83284 .93043 L
.83967 .9068 L
.84625 .88215 L
.85232 .8575 L
.8575 .83466 L
.85789 .83284 L
.86297 .80819 L
.86759 .78353 L
.87179 .75888 L
.87556 .73422 L
.87892 .70957 L
.88188 .68491 L
.88215 .68251 L
.88444 .66026 L
.88662 .6356 L
.88842 .61095 L
.88986 .58629 L
.89092 .56164 L
.89162 .53698 L
.89196 .51233 L
.89194 .48767 L
.89156 .46302 L
.89082 .43836 L
.88971 .41371 L
.88823 .38905 L
.88639 .3644 L
.88417 .33974 L
.88215 .32027 L
.88157 .31509 L
.87856 .29043 L
.87516 .26578 L
.87135 .24112 L
.86711 .21647 L
.86244 .19181 L
.8575 .16796 L
.85732 .16716 L
.85171 .1425 L
.8456 .11785 L
.83897 .0932 L
.83284 .07201 L
.83179 .06854 L
.82401 .04389 L
.81559 .01923 L
s
.89331 .98077 m
.90008 .95611 L
.9064 .93146 L
.9068 .9298 L
.91224 .9068 L
.91768 .88215 L
.92272 .8575 L
.92737 .83284 L
.93146 .80929 L
.93164 .80819 L
.93553 .78353 L
.93906 .75888 L
.94225 .73422 L
.9451 .70957 L
.94762 .68491 L
.94981 .66026 L
.95168 .6356 L
.95323 .61095 L
.95446 .58629 L
.95537 .56164 L
.95598 .53698 L
.95611 .52819 L
.95627 .51233 L
.95624 .48767 L
.95611 .47514 L
.95591 .46302 L
.95527 .43836 L
.95431 .41371 L
.95304 .38905 L
.95145 .3644 L
.94954 .33974 L
.9473 .31509 L
.94474 .29043 L
.94185 .26578 L
.93862 .24112 L
.93505 .21647 L
.93146 .19386 L
.93112 .19181 L
.9268 .16716 L
.92211 .1425 L
.91703 .11785 L
.91155 .0932 L
.9068 .07317 L
.90566 .06854 L
.8993 .04389 L
.89249 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.89331 .98077 m
.90008 .95611 L
.9064 .93146 L
.9068 .9298 L
.91224 .9068 L
.91768 .88215 L
.92272 .8575 L
.92737 .83284 L
.93146 .80929 L
.93164 .80819 L
.93553 .78353 L
.93906 .75888 L
.94225 .73422 L
.9451 .70957 L
.94762 .68491 L
.94981 .66026 L
.95168 .6356 L
.95323 .61095 L
.95446 .58629 L
.95537 .56164 L
.95598 .53698 L
.95611 .52819 L
.95627 .51233 L
.95624 .48767 L
.95611 .47514 L
.95591 .46302 L
.95527 .43836 L
.95431 .41371 L
.95304 .38905 L
.95145 .3644 L
.94954 .33974 L
.9473 .31509 L
.94474 .29043 L
.94185 .26578 L
.93862 .24112 L
.93505 .21647 L
.93146 .19386 L
.93112 .19181 L
.9268 .16716 L
.92211 .1425 L
.91703 .11785 L
.91155 .0932 L
.9068 .07317 L
.90566 .06854 L
.8993 .04389 L
.89249 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00480769 0.5 0.00480769 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .3498 m
.04389 .34519 L
.06854 .34088 L
.07541 .33974 L
.0932 .33728 L
.11785 .33399 L
.1425 .33086 L
.16716 .3279 L
.19181 .32513 L
.21647 .32258 L
.24112 .32023 L
.26578 .31811 L
.29043 .31621 L
.30664 .31509 L
.31509 .31467 L
.33974 .31352 L
.3644 .31252 L
.38905 .31168 L
.41371 .31099 L
.43836 .31047 L
.46302 .31012 L
.48767 .30995 L
.51233 .30995 L
.53698 .31012 L
.56164 .31047 L
.58629 .31098 L
.61095 .31167 L
.6356 .31251 L
.66026 .31351 L
.68491 .31465 L
.69376 .31509 L
.70957 .31619 L
.73422 .31808 L
.75888 .3202 L
.78353 .32254 L
.80819 .32509 L
.83284 .32786 L
.8575 .33081 L
.88215 .33394 L
.9068 .33723 L
.92494 .33974 L
.93146 .34083 L
.95611 .34513 L
.98077 .34974 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .3498 m
.04389 .34519 L
.06854 .34088 L
.07541 .33974 L
.0932 .33728 L
.11785 .33399 L
.1425 .33086 L
.16716 .3279 L
.19181 .32513 L
.21647 .32258 L
.24112 .32023 L
.26578 .31811 L
.29043 .31621 L
.30664 .31509 L
.31509 .31467 L
.33974 .31352 L
.3644 .31252 L
.38905 .31168 L
.41371 .31099 L
.43836 .31047 L
.46302 .31012 L
.48767 .30995 L
.51233 .30995 L
.53698 .31012 L
.56164 .31047 L
.58629 .31098 L
.61095 .31167 L
.6356 .31251 L
.66026 .31351 L
.68491 .31465 L
.69376 .31509 L
.70957 .31619 L
.73422 .31808 L
.75888 .3202 L
.78353 .32254 L
.80819 .32509 L
.83284 .32786 L
.8575 .33081 L
.88215 .33394 L
.9068 .33723 L
.92494 .33974 L
.93146 .34083 L
.95611 .34513 L
.98077 .34974 L
s
.2 g
.01923 .3954 m
.0436 .38905 L
.04389 .38899 L
.06854 .38339 L
.0932 .37828 L
.11785 .3736 L
.1425 .36933 L
.16716 .36543 L
.17412 .3644 L
.19181 .36208 L
.21647 .35909 L
.24112 .35637 L
.26578 .3539 L
.29043 .35169 L
.31509 .34973 L
.33974 .34802 L
.3644 .34656 L
.38905 .34535 L
.41371 .34439 L
.43836 .34366 L
.46302 .34318 L
.48767 .34294 L
.51233 .34294 L
.53698 .34318 L
.56164 .34366 L
.58629 .34437 L
.61095 .34534 L
.6356 .34654 L
.66026 .348 L
.68491 .3497 L
.70957 .35166 L
.73422 .35387 L
.75888 .35634 L
.78353 .35906 L
.80819 .36205 L
.82617 .3644 L
.83284 .36539 L
.8575 .36928 L
.88215 .37355 L
.9068 .37822 L
.93146 .38333 L
.95611 .38893 L
.95664 .38905 L
.98077 .39534 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .3954 m
.0436 .38905 L
.04389 .38899 L
.06854 .38339 L
.0932 .37828 L
.11785 .3736 L
.1425 .36933 L
.16716 .36543 L
.17412 .3644 L
.19181 .36208 L
.21647 .35909 L
.24112 .35637 L
.26578 .3539 L
.29043 .35169 L
.31509 .34973 L
.33974 .34802 L
.3644 .34656 L
.38905 .34535 L
.41371 .34439 L
.43836 .34366 L
.46302 .34318 L
.48767 .34294 L
.51233 .34294 L
.53698 .34318 L
.56164 .34366 L
.58629 .34437 L
.61095 .34534 L
.6356 .34654 L
.66026 .348 L
.68491 .3497 L
.70957 .35166 L
.73422 .35387 L
.75888 .35634 L
.78353 .35906 L
.80819 .36205 L
.82617 .3644 L
.83284 .36539 L
.8575 .36928 L
.88215 .37355 L
.9068 .37822 L
.93146 .38333 L
.95611 .38893 L
.95664 .38905 L
.98077 .39534 L
s
.3 g
.01923 .43105 m
.04389 .42171 L
.06854 .41388 L
.06911 .41371 L
.0932 .40705 L
.11785 .40103 L
.1425 .39568 L
.16716 .39091 L
.17755 .38905 L
.19181 .38672 L
.21647 .38302 L
.24112 .37971 L
.26578 .37675 L
.29043 .37412 L
.31509 .37182 L
.33974 .36983 L
.3644 .36815 L
.38905 .36675 L
.41371 .36565 L
.43836 .36482 L
.45515 .3644 L
.46302 .36428 L
.48767 .36403 L
.51233 .36403 L
.53698 .36428 L
.5452 .3644 L
.56164 .36481 L
.58629 .36564 L
.61095 .36674 L
.6356 .36813 L
.66026 .36981 L
.68491 .3718 L
.70957 .37409 L
.73422 .37672 L
.75888 .37967 L
.78353 .38299 L
.80819 .38668 L
.82269 .38905 L
.83284 .39087 L
.8575 .39564 L
.88215 .40098 L
.9068 .40699 L
.93107 .41371 L
.93146 .41382 L
.95611 .42165 L
.98077 .43099 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .43105 m
.04389 .42171 L
.06854 .41388 L
.06911 .41371 L
.0932 .40705 L
.11785 .40103 L
.1425 .39568 L
.16716 .39091 L
.17755 .38905 L
.19181 .38672 L
.21647 .38302 L
.24112 .37971 L
.26578 .37675 L
.29043 .37412 L
.31509 .37182 L
.33974 .36983 L
.3644 .36815 L
.38905 .36675 L
.41371 .36565 L
.43836 .36482 L
.45515 .3644 L
.46302 .36428 L
.48767 .36403 L
.51233 .36403 L
.53698 .36428 L
.5452 .3644 L
.56164 .36481 L
.58629 .36564 L
.61095 .36674 L
.6356 .36813 L
.66026 .36981 L
.68491 .3718 L
.70957 .37409 L
.73422 .37672 L
.75888 .37967 L
.78353 .38299 L
.80819 .38668 L
.82269 .38905 L
.83284 .39087 L
.8575 .39564 L
.88215 .40098 L
.9068 .40699 L
.93107 .41371 L
.93146 .41382 L
.95611 .42165 L
.98077 .43099 L
s
.4 g
.01923 .47806 m
.03488 .46302 L
.04389 .45613 L
.06854 .44309 L
.08111 .43836 L
.0932 .43364 L
.11785 .42538 L
.1425 .41847 L
.16208 .41371 L
.16716 .41255 L
.19181 .40735 L
.21647 .40279 L
.24112 .39878 L
.26578 .39526 L
.29043 .39218 L
.31509 .38951 L
.31966 .38905 L
.33974 .38728 L
.3644 .38541 L
.38905 .38387 L
.41371 .38265 L
.43836 .38174 L
.46302 .38113 L
.48767 .38083 L
.51233 .38083 L
.53698 .38113 L
.56164 .38173 L
.58629 .38264 L
.61095 .38385 L
.6356 .38539 L
.66026 .38726 L
.68057 .38905 L
.68491 .38948 L
.70957 .39215 L
.73422 .39523 L
.75888 .39875 L
.78353 .40276 L
.80819 .40731 L
.83284 .4125 L
.83811 .41371 L
.8575 .41843 L
.88215 .42533 L
.9068 .43359 L
.91902 .43836 L
.93146 .44304 L
.95611 .45606 L
.9652 .46302 L
.98077 .47799 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .47806 m
.03488 .46302 L
.04389 .45613 L
.06854 .44309 L
.08111 .43836 L
.0932 .43364 L
.11785 .42538 L
.1425 .41847 L
.16208 .41371 L
.16716 .41255 L
.19181 .40735 L
.21647 .40279 L
.24112 .39878 L
.26578 .39526 L
.29043 .39218 L
.31509 .38951 L
.31966 .38905 L
.33974 .38728 L
.3644 .38541 L
.38905 .38387 L
.41371 .38265 L
.43836 .38174 L
.46302 .38113 L
.48767 .38083 L
.51233 .38083 L
.53698 .38113 L
.56164 .38173 L
.58629 .38264 L
.61095 .38385 L
.6356 .38539 L
.66026 .38726 L
.68057 .38905 L
.68491 .38948 L
.70957 .39215 L
.73422 .39523 L
.75888 .39875 L
.78353 .40276 L
.80819 .40731 L
.83284 .4125 L
.83811 .41371 L
.8575 .41843 L
.88215 .42533 L
.9068 .43359 L
.91902 .43836 L
.93146 .44304 L
.95611 .45606 L
.9652 .46302 L
.98077 .47799 L
s
.3 g
.01923 .52201 m
.0348 .53698 L
.04389 .54394 L
.06854 .55696 L
.08098 .56164 L
.0932 .56641 L
.11785 .57467 L
.1425 .58157 L
.16189 .58629 L
.16716 .5875 L
.19181 .59269 L
.21647 .59724 L
.24112 .60125 L
.26578 .60477 L
.29043 .60785 L
.31509 .61052 L
.31943 .61095 L
.33974 .61274 L
.3644 .61461 L
.38905 .61615 L
.41371 .61736 L
.43836 .61827 L
.46302 .61887 L
.48767 .61917 L
.51233 .61917 L
.53698 .61887 L
.56164 .61826 L
.58629 .61735 L
.61095 .61613 L
.6356 .61459 L
.66026 .61272 L
.68034 .61095 L
.68491 .61049 L
.70957 .60782 L
.73422 .60474 L
.75888 .60122 L
.78353 .59721 L
.80819 .59265 L
.83284 .58745 L
.83792 .58629 L
.8575 .58153 L
.88215 .57462 L
.9068 .56636 L
.91889 .56164 L
.93146 .55691 L
.95611 .54387 L
.96512 .53698 L
.98077 .52194 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .52201 m
.0348 .53698 L
.04389 .54394 L
.06854 .55696 L
.08098 .56164 L
.0932 .56641 L
.11785 .57467 L
.1425 .58157 L
.16189 .58629 L
.16716 .5875 L
.19181 .59269 L
.21647 .59724 L
.24112 .60125 L
.26578 .60477 L
.29043 .60785 L
.31509 .61052 L
.31943 .61095 L
.33974 .61274 L
.3644 .61461 L
.38905 .61615 L
.41371 .61736 L
.43836 .61827 L
.46302 .61887 L
.48767 .61917 L
.51233 .61917 L
.53698 .61887 L
.56164 .61826 L
.58629 .61735 L
.61095 .61613 L
.6356 .61459 L
.66026 .61272 L
.68034 .61095 L
.68491 .61049 L
.70957 .60782 L
.73422 .60474 L
.75888 .60122 L
.78353 .59721 L
.80819 .59265 L
.83284 .58745 L
.83792 .58629 L
.8575 .58153 L
.88215 .57462 L
.9068 .56636 L
.91889 .56164 L
.93146 .55691 L
.95611 .54387 L
.96512 .53698 L
.98077 .52194 L
s
.2 g
.01923 .56901 m
.04389 .57835 L
.06854 .58618 L
.06893 .58629 L
.0932 .59301 L
.11785 .59902 L
.1425 .60436 L
.16716 .60913 L
.17731 .61095 L
.19181 .61332 L
.21647 .61701 L
.24112 .62033 L
.26578 .62328 L
.29043 .62591 L
.31509 .6282 L
.33974 .63019 L
.3644 .63187 L
.38905 .63326 L
.41371 .63436 L
.43836 .63519 L
.4548 .6356 L
.46302 .63572 L
.48767 .63597 L
.51233 .63597 L
.53698 .63572 L
.54485 .6356 L
.56164 .63518 L
.58629 .63435 L
.61095 .63325 L
.6356 .63185 L
.66026 .63017 L
.68491 .62818 L
.70957 .62588 L
.73422 .62325 L
.75888 .62029 L
.78353 .61698 L
.80819 .61328 L
.82245 .61095 L
.83284 .60909 L
.8575 .60432 L
.88215 .59897 L
.9068 .59295 L
.93089 .58629 L
.93146 .58612 L
.95611 .57829 L
.98077 .56895 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .56901 m
.04389 .57835 L
.06854 .58618 L
.06893 .58629 L
.0932 .59301 L
.11785 .59902 L
.1425 .60436 L
.16716 .60913 L
.17731 .61095 L
.19181 .61332 L
.21647 .61701 L
.24112 .62033 L
.26578 .62328 L
.29043 .62591 L
.31509 .6282 L
.33974 .63019 L
.3644 .63187 L
.38905 .63326 L
.41371 .63436 L
.43836 .63519 L
.4548 .6356 L
.46302 .63572 L
.48767 .63597 L
.51233 .63597 L
.53698 .63572 L
.54485 .6356 L
.56164 .63518 L
.58629 .63435 L
.61095 .63325 L
.6356 .63185 L
.66026 .63017 L
.68491 .62818 L
.70957 .62588 L
.73422 .62325 L
.75888 .62029 L
.78353 .61698 L
.80819 .61328 L
.82245 .61095 L
.83284 .60909 L
.8575 .60432 L
.88215 .59897 L
.9068 .59295 L
.93089 .58629 L
.93146 .58612 L
.95611 .57829 L
.98077 .56895 L
s
.1 g
.01923 .60466 m
.04336 .61095 L
.04389 .61107 L
.06854 .61667 L
.0932 .62178 L
.11785 .62645 L
.1425 .63072 L
.16716 .63461 L
.17383 .6356 L
.19181 .63795 L
.21647 .64094 L
.24112 .64366 L
.26578 .64613 L
.29043 .64834 L
.31509 .6503 L
.33974 .652 L
.3644 .65346 L
.38905 .65466 L
.41371 .65563 L
.43836 .65634 L
.46302 .65682 L
.48767 .65706 L
.51233 .65706 L
.53698 .65682 L
.56164 .65634 L
.58629 .65561 L
.61095 .65465 L
.6356 .65344 L
.66026 .65198 L
.68491 .65027 L
.70957 .64831 L
.73422 .6461 L
.75888 .64363 L
.78353 .64091 L
.80819 .63792 L
.82588 .6356 L
.83284 .63457 L
.8575 .63067 L
.88215 .6264 L
.9068 .62172 L
.93146 .61661 L
.95611 .61101 L
.9564 .61095 L
.98077 .6046 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .60466 m
.04336 .61095 L
.04389 .61107 L
.06854 .61667 L
.0932 .62178 L
.11785 .62645 L
.1425 .63072 L
.16716 .63461 L
.17383 .6356 L
.19181 .63795 L
.21647 .64094 L
.24112 .64366 L
.26578 .64613 L
.29043 .64834 L
.31509 .6503 L
.33974 .652 L
.3644 .65346 L
.38905 .65466 L
.41371 .65563 L
.43836 .65634 L
.46302 .65682 L
.48767 .65706 L
.51233 .65706 L
.53698 .65682 L
.56164 .65634 L
.58629 .65561 L
.61095 .65465 L
.6356 .65344 L
.66026 .65198 L
.68491 .65027 L
.70957 .64831 L
.73422 .6461 L
.75888 .64363 L
.78353 .64091 L
.80819 .63792 L
.82588 .6356 L
.83284 .63457 L
.8575 .63067 L
.88215 .6264 L
.9068 .62172 L
.93146 .61661 L
.95611 .61101 L
.9564 .61095 L
.98077 .6046 L
s
.01923 .65026 m
.04389 .65487 L
.06854 .65917 L
.07506 .66026 L
.0932 .66277 L
.11785 .66606 L
.1425 .66919 L
.16716 .67214 L
.19181 .67491 L
.21647 .67746 L
.24112 .6798 L
.26578 .68192 L
.29043 .68381 L
.30624 .68491 L
.31509 .68535 L
.33974 .68649 L
.3644 .68749 L
.38905 .68833 L
.41371 .68902 L
.43836 .68953 L
.46302 .68988 L
.48767 .69005 L
.51233 .69005 L
.53698 .68988 L
.56164 .68953 L
.58629 .68901 L
.61095 .68832 L
.6356 .68748 L
.66026 .68648 L
.68491 .68533 L
.69336 .68491 L
.70957 .68379 L
.73422 .68189 L
.75888 .67977 L
.78353 .67742 L
.80819 .67487 L
.83284 .6721 L
.8575 .66914 L
.88215 .66601 L
.9068 .66272 L
.92459 .66026 L
.93146 .65912 L
.95611 .65481 L
.98077 .6502 L
.98077 .98077 L
.01923 .98077 L
F
.01923 .65026 m
.04389 .65487 L
.06854 .65917 L
.07506 .66026 L
.0932 .66277 L
.11785 .66606 L
.1425 .66919 L
.16716 .67214 L
.19181 .67491 L
.21647 .67746 L
.24112 .6798 L
.26578 .68192 L
.29043 .68381 L
.30624 .68491 L
.31509 .68535 L
.33974 .68649 L
.3644 .68749 L
.38905 .68833 L
.41371 .68902 L
.43836 .68953 L
.46302 .68988 L
.48767 .69005 L
.51233 .69005 L
.53698 .68988 L
.56164 .68953 L
.58629 .68901 L
.61095 .68832 L
.6356 .68748 L
.66026 .68648 L
.68491 .68533 L
.69336 .68491 L
.70957 .68379 L
.73422 .68189 L
.75888 .67977 L
.78353 .67742 L
.80819 .67487 L
.83284 .6721 L
.8575 .66914 L
.88215 .66601 L
.9068 .66272 L
.92459 .66026 L
.93146 .65912 L
.95611 .65481 L
.98077 .6502 L
s
.5 g
.26578 .41204 m
.29043 .40843 L
.31509 .40533 L
.33974 .4027 L
.3644 .4005 L
.38905 .39869 L
.41371 .39727 L
.43836 .39621 L
.46302 .39552 L
.48767 .39517 L
.51233 .39517 L
.53698 .39551 L
.56164 .39621 L
.58629 .39726 L
.61095 .39868 L
.6356 .40048 L
.66026 .40268 L
.68491 .40531 L
.70957 .4084 L
.73422 .41201 L
.74467 .41371 L
.75888 .41618 L
.78353 .42101 L
.80819 .42669 L
.83284 .43347 L
.84804 .43836 L
.8575 .44123 L
.88215 .45086 L
.90245 .46302 L
.9068 .46601 L
.92705 .48767 L
.92702 .51233 L
.9068 .53394 L
.90237 .53698 L
.88215 .54908 L
.8575 .55873 L
.84791 .56164 L
.83284 .56649 L
.80819 .57327 L
.78353 .57895 L
.75888 .58379 L
.74449 .58629 L
.73422 .58796 L
.70957 .59157 L
.68491 .59467 L
.66026 .5973 L
.6356 .5995 L
.61095 .60131 L
.58629 .60273 L
.56164 .60379 L
.53698 .60448 L
.51233 .60483 L
.48767 .60483 L
.46302 .60449 L
.43836 .60379 L
.41371 .60274 L
.38905 .60132 L
.3644 .59952 L
.33974 .59732 L
.31509 .59469 L
.29043 .5916 L
.26578 .58799 L
.25533 .58629 L
.24112 .58382 L
.21647 .57899 L
.19181 .57331 L
.16716 .56653 L
.15196 .56164 L
.1425 .55877 L
.11785 .54914 L
.09755 .53698 L
.0932 .53399 L
.07295 .51233 L
.07298 .48767 L
.0932 .46606 L
.09763 .46302 L
.11785 .45092 L
.1425 .44127 L
.15209 .43836 L
.16716 .43351 L
.19181 .42673 L
.21647 .42105 L
.24112 .41621 L
.25551 .41371 L
F
0 g
.26578 .41204 m
.29043 .40843 L
.31509 .40533 L
.33974 .4027 L
.3644 .4005 L
.38905 .39869 L
.41371 .39727 L
.43836 .39621 L
.46302 .39552 L
.48767 .39517 L
.51233 .39517 L
.53698 .39551 L
.56164 .39621 L
.58629 .39726 L
.61095 .39868 L
.6356 .40048 L
.66026 .40268 L
.68491 .40531 L
.70957 .4084 L
.73422 .41201 L
.74467 .41371 L
.75888 .41618 L
.78353 .42101 L
.80819 .42669 L
.83284 .43347 L
.84804 .43836 L
.8575 .44123 L
.88215 .45086 L
.90245 .46302 L
.9068 .46601 L
.92705 .48767 L
.92702 .51233 L
.9068 .53394 L
.90237 .53698 L
.88215 .54908 L
.8575 .55873 L
.84791 .56164 L
.83284 .56649 L
.80819 .57327 L
.78353 .57895 L
.75888 .58379 L
.74449 .58629 L
.73422 .58796 L
.70957 .59157 L
.68491 .59467 L
.66026 .5973 L
.6356 .5995 L
.61095 .60131 L
.58629 .60273 L
.56164 .60379 L
Mistroke
.53698 .60448 L
.51233 .60483 L
.48767 .60483 L
.46302 .60449 L
.43836 .60379 L
.41371 .60274 L
.38905 .60132 L
.3644 .59952 L
.33974 .59732 L
.31509 .59469 L
.29043 .5916 L
.26578 .58799 L
.25533 .58629 L
.24112 .58382 L
.21647 .57899 L
.19181 .57331 L
.16716 .56653 L
.15196 .56164 L
.1425 .55877 L
.11785 .54914 L
.09755 .53698 L
.0932 .53399 L
.07295 .51233 L
.07298 .48767 L
.0932 .46606 L
.09763 .46302 L
.11785 .45092 L
.1425 .44127 L
.15209 .43836 L
.16716 .43351 L
.19181 .42673 L
.21647 .42105 L
.24112 .41621 L
.25551 .41371 L
.26578 .41204 L
Mfstroke
.6 g
.38905 .41251 m
.41371 .41088 L
.43836 .40967 L
.46302 .40888 L
.48767 .40848 L
.51233 .40848 L
.53698 .40887 L
.56164 .40967 L
.58629 .41087 L
.61095 .4125 L
.62603 .41371 L
.6356 .41457 L
.66026 .41711 L
.68491 .42019 L
.70957 .42388 L
.73422 .42828 L
.75888 .43357 L
.77776 .43836 L
.78353 .43972 L
.80819 .44672 L
.83284 .45694 L
.8435 .46302 L
.8575 .47211 L
.87202 .48767 L
.87199 .51233 L
.8575 .52784 L
.84342 .53698 L
.83284 .54301 L
.80819 .55324 L
.78353 .56024 L
.77763 .56164 L
.75888 .5664 L
.73422 .57169 L
.70957 .5761 L
.68491 .57979 L
.66026 .58287 L
.6356 .58541 L
.62584 .58629 L
.61095 .58749 L
.58629 .58912 L
.56164 .59033 L
.53698 .59112 L
.51233 .59152 L
.48767 .59152 L
.46302 .59113 L
.43836 .59033 L
.41371 .58913 L
.38905 .5875 L
.37397 .58629 L
.3644 .58543 L
.33974 .58289 L
.31509 .57981 L
.29043 .57612 L
.26578 .57172 L
.24112 .56643 L
.22224 .56164 L
.21647 .56028 L
.19181 .55328 L
.16716 .54306 L
.1565 .53698 L
.1425 .52789 L
.12798 .51233 L
.12801 .48767 L
.1425 .47216 L
.15658 .46302 L
.16716 .45699 L
.19181 .44676 L
.21647 .43976 L
.22237 .43836 L
.24112 .4336 L
.26578 .42831 L
.29043 .4239 L
.31509 .42021 L
.33974 .41713 L
.3644 .41459 L
.37416 .41371 L
F
0 g
.38905 .41251 m
.41371 .41088 L
.43836 .40967 L
.46302 .40888 L
.48767 .40848 L
.51233 .40848 L
.53698 .40887 L
.56164 .40967 L
.58629 .41087 L
.61095 .4125 L
.62603 .41371 L
.6356 .41457 L
.66026 .41711 L
.68491 .42019 L
.70957 .42388 L
.73422 .42828 L
.75888 .43357 L
.77776 .43836 L
.78353 .43972 L
.80819 .44672 L
.83284 .45694 L
.8435 .46302 L
.8575 .47211 L
.87202 .48767 L
.87199 .51233 L
.8575 .52784 L
.84342 .53698 L
.83284 .54301 L
.80819 .55324 L
.78353 .56024 L
.77763 .56164 L
.75888 .5664 L
.73422 .57169 L
.70957 .5761 L
.68491 .57979 L
.66026 .58287 L
.6356 .58541 L
.62584 .58629 L
.61095 .58749 L
.58629 .58912 L
.56164 .59033 L
.53698 .59112 L
.51233 .59152 L
.48767 .59152 L
.46302 .59113 L
.43836 .59033 L
.41371 .58913 L
.38905 .5875 L
.37397 .58629 L
.3644 .58543 L
Mistroke
.33974 .58289 L
.31509 .57981 L
.29043 .57612 L
.26578 .57172 L
.24112 .56643 L
.22224 .56164 L
.21647 .56028 L
.19181 .55328 L
.16716 .54306 L
.1565 .53698 L
.1425 .52789 L
.12798 .51233 L
.12801 .48767 L
.1425 .47216 L
.15658 .46302 L
.16716 .45699 L
.19181 .44676 L
.21647 .43976 L
.22237 .43836 L
.24112 .4336 L
.26578 .42831 L
.29043 .4239 L
.31509 .42021 L
.33974 .41713 L
.3644 .41459 L
.37416 .41371 L
.38905 .41251 L
Mfstroke
.7 g
.31509 .43548 m
.33974 .43161 L
.3644 .42848 L
.38905 .42599 L
.41371 .42406 L
.43836 .42265 L
.46302 .42172 L
.48767 .42126 L
.51233 .42126 L
.53698 .42172 L
.56164 .42264 L
.58629 .42405 L
.61095 .42597 L
.6356 .42846 L
.66026 .43159 L
.68491 .43545 L
.70064 .43836 L
.70957 .43991 L
.73422 .44503 L
.75888 .45206 L
.78353 .46237 L
.78477 .46302 L
.80819 .47687 L
.8186 .48767 L
.81857 .51233 L
.80819 .52309 L
.78469 .53698 L
.78353 .53758 L
.75888 .54791 L
.73422 .55494 L
.70957 .56007 L
.70051 .56164 L
.68491 .56452 L
.66026 .56839 L
.6356 .57152 L
.61095 .57401 L
.58629 .57594 L
.56164 .57735 L
.53698 .57828 L
.51233 .57874 L
.48767 .57874 L
.46302 .57828 L
.43836 .57736 L
.41371 .57595 L
.38905 .57403 L
.3644 .57154 L
.33974 .56841 L
.31509 .56455 L
.29936 .56164 L
.29043 .56009 L
.26578 .55497 L
.24112 .54794 L
.21647 .53763 L
.21523 .53698 L
.19181 .52313 L
.1814 .51233 L
.18143 .48767 L
.19181 .47691 L
.21531 .46302 L
.21647 .46242 L
.24112 .45209 L
.26578 .44506 L
.29043 .43993 L
.29949 .43836 L
F
0 g
.31509 .43548 m
.33974 .43161 L
.3644 .42848 L
.38905 .42599 L
.41371 .42406 L
.43836 .42265 L
.46302 .42172 L
.48767 .42126 L
.51233 .42126 L
.53698 .42172 L
.56164 .42264 L
.58629 .42405 L
.61095 .42597 L
.6356 .42846 L
.66026 .43159 L
.68491 .43545 L
.70064 .43836 L
.70957 .43991 L
.73422 .44503 L
.75888 .45206 L
.78353 .46237 L
.78477 .46302 L
.80819 .47687 L
.8186 .48767 L
.81857 .51233 L
.80819 .52309 L
.78469 .53698 L
.78353 .53758 L
.75888 .54791 L
.73422 .55494 L
.70957 .56007 L
.70051 .56164 L
.68491 .56452 L
.66026 .56839 L
.6356 .57152 L
.61095 .57401 L
.58629 .57594 L
.56164 .57735 L
.53698 .57828 L
.51233 .57874 L
.48767 .57874 L
.46302 .57828 L
.43836 .57736 L
.41371 .57595 L
.38905 .57403 L
.3644 .57154 L
.33974 .56841 L
.31509 .56455 L
.29936 .56164 L
.29043 .56009 L
Mistroke
.26578 .55497 L
.24112 .54794 L
.21647 .53763 L
.21523 .53698 L
.19181 .52313 L
.1814 .51233 L
.18143 .48767 L
.19181 .47691 L
.21531 .46302 L
.21647 .46242 L
.24112 .45209 L
.26578 .44506 L
.29043 .43993 L
.29949 .43836 L
.31509 .43548 L
Mfstroke
.8 g
.41371 .43788 m
.43836 .43612 L
.46302 .43498 L
.48767 .43441 L
.51233 .43441 L
.53698 .43497 L
.56164 .43611 L
.58629 .43787 L
.59207 .43836 L
.61095 .43999 L
.6356 .44273 L
.66026 .44639 L
.68491 .45138 L
.70957 .45837 L
.72207 .46302 L
.73422 .46785 L
.75888 .48241 L
.76406 .48767 L
.76403 .51233 L
.75888 .51756 L
.73422 .53212 L
.72199 .53698 L
.70957 .5416 L
.68491 .54859 L
.66026 .55359 L
.6356 .55726 L
.61095 .56 L
.59194 .56164 L
.58629 .56212 L
.56164 .56388 L
.53698 .56502 L
.51233 .56559 L
.48767 .56559 L
.46302 .56503 L
.43836 .56389 L
.41371 .56213 L
.40793 .56164 L
.38905 .56001 L
.3644 .55727 L
.33974 .55361 L
.31509 .54862 L
.29043 .54163 L
.27793 .53698 L
.26578 .53215 L
.24112 .51759 L
.23594 .51233 L
.23597 .48767 L
.24112 .48244 L
.26578 .46788 L
.27801 .46302 L
.29043 .4584 L
.31509 .45141 L
.33974 .44641 L
.3644 .44274 L
.38905 .44 L
.40806 .43836 L
F
0 g
.41371 .43788 m
.43836 .43612 L
.46302 .43498 L
.48767 .43441 L
.51233 .43441 L
.53698 .43497 L
.56164 .43611 L
.58629 .43787 L
.59207 .43836 L
.61095 .43999 L
.6356 .44273 L
.66026 .44639 L
.68491 .45138 L
.70957 .45837 L
.72207 .46302 L
.73422 .46785 L
.75888 .48241 L
.76406 .48767 L
.76403 .51233 L
.75888 .51756 L
.73422 .53212 L
.72199 .53698 L
.70957 .5416 L
.68491 .54859 L
.66026 .55359 L
.6356 .55726 L
.61095 .56 L
.59194 .56164 L
.58629 .56212 L
.56164 .56388 L
.53698 .56502 L
.51233 .56559 L
.48767 .56559 L
.46302 .56503 L
.43836 .56389 L
.41371 .56213 L
.40793 .56164 L
.38905 .56001 L
.3644 .55727 L
.33974 .55361 L
.31509 .54862 L
.29043 .54163 L
.27793 .53698 L
.26578 .53215 L
.24112 .51759 L
.23594 .51233 L
.23597 .48767 L
.24112 .48244 L
.26578 .46788 L
.27801 .46302 L
Mistroke
.29043 .4584 L
.31509 .45141 L
.33974 .44641 L
.3644 .44274 L
.38905 .44 L
.40806 .43836 L
.41371 .43788 L
Mfstroke
.9 g
.3644 .46037 m
.38905 .45555 L
.41371 .45216 L
.43836 .44985 L
.46302 .44841 L
.48767 .44771 L
.51233 .44771 L
.53698 .4484 L
.56164 .44984 L
.58629 .45215 L
.61095 .45553 L
.6356 .46035 L
.64631 .46302 L
.66026 .46669 L
.68491 .47551 L
.7045 .48767 L
.70447 .51233 L
.68491 .52447 L
.66026 .53329 L
.64623 .53698 L
.6356 .53963 L
.61095 .54445 L
.58629 .54784 L
.56164 .55015 L
.53698 .55159 L
.51233 .55229 L
.48767 .55229 L
.46302 .5516 L
.43836 .55016 L
.41371 .54785 L
.38905 .54447 L
.3644 .53965 L
.35369 .53698 L
.33974 .53331 L
.31509 .52449 L
.2955 .51233 L
.29553 .48767 L
.31509 .47553 L
.33974 .46671 L
.35377 .46302 L
F
0 g
.3644 .46037 m
.38905 .45555 L
.41371 .45216 L
.43836 .44985 L
.46302 .44841 L
.48767 .44771 L
.51233 .44771 L
.53698 .4484 L
.56164 .44984 L
.58629 .45215 L
.61095 .45553 L
.6356 .46035 L
.64631 .46302 L
.66026 .46669 L
.68491 .47551 L
.7045 .48767 L
.70447 .51233 L
.68491 .52447 L
.66026 .53329 L
.64623 .53698 L
.6356 .53963 L
.61095 .54445 L
.58629 .54784 L
.56164 .55015 L
.53698 .55159 L
.51233 .55229 L
.48767 .55229 L
.46302 .5516 L
.43836 .55016 L
.41371 .54785 L
.38905 .54447 L
.3644 .53965 L
.35369 .53698 L
.33974 .53331 L
.31509 .52449 L
.2955 .51233 L
.29553 .48767 L
.31509 .47553 L
.33974 .46671 L
.35377 .46302 L
.3644 .46037 L
s
1 g
.38905 .47947 m
.41371 .47335 L
.43836 .46953 L
.46302 .46722 L
.48767 .46612 L
.51233 .46612 L
.53698 .46721 L
.56164 .46952 L
.58629 .47334 L
.61095 .47946 L
.63017 .48767 L
.63014 .51233 L
.61095 .52053 L
.58629 .52665 L
.56164 .53047 L
.53698 .53278 L
.51233 .53388 L
.48767 .53388 L
.46302 .53279 L
.43836 .53048 L
.41371 .52666 L
.38905 .52054 L
.36983 .51233 L
.36986 .48767 L
F
0 g
.38905 .47947 m
.41371 .47335 L
.43836 .46953 L
.46302 .46722 L
.48767 .46612 L
.51233 .46612 L
.53698 .46721 L
.56164 .46952 L
.58629 .47334 L
.61095 .47946 L
.63017 .48767 L
.63014 .51233 L
.61095 .52053 L
.58629 .52665 L
.56164 .53047 L
.53698 .53278 L
.51233 .53388 L
.48767 .53388 L
.46302 .53279 L
.43836 .53048 L
.41371 .52666 L
.38905 .52054 L
.36983 .51233 L
.36986 .48767 L
.38905 .47947 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.539 .722 .958 r
.39727 .59706 .40512 .60371 .41817 .60278 .41034 .59627 Mtetra
.504 .714 .966 r
.41034 .59627 .41817 .60278 .43129 .6024 .42349 .59607 Mtetra
.46 .702 .972 r
.42349 .59607 .43129 .6024 .44448 .60264 .43672 .59652 Mtetra
.407 .686 .976 r
.43672 .59652 .44448 .60264 .45776 .60352 .45003 .59765 Mtetra
.342 .664 .973 r
.45003 .59765 .45776 .60352 .47114 .60506 .46343 .59949 Mtetra
.267 .635 .963 r
.46343 .59949 .47114 .60506 .48462 .60726 .47694 .60202 Mtetra
.183 .598 .942 r
.47694 .60202 .48462 .60726 .49821 .61007 .49056 .60521 Mtetra
.096 .555 .91 r
.49056 .60521 .49821 .61007 .51192 .61343 .50431 .60898 Mtetra
.012 .51 .868 r
.50431 .60898 .51192 .61343 .52576 .61724 .51819 .61322 Mtetra
0 .468 .822 r
.51819 .61322 .52576 .61724 .53973 .62135 .53221 .6178 Mtetra
0 .435 .778 r
.53221 .6178 .53973 .62135 .55384 .62559 .54637 .62251 Mtetra
0 .415 .742 r
.54637 .62251 .55384 .62559 .5681 .62977 .56067 .62716 Mtetra
0 .414 .719 r
.56067 .62716 .5681 .62977 .58248 .63365 .57512 .6315 Mtetra
0 .432 .712 r
.57512 .6315 .58248 .63365 .597 .637 .58971 .63528 Mtetra
0 .472 .723 r
.58971 .63528 .597 .637 .61164 .63957 .60441 .63823 Mtetra
0 .533 .751 r
.60441 .63823 .61164 .63957 .62638 .64112 .61923 .64011 Mtetra
.049 .611 .792 r
.61923 .64011 .62638 .64112 .6412 .64146 .63414 .6407 Mtetra
.167 .701 .84 r
.63414 .6407 .6412 .64146 .65609 .64041 .64911 .6398 Mtetra
.3 .79 .886 r
.64911 .6398 .65609 .64041 .67102 .63784 .66412 .6373 Mtetra
.433 .867 .92 r
.66412 .6373 .67102 .63784 .68597 .63368 .67916 .63312 Mtetra
.552 .922 .938 r
.67916 .63312 .68597 .63368 .70092 .62793 .69419 .62723 Mtetra
.649 .955 .941 r
.69419 .62723 .70092 .62793 .71585 .62064 .70921 .61972 Mtetra
.722 .969 .933 r
.70921 .61972 .71585 .62064 .73075 .61192 .72419 .61069 Mtetra
.774 .971 .921 r
.72419 .61069 .73075 .61192 .74561 .60193 .73912 .60031 Mtetra
.809 .964 .908 r
.73912 .60031 .74561 .60193 .76043 .59088 .75401 .5888 Mtetra
.832 .953 .895 r
.75401 .5888 .76043 .59088 .77521 .57898 .76886 .5764 Mtetra
.845 .94 .886 r
.76886 .5764 .77521 .57898 .78995 .56649 .78366 .56338 Mtetra
.851 .927 .879 r
.78366 .56338 .78995 .56649 .80468 .55365 .79844 .54998 Mtetra
.852 .913 .874 r
.79844 .54998 .80468 .55365 .8194 .54068 .81321 .53645 Mtetra
.848 .899 .872 r
.81321 .53645 .8194 .54068 .83413 .52779 .82799 .52301 Mtetra
.842 .886 .872 r
.82799 .52301 .83413 .52779 .84889 .51517 .8428 .50986 Mtetra
.832 .873 .874 r
.8428 .50986 .84889 .51517 .8637 .50296 .85766 .49716 Mtetra
.821 .86 .876 r
.85766 .49716 .8637 .50296 .87858 .49128 .87258 .485 Mtetra
.808 .848 .879 r
.87258 .485 .87858 .49128 .89355 .48019 .88758 .47349 Mtetra
.795 .835 .883 r
.88758 .47349 .89355 .48019 .90861 .46975 .90269 .46266 Mtetra
.78 .824 .886 r
.90269 .46266 .90861 .46975 .92379 .45996 .9179 .45253 Mtetra
.766 .812 .89 r
.9179 .45253 .92379 .45996 .93908 .45082 .93324 .44308 Mtetra
.752 .802 .893 r
.93324 .44308 .93908 .45082 .9545 .44229 .9487 .43429 Mtetra
.739 .792 .895 r
.9487 .43429 .9545 .44229 .97004 .43434 .9643 .4261 Mtetra
.531 .719 .959 r
.38933 .59035 .39727 .59706 .41034 .59627 .40244 .58969 Mtetra
.493 .709 .967 r
.40244 .58969 .41034 .59627 .42349 .59607 .41562 .58967 Mtetra
.446 .696 .973 r
.41562 .58967 .42349 .59607 .43672 .59652 .42887 .59034 Mtetra
.387 .677 .975 r
.42887 .59034 .43672 .59652 .45003 .59765 .44221 .59173 Mtetra
.317 .651 .97 r
.44221 .59173 .45003 .59765 .46343 .59949 .45564 .59386 Mtetra
.236 .617 .956 r
.45564 .59386 .46343 .59949 .47694 .60202 .46918 .59673 Mtetra
.146 .575 .929 r
.46918 .59673 .47694 .60202 .49056 .60521 .48284 .60029 Mtetra
.054 .527 .891 r
.48284 .60029 .49056 .60521 .50431 .60898 .49662 .60447 Mtetra
0 .477 .844 r
.49662 .60447 .50431 .60898 .51819 .61322 .51053 .60916 Mtetra
0 .432 .794 r
.51053 .60916 .51819 .61322 .53221 .6178 .52459 .6142 Mtetra
0 .397 .747 r
.52459 .6142 .53221 .6178 .54637 .62251 .5388 .61939 Mtetra
0 .378 .71 r
.5388 .61939 .54637 .62251 .56067 .62716 .55316 .62452 Mtetra
0 .378 .688 r
.55316 .62452 .56067 .62716 .57512 .6315 .56767 .62932 Mtetra
0 .398 .684 r
.56767 .62932 .57512 .6315 .58971 .63528 .58231 .63353 Mtetra
0 .442 .699 r
.58231 .63353 .58971 .63528 .60441 .63823 .59709 .63687 Mtetra
0 .508 .732 r
.59709 .63687 .60441 .63823 .61923 .64011 .61198 .63907 Mtetra
.025 .593 .779 r
.61198 .63907 .61923 .64011 .63414 .6407 .62697 .63991 Mtetra
.152 .69 .833 r
.62697 .63991 .63414 .6407 .64911 .6398 .64202 .63918 Mtetra
.293 .786 .884 r
.64202 .63918 .64911 .6398 .66412 .6373 .65713 .63675 Mtetra
.434 .867 .921 r
.65713 .63675 .66412 .6373 .67916 .63312 .67225 .63253 Mtetra
.558 .925 .939 r
.67225 .63253 .67916 .63312 .69419 .62723 .68737 .62652 Mtetra
.658 .958 .94 r
.68737 .62652 .69419 .62723 .70921 .61972 .70247 .61877 Mtetra
.732 .971 .931 r
.70247 .61877 .70921 .61972 .72419 .61069 .71753 .60942 Mtetra
.784 .971 .917 r
.71753 .60942 .72419 .61069 .73912 .60031 .73255 .59865 Mtetra
.818 .963 .902 r
.73255 .59865 .73912 .60031 .75401 .5888 .74751 .58668 Mtetra
.84 .952 .889 r
.74751 .58668 .75401 .5888 .76886 .5764 .76242 .57378 Mtetra
.852 .939 .879 r
.76242 .57378 .76886 .5764 .78366 .56338 .77729 .56021 Mtetra
.858 .925 .872 r
.77729 .56021 .78366 .56338 .79844 .54998 .79213 .54625 Mtetra
.858 .912 .867 r
.79213 .54625 .79844 .54998 .81321 .53645 .80695 .53216 Mtetra
.855 .899 .866 r
.80695 .53216 .81321 .53645 .82799 .52301 .82178 .51817 Mtetra
.848 .886 .866 r
.82178 .51817 .82799 .52301 .8428 .50986 .83664 .50449 Mtetra
.839 .873 .868 r
.83664 .50449 .8428 .50986 .85766 .49716 .85154 .49128 Mtetra
.827 .86 .871 r
.85154 .49128 .85766 .49716 .87258 .485 .8665 .47866 Mtetra
.814 .848 .875 r
.8665 .47866 .87258 .485 .88758 .47349 .88155 .46671 Mtetra
.8 .836 .879 r
.88155 .46671 .88758 .47349 .90269 .46266 .8967 .45549 Mtetra
.785 .825 .883 r
.8967 .45549 .90269 .46266 .9179 .45253 .91196 .44502 Mtetra
.77 .813 .887 r
.91196 .44502 .9179 .45253 .93324 .44308 .92734 .43526 Mtetra
.756 .803 .891 r
.92734 .43526 .93324 .44308 .9487 .43429 .94285 .4262 Mtetra
.742 .793 .894 r
.94285 .4262 .9487 .43429 .9643 .4261 .95849 .41778 Mtetra
.522 .715 .96 r
.38133 .58356 .38933 .59035 .40244 .58969 .39446 .58305 Mtetra
.481 .705 .968 r
.39446 .58305 .40244 .58969 .41562 .58967 .40767 .58321 Mtetra
.431 .689 .973 r
.40767 .58321 .41562 .58967 .42887 .59034 .42095 .58408 Mtetra
.368 .667 .973 r
.42095 .58408 .42887 .59034 .44221 .59173 .43431 .58573 Mtetra
.292 .638 .965 r
.43431 .58573 .44221 .59173 .45564 .59386 .44777 .58815 Mtetra
.205 .599 .947 r
.44777 .58815 .45564 .59386 .46918 .59673 .46134 .59136 Mtetra
.11 .551 .916 r
.46134 .59136 .46918 .59673 .48284 .60029 .47502 .5953 Mtetra
.014 .498 .872 r
.47502 .5953 .48284 .60029 .49662 .60447 .48884 .59989 Mtetra
0 .445 .82 r
.48884 .59989 .49662 .60447 .51053 .60916 .50279 .60502 Mtetra
0 .397 .766 r
.50279 .60502 .51053 .60916 .52459 .6142 .51689 .61053 Mtetra
0 .362 .718 r
.51689 .61053 .52459 .6142 .5388 .61939 .53114 .6162 Mtetra
0 .343 .681 r
.53114 .6162 .5388 .61939 .55316 .62452 .54555 .62181 Mtetra
.244 0 0 r
.54555 .62181 .55316 .62452 .56767 .62932 .56011 .62707 Mtetra
.225 0 0 r
.56011 .62707 .56767 .62932 .58231 .63353 .57482 .63171 Mtetra
.178 0 0 r
.57482 .63171 .58231 .63353 .59709 .63687 .58967 .63544 Mtetra
0 .486 .717 r
.58967 .63544 .59709 .63687 .61198 .63907 .60464 .63797 Mtetra
.006 .577 .77 r
.60464 .63797 .61198 .63907 .62697 .63991 .6197 .63906 Mtetra
.14 .681 .83 r
.6197 .63906 .62697 .63991 .64202 .63918 .63484 .6385 Mtetra
.29 .783 .885 r
.63484 .6385 .64202 .63918 .65713 .63675 .65003 .63613 Mtetra
.438 .869 .924 r
.65003 .63613 .65713 .63675 .67225 .63253 .66524 .63188 Mtetra
.567 .927 .941 r
.66524 .63188 .67225 .63253 .68737 .62652 .68045 .62574 Mtetra
.669 .96 .941 r
.68045 .62574 .68737 .62652 .70247 .61877 .69563 .61777 Mtetra
.743 .971 .929 r
.69563 .61777 .70247 .61877 .71753 .60942 .71078 .6081 Mtetra
.793 .97 .913 r
.71078 .6081 .71753 .60942 .73255 .59865 .72588 .59692 Mtetra
.827 .961 .897 r
.72588 .59692 .73255 .59865 .74751 .58668 .74091 .58449 Mtetra
.848 .95 .883 r
.74091 .58449 .74751 .58668 .76242 .57378 .7559 .57108 Mtetra
.859 .936 .872 r
.7559 .57108 .76242 .57378 .77729 .56021 .77083 .55696 Mtetra
.865 .923 .865 r
.77083 .55696 .77729 .56021 .79213 .54625 .78573 .54244 Mtetra
.865 .91 .861 r
.78573 .54244 .79213 .54625 .80695 .53216 .80061 .52779 Mtetra
.861 .897 .859 r
.80061 .52779 .80695 .53216 .82178 .51817 .81549 .51324 Mtetra
.854 .884 .86 r
.81549 .51324 .82178 .51817 .83664 .50449 .8304 .49903 Mtetra
.844 .872 .862 r
.8304 .49903 .83664 .50449 .85154 .49128 .84534 .48531 Mtetra
.832 .86 .866 r
.84534 .48531 .85154 .49128 .8665 .47866 .86035 .47222 Mtetra
.819 .848 .87 r
.86035 .47222 .8665 .47866 .88155 .46671 .87545 .45984 Mtetra
.805 .837 .875 r
.87545 .45984 .88155 .46671 .8967 .45549 .89064 .44824 Mtetra
.79 .825 .88 r
.89064 .44824 .8967 .45549 .91196 .44502 .90594 .43741 Mtetra
.775 .814 .884 r
.90594 .43741 .91196 .44502 .92734 .43526 .92137 .42735 Mtetra
.76 .804 .888 r
.92137 .42735 .92734 .43526 .94285 .4262 .93693 .41802 Mtetra
.745 .794 .892 r
.93693 .41802 .94285 .4262 .95849 .41778 .95262 .40936 Mtetra
.514 .712 .961 r
.37325 .57671 .38133 .58356 .39446 .58305 .38641 .57633 Mtetra
.47 .7 .968 r
.38641 .57633 .39446 .58305 .40767 .58321 .39964 .57666 Mtetra
.416 .682 .972 r
.39964 .57666 .40767 .58321 .42095 .58408 .41295 .57775 Mtetra
.348 .657 .971 r
.41295 .57775 .42095 .58408 .43431 .58573 .42634 .57965 Mtetra
.268 .624 .96 r
.42634 .57965 .43431 .58573 .44777 .58815 .43982 .58237 Mtetra
.175 .58 .938 r
.43982 .58237 .44777 .58815 .46134 .59136 .45342 .5859 Mtetra
.075 .528 .901 r
.45342 .5859 .46134 .59136 .47502 .5953 .46713 .59022 Mtetra
0 .47 .852 r
.46713 .59022 .47502 .5953 .48884 .59989 .48097 .59522 Mtetra
0 .413 .796 r
.48097 .59522 .48884 .59989 .50279 .60502 .49496 .6008 Mtetra
0 .364 .739 r
.49496 .6008 .50279 .60502 .51689 .61053 .50909 .60676 Mtetra
0 .328 .69 r
.50909 .60676 .51689 .61053 .53114 .6162 .52339 .61291 Mtetra
0 .31 .655 r
.52339 .61291 .53114 .6162 .54555 .62181 .53785 .61899 Mtetra
.276 0 0 r
.53785 .61899 .54555 .62181 .56011 .62707 .55246 .62472 Mtetra
.254 0 0 r
.55246 .62472 .56011 .62707 .57482 .63171 .56723 .6298 Mtetra
.204 0 0 r
.56723 .6298 .57482 .63171 .58967 .63544 .58215 .63391 Mtetra
0 .467 .706 r
.58215 .63391 .58967 .63544 .60464 .63797 .59719 .63677 Mtetra
0 .564 .765 r
.59719 .63677 .60464 .63797 .6197 .63906 .61233 .63811 Mtetra
.133 .675 .831 r
.61233 .63811 .6197 .63906 .63484 .6385 .62755 .63771 Mtetra
.291 .783 .89 r
.62755 .63771 .63484 .6385 .65003 .63613 .64283 .63541 Mtetra
.446 .871 .93 r
.64283 .63541 .65003 .63613 .66524 .63188 .65813 .63113 Mtetra
.578 .93 .945 r
.65813 .63113 .66524 .63188 .68045 .62574 .67342 .62485 Mtetra
.681 .961 .942 r
.67342 .62485 .68045 .62574 .69563 .61777 .6887 .61665 Mtetra
.754 .971 .927 r
.6887 .61665 .69563 .61777 .71078 .6081 .70393 .60666 Mtetra
.803 .968 .909 r
.70393 .60666 .71078 .6081 .72588 .59692 .71911 .59509 Mtetra
.835 .959 .891 r
.71911 .59509 .72588 .59692 .74091 .58449 .73422 .58219 Mtetra
.855 .946 .877 r
.73422 .58219 .74091 .58449 .7559 .57108 .74928 .56826 Mtetra
.866 .933 .866 r
.74928 .56826 .7559 .57108 .77083 .55696 .76428 .55361 Mtetra
.87 .92 .858 r
.76428 .55361 .77083 .55696 .78573 .54244 .77925 .53852 Mtetra
.87 .907 .854 r
.77925 .53852 .78573 .54244 .80061 .52779 .79419 .5233 Mtetra
.866 .894 .853 r
.79419 .5233 .80061 .52779 .81549 .51324 .80912 .5082 Mtetra
.859 .882 .854 r
.80912 .5082 .81549 .51324 .8304 .49903 .82408 .49345 Mtetra
.849 .871 .857 r
.82408 .49345 .8304 .49903 .84534 .48531 .83908 .47923 Mtetra
.837 .859 .861 r
.83908 .47923 .84534 .48531 .86035 .47222 .85413 .46567 Mtetra
.824 .848 .866 r
.85413 .46567 .86035 .47222 .87545 .45984 .86927 .45287 Mtetra
.809 .837 .871 r
.86927 .45287 .87545 .45984 .89064 .44824 .88451 .44088 Mtetra
.794 .826 .876 r
.88451 .44088 .89064 .44824 .90594 .43741 .89986 .4297 Mtetra
.779 .815 .881 r
.89986 .4297 .90594 .43741 .92137 .42735 .91534 .41934 Mtetra
.763 .804 .886 r
.91534 .41934 .92137 .42735 .93693 .41802 .93095 .40974 Mtetra
.749 .795 .89 r
.93095 .40974 .93693 .41802 .95262 .40936 .94669 .40085 Mtetra
.505 .708 .962 r
.36509 .56977 .37325 .57671 .38641 .57633 .37828 .56954 Mtetra
.459 .694 .968 r
.37828 .56954 .38641 .57633 .39964 .57666 .39153 .57004 Mtetra
.401 .675 .971 r
.39153 .57004 .39964 .57666 .41295 .57775 .40486 .57133 Mtetra
.329 .647 .968 r
.40486 .57133 .41295 .57775 .42634 .57965 .41828 .57347 Mtetra
.243 .609 .954 r
.41828 .57347 .42634 .57965 .43982 .58237 .43179 .57648 Mtetra
.146 .561 .928 r
.43179 .57648 .43982 .58237 .45342 .5859 .44541 .58035 Mtetra
.042 .504 .886 r
.44541 .58035 .45342 .5859 .46713 .59022 .45915 .58503 Mtetra
0 .442 .833 r
.45915 .58503 .46713 .59022 .48097 .59522 .47302 .59044 Mtetra
0 .383 .773 r
.47302 .59044 .48097 .59522 .49496 .6008 .48703 .59645 Mtetra
0 .332 .715 r
.48703 .59645 .49496 .6008 .50909 .60676 .50121 .60287 Mtetra
0 .297 .666 r
.50121 .60287 .50909 .60676 .52339 .61291 .51554 .6095 Mtetra
.302 0 0 r
.51554 .6095 .52339 .61291 .53785 .61899 .53004 .61605 Mtetra
.304 0 0 r
.53004 .61605 .53785 .61899 .55246 .62472 .54471 .62223 Mtetra
.279 0 0 r
.54471 .62223 .55246 .62472 .56723 .6298 .55954 .62773 Mtetra
.225 0 0 r
.55954 .62773 .56723 .6298 .58215 .63391 .57452 .63223 Mtetra
0 .451 .7 r
.57452 .63223 .58215 .63391 .59719 .63677 .58963 .63541 Mtetra
0 .555 .765 r
.58963 .63541 .59719 .63677 .61233 .63811 .60485 .637 Mtetra
.131 .672 .837 r
.60485 .637 .61233 .63811 .62755 .63771 .62015 .63677 Mtetra
.297 .785 .898 r
.62015 .63677 .62755 .63771 .64283 .63541 .63552 .63453 Mtetra
.457 .875 .937 r
.63552 .63453 .64283 .63541 .65813 .63113 .6509 .63022 Mtetra
.592 .933 .95 r
.6509 .63022 .65813 .63113 .67342 .62485 .66629 .62381 Mtetra
.693 .961 .943 r
.66629 .62381 .67342 .62485 .6887 .61665 .68166 .61537 Mtetra
.765 .969 .926 r
.68166 .61537 .6887 .61665 .70393 .60666 .69698 .60506 Mtetra
.812 .965 .905 r
.69698 .60506 .70393 .60666 .71911 .59509 .71224 .59309 Mtetra
.843 .954 .886 r
.71224 .59309 .71911 .59509 .73422 .58219 .72743 .57974 Mtetra
.861 .942 .871 r
.72743 .57974 .73422 .58219 .74928 .56826 .74257 .5653 Mtetra
.871 .928 .859 r
.74257 .5653 .74928 .56826 .76428 .55361 .75764 .5501 Mtetra
.875 .915 .851 r
.75764 .5501 .76428 .55361 .77925 .53852 .77267 .53446 Mtetra
.875 .903 .847 r
.77267 .53446 .77925 .53852 .79419 .5233 .78768 .51868 Mtetra
.871 .891 .846 r
.78768 .51868 .79419 .5233 .80912 .5082 .80267 .50303 Mtetra
.863 .88 .848 r
.80267 .50303 .80912 .5082 .82408 .49345 .81768 .48775 Mtetra
.854 .869 .851 r
.81768 .48775 .82408 .49345 .83908 .47923 .83273 .47303 Mtetra
.842 .858 .856 r
.83273 .47303 .83908 .47923 .85413 .46567 .84784 .45901 Mtetra
.828 .847 .861 r
.84784 .45901 .85413 .46567 .86927 .45287 .86303 .44578 Mtetra
.814 .836 .867 r
.86303 .44578 .86927 .45287 .88451 .44088 .87831 .4334 Mtetra
.798 .825 .873 r
.87831 .4334 .88451 .44088 .89986 .4297 .89371 .42189 Mtetra
.782 .815 .878 r
.89371 .42189 .89986 .4297 .91534 .41934 .90924 .41122 Mtetra
.767 .805 .884 r
.90924 .41122 .91534 .41934 .93095 .40974 .9249 .40135 Mtetra
.752 .795 .888 r
.9249 .40135 .93095 .40974 .94669 .40085 .9407 .39223 Mtetra
.497 .705 .963 r
.35685 .56275 .36509 .56977 .37828 .56954 .37007 .56265 Mtetra
.448 .689 .968 r
.37007 .56265 .37828 .56954 .39153 .57004 .38335 .56332 Mtetra
.386 .667 .97 r
.38335 .56332 .39153 .57004 .40486 .57133 .3967 .56482 Mtetra
.31 .636 .965 r
.3967 .56482 .40486 .57133 .41828 .57347 .41014 .5672 Mtetra
.22 .594 .948 r
.41014 .5672 .41828 .57347 .43179 .57648 .42367 .57049 Mtetra
.118 .542 .917 r
.42367 .57049 .43179 .57648 .44541 .58035 .43732 .57467 Mtetra
.011 .481 .872 r
.43732 .57467 .44541 .58035 .45915 .58503 .45108 .57972 Mtetra
0 .416 .814 r
.45108 .57972 .45915 .58503 .47302 .59044 .46497 .58552 Mtetra
0 .354 .752 r
.46497 .58552 .47302 .59044 .48703 .59645 .47902 .59196 Mtetra
0 .304 .693 r
.47902 .59196 .48703 .59645 .50121 .60287 .49322 .59883 Mtetra
0 .269 .644 r
.49322 .59883 .50121 .60287 .51554 .6095 .5076 .60592 Mtetra
.328 0 0 r
.5076 .60592 .51554 .6095 .53004 .61605 .52214 .61293 Mtetra
.327 0 0 r
.52214 .61293 .53004 .61605 .54471 .62223 .53686 .61956 Mtetra
.299 0 0 r
.53686 .61956 .54471 .62223 .55954 .62773 .55174 .62549 Mtetra
.242 0 0 r
.55174 .62549 .55954 .62773 .57452 .63223 .56678 .63036 Mtetra
0 .439 .698 r
.56678 .63036 .57452 .63223 .58963 .63541 .58196 .63386 Mtetra
0 .549 .77 r
.58196 .63386 .58963 .63541 .60485 .637 .59726 .63569 Mtetra
.133 .671 .846 r
.59726 .63569 .60485 .637 .62015 .63677 .61265 .63561 Mtetra
.306 .788 .909 r
.61265 .63561 .62015 .63677 .63552 .63453 .62809 .63345 Mtetra
.47 .879 .947 r
.62809 .63345 .63552 .63453 .6509 .63022 .64357 .6291 Mtetra
.606 .935 .956 r
.64357 .6291 .6509 .63022 .66629 .62381 .65905 .62255 Mtetra
.707 .96 .945 r
.65905 .62255 .66629 .62381 .68166 .61537 .67451 .61389 Mtetra
.776 .966 .924 r
.67451 .61389 .68166 .61537 .69698 .60506 .68991 .60326 Mtetra
.821 .96 .902 r
.68991 .60326 .69698 .60506 .71224 .59309 .70526 .5909 Mtetra
.85 .949 .881 r
.70526 .5909 .71224 .59309 .72743 .57974 .72054 .57709 Mtetra
.867 .936 .865 r
.72054 .57709 .72743 .57974 .74257 .5653 .73576 .56215 Mtetra
.876 .923 .853 r
.73576 .56215 .74257 .5653 .75764 .5501 .7509 .54641 Mtetra
.88 .911 .845 r
.7509 .54641 .75764 .5501 .77267 .53446 .766 .53022 Mtetra
.879 .899 .841 r
.766 .53022 .77267 .53446 .78768 .51868 .78107 .51388 Mtetra
.875 .887 .84 r
.78107 .51388 .78768 .51868 .80267 .50303 .79613 .4977 Mtetra
.867 .877 .842 r
.79613 .4977 .80267 .50303 .81768 .48775 .8112 .48189 Mtetra
.858 .866 .845 r
.8112 .48189 .81768 .48775 .83273 .47303 .8263 .46668 Mtetra
.846 .856 .85 r
.8263 .46668 .83273 .47303 .84784 .45901 .84146 .4522 Mtetra
.832 .846 .856 r
.84146 .4522 .84784 .45901 .86303 .44578 .8567 .43856 Mtetra
.818 .835 .863 r
.8567 .43856 .86303 .44578 .87831 .4334 .87204 .4258 Mtetra
.802 .825 .869 r
.87204 .4258 .87831 .4334 .89371 .42189 .88749 .41395 Mtetra
.786 .815 .875 r
.88749 .41395 .89371 .42189 .90924 .41122 .90307 .40298 Mtetra
.77 .805 .881 r
.90307 .40298 .90924 .41122 .9249 .40135 .91878 .39285 Mtetra
.755 .796 .886 r
.91878 .39285 .9249 .40135 .9407 .39223 .93463 .3835 Mtetra
.489 .701 .963 r
.34854 .55564 .35685 .56275 .37007 .56265 .36178 .55567 Mtetra
.437 .684 .968 r
.36178 .55567 .37007 .56265 .38335 .56332 .37508 .5565 Mtetra
.372 .659 .969 r
.37508 .5565 .38335 .56332 .3967 .56482 .38846 .55819 Mtetra
.292 .625 .961 r
.38846 .55819 .3967 .56482 .41014 .5672 .40192 .56081 Mtetra
.198 .58 .941 r
.40192 .56081 .41014 .5672 .42367 .57049 .41547 .56437 Mtetra
.092 .523 .907 r
.41547 .56437 .42367 .57049 .43732 .57467 .42914 .56887 Mtetra
0 .458 .857 r
.42914 .56887 .43732 .57467 .45108 .57972 .44292 .57426 Mtetra
0 .391 .797 r
.44292 .57426 .45108 .57972 .46497 .58552 .45684 .58045 Mtetra
0 .328 .732 r
.45684 .58045 .46497 .58552 .47902 .59196 .47091 .5873 Mtetra
0 .278 .673 r
.47091 .5873 .47902 .59196 .49322 .59883 .48515 .59461 Mtetra
0 .244 .627 r
.48515 .59461 .49322 .59883 .5076 .60592 .49955 .60214 Mtetra
.349 0 0 r
.49955 .60214 .5076 .60592 .52214 .61293 .51414 .60961 Mtetra
.346 0 0 r
.51414 .60961 .52214 .61293 .53686 .61956 .5289 .61668 Mtetra
.315 0 0 r
.5289 .61668 .53686 .61956 .55174 .62549 .54384 .62301 Mtetra
.254 0 0 r
.54384 .62301 .55174 .62549 .56678 .63036 .55894 .62825 Mtetra
0 .43 .701 r
.55894 .62825 .56678 .63036 .58196 .63386 .57419 .63206 Mtetra
0 .545 .778 r
.57419 .63206 .58196 .63386 .59726 .63569 .58956 .63413 Mtetra
.14 .673 .859 r
.58956 .63413 .59726 .63569 .61265 .63561 .60503 .63421 Mtetra
.32 .792 .923 r
.60503 .63421 .61265 .63561 .62809 .63345 .62056 .6321 Mtetra
.487 .882 .957 r
.62056 .6321 .62809 .63345 .64357 .6291 .63613 .62772 Mtetra
.622 .935 .962 r
.63613 .62772 .64357 .6291 .65905 .62255 .6517 .62104 Mtetra
.72 .958 .946 r
.6517 .62104 .65905 .62255 .67451 .61389 .66724 .61214 Mtetra
.786 .961 .922 r
.66724 .61214 .67451 .61389 .68991 .60326 .68274 .6012 Mtetra
.829 .954 .898 r
.68274 .6012 .68991 .60326 .70526 .5909 .69818 .58846 Mtetra
.856 .942 .876 r
.69818 .58846 .70526 .5909 .72054 .57709 .71355 .5742 Mtetra
.872 .93 .859 r
.71355 .5742 .72054 .57709 .73576 .56215 .72884 .55876 Mtetra
.88 .917 .846 r
.72884 .55876 .73576 .56215 .7509 .54641 .74407 .5425 Mtetra
.884 .905 .839 r
.74407 .5425 .7509 .54641 .766 .53022 .75924 .52577 Mtetra
.882 .894 .834 r
.75924 .52577 .766 .53022 .78107 .51388 .77438 .50889 Mtetra
.878 .883 .834 r
.77438 .50889 .78107 .51388 .79613 .4977 .7895 .49217 Mtetra
.871 .873 .836 r
.7895 .49217 .79613 .4977 .8112 .48189 .80462 .47586 Mtetra
.861 .863 .84 r
.80462 .47586 .8112 .48189 .8263 .46668 .81979 .46017 Mtetra
.849 .854 .845 r
.81979 .46017 .8263 .46668 .84146 .4522 .835 .44524 Mtetra
.836 .844 .852 r
.835 .44524 .84146 .4522 .8567 .43856 .8503 .43119 Mtetra
.821 .834 .859 r
.8503 .43119 .8567 .43856 .87204 .4258 .86569 .41806 Mtetra
.805 .824 .866 r
.86569 .41806 .87204 .4258 .88749 .41395 .8812 .40588 Mtetra
.789 .815 .872 r
.8812 .40588 .88749 .41395 .90307 .40298 .89683 .39462 Mtetra
.773 .805 .879 r
.89683 .39462 .90307 .40298 .91878 .39285 .9126 .38423 Mtetra
.757 .796 .884 r
.9126 .38423 .91878 .39285 .93463 .3835 .9285 .37466 Mtetra
.481 .697 .963 r
.34014 .54844 .34854 .55564 .36178 .55567 .35341 .54859 Mtetra
.427 .678 .968 r
.35341 .54859 .36178 .55567 .37508 .5565 .36674 .54957 Mtetra
.359 .651 .967 r
.36674 .54957 .37508 .5565 .38846 .55819 .38014 .55145 Mtetra
.275 .614 .957 r
.38014 .55145 .38846 .55819 .40192 .56081 .39362 .55429 Mtetra
.177 .566 .935 r
.39362 .55429 .40192 .56081 .41547 .56437 .40719 .55811 Mtetra
.069 .505 .897 r
.40719 .55811 .41547 .56437 .42914 .56887 .42087 .56291 Mtetra
0 .437 .844 r
.42087 .56291 .42914 .56887 .44292 .57426 .43468 .56863 Mtetra
0 .368 .781 r
.43468 .56863 .44292 .57426 .45684 .58045 .44862 .57519 Mtetra
0 .305 .716 r
.44862 .57519 .45684 .58045 .47091 .5873 .46272 .58244 Mtetra
0 .255 .657 r
.46272 .58244 .47091 .5873 .48515 .59461 .47698 .59018 Mtetra
.347 0 0 r
.47698 .59018 .48515 .59461 .49955 .60214 .49142 .59814 Mtetra
.367 0 0 r
.49142 .59814 .49955 .60214 .51414 .60961 .50604 .60604 Mtetra
.36 0 0 r
.50604 .60604 .51414 .60961 .5289 .61668 .52084 .61354 Mtetra
.327 0 0 r
.52084 .61354 .5289 .61668 .54384 .62301 .53583 .62027 Mtetra
.262 0 0 r
.53583 .62027 .54384 .62301 .55894 .62825 .55099 .62586 Mtetra
0 .425 .709 r
.55099 .62586 .55894 .62825 .57419 .63206 .56631 .62997 Mtetra
0 .545 .791 r
.56631 .62997 .57419 .63206 .58956 .63413 .58175 .63227 Mtetra
.152 .677 .874 r
.58175 .63227 .58956 .63413 .60503 .63421 .5973 .63249 Mtetra
.336 .797 .938 r
.5973 .63249 .60503 .63421 .62056 .6321 .61291 .63044 Mtetra
.505 .885 .968 r
.61291 .63044 .62056 .6321 .63613 .62772 .62857 .62602 Mtetra
.638 .934 .967 r
.62857 .62602 .63613 .62772 .6517 .62104 .64423 .61921 Mtetra
.732 .954 .947 r
.64423 .61921 .6517 .62104 .66724 .61214 .65987 .61009 Mtetra
.795 .955 .92 r
.65987 .61009 .66724 .61214 .68274 .6012 .67546 .59885 Mtetra
.835 .947 .893 r
.67546 .59885 .68274 .6012 .69818 .58846 .69099 .58572 Mtetra
.861 .935 .871 r
.69099 .58572 .69818 .58846 .71355 .5742 .70644 .57102 Mtetra
.876 .922 .853 r
.70644 .57102 .71355 .5742 .72884 .55876 .72182 .55511 Mtetra
.884 .91 .84 r
.72182 .55511 .72884 .55876 .74407 .5425 .73713 .53834 Mtetra
.886 .898 .832 r
.73713 .53834 .74407 .5425 .75924 .52577 .75237 .52108 Mtetra
.885 .888 .828 r
.75237 .52108 .75924 .52577 .77438 .50889 .76758 .50367 Mtetra
.881 .878 .828 r
.76758 .50367 .77438 .50889 .7895 .49217 .78277 .48644 Mtetra
.874 .869 .83 r
.78277 .48644 .7895 .49217 .80462 .47586 .79796 .46963 Mtetra
.864 .86 .834 r
.79796 .46963 .80462 .47586 .81979 .46017 .81319 .45347 Mtetra
.852 .851 .84 r
.81319 .45347 .81979 .46017 .835 .44524 .82846 .43811 Mtetra
.839 .842 .847 r
.82846 .43811 .835 .44524 .8503 .43119 .84381 .42365 Mtetra
.824 .833 .855 r
.84381 .42365 .8503 .43119 .86569 .41806 .85926 .41017 Mtetra
.809 .823 .862 r
.85926 .41017 .86569 .41806 .8812 .40588 .87482 .39766 Mtetra
.792 .814 .869 r
.87482 .39766 .8812 .40588 .89683 .39462 .89051 .38612 Mtetra
.776 .805 .876 r
.89051 .38612 .89683 .39462 .9126 .38423 .90634 .37548 Mtetra
.76 .796 .882 r
.90634 .37548 .9126 .38423 .9285 .37466 .9223 .36569 Mtetra
.474 .693 .963 r
.33167 .54114 .34014 .54844 .35341 .54859 .34496 .5414 Mtetra
.417 .673 .967 r
.34496 .5414 .35341 .54859 .36674 .54957 .35831 .54252 Mtetra
.346 .644 .965 r
.35831 .54252 .36674 .54957 .38014 .55145 .37173 .54458 Mtetra
.26 .604 .953 r
.37173 .54458 .38014 .55145 .39362 .55429 .38523 .54763 Mtetra
.159 .552 .928 r
.38523 .54763 .39362 .55429 .40719 .55811 .39882 .5517 Mtetra
.047 .489 .887 r
.39882 .5517 .40719 .55811 .42087 .56291 .41252 .55678 Mtetra
0 .418 .832 r
.41252 .55678 .42087 .56291 .43468 .56863 .42635 .56283 Mtetra
0 .347 .767 r
.42635 .56283 .43468 .56863 .44862 .57519 .44031 .56974 Mtetra
0 .284 .702 r
.44031 .56974 .44862 .57519 .46272 .58244 .45442 .57737 Mtetra
0 .235 .644 r
.45442 .57737 .46272 .58244 .47698 .59018 .46871 .5855 Mtetra
.363 0 0 r
.46871 .5855 .47698 .59018 .49142 .59814 .48318 .59388 Mtetra
.38 0 0 r
.48318 .59388 .49142 .59814 .50604 .60604 .49784 .6022 Mtetra
.371 0 0 r
.49784 .6022 .50604 .60604 .52084 .61354 .51268 .61009 Mtetra
.334 0 0 r
.51268 .61009 .52084 .61354 .53583 .62027 .52772 .6172 Mtetra
.265 0 0 r
.52772 .6172 .53583 .62027 .55099 .62586 .54294 .62314 Mtetra
0 .422 .721 r
.54294 .62314 .55099 .62586 .56631 .62997 .55831 .62753 Mtetra
0 .547 .807 r
.55831 .62753 .56631 .62997 .58175 .63227 .57382 .63004 Mtetra
.167 .682 .892 r
.57382 .63004 .58175 .63227 .5973 .63249 .58945 .6304 Mtetra
.356 .802 .953 r
.58945 .6304 .5973 .63249 .61291 .63044 .60515 .62841 Mtetra
.524 .886 .977 r
.60515 .62841 .61291 .63044 .62857 .62602 .62089 .62395 Mtetra
.653 .931 .971 r
.62089 .62395 .62857 .62602 .64423 .61921 .63664 .61701 Mtetra
.743 .947 .946 r
.63664 .61701 .64423 .61921 .65987 .61009 .65237 .60768 Mtetra
.803 .947 .917 r
.65237 .60768 .65987 .61009 .67546 .59885 .66806 .59613 Mtetra
.841 .938 .889 r
.66806 .59613 .67546 .59885 .69099 .58572 .68368 .58264 Mtetra
.865 .926 .865 r
.68368 .58264 .69099 .58572 .70644 .57102 .69922 .56752 Mtetra
.879 .914 .847 r
.69922 .56752 .70644 .57102 .72182 .55511 .71469 .55114 Mtetra
.886 .902 .835 r
.71469 .55114 .72182 .55511 .73713 .53834 .73008 .53387 Mtetra
.888 .892 .827 r
.73008 .53387 .73713 .53834 .75237 .52108 .74541 .51611 Mtetra
.887 .882 .823 r
.74541 .51611 .75237 .52108 .76758 .50367 .76069 .49819 Mtetra
.883 .873 .822 r
.76069 .49819 .76758 .50367 .78277 .48644 .77595 .48046 Mtetra
.876 .864 .824 r
.77595 .48046 .78277 .48644 .79796 .46963 .79121 .46317 Mtetra
.866 .856 .829 r
.79121 .46317 .79796 .46963 .81319 .45347 .8065 .44656 Mtetra
.855 .848 .835 r
.8065 .44656 .81319 .45347 .82846 .43811 .82183 .43078 Mtetra
.842 .839 .843 r
.82183 .43078 .82846 .43811 .84381 .42365 .83725 .41594 Mtetra
.827 .831 .851 r
.83725 .41594 .84381 .42365 .85926 .41017 .85276 .40211 Mtetra
.811 .822 .859 r
.85276 .40211 .85926 .41017 .87482 .39766 .86838 .3893 Mtetra
.795 .813 .866 r
.86838 .3893 .87482 .39766 .89051 .38612 .88412 .37748 Mtetra
.778 .804 .874 r
.88412 .37748 .89051 .38612 .90634 .37548 .90001 .3666 Mtetra
.762 .795 .88 r
.90001 .3666 .90634 .37548 .9223 .36569 .91603 .3566 Mtetra
.467 .689 .963 r
.32311 .53374 .33167 .54114 .34496 .5414 .33643 .5341 Mtetra
.409 .667 .966 r
.33643 .5341 .34496 .5414 .35831 .54252 .3498 .53536 Mtetra
.335 .636 .963 r
.3498 .53536 .35831 .54252 .37173 .54458 .36324 .53758 Mtetra
.246 .594 .949 r
.36324 .53758 .37173 .54458 .38523 .54763 .37676 .54082 Mtetra
.142 .539 .922 r
.37676 .54082 .38523 .54763 .39882 .5517 .39037 .54512 Mtetra
.029 .473 .878 r
.39037 .54512 .39882 .5517 .41252 .55678 .40409 .55047 Mtetra
0 .401 .821 r
.40409 .55047 .41252 .55678 .42635 .56283 .41793 .55682 Mtetra
0 .329 .755 r
.41793 .55682 .42635 .56283 .44031 .56974 .43191 .56406 Mtetra
0 .266 .69 r
.43191 .56406 .44031 .56974 .45442 .57737 .44604 .57205 Mtetra
0 .218 .635 r
.44604 .57205 .45442 .57737 .46871 .5855 .46035 .58056 Mtetra
.375 0 0 r
.46035 .58056 .46871 .5855 .48318 .59388 .47484 .58933 Mtetra
.389 0 0 r
.47484 .58933 .48318 .59388 .49784 .6022 .48953 .59804 Mtetra
.377 0 0 r
.48953 .59804 .49784 .6022 .51268 .61009 .50442 .60632 Mtetra
.337 0 0 r
.50442 .60632 .51268 .61009 .52772 .6172 .5195 .61378 Mtetra
0 .319 .659 r
.5195 .61378 .52772 .6172 .54294 .62314 .53477 .62003 Mtetra
0 .423 .736 r
.53477 .62003 .54294 .62314 .55831 .62753 .5502 .62469 Mtetra
.002 .552 .826 r
.5502 .62469 .55831 .62753 .57382 .63004 .56579 .62741 Mtetra
.187 .688 .911 r
.56579 .62741 .57382 .63004 .58945 .6304 .58148 .6279 Mtetra
.377 .806 .967 r
.58148 .6279 .58945 .6304 .60515 .62841 .59726 .62595 Mtetra
.543 .885 .985 r
.59726 .62595 .60515 .62841 .62089 .62395 .61309 .62145 Mtetra
.668 .926 .973 r
.61309 .62145 .62089 .62395 .63664 .61701 .62894 .61439 Mtetra
.754 .939 .945 r
.62894 .61439 .63664 .61701 .65237 .60768 .64476 .60485 Mtetra
.81 .937 .913 r
.64476 .60485 .65237 .60768 .66806 .59613 .66054 .59302 Mtetra
.845 .928 .884 r
.66054 .59302 .66806 .59613 .68368 .58264 .67625 .57917 Mtetra
.867 .917 .86 r
.67625 .57917 .68368 .58264 .69922 .56752 .69189 .56365 Mtetra
.881 .905 .842 r
.69189 .56365 .69922 .56752 .71469 .55114 .70745 .54681 Mtetra
.887 .894 .829 r
.70745 .54681 .71469 .55114 .73008 .53387 .72292 .52908 Mtetra
.89 .884 .821 r
.72292 .52908 .73008 .53387 .74541 .51611 .73833 .51082 Mtetra
.888 .875 .817 r
.73833 .51082 .74541 .51611 .76069 .49819 .75369 .49242 Mtetra
.884 .867 .817 r
.75369 .49242 .76069 .49819 .77595 .48046 .76903 .47421 Mtetra
.877 .859 .819 r
.76903 .47421 .77595 .48046 .79121 .46317 .78436 .45647 Mtetra
.868 .852 .824 r
.78436 .45647 .79121 .46317 .8065 .44656 .79971 .43943 Mtetra
.857 .844 .831 r
.79971 .43943 .8065 .44656 .82183 .43078 .81512 .42325 Mtetra
.844 .836 .839 r
.81512 .42325 .82183 .43078 .83725 .41594 .8306 .40804 Mtetra
.829 .829 .847 r
.8306 .40804 .83725 .41594 .85276 .40211 .84617 .39388 Mtetra
.814 .82 .855 r
.84617 .39388 .85276 .40211 .86838 .3893 .86185 .38077 Mtetra
.797 .812 .864 r
.86185 .38077 .86838 .3893 .88412 .37748 .87766 .36868 Mtetra
.781 .803 .871 r
.87766 .36868 .88412 .37748 .90001 .3666 .8936 .35758 Mtetra
.764 .795 .878 r
.8936 .35758 .90001 .3666 .91603 .3566 .90969 .34737 Mtetra
.461 .685 .963 r
.31448 .52622 .32311 .53374 .33643 .5341 .32781 .52668 Mtetra
.4 .662 .965 r
.32781 .52668 .33643 .5341 .3498 .53536 .34121 .52806 Mtetra
.325 .629 .961 r
.34121 .52806 .3498 .53536 .36324 .53758 .35467 .53043 Mtetra
.233 .585 .946 r
.35467 .53043 .36324 .53758 .37676 .54082 .36821 .53385 Mtetra
.127 .527 .916 r
.36821 .53385 .37676 .54082 .39037 .54512 .38183 .53837 Mtetra
.013 .459 .871 r
.38183 .53837 .39037 .54512 .40409 .55047 .39557 .54396 Mtetra
0 .385 .812 r
.39557 .54396 .40409 .55047 .41793 .55682 .40942 .55059 Mtetra
0 .313 .746 r
.40942 .55059 .41793 .55682 .43191 .56406 .42341 .55814 Mtetra
0 .251 .682 r
.42341 .55814 .43191 .56406 .44604 .57205 .43757 .56646 Mtetra
0 .204 .629 r
.43757 .56646 .44604 .57205 .46035 .58056 .4519 .57532 Mtetra
.382 0 0 r
.4519 .57532 .46035 .58056 .47484 .58933 .46641 .58445 Mtetra
.394 0 0 r
.46641 .58445 .47484 .58933 .48953 .59804 .48113 .59352 Mtetra
.379 0 0 r
.48113 .59352 .48953 .59804 .50442 .60632 .49605 .60216 Mtetra
.336 0 0 r
.49605 .60216 .50442 .60632 .5195 .61378 .51117 .60996 Mtetra
0 .318 .673 r
.51117 .60996 .5195 .61378 .53477 .62003 .52649 .61651 Mtetra
0 .426 .754 r
.52649 .61651 .53477 .62003 .5502 .62469 .54198 .62141 Mtetra
.02 .558 .847 r
.54198 .62141 .5502 .62469 .56579 .62741 .55763 .62432 Mtetra
.209 .694 .929 r
.55763 .62432 .56579 .62741 .58148 .6279 .5734 .62493 Mtetra
.399 .808 .98 r
.5734 .62493 .58148 .6279 .59726 .62595 .58926 .62302 Mtetra
.561 .882 .991 r
.58926 .62302 .59726 .62595 .61309 .62145 .60518 .61848 Mtetra
.681 .918 .973 r
.60518 .61848 .61309 .62145 .62894 .61439 .62111 .61129 Mtetra
.762 .929 .942 r
.62111 .61129 .62894 .61439 .64476 .60485 .63703 .60155 Mtetra
.815 .926 .909 r
.63703 .60155 .64476 .60485 .66054 .59302 .6529 .58945 Mtetra
.848 .917 .879 r
.6529 .58945 .66054 .59302 .67625 .57917 .66871 .57526 Mtetra
.869 .906 .855 r
.66871 .57526 .67625 .57917 .69189 .56365 .68444 .55935 Mtetra
.882 .895 .836 r
.68444 .55935 .69189 .56365 .70745 .54681 .70009 .5421 Mtetra
.888 .885 .824 r
.70009 .5421 .70745 .54681 .72292 .52908 .71566 .52391 Mtetra
.89 .876 .816 r
.71566 .52391 .72292 .52908 .73833 .51082 .73115 .5052 Mtetra
.889 .868 .812 r
.73115 .5052 .73833 .51082 .75369 .49242 .74659 .48634 Mtetra
.885 .861 .812 r
.74659 .48634 .75369 .49242 .76903 .47421 .76201 .46768 Mtetra
.878 .854 .814 r
.76201 .46768 .76903 .47421 .78436 .45647 .77741 .4495 Mtetra
.869 .847 .819 r
.77741 .4495 .78436 .45647 .79971 .43943 .79284 .43205 Mtetra
.858 .84 .826 r
.79284 .43205 .79971 .43943 .81512 .42325 .80831 .41549 Mtetra
.845 .833 .834 r
.80831 .41549 .81512 .42325 .8306 .40804 .82386 .39994 Mtetra
.831 .826 .843 r
.82386 .39994 .8306 .40804 .84617 .39388 .83949 .38546 Mtetra
.815 .818 .852 r
.83949 .38546 .84617 .39388 .86185 .38077 .85524 .37207 Mtetra
.799 .811 .861 r
.85524 .37207 .86185 .38077 .87766 .36868 .87111 .35973 Mtetra
.783 .802 .869 r
.87111 .35973 .87766 .36868 .8936 .35758 .88712 .3484 Mtetra
.766 .794 .876 r
.88712 .3484 .8936 .35758 .90969 .34737 .90327 .338 Mtetra
.456 .682 .962 r
.30576 .51859 .31448 .52622 .32781 .52668 .31912 .51913 Mtetra
.393 .657 .964 r
.31912 .51913 .32781 .52668 .34121 .52806 .33254 .52062 Mtetra
.316 .622 .959 r
.33254 .52062 .34121 .52806 .35467 .53043 .34601 .52312 Mtetra
.222 .576 .942 r
.34601 .52312 .35467 .53043 .36821 .53385 .35957 .52671 Mtetra
.115 .517 .911 r
.35957 .52671 .36821 .53385 .38183 .53837 .37321 .53142 Mtetra
.001 .447 .864 r
.37321 .53142 .38183 .53837 .39557 .54396 .38696 .53724 Mtetra
0 .372 .805 r
.38696 .53724 .39557 .54396 .40942 .55059 .40082 .54412 Mtetra
0 .3 .739 r
.40082 .54412 .40942 .55059 .42341 .55814 .41483 .55195 Mtetra
0 .239 .677 r
.41483 .55195 .42341 .55814 .43757 .56646 .429 .56057 Mtetra
0 .194 .626 r
.429 .56057 .43757 .56646 .4519 .57532 .44335 .56976 Mtetra
.386 0 0 r
.44335 .56976 .4519 .57532 .46641 .58445 .45789 .57922 Mtetra
.395 0 0 r
.45789 .57922 .46641 .58445 .48113 .59352 .47263 .58863 Mtetra
.377 0 0 r
.47263 .58863 .48113 .59352 .49605 .60216 .48758 .59758 Mtetra
0 .239 .628 r
.48758 .59758 .49605 .60216 .51117 .60996 .50274 .60569 Mtetra
0 .32 .69 r
.50274 .60569 .51117 .60996 .52649 .61651 .51811 .61251 Mtetra
0 .432 .774 r
.51811 .61251 .52649 .61651 .54198 .62141 .53365 .61764 Mtetra
.042 .565 .867 r
.53365 .61764 .54198 .62141 .55763 .62432 .54936 .62072 Mtetra
.234 .699 .946 r
.54936 .62072 .55763 .62432 .5734 .62493 .56521 .62143 Mtetra
.422 .807 .99 r
.56521 .62143 .5734 .62493 .58926 .62302 .58114 .61956 Mtetra
.578 .875 .994 r
.58114 .61956 .58926 .62302 .60518 .61848 .59714 .61498 Mtetra
.692 .908 .971 r
.59714 .61498 .60518 .61848 .62111 .61129 .61317 .60767 Mtetra
.768 .917 .938 r
.61317 .60767 .62111 .61129 .63703 .60155 .62918 .59773 Mtetra
.818 .914 .903 r
.62918 .59773 .63703 .60155 .6529 .58945 .64515 .58537 Mtetra
.85 .905 .873 r
.64515 .58537 .6529 .58945 .66871 .57526 .66105 .57087 Mtetra
.87 .895 .849 r
.66105 .57087 .66871 .57526 .68444 .55935 .67688 .5546 Mtetra
.882 .885 .831 r
.67688 .5546 .68444 .55935 .70009 .5421 .69262 .53695 Mtetra
.888 .876 .818 r
.69262 .53695 .70009 .5421 .71566 .52391 .70828 .51834 Mtetra
.89 .868 .811 r
.70828 .51834 .71566 .52391 .73115 .5052 .72386 .49919 Mtetra
.889 .861 .807 r
.72386 .49919 .73115 .5052 .74659 .48634 .73939 .4799 Mtetra
.885 .854 .807 r
.73939 .4799 .74659 .48634 .76201 .46768 .75488 .46082 Mtetra
.879 .848 .81 r
.75488 .46082 .76201 .46768 .77741 .4495 .77037 .44224 Mtetra
.87 .842 .815 r
.77037 .44224 .77741 .4495 .79284 .43205 .78587 .4244 Mtetra
.859 .836 .822 r
.78587 .4244 .79284 .43205 .80831 .41549 .80142 .40749 Mtetra
.847 .83 .831 r
.80142 .40749 .80831 .41549 .82386 .39994 .81703 .39161 Mtetra
.833 .823 .84 r
.81703 .39161 .82386 .39994 .83949 .38546 .83274 .37684 Mtetra
.817 .816 .849 r
.83274 .37684 .83949 .38546 .85524 .37207 .84855 .36318 Mtetra
.801 .809 .858 r
.84855 .36318 .85524 .37207 .87111 .35973 .86449 .35061 Mtetra
.784 .801 .866 r
.86449 .35061 .87111 .35973 .88712 .3484 .88056 .33907 Mtetra
.768 .794 .874 r
.88056 .33907 .88712 .3484 .90327 .338 .89678 .32848 Mtetra
.451 .679 .962 r
.29696 .51084 .30576 .51859 .31912 .51913 .31034 .51146 Mtetra
.387 .652 .963 r
.31034 .51146 .31912 .51913 .33254 .52062 .32378 .51303 Mtetra
.308 .616 .956 r
.32378 .51303 .33254 .52062 .34601 .52312 .33728 .51566 Mtetra
.214 .568 .939 r
.33728 .51566 .34601 .52312 .35957 .52671 .35085 .51939 Mtetra
.106 .507 .907 r
.35085 .51939 .35957 .52671 .37321 .53142 .3645 .52427 Mtetra
0 .437 .859 r
.3645 .52427 .37321 .53142 .38696 .53724 .37826 .53029 Mtetra
0 .362 .799 r
.37826 .53029 .38696 .53724 .40082 .54412 .39214 .53739 Mtetra
0 .29 .735 r
.39214 .53739 .40082 .54412 .41483 .55195 .40616 .54547 Mtetra
0 .23 .675 r
.40616 .54547 .41483 .55195 .429 .56057 .42035 .55437 Mtetra
0 .186 .627 r
.42035 .55437 .429 .56057 .44335 .56976 .43471 .56384 Mtetra
0 .163 .596 r
.43471 .56384 .44335 .56976 .45789 .57922 .44926 .5736 Mtetra
.392 0 0 r
.44926 .5736 .45789 .57922 .47263 .58863 .46403 .58331 Mtetra
0 .188 .602 r
.46403 .58331 .47263 .58863 .48758 .59758 .47901 .59256 Mtetra
0 .241 .643 r
.47901 .59256 .48758 .59758 .50274 .60569 .49421 .60093 Mtetra
0 .325 .709 r
.49421 .60093 .50274 .60569 .51811 .61251 .50961 .608 Mtetra
0 .439 .796 r
.50961 .608 .51811 .61251 .53365 .61764 .52521 .61334 Mtetra
.068 .572 .888 r
.52521 .61334 .53365 .61764 .54936 .62072 .54098 .61656 Mtetra
.261 .702 .961 r
.54098 .61656 .54936 .62072 .56521 .62143 .55689 .61737 Mtetra
.444 .804 .996 r
.55689 .61737 .56521 .62143 .58114 .61956 .57291 .61552 Mtetra
.594 .867 .994 r
.57291 .61552 .58114 .61956 .59714 .61498 .58899 .61089 Mtetra
.701 .896 .967 r
.58899 .61089 .59714 .61498 .61317 .60767 .6051 .60347 Mtetra
.773 .903 .932 r
.6051 .60347 .61317 .60767 .62918 .59773 .6212 .59335 Mtetra
.82 .9 .897 r
.6212 .59335 .62918 .59773 .64515 .58537 .63727 .58075 Mtetra
.85 .893 .868 r
.63727 .58075 .64515 .58537 .66105 .57087 .65327 .56596 Mtetra
.869 .884 .844 r
.65327 .56596 .66105 .57087 .67688 .5546 .66919 .54934 Mtetra
.881 .875 .826 r
.66919 .54934 .67688 .5546 .69262 .53695 .68503 .53132 Mtetra
.887 .867 .813 r
.68503 .53132 .69262 .53695 .70828 .51834 .70078 .51233 Mtetra
.889 .86 .806 r
.70078 .51233 .70828 .51834 .72386 .49919 .71646 .49278 Mtetra
.888 .853 .802 r
.71646 .49278 .72386 .49919 .73939 .4799 .73208 .47309 Mtetra
.885 .848 .802 r
.73208 .47309 .73939 .4799 .75488 .46082 .74766 .45362 Mtetra
.878 .842 .805 r
.74766 .45362 .75488 .46082 .77037 .44224 .76322 .43467 Mtetra
.87 .837 .811 r
.76322 .43467 .77037 .44224 .78587 .4244 .7788 .41648 Mtetra
.86 .832 .818 r
.7788 .41648 .78587 .4244 .80142 .40749 .79443 .39923 Mtetra
.847 .826 .827 r
.79443 .39923 .80142 .40749 .81703 .39161 .81011 .38306 Mtetra
.834 .82 .836 r
.81011 .38306 .81703 .39161 .83274 .37684 .82589 .36801 Mtetra
.818 .814 .846 r
.82589 .36801 .83274 .37684 .84855 .36318 .84177 .3541 Mtetra
.802 .807 .855 r
.84177 .3541 .84855 .36318 .86449 .35061 .85778 .34131 Mtetra
.786 .8 .864 r
.85778 .34131 .86449 .35061 .88056 .33907 .87393 .32958 Mtetra
.769 .793 .872 r
.87393 .32958 .88056 .33907 .89678 .32848 .89022 .31882 Mtetra
.447 .675 .961 r
.28808 .50296 .29696 .51084 .31034 .51146 .30148 .50364 Mtetra
.382 .648 .962 r
.30148 .50364 .31034 .51146 .32378 .51303 .31494 .50529 Mtetra
.303 .611 .954 r
.31494 .50529 .32378 .51303 .33728 .51566 .32846 .50802 Mtetra
.207 .562 .936 r
.32846 .50802 .33728 .51566 .35085 .51939 .34204 .51188 Mtetra
.099 .5 .903 r
.34204 .51188 .35085 .51939 .3645 .52427 .35571 .5169 Mtetra
0 .428 .855 r
.35571 .5169 .3645 .52427 .37826 .53029 .36948 .52309 Mtetra
0 .353 .796 r
.36948 .52309 .37826 .53029 .39214 .53739 .38338 .53039 Mtetra
0 .283 .733 r
.38338 .53039 .39214 .53739 .40616 .54547 .39741 .53869 Mtetra
0 .224 .675 r
.39741 .53869 .40616 .54547 .42035 .55437 .4116 .54782 Mtetra
0 .182 .63 r
.4116 .54782 .42035 .55437 .43471 .56384 .42597 .55755 Mtetra
0 .161 .603 r
.42597 .55755 .43471 .56384 .44926 .5736 .44055 .56757 Mtetra
0 .163 .598 r
.44055 .56757 .44926 .5736 .46403 .58331 .45533 .57754 Mtetra
0 .19 .616 r
.45533 .57754 .46403 .58331 .47901 .59256 .47034 .58705 Mtetra
0 .246 .661 r
.47034 .58705 .47901 .59256 .49421 .60093 .48557 .59566 Mtetra
0 .332 .73 r
.48557 .59566 .49421 .60093 .50961 .608 .50102 .60294 Mtetra
0 .447 .818 r
.50102 .60294 .50961 .608 .52521 .61334 .51666 .60845 Mtetra
.096 .578 .906 r
.51666 .60845 .52521 .61334 .54098 .61656 .53249 .61181 Mtetra
.288 .703 .972 r
.53249 .61181 .54098 .61656 .55689 .61737 .54847 .61269 Mtetra
.465 .798 .999 r
.54847 .61269 .55689 .61737 .57291 .61552 .56455 .61085 Mtetra
.607 .855 .991 r
.56455 .61085 .57291 .61552 .58899 .61089 .58072 .60618 Mtetra
.708 .881 .961 r
.58072 .60618 .58899 .61089 .6051 .60347 .59691 .59865 Mtetra
.776 .889 .925 r
.59691 .59865 .6051 .60347 .6212 .59335 .61311 .58836 Mtetra
.821 .886 .891 r
.61311 .58836 .6212 .59335 .63727 .58075 .62927 .57554 Mtetra
.849 .88 .862 r
.62927 .57554 .63727 .58075 .65327 .56596 .64537 .56047 Mtetra
.868 .872 .838 r
.64537 .56047 .65327 .56596 .66919 .54934 .66139 .54355 Mtetra
.879 .864 .821 r
.66139 .54355 .66919 .54934 .68503 .53132 .67733 .52519 Mtetra
.885 .857 .809 r
.67733 .52519 .68503 .53132 .70078 .51233 .69318 .50584 Mtetra
.888 .851 .801 r
.69318 .50584 .70078 .51233 .71646 .49278 .70895 .48593 Mtetra
.887 .846 .798 r
.70895 .48593 .71646 .49278 .73208 .47309 .72465 .46588 Mtetra
.884 .841 .798 r
.72465 .46588 .73208 .47309 .74766 .45362 .74032 .44605 Mtetra
.878 .836 .801 r
.74032 .44605 .74766 .45362 .76322 .43467 .75598 .42676 Mtetra
.87 .832 .807 r
.75598 .42676 .76322 .43467 .7788 .41648 .77164 .40825 Mtetra
.86 .827 .815 r
.77164 .40825 .7788 .41648 .79443 .39923 .78734 .39071 Mtetra
.848 .823 .824 r
.78734 .39071 .79443 .39923 .81011 .38306 .8031 .37426 Mtetra
.834 .817 .833 r
.8031 .37426 .81011 .38306 .82589 .36801 .81896 .35896 Mtetra
.819 .812 .843 r
.81896 .35896 .82589 .36801 .84177 .3541 .83491 .34483 Mtetra
.803 .805 .853 r
.83491 .34483 .84177 .3541 .85778 .34131 .85099 .33183 Mtetra
.787 .798 .862 r
.85099 .33183 .85778 .34131 .87393 .32958 .86721 .31992 Mtetra
.77 .792 .87 r
.86721 .31992 .87393 .32958 .89022 .31882 .88357 .30899 Mtetra
.444 .673 .96 r
.27911 .49496 .28808 .50296 .30148 .50364 .29254 .49568 Mtetra
.379 .645 .96 r
.29254 .49568 .30148 .50364 .31494 .50529 .30602 .4974 Mtetra
.298 .606 .953 r
.30602 .4974 .31494 .50529 .32846 .50802 .31955 .5002 Mtetra
.202 .556 .934 r
.31955 .5002 .32846 .50802 .34204 .51188 .33315 .50416 Mtetra
.095 .493 .9 r
.33315 .50416 .34204 .51188 .35571 .5169 .34684 .50931 Mtetra
0 .422 .853 r
.34684 .50931 .35571 .5169 .36948 .52309 .36062 .51564 Mtetra
0 .347 .795 r
.36062 .51564 .36948 .52309 .38338 .53039 .37452 .52311 Mtetra
0 .278 .734 r
.37452 .52311 .38338 .53039 .39741 .53869 .38856 .53159 Mtetra
0 .221 .679 r
.38856 .53159 .39741 .53869 .4116 .54782 .40277 .54092 Mtetra
0 .181 .636 r
.40277 .54092 .4116 .54782 .42597 .55755 .41715 .55086 Mtetra
0 .161 .613 r
.41715 .55086 .42597 .55755 .44055 .56757 .43174 .56111 Mtetra
0 .165 .611 r
.43174 .56111 .44055 .56757 .45533 .57754 .44654 .57129 Mtetra
0 .195 .633 r
.44654 .57129 .45533 .57754 .47034 .58705 .46157 .58102 Mtetra
0 .253 .681 r
.46157 .58102 .47034 .58705 .48557 .59566 .47683 .58983 Mtetra
0 .341 .752 r
.47683 .58983 .48557 .59566 .50102 .60294 .49232 .59729 Mtetra
0 .456 .838 r
.49232 .59729 .50102 .60294 .51666 .60845 .50801 .60294 Mtetra
.127 .584 .922 r
.50801 .60294 .51666 .60845 .53249 .61181 .52389 .60641 Mtetra
.314 .702 .979 r
.52389 .60641 .53249 .61181 .54847 .61269 .53993 .60735 Mtetra
.485 .79 .998 r
.53993 .60735 .54847 .61269 .56455 .61085 .55608 .60552 Mtetra
.618 .842 .985 r
.55608 .60552 .56455 .61085 .58072 .60618 .57233 .6008 Mtetra
.713 .866 .954 r
.57233 .6008 .58072 .60618 .59691 .59865 .58861 .59316 Mtetra
.777 .873 .918 r
.58861 .59316 .59691 .59865 .61311 .58836 .6049 .58272 Mtetra
.82 .872 .884 r
.6049 .58272 .61311 .58836 .62927 .57554 .62115 .56969 Mtetra
.848 .866 .855 r
.62115 .56969 .62927 .57554 .64537 .56047 .63735 .55439 Mtetra
.865 .86 .833 r
.63735 .55439 .64537 .56047 .66139 .54355 .65347 .53719 Mtetra
.877 .853 .816 r
.65347 .53719 .66139 .54355 .67733 .52519 .66951 .51853 Mtetra
.883 .848 .804 r
.66951 .51853 .67733 .52519 .69318 .50584 .68545 .49886 Mtetra
.886 .842 .797 r
.68545 .49886 .69318 .50584 .70895 .48593 .70132 .47863 Mtetra
.885 .838 .794 r
.70132 .47863 .70895 .48593 .72465 .46588 .71712 .45825 Mtetra
.882 .834 .794 r
.71712 .45825 .72465 .46588 .74032 .44605 .73288 .43811 Mtetra
.877 .83 .798 r
.73288 .43811 .74032 .44605 .75598 .42676 .74862 .41851 Mtetra
.869 .827 .804 r
.74862 .41851 .75598 .42676 .77164 .40825 .76437 .39971 Mtetra
.859 .823 .811 r
.76437 .39971 .77164 .40825 .78734 .39071 .78016 .3819 Mtetra
.848 .819 .82 r
.78016 .3819 .78734 .39071 .8031 .37426 .796 .3652 Mtetra
.834 .814 .83 r
.796 .3652 .8031 .37426 .81896 .35896 .81193 .34968 Mtetra
.819 .809 .841 r
.81193 .34968 .81896 .35896 .83491 .34483 .82797 .33534 Mtetra
.804 .803 .851 r
.82797 .33534 .83491 .34483 .85099 .33183 .84412 .32216 Mtetra
.787 .797 .86 r
.84412 .32216 .85099 .33183 .86721 .31992 .86041 .31008 Mtetra
.771 .79 .869 r
.86041 .31008 .86721 .31992 .88357 .30899 .87684 .29901 Mtetra
.442 .67 .96 r
.27005 .48682 .27911 .49496 .29254 .49568 .28351 .48757 Mtetra
.376 .641 .959 r
.28351 .48757 .29254 .49568 .30602 .4974 .29701 .48934 Mtetra
.296 .602 .951 r
.29701 .48934 .30602 .4974 .31955 .5002 .31056 .4922 Mtetra
.2 .551 .932 r
.31056 .4922 .31955 .5002 .33315 .50416 .32418 .49624 Mtetra
.093 .489 .899 r
.32418 .49624 .33315 .50416 .34684 .50931 .33788 .50148 Mtetra
0 .417 .852 r
.33788 .50148 .34684 .50931 .36062 .51564 .35167 .50793 Mtetra
0 .344 .795 r
.35167 .50793 .36062 .51564 .37452 .52311 .36558 .51552 Mtetra
0 .276 .737 r
.36558 .51552 .37452 .52311 .38856 .53159 .37963 .52415 Mtetra
0 .22 .684 r
.37963 .52415 .38856 .53159 .40277 .54092 .39385 .53364 Mtetra
0 .182 .645 r
.39385 .53364 .40277 .54092 .41715 .55086 .40824 .54376 Mtetra
0 .165 .625 r
.40824 .54376 .41715 .55086 .43174 .56111 .42284 .55418 Mtetra
0 .171 .626 r
.42284 .55418 .43174 .56111 .44654 .57129 .43766 .56455 Mtetra
0 .203 .652 r
.43766 .56455 .44654 .57129 .46157 .58102 .45271 .57444 Mtetra
0 .263 .702 r
.45271 .57444 .46157 .58102 .47683 .58983 .468 .58342 Mtetra
0 .352 .774 r
.468 .58342 .47683 .58983 .49232 .59729 .48352 .59101 Mtetra
0 .465 .857 r
.48352 .59101 .49232 .59729 .50801 .60294 .49925 .59679 Mtetra
.158 .588 .934 r
.49925 .59679 .50801 .60294 .52389 .60641 .51518 .60033 Mtetra
.34 .699 .983 r
.51518 .60033 .52389 .60641 .53993 .60735 .53128 .60131 Mtetra
.502 .779 .994 r
.53128 .60131 .53993 .60735 .55608 .60552 .5475 .59948 Mtetra
.627 .827 .977 r
.5475 .59948 .55608 .60552 .57233 .6008 .56382 .59471 Mtetra
.717 .85 .945 r
.56382 .59471 .57233 .6008 .58861 .59316 .58019 .58698 Mtetra
.777 .857 .91 r
.58019 .58698 .58861 .59316 .6049 .58272 .59656 .5764 Mtetra
.818 .857 .877 r
.59656 .5764 .6049 .58272 .62115 .56969 .61291 .56319 Mtetra
.845 .853 .849 r
.61291 .56319 .62115 .56969 .63735 .55439 .62921 .54766 Mtetra
.862 .848 .827 r
.62921 .54766 .63735 .55439 .65347 .53719 .64543 .53022 Mtetra
.874 .843 .811 r
.64543 .53022 .65347 .53719 .66951 .51853 .66157 .5113 Mtetra
.88 .838 .8 r
.66157 .5113 .66951 .51853 .68545 .49886 .67761 .49135 Mtetra
.883 .834 .793 r
.67761 .49135 .68545 .49886 .70132 .47863 .69358 .47083 Mtetra
.883 .83 .79 r
.69358 .47083 .70132 .47863 .71712 .45825 .70948 .45018 Mtetra
.88 .827 .791 r
.70948 .45018 .71712 .45825 .73288 .43811 .72534 .42975 Mtetra
.875 .824 .794 r
.72534 .42975 .73288 .43811 .74862 .41851 .74117 .40989 Mtetra
.868 .821 .8 r
.74117 .40989 .74862 .41851 .76437 .39971 .75701 .39084 Mtetra
.859 .818 .808 r
.75701 .39084 .76437 .39971 .78016 .3819 .77288 .3728 Mtetra
.847 .815 .818 r
.77288 .3728 .78016 .3819 .796 .3652 .78881 .35588 Mtetra
.834 .811 .828 r
.78881 .35588 .796 .3652 .81193 .34968 .80482 .34015 Mtetra
.82 .806 .838 r
.80482 .34015 .81193 .34968 .82797 .33534 .82093 .32563 Mtetra
.804 .801 .849 r
.82093 .32563 .82797 .33534 .84412 .32216 .83716 .31229 Mtetra
.788 .795 .858 r
.83716 .31229 .84412 .32216 .86041 .31008 .85353 .30006 Mtetra
.771 .789 .867 r
.85353 .30006 .86041 .31008 .87684 .29901 .87004 .28885 Mtetra
.44 .668 .959 r
.26092 .47855 .27005 .48682 .28351 .48757 .27439 .47931 Mtetra
.375 .639 .958 r
.27439 .47931 .28351 .48757 .29701 .48934 .28792 .4811 Mtetra
.295 .599 .95 r
.28792 .4811 .29701 .48934 .31056 .4922 .30149 .48401 Mtetra
.2 .548 .93 r
.30149 .48401 .31056 .4922 .32418 .49624 .31512 .4881 Mtetra
.094 .486 .898 r
.31512 .4881 .32418 .49624 .33788 .50148 .32883 .49341 Mtetra
0 .415 .852 r
.32883 .49341 .33788 .50148 .35167 .50793 .34264 .49993 Mtetra
0 .343 .798 r
.34264 .49993 .35167 .50793 .36558 .51552 .35656 .50762 Mtetra
0 .276 .742 r
.35656 .50762 .36558 .51552 .37963 .52415 .37062 .51636 Mtetra
0 .222 .692 r
.37062 .51636 .37963 .52415 .39385 .53364 .38484 .52598 Mtetra
0 .186 .656 r
.38484 .52598 .39385 .53364 .40824 .54376 .39924 .53621 Mtetra
0 .171 .639 r
.39924 .53621 .40824 .54376 .42284 .55418 .41385 .54677 Mtetra
0 .179 .644 r
.41385 .54677 .42284 .55418 .43766 .56455 .42869 .55727 Mtetra
0 .212 .672 r
.42869 .55727 .43766 .56455 .45271 .57444 .44376 .5673 Mtetra
0 .274 .723 r
.44376 .5673 .45271 .57444 .468 .58342 .45907 .57639 Mtetra
0 .363 .795 r
.45907 .57639 .468 .58342 .48352 .59101 .47462 .58409 Mtetra
.017 .474 .874 r
.47462 .58409 .48352 .59101 .49925 .59679 .49039 .58995 Mtetra
.189 .591 .942 r
.49039 .58995 .49925 .59679 .51518 .60033 .50637 .59354 Mtetra
.364 .694 .982 r
.50637 .59354 .51518 .60033 .53128 .60131 .52252 .59455 Mtetra
.517 .767 .988 r
.52252 .59455 .53128 .60131 .5475 .59948 .53881 .5927 Mtetra
.634 .811 .968 r
.53881 .5927 .5475 .59948 .56382 .59471 .5552 .58788 Mtetra
.718 .833 .936 r
.5552 .58788 .56382 .59471 .58019 .58698 .57165 .58006 Mtetra
.776 .841 .901 r
.57165 .58006 .58019 .58698 .59656 .5764 .58811 .56935 Mtetra
.815 .842 .87 r
.58811 .56935 .59656 .5764 .61291 .56319 .60456 .55598 Mtetra
.841 .839 .843 r
.60456 .55598 .61291 .56319 .62921 .54766 .62095 .54028 Mtetra
.859 .836 .822 r
.62095 .54028 .62921 .54766 .64543 .53022 .63727 .52262 Mtetra
.87 .832 .807 r
.63727 .52262 .64543 .53022 .66157 .5113 .65351 .50347 Mtetra
.877 .828 .796 r
.65351 .50347 .66157 .5113 .67761 .49135 .66966 .48329 Mtetra
.88 .825 .79 r
.66966 .48329 .67761 .49135 .69358 .47083 .68573 .46254 Mtetra
.88 .822 .787 r
.68573 .46254 .69358 .47083 .70948 .45018 .70173 .44164 Mtetra
.878 .82 .788 r
.70173 .44164 .70948 .45018 .72534 .42975 .71768 .42098 Mtetra
.873 .818 .791 r
.71768 .42098 .72534 .42975 .74117 .40989 .73361 .4009 Mtetra
.866 .816 .797 r
.73361 .4009 .74117 .40989 .75701 .39084 .74954 .38163 Mtetra
.857 .813 .806 r
.74954 .38163 .75701 .39084 .77288 .3728 .7655 .36339 Mtetra
.846 .811 .815 r
.7655 .36339 .77288 .3728 .78881 .35588 .78152 .34628 Mtetra
.834 .807 .825 r
.78152 .34628 .78881 .35588 .80482 .34015 .79761 .33039 Mtetra
.819 .803 .836 r
.79761 .33039 .80482 .34015 .82093 .32563 .81381 .31571 Mtetra
.804 .798 .847 r
.81381 .31571 .82093 .32563 .83716 .31229 .83012 .30222 Mtetra
.788 .793 .857 r
.83012 .30222 .83716 .31229 .85353 .30006 .84657 .28986 Mtetra
.772 .787 .866 r
.84657 .28986 .85353 .30006 .87004 .28885 .86315 .27853 Mtetra
.44 .666 .958 r
.25169 .47014 .26092 .47855 .27439 .47931 .2652 .4709 Mtetra
.375 .637 .957 r
.2652 .4709 .27439 .47931 .28792 .4811 .27874 .4727 Mtetra
.295 .597 .949 r
.27874 .4727 .28792 .4811 .30149 .48401 .29233 .47562 Mtetra
.202 .546 .929 r
.29233 .47562 .30149 .48401 .31512 .4881 .30598 .47973 Mtetra
.098 .484 .898 r
.30598 .47973 .31512 .4881 .32883 .49341 .31971 .48508 Mtetra
0 .415 .853 r
.31971 .48508 .32883 .49341 .34264 .49993 .33352 .49166 Mtetra
0 .344 .801 r
.33352 .49166 .34264 .49993 .35656 .50762 .34745 .49941 Mtetra
0 .279 .748 r
.34745 .49941 .35656 .50762 .37062 .51636 .36152 .50821 Mtetra
0 .227 .702 r
.36152 .50821 .37062 .51636 .38484 .52598 .37575 .5179 Mtetra
0 .193 .669 r
.37575 .5179 .38484 .52598 .39924 .53621 .39016 .52822 Mtetra
0 .179 .655 r
.39016 .52822 .39924 .53621 .41385 .54677 .40478 .53887 Mtetra
0 .189 .662 r
.40478 .53887 .41385 .54677 .42869 .55727 .41963 .54946 Mtetra
0 .224 .693 r
.41963 .54946 .42869 .55727 .44376 .5673 .43471 .55956 Mtetra
0 .287 .745 r
.43471 .55956 .44376 .5673 .45907 .57639 .45004 .56874 Mtetra
0 .375 .814 r
.45004 .56874 .45907 .57639 .47462 .58409 .46562 .5765 Mtetra
.052 .482 .887 r
.46562 .5765 .47462 .58409 .49039 .58995 .48143 .5824 Mtetra
.22 .592 .947 r
.48143 .5824 .49039 .58995 .50637 .59354 .49745 .58602 Mtetra
.386 .687 .979 r
.49745 .58602 .50637 .59354 .52252 .59455 .51366 .58703 Mtetra
.53 .754 .979 r
.51366 .58703 .52252 .59455 .53881 .5927 .53001 .58516 Mtetra
.64 .795 .957 r
.53001 .58516 .53881 .5927 .5552 .58788 .54647 .58028 Mtetra
.719 .816 .925 r
.54647 .58028 .5552 .58788 .57165 .58006 .563 .57238 Mtetra
.774 .824 .892 r
.563 .57238 .57165 .58006 .58811 .56935 .57955 .56156 Mtetra
.811 .827 .862 r
.57955 .56156 .58811 .56935 .60456 .55598 .59609 .54806 Mtetra
.837 .826 .837 r
.59609 .54806 .60456 .55598 .62095 .54028 .61258 .5322 Mtetra
.854 .824 .817 r
.61258 .5322 .62095 .54028 .63727 .52262 .629 .51437 Mtetra
.866 .821 .802 r
.629 .51437 .63727 .52262 .65351 .50347 .64534 .49504 Mtetra
.873 .819 .792 r
.64534 .49504 .65351 .50347 .66966 .48329 .66159 .47467 Mtetra
.876 .816 .786 r
.66159 .47467 .66966 .48329 .68573 .46254 .67777 .45372 Mtetra
.877 .815 .784 r
.67777 .45372 .68573 .46254 .70173 .44164 .69387 .43263 Mtetra
.875 .813 .785 r
.69387 .43263 .70173 .44164 .71768 .42098 .70992 .41178 Mtetra
.871 .812 .789 r
.70992 .41178 .71768 .42098 .73361 .4009 .72595 .39151 Mtetra
.864 .81 .795 r
.72595 .39151 .73361 .4009 .74954 .38163 .74197 .37207 Mtetra
.856 .809 .803 r
.74197 .37207 .74954 .38163 .7655 .36339 .75803 .35366 Mtetra
.845 .806 .813 r
.75803 .35366 .7655 .36339 .78152 .34628 .77413 .3364 Mtetra
.833 .804 .823 r
.77413 .3364 .78152 .34628 .79761 .33039 .79031 .32036 Mtetra
.819 .8 .834 r
.79031 .32036 .79761 .33039 .81381 .31571 .80659 .30555 Mtetra
.803 .796 .845 r
.80659 .30555 .81381 .31571 .83012 .30222 .82299 .29194 Mtetra
.788 .791 .855 r
.82299 .29194 .83012 .30222 .84657 .28986 .83952 .27947 Mtetra
.772 .786 .865 r
.83952 .27947 .84657 .28986 .86315 .27853 .85618 .26803 Mtetra
.44 .665 .957 r
.24238 .46158 .25169 .47014 .2652 .4709 .25591 .46233 Mtetra
.376 .635 .956 r
.25591 .46233 .2652 .4709 .27874 .4727 .26948 .46411 Mtetra
.297 .596 .948 r
.26948 .46411 .27874 .4727 .29233 .47562 .28309 .46703 Mtetra
.206 .545 .929 r
.28309 .46703 .29233 .47562 .30598 .47973 .29676 .47115 Mtetra
.104 .484 .898 r
.29676 .47115 .30598 .47973 .31971 .48508 .3105 .4765 Mtetra
0 .416 .856 r
.3105 .4765 .31971 .48508 .33352 .49166 .32432 .48309 Mtetra
0 .347 .807 r
.32432 .48309 .33352 .49166 .34745 .49941 .33827 .49086 Mtetra
0 .284 .757 r
.33827 .49086 .34745 .49941 .36152 .50821 .35234 .49969 Mtetra
0 .234 .714 r
.35234 .49969 .36152 .50821 .37575 .5179 .36658 .50941 Mtetra
0 .202 .684 r
.36658 .50941 .37575 .5179 .39016 .52822 .381 .51977 Mtetra
0 .19 .673 r
.381 .51977 .39016 .52822 .40478 .53887 .39562 .53045 Mtetra
0 .201 .682 r
.39562 .53045 .40478 .53887 .41963 .54946 .41048 .54108 Mtetra
0 .238 .714 r
.41048 .54108 .41963 .54946 .43471 .55956 .42558 .55123 Mtetra
0 .301 .765 r
.42558 .55123 .43471 .55956 .45004 .56874 .44093 .56043 Mtetra
0 .387 .831 r
.44093 .56043 .45004 .56874 .46562 .5765 .45653 .56822 Mtetra
.087 .489 .898 r
.45653 .56822 .46562 .5765 .48143 .5824 .47238 .57413 Mtetra
.249 .592 .949 r
.47238 .57413 .48143 .5824 .49745 .58602 .48844 .57775 Mtetra
.407 .679 .972 r
.48844 .57775 .49745 .58602 .51366 .58703 .50469 .57873 Mtetra
.54 .741 .968 r
.50469 .57873 .51366 .58703 .53001 .58516 .52111 .57683 Mtetra
.643 .779 .946 r
.52111 .57683 .53001 .58516 .54647 .58028 .53764 .57189 Mtetra
.718 .799 .915 r
.53764 .57189 .54647 .58028 .563 .57238 .55424 .56392 Mtetra
.77 .809 .883 r
.55424 .56392 .563 .57238 .57955 .56156 .57088 .55301 Mtetra
.807 .812 .855 r
.57088 .55301 .57955 .56156 .59609 .54806 .5875 .5394 Mtetra
.832 .813 .831 r
.5875 .5394 .59609 .54806 .61258 .5322 .60409 .52341 Mtetra
.85 .812 .813 r
.60409 .52341 .61258 .5322 .629 .51437 .62061 .50546 Mtetra
.861 .81 .799 r
.62061 .50546 .629 .51437 .64534 .49504 .63706 .48598 Mtetra
.869 .809 .789 r
.63706 .48598 .64534 .49504 .66159 .47467 .65341 .46546 Mtetra
.872 .808 .783 r
.65341 .46546 .66159 .47467 .67777 .45372 .66969 .44436 Mtetra
.873 .807 .781 r
.66969 .44436 .67777 .45372 .69387 .43263 .6859 .42313 Mtetra
.872 .806 .782 r
.6859 .42313 .69387 .43263 .70992 .41178 .70205 .40214 Mtetra
.868 .806 .786 r
.70205 .40214 .70992 .41178 .72595 .39151 .71818 .38173 Mtetra
.862 .805 .793 r
.71818 .38173 .72595 .39151 .74197 .37207 .7343 .36215 Mtetra
.854 .804 .801 r
.7343 .36215 .74197 .37207 .75803 .35366 .75045 .34362 Mtetra
.844 .802 .811 r
.75045 .34362 .75803 .35366 .77413 .3364 .76665 .32624 Mtetra
.831 .8 .821 r
.76665 .32624 .77413 .3364 .79031 .32036 .78292 .31008 Mtetra
.818 .797 .832 r
.78292 .31008 .79031 .32036 .80659 .30555 .79929 .29517 Mtetra
.803 .793 .843 r
.79929 .29517 .80659 .30555 .82299 .29194 .81577 .28145 Mtetra
.787 .789 .854 r
.81577 .28145 .82299 .29194 .83952 .27947 .83238 .26888 Mtetra
.771 .784 .863 r
.83238 .26888 .83952 .27947 .85618 .26803 .84913 .25736 Mtetra
.442 .664 .956 r
.23298 .45288 .24238 .46158 .25591 .46233 .24654 .4536 Mtetra
.378 .634 .955 r
.24654 .4536 .25591 .46233 .26948 .46411 .26013 .45535 Mtetra
.301 .595 .947 r
.26013 .45535 .26948 .46411 .28309 .46703 .27376 .45824 Mtetra
.212 .545 .929 r
.27376 .45824 .28309 .46703 .29676 .47115 .28745 .46233 Mtetra
.113 .485 .9 r
.28745 .46233 .29676 .47115 .3105 .4765 .3012 .46766 Mtetra
.011 .419 .86 r
.3012 .46766 .3105 .4765 .32432 .48309 .31504 .47423 Mtetra
0 .352 .813 r
.31504 .47423 .32432 .48309 .33827 .49086 .329 .48198 Mtetra
0 .292 .766 r
.329 .48198 .33827 .49086 .35234 .49969 .34308 .4908 Mtetra
0 .244 .727 r
.34308 .4908 .35234 .49969 .36658 .50941 .35732 .50051 Mtetra
0 .213 .7 r
.35732 .50051 .36658 .50941 .381 .51977 .37175 .51085 Mtetra
0 .203 .691 r
.37175 .51085 .381 .51977 .39562 .53045 .38638 .52152 Mtetra
0 .216 .702 r
.38638 .52152 .39562 .53045 .41048 .54108 .40125 .53214 Mtetra
0 .253 .734 r
.40125 .53214 .41048 .54108 .42558 .55123 .41636 .54227 Mtetra
0 .315 .784 r
.41636 .54227 .42558 .55123 .44093 .56043 .43173 .55146 Mtetra
0 .399 .845 r
.43173 .55146 .44093 .56043 .45653 .56822 .44736 .55923 Mtetra
.121 .496 .905 r
.44736 .55923 .45653 .56822 .47238 .57413 .46323 .56511 Mtetra
.277 .591 .947 r
.46323 .56511 .47238 .57413 .48844 .57775 .47933 .5687 Mtetra
.425 .67 .964 r
.47933 .5687 .48844 .57775 .50469 .57873 .49563 .56965 Mtetra
.55 .727 .957 r
.49563 .56965 .50469 .57873 .52111 .57683 .5121 .56769 Mtetra
.646 .762 .934 r
.5121 .56769 .52111 .57683 .53764 .57189 .5287 .5627 Mtetra
.716 .783 .904 r
.5287 .5627 .53764 .57189 .55424 .56392 .54538 .55466 Mtetra
.767 .793 .875 r
.54538 .55466 .55424 .56392 .57088 .55301 .56209 .54368 Mtetra
.802 .798 .848 r
.56209 .54368 .57088 .55301 .5875 .5394 .57881 .52998 Mtetra
.827 .8 .826 r
.57881 .52998 .5875 .5394 .60409 .52341 .59549 .51391 Mtetra
.844 .8 .808 r
.59549 .51391 .60409 .52341 .62061 .50546 .61211 .49586 Mtetra
.856 .8 .795 r
.61211 .49586 .62061 .50546 .63706 .48598 .62866 .47629 Mtetra
.864 .8 .786 r
.62866 .47629 .63706 .48598 .65341 .46546 .64512 .45567 Mtetra
.868 .8 .781 r
.64512 .45567 .65341 .46546 .66969 .44436 .6615 .43447 Mtetra
.87 .8 .779 r
.6615 .43447 .66969 .44436 .6859 .42313 .67782 .41313 Mtetra
.869 .8 .78 r
.67782 .41313 .6859 .42313 .70205 .40214 .69408 .39204 Mtetra
.865 .8 .784 r
.69408 .39204 .70205 .40214 .71818 .38173 .7103 .37154 Mtetra
.859 .8 .791 r
.7103 .37154 .71818 .38173 .7343 .36215 .72653 .35187 Mtetra
.852 .799 .799 r
.72653 .35187 .7343 .36215 .75045 .34362 .74277 .33324 Mtetra
.842 .798 .809 r
.74277 .33324 .75045 .34362 .76665 .32624 .75907 .31578 Mtetra
.83 .796 .82 r
.75907 .31578 .76665 .32624 .78292 .31008 .77543 .29954 Mtetra
.816 .794 .831 r
.77543 .29954 .78292 .31008 .79929 .29517 .79189 .28454 Mtetra
.802 .791 .842 r
.79189 .28454 .79929 .29517 .81577 .28145 .80846 .27075 Mtetra
.786 .787 .853 r
.80846 .27075 .81577 .28145 .83238 .26888 .82516 .2581 Mtetra
.771 .782 .862 r
.82516 .2581 .83238 .26888 .84913 .25736 .84199 .2465 Mtetra
.444 .663 .955 r
.2235 .44404 .23298 .45288 .24654 .4536 .23708 .4447 Mtetra
.382 .634 .954 r
.23708 .4447 .24654 .4536 .26013 .45535 .25069 .4464 Mtetra
.306 .595 .946 r
.25069 .4464 .26013 .45535 .27376 .45824 .26435 .44924 Mtetra
.219 .546 .929 r
.26435 .44924 .27376 .45824 .28745 .46233 .27805 .45328 Mtetra
.123 .488 .902 r
.27805 .45328 .28745 .46233 .3012 .46766 .29183 .45855 Mtetra
.025 .424 .864 r
.29183 .45855 .3012 .46766 .31504 .47423 .30568 .46507 Mtetra
0 .359 .82 r
.30568 .46507 .31504 .47423 .329 .48198 .31964 .47276 Mtetra
0 .301 .777 r
.31964 .47276 .329 .48198 .34308 .4908 .33374 .48152 Mtetra
0 .255 .74 r
.33374 .48152 .34308 .4908 .35732 .50051 .34799 .49117 Mtetra
0 .226 .717 r
.34799 .49117 .35732 .50051 .37175 .51085 .36242 .50146 Mtetra
0 .217 .71 r
.36242 .50146 .37175 .51085 .38638 .52152 .37707 .51207 Mtetra
0 .231 .722 r
.37707 .51207 .38638 .52152 .40125 .53214 .39194 .52263 Mtetra
0 .269 .754 r
.39194 .52263 .40125 .53214 .41636 .54227 .40707 .5327 Mtetra
0 .33 .802 r
.40707 .5327 .41636 .54227 .43173 .55146 .42245 .54182 Mtetra
.016 .41 .857 r
.42245 .54182 .43173 .55146 .44736 .55923 .4381 .54953 Mtetra
.154 .501 .909 r
.4381 .54953 .44736 .55923 .46323 .56511 .454 .55536 Mtetra
.302 .588 .943 r
.454 .55536 .46323 .56511 .47933 .5687 .47013 .55888 Mtetra
.441 .661 .954 r
.47013 .55888 .47933 .5687 .49563 .56965 .48648 .55977 Mtetra
.557 .713 .945 r
.48648 .55977 .49563 .56965 .5121 .56769 .503 .55775 Mtetra
.647 .747 .922 r
.503 .55775 .5121 .56769 .5287 .5627 .51966 .5527 Mtetra
.714 .767 .894 r
.51966 .5527 .5287 .5627 .54538 .55466 .53641 .5446 Mtetra
.762 .778 .866 r
.53641 .5446 .54538 .55466 .56209 .54368 .5532 .53356 Mtetra
.797 .785 .841 r
.5532 .53356 .56209 .54368 .57881 .52998 .57001 .51981 Mtetra
.822 .788 .82 r
.57001 .51981 .57881 .52998 .59549 .51391 .58678 .50368 Mtetra
.839 .789 .804 r
.58678 .50368 .59549 .51391 .61211 .49586 .6035 .48557 Mtetra
.851 .79 .791 r
.6035 .48557 .61211 .49586 .62866 .47629 .62015 .46595 Mtetra
.859 .791 .783 r
.62015 .46595 .62866 .47629 .64512 .45567 .63672 .44527 Mtetra
.864 .792 .778 r
.63672 .44527 .64512 .45567 .6615 .43447 .65321 .42402 Mtetra
.866 .792 .777 r
.65321 .42402 .6615 .43447 .67782 .41313 .66963 .40264 Mtetra
.865 .793 .778 r
.66963 .40264 .67782 .41313 .69408 .39204 .68599 .3815 Mtetra
.862 .794 .783 r
.68599 .3815 .69408 .39204 .7103 .37154 .70233 .36094 Mtetra
.857 .794 .789 r
.70233 .36094 .7103 .37154 .72653 .35187 .71865 .34122 Mtetra
.849 .794 .798 r
.71865 .34122 .72653 .35187 .74277 .33324 .735 .32254 Mtetra
.839 .794 .808 r
.735 .32254 .74277 .33324 .75907 .31578 .75139 .30502 Mtetra
.828 .793 .819 r
.75139 .30502 .75907 .31578 .77543 .29954 .76785 .28873 Mtetra
.815 .791 .83 r
.76785 .28873 .77543 .29954 .79189 .28454 .7844 .27368 Mtetra
.801 .788 .841 r
.7844 .27368 .79189 .28454 .80846 .27075 .80106 .25983 Mtetra
.785 .785 .852 r
.80106 .25983 .80846 .27075 .82516 .2581 .81785 .24712 Mtetra
.77 .781 .862 r
.81785 .24712 .82516 .2581 .84199 .2465 .83477 .23546 Mtetra
.447 .663 .954 r
.21392 .43505 .2235 .44404 .23708 .4447 .22753 .43564 Mtetra
.386 .634 .953 r
.22753 .43564 .23708 .4447 .25069 .4464 .24117 .43727 Mtetra
.313 .596 .946 r
.24117 .43727 .25069 .4464 .26435 .44924 .25485 .44003 Mtetra
.229 .548 .93 r
.25485 .44003 .26435 .44924 .27805 .45328 .26858 .44399 Mtetra
.136 .492 .904 r
.26858 .44399 .27805 .45328 .29183 .45855 .28237 .44918 Mtetra
.042 .43 .869 r
.28237 .44918 .29183 .45855 .30568 .46507 .29624 .45561 Mtetra
0 .368 .829 r
.29624 .45561 .30568 .46507 .31964 .47276 .31021 .46321 Mtetra
0 .312 .788 r
.31021 .46321 .31964 .47276 .33374 .48152 .32432 .47187 Mtetra
0 .268 .755 r
.32432 .47187 .33374 .48152 .34799 .49117 .33858 .48141 Mtetra
0 .241 .734 r
.33858 .48141 .34799 .49117 .36242 .50146 .35302 .49159 Mtetra
0 .234 .729 r
.35302 .49159 .36242 .50146 .37707 .51207 .36767 .50209 Mtetra
0 .248 .742 r
.36767 .50209 .37707 .51207 .39194 .52263 .38255 .51254 Mtetra
0 .286 .773 r
.38255 .51254 .39194 .52263 .40707 .5327 .39769 .5225 Mtetra
0 .345 .817 r
.39769 .5225 .40707 .5327 .42245 .54182 .41309 .53152 Mtetra
.053 .421 .866 r
.41309 .53152 .42245 .54182 .4381 .54953 .42876 .53912 Mtetra
.186 .505 .91 r
.42876 .53912 .4381 .54953 .454 .55536 .44468 .54485 Mtetra
.326 .585 .937 r
.44468 .54485 .454 .55536 .47013 .55888 .46085 .54829 Mtetra
.455 .652 .944 r
.46085 .54829 .47013 .55888 .48648 .55977 .47724 .54909 Mtetra
.563 .7 .933 r
.47724 .54909 .48648 .55977 .503 .55775 .49381 .547 Mtetra
.648 .732 .911 r
.49381 .547 .503 .55775 .51966 .5527 .51053 .54189 Mtetra
.711 .752 .884 r
.51053 .54189 .51966 .5527 .53641 .5446 .52734 .53373 Mtetra
.758 .764 .858 r
.52734 .53373 .53641 .5446 .5532 .53356 .54422 .52265 Mtetra
.792 .772 .835 r
.54422 .52265 .5532 .53356 .57001 .51981 .5611 .50887 Mtetra
.816 .776 .815 r
.5611 .50887 .57001 .51981 .58678 .50368 .57797 .49272 Mtetra
.834 .779 .8 r
.57797 .49272 .58678 .50368 .6035 .48557 .59479 .4746 Mtetra
.846 .781 .788 r
.59479 .4746 .6035 .48557 .62015 .46595 .61154 .45496 Mtetra
.854 .782 .781 r
.61154 .45496 .62015 .46595 .63672 .44527 .62821 .43428 Mtetra
.859 .784 .776 r
.62821 .43428 .63672 .44527 .65321 .42402 .64481 .41303 Mtetra
.861 .785 .775 r
.64481 .41303 .65321 .42402 .66963 .40264 .66133 .39164 Mtetra
.861 .787 .777 r
.66133 .39164 .66963 .40264 .68599 .3815 .67781 .3705 Mtetra
.858 .788 .781 r
.67781 .3705 .68599 .3815 .70233 .36094 .69425 .34993 Mtetra
.853 .789 .788 r
.69425 .34993 .70233 .36094 .71865 .34122 .71068 .33021 Mtetra
.846 .79 .797 r
.71068 .33021 .71865 .34122 .735 .32254 .72713 .31151 Mtetra
.837 .79 .807 r
.72713 .31151 .735 .32254 .75139 .30502 .74362 .29397 Mtetra
.826 .789 .818 r
.74362 .29397 .75139 .30502 .76785 .28873 .76017 .27766 Mtetra
.813 .788 .829 r
.76017 .27766 .76785 .28873 .7844 .27368 .77682 .26257 Mtetra
.799 .786 .84 r
.77682 .26257 .7844 .27368 .80106 .25983 .79357 .24869 Mtetra
.784 .782 .851 r
.79357 .24869 .80106 .25983 .81785 .24712 .81045 .23594 Mtetra
.769 .779 .861 r
.81045 .23594 .81785 .24712 .83477 .23546 .82746 .22424 Mtetra
.451 .663 .953 r
.20426 .4259 .21392 .43505 .22753 .43564 .2179 .42642 Mtetra
.392 .635 .952 r
.2179 .42642 .22753 .43564 .24117 .43727 .23157 .42796 Mtetra
.321 .598 .945 r
.23157 .42796 .24117 .43727 .25485 .44003 .24527 .43062 Mtetra
.239 .552 .931 r
.24527 .43062 .25485 .44003 .26858 .44399 .25902 .43447 Mtetra
.15 .497 .907 r
.25902 .43447 .26858 .44399 .28237 .44918 .27283 .43955 Mtetra
.06 .437 .874 r
.27283 .43955 .28237 .44918 .29624 .45561 .28671 .44585 Mtetra
0 .378 .837 r
.28671 .44585 .29624 .45561 .31021 .46321 .3007 .45331 Mtetra
0 .324 .8 r
.3007 .45331 .31021 .46321 .32432 .47187 .31482 .46183 Mtetra
0 .283 .77 r
.31482 .46183 .32432 .47187 .33858 .48141 .32909 .47123 Mtetra
0 .257 .751 r
.32909 .47123 .33858 .48141 .35302 .49159 .34354 .48125 Mtetra
0 .251 .747 r
.34354 .48125 .35302 .49159 .36767 .50209 .3582 .4916 Mtetra
0 .266 .761 r
.3582 .4916 .36767 .50209 .38255 .51254 .37309 .50188 Mtetra
0 .303 .789 r
.37309 .50188 .38255 .51254 .39769 .5225 .38824 .51168 Mtetra
0 .36 .83 r
.38824 .51168 .39769 .5225 .41309 .53152 .40365 .52055 Mtetra
.089 .431 .873 r
.40365 .52055 .41309 .53152 .42876 .53912 .41934 .52801 Mtetra
.217 .509 .91 r
.41934 .52801 .42876 .53912 .44468 .54485 .43529 .5336 Mtetra
.348 .582 .93 r
.43529 .5336 .44468 .54485 .46085 .54829 .45149 .53692 Mtetra
.468 .643 .933 r
.45149 .53692 .46085 .54829 .47724 .54909 .46791 .53761 Mtetra
.569 .688 .921 r
.46791 .53761 .47724 .54909 .49381 .547 .48453 .53544 Mtetra
.648 .718 .9 r
.48453 .53544 .49381 .547 .51053 .54189 .5013 .53027 Mtetra
.708 .738 .875 r
.5013 .53027 .51053 .54189 .52734 .53373 .51818 .52207 Mtetra
.753 .751 .851 r
.51818 .52207 .52734 .53373 .54422 .52265 .53513 .51096 Mtetra
.786 .759 .829 r
.53513 .51096 .54422 .52265 .5611 .50887 .5521 .49718 Mtetra
.81 .765 .811 r
.5521 .49718 .5611 .50887 .57797 .49272 .56906 .48104 Mtetra
.828 .769 .796 r
.56906 .48104 .57797 .49272 .59479 .4746 .58597 .46294 Mtetra
.84 .772 .786 r
.58597 .46294 .59479 .4746 .61154 .45496 .60282 .44334 Mtetra
.849 .774 .778 r
.60282 .44334 .61154 .45496 .62821 .43428 .6196 .4227 Mtetra
.854 .777 .774 r
.6196 .4227 .62821 .43428 .64481 .41303 .6363 .40149 Mtetra
.857 .779 .774 r
.6363 .40149 .64481 .41303 .66133 .39164 .65293 .38014 Mtetra
.857 .781 .776 r
.65293 .38014 .66133 .39164 .67781 .3705 .66951 .35904 Mtetra
.855 .783 .78 r
.66951 .35904 .67781 .3705 .69425 .34993 .68606 .33852 Mtetra
.85 .784 .787 r
.68606 .33852 .69425 .34993 .71068 .33021 .7026 .31882 Mtetra
.843 .785 .796 r
.7026 .31882 .71068 .33021 .72713 .31151 .71915 .30015 Mtetra
.834 .786 .806 r
.71915 .30015 .72713 .31151 .74362 .29397 .73574 .28262 Mtetra
.823 .786 .817 r
.73574 .28262 .74362 .29397 .76017 .27766 .7524 .26631 Mtetra
.811 .785 .828 r
.7524 .26631 .76017 .27766 .77682 .26257 .76914 .25122 Mtetra
.797 .783 .84 r
.76914 .25122 .77682 .26257 .79357 .24869 .78599 .23733 Mtetra
.783 .78 .85 r
.78599 .23733 .79357 .24869 .81045 .23594 .80296 .22456 Mtetra
.768 .777 .86 r
.80296 .22456 .81045 .23594 .82746 .22424 .82006 .21283 Mtetra
.455 .664 .952 r
.1945 .41662 .20426 .4259 .2179 .42642 .20817 .41703 Mtetra
.398 .636 .951 r
.20817 .41703 .2179 .42642 .23157 .42796 .22187 .41846 Mtetra
.33 .6 .945 r
.22187 .41846 .23157 .42796 .24527 .43062 .2356 .421 Mtetra
.252 .555 .932 r
.2356 .421 .24527 .43062 .25902 .43447 .24937 .42472 Mtetra
.166 .503 .91 r
.24937 .42472 .25902 .43447 .27283 .43955 .2632 .42965 Mtetra
.08 .446 .88 r
.2632 .42965 .27283 .43955 .28671 .44585 .27711 .43579 Mtetra
0 .389 .846 r
.27711 .43579 .28671 .44585 .3007 .45331 .29111 .44309 Mtetra
0 .338 .812 r
.29111 .44309 .3007 .45331 .31482 .46183 .30524 .45142 Mtetra
0 .299 .784 r
.30524 .45142 .31482 .46183 .32909 .47123 .31952 .46063 Mtetra
0 .275 .768 r
.31952 .46063 .32909 .47123 .34354 .48125 .33398 .47045 Mtetra
0 .27 .765 r
.33398 .47045 .34354 .48125 .3582 .4916 .34865 .48059 Mtetra
0 .285 .778 r
.34865 .48059 .3582 .4916 .37309 .50188 .36356 .49066 Mtetra
0 .32 .805 r
.36356 .49066 .37309 .50188 .38824 .51168 .37871 .50026 Mtetra
.017 .374 .84 r
.37871 .50026 .38824 .51168 .40365 .52055 .39414 .50893 Mtetra
.124 .441 .878 r
.39414 .50893 .40365 .52055 .41934 .52801 .40984 .51619 Mtetra
.245 .512 .907 r
.40984 .51619 .41934 .52801 .43529 .5336 .42581 .52162 Mtetra
.367 .579 .923 r
.42581 .52162 .43529 .5336 .45149 .53692 .44204 .52479 Mtetra
.479 .634 .922 r
.44204 .52479 .45149 .53692 .46791 .53761 .45851 .52536 Mtetra
.573 .676 .91 r
.45851 .52536 .46791 .53761 .48453 .53544 .47517 .52309 Mtetra
.648 .705 .889 r
.47517 .52309 .48453 .53544 .5013 .53027 .49199 .51785 Mtetra
.705 .725 .866 r
.49199 .51785 .5013 .53027 .51818 .52207 .50894 .50962 Mtetra
.748 .739 .844 r
.50894 .50962 .51818 .52207 .53513 .51096 .52595 .49851 Mtetra
.78 .748 .823 r
.52595 .49851 .53513 .51096 .5521 .49718 .543 .48474 Mtetra
.804 .754 .807 r
.543 .48474 .5521 .49718 .56906 .48104 .56004 .46864 Mtetra
.822 .759 .793 r
.56004 .46864 .56906 .48104 .58597 .46294 .57705 .45061 Mtetra
.835 .763 .783 r
.57705 .45061 .58597 .46294 .60282 .44334 .594 .43108 Mtetra
.844 .766 .776 r
.594 .43108 .60282 .44334 .6196 .4227 .61088 .41053 Mtetra
.849 .769 .773 r
.61088 .41053 .6196 .4227 .6363 .40149 .62769 .38941 Mtetra
.852 .772 .773 r
.62769 .38941 .6363 .40149 .65293 .38014 .64443 .36816 Mtetra
.853 .775 .775 r
.64443 .36816 .65293 .38014 .66951 .35904 .66112 .34714 Mtetra
.851 .777 .78 r
.66112 .34714 .66951 .35904 .68606 .33852 .67778 .32669 Mtetra
.846 .779 .786 r
.67778 .32669 .68606 .33852 .7026 .31882 .69442 .30707 Mtetra
.84 .781 .795 r
.69442 .30707 .7026 .31882 .71915 .30015 .71108 .28846 Mtetra
.831 .782 .805 r
.71108 .28846 .71915 .30015 .73574 .28262 .72778 .27098 Mtetra
.821 .782 .816 r
.72778 .27098 .73574 .28262 .7524 .26631 .74453 .2547 Mtetra
.809 .782 .828 r
.74453 .2547 .7524 .26631 .76914 .25122 .76138 .23964 Mtetra
.795 .78 .839 r
.76138 .23964 .76914 .25122 .78599 .23733 .77832 .22575 Mtetra
.781 .778 .85 r
.77832 .22575 .78599 .23733 .80296 .22456 .79538 .21298 Mtetra
.766 .775 .86 r
.79538 .21298 .80296 .22456 .82006 .21283 .81257 .20123 Mtetra
.46 .665 .95 r
.18466 .40718 .1945 .41662 .20817 .41703 .19836 .40748 Mtetra
.405 .638 .95 r
.19836 .40748 .20817 .41703 .22187 .41846 .21209 .40878 Mtetra
.34 .603 .945 r
.21209 .40878 .22187 .41846 .2356 .421 .22584 .41118 Mtetra
.265 .56 .933 r
.22584 .41118 .2356 .421 .24937 .42472 .23964 .41474 Mtetra
.184 .51 .913 r
.23964 .41474 .24937 .42472 .2632 .42965 .2535 .41949 Mtetra
.101 .456 .886 r
.2535 .41949 .2632 .42965 .27711 .43579 .26742 .42544 Mtetra
.025 .402 .855 r
.26742 .42544 .27711 .43579 .29111 .44309 .28145 .43253 Mtetra
0 .353 .824 r
.28145 .43253 .29111 .44309 .30524 .45142 .29559 .44065 Mtetra
0 .316 .799 r
.29559 .44065 .30524 .45142 .31952 .46063 .30988 .44961 Mtetra
0 .293 .784 r
.30988 .44961 .31952 .46063 .33398 .47045 .32436 .45919 Mtetra
0 .289 .782 r
.32436 .45919 .33398 .47045 .34865 .48059 .33904 .46907 Mtetra
0 .304 .794 r
.33904 .46907 .34865 .48059 .36356 .49066 .35395 .47889 Mtetra
0 .338 .818 r
.35395 .47889 .36356 .49066 .37871 .50026 .36912 .48824 Mtetra
.054 .388 .849 r
.36912 .48824 .37871 .50026 .39414 .50893 .38456 .49666 Mtetra
.157 .45 .88 r
.38456 .49666 .39414 .50893 .40984 .51619 .40028 .50371 Mtetra
.271 .515 .904 r
.40028 .50371 .40984 .51619 .42581 .52162 .41627 .50892 Mtetra
.385 .576 .915 r
.41627 .50892 .42581 .52162 .44204 .52479 .43252 .51192 Mtetra
.489 .627 .912 r
.43252 .51192 .44204 .52479 .45851 .52536 .44902 .51235 Mtetra
.577 .665 .899 r
.44902 .51235 .45851 .52536 .47517 .52309 .46572 .50997 Mtetra
.647 .694 .879 r
.46572 .50997 .47517 .52309 .49199 .51785 .4826 .50466 Mtetra
.701 .713 .858 r
.4826 .50466 .49199 .51785 .50894 .50962 .4996 .4964 Mtetra
.743 .727 .837 r
.4996 .4964 .50894 .50962 .52595 .49851 .51668 .4853 Mtetra
.775 .737 .818 r
.51668 .4853 .52595 .49851 .543 .48474 .53381 .47158 Mtetra
.798 .744 .803 r
.53381 .47158 .543 .48474 .56004 .46864 .55093 .45556 Mtetra
.816 .75 .79 r
.55093 .45556 .56004 .46864 .57705 .45061 .56803 .43762 Mtetra
.829 .755 .781 r
.56803 .43762 .57705 .45061 .594 .43108 .58508 .41821 Mtetra
.838 .759 .775 r
.58508 .41821 .594 .43108 .61088 .41053 .60206 .39779 Mtetra
.844 .762 .772 r
.60206 .39779 .61088 .41053 .62769 .38941 .61898 .37681 Mtetra
.848 .766 .772 r
.61898 .37681 .62769 .38941 .64443 .36816 .63583 .35569 Mtetra
.848 .769 .774 r
.63583 .35569 .64443 .36816 .66112 .34714 .65262 .3348 Mtetra
.846 .772 .779 r
.65262 .3348 .66112 .34714 .67778 .32669 .66939 .31448 Mtetra
.843 .775 .786 r
.66939 .31448 .67778 .32669 .69442 .30707 .68614 .29496 Mtetra
.836 .777 .795 r
.68614 .29496 .69442 .30707 .71108 .28846 .70291 .27644 Mtetra
.828 .778 .805 r
.70291 .27644 .71108 .28846 .72778 .27098 .71971 .25905 Mtetra
.818 .779 .816 r
.71971 .25905 .72778 .27098 .74453 .2547 .73657 .24283 Mtetra
.806 .779 .828 r
.73657 .24283 .74453 .2547 .76138 .23964 .75351 .22781 Mtetra
.793 .778 .839 r
.75351 .22781 .76138 .23964 .77832 .22575 .77055 .21395 Mtetra
.779 .776 .85 r
.77055 .21395 .77832 .22575 .79538 .21298 .78771 .20119 Mtetra
.765 .773 .86 r
.78771 .20119 .79538 .21298 .81257 .20123 .805 .18945 Mtetra
.466 .666 .949 r
.17471 .39759 .18466 .40718 .19836 .40748 .18845 .39776 Mtetra
.413 .64 .949 r
.18845 .39776 .19836 .40748 .21209 .40878 .20221 .39892 Mtetra
.351 .606 .945 r
.20221 .39892 .21209 .40878 .22584 .41118 .216 .40115 Mtetra
.279 .565 .934 r
.216 .40115 .22584 .41118 .23964 .41474 .22983 .40453 Mtetra
.202 .518 .916 r
.22983 .40453 .23964 .41474 .2535 .41949 .24371 .40908 Mtetra
.124 .466 .891 r
.24371 .40908 .2535 .41949 .26742 .42544 .25766 .41481 Mtetra
.052 .415 .863 r
.25766 .41481 .26742 .42544 .28145 .43253 .2717 .42165 Mtetra
0 .369 .835 r
.2717 .42165 .28145 .43253 .29559 .44065 .28586 .42951 Mtetra
0 .333 .813 r
.28586 .42951 .29559 .44065 .30988 .44961 .30017 .4382 Mtetra
0 .312 .799 r
.30017 .4382 .30988 .44961 .32436 .45919 .31466 .44748 Mtetra
0 .308 .798 r
.31466 .44748 .32436 .45919 .33904 .46907 .32935 .45707 Mtetra
0 .323 .808 r
.32935 .45707 .33904 .46907 .35395 .47889 .34427 .46659 Mtetra
.012 .355 .829 r
.34427 .46659 .35395 .47889 .36912 .48824 .35945 .47564 Mtetra
.091 .402 .856 r
.35945 .47564 .36912 .48824 .38456 .49666 .37491 .48378 Mtetra
.188 .458 .881 r
.37491 .48378 .38456 .49666 .40028 .50371 .39064 .49056 Mtetra
.296 .518 .9 r
.39064 .49056 .40028 .50371 .41627 .50892 .40665 .49554 Mtetra
.402 .573 .907 r
.40665 .49554 .41627 .50892 .43252 .51192 .42294 .49833 Mtetra
.498 .619 .902 r
.42294 .49833 .43252 .51192 .44902 .51235 .43946 .4986 Mtetra
.58 .656 .889 r
.43946 .4986 .44902 .51235 .46572 .50997 .45621 .49611 Mtetra
.646 .683 .871 r
.45621 .49611 .46572 .50997 .4826 .50466 .47313 .49073 Mtetra
.698 .702 .851 r
.47313 .49073 .4826 .50466 .4996 .4964 .49018 .48245 Mtetra
.738 .717 .831 r
.49018 .48245 .4996 .4964 .51668 .4853 .50733 .47137 Mtetra
.769 .727 .814 r
.50733 .47137 .51668 .4853 .53381 .47158 .52453 .45772 Mtetra
.793 .735 .799 r
.52453 .45772 .53381 .47158 .55093 .45556 .54174 .4418 Mtetra
.81 .742 .788 r
.54174 .4418 .55093 .45556 .56803 .43762 .55892 .42399 Mtetra
.824 .747 .779 r
.55892 .42399 .56803 .43762 .58508 .41821 .57606 .40474 Mtetra
.833 .752 .774 r
.57606 .40474 .58508 .41821 .60206 .39779 .59315 .38449 Mtetra
.839 .756 .771 r
.59315 .38449 .60206 .39779 .61898 .37681 .61016 .36369 Mtetra
.843 .76 .771 r
.61016 .36369 .61898 .37681 .63583 .35569 .62712 .34274 Mtetra
.844 .764 .774 r
.62712 .34274 .63583 .35569 .65262 .3348 .64403 .32203 Mtetra
.842 .767 .779 r
.64403 .32203 .65262 .3348 .66939 .31448 .6609 .30187 Mtetra
.839 .77 .786 r
.6609 .30187 .66939 .31448 .68614 .29496 .67777 .2825 Mtetra
.833 .773 .795 r
.67777 .2825 .68614 .29496 .70291 .27644 .69464 .26411 Mtetra
.825 .774 .805 r
.69464 .26411 .70291 .27644 .71971 .25905 .71155 .24682 Mtetra
.815 .776 .816 r
.71155 .24682 .71971 .25905 .73657 .24283 .72851 .2307 Mtetra
.803 .776 .828 r
.72851 .2307 .73657 .24283 .75351 .22781 .74555 .21574 Mtetra
.79 .775 .839 r
.74555 .21574 .75351 .22781 .77055 .21395 .7627 .20194 Mtetra
.777 .773 .85 r
.7627 .20194 .77055 .21395 .78771 .20119 .77995 .18921 Mtetra
.763 .771 .86 r
.77995 .18921 .78771 .20119 .805 .18945 .79733 .17748 Mtetra
.472 .667 .948 r
.16468 .38786 .17471 .39759 .18845 .39776 .17845 .38789 Mtetra
.422 .642 .948 r
.17845 .38789 .18845 .39776 .20221 .39892 .19225 .38888 Mtetra
.362 .61 .944 r
.19225 .38888 .20221 .39892 .216 .40115 .20607 .39093 Mtetra
.294 .571 .935 r
.20607 .39093 .216 .40115 .22983 .40453 .21992 .3941 Mtetra
.221 .526 .919 r
.21992 .3941 .22983 .40453 .24371 .40908 .23383 .39842 Mtetra
.148 .477 .897 r
.23383 .39842 .24371 .40908 .25766 .41481 .24781 .40389 Mtetra
.079 .428 .871 r
.24781 .40389 .25766 .41481 .2717 .42165 .26187 .41046 Mtetra
.022 .385 .846 r
.26187 .41046 .2717 .42165 .28586 .42951 .27606 .41802 Mtetra
0 .351 .826 r
.27606 .41802 .28586 .42951 .30017 .4382 .29038 .42639 Mtetra
0 .332 .814 r
.29038 .42639 .30017 .4382 .31466 .44748 .30489 .43535 Mtetra
0 .328 .812 r
.30489 .43535 .31466 .44748 .32935 .45707 .31959 .44459 Mtetra
0 .341 .821 r
.31959 .44459 .32935 .45707 .34427 .46659 .33453 .45377 Mtetra
.05 .371 .839 r
.33453 .45377 .34427 .46659 .35945 .47564 .34972 .46248 Mtetra
.126 .414 .861 r
.34972 .46248 .35945 .47564 .37491 .48378 .36519 .4703 Mtetra
.218 .466 .881 r
.36519 .4703 .37491 .48378 .39064 .49056 .38094 .47678 Mtetra
.318 .52 .895 r
.38094 .47678 .39064 .49056 .40665 .49554 .39697 .48149 Mtetra
.417 .57 .899 r
.39697 .48149 .40665 .49554 .42294 .49833 .41328 .48406 Mtetra
.506 .613 .893 r
.41328 .48406 .42294 .49833 .43946 .4986 .42983 .48414 Mtetra
.582 .647 .88 r
.42983 .48414 .43946 .4986 .45621 .49611 .44661 .48153 Mtetra
.645 .673 .862 r
.44661 .48153 .45621 .49611 .47313 .49073 .46358 .47608 Mtetra
.695 .692 .844 r
.46358 .47608 .47313 .49073 .49018 .48245 .48069 .46778 Mtetra
.733 .707 .826 r
.48069 .46778 .49018 .48245 .50733 .47137 .4979 .45674 Mtetra
.764 .718 .81 r
.4979 .45674 .50733 .47137 .52453 .45772 .51516 .44318 Mtetra
.787 .726 .796 r
.51516 .44318 .52453 .45772 .54174 .4418 .53245 .42739 Mtetra
.805 .734 .786 r
.53245 .42739 .54174 .4418 .55892 .42399 .54972 .40976 Mtetra
.818 .74 .778 r
.54972 .40976 .55892 .42399 .57606 .40474 .56696 .3907 Mtetra
.827 .745 .773 r
.56696 .3907 .57606 .40474 .59315 .38449 .58414 .37066 Mtetra
.834 .75 .771 r
.58414 .37066 .59315 .38449 .61016 .36369 .60126 .35007 Mtetra
.838 .754 .771 r
.60126 .35007 .61016 .36369 .62712 .34274 .61832 .32935 Mtetra
.839 .758 .774 r
.61832 .32935 .62712 .34274 .64403 .32203 .63534 .30885 Mtetra
.838 .762 .779 r
.63534 .30885 .64403 .32203 .6609 .30187 .65232 .28888 Mtetra
.834 .766 .786 r
.65232 .28888 .6609 .30187 .67777 .2825 .66929 .2697 Mtetra
.829 .769 .795 r
.66929 .2697 .67777 .2825 .69464 .26411 .68627 .25147 Mtetra
.821 .771 .805 r
.68627 .25147 .69464 .26411 .71155 .24682 .70329 .23432 Mtetra
.812 .772 .816 r
.70329 .23432 .71155 .24682 .72851 .2307 .72036 .21831 Mtetra
.8 .773 .828 r
.72036 .21831 .72851 .2307 .74555 .21574 .7375 .20344 Mtetra
.788 .773 .839 r
.7375 .20344 .74555 .21574 .7627 .20194 .75474 .1897 Mtetra
.774 .771 .85 r
.75474 .1897 .7627 .20194 .77995 .18921 .7721 .17702 Mtetra
.761 .769 .86 r
.7721 .17702 .77995 .18921 .79733 .17748 .78957 .16532 Mtetra
.479 .669 .947 r
.15455 .37799 .16468 .38786 .17845 .38789 .16836 .37785 Mtetra
.431 .645 .947 r
.16836 .37785 .17845 .38789 .19225 .38888 .18219 .37867 Mtetra
.374 .614 .944 r
.18219 .37867 .19225 .38888 .20607 .39093 .19605 .38051 Mtetra
.31 .577 .935 r
.19605 .38051 .20607 .39093 .21992 .3941 .20994 .38345 Mtetra
.241 .534 .921 r
.20994 .38345 .21992 .3941 .23383 .39842 .22387 .38752 Mtetra
.172 .488 .902 r
.22387 .38752 .23383 .39842 .24781 .40389 .23788 .39271 Mtetra
.108 .443 .879 r
.23788 .39271 .24781 .40389 .26187 .41046 .25197 .39897 Mtetra
.054 .402 .857 r
.25197 .39897 .26187 .41046 .27606 .41802 .26618 .40619 Mtetra
.017 .37 .838 r
.26618 .40619 .27606 .41802 .29038 .42639 .28052 .41421 Mtetra
0 .351 .827 r
.28052 .41421 .29038 .42639 .30489 .43535 .29504 .4228 Mtetra
.005 .347 .825 r
.29504 .4228 .30489 .43535 .31959 .44459 .30977 .43167 Mtetra
.034 .36 .832 r
.30977 .43167 .31959 .44459 .33453 .45377 .32472 .44046 Mtetra
.087 .387 .847 r
.32472 .44046 .33453 .45377 .34972 .46248 .33993 .4488 Mtetra
.159 .427 .864 r
.33993 .4488 .34972 .46248 .36519 .4703 .35541 .45626 Mtetra
.246 .474 .88 r
.35541 .45626 .36519 .4703 .38094 .47678 .37118 .4624 Mtetra
.339 .523 .89 r
.37118 .4624 .38094 .47678 .39697 .48149 .38723 .46682 Mtetra
.43 .568 .891 r
.38723 .46682 .39697 .48149 .41328 .48406 .40356 .46913 Mtetra
.513 .608 .884 r
.40356 .46913 .41328 .48406 .42983 .48414 .42014 .46902 Mtetra
.585 .639 .871 r
.42014 .46902 .42983 .48414 .44661 .48153 .43695 .46627 Mtetra
.644 .664 .855 r
.43695 .46627 .44661 .48153 .46358 .47608 .45396 .46074 Mtetra
.691 .683 .838 r
.45396 .46074 .46358 .47608 .48069 .46778 .47112 .45244 Mtetra
.729 .698 .821 r
.47112 .45244 .48069 .46778 .4979 .45674 .48838 .44145 Mtetra
.758 .709 .806 r
.48838 .44145 .4979 .45674 .51516 .44318 .50572 .428 Mtetra
.781 .718 .794 r
.50572 .428 .51516 .44318 .53245 .42739 .52308 .41237 Mtetra
.799 .726 .784 r
.52308 .41237 .53245 .42739 .54972 .40976 .54043 .39493 Mtetra
.812 .733 .777 r
.54043 .39493 .54972 .40976 .56696 .3907 .55776 .3761 Mtetra
.822 .739 .772 r
.55776 .3761 .56696 .3907 .58414 .37066 .57503 .35631 Mtetra
.829 .744 .771 r
.57503 .35631 .58414 .37066 .60126 .35007 .59226 .33598 Mtetra
.833 .749 .771 r
.59226 .33598 .60126 .35007 .61832 .32935 .60942 .31552 Mtetra
.834 .754 .774 r
.60942 .31552 .61832 .32935 .63534 .30885 .62655 .29527 Mtetra
.833 .758 .78 r
.62655 .29527 .63534 .30885 .65232 .28888 .64364 .27553 Mtetra
.83 .762 .787 r
.64364 .27553 .65232 .28888 .66929 .2697 .66072 .25656 Mtetra
.825 .765 .796 r
.66072 .25656 .66929 .2697 .68627 .25147 .67781 .23852 Mtetra
.817 .767 .806 r
.67781 .23852 .68627 .25147 .70329 .23432 .69493 .22154 Mtetra
.808 .769 .817 r
.69493 .22154 .70329 .23432 .72036 .21831 .7121 .20566 Mtetra
.797 .77 .828 r
.7121 .20566 .72036 .21831 .7375 .20344 .72936 .19092 Mtetra
.785 .77 .84 r
.72936 .19092 .7375 .20344 .75474 .1897 .7467 .17726 Mtetra
.772 .769 .85 r
.7467 .17726 .75474 .1897 .7721 .17702 .76415 .16464 Mtetra
.758 .767 .86 r
.76415 .16464 .7721 .17702 .78957 .16532 .78172 .15298 Mtetra
.486 .671 .945 r
.14432 .36797 .15455 .37799 .16836 .37785 .15817 .36766 Mtetra
.44 .648 .946 r
.15817 .36766 .16836 .37785 .18219 .37867 .17204 .36828 Mtetra
.387 .619 .943 r
.17204 .36828 .18219 .37867 .19605 .38051 .18593 .3699 Mtetra
.326 .583 .936 r
.18593 .3699 .19605 .38051 .20994 .38345 .19986 .3726 Mtetra
.262 .543 .924 r
.19986 .3726 .20994 .38345 .22387 .38752 .21383 .37638 Mtetra
.197 .5 .906 r
.21383 .37638 .22387 .38752 .23788 .39271 .22787 .38127 Mtetra
.137 .457 .886 r
.22787 .38127 .23788 .39271 .25197 .39897 .24199 .38719 Mtetra
.087 .418 .866 r
.24199 .38719 .25197 .39897 .26618 .40619 .25622 .39405 Mtetra
.052 .388 .849 r
.25622 .39405 .26618 .40619 .28052 .41421 .27059 .40168 Mtetra
.037 .371 .839 r
.27059 .40168 .28052 .41421 .29504 .4228 .28513 .40986 Mtetra
.043 .367 .836 r
.28513 .40986 .29504 .4228 .30977 .43167 .29987 .41831 Mtetra
.072 .378 .842 r
.29987 .41831 .30977 .43167 .32472 .44046 .31484 .42669 Mtetra
.122 .403 .853 r
.31484 .42669 .32472 .44046 .33993 .4488 .33007 .43461 Mtetra
.191 .439 .867 r
.33007 .43461 .33993 .4488 .35541 .45626 .34557 .44167 Mtetra
.272 .481 .879 r
.34557 .44167 .35541 .45626 .37118 .4624 .36135 .44746 Mtetra
.358 .525 .885 r
.36135 .44746 .37118 .4624 .38723 .46682 .37742 .45155 Mtetra
.443 .567 .884 r
.37742 .45155 .38723 .46682 .40356 .46913 .39377 .45359 Mtetra
.52 .603 .877 r
.39377 .45359 .40356 .46913 .42014 .46902 .41038 .45327 Mtetra
.587 .633 .864 r
.41038 .45327 .42014 .46902 .43695 .46627 .42723 .45037 Mtetra
.643 .656 .848 r
.42723 .45037 .43695 .46627 .45396 .46074 .44427 .44477 Mtetra
.688 .675 .832 r
.44427 .44477 .45396 .46074 .47112 .45244 .46148 .43646 Mtetra
.724 .69 .817 r
.46148 .43646 .47112 .45244 .48838 .44145 .4788 .42554 Mtetra
.753 .701 .803 r
.4788 .42554 .48838 .44145 .50572 .428 .49619 .41222 Mtetra
.776 .711 .791 r
.49619 .41222 .50572 .428 .52308 .41237 .51363 .39677 Mtetra
.793 .719 .782 r
.51363 .39677 .52308 .41237 .54043 .39493 .53106 .37956 Mtetra
.807 .726 .776 r
.53106 .37956 .54043 .39493 .55776 .3761 .54847 .36099 Mtetra
.816 .733 .772 r
.54847 .36099 .55776 .3761 .57503 .35631 .56584 .34148 Mtetra
.823 .738 .771 r
.56584 .34148 .57503 .35631 .59226 .33598 .58316 .32144 Mtetra
.828 .744 .772 r
.58316 .32144 .59226 .33598 .60942 .31552 .60043 .30127 Mtetra
.829 .749 .775 r
.60043 .30127 .60942 .31552 .62655 .29527 .61766 .2813 Mtetra
.829 .754 .781 r
.61766 .2813 .62655 .29527 .64364 .27553 .63486 .26184 Mtetra
.826 .758 .788 r
.63486 .26184 .64364 .27553 .66072 .25656 .65205 .24311 Mtetra
.821 .761 .797 r
.65205 .24311 .66072 .25656 .67781 .23852 .66925 .22529 Mtetra
.813 .764 .807 r
.66925 .22529 .67781 .23852 .69493 .22154 .68648 .20849 Mtetra
.804 .766 .818 r
.68648 .20849 .69493 .22154 .7121 .20566 .70376 .19278 Mtetra
.794 .767 .829 r
.70376 .19278 .7121 .20566 .72936 .19092 .72111 .17816 Mtetra
.782 .768 .84 r
.72111 .17816 .72936 .19092 .7467 .17726 .73856 .16461 Mtetra
.769 .767 .851 r
.73856 .16461 .7467 .17726 .76415 .16464 .75611 .15206 Mtetra
.756 .765 .861 r
.75611 .15206 .76415 .16464 .78172 .15298 .77378 .14045 Mtetra
.493 .673 .944 r
.13399 .35781 .14432 .36797 .15817 .36766 .14789 .35732 Mtetra
.45 .651 .945 r
.14789 .35732 .15817 .36766 .17204 .36828 .1618 .35773 Mtetra
.399 .623 .943 r
.1618 .35773 .17204 .36828 .18593 .3699 .17573 .35911 Mtetra
.343 .59 .937 r
.17573 .35911 .18593 .3699 .19986 .3726 .18969 .36154 Mtetra
.282 .552 .926 r
.18969 .36154 .19986 .3726 .21383 .37638 .2037 .36502 Mtetra
.222 .512 .91 r
.2037 .36502 .21383 .37638 .22787 .38127 .21777 .36957 Mtetra
.166 .471 .892 r
.21777 .36957 .22787 .38127 .24199 .38719 .23192 .37513 Mtetra
.119 .435 .874 r
.23192 .37513 .24199 .38719 .25622 .39405 .24618 .3816 Mtetra
.087 .407 .859 r
.24618 .3816 .25622 .39405 .27059 .40168 .26058 .38881 Mtetra
.074 .39 .849 r
.26058 .38881 .27059 .40168 .28513 .40986 .27515 .39656 Mtetra
.081 .386 .846 r
.27515 .39656 .28513 .40986 .29987 .41831 .28991 .40456 Mtetra
.108 .395 .85 r
.28991 .40456 .29987 .41831 .31484 .42669 .3049 .41248 Mtetra
.156 .418 .859 r
.3049 .41248 .31484 .42669 .33007 .43461 .32015 .41996 Mtetra
.221 .45 .869 r
.32015 .41996 .33007 .43461 .34557 .44167 .33566 .42659 Mtetra
.296 .488 .877 r
.33566 .42659 .34557 .44167 .36135 .44746 .35146 .43198 Mtetra
.376 .528 .88 r
.35146 .43198 .36135 .44746 .37742 .45155 .36755 .43573 Mtetra
.455 .566 .878 r
.36755 .43573 .37742 .45155 .39377 .45359 .38392 .43747 Mtetra
.526 .599 .87 r
.38392 .43747 .39377 .45359 .41038 .45327 .40056 .43693 Mtetra
.589 .627 .857 r
.40056 .43693 .41038 .45327 .42723 .45037 .41743 .43388 Mtetra
.642 .65 .843 r
.41743 .43388 .42723 .45037 .44427 .44477 .43452 .4282 Mtetra
.685 .668 .827 r
.43452 .4282 .44427 .44477 .46148 .43646 .45176 .4199 Mtetra
.72 .682 .813 r
.45176 .4199 .46148 .43646 .4788 .42554 .46914 .40905 Mtetra
.748 .694 .8 r
.46914 .40905 .4788 .42554 .49619 .41222 .48659 .39587 Mtetra
.77 .704 .79 r
.48659 .39587 .49619 .41222 .51363 .39677 .50409 .38063 Mtetra
.788 .713 .781 r
.50409 .38063 .51363 .39677 .53106 .37956 .5216 .36367 Mtetra
.801 .72 .776 r
.5216 .36367 .53106 .37956 .54847 .36099 .5391 .34539 Mtetra
.811 .727 .772 r
.5391 .34539 .54847 .36099 .56584 .34148 .55656 .32619 Mtetra
.818 .733 .771 r
.55656 .32619 .56584 .34148 .58316 .32144 .57398 .30648 Mtetra
.822 .739 .772 r
.57398 .30648 .58316 .32144 .60043 .30127 .59135 .28663 Mtetra
.824 .745 .776 r
.59135 .28663 .60043 .30127 .61766 .2813 .60868 .26697 Mtetra
.824 .75 .782 r
.60868 .26697 .61766 .2813 .63486 .26184 .62599 .2478 Mtetra
.821 .754 .789 r
.62599 .2478 .63486 .26184 .65205 .24311 .64328 .22935 Mtetra
.816 .758 .798 r
.64328 .22935 .65205 .24311 .66925 .22529 .66059 .21177 Mtetra
.809 .761 .808 r
.66059 .21177 .66925 .22529 .68648 .20849 .67793 .19519 Mtetra
.801 .763 .819 r
.67793 .19519 .68648 .20849 .70376 .19278 .69531 .17966 Mtetra
.79 .765 .83 r
.69531 .17966 .70376 .19278 .72111 .17816 .71277 .16518 Mtetra
.779 .765 .841 r
.71277 .16518 .72111 .17816 .73856 .16461 .73032 .15175 Mtetra
.766 .765 .851 r
.73032 .15175 .73856 .16461 .75611 .15206 .74798 .13929 Mtetra
.753 .764 .861 r
.74798 .13929 .75611 .15206 .77378 .14045 .76575 .12774 Mtetra
.501 .675 .943 r
.12357 .34751 .13399 .35781 .14789 .35732 .1375 .34683 Mtetra
.46 .654 .944 r
.1375 .34683 .14789 .35732 .1618 .35773 .15145 .34701 Mtetra
.412 .628 .942 r
.15145 .34701 .1618 .35773 .17573 .35911 .16543 .34814 Mtetra
.359 .597 .937 r
.16543 .34814 .17573 .35911 .18969 .36154 .17943 .35028 Mtetra
.303 .561 .927 r
.17943 .35028 .18969 .36154 .2037 .36502 .19348 .35345 Mtetra
.246 .523 .914 r
.19348 .35345 .2037 .36502 .21777 .36957 .20759 .35764 Mtetra
.194 .486 .898 r
.20759 .35764 .21777 .36957 .23192 .37513 .22178 .36281 Mtetra
.151 .452 .882 r
.22178 .36281 .23192 .37513 .24618 .3816 .23607 .36886 Mtetra
.122 .425 .868 r
.23607 .36886 .24618 .3816 .26058 .38881 .2505 .37563 Mtetra
.11 .409 .859 r
.2505 .37563 .26058 .38881 .27515 .39656 .26509 .3829 Mtetra
.117 .404 .855 r
.26509 .3829 .27515 .39656 .28991 .40456 .27988 .39042 Mtetra
.144 .412 .857 r
.27988 .39042 .28991 .40456 .3049 .41248 .2949 .39786 Mtetra
.189 .432 .863 r
.2949 .39786 .3049 .41248 .32015 .41996 .31016 .40487 Mtetra
.249 .461 .87 r
.31016 .40487 .32015 .41996 .33566 .42659 .3257 .41105 Mtetra
.319 .495 .875 r
.3257 .41105 .33566 .42659 .35146 .43198 .34152 .41602 Mtetra
.393 .531 .876 r
.34152 .41602 .35146 .43198 .36755 .43573 .35762 .4194 Mtetra
.465 .565 .872 r
.35762 .4194 .36755 .43573 .38392 .43747 .37402 .42083 Mtetra
.532 .596 .863 r
.37402 .42083 .38392 .43747 .40056 .43693 .39068 .42005 Mtetra
.591 .622 .851 r
.39068 .42005 .40056 .43693 .41743 .43388 .40758 .41684 Mtetra
.641 .644 .837 r
.40758 .41684 .41743 .43388 .43452 .4282 .4247 .41109 Mtetra
.682 .661 .823 r
.4247 .41109 .43452 .4282 .45176 .4199 .44199 .40279 Mtetra
.716 .676 .81 r
.44199 .40279 .45176 .4199 .46914 .40905 .45941 .39203 Mtetra
.743 .688 .798 r
.45941 .39203 .46914 .40905 .48659 .39587 .47692 .37901 Mtetra
.765 .698 .788 r
.47692 .37901 .48659 .39587 .50409 .38063 .49449 .36399 Mtetra
.782 .707 .781 r
.49449 .36399 .50409 .38063 .5216 .36367 .51207 .3473 Mtetra
.795 .715 .776 r
.51207 .3473 .5216 .36367 .5391 .34539 .52964 .32934 Mtetra
.806 .722 .773 r
.52964 .32934 .5391 .34539 .55656 .32619 .54719 .31048 Mtetra
.813 .729 .772 r
.54719 .31048 .55656 .32619 .57398 .30648 .5647 .29112 Mtetra
.817 .735 .774 r
.5647 .29112 .57398 .30648 .59135 .28663 .58217 .27162 Mtetra
.819 .741 .777 r
.58217 .27162 .59135 .28663 .60868 .26697 .59961 .2523 Mtetra
.819 .746 .783 r
.59961 .2523 .60868 .26697 .62599 .2478 .61702 .23346 Mtetra
.816 .751 .79 r
.61702 .23346 .62599 .2478 .64328 .22935 .63442 .2153 Mtetra
.812 .755 .799 r
.63442 .2153 .64328 .22935 .66059 .21177 .65184 .19799 Mtetra
.805 .758 .809 r
.65184 .19799 .66059 .21177 .67793 .19519 .66928 .18164 Mtetra
.797 .761 .82 r
.66928 .18164 .67793 .19519 .69531 .17966 .68678 .1663 Mtetra
.787 .762 .831 r
.68678 .1663 .69531 .17966 .71277 .16518 .70434 .15199 Mtetra
.775 .763 .842 r
.70434 .15199 .71277 .16518 .73032 .15175 .72199 .13869 Mtetra
.763 .763 .852 r
.72199 .13869 .73032 .15175 .74798 .13929 .73975 .12633 Mtetra
.751 .762 .862 r
.73975 .12633 .74798 .13929 .76575 .12774 .75762 .11484 Mtetra
.508 .677 .941 r
.11304 .33708 .12357 .34751 .1375 .34683 .12702 .33619 Mtetra
.47 .657 .943 r
.12702 .33619 .1375 .34683 .15145 .34701 .14102 .33614 Mtetra
.425 .633 .941 r
.14102 .33614 .15145 .34701 .16543 .34814 .15503 .337 Mtetra
.376 .604 .937 r
.15503 .337 .16543 .34814 .17943 .35028 .16908 .33884 Mtetra
.323 .571 .929 r
.16908 .33884 .17943 .35028 .19348 .35345 .18317 .34167 Mtetra
.271 .535 .917 r
.18317 .34167 .19348 .35345 .20759 .35764 .19732 .34549 Mtetra
.222 .5 .903 r
.19732 .34549 .20759 .35764 .22178 .36281 .21155 .35025 Mtetra
.183 .468 .888 r
.21155 .35025 .22178 .36281 .23607 .36886 .22588 .35585 Mtetra
.156 .443 .876 r
.22588 .35585 .23607 .36886 .2505 .37563 .24034 .36215 Mtetra
.145 .427 .867 r
.24034 .36215 .2505 .37563 .26509 .3829 .25496 .36893 Mtetra
.152 .422 .862 r
.25496 .36893 .26509 .3829 .27988 .39042 .26978 .37594 Mtetra
.177 .429 .863 r
.26978 .37594 .27988 .39042 .2949 .39786 .28482 .38287 Mtetra
.219 .446 .866 r
.28482 .38287 .2949 .39786 .31016 .40487 .30011 .38938 Mtetra
.275 .471 .87 r
.30011 .38938 .31016 .40487 .3257 .41105 .31567 .39508 Mtetra
.34 .502 .873 r
.31567 .39508 .3257 .41105 .34152 .41602 .33151 .39961 Mtetra
.408 .534 .872 r
.33151 .39961 .34152 .41602 .35762 .4194 .34764 .4026 Mtetra
.475 .565 .867 r
.34764 .4026 .35762 .4194 .37402 .42083 .36405 .40371 Mtetra
.538 .593 .858 r
.36405 .40371 .37402 .42083 .39068 .42005 .38073 .40268 Mtetra
.593 .618 .846 r
.38073 .40268 .39068 .42005 .40758 .41684 .39767 .3993 Mtetra
.64 .639 .833 r
.39767 .3993 .40758 .41684 .4247 .41109 .41481 .39347 Mtetra
.679 .656 .82 r
.41481 .39347 .4247 .41109 .44199 .40279 .43214 .38518 Mtetra
.712 .67 .808 r
.43214 .38518 .44199 .40279 .45941 .39203 .44961 .37452 Mtetra
.738 .682 .797 r
.44961 .37452 .45941 .39203 .47692 .37901 .46718 .36167 Mtetra
.76 .693 .788 r
.46718 .36167 .47692 .37901 .49449 .36399 .4848 .34689 Mtetra
.777 .702 .781 r
.4848 .34689 .49449 .36399 .51207 .3473 .50246 .3305 Mtetra
.79 .71 .776 r
.50246 .3305 .51207 .3473 .52964 .32934 .52011 .31287 Mtetra
.8 .717 .773 r
.52011 .31287 .52964 .32934 .54719 .31048 .53774 .29437 Mtetra
.807 .724 .773 r
.53774 .29437 .54719 .31048 .5647 .29112 .55534 .27539 Mtetra
.812 .731 .775 r
.55534 .27539 .5647 .29112 .58217 .27162 .57291 .25626 Mtetra
.814 .737 .779 r
.57291 .25626 .58217 .27162 .59961 .2523 .59045 .23732 Mtetra
.814 .742 .785 r
.59045 .23732 .59961 .2523 .61702 .23346 .60796 .21881 Mtetra
.812 .747 .792 r
.60796 .21881 .61702 .23346 .63442 .2153 .62547 .20097 Mtetra
.807 .752 .801 r
.62547 .20097 .63442 .2153 .65184 .19799 .64299 .18395 Mtetra
.801 .755 .811 r
.64299 .18395 .65184 .19799 .66928 .18164 .66054 .16785 Mtetra
.793 .758 .822 r
.66054 .16785 .66928 .18164 .68678 .1663 .67814 .15273 Mtetra
.783 .76 .832 r
.67814 .15273 .68678 .1663 .70434 .15199 .69581 .1386 Mtetra
.772 .761 .843 r
.69581 .1386 .70434 .15199 .72199 .13869 .71356 .12543 Mtetra
.76 .761 .853 r
.71356 .12543 .72199 .13869 .73975 .12633 .73142 .11318 Mtetra
.748 .76 .863 r
.73142 .11318 .73975 .12633 .75762 .11484 .74939 .10177 Mtetra
.516 .68 .94 r
.10241 .32651 .11304 .33708 .12702 .33619 .11643 .32541 Mtetra
.48 .661 .941 r
.11643 .32541 .12702 .33619 .14102 .33614 .13048 .32511 Mtetra
.438 .638 .941 r
.13048 .32511 .14102 .33614 .15503 .337 .14454 .3257 Mtetra
.392 .611 .937 r
.14454 .3257 .15503 .337 .16908 .33884 .15864 .32722 Mtetra
.343 .58 .93 r
.15864 .32722 .16908 .33884 .18317 .34167 .17277 .32969 Mtetra
.295 .547 .92 r
.17277 .32969 .18317 .34167 .19732 .34549 .18696 .33312 Mtetra
.25 .514 .907 r
.18696 .33312 .19732 .34549 .21155 .35025 .20123 .33745 Mtetra
.213 .484 .894 r
.20123 .33745 .21155 .35025 .22588 .35585 .2156 .34259 Mtetra
.189 .46 .882 r
.2156 .34259 .22588 .35585 .24034 .36215 .2301 .3484 Mtetra
.179 .445 .874 r
.2301 .3484 .24034 .36215 .25496 .36893 .24476 .35466 Mtetra
.186 .439 .869 r
.24476 .35466 .25496 .36893 .26978 .37594 .25961 .36114 Mtetra
.209 .445 .867 r
.25961 .36114 .26978 .37594 .28482 .38287 .27468 .36754 Mtetra
.248 .459 .869 r
.27468 .36754 .28482 .38287 .30011 .38938 .28999 .37353 Mtetra
.3 .482 .871 r
.28999 .37353 .30011 .38938 .31567 .39508 .30558 .37873 Mtetra
.36 .509 .871 r
.30558 .37873 .31567 .39508 .33151 .39961 .32144 .38281 Mtetra
.423 .537 .868 r
.32144 .38281 .33151 .39961 .34764 .4026 .33759 .38539 Mtetra
.485 .566 .862 r
.33759 .38539 .34764 .4026 .36405 .40371 .35402 .38616 Mtetra
.543 .592 .853 r
.35402 .38616 .36405 .40371 .38073 .40268 .37073 .38487 Mtetra
.594 .615 .842 r
.37073 .38487 .38073 .40268 .39767 .3993 .38769 .38132 Mtetra
.639 .634 .829 r
.38769 .38132 .39767 .3993 .41481 .39347 .40487 .37541 Mtetra
.676 .651 .817 r
.40487 .37541 .41481 .39347 .43214 .38518 .42223 .36714 Mtetra
.708 .665 .806 r
.42223 .36714 .43214 .38518 .44961 .37452 .43974 .35657 Mtetra
.734 .677 .795 r
.43974 .35657 .44961 .37452 .46718 .36167 .45736 .3439 Mtetra
.755 .688 .787 r
.45736 .3439 .46718 .36167 .4848 .34689 .47505 .32938 Mtetra
.771 .697 .781 r
.47505 .32938 .4848 .34689 .50246 .3305 .49277 .3133 Mtetra
.785 .706 .776 r
.49277 .3133 .50246 .3305 .52011 .31287 .51049 .29602 Mtetra
.795 .713 .774 r
.51049 .29602 .52011 .31287 .53774 .29437 .52821 .27791 Mtetra
.802 .72 .774 r
.52821 .27791 .53774 .29437 .55534 .27539 .5459 .25932 Mtetra
.807 .727 .777 r
.5459 .25932 .55534 .27539 .57291 .25626 .56356 .24059 Mtetra
.809 .733 .781 r
.56356 .24059 .57291 .25626 .59045 .23732 .58119 .22203 Mtetra
.809 .739 .787 r
.58119 .22203 .59045 .23732 .60796 .21881 .59881 .20389 Mtetra
.807 .744 .794 r
.59881 .20389 .60796 .21881 .62547 .20097 .61642 .18639 Mtetra
.803 .749 .803 r
.61642 .18639 .62547 .20097 .64299 .18395 .63404 .16967 Mtetra
.796 .753 .813 r
.63404 .16967 .64299 .18395 .66054 .16785 .6517 .15383 Mtetra
.788 .756 .823 r
.6517 .15383 .66054 .16785 .67814 .15273 .66941 .13894 Mtetra
.779 .758 .834 r
.66941 .13894 .67814 .15273 .69581 .1386 .68718 .125 Mtetra
.768 .759 .844 r
.68718 .125 .69581 .1386 .71356 .12543 .70504 .11198 Mtetra
.757 .759 .854 r
.70504 .11198 .71356 .12543 .73142 .11318 .723 .09985 Mtetra
.745 .759 .864 r
.723 .09985 .73142 .11318 .74939 .10177 .74107 .08852 Mtetra
.524 .682 .938 r
.09167 .31581 .10241 .32651 .11643 .32541 .10574 .31448 Mtetra
.49 .665 .94 r
.10574 .31448 .11643 .32541 .13048 .32511 .11984 .31394 Mtetra
.451 .643 .94 r
.11984 .31394 .13048 .32511 .14454 .3257 .13395 .31424 Mtetra
.408 .617 .937 r
.13395 .31424 .14454 .3257 .15864 .32722 .14809 .31543 Mtetra
.363 .589 .931 r
.14809 .31543 .15864 .32722 .17277 .32969 .16228 .31754 Mtetra
.318 .558 .922 r
.16228 .31754 .17277 .32969 .18696 .33312 .17651 .32056 Mtetra
.277 .527 .911 r
.17651 .32056 .18696 .33312 .20123 .33745 .19083 .32445 Mtetra
.243 .499 .899 r
.19083 .32445 .20123 .33745 .2156 .34259 .20524 .3291 Mtetra
.22 .477 .888 r
.20524 .3291 .2156 .34259 .2301 .3484 .21978 .3344 Mtetra
.211 .462 .879 r
.21978 .3344 .2301 .3484 .24476 .35466 .23448 .34013 Mtetra
.218 .456 .874 r
.23448 .34013 .24476 .35466 .25961 .36114 .24937 .34606 Mtetra
.24 .46 .871 r
.24937 .34606 .25961 .36114 .27468 .36754 .26447 .35191 Mtetra
.276 .472 .871 r
.26447 .35191 .27468 .36754 .28999 .37353 .27981 .35735 Mtetra
.323 .492 .871 r
.27981 .35735 .28999 .37353 .30558 .37873 .29542 .36204 Mtetra
.378 .515 .869 r
.29542 .36204 .30558 .37873 .32144 .38281 .31131 .36564 Mtetra
.436 .541 .865 r
.31131 .36564 .32144 .38281 .33759 .38539 .32748 .36781 Mtetra
.494 .567 .858 r
.32748 .36781 .33759 .38539 .35402 .38616 .34394 .36823 Mtetra
.548 .591 .849 r
.34394 .36823 .35402 .38616 .37073 .38487 .36067 .36668 Mtetra
.596 .612 .838 r
.36067 .36668 .37073 .38487 .38769 .38132 .37765 .36295 Mtetra
.638 .631 .826 r
.37765 .36295 .38769 .38132 .40487 .37541 .39486 .35696 Mtetra
.674 .647 .815 r
.39486 .35696 .40487 .37541 .42223 .36714 .41226 .3487 Mtetra
.704 .661 .804 r
.41226 .3487 .42223 .36714 .43974 .35657 .42981 .33824 Mtetra
.729 .673 .795 r
.42981 .33824 .43974 .35657 .45736 .3439 .44748 .32576 Mtetra
.75 .683 .787 r
.44748 .32576 .45736 .3439 .47505 .32938 .46522 .3115 Mtetra
.766 .693 .781 r
.46522 .3115 .47505 .32938 .49277 .3133 .483 .29575 Mtetra
.78 .701 .777 r
.483 .29575 .49277 .3133 .51049 .29602 .5008 .27884 Mtetra
.79 .709 .776 r
.5008 .27884 .51049 .29602 .52821 .27791 .51859 .26112 Mtetra
.797 .717 .776 r
.51859 .26112 .52821 .27791 .5459 .25932 .53636 .24295 Mtetra
.802 .724 .778 r
.53636 .24295 .5459 .25932 .56356 .24059 .55412 .22463 Mtetra
.804 .73 .783 r
.55412 .22463 .56356 .24059 .58119 .22203 .57185 .20647 Mtetra
.804 .736 .789 r
.57185 .20647 .58119 .22203 .59881 .20389 .58956 .18872 Mtetra
.802 .742 .796 r
.58956 .18872 .59881 .20389 .61642 .18639 .60728 .17156 Mtetra
.798 .746 .805 r
.60728 .17156 .61642 .18639 .63404 .16967 .625 .15516 Mtetra
.792 .75 .815 r
.625 .15516 .63404 .16967 .6517 .15383 .64276 .1396 Mtetra
.784 .754 .825 r
.64276 .1396 .6517 .15383 .66941 .13894 .66058 .12494 Mtetra
.775 .756 .836 r
.66058 .12494 .66941 .13894 .68718 .125 .67845 .1112 Mtetra
.765 .757 .846 r
.67845 .1112 .68718 .125 .70504 .11198 .69642 .09834 Mtetra
.753 .757 .856 r
.69642 .09834 .70504 .11198 .723 .09985 .71448 .08633 Mtetra
.742 .757 .865 r
.71448 .08633 .723 .09985 .74107 .08852 .73265 .07509 Mtetra
.531 .685 .937 r
.08082 .30498 .09167 .31581 .10574 .31448 .09495 .30343 Mtetra
.5 .668 .938 r
.09495 .30343 .10574 .31448 .11984 .31394 .10909 .30262 Mtetra
.464 .648 .938 r
.10909 .30262 .11984 .31394 .13395 .31424 .12326 .30262 Mtetra
.424 .624 .936 r
.12326 .30262 .13395 .31424 .14809 .31543 .13745 .30348 Mtetra
.382 .597 .931 r
.13745 .30348 .14809 .31543 .16228 .31754 .15169 .30521 Mtetra
.341 .569 .923 r
.15169 .30521 .16228 .31754 .17651 .32056 .16598 .30781 Mtetra
.303 .54 .913 r
.16598 .30781 .17651 .32056 .19083 .32445 .18034 .31124 Mtetra
.272 .514 .903 r
.18034 .31124 .19083 .32445 .20524 .3291 .1948 .3154 Mtetra
.251 .493 .893 r
.1948 .3154 .20524 .3291 .21978 .3344 .20939 .32017 Mtetra
.243 .478 .884 r
.20939 .32017 .21978 .3344 .23448 .34013 .22413 .32535 Mtetra
.249 .472 .878 r
.22413 .32535 .23448 .34013 .24937 .34606 .23905 .33072 Mtetra
.269 .474 .875 r
.23905 .33072 .24937 .34606 .26447 .35191 .25419 .336 Mtetra
.302 .485 .872 r
.25419 .336 .26447 .35191 .27981 .35735 .26956 .34089 Mtetra
.345 .501 .87 r
.26956 .34089 .27981 .35735 .29542 .36204 .2852 .34505 Mtetra
.396 .522 .867 r
.2852 .34505 .29542 .36204 .31131 .36564 .30111 .34816 Mtetra
.449 .545 .862 r
.30111 .34816 .31131 .36564 .32748 .36781 .31731 .3499 Mtetra
.502 .568 .855 r
.31731 .3499 .32748 .36781 .34394 .36823 .33379 .34997 Mtetra
.552 .59 .846 r
.33379 .34997 .34394 .36823 .36067 .36668 .35055 .34814 Mtetra
.598 .61 .835 r
.35055 .34814 .36067 .36668 .37765 .36295 .36756 .34424 Mtetra
.638 .628 .824 r
.36756 .34424 .37765 .36295 .39486 .35696 .38479 .33817 Mtetra
.672 .643 .813 r
.38479 .33817 .39486 .35696 .41226 .3487 .40222 .32992 Mtetra
.701 .657 .803 r
.40222 .32992 .41226 .3487 .42981 .33824 .41981 .31957 Mtetra
.725 .669 .794 r
.41981 .31957 .42981 .33824 .44748 .32576 .43752 .30729 Mtetra
.745 .68 .787 r
.43752 .30729 .44748 .32576 .46522 .3115 .45531 .2933 Mtetra
.761 .689 .782 r
.45531 .2933 .46522 .3115 .483 .29575 .47316 .27788 Mtetra
.774 .698 .779 r
.47316 .27788 .483 .29575 .5008 .27884 .49102 .26135 Mtetra
.784 .706 .777 r
.49102 .26135 .5008 .27884 .51859 .26112 .50889 .24405 Mtetra
.792 .714 .778 r
.50889 .24405 .51859 .26112 .53636 .24295 .52675 .2263 Mtetra
.796 .721 .781 r
.52675 .2263 .53636 .24295 .55412 .22463 .54459 .20841 Mtetra
.799 .727 .785 r
.54459 .20841 .55412 .22463 .57185 .20647 .56241 .19066 Mtetra
.799 .734 .791 r
.56241 .19066 .57185 .20647 .58956 .18872 .58022 .1733 Mtetra
.797 .739 .799 r
.58022 .1733 .58956 .18872 .60728 .17156 .59804 .15651 Mtetra
.793 .744 .807 r
.59804 .15651 .60728 .17156 .625 .15516 .61587 .14043 Mtetra
.787 .748 .817 r
.61587 .14043 .625 .15516 .64276 .1396 .63373 .12516 Mtetra
.78 .751 .827 r
.63373 .12516 .64276 .1396 .66058 .12494 .65165 .11075 Mtetra
.771 .754 .838 r
.65165 .11075 .66058 .12494 .67845 .1112 .66963 .09721 Mtetra
.761 .755 .848 r
.66963 .09721 .67845 .1112 .69642 .09834 .6877 .08452 Mtetra
.75 .756 .857 r
.6877 .08452 .69642 .09834 .71448 .08633 .70586 .07264 Mtetra
.739 .756 .866 r
.70586 .07264 .71448 .08633 .73265 .07509 .72413 .06149 Mtetra
.539 .687 .935 r
.06987 .29402 .08082 .30498 .09495 .30343 .08405 .29224 Mtetra
.509 .672 .937 r
.08405 .29224 .09495 .30343 .10909 .30262 .09824 .29117 Mtetra
.476 .653 .937 r
.09824 .29117 .10909 .30262 .12326 .30262 .11246 .29086 Mtetra
.439 .631 .935 r
.11246 .29086 .12326 .30262 .13745 .30348 .12671 .29137 Mtetra
.401 .606 .931 r
.12671 .29137 .13745 .30348 .15169 .30521 .141 .29272 Mtetra
.363 .579 .924 r
.141 .29272 .15169 .30521 .16598 .30781 .15534 .29489 Mtetra
.328 .553 .916 r
.15534 .29489 .16598 .30781 .18034 .31124 .16976 .29785 Mtetra
.299 .528 .906 r
.16976 .29785 .18034 .31124 .1948 .3154 .18427 .30151 Mtetra
.28 .508 .897 r
.18427 .30151 .1948 .3154 .20939 .32017 .1989 .30574 Mtetra
.272 .494 .888 r
.1989 .30574 .20939 .32017 .22413 .32535 .21369 .31036 Mtetra
.278 .487 .882 r
.21369 .31036 .22413 .32535 .23905 .33072 .22865 .31515 Mtetra
.296 .488 .877 r
.22865 .31515 .23905 .33072 .25419 .336 .24383 .31985 Mtetra
.326 .497 .874 r
.24383 .31985 .25419 .336 .26956 .34089 .25924 .32418 Mtetra
.366 .511 .87 r
.25924 .32418 .26956 .34089 .2852 .34505 .27491 .3278 Mtetra
.412 .529 .866 r
.27491 .3278 .2852 .34505 .30111 .34816 .29085 .33042 Mtetra
.461 .55 .86 r
.29085 .33042 .30111 .34816 .31731 .3499 .30707 .33172 Mtetra
.51 .571 .852 r
.30707 .33172 .31731 .3499 .33379 .34997 .32358 .33143 Mtetra
.557 .591 .843 r
.32358 .33143 .33379 .34997 .35055 .34814 .34036 .32932 Mtetra
.599 .609 .833 r
.34036 .32932 .35055 .34814 .36756 .34424 .3574 .32524 Mtetra
.637 .626 .822 r
.3574 .32524 .36756 .34424 .38479 .33817 .37466 .31908 Mtetra
.67 .641 .812 r
.37466 .31908 .38479 .33817 .40222 .32992 .39212 .31085 Mtetra
.698 .654 .803 r
.39212 .31085 .40222 .32992 .41981 .31957 .40975 .30062 Mtetra
.721 .666 .795 r
.40975 .30062 .41981 .31957 .43752 .30729 .4275 .28854 Mtetra
.741 .676 .788 r
.4275 .28854 .43752 .30729 .45531 .2933 .44534 .27482 Mtetra
.757 .686 .783 r
.44534 .27482 .45531 .2933 .47316 .27788 .46324 .25975 Mtetra
.769 .695 .78 r
.46324 .25975 .47316 .27788 .49102 .26135 .48117 .24361 Mtetra
.779 .703 .779 r
.48117 .24361 .49102 .26135 .50889 .24405 .49911 .22672 Mtetra
.786 .711 .78 r
.49911 .22672 .50889 .24405 .52675 .2263 .51704 .2094 Mtetra
.791 .718 .783 r
.51704 .2094 .52675 .2263 .54459 .20841 .53497 .19195 Mtetra
.794 .725 .788 r
.53497 .19195 .54459 .20841 .56241 .19066 .55288 .17463 Mtetra
.794 .731 .794 r
.55288 .17463 .56241 .19066 .58022 .1733 .57079 .15767 Mtetra
.792 .737 .801 r
.57079 .15767 .58022 .1733 .59804 .15651 .5887 .14125 Mtetra
.788 .742 .81 r
.5887 .14125 .59804 .15651 .61587 .14043 .60664 .12551 Mtetra
.783 .746 .82 r
.60664 .12551 .61587 .14043 .63373 .12516 .6246 .11053 Mtetra
.775 .749 .829 r
.6246 .11053 .63373 .12516 .65165 .11075 .64262 .09637 Mtetra
.767 .752 .84 r
.64262 .09637 .65165 .11075 .66963 .09721 .66071 .08304 Mtetra
.757 .754 .849 r
.66071 .08304 .66963 .09721 .6877 .08452 .67887 .07052 Mtetra
.747 .754 .859 r
.67887 .07052 .6877 .08452 .70586 .07264 .69714 .05877 Mtetra
.736 .754 .867 r
.69714 .05877 .70586 .07264 .72413 .06149 .71552 .04772 Mtetra
.546 .69 .934 r
.0588 .28295 .06987 .29402 .08405 .29224 .07303 .28093 Mtetra
.519 .675 .935 r
.07303 .28093 .08405 .29224 .09824 .29117 .08728 .27958 Mtetra
.488 .658 .936 r
.08728 .27958 .09824 .29117 .11246 .29086 .10156 .27897 Mtetra
.454 .637 .934 r
.10156 .27897 .11246 .29086 .12671 .29137 .11586 .27913 Mtetra
.419 .614 .931 r
.11586 .27913 .12671 .29137 .141 .29272 .13021 .28008 Mtetra
.384 .589 .925 r
.13021 .28008 .141 .29272 .15534 .29489 .14461 .28182 Mtetra
.352 .565 .917 r
.14461 .28182 .15534 .29489 .16976 .29785 .15908 .2843 Mtetra
.326 .542 .909 r
.15908 .2843 .16976 .29785 .18427 .30151 .17364 .28745 Mtetra
.308 .523 .9 r
.17364 .28745 .18427 .30151 .1989 .30574 .18833 .29113 Mtetra
.301 .509 .892 r
.18833 .29113 .1989 .30574 .21369 .31036 .20316 .29518 Mtetra
.305 .502 .885 r
.20316 .29518 .21369 .31036 .22865 .31515 .21818 .29939 Mtetra
.322 .502 .88 r
.21818 .29939 .22865 .31515 .24383 .31985 .23339 .3035 Mtetra
.349 .509 .875 r
.23339 .3035 .24383 .31985 .25924 .32418 .24884 .30725 Mtetra
.386 .521 .87 r
.24884 .30725 .25924 .32418 .27491 .3278 .26455 .31033 Mtetra
.428 .536 .865 r
.26455 .31033 .27491 .3278 .29085 .33042 .28052 .31245 Mtetra
.473 .555 .858 r
.28052 .31245 .29085 .33042 .30707 .33172 .29677 .31331 Mtetra
.518 .573 .85 r
.29677 .31331 .30707 .33172 .32358 .33143 .31331 .31265 Mtetra
.561 .592 .841 r
.31331 .31265 .32358 .33143 .34036 .32932 .33011 .31027 Mtetra
.601 .609 .831 r
.33011 .31027 .34036 .32932 .3574 .32524 .34717 .306 Mtetra
.637 .624 .821 r
.34717 .306 .3574 .32524 .37466 .31908 .36446 .29976 Mtetra
.668 .639 .812 r
.36446 .29976 .37466 .31908 .39212 .31085 .38195 .29154 Mtetra
.695 .651 .803 r
.38195 .29154 .39212 .31085 .40975 .30062 .39961 .28142 Mtetra
.717 .663 .795 r
.39961 .28142 .40975 .30062 .4275 .28854 .4174 .26955 Mtetra
.736 .674 .789 r
.4174 .26955 .4275 .28854 .44534 .27482 .43529 .25611 Mtetra
.752 .683 .785 r
.43529 .25611 .44534 .27482 .46324 .25975 .45324 .24138 Mtetra
.764 .692 .782 r
.45324 .24138 .46324 .25975 .48117 .24361 .47124 .22563 Mtetra
.774 .701 .782 r
.47124 .22563 .48117 .24361 .49911 .22672 .48924 .20917 Mtetra
.781 .708 .783 r
.48924 .20917 .49911 .22672 .51704 .2094 .50726 .19229 Mtetra
.786 .716 .786 r
.50726 .19229 .51704 .2094 .53497 .19195 .52526 .17528 Mtetra
.789 .723 .791 r
.52526 .17528 .53497 .19195 .55288 .17463 .54326 .15839 Mtetra
.789 .729 .797 r
.54326 .15839 .55288 .17463 .57079 .15767 .56126 .14184 Mtetra
.787 .735 .804 r
.56126 .14184 .57079 .15767 .5887 .14125 .57927 .12579 Mtetra
.783 .74 .813 r
.57927 .12579 .5887 .14125 .60664 .12551 .59731 .11039 Mtetra
.778 .744 .822 r
.59731 .11039 .60664 .12551 .6246 .11053 .61537 .09572 Mtetra
.771 .748 .832 r
.61537 .09572 .6246 .11053 .64262 .09637 .63349 .08182 Mtetra
.762 .75 .842 r
.63349 .08182 .64262 .09637 .66071 .08304 .65168 .0687 Mtetra
.753 .752 .851 r
.65168 .0687 .66071 .08304 .67887 .07052 .66995 .05635 Mtetra
.743 .753 .86 r
.66995 .05635 .67887 .07052 .69714 .05877 .68832 .04473 Mtetra
.733 .753 .868 r
.68832 .04473 .69714 .05877 .71552 .04772 .7068 .03378 Mtetra
.553 .693 .932 r
.04762 .27175 .0588 .28295 .07303 .28093 .06191 .26949 Mtetra
.528 .679 .934 r
.06191 .26949 .07303 .28093 .08728 .27958 .07621 .26787 Mtetra
.5 .663 .934 r
.07621 .26787 .08728 .27958 .10156 .27897 .09055 .26694 Mtetra
.469 .644 .933 r
.09055 .26694 .10156 .27897 .11586 .27913 .10491 .26675 Mtetra
.436 .622 .93 r
.10491 .26675 .11586 .27913 .13021 .28008 .11932 .2673 Mtetra
.404 .599 .925 r
.11932 .2673 .13021 .28008 .14461 .28182 .13377 .2686 Mtetra
.375 .576 .919 r
.13377 .2686 .14461 .28182 .15908 .2843 .1483 .2706 Mtetra
.351 .555 .911 r
.1483 .2706 .15908 .2843 .17364 .28745 .16292 .27323 Mtetra
.334 .537 .902 r
.16292 .27323 .17364 .28745 .18833 .29113 .17767 .27636 Mtetra
.327 .523 .895 r
.17767 .27636 .18833 .29113 .20316 .29518 .19255 .27983 Mtetra
.331 .516 .888 r
.19255 .27983 .20316 .29518 .21818 .29939 .20761 .28345 Mtetra
.346 .515 .881 r
.20761 .28345 .21818 .29939 .23339 .3035 .22288 .28698 Mtetra
.371 .52 .876 r
.22288 .28698 .23339 .3035 .24884 .30725 .23837 .29015 Mtetra
.404 .53 .87 r
.23837 .29015 .24884 .30725 .26455 .31033 .25411 .29268 Mtetra
.442 .544 .864 r
.25411 .29268 .26455 .31033 .28052 .31245 .27012 .2943 Mtetra
.484 .56 .857 r
.27012 .2943 .28052 .31245 .29677 .31331 .2864 .29471 Mtetra
.526 .576 .849 r
.2864 .29471 .29677 .31331 .31331 .31265 .30296 .29369 Mtetra
.566 .593 .84 r
.30296 .29369 .31331 .31265 .33011 .31027 .31979 .29102 Mtetra
.603 .609 .83 r
.31979 .29102 .33011 .31027 .34717 .306 .33688 .28656 Mtetra
.637 .624 .821 r
.33688 .28656 .34717 .306 .36446 .29976 .35419 .28024 Mtetra
.666 .637 .811 r
.35419 .28024 .36446 .29976 .38195 .29154 .37171 .27204 Mtetra
.692 .65 .803 r
.37171 .27204 .38195 .29154 .39961 .28142 .38941 .26204 Mtetra
.714 .661 .796 r
.38941 .26204 .39961 .28142 .4174 .26955 .40724 .25036 Mtetra
.732 .671 .791 r
.40724 .25036 .4174 .26955 .43529 .25611 .42517 .23721 Mtetra
.747 .681 .787 r
.42517 .23721 .43529 .25611 .45324 .24138 .44317 .22282 Mtetra
.76 .69 .785 r
.44317 .22282 .45324 .24138 .47124 .22563 .46122 .20747 Mtetra
.769 .698 .784 r
.46122 .20747 .47124 .22563 .48924 .20917 .4793 .19143 Mtetra
.776 .706 .786 r
.4793 .19143 .48924 .20917 .50726 .19229 .49738 .175 Mtetra
.781 .714 .789 r
.49738 .175 .50726 .19229 .52526 .17528 .51547 .15843 Mtetra
.783 .721 .794 r
.51547 .15843 .52526 .17528 .54326 .15839 .53355 .14197 Mtetra
.784 .727 .8 r
.53355 .14197 .54326 .15839 .56126 .14184 .55164 .12583 Mtetra
.782 .733 .807 r
.55164 .12583 .56126 .14184 .57927 .12579 .56975 .11016 Mtetra
.779 .738 .816 r
.56975 .11016 .57927 .12579 .59731 .11039 .58788 .0951 Mtetra
.773 .742 .825 r
.58788 .0951 .59731 .11039 .61537 .09572 .60604 .08073 Mtetra
.766 .746 .834 r
.60604 .08073 .61537 .09572 .63349 .08182 .62426 .06708 Mtetra
.758 .749 .844 r
.62426 .06708 .63349 .08182 .65168 .0687 .64255 .05418 Mtetra
.749 .75 .853 r
.64255 .05418 .65168 .0687 .66995 .05635 .66093 .04201 Mtetra
.739 .751 .862 r
.66093 .04201 .66995 .05635 .68832 .04473 .6794 .03052 Mtetra
.73 .752 .87 r
.6794 .03052 .68832 .04473 .7068 .03378 .69798 .01967 Mtetra
.56 .695 .931 r
.03632 .26043 .04762 .27175 .06191 .26949 .05066 .25793 Mtetra
.537 .682 .932 r
.05066 .25793 .06191 .26949 .07621 .26787 .06503 .25603 Mtetra
.511 .667 .933 r
.06503 .25603 .07621 .26787 .09055 .26694 .07942 .25479 Mtetra
.482 .65 .932 r
.07942 .25479 .09055 .26694 .10491 .26675 .09385 .25424 Mtetra
.453 .63 .93 r
.09385 .25424 .10491 .26675 .11932 .2673 .10831 .25439 Mtetra
.423 .609 .925 r
.10831 .25439 .11932 .2673 .13377 .2686 .12283 .25525 Mtetra
.396 .587 .919 r
.12283 .25525 .13377 .2686 .1483 .2706 .13743 .25677 Mtetra
.374 .567 .912 r
.13743 .25677 .1483 .2706 .16292 .27323 .15211 .25888 Mtetra
.359 .55 .904 r
.15211 .25888 .16292 .27323 .17767 .27636 .16691 .26145 Mtetra
.353 .537 .897 r
.16691 .26145 .17767 .27636 .19255 .27983 .18185 .26435 Mtetra
.356 .53 .89 r
.18185 .26435 .19255 .27983 .20761 .28345 .19697 .26738 Mtetra
.369 .528 .883 r
.19697 .26738 .20761 .28345 .22288 .28698 .21228 .27031 Mtetra
.392 .531 .877 r
.21228 .27031 .22288 .28698 .23837 .29015 .22781 .27291 Mtetra
.421 .539 .871 r
.22781 .27291 .23837 .29015 .25411 .29268 .2436 .27489 Mtetra
.456 .551 .864 r
.2436 .27489 .25411 .29268 .27012 .2943 .25964 .276 Mtetra
.494 .565 .856 r
.25964 .276 .27012 .2943 .2864 .29471 .27595 .27597 Mtetra
.533 .58 .848 r
.27595 .27597 .2864 .29471 .30296 .29369 .29254 .27458 Mtetra
.57 .595 .839 r
.29254 .27458 .30296 .29369 .31979 .29102 .3094 .27163 Mtetra
.605 .61 .83 r
.3094 .27163 .31979 .29102 .33688 .28656 .32651 .26698 Mtetra
.637 .624 .82 r
.32651 .26698 .33688 .28656 .35419 .28024 .34386 .26057 Mtetra
.665 .636 .812 r
.34386 .26057 .35419 .28024 .37171 .27204 .36141 .25239 Mtetra
.689 .648 .804 r
.36141 .25239 .37171 .27204 .38941 .26204 .37913 .2425 Mtetra
.71 .659 .798 r
.37913 .2425 .38941 .26204 .40724 .25036 .39699 .23103 Mtetra
.728 .67 .793 r
.39699 .23103 .40724 .25036 .42517 .23721 .41497 .21815 Mtetra
.743 .679 .789 r
.41497 .21815 .42517 .23721 .44317 .22282 .43302 .20411 Mtetra
.755 .688 .787 r
.43302 .20411 .44317 .22282 .46122 .20747 .45113 .18915 Mtetra
.764 .697 .787 r
.45113 .18915 .46122 .20747 .4793 .19143 .46926 .17354 Mtetra
.771 .704 .789 r
.46926 .17354 .4793 .19143 .49738 .175 .48742 .15754 Mtetra
.776 .712 .792 r
.48742 .15754 .49738 .175 .51547 .15843 .50558 .14142 Mtetra
.778 .719 .797 r
.50558 .14142 .51547 .15843 .53355 .14197 .52375 .12539 Mtetra
.779 .725 .803 r
.52375 .12539 .53355 .14197 .55164 .12583 .54193 .10965 Mtetra
.777 .731 .81 r
.54193 .10965 .55164 .12583 .56975 .11016 .56013 .09437 Mtetra
.774 .736 .819 r
.56013 .09437 .56975 .11016 .58788 .0951 .57835 .07965 Mtetra
.768 .741 .828 r
.57835 .07965 .58788 .0951 .60604 .08073 .59661 .06557 Mtetra
.762 .744 .837 r
.59661 .06557 .60604 .08073 .62426 .06708 .61493 .05219 Mtetra
.754 .747 .846 r
.61493 .05219 .62426 .06708 .64255 .05418 .63333 .0395 Mtetra
.745 .749 .855 r
.63333 .0395 .64255 .05418 .66093 .04201 .6518 .0275 Mtetra
.736 .75 .864 r
.6518 .0275 .66093 .04201 .6794 .03052 .67037 .01615 Mtetra
.726 .75 .871 r
.67037 .01615 .6794 .03052 .69798 .01967 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .53889 Mtetra
.5879 .53889 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53034 Mtetra
.61624 .53034 .62337 .53824 .63759 .53397 .63052 .52603 Mtetra
.63052 .52603 .63759 .53397 .6519 .52968 .64487 .5217 Mtetra
.64487 .5217 .6519 .52968 .66627 .52537 .6593 .51735 Mtetra
.6593 .51735 .66627 .52537 .68072 .52103 .67379 .51297 Mtetra
.67379 .51297 .68072 .52103 .69524 .51668 .68837 .50857 Mtetra
.68837 .50857 .69524 .51668 .70984 .5123 .70302 .50415 Mtetra
.70302 .50415 .70984 .5123 .72452 .5079 .71774 .49971 Mtetra
.71774 .49971 .72452 .5079 .73926 .50347 .73255 .49524 Mtetra
.73255 .49524 .73926 .50347 .75409 .49902 .74743 .49075 Mtetra
.74743 .49075 .75409 .49902 .76899 .49455 .76238 .48624 Mtetra
.76238 .48624 .76899 .49455 .78397 .49006 .77742 .4817 Mtetra
.77742 .4817 .78397 .49006 .79903 .48554 .79253 .47714 Mtetra
.79253 .47714 .79903 .48554 .81417 .481 .80773 .47255 Mtetra
.80773 .47255 .81417 .481 .82939 .47643 .823 .46794 Mtetra
.823 .46794 .82939 .47643 .84468 .47184 .83836 .46331 Mtetra
.83836 .46331 .84468 .47184 .86006 .46723 .8538 .45865 Mtetra
.8538 .45865 .86006 .46723 .87552 .46259 .86932 .45397 Mtetra
.86932 .45397 .87552 .46259 .89107 .45793 .88492 .44926 Mtetra
.88492 .44926 .89107 .45793 .90669 .45324 .9006 .44452 Mtetra
.9006 .44452 .90669 .45324 .9224 .44853 .91637 .43976 Mtetra
.91637 .43976 .9224 .44853 .93819 .44379 .93223 .43498 Mtetra
.93223 .43498 .93819 .44379 .95407 .43903 .94817 .43017 Mtetra
.94817 .43017 .95407 .43903 .97003 .43424 .96419 .42533 Mtetra
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.5665 .53529 .57384 .54314 .5879 .53889 .58061 .531 Mtetra
.58061 .531 .5879 .53889 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53034 .60905 .52237 Mtetra
.60905 .52237 .61624 .53034 .63052 .52603 .62338 .51802 Mtetra
.62338 .51802 .63052 .52603 .64487 .5217 .63778 .51365 Mtetra
.63778 .51365 .64487 .5217 .6593 .51735 .65225 .50925 Mtetra
.65225 .50925 .6593 .51735 .67379 .51297 .6668 .50483 Mtetra
.6668 .50483 .67379 .51297 .68837 .50857 .68143 .50039 Mtetra
.68143 .50039 .68837 .50857 .70302 .50415 .69613 .49593 Mtetra
.69613 .49593 .70302 .50415 .71774 .49971 .71091 .49144 Mtetra
.71091 .49144 .71774 .49971 .73255 .49524 .72577 .48693 Mtetra
.72577 .48693 .73255 .49524 .74743 .49075 .7407 .4824 Mtetra
.7407 .4824 .74743 .49075 .76238 .48624 .75571 .47784 Mtetra
.75571 .47784 .76238 .48624 .77742 .4817 .7708 .47326 Mtetra
.7708 .47326 .77742 .4817 .79253 .47714 .78597 .46865 Mtetra
.78597 .46865 .79253 .47714 .80773 .47255 .80122 .46402 Mtetra
.80122 .46402 .80773 .47255 .823 .46794 .81656 .45937 Mtetra
.81656 .45937 .823 .46794 .83836 .46331 .83197 .45469 Mtetra
.83197 .45469 .83836 .46331 .8538 .45865 .84747 .44998 Mtetra
.84747 .44998 .8538 .45865 .86932 .45397 .86305 .44525 Mtetra
.86305 .44525 .86932 .45397 .88492 .44926 .87871 .4405 Mtetra
.87871 .4405 .88492 .44926 .9006 .44452 .89445 .43572 Mtetra
.89445 .43572 .9006 .44452 .91637 .43976 .91029 .43091 Mtetra
.91029 .43091 .91637 .43976 .93223 .43498 .9262 .42608 Mtetra
.9262 .42608 .93223 .43498 .94817 .43017 .94221 .42122 Mtetra
.94221 .42122 .94817 .43017 .96419 .42533 .9583 .41633 Mtetra
.38141 .58164 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55703 Mtetra
.46198 .55703 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53595 Mtetra
.531 .53595 .5385 .54379 .55246 .53955 .54501 .53166 Mtetra
.54501 .53166 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .531 .57325 .52304 Mtetra
.57325 .52304 .58061 .531 .59479 .5267 .58748 .51869 Mtetra
.58748 .51869 .59479 .5267 .60905 .52237 .60179 .51432 Mtetra
.60179 .51432 .60905 .52237 .62338 .51802 .61616 .50993 Mtetra
.61616 .50993 .62338 .51802 .63778 .51365 .63062 .50552 Mtetra
.63062 .50552 .63778 .51365 .65225 .50925 .64514 .50108 Mtetra
.64514 .50108 .65225 .50925 .6668 .50483 .65974 .49662 Mtetra
.65974 .49662 .6668 .50483 .68143 .50039 .67442 .49214 Mtetra
.67442 .49214 .68143 .50039 .69613 .49593 .68918 .48763 Mtetra
.68918 .48763 .69613 .49593 .71091 .49144 .70401 .4831 Mtetra
.70401 .4831 .71091 .49144 .72577 .48693 .71892 .47854 Mtetra
.71892 .47854 .72577 .48693 .7407 .4824 .73391 .47397 Mtetra
.73391 .47397 .7407 .4824 .75571 .47784 .74897 .46936 Mtetra
.74897 .46936 .75571 .47784 .7708 .47326 .76412 .46474 Mtetra
.76412 .46474 .7708 .47326 .78597 .46865 .77935 .46009 Mtetra
.77935 .46009 .78597 .46865 .80122 .46402 .79466 .45541 Mtetra
.79466 .45541 .80122 .46402 .81656 .45937 .81005 .45071 Mtetra
.81005 .45071 .81656 .45937 .83197 .45469 .82552 .44598 Mtetra
.82552 .44598 .83197 .45469 .84747 .44998 .84107 .44123 Mtetra
.84107 .44123 .84747 .44998 .86305 .44525 .85671 .43645 Mtetra
.85671 .43645 .86305 .44525 .87871 .4405 .87244 .43165 Mtetra
.87244 .43165 .87871 .4405 .89445 .43572 .88825 .42682 Mtetra
.88825 .42682 .89445 .43572 .91029 .43091 .90414 .42197 Mtetra
.90414 .42197 .91029 .43091 .9262 .42608 .92012 .41709 Mtetra
.92012 .41709 .9262 .42608 .94221 .42122 .93619 .41218 Mtetra
.93619 .41218 .94221 .42122 .9583 .41633 .95234 .40724 Mtetra
.37336 .57414 .38141 .58164 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56595 Mtetra
.40003 .56595 .408 .57351 .42139 .56942 .41347 .56182 Mtetra
.41347 .56182 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .5535 Mtetra
.44054 .5535 .44838 .56118 .46198 .55703 .45418 .54931 Mtetra
.45418 .54931 .46198 .55703 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53233 Mtetra
.50944 .53233 .51705 .5402 .531 .53595 .52343 .52803 Mtetra
.52343 .52803 .531 .53595 .54501 .53166 .53749 .52371 Mtetra
.53749 .52371 .54501 .53166 .5591 .52736 .55162 .51936 Mtetra
.55162 .51936 .5591 .52736 .57325 .52304 .56582 .515 Mtetra
.56582 .515 .57325 .52304 .58748 .51869 .5801 .51061 Mtetra
.5801 .51061 .58748 .51869 .60179 .51432 .59446 .5062 Mtetra
.59446 .5062 .60179 .51432 .61616 .50993 .60888 .50177 Mtetra
.60888 .50177 .61616 .50993 .63062 .50552 .62339 .49731 Mtetra
.62339 .49731 .63062 .50552 .64514 .50108 .63796 .49283 Mtetra
.63796 .49283 .64514 .50108 .65974 .49662 .65262 .48833 Mtetra
.65262 .48833 .65974 .49662 .67442 .49214 .66735 .4838 Mtetra
.66735 .4838 .67442 .49214 .68918 .48763 .68215 .47925 Mtetra
.68215 .47925 .68918 .48763 .70401 .4831 .69704 .47468 Mtetra
.69704 .47468 .70401 .4831 .71892 .47854 .712 .47008 Mtetra
.712 .47008 .71892 .47854 .73391 .47397 .72705 .46545 Mtetra
.72705 .46545 .73391 .47397 .74897 .46936 .74217 .46081 Mtetra
.74217 .46081 .74897 .46936 .76412 .46474 .75737 .45613 Mtetra
.75737 .45613 .76412 .46474 .77935 .46009 .77266 .45144 Mtetra
.77266 .45144 .77935 .46009 .79466 .45541 .78802 .44672 Mtetra
.78802 .44672 .79466 .45541 .81005 .45071 .80347 .44197 Mtetra
.80347 .44197 .81005 .45071 .82552 .44598 .819 .43719 Mtetra
.819 .43719 .82552 .44598 .84107 .44123 .83462 .4324 Mtetra
.83462 .4324 .84107 .44123 .85671 .43645 .85032 .42757 Mtetra
.85032 .42757 .85671 .43645 .87244 .43165 .8661 .42272 Mtetra
.8661 .42272 .87244 .43165 .88825 .42682 .88197 .41784 Mtetra
.88197 .41784 .88825 .42682 .90414 .42197 .89793 .41294 Mtetra
.89793 .41294 .90414 .42197 .92012 .41709 .91398 .40801 Mtetra
.91398 .40801 .92012 .41709 .93619 .41218 .93011 .40305 Mtetra
.93011 .40305 .93619 .41218 .95234 .40724 .94633 .39806 Mtetra
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56246 Mtetra
.37858 .56246 .38666 .57005 .40003 .56595 .39199 .55831 Mtetra
.39199 .55831 .40003 .56595 .41347 .56182 .40547 .55415 Mtetra
.40547 .55415 .41347 .56182 .42697 .55767 .41902 .54996 Mtetra
.41902 .54996 .42697 .55767 .44054 .5535 .43263 .54575 Mtetra
.43263 .54575 .44054 .5535 .45418 .54931 .44632 .54152 Mtetra
.44632 .54152 .45418 .54931 .46789 .54509 .46007 .53727 Mtetra
.46007 .53727 .46789 .54509 .48167 .54086 .47389 .533 Mtetra
.664 .742 .908 r
.47389 .533 .48167 .54086 .49552 .5366 .48778 .5287 Mtetra
.48778 .5287 .49552 .5366 .50944 .53233 .50175 .52438 Mtetra
.50175 .52438 .50944 .53233 .52343 .52803 .51578 .52004 Mtetra
.51578 .52004 .52343 .52803 .53749 .52371 .52989 .51568 Mtetra
.52989 .51568 .53749 .52371 .55162 .51936 .54407 .5113 Mtetra
.54407 .5113 .55162 .51936 .56582 .515 .55833 .50689 Mtetra
.55833 .50689 .56582 .515 .5801 .51061 .57265 .50246 Mtetra
.57265 .50246 .5801 .51061 .59446 .5062 .58706 .49801 Mtetra
.58706 .49801 .59446 .5062 .60888 .50177 .60153 .49353 Mtetra
.60153 .49353 .60888 .50177 .62339 .49731 .61609 .48903 Mtetra
.61609 .48903 .62339 .49731 .63796 .49283 .63071 .48451 Mtetra
.63071 .48451 .63796 .49283 .65262 .48833 .64542 .47997 Mtetra
.64542 .47997 .65262 .48833 .66735 .4838 .6602 .47539 Mtetra
.6602 .47539 .66735 .4838 .68215 .47925 .67506 .4708 Mtetra
.67506 .4708 .68215 .47925 .69704 .47468 .69 .46618 Mtetra
.69 .46618 .69704 .47468 .712 .47008 .70502 .46154 Mtetra
.70502 .46154 .712 .47008 .72705 .46545 .72012 .45687 Mtetra
.72012 .45687 .72705 .46545 .74217 .46081 .7353 .45217 Mtetra
.7353 .45217 .74217 .46081 .75737 .45613 .75056 .44745 Mtetra
.75056 .44745 .75737 .45613 .77266 .45144 .7659 .44271 Mtetra
.7659 .44271 .77266 .45144 .78802 .44672 .78133 .43794 Mtetra
.78133 .43794 .78802 .44672 .80347 .44197 .79683 .43315 Mtetra
.79683 .43315 .80347 .44197 .819 .43719 .81242 .42832 Mtetra
.81242 .42832 .819 .43719 .83462 .4324 .8281 .42348 Mtetra
.8281 .42348 .83462 .4324 .85032 .42757 .84386 .4186 Mtetra
.664 .741 .908 r
.84386 .4186 .85032 .42757 .8661 .42272 .85971 .4137 Mtetra
.85971 .4137 .8661 .42272 .88197 .41784 .87564 .40877 Mtetra
.87564 .40877 .88197 .41784 .89793 .41294 .89166 .40382 Mtetra
.89166 .40382 .89793 .41294 .91398 .40801 .90777 .39884 Mtetra
.90777 .39884 .91398 .40801 .93011 .40305 .92397 .39383 Mtetra
.92397 .39383 .93011 .40305 .94633 .39806 .94025 .38879 Mtetra
.663 .742 .908 r
.35704 .55897 .36524 .56658 .37858 .56246 .37043 .5548 Mtetra
.37043 .5548 .37858 .56246 .39199 .55831 .38388 .55062 Mtetra
.38388 .55062 .39199 .55831 .40547 .55415 .3974 .54642 Mtetra
.3974 .54642 .40547 .55415 .41902 .54996 .41099 .54219 Mtetra
.41099 .54219 .41902 .54996 .43263 .54575 .42464 .53795 Mtetra
.42464 .53795 .43263 .54575 .44632 .54152 .43837 .53368 Mtetra
.43837 .53368 .44632 .54152 .46007 .53727 .45217 .52939 Mtetra
.45217 .52939 .46007 .53727 .47389 .533 .46604 .52508 Mtetra
.663 .742 .909 r
.46604 .52508 .47389 .533 .48778 .5287 .47998 .52074 Mtetra
.47998 .52074 .48778 .5287 .50175 .52438 .49399 .51639 Mtetra
.49399 .51639 .50175 .52438 .51578 .52004 .50807 .51201 Mtetra
.50807 .51201 .51578 .52004 .52989 .51568 .52222 .50761 Mtetra
.52222 .50761 .52989 .51568 .54407 .5113 .53645 .50318 Mtetra
.53645 .50318 .54407 .5113 .55833 .50689 .55076 .49874 Mtetra
.55076 .49874 .55833 .50689 .57265 .50246 .56513 .49426 Mtetra
.56513 .49426 .57265 .50246 .58706 .49801 .57958 .48977 Mtetra
.57958 .48977 .58706 .49801 .60153 .49353 .59411 .48525 Mtetra
.664 .742 .909 r
.59411 .48525 .60153 .49353 .61609 .48903 .60872 .48071 Mtetra
.60872 .48071 .61609 .48903 .63071 .48451 .6234 .47614 Mtetra
.6234 .47614 .63071 .48451 .64542 .47997 .63815 .47155 Mtetra
.63815 .47155 .64542 .47997 .6602 .47539 .65299 .46694 Mtetra
.65299 .46694 .6602 .47539 .67506 .4708 .66791 .4623 Mtetra
.66791 .4623 .67506 .4708 .69 .46618 .6829 .45763 Mtetra
.6829 .45763 .69 .46618 .70502 .46154 .69797 .45294 Mtetra
.69797 .45294 .70502 .46154 .72012 .45687 .71313 .44822 Mtetra
.71313 .44822 .72012 .45687 .7353 .45217 .72836 .44348 Mtetra
.72836 .44348 .7353 .45217 .75056 .44745 .74368 .43871 Mtetra
.74368 .43871 .75056 .44745 .7659 .44271 .75908 .43392 Mtetra
.75908 .43392 .7659 .44271 .78133 .43794 .77456 .4291 Mtetra
.77456 .4291 .78133 .43794 .79683 .43315 .79013 .42426 Mtetra
.79013 .42426 .79683 .43315 .81242 .42832 .80578 .41939 Mtetra
.664 .742 .908 r
.80578 .41939 .81242 .42832 .8281 .42348 .82152 .41449 Mtetra
.82152 .41449 .8281 .42348 .84386 .4186 .83734 .40956 Mtetra
.83734 .40956 .84386 .4186 .85971 .4137 .85325 .40461 Mtetra
.85325 .40461 .85971 .4137 .87564 .40877 .86924 .39963 Mtetra
.86924 .39963 .87564 .40877 .89166 .40382 .88533 .39463 Mtetra
.88533 .39463 .89166 .40382 .90777 .39884 .9015 .38959 Mtetra
.9015 .38959 .90777 .39884 .92397 .39383 .91776 .38453 Mtetra
.91776 .38453 .92397 .39383 .94025 .38879 .93411 .37944 Mtetra
.663 .742 .909 r
.34876 .55131 .35704 .55897 .37043 .5548 .36219 .54711 Mtetra
.663 .743 .909 r
.36219 .54711 .37043 .5548 .38388 .55062 .37568 .5429 Mtetra
.37568 .5429 .38388 .55062 .3974 .54642 .38925 .53866 Mtetra
.38925 .53866 .3974 .54642 .41099 .54219 .40288 .5344 Mtetra
.40288 .5344 .41099 .54219 .42464 .53795 .41658 .53012 Mtetra
.41658 .53012 .42464 .53795 .43837 .53368 .43035 .52582 Mtetra
.663 .743 .91 r
.43035 .52582 .43837 .53368 .45217 .52939 .44419 .52149 Mtetra
.44419 .52149 .45217 .52939 .46604 .52508 .45811 .51715 Mtetra
.663 .744 .91 r
.45811 .51715 .46604 .52508 .47998 .52074 .47209 .51278 Mtetra
.47209 .51278 .47998 .52074 .49399 .51639 .48615 .50839 Mtetra
.48615 .50839 .49399 .51639 .50807 .51201 .50028 .50397 Mtetra
.50028 .50397 .50807 .51201 .52222 .50761 .51448 .49953 Mtetra
.51448 .49953 .52222 .50761 .53645 .50318 .52876 .49507 Mtetra
.52876 .49507 .53645 .50318 .55076 .49874 .54311 .49058 Mtetra
.54311 .49058 .55076 .49874 .56513 .49426 .55754 .48607 Mtetra
.55754 .48607 .56513 .49426 .57958 .48977 .57204 .48154 Mtetra
.57204 .48154 .57958 .48977 .59411 .48525 .58662 .47698 Mtetra
.58662 .47698 .59411 .48525 .60872 .48071 .60128 .47239 Mtetra
.663 .745 .91 r
.60128 .47239 .60872 .48071 .6234 .47614 .61601 .46778 Mtetra
.61601 .46778 .6234 .47614 .63815 .47155 .63082 .46314 Mtetra
.63082 .46314 .63815 .47155 .65299 .46694 .64571 .45848 Mtetra
.664 .745 .91 r
.64571 .45848 .65299 .46694 .66791 .4623 .66068 .4538 Mtetra
.66068 .4538 .66791 .4623 .6829 .45763 .67573 .44908 Mtetra
.664 .744 .91 r
.67573 .44908 .6829 .45763 .69797 .45294 .69086 .44434 Mtetra
.69086 .44434 .69797 .45294 .71313 .44822 .70607 .43958 Mtetra
.70607 .43958 .71313 .44822 .72836 .44348 .72136 .43478 Mtetra
.72136 .43478 .72836 .44348 .74368 .43871 .73674 .42997 Mtetra
.73674 .42997 .74368 .43871 .75908 .43392 .75219 .42512 Mtetra
.75219 .42512 .75908 .43392 .77456 .4291 .76774 .42025 Mtetra
.76774 .42025 .77456 .4291 .79013 .42426 .78336 .41535 Mtetra
.78336 .41535 .79013 .42426 .80578 .41939 .79907 .41042 Mtetra
.79907 .41042 .80578 .41939 .82152 .41449 .81487 .40547 Mtetra
.81487 .40547 .82152 .41449 .83734 .40956 .83076 .40049 Mtetra
.664 .743 .909 r
.83076 .40049 .83734 .40956 .85325 .40461 .84673 .39548 Mtetra
.84673 .39548 .85325 .40461 .86924 .39963 .86279 .39044 Mtetra
.86279 .39044 .86924 .39963 .88533 .39463 .87893 .38538 Mtetra
.87893 .38538 .88533 .39463 .9015 .38959 .89517 .38029 Mtetra
.89517 .38029 .9015 .38959 .91776 .38453 .9115 .37517 Mtetra
.9115 .37517 .91776 .38453 .93411 .37944 .92792 .37002 Mtetra
.663 .744 .911 r
.3404 .54367 .34876 .55131 .36219 .54711 .35387 .53944 Mtetra
.663 .745 .911 r
.35387 .53944 .36219 .54711 .37568 .5429 .36741 .5352 Mtetra
.36741 .5352 .37568 .5429 .38925 .53866 .38102 .53094 Mtetra
.663 .746 .912 r
.38102 .53094 .38925 .53866 .40288 .5344 .39469 .52666 Mtetra
.39469 .52666 .40288 .5344 .41658 .53012 .40844 .52235 Mtetra
.40844 .52235 .41658 .53012 .43035 .52582 .42225 .51803 Mtetra
.663 .747 .913 r
.42225 .51803 .43035 .52582 .44419 .52149 .43614 .51368 Mtetra
.43614 .51368 .44419 .52149 .45811 .51715 .4501 .5093 Mtetra
.663 .748 .913 r
.4501 .5093 .45811 .51715 .47209 .51278 .46413 .50491 Mtetra
.46413 .50491 .47209 .51278 .48615 .50839 .47824 .50049 Mtetra
.663 .748 .914 r
.47824 .50049 .48615 .50839 .50028 .50397 .49241 .49605 Mtetra
.663 .749 .914 r
.49241 .49605 .50028 .50397 .51448 .49953 .50667 .49158 Mtetra
.50667 .49158 .51448 .49953 .52876 .49507 .52099 .48708 Mtetra
.52099 .48708 .52876 .49507 .54311 .49058 .5354 .48257 Mtetra
.663 .75 .915 r
.5354 .48257 .54311 .49058 .55754 .48607 .54987 .47802 Mtetra
.54987 .47802 .55754 .48607 .57204 .48154 .56443 .47345 Mtetra
.56443 .47345 .57204 .48154 .58662 .47698 .57906 .46885 Mtetra
.57906 .46885 .58662 .47698 .60128 .47239 .59377 .46422 Mtetra
.59377 .46422 .60128 .47239 .61601 .46778 .60856 .45957 Mtetra
.60856 .45957 .61601 .46778 .63082 .46314 .62342 .45489 Mtetra
.62342 .45489 .63082 .46314 .64571 .45848 .63837 .45018 Mtetra
.63837 .45018 .64571 .45848 .66068 .4538 .65339 .44544 Mtetra
.664 .75 .915 r
.65339 .44544 .66068 .4538 .67573 .44908 .6685 .44068 Mtetra
.6685 .44068 .67573 .44908 .69086 .44434 .68368 .43588 Mtetra
.68368 .43588 .69086 .44434 .70607 .43958 .69895 .43106 Mtetra
.664 .75 .914 r
.69895 .43106 .70607 .43958 .72136 .43478 .7143 .42621 Mtetra
.7143 .42621 .72136 .43478 .73674 .42997 .72974 .42133 Mtetra
.664 .749 .914 r
.72974 .42133 .73674 .42997 .75219 .42512 .74525 .41643 Mtetra
.74525 .41643 .75219 .42512 .76774 .42025 .76086 .41149 Mtetra
.664 .749 .913 r
.76086 .41149 .76774 .42025 .78336 .41535 .77654 .40653 Mtetra
.664 .748 .913 r
.77654 .40653 .78336 .41535 .79907 .41042 .79231 .40154 Mtetra
.79231 .40154 .79907 .41042 .81487 .40547 .80817 .39652 Mtetra
.664 .748 .912 r
.80817 .39652 .81487 .40547 .83076 .40049 .82412 .39147 Mtetra
.664 .747 .912 r
.82412 .39147 .83076 .40049 .84673 .39548 .84015 .38639 Mtetra
.84015 .38639 .84673 .39548 .86279 .39044 .85628 .38129 Mtetra
.664 .746 .911 r
.85628 .38129 .86279 .39044 .87893 .38538 .87249 .37616 Mtetra
.87249 .37616 .87893 .38538 .89517 .38029 .88879 .371 Mtetra
.88879 .371 .89517 .38029 .9115 .37517 .90518 .36581 Mtetra
.664 .745 .911 r
.90518 .36581 .9115 .37517 .92792 .37002 .92167 .3606 Mtetra
.662 .749 .915 r
.33196 .53615 .3404 .54367 .35387 .53944 .34546 .53193 Mtetra
.662 .75 .916 r
.34546 .53193 .35387 .53944 .36741 .5352 .35904 .52768 Mtetra
.662 .751 .917 r
.35904 .52768 .36741 .5352 .38102 .53094 .37269 .52342 Mtetra
.661 .752 .917 r
.37269 .52342 .38102 .53094 .39469 .52666 .38641 .51914 Mtetra
.661 .753 .918 r
.38641 .51914 .39469 .52666 .40844 .52235 .4002 .51483 Mtetra
.661 .754 .919 r
.4002 .51483 .40844 .52235 .42225 .51803 .41406 .5105 Mtetra
.661 .755 .92 r
.41406 .5105 .42225 .51803 .43614 .51368 .428 .50615 Mtetra
.661 .756 .921 r
.428 .50615 .43614 .51368 .4501 .5093 .442 .50178 Mtetra
.661 .757 .921 r
.442 .50178 .4501 .5093 .46413 .50491 .45608 .49738 Mtetra
.661 .758 .922 r
.45608 .49738 .46413 .50491 .47824 .50049 .47024 .49296 Mtetra
.661 .759 .923 r
.47024 .49296 .47824 .50049 .49241 .49605 .48446 .48851 Mtetra
.661 .76 .923 r
.48446 .48851 .49241 .49605 .50667 .49158 .49877 .48403 Mtetra
.661 .761 .924 r
.49877 .48403 .50667 .49158 .52099 .48708 .51315 .47952 Mtetra
.661 .762 .925 r
.51315 .47952 .52099 .48708 .5354 .48257 .5276 .47499 Mtetra
.662 .763 .925 r
.5276 .47499 .5354 .48257 .54987 .47802 .54214 .47042 Mtetra
.54214 .47042 .54987 .47802 .56443 .47345 .55674 .46583 Mtetra
.662 .764 .926 r
.55674 .46583 .56443 .47345 .57906 .46885 .57143 .4612 Mtetra
.57143 .4612 .57906 .46885 .59377 .46422 .5862 .45654 Mtetra
.662 .765 .926 r
.5862 .45654 .59377 .46422 .60856 .45957 .60104 .45185 Mtetra
.60104 .45185 .60856 .45957 .62342 .45489 .61596 .44712 Mtetra
.663 .765 .926 r
.61596 .44712 .62342 .45489 .63837 .45018 .63097 .44236 Mtetra
.63097 .44236 .63837 .45018 .65339 .44544 .64605 .43757 Mtetra
.663 .765 .925 r
.64605 .43757 .65339 .44544 .6685 .44068 .66122 .43274 Mtetra
.663 .764 .925 r
.66122 .43274 .6685 .44068 .68368 .43588 .67646 .42788 Mtetra
.664 .764 .925 r
.67646 .42788 .68368 .43588 .69895 .43106 .69179 .42299 Mtetra
.664 .763 .924 r
.69179 .42299 .69895 .43106 .7143 .42621 .7072 .41806 Mtetra
.7072 .41806 .7143 .42621 .72974 .42133 .72269 .41311 Mtetra
.664 .762 .923 r
.72269 .41311 .72974 .42133 .74525 .41643 .73827 .40812 Mtetra
.664 .761 .922 r
.73827 .40812 .74525 .41643 .76086 .41149 .75394 .40309 Mtetra
.664 .76 .922 r
.75394 .40309 .76086 .41149 .77654 .40653 .76968 .39804 Mtetra
.665 .759 .921 r
.76968 .39804 .77654 .40653 .79231 .40154 .78552 .39296 Mtetra
.665 .758 .92 r
.78552 .39296 .79231 .40154 .80817 .39652 .80144 .38785 Mtetra
.665 .757 .919 r
.80144 .38785 .80817 .39652 .82412 .39147 .81745 .38271 Mtetra
.665 .756 .918 r
.81745 .38271 .82412 .39147 .84015 .38639 .83354 .37754 Mtetra
.665 .755 .918 r
.83354 .37754 .84015 .38639 .85628 .38129 .84973 .37234 Mtetra
.665 .754 .917 r
.84973 .37234 .85628 .38129 .87249 .37616 .866 .36712 Mtetra
.665 .753 .916 r
.866 .36712 .87249 .37616 .88879 .371 .88237 .36187 Mtetra
.665 .752 .915 r
.88237 .36187 .88879 .371 .90518 .36581 .89883 .35659 Mtetra
.665 .751 .915 r
.89883 .35659 .90518 .36581 .92167 .3606 .91538 .35128 Mtetra
.659 .76 .925 r
.3234 .529 .33196 .53615 .34546 .53193 .33695 .52482 Mtetra
.658 .762 .926 r
.33695 .52482 .34546 .53193 .35904 .52768 .35057 .52062 Mtetra
.658 .764 .928 r
.35057 .52062 .35904 .52768 .37269 .52342 .36426 .5164 Mtetra
.658 .767 .93 r
.36426 .5164 .37269 .52342 .38641 .51914 .37802 .51217 Mtetra
.657 .769 .932 r
.37802 .51217 .38641 .51914 .4002 .51483 .39186 .50792 Mtetra
.657 .771 .934 r
.39186 .50792 .4002 .51483 .41406 .5105 .40576 .50365 Mtetra
.657 .774 .935 r
.40576 .50365 .41406 .5105 .428 .50615 .41975 .49935 Mtetra
.656 .776 .937 r
.41975 .49935 .428 .50615 .442 .50178 .4338 .49503 Mtetra
.656 .779 .939 r
.4338 .49503 .442 .50178 .45608 .49738 .44793 .49068 Mtetra
.656 .781 .941 r
.44793 .49068 .45608 .49738 .47024 .49296 .46214 .4863 Mtetra
.656 .784 .942 r
.46214 .4863 .47024 .49296 .48446 .48851 .47642 .48189 Mtetra
.656 .786 .944 r
.47642 .48189 .48446 .48851 .49877 .48403 .49078 .47745 Mtetra
.656 .788 .945 r
.49078 .47745 .49877 .48403 .51315 .47952 .50521 .47297 Mtetra
.656 .79 .946 r
.50521 .47297 .51315 .47952 .5276 .47499 .51973 .46845 Mtetra
.656 .792 .947 r
.51973 .46845 .5276 .47499 .54214 .47042 .53432 .4639 Mtetra
.656 .794 .948 r
.53432 .4639 .54214 .47042 .55674 .46583 .54899 .4593 Mtetra
.656 .795 .949 r
.54899 .4593 .55674 .46583 .57143 .4612 .56374 .45466 Mtetra
.657 .796 .949 r
.56374 .45466 .57143 .4612 .5862 .45654 .57857 .44998 Mtetra
.657 .797 .949 r
.57857 .44998 .5862 .45654 .60104 .45185 .59347 .44526 Mtetra
.658 .797 .949 r
.59347 .44526 .60104 .45185 .61596 .44712 .60846 .44049 Mtetra
.659 .798 .949 r
.60846 .44049 .61596 .44712 .63097 .44236 .62353 .43567 Mtetra
.659 .797 .949 r
.62353 .43567 .63097 .44236 .64605 .43757 .63867 .43081 Mtetra
.66 .797 .948 r
.63867 .43081 .64605 .43757 .66122 .43274 .6539 .4259 Mtetra
.661 .796 .947 r
.6539 .4259 .66122 .43274 .67646 .42788 .66921 .42095 Mtetra
.661 .795 .946 r
.66921 .42095 .67646 .42788 .69179 .42299 .68461 .41596 Mtetra
.662 .794 .945 r
.68461 .41596 .69179 .42299 .7072 .41806 .70008 .41093 Mtetra
.663 .792 .944 r
.70008 .41093 .7072 .41806 .72269 .41311 .71564 .40585 Mtetra
.663 .791 .942 r
.71564 .40585 .72269 .41311 .73827 .40812 .73128 .40073 Mtetra
.664 .789 .941 r
.73128 .40073 .73827 .40812 .75394 .40309 .74701 .39558 Mtetra
.664 .786 .939 r
.74701 .39558 .75394 .40309 .76968 .39804 .76282 .39039 Mtetra
.665 .784 .937 r
.76282 .39039 .76968 .39804 .78552 .39296 .77872 .38517 Mtetra
.665 .782 .936 r
.77872 .38517 .78552 .39296 .80144 .38785 .7947 .37991 Mtetra
.666 .779 .934 r
.7947 .37991 .80144 .38785 .81745 .38271 .81077 .37462 Mtetra
.666 .777 .932 r
.81077 .37462 .81745 .38271 .83354 .37754 .82693 .36931 Mtetra
.666 .774 .93 r
.82693 .36931 .83354 .37754 .84973 .37234 .84318 .36396 Mtetra
.666 .772 .928 r
.84318 .36396 .84973 .37234 .866 .36712 .85952 .35859 Mtetra
.666 .769 .927 r
.85952 .35859 .866 .36712 .88237 .36187 .87594 .35319 Mtetra
.666 .767 .925 r
.87594 .35319 .88237 .36187 .89883 .35659 .89247 .34777 Mtetra
.666 .765 .923 r
.89247 .34777 .89883 .35659 .91538 .35128 .90908 .34233 Mtetra
.65 .781 .943 r
.3147 .52261 .3234 .529 .33695 .52482 .32829 .51856 Mtetra
.649 .786 .947 r
.32829 .51856 .33695 .52482 .35057 .52062 .34195 .51451 Mtetra
.647 .79 .951 r
.34195 .51451 .35057 .52062 .36426 .5164 .35568 .51044 Mtetra
.646 .795 .954 r
.35568 .51044 .36426 .5164 .37802 .51217 .36949 .50636 Mtetra
.644 .801 .958 r
.36949 .50636 .37802 .51217 .39186 .50792 .38337 .50226 Mtetra
.643 .806 .961 r
.38337 .50226 .39186 .50792 .40576 .50365 .39733 .49814 Mtetra
.641 .811 .965 r
.39733 .49814 .40576 .50365 .41975 .49935 .41136 .494 Mtetra
.639 .817 .968 r
.41136 .494 .41975 .49935 .4338 .49503 .42546 .48983 Mtetra
.637 .822 .971 r
.42546 .48983 .4338 .49503 .44793 .49068 .43965 .48563 Mtetra
.635 .827 .974 r
.43965 .48563 .44793 .49068 .46214 .4863 .45391 .4814 Mtetra
.634 .832 .977 r
.45391 .4814 .46214 .4863 .47642 .48189 .46826 .47712 Mtetra
.632 .837 .979 r
.46826 .47712 .47642 .48189 .49078 .47745 .48268 .4728 Mtetra
.631 .842 .981 r
.48268 .4728 .49078 .47745 .50521 .47297 .49718 .46843 Mtetra
.63 .846 .983 r
.49718 .46843 .50521 .47297 .51973 .46845 .51176 .464 Mtetra
.629 .849 .984 r
.51176 .464 .51973 .46845 .53432 .4639 .52642 .45951 Mtetra
.628 .853 .985 r
.52642 .45951 .53432 .4639 .54899 .4593 .54116 .45497 Mtetra
.628 .855 .985 r
.54116 .45497 .54899 .4593 .56374 .45466 .55598 .45036 Mtetra
.629 .858 .986 r
.55598 .45036 .56374 .45466 .57857 .44998 .57088 .44568 Mtetra
.63 .859 .986 r
.57088 .44568 .57857 .44998 .59347 .44526 .58586 .44094 Mtetra
.631 .861 .985 r
.58586 .44094 .59347 .44526 .60846 .44049 .60092 .43613 Mtetra
.633 .861 .985 r
.60092 .43613 .60846 .44049 .62353 .43567 .61607 .43124 Mtetra
.635 .861 .984 r
.61607 .43124 .62353 .43567 .63867 .43081 .63129 .42629 Mtetra
.638 .86 .983 r
.63129 .42629 .63867 .43081 .6539 .4259 .64659 .42127 Mtetra
.64 .859 .982 r
.64659 .42127 .6539 .4259 .66921 .42095 .66198 .41619 Mtetra
.643 .857 .981 r
.66198 .41619 .66921 .42095 .68461 .41596 .67745 .41104 Mtetra
.646 .855 .979 r
.67745 .41104 .68461 .41596 .70008 .41093 .69299 .40582 Mtetra
.649 .851 .977 r
.69299 .40582 .70008 .41093 .71564 .40585 .70862 .40055 Mtetra
.652 .848 .975 r
.70862 .40055 .71564 .40585 .73128 .40073 .72433 .39523 Mtetra
.655 .844 .973 r
.72433 .39523 .73128 .40073 .74701 .39558 .74013 .38985 Mtetra
.658 .839 .97 r
.74013 .38985 .74701 .39558 .76282 .39039 .75601 .38443 Mtetra
.66 .834 .967 r
.75601 .38443 .76282 .39039 .77872 .38517 .77197 .37896 Mtetra
.662 .829 .964 r
.77197 .37896 .77872 .38517 .7947 .37991 .78802 .37346 Mtetra
.664 .824 .96 r
.78802 .37346 .7947 .37991 .81077 .37462 .80415 .36792 Mtetra
.665 .818 .957 r
.80415 .36792 .81077 .37462 .82693 .36931 .82037 .36235 Mtetra
.666 .813 .953 r
.82037 .36235 .82693 .36931 .84318 .36396 .83668 .35675 Mtetra
.667 .807 .95 r
.83668 .35675 .84318 .36396 .85952 .35859 .85308 .35113 Mtetra
.668 .802 .947 r
.85308 .35113 .85952 .35859 .87594 .35319 .86956 .34548 Mtetra
.668 .796 .943 r
.86956 .34548 .87594 .35319 .89247 .34777 .88614 .33982 Mtetra
.669 .791 .94 r
.88614 .33982 .89247 .34777 .90908 .34233 .90281 .33414 Mtetra
.626 .817 .974 r
.30583 .51759 .3147 .52261 .32829 .51856 .31945 .51382 Mtetra
.62 .826 .979 r
.31945 .51382 .32829 .51856 .34195 .51451 .33314 .51006 Mtetra
.613 .834 .984 r
.33314 .51006 .34195 .51451 .35568 .51044 .34691 .50631 Mtetra
.605 .843 .989 r
.34691 .50631 .35568 .51044 .36949 .50636 .36076 .50255 Mtetra
.597 .851 .992 r
.36076 .50255 .36949 .50636 .38337 .50226 .37469 .49879 Mtetra
.587 .859 .995 r
.37469 .49879 .38337 .50226 .39733 .49814 .38869 .495 Mtetra
.575 .866 .995 r
.38869 .495 .39733 .49814 .41136 .494 .40277 .4912 Mtetra
.563 .872 .995 r
.40277 .4912 .41136 .494 .42546 .48983 .41694 .48736 Mtetra
.55 .877 .992 r
.41694 .48736 .42546 .48983 .43965 .48563 .43119 .48348 Mtetra
.536 .88 .987 r
.43119 .48348 .43965 .48563 .45391 .4814 .44552 .47956 Mtetra
.522 .882 .98 r
.44552 .47956 .45391 .4814 .46826 .47712 .45993 .47557 Mtetra
.508 .883 .972 r
.45993 .47557 .46826 .47712 .48268 .4728 .47442 .47152 Mtetra
.494 .883 .963 r
.47442 .47152 .48268 .4728 .49718 .46843 .489 .46738 Mtetra
.482 .882 .953 r
.489 .46738 .49718 .46843 .51176 .464 .50366 .46317 Mtetra
.471 .881 .943 r
.50366 .46317 .51176 .464 .52642 .45951 .51841 .45886 Mtetra
.462 .879 .934 r
.51841 .45886 .52642 .45951 .54116 .45497 .53324 .45445 Mtetra
.457 .878 .926 r
.53324 .45445 .54116 .45497 .55598 .45036 .54815 .44994 Mtetra
.454 .878 .92 r
.54815 .44994 .55598 .45036 .57088 .44568 .56314 .44532 Mtetra
.454 .879 .917 r
.56314 .44532 .57088 .44568 .58586 .44094 .57822 .44058 Mtetra
.457 .881 .915 r
.57822 .44058 .58586 .44094 .60092 .43613 .59338 .43573 Mtetra
.464 .885 .917 r
.59338 .43573 .60092 .43613 .61607 .43124 .60861 .43076 Mtetra
.473 .889 .92 r
.60861 .43076 .61607 .43124 .63129 .42629 .62393 .42568 Mtetra
.486 .894 .926 r
.62393 .42568 .63129 .42629 .64659 .42127 .63933 .42049 Mtetra
.5 .899 .933 r
.63933 .42049 .64659 .42127 .66198 .41619 .65481 .41518 Mtetra
.516 .904 .942 r
.65481 .41518 .66198 .41619 .67745 .41104 .67036 .40978 Mtetra
.533 .909 .951 r
.67036 .40978 .67745 .41104 .69299 .40582 .68599 .40427 Mtetra
.55 .912 .959 r
.68599 .40427 .69299 .40582 .70862 .40055 .70171 .39867 Mtetra
.568 .914 .967 r
.70171 .39867 .70862 .40055 .72433 .39523 .7175 .39299 Mtetra
.584 .914 .974 r
.7175 .39299 .72433 .39523 .74013 .38985 .73337 .38724 Mtetra
.6 .912 .979 r
.73337 .38724 .74013 .38985 .75601 .38443 .74932 .38142 Mtetra
.614 .908 .983 r
.74932 .38142 .75601 .38443 .77197 .37896 .76535 .37554 Mtetra
.626 .903 .985 r
.76535 .37554 .77197 .37896 .78802 .37346 .78147 .36961 Mtetra
.637 .896 .985 r
.78147 .36961 .78802 .37346 .80415 .36792 .79766 .36364 Mtetra
.646 .888 .984 r
.79766 .36364 .80415 .36792 .82037 .36235 .81394 .35763 Mtetra
.653 .879 .982 r
.81394 .35763 .82037 .36235 .83668 .35675 .83031 .3516 Mtetra
.659 .869 .978 r
.83031 .3516 .83668 .35675 .85308 .35113 .84676 .34556 Mtetra
.663 .859 .974 r
.84676 .34556 .85308 .35113 .86956 .34548 .8633 .3395 Mtetra
.667 .849 .97 r
.8633 .3395 .86956 .34548 .88614 .33982 .87993 .33343 Mtetra
.669 .839 .965 r
.87993 .33343 .88614 .33982 .90281 .33414 .89665 .32736 Mtetra
.545 .857 .997 r
.2967 .51463 .30583 .51759 .31945 .51382 .31035 .51138 Mtetra
.519 .862 .993 r
.31035 .51138 .31945 .51382 .33314 .51006 .32407 .50817 Mtetra
.486 .862 .982 r
.32407 .50817 .33314 .51006 .34691 .50631 .33788 .50498 Mtetra
.448 .857 .963 r
.33788 .50498 .34691 .50631 .36076 .50255 .35176 .50181 Mtetra
.404 .845 .934 r
.35176 .50181 .36076 .50255 .37469 .49879 .36573 .49864 Mtetra
.354 .824 .895 r
.36573 .49864 .37469 .49879 .38869 .495 .37979 .49547 Mtetra
.301 .796 .846 r
.37979 .49547 .38869 .495 .40277 .4912 .39393 .49227 Mtetra
.246 .76 .789 r
.39393 .49227 .40277 .4912 .41694 .48736 .40815 .48903 Mtetra
.192 .719 .728 r
.40815 .48903 .41694 .48736 .43119 .48348 .42247 .48573 Mtetra
0 0 0 r
.42247 .48573 .43119 .48348 .44552 .47956 .43688 .48237 Mtetra
.43688 .48237 .44552 .47956 .45993 .47557 .45137 .47891 Mtetra
.45137 .47891 .45993 .47557 .47442 .47152 .46596 .47535 Mtetra
.46596 .47535 .47442 .47152 .489 .46738 .48064 .47167 Mtetra
.004 0 0 r
.48064 .47167 .489 .46738 .50366 .46317 .4954 .46785 Mtetra
.024 0 0 r
.4954 .46785 .50366 .46317 .51841 .45886 .51026 .46388 Mtetra
.038 0 0 r
.51026 .46388 .51841 .45886 .53324 .45445 .5252 .45974 Mtetra
.047 0 0 r
.5252 .45974 .53324 .45445 .54815 .44994 .54023 .45542 Mtetra
.05 0 0 r
.54023 .45542 .54815 .44994 .56314 .44532 .55534 .45093 Mtetra
.048 0 0 r
.55534 .45093 .56314 .44532 .57822 .44058 .57054 .44624 Mtetra
.041 0 0 r
.57054 .44624 .57822 .44058 .59338 .43573 .58582 .44135 Mtetra
.03 0 0 r
.58582 .44135 .59338 .43573 .60861 .43076 .60119 .43628 Mtetra
.013 0 0 r
.60119 .43628 .60861 .43076 .62393 .42568 .61663 .43101 Mtetra
0 0 0 r
.61663 .43101 .62393 .42568 .63933 .42049 .63214 .42555 Mtetra
.63214 .42555 .63933 .42049 .65481 .41518 .64774 .41991 Mtetra
.64774 .41991 .65481 .41518 .67036 .40978 .66341 .41409 Mtetra
.66341 .41409 .67036 .40978 .68599 .40427 .67915 .40812 Mtetra
.67915 .40812 .68599 .40427 .70171 .39867 .69496 .402 Mtetra
.69496 .402 .70171 .39867 .7175 .39299 .71085 .39575 Mtetra
.71085 .39575 .7175 .39299 .73337 .38724 .72681 .38938 Mtetra
.309 .788 .706 r
.72681 .38938 .73337 .38724 .74932 .38142 .74285 .38291 Mtetra
.366 .83 .763 r
.74285 .38291 .74932 .38142 .76535 .37554 .75896 .37635 Mtetra
.421 .866 .817 r
.75896 .37635 .76535 .37554 .78147 .36961 .77514 .36973 Mtetra
.473 .895 .865 r
.77514 .36973 .78147 .36961 .79766 .36364 .7914 .36306 Mtetra
.519 .915 .905 r
.7914 .36306 .79766 .36364 .81394 .35763 .80774 .35635 Mtetra
.559 .926 .935 r
.80774 .35635 .81394 .35763 .83031 .3516 .82415 .34962 Mtetra
.591 .929 .957 r
.82415 .34962 .83031 .3516 .84676 .34556 .84065 .34288 Mtetra
.617 .926 .971 r
.84065 .34288 .84676 .34556 .8633 .3395 .85724 .33614 Mtetra
.636 .918 .978 r
.85724 .33614 .8633 .3395 .87993 .33343 .87391 .32942 Mtetra
.65 .907 .981 r
.87391 .32942 .87993 .33343 .89665 .32736 .89067 .32272 Mtetra
.303 .792 .885 r
.28726 .51436 .2967 .51463 .31035 .51138 .30092 .51193 Mtetra
.219 .742 .809 r
.30092 .51193 .31035 .51138 .32407 .50817 .31467 .50958 Mtetra
.13 .676 .714 r
.31467 .50958 .32407 .50817 .33788 .50498 .3285 .50728 Mtetra
0 0 0 r
.3285 .50728 .33788 .50498 .35176 .50181 .34242 .50504 Mtetra
.039 0 0 r
.34242 .50504 .35176 .50181 .36573 .49864 .35643 .50282 Mtetra
.109 0 0 r
.35643 .50282 .36573 .49864 .37979 .49547 .37053 .5006 Mtetra
.167 0 0 r
.37053 .5006 .37979 .49547 .39393 .49227 .38473 .49836 Mtetra
.213 0 0 r
.38473 .49836 .39393 .49227 .40815 .48903 .39902 .49607 Mtetra
.25 0 0 r
.39902 .49607 .40815 .48903 .42247 .48573 .41342 .49371 Mtetra
.278 0 0 r
.41342 .49371 .42247 .48573 .43688 .48237 .42792 .49124 Mtetra
.3 0 0 r
.42792 .49124 .43688 .48237 .45137 .47891 .44251 .48864 Mtetra
.316 0 0 r
.44251 .48864 .45137 .47891 .46596 .47535 .45721 .48587 Mtetra
.328 0 .02 r
.45721 .48587 .46596 .47535 .48064 .47167 .47201 .48291 Mtetra
.335 0 .045 r
.47201 .48291 .48064 .47167 .4954 .46785 .4869 .47973 Mtetra
.34 0 .064 r
.4869 .47973 .4954 .46785 .51026 .46388 .5019 .47631 Mtetra
.342 0 .079 r
.5019 .47631 .51026 .46388 .5252 .45974 .51699 .47262 Mtetra
.341 0 .089 r
.51699 .47262 .5252 .45974 .54023 .45542 .53217 .46864 Mtetra
.338 0 .096 r
.53217 .46864 .54023 .45542 .55534 .45093 .54745 .46436 Mtetra
.333 0 .098 r
.54745 .46436 .55534 .45093 .57054 .44624 .56281 .45978 Mtetra
.325 0 .097 r
.56281 .45978 .57054 .44624 .58582 .44135 .57825 .45487 Mtetra
.316 0 .092 r
.57825 .45487 .58582 .44135 .60119 .43628 .59378 .44965 Mtetra
.304 0 .084 r
.59378 .44965 .60119 .43628 .61663 .43101 .60938 .44411 Mtetra
.289 0 .071 r
.60938 .44411 .61663 .43101 .63214 .42555 .62505 .43827 Mtetra
.272 0 .054 r
.62505 .43827 .63214 .42555 .64774 .41991 .6408 .43213 Mtetra
.252 0 .032 r
.6408 .43213 .64774 .41991 .66341 .41409 .65661 .42571 Mtetra
.228 0 .005 r
.65661 .42571 .66341 .41409 .67915 .40812 .67249 .41904 Mtetra
.2 0 0 r
.67249 .41904 .67915 .40812 .69496 .402 .68844 .41213 Mtetra
.166 0 0 r
.68844 .41213 .69496 .402 .71085 .39575 .70444 .40501 Mtetra
.127 0 0 r
.70444 .40501 .71085 .39575 .72681 .38938 .72051 .39771 Mtetra
.08 0 0 r
.72051 .39771 .72681 .38938 .74285 .38291 .73665 .39026 Mtetra
.026 0 0 r
.73665 .39026 .74285 .38291 .75896 .37635 .75284 .38269 Mtetra
0 0 0 r
.75284 .38269 .75896 .37635 .77514 .36973 .7691 .37502 Mtetra
.7691 .37502 .77514 .36973 .7914 .36306 .78543 .36729 Mtetra
.78543 .36729 .7914 .36306 .80774 .35635 .80182 .35952 Mtetra
.80182 .35952 .80774 .35635 .82415 .34962 .81829 .35173 Mtetra
.355 .812 .699 r
.81829 .35173 .82415 .34962 .84065 .34288 .83483 .34396 Mtetra
.434 .869 .784 r
.83483 .34396 .84065 .34288 .85724 .33614 .85145 .33621 Mtetra
.502 .909 .854 r
.85145 .33621 .85724 .33614 .87391 .32942 .86815 .32851 Mtetra
.559 .932 .907 r
.86815 .32851 .87391 .32942 .89067 .32272 .88493 .32087 Mtetra
.071 0 0 r
.27748 .51692 .28726 .51436 .30092 .51193 .29114 .51563 Mtetra
.163 0 0 r
.29114 .51563 .30092 .51193 .31467 .50958 .30489 .51448 Mtetra
.237 0 0 r
.30489 .51448 .31467 .50958 .3285 .50728 .31873 .51344 Mtetra
.295 0 0 r
.31873 .51344 .3285 .50728 .34242 .50504 .33267 .51249 Mtetra
.339 0 0 r
.33267 .51249 .34242 .50504 .35643 .50282 .34671 .51159 Mtetra
.372 0 0 r
.34671 .51159 .35643 .50282 .37053 .5006 .36086 .51071 Mtetra
.396 0 .05 r
.36086 .51071 .37053 .5006 .38473 .49836 .37512 .50982 Mtetra
.414 0 .096 r
.37512 .50982 .38473 .49836 .39902 .49607 .38949 .50887 Mtetra
.427 .006 .134 r
.38949 .50887 .39902 .49607 .41342 .49371 .40397 .50782 Mtetra
.436 .028 .165 r
.40397 .50782 .41342 .49371 .42792 .49124 .41857 .50662 Mtetra
.442 .045 .19 r
.41857 .50662 .42792 .49124 .44251 .48864 .43328 .50522 Mtetra
.445 .058 .21 r
.43328 .50522 .44251 .48864 .45721 .48587 .44811 .50358 Mtetra
.447 .068 .226 r
.44811 .50358 .45721 .48587 .47201 .48291 .46305 .50165 Mtetra
.447 .075 .239 r
.46305 .50165 .47201 .48291 .4869 .47973 .47811 .49938 Mtetra
.445 .079 .249 r
.47811 .49938 .4869 .47973 .5019 .47631 .49327 .49675 Mtetra
.442 .081 .256 r
.49327 .49675 .5019 .47631 .51699 .47262 .50855 .4937 Mtetra
.437 .081 .261 r
.50855 .4937 .51699 .47262 .53217 .46864 .52392 .49022 Mtetra
.432 .079 .264 r
.52392 .49022 .53217 .46864 .54745 .46436 .5394 .48627 Mtetra
.425 .075 .265 r
.5394 .48627 .54745 .46436 .56281 .45978 .55496 .48185 Mtetra
.418 .069 .263 r
.55496 .48185 .56281 .45978 .57825 .45487 .57061 .47693 Mtetra
.409 .06 .26 r
.57061 .47693 .57825 .45487 .59378 .44965 .58634 .47153 Mtetra
.399 .05 .254 r
.58634 .47153 .59378 .44965 .60938 .44411 .60214 .46563 Mtetra
.388 .038 .246 r
.60214 .46563 .60938 .44411 .62505 .43827 .61802 .45927 Mtetra
.375 .023 .235 r
.61802 .45927 .62505 .43827 .6408 .43213 .63395 .45245 Mtetra
.36 .006 .222 r
.63395 .45245 .6408 .43213 .65661 .42571 .64995 .44521 Mtetra
.343 0 .206 r
.64995 .44521 .65661 .42571 .67249 .41904 .666 .43758 Mtetra
.324 0 .186 r
.666 .43758 .67249 .41904 .68844 .41213 .6821 .42959 Mtetra
.302 0 .161 r
.6821 .42959 .68844 .41213 .70444 .40501 .69826 .42128 Mtetra
.276 0 .132 r
.69826 .42128 .70444 .40501 .72051 .39771 .71446 .41271 Mtetra
.246 0 .096 r
.71446 .41271 .72051 .39771 .73665 .39026 .7307 .40392 Mtetra
.211 0 .053 r
.7307 .40392 .73665 .39026 .75284 .38269 .747 .39495 Mtetra
.17 0 .001 r
.747 .39495 .75284 .38269 .7691 .37502 .76334 .38585 Mtetra
.12 0 0 r
.76334 .38585 .7691 .37502 .78543 .36729 .77974 .37667 Mtetra
.061 0 0 r
.77974 .37667 .78543 .36729 .80182 .35952 .79619 .36745 Mtetra
0 0 0 r
.79619 .36745 .80182 .35952 .81829 .35173 .81271 .35822 Mtetra
.81271 .35822 .81829 .35173 .83483 .34396 .82928 .34903 Mtetra
.82928 .34903 .83483 .34396 .85145 .33621 .84592 .33991 Mtetra
.84592 .33991 .85145 .33621 .86815 .32851 .86264 .33088 Mtetra
.376 .817 .673 r
.86264 .33088 .86815 .32851 .88493 .32087 .87943 .32196 Mtetra
.306 0 0 r
.26738 .5216 .27748 .51692 .29114 .51563 .28102 .52171 Mtetra
.364 0 0 r
.28102 .52171 .29114 .51563 .30489 .51448 .29476 .52202 Mtetra
.406 0 0 r
.29476 .52202 .30489 .51448 .31873 .51344 .3086 .52251 Mtetra
.436 0 .046 r
.3086 .52251 .31873 .51344 .33267 .51249 .32255 .52315 Mtetra
.458 .014 .104 r
.32255 .52315 .33267 .51249 .34671 .51159 .33662 .52388 Mtetra
.473 .048 .15 r
.33662 .52388 .34671 .51159 .36086 .51071 .3508 .52466 Mtetra
.484 .075 .188 r
.3508 .52466 .36086 .51071 .37512 .50982 .36511 .52543 Mtetra
.491 .096 .218 r
.36511 .52543 .37512 .50982 .38949 .50887 .37955 .52613 Mtetra
.495 .112 .243 r
.37955 .52613 .38949 .50887 .40397 .50782 .39412 .5267 Mtetra
.497 .124 .263 r
.39412 .5267 .40397 .50782 .41857 .50662 .40882 .52707 Mtetra
.497 .134 .279 r
.40882 .52707 .41857 .50662 .43328 .50522 .42366 .52717 Mtetra
.496 .14 .293 r
.42366 .52717 .43328 .50522 .44811 .50358 .43863 .52693 Mtetra
.493 .144 .303 r
.43863 .52693 .44811 .50358 .46305 .50165 .45374 .52628 Mtetra
.489 .146 .311 r
.45374 .52628 .46305 .50165 .47811 .49938 .46897 .52517 Mtetra
.485 .147 .318 r
.46897 .52517 .47811 .49938 .49327 .49675 .48433 .52352 Mtetra
.479 .145 .322 r
.48433 .52352 .49327 .49675 .50855 .4937 .49982 .52129 Mtetra
.473 .143 .325 r
.49982 .52129 .50855 .4937 .52392 .49022 .51541 .51844 Mtetra
.466 .138 .326 r
.51541 .51844 .52392 .49022 .5394 .48627 .53111 .51491 Mtetra
.458 .133 .325 r
.53111 .51491 .5394 .48627 .55496 .48185 .54692 .5107 Mtetra
.449 .125 .324 r
.54692 .5107 .55496 .48185 .57061 .47693 .56281 .50579 Mtetra
.44 .117 .32 r
.56281 .50579 .57061 .47693 .58634 .47153 .57878 .50017 Mtetra
.429 .107 .315 r
.57878 .50017 .58634 .47153 .60214 .46563 .59482 .49385 Mtetra
.418 .095 .308 r
.59482 .49385 .60214 .46563 .61802 .45927 .61093 .48685 Mtetra
.405 .081 .3 r
.61093 .48685 .61802 .45927 .63395 .45245 .62709 .4792 Mtetra
.391 .066 .289 r
.62709 .4792 .63395 .45245 .64995 .44521 .6433 .47094 Mtetra
.375 .048 .276 r
.6433 .47094 .64995 .44521 .666 .43758 .65955 .46213 Mtetra
.358 .027 .261 r
.65955 .46213 .666 .43758 .6821 .42959 .67584 .45281 Mtetra
.338 .003 .242 r
.67584 .45281 .6821 .42959 .69826 .42128 .69216 .44305 Mtetra
.316 0 .22 r
.69216 .44305 .69826 .42128 .71446 .41271 .70851 .43292 Mtetra
.29 0 .193 r
.70851 .43292 .71446 .41271 .7307 .40392 .72489 .42248 Mtetra
.261 0 .16 r
.72489 .42248 .7307 .40392 .747 .39495 .7413 .41181 Mtetra
.227 0 .121 r
.7413 .41181 .747 .39495 .76334 .38585 .75774 .40096 Mtetra
.187 0 .073 r
.75774 .40096 .76334 .38585 .77974 .37667 .77421 .39001 Mtetra
.139 0 .016 r
.77421 .39001 .77974 .37667 .79619 .36745 .79073 .37902 Mtetra
.082 0 0 r
.79073 .37902 .79619 .36745 .81271 .35822 .80729 .36805 Mtetra
.015 0 0 r
.80729 .36805 .81271 .35822 .82928 .34903 .82389 .35714 Mtetra
0 0 0 r
.82389 .35714 .82928 .34903 .84592 .33991 .84056 .34635 Mtetra
.84056 .34635 .84592 .33991 .86264 .33088 .85728 .33572 Mtetra
.85728 .33572 .86264 .33088 .87943 .32196 .87408 .32527 Mtetra
.402 0 0 r
.25707 .52665 .26738 .5216 .28102 .52171 .27068 .52821 Mtetra
.445 0 0 r
.27068 .52821 .28102 .52171 .29476 .52202 .2844 .53006 Mtetra
.475 0 .042 r
.2844 .53006 .29476 .52202 .3086 .52251 .29823 .53216 Mtetra
.496 .042 .102 r
.29823 .53216 .3086 .52251 .32255 .52315 .31218 .53446 Mtetra
.51 .076 .151 r
.31218 .53446 .32255 .52315 .33662 .52388 .32626 .5369 Mtetra
.519 .102 .19 r
.32626 .5369 .33662 .52388 .3508 .52466 .34047 .53943 Mtetra
.524 .123 .221 r
.34047 .53943 .3508 .52466 .36511 .52543 .35482 .54195 Mtetra
.527 .138 .247 r
.35482 .54195 .36511 .52543 .37955 .52613 .36932 .54441 Mtetra
.527 .15 .268 r
.36932 .54441 .37955 .52613 .39412 .5267 .38397 .5467 Mtetra
.526 .158 .285 r
.38397 .5467 .39412 .5267 .40882 .52707 .39878 .54874 Mtetra
.523 .163 .298 r
.39878 .54874 .40882 .52707 .42366 .52717 .41373 .55044 Mtetra
.519 .167 .309 r
.41373 .55044 .42366 .52717 .43863 .52693 .42885 .5517 Mtetra
.514 .168 .318 r
.42885 .5517 .43863 .52693 .45374 .52628 .44411 .55243 Mtetra
.507 .167 .324 r
.44411 .55243 .45374 .52628 .46897 .52517 .45953 .55254 Mtetra
.5 .165 .329 r
.45953 .55254 .46897 .52517 .48433 .52352 .47509 .55196 Mtetra
.492 .161 .332 r
.47509 .55196 .48433 .52352 .49982 .52129 .49079 .55061 Mtetra
.484 .155 .334 r
.49079 .55061 .49982 .52129 .51541 .51844 .50661 .54843 Mtetra
.474 .149 .334 r
.50661 .54843 .51541 .51844 .53111 .51491 .52255 .54537 Mtetra
.464 .141 .332 r
.52255 .54537 .53111 .51491 .54692 .5107 .5386 .54139 Mtetra
.452 .131 .33 r
.5386 .54139 .54692 .5107 .56281 .50579 .55474 .53648 Mtetra
.44 .12 .325 r
.55474 .53648 .56281 .50579 .57878 .50017 .57097 .53063 Mtetra
.427 .108 .32 r
.57097 .53063 .57878 .50017 .59482 .49385 .58727 .52386 Mtetra
.413 .094 .312 r
.58727 .52386 .59482 .49385 .61093 .48685 .60362 .51618 Mtetra
.397 .078 .303 r
.60362 .51618 .61093 .48685 .62709 .4792 .62002 .50764 Mtetra
.38 .06 .292 r
.62002 .50764 .62709 .4792 .6433 .47094 .63646 .49831 Mtetra
.361 .04 .278 r
.63646 .49831 .6433 .47094 .65955 .46213 .65292 .48823 Mtetra
.341 .017 .262 r
.65292 .48823 .65955 .46213 .67584 .45281 .66941 .4775 Mtetra
.318 0 .242 r
.66941 .4775 .67584 .45281 .69216 .44305 .68591 .46619 Mtetra
.292 0 .219 r
.68591 .46619 .69216 .44305 .70851 .43292 .70242 .4544 Mtetra
.263 0 .191 r
.70242 .4544 .70851 .43292 .72489 .42248 .71894 .44221 Mtetra
.23 0 .158 r
.71894 .44221 .72489 .42248 .7413 .41181 .73548 .42972 Mtetra
.192 0 .118 r
.73548 .42972 .7413 .41181 .75774 .40096 .75202 .41703 Mtetra
.148 0 .071 r
.75202 .41703 .75774 .40096 .77421 .39001 .76858 .40421 Mtetra
.096 0 .013 r
.76858 .40421 .77421 .39001 .79073 .37902 .78517 .39136 Mtetra
.036 0 0 r
.78517 .39136 .79073 .37902 .80729 .36805 .80178 .37855 Mtetra
0 0 0 r
.80178 .37855 .80729 .36805 .82389 .35714 .81842 .36584 Mtetra
.81842 .36584 .82389 .35714 .84056 .34635 .83511 .35331 Mtetra
.83511 .35331 .84056 .34635 .85728 .33572 .85185 .34099 Mtetra
.85185 .34099 .85728 .33572 .87408 .32527 .86865 .32895 Mtetra
.407 0 0 r
.24677 .5295 .25707 .52665 .27068 .52821 .26036 .53228 Mtetra
.456 0 0 r
.26036 .53228 .27068 .52821 .2844 .53006 .27405 .53543 Mtetra
.49 0 0 r
.27405 .53543 .2844 .53006 .29823 .53216 .28787 .53889 Mtetra
.513 .022 .027 r
.28787 .53889 .29823 .53216 .31218 .53446 .30181 .54261 Mtetra
.529 .058 .081 r
.30181 .54261 .31218 .53446 .32626 .5369 .3159 .54651 Mtetra
.538 .086 .125 r
.3159 .54651 .32626 .5369 .34047 .53943 .33012 .55052 Mtetra
.543 .107 .161 r
.33012 .55052 .34047 .53943 .35482 .54195 .34451 .55456 Mtetra
.544 .122 .19 r
.34451 .55456 .35482 .54195 .36932 .54441 .35905 .55851 Mtetra
.543 .133 .214 r
.35905 .55851 .36932 .54441 .38397 .5467 .37377 .56228 Mtetra
.539 .14 .232 r
.37377 .56228 .38397 .5467 .39878 .54874 .38865 .56576 Mtetra
.534 .144 .247 r
.38865 .56576 .39878 .54874 .41373 .55044 .40371 .56884 Mtetra
.527 .145 .259 r
.40371 .56884 .41373 .55044 .42885 .5517 .41894 .57139 Mtetra
.518 .143 .268 r
.41894 .57139 .42885 .5517 .44411 .55243 .43435 .57331 Mtetra
.509 .139 .275 r
.43435 .57331 .44411 .55243 .45953 .55254 .44992 .57449 Mtetra
.497 .133 .279 r
.44992 .57449 .45953 .55254 .47509 .55196 .46565 .57483 Mtetra
.485 .126 .281 r
.46565 .57483 .47509 .55196 .49079 .55061 .48153 .57424 Mtetra
.471 .116 .281 r
.48153 .57424 .49079 .55061 .50661 .54843 .49756 .57265 Mtetra
.456 .104 .279 r
.49756 .57265 .50661 .54843 .52255 .54537 .51371 .56998 Mtetra
.44 .091 .275 r
.51371 .56998 .52255 .54537 .5386 .54139 .52998 .56621 Mtetra
.422 .075 .27 r
.52998 .56621 .5386 .54139 .55474 .53648 .54635 .56129 Mtetra
.403 .058 .262 r
.54635 .56129 .55474 .53648 .57097 .53063 .56281 .55524 Mtetra
.381 .038 .252 r
.56281 .55524 .57097 .53063 .58727 .52386 .57933 .54806 Mtetra
.358 .015 .24 r
.57933 .54806 .58727 .52386 .60362 .51618 .59591 .53978 Mtetra
.333 0 .225 r
.59591 .53978 .60362 .51618 .62002 .50764 .61253 .53046 Mtetra
.306 0 .207 r
.61253 .53046 .62002 .50764 .63646 .49831 .62918 .52018 Mtetra
.275 0 .185 r
.62918 .52018 .63646 .49831 .65292 .48823 .64585 .509 Mtetra
.242 0 .16 r
.64585 .509 .65292 .48823 .66941 .4775 .66252 .49702 Mtetra
.204 0 .13 r
.66252 .49702 .66941 .4775 .68591 .46619 .6792 .48436 Mtetra
.163 0 .094 r
.6792 .48436 .68591 .46619 .70242 .4544 .69587 .47112 Mtetra
.116 0 .052 r
.69587 .47112 .70242 .4544 .71894 .44221 .71253 .45741 Mtetra
.063 0 .003 r
.71253 .45741 .71894 .44221 .73548 .42972 .72919 .44335 Mtetra
.003 0 0 r
.72919 .44335 .73548 .42972 .75202 .41703 .74584 .42905 Mtetra
0 0 0 r
.74584 .42905 .75202 .41703 .76858 .40421 .7625 .41461 Mtetra
.7625 .41461 .76858 .40421 .78517 .39136 .77916 .40015 Mtetra
.77916 .40015 .78517 .39136 .80178 .37855 .79583 .38575 Mtetra
.79583 .38575 .80178 .37855 .81842 .36584 .81253 .37149 Mtetra
.81253 .37149 .81842 .36584 .83511 .35331 .82926 .35746 Mtetra
.494 .849 .593 r
.82926 .35746 .83511 .35331 .85185 .34099 .84603 .3437 Mtetra
.574 .912 .687 r
.84603 .3437 .85185 .34099 .86865 .32895 .86286 .33028 Mtetra
.218 0 0 r
.23671 .52749 .24677 .5295 .26036 .53228 .25029 .53098 Mtetra
.297 0 0 r
.25029 .53098 .26036 .53228 .27405 .53543 .26398 .53487 Mtetra
.362 0 0 r
.26398 .53487 .27405 .53543 .28787 .53889 .27779 .53911 Mtetra
.413 0 0 r
.27779 .53911 .28787 .53889 .30181 .54261 .29173 .54364 Mtetra
.45 0 0 r
.29173 .54364 .30181 .54261 .3159 .54651 .30582 .54839 Mtetra
.476 0 0 r
.30582 .54839 .3159 .54651 .33012 .55052 .32007 .55326 Mtetra
.493 0 0 r
.32007 .55326 .33012 .55052 .34451 .55456 .33447 .55816 Mtetra
.502 0 0 r
.33447 .55816 .34451 .55456 .35905 .55851 .34905 .56298 Mtetra
.505 0 0 r
.34905 .56298 .35905 .55851 .37377 .56228 .36381 .56761 Mtetra
.502 0 0 r
.36381 .56761 .37377 .56228 .38865 .56576 .37875 .57193 Mtetra
.494 0 0 r
.37875 .57193 .38865 .56576 .40371 .56884 .39388 .5758 Mtetra
.481 0 0 r
.39388 .5758 .40371 .56884 .41894 .57139 .40919 .5791 Mtetra
.465 0 0 r
.40919 .5791 .41894 .57139 .43435 .57331 .42468 .58171 Mtetra
.444 0 0 r
.42468 .58171 .43435 .57331 .44992 .57449 .44036 .58351 Mtetra
.419 0 0 r
.44036 .58351 .44992 .57449 .46565 .57483 .45621 .58438 Mtetra
.39 0 0 r
.45621 .58438 .46565 .57483 .48153 .57424 .47222 .58422 Mtetra
.356 0 0 r
.47222 .58422 .48153 .57424 .49756 .57265 .48838 .58295 Mtetra
.318 0 0 r
.48838 .58295 .49756 .57265 .51371 .56998 .50468 .58051 Mtetra
.274 0 0 r
.50468 .58051 .51371 .56998 .52998 .56621 .52111 .57683 Mtetra
.225 0 0 r
.52111 .57683 .52998 .56621 .54635 .56129 .53764 .57189 Mtetra
.169 0 0 r
.53764 .57189 .54635 .56129 .56281 .55524 .55426 .56569 Mtetra
.108 0 0 r
.55426 .56569 .56281 .55524 .57933 .54806 .57095 .55825 Mtetra
.041 0 0 r
.57095 .55825 .57933 .54806 .59591 .53978 .58769 .54959 Mtetra
0 0 0 r
.58769 .54959 .59591 .53978 .61253 .53046 .60448 .53978 Mtetra
.60448 .53978 .61253 .53046 .62918 .52018 .62129 .5289 Mtetra
.62129 .5289 .62918 .52018 .64585 .509 .63811 .51704 Mtetra
.63811 .51704 .64585 .509 .66252 .49702 .65493 .50431 Mtetra
.65493 .50431 .66252 .49702 .6792 .48436 .67175 .49081 Mtetra
.67175 .49081 .6792 .48436 .69587 .47112 .68855 .47668 Mtetra
.519 .858 .588 r
.68855 .47668 .69587 .47112 .71253 .45741 .70534 .46204 Mtetra
.59 .905 .644 r
.70534 .46204 .71253 .45741 .72919 .44335 .72212 .44702 Mtetra
.651 .942 .696 r
.72212 .44702 .72919 .44335 .74584 .42905 .73888 .43175 Mtetra
.703 .97 .741 r
.73888 .43175 .74584 .42905 .7625 .41461 .75563 .41633 Mtetra
.744 .987 .78 r
.75563 .41633 .7625 .41461 .77916 .40015 .77238 .40089 Mtetra
.776 .997 .812 r
.77238 .40089 .77916 .40015 .79583 .38575 .78913 .38553 Mtetra
.798 .999 .839 r
.78913 .38553 .79583 .38575 .81253 .37149 .8059 .37033 Mtetra
.813 .995 .86 r
.8059 .37033 .81253 .37149 .82926 .35746 .8227 .35539 Mtetra
.821 .987 .877 r
.8227 .35539 .82926 .35746 .84603 .3437 .83953 .34076 Mtetra
.824 .976 .89 r
.83953 .34076 .84603 .3437 .86286 .33028 .85641 .32651 Mtetra
.242 .572 .941 r
.2271 .51894 .23671 .52749 .25029 .53098 .24069 .5224 Mtetra
.213 .555 .934 r
.24069 .5224 .25029 .53098 .26398 .53487 .2544 .52626 Mtetra
.187 .54 .927 r
.2544 .52626 .26398 .53487 .27779 .53911 .26823 .53048 Mtetra
.167 .528 .921 r
.26823 .53048 .27779 .53911 .29173 .54364 .2822 .53498 Mtetra
.153 .52 .917 r
.2822 .53498 .29173 .54364 .30582 .54839 .2963 .53971 Mtetra
.147 .517 .915 r
.2963 .53971 .30582 .54839 .32007 .55326 .31057 .54455 Mtetra
.149 .518 .916 r
.31057 .54455 .32007 .55326 .33447 .55816 .325 .54943 Mtetra
.16 .524 .919 r
.325 .54943 .33447 .55816 .34905 .56298 .3396 .55423 Mtetra
.179 .536 .925 r
.3396 .55423 .34905 .56298 .36381 .56761 .35438 .55884 Mtetra
.206 .552 .932 r
.35438 .55884 .36381 .56761 .37875 .57193 .36935 .56312 Mtetra
.241 .573 .941 r
.36935 .56312 .37875 .57193 .39388 .5758 .3845 .56697 Mtetra
.283 .596 .949 r
.3845 .56697 .39388 .5758 .40919 .5791 .39985 .57025 Mtetra
.329 .622 .957 r
.39985 .57025 .40919 .5791 .42468 .58171 .41538 .57282 Mtetra
.378 .647 .962 r
.41538 .57282 .42468 .58171 .44036 .58351 .43109 .57459 Mtetra
.428 .673 .965 r
.43109 .57459 .44036 .58351 .45621 .58438 .44699 .57542 Mtetra
.478 .696 .964 r
.44699 .57542 .45621 .58438 .47222 .58422 .46305 .57523 Mtetra
.525 .717 .96 r
.46305 .57523 .47222 .58422 .48838 .58295 .47926 .57392 Mtetra
.57 .735 .953 r
.47926 .57392 .48838 .58295 .50468 .58051 .49562 .57142 Mtetra
.61 .75 .944 r
.49562 .57142 .50468 .58051 .52111 .57683 .5121 .56769 Mtetra
.646 .762 .934 r
.5121 .56769 .52111 .57683 .53764 .57189 .5287 .5627 Mtetra
.677 .772 .922 r
.5287 .5627 .53764 .57189 .55426 .56569 .54539 .55645 Mtetra
.705 .78 .91 r
.54539 .55645 .55426 .56569 .57095 .55825 .56215 .54894 Mtetra
.728 .786 .899 r
.56215 .54894 .57095 .55825 .58769 .54959 .57897 .54022 Mtetra
.748 .791 .887 r
.57897 .54022 .58769 .54959 .60448 .53978 .59584 .53034 Mtetra
.765 .794 .877 r
.59584 .53034 .60448 .53978 .62129 .5289 .61273 .51939 Mtetra
.779 .797 .867 r
.61273 .51939 .62129 .5289 .63811 .51704 .62964 .50745 Mtetra
.79 .799 .859 r
.62964 .50745 .63811 .51704 .65493 .50431 .64655 .49463 Mtetra
.8 .8 .852 r
.64655 .49463 .65493 .50431 .67175 .49081 .66346 .48106 Mtetra
.807 .801 .846 r
.66346 .48106 .67175 .49081 .68855 .47668 .68035 .46685 Mtetra
.813 .802 .841 r
.68035 .46685 .68855 .47668 .70534 .46204 .69724 .45212 Mtetra
.817 .803 .838 r
.69724 .45212 .70534 .46204 .72212 .44702 .71411 .43702 Mtetra
.82 .803 .835 r
.71411 .43702 .72212 .44702 .73888 .43175 .73096 .42165 Mtetra
.822 .803 .834 r
.73096 .42165 .73888 .43175 .75563 .41633 .74781 .40615 Mtetra
.74781 .40615 .75563 .41633 .77238 .40089 .76465 .39062 Mtetra
.821 .803 .835 r
.76465 .39062 .77238 .40089 .78913 .38553 .7815 .37517 Mtetra
.819 .803 .836 r
.7815 .37517 .78913 .38553 .8059 .37033 .79837 .35989 Mtetra
.816 .802 .838 r
.79837 .35989 .8059 .37033 .8227 .35539 .81526 .34486 Mtetra
.812 .802 .841 r
.81526 .34486 .8227 .35539 .83953 .34076 .83218 .33015 Mtetra
.808 .801 .845 r
.83218 .33015 .83953 .34076 .85641 .32651 .84915 .31581 Mtetra
.446 .534 .854 r
.21799 .50379 .2271 .51894 .24069 .5224 .23164 .50649 Mtetra
.441 .521 .844 r
.23164 .50649 .24069 .5224 .2544 .52626 .2454 .50955 Mtetra
.439 .509 .834 r
.2454 .50955 .2544 .52626 .26823 .53048 .25928 .51293 Mtetra
.439 .498 .824 r
.25928 .51293 .26823 .53048 .2822 .53498 .27329 .51656 Mtetra
.441 .49 .814 r
.27329 .51656 .2822 .53498 .2963 .53971 .28743 .52039 Mtetra
.446 .483 .804 r
.28743 .52039 .2963 .53971 .31057 .54455 .30173 .52432 Mtetra
.452 .478 .795 r
.30173 .52432 .31057 .54455 .325 .54943 .31619 .52827 Mtetra
.461 .474 .786 r
.31619 .52827 .325 .54943 .3396 .55423 .33081 .53215 Mtetra
.471 .473 .778 r
.33081 .53215 .3396 .55423 .35438 .55884 .3456 .53584 Mtetra
.483 .473 .77 r
.3456 .53584 .35438 .55884 .36935 .56312 .36058 .53923 Mtetra
.495 .474 .763 r
.36058 .53923 .36935 .56312 .3845 .56697 .37573 .54222 Mtetra
.508 .476 .756 r
.37573 .54222 .3845 .56697 .39985 .57025 .39106 .54468 Mtetra
.521 .479 .75 r
.39106 .54468 .39985 .57025 .41538 .57282 .40658 .5465 Mtetra
.535 .483 .745 r
.40658 .5465 .41538 .57282 .43109 .57459 .42228 .54758 Mtetra
.549 .488 .74 r
.42228 .54758 .43109 .57459 .44699 .57542 .43814 .5478 Mtetra
.562 .493 .736 r
.43814 .5478 .44699 .57542 .46305 .57523 .45417 .54709 Mtetra
.576 .499 .732 r
.45417 .54709 .46305 .57523 .47926 .57392 .47035 .54536 Mtetra
.589 .506 .728 r
.47035 .54536 .47926 .57392 .49562 .57142 .48668 .54256 Mtetra
.602 .512 .725 r
.48668 .54256 .49562 .57142 .5121 .56769 .50313 .53863 Mtetra
.614 .519 .723 r
.50313 .53863 .5121 .56769 .5287 .5627 .51969 .53356 Mtetra
.626 .526 .721 r
.51969 .53356 .5287 .5627 .54539 .55645 .53635 .52733 Mtetra
.637 .533 .72 r
.53635 .52733 .54539 .55645 .56215 .54894 .55309 .51996 Mtetra
.648 .54 .719 r
.55309 .51996 .56215 .54894 .57897 .54022 .5699 .51149 Mtetra
.658 .548 .718 r
.5699 .51149 .57897 .54022 .59584 .53034 .58675 .50197 Mtetra
.668 .555 .718 r
.58675 .50197 .59584 .53034 .61273 .51939 .60364 .49147 Mtetra
.677 .563 .719 r
.60364 .49147 .61273 .51939 .62964 .50745 .62056 .48007 Mtetra
.686 .571 .72 r
.62056 .48007 .62964 .50745 .64655 .49463 .63749 .46787 Mtetra
.694 .578 .721 r
.63749 .46787 .64655 .49463 .66346 .48106 .65443 .45497 Mtetra
.701 .586 .724 r
.65443 .45497 .66346 .48106 .68035 .46685 .67137 .44149 Mtetra
.708 .594 .726 r
.67137 .44149 .68035 .46685 .69724 .45212 .68831 .42753 Mtetra
.715 .602 .73 r
.68831 .42753 .69724 .45212 .71411 .43702 .70524 .41322 Mtetra
.721 .611 .733 r
.70524 .41322 .71411 .43702 .73096 .42165 .72217 .39867 Mtetra
.726 .619 .738 r
.72217 .39867 .73096 .42165 .74781 .40615 .7391 .38399 Mtetra
.731 .627 .743 r
.7391 .38399 .74781 .40615 .76465 .39062 .75604 .36927 Mtetra
.735 .635 .749 r
.75604 .36927 .76465 .39062 .7815 .37517 .773 .35461 Mtetra
.738 .644 .755 r
.773 .35461 .7815 .37517 .79837 .35989 .78997 .34011 Mtetra
.741 .652 .762 r
.78997 .34011 .79837 .35989 .81526 .34486 .80697 .32582 Mtetra
.742 .66 .769 r
.80697 .32582 .81526 .34486 .83218 .33015 .82402 .31181 Mtetra
.744 .668 .777 r
.82402 .31181 .83218 .33015 .84915 .31581 .84112 .29814 Mtetra
.514 .508 .788 r
.20928 .48367 .21799 .50379 .23164 .50649 .22302 .48506 Mtetra
.511 .495 .775 r
.22302 .48506 .23164 .50649 .2454 .50955 .23687 .48675 Mtetra
.51 .484 .764 r
.23687 .48675 .2454 .50955 .25928 .51293 .25082 .48869 Mtetra
.509 .473 .752 r
.25082 .48869 .25928 .51293 .27329 .51656 .2649 .49084 Mtetra
.51 .464 .742 r
.2649 .49084 .27329 .51656 .28743 .52039 .27911 .49313 Mtetra
.512 .456 .731 r
.27911 .49313 .28743 .52039 .30173 .52432 .29346 .4955 Mtetra
.514 .45 .722 r
.29346 .4955 .30173 .52432 .31619 .52827 .30795 .49787 Mtetra
.518 .445 .714 r
.30795 .49787 .31619 .52827 .33081 .53215 .32259 .50017 Mtetra
.523 .442 .706 r
.32259 .50017 .33081 .53215 .3456 .53584 .3374 .5023 Mtetra
.528 .439 .699 r
.3374 .5023 .3456 .53584 .36058 .53923 .35236 .50418 Mtetra
.533 .438 .692 r
.35236 .50418 .36058 .53923 .37573 .54222 .3675 .50571 Mtetra
.539 .437 .687 r
.3675 .50571 .37573 .54222 .39106 .54468 .3828 .50679 Mtetra
.546 .438 .682 r
.3828 .50679 .39106 .54468 .40658 .5465 .39827 .50734 Mtetra
.552 .439 .678 r
.39827 .50734 .40658 .5465 .42228 .54758 .4139 .50726 Mtetra
.559 .441 .674 r
.4139 .50726 .42228 .54758 .43814 .5478 .42969 .50648 Mtetra
.566 .443 .671 r
.42969 .50648 .43814 .5478 .45417 .54709 .44563 .50491 Mtetra
.573 .446 .669 r
.44563 .50491 .45417 .54709 .47035 .54536 .46172 .5025 Mtetra
.58 .449 .667 r
.46172 .5025 .47035 .54536 .48668 .54256 .47794 .4992 Mtetra
.587 .453 .665 r
.47794 .4992 .48668 .54256 .50313 .53863 .49429 .49497 Mtetra
.594 .457 .665 r
.49429 .49497 .50313 .53863 .51969 .53356 .51075 .48978 Mtetra
.601 .462 .664 r
.51075 .48978 .51969 .53356 .53635 .52733 .52731 .48365 Mtetra
.608 .467 .664 r
.52731 .48365 .53635 .52733 .55309 .51996 .54395 .47657 Mtetra
.615 .472 .664 r
.54395 .47657 .55309 .51996 .5699 .51149 .56067 .46858 Mtetra
.622 .478 .665 r
.56067 .46858 .5699 .51149 .58675 .50197 .57744 .45972 Mtetra
.628 .484 .667 r
.57744 .45972 .58675 .50197 .60364 .49147 .59427 .45004 Mtetra
.635 .49 .668 r
.59427 .45004 .60364 .49147 .62056 .48007 .61113 .43961 Mtetra
.641 .497 .671 r
.61113 .43961 .62056 .48007 .63749 .46787 .62803 .42852 Mtetra
.647 .503 .673 r
.62803 .42852 .63749 .46787 .65443 .45497 .64495 .41684 Mtetra
.653 .511 .677 r
.64495 .41684 .65443 .45497 .67137 .44149 .66189 .40466 Mtetra
.659 .518 .68 r
.66189 .40466 .67137 .44149 .68831 .42753 .67884 .39209 Mtetra
.665 .526 .685 r
.67884 .39209 .68831 .42753 .70524 .41322 .69581 .37921 Mtetra
.67 .534 .689 r
.69581 .37921 .70524 .41322 .72217 .39867 .71279 .36612 Mtetra
.676 .542 .695 r
.71279 .36612 .72217 .39867 .7391 .38399 .7298 .3529 Mtetra
.68 .551 .701 r
.7298 .3529 .7391 .38399 .75604 .36927 .74682 .33965 Mtetra
.685 .56 .708 r
.74682 .33965 .75604 .36927 .773 .35461 .76388 .32643 Mtetra
.689 .569 .715 r
.76388 .32643 .773 .35461 .78997 .34011 .78096 .31333 Mtetra
.693 .579 .723 r
.78096 .31333 .78997 .34011 .80697 .32582 .7981 .30039 Mtetra
.697 .589 .731 r
.7981 .30039 .80697 .32582 .82402 .31181 .81528 .28768 Mtetra
.7 .599 .74 r
.81528 .28768 .82402 .31181 .84112 .29814 .83252 .27524 Mtetra
.55 .508 .762 r
.20078 .4612 .20928 .48367 .22302 .48506 .21463 .46105 Mtetra
.547 .495 .75 r
.21463 .46105 .22302 .48506 .23687 .48675 .22857 .46111 Mtetra
.544 .484 .739 r
.22857 .46111 .23687 .48675 .25082 .48869 .24263 .46136 Mtetra
.543 .474 .728 r
.24263 .46136 .25082 .48869 .2649 .49084 .25679 .46174 Mtetra
.542 .464 .717 r
.25679 .46174 .2649 .49084 .27911 .49313 .27107 .46222 Mtetra
.542 .456 .708 r
.27107 .46222 .27911 .49313 .29346 .4955 .28548 .46275 Mtetra
.543 .45 .699 r
.28548 .46275 .29346 .4955 .30795 .49787 .30002 .46327 Mtetra
.544 .444 .691 r
.30002 .46327 .30795 .49787 .32259 .50017 .3147 .46372 Mtetra
.546 .439 .684 r
.3147 .46372 .32259 .50017 .3374 .5023 .32951 .46404 Mtetra
.548 .436 .678 r
.32951 .46404 .3374 .5023 .35236 .50418 .34448 .46414 Mtetra
.551 .433 .672 r
.34448 .46414 .35236 .50418 .3675 .50571 .35959 .46397 Mtetra
.554 .431 .667 r
.35959 .46397 .3675 .50571 .3828 .50679 .37485 .46345 Mtetra
.558 .43 .662 r
.37485 .46345 .3828 .50679 .39827 .50734 .39025 .46252 Mtetra
.562 .43 .659 r
.39025 .46252 .39827 .50734 .4139 .50726 .40581 .46111 Mtetra
.566 .43 .655 r
.40581 .46111 .4139 .50726 .42969 .50648 .4215 .45915 Mtetra
.57 .431 .653 r
.4215 .45915 .42969 .50648 .44563 .50491 .43734 .4566 Mtetra
.574 .433 .651 r
.43734 .4566 .44563 .50491 .46172 .5025 .45331 .45341 Mtetra
.579 .434 .649 r
.45331 .45341 .46172 .5025 .47794 .4992 .46941 .44954 Mtetra
.583 .437 .648 r
.46941 .44954 .47794 .4992 .49429 .49497 .48562 .44496 Mtetra
.588 .44 .647 r
.48562 .44496 .49429 .49497 .51075 .48978 .50194 .43966 Mtetra
.593 .443 .647 r
.50194 .43966 .51075 .48978 .52731 .48365 .51836 .43365 Mtetra
.598 .446 .647 r
.51836 .43365 .52731 .48365 .54395 .47657 .53487 .42691 Mtetra
.602 .45 .648 r
.53487 .42691 .54395 .47657 .56067 .46858 .55146 .41949 Mtetra
.607 .455 .649 r
.55146 .41949 .56067 .46858 .57744 .45972 .56812 .4114 Mtetra
.612 .46 .651 r
.56812 .4114 .57744 .45972 .59427 .45004 .58485 .40268 Mtetra
.617 .465 .653 r
.58485 .40268 .59427 .45004 .61113 .43961 .60163 .3934 Mtetra
.622 .47 .655 r
.60163 .3934 .61113 .43961 .62803 .42852 .61846 .38361 Mtetra
.626 .476 .658 r
.61846 .38361 .62803 .42852 .64495 .41684 .63533 .37336 Mtetra
.631 .482 .662 r
.63533 .37336 .64495 .41684 .66189 .40466 .65224 .36273 Mtetra
.636 .489 .666 r
.65224 .36273 .66189 .40466 .67884 .39209 .66918 .35178 Mtetra
.641 .496 .67 r
.66918 .35178 .67884 .39209 .69581 .37921 .68617 .34059 Mtetra
.645 .504 .675 r
.68617 .34059 .69581 .37921 .71279 .36612 .70319 .32923 Mtetra
.65 .511 .681 r
.70319 .32923 .71279 .36612 .7298 .3529 .72025 .31775 Mtetra
.655 .52 .687 r
.72025 .31775 .7298 .3529 .74682 .33965 .73735 .30624 Mtetra
.659 .529 .694 r
.73735 .30624 .74682 .33965 .76388 .32643 .7545 .29473 Mtetra
.663 .538 .702 r
.7545 .29473 .76388 .32643 .78096 .31333 .77169 .2833 Mtetra
.667 .548 .71 r
.77169 .2833 .78096 .31333 .7981 .30039 .78895 .27198 Mtetra
.671 .558 .719 r
.78895 .27198 .7981 .30039 .81528 .28768 .80627 .26082 Mtetra
.675 .569 .728 r
.80627 .26082 .81528 .28768 .83252 .27524 .82366 .24984 Mtetra
.576 .525 .761 r
.19222 .43897 .20078 .4612 .21463 .46105 .20619 .43733 Mtetra
.572 .513 .75 r
.20619 .43733 .21463 .46105 .22857 .46111 .22025 .43582 Mtetra
.57 .501 .739 r
.22025 .43582 .22857 .46111 .24263 .46136 .2344 .43442 Mtetra
.567 .491 .728 r
.2344 .43442 .24263 .46136 .25679 .46174 .24866 .43312 Mtetra
.566 .481 .718 r
.24866 .43312 .25679 .46174 .27107 .46222 .26302 .43186 Mtetra
.565 .473 .709 r
.26302 .43186 .27107 .46222 .28548 .46275 .2775 .43063 Mtetra
.564 .465 .701 r
.2775 .43063 .28548 .46275 .30002 .46327 .2921 .42938 Mtetra
.564 .459 .693 r
.2921 .42938 .30002 .46327 .3147 .46372 .30681 .42806 Mtetra
.564 .453 .686 r
.30681 .42806 .3147 .46372 .32951 .46404 .32165 .42664 Mtetra
.565 .449 .679 r
.32165 .42664 .32951 .46404 .34448 .46414 .33661 .42506 Mtetra
.566 .445 .674 r
.33661 .42506 .34448 .46414 .35959 .46397 .35171 .42327 Mtetra
.568 .442 .669 r
.35171 .42327 .35959 .46397 .37485 .46345 .36694 .42124 Mtetra
.57 .44 .664 r
.36694 .42124 .37485 .46345 .39025 .46252 .38229 .41891 Mtetra
.572 .438 .661 r
.38229 .41891 .39025 .46252 .40581 .46111 .39778 .41623 Mtetra
.574 .438 .657 r
.39778 .41623 .40581 .46111 .4215 .45915 .41339 .41317 Mtetra
.577 .437 .655 r
.41339 .41317 .4215 .45915 .43734 .4566 .42913 .40969 Mtetra
.579 .438 .653 r
.42913 .40969 .43734 .4566 .45331 .45341 .44499 .40576 Mtetra
.582 .438 .651 r
.44499 .40576 .45331 .45341 .46941 .44954 .46096 .40135 Mtetra
.585 .44 .65 r
.46096 .40135 .46941 .44954 .48562 .44496 .47705 .39645 Mtetra
.589 .442 .649 r
.47705 .39645 .48562 .44496 .50194 .43966 .49324 .39104 Mtetra
.592 .444 .649 r
.49324 .39104 .50194 .43966 .51836 .43365 .50953 .38513 Mtetra
.596 .447 .649 r
.50953 .38513 .51836 .43365 .53487 .42691 .52591 .37871 Mtetra
.599 .45 .65 r
.52591 .37871 .53487 .42691 .55146 .41949 .54238 .37181 Mtetra
.603 .453 .651 r
.54238 .37181 .55146 .41949 .56812 .4114 .55893 .36445 Mtetra
.607 .457 .653 r
.55893 .36445 .56812 .4114 .58485 .40268 .57555 .35664 Mtetra
.61 .462 .655 r
.57555 .35664 .58485 .40268 .60163 .3934 .59224 .34844 Mtetra
.614 .467 .658 r
.59224 .34844 .60163 .3934 .61846 .38361 .609 .33986 Mtetra
.618 .472 .661 r
.609 .33986 .61846 .38361 .63533 .37336 .62582 .33096 Mtetra
.622 .478 .665 r
.62582 .33096 .63533 .37336 .65224 .36273 .64269 .32179 Mtetra
.626 .484 .669 r
.64269 .32179 .65224 .36273 .66918 .35178 .65963 .31238 Mtetra
.63 .491 .674 r
.65963 .31238 .66918 .35178 .68617 .34059 .67662 .30279 Mtetra
.634 .498 .679 r
.67662 .30279 .68617 .34059 .70319 .32923 .69366 .29307 Mtetra
.638 .506 .685 r
.69366 .29307 .70319 .32923 .72025 .31775 .71077 .28325 Mtetra
.642 .514 .692 r
.71077 .28325 .72025 .31775 .73735 .30624 .72793 .27339 Mtetra
.646 .523 .699 r
.72793 .27339 .73735 .30624 .7545 .29473 .74516 .26353 Mtetra
.65 .532 .707 r
.74516 .26353 .7545 .29473 .77169 .2833 .76246 .25369 Mtetra
.654 .542 .715 r
.76246 .25369 .77169 .2833 .78895 .27198 .77983 .24392 Mtetra
.658 .553 .724 r
.77983 .24392 .78895 .27198 .80627 .26082 .79728 .23425 Mtetra
.661 .563 .734 r
.79728 .23425 .80627 .26082 .82366 .24984 .8148 .22468 Mtetra
.599 .555 .777 r
.18343 .4188 .19222 .43897 .20619 .43733 .19751 .4159 Mtetra
.595 .544 .767 r
.19751 .4159 .20619 .43733 .22025 .43582 .21167 .41308 Mtetra
.592 .532 .756 r
.21167 .41308 .22025 .43582 .2344 .43442 .22592 .41032 Mtetra
.59 .522 .746 r
.22592 .41032 .2344 .43442 .24866 .43312 .24027 .40761 Mtetra
.588 .512 .737 r
.24027 .40761 .24866 .43312 .26302 .43186 .25472 .40491 Mtetra
.586 .503 .728 r
.25472 .40491 .26302 .43186 .2775 .43063 .26926 .40222 Mtetra
.584 .495 .719 r
.26926 .40222 .2775 .43063 .2921 .42938 .28392 .3995 Mtetra
.583 .487 .711 r
.28392 .3995 .2921 .42938 .30681 .42806 .29868 .39673 Mtetra
.583 .481 .704 r
.29868 .39673 .30681 .42806 .32165 .42664 .31355 .39387 Mtetra
.582 .476 .698 r
.31355 .39387 .32165 .42664 .33661 .42506 .32853 .39091 Mtetra
.582 .471 .692 r
.32853 .39091 .33661 .42506 .35171 .42327 .34362 .3878 Mtetra
.583 .467 .687 r
.34362 .3878 .35171 .42327 .36694 .42124 .35884 .38452 Mtetra
.583 .464 .682 r
.35884 .38452 .36694 .42124 .38229 .41891 .37416 .38104 Mtetra
.584 .461 .678 r
.37416 .38104 .38229 .41891 .39778 .41623 .3896 .37732 Mtetra
.586 .459 .674 r
.3896 .37732 .39778 .41623 .41339 .41317 .40516 .37336 Mtetra
.587 .458 .672 r
.40516 .37336 .41339 .41317 .42913 .40969 .42083 .36911 Mtetra
.589 .457 .669 r
.42083 .36911 .42913 .40969 .44499 .40576 .43661 .36457 Mtetra
.591 .457 .668 r
.43661 .36457 .44499 .40576 .46096 .40135 .45249 .35972 Mtetra
.593 .458 .666 r
.45249 .35972 .46096 .40135 .47705 .39645 .46848 .35454 Mtetra
.595 .459 .666 r
.46848 .35454 .47705 .39645 .49324 .39104 .48458 .34904 Mtetra
.598 .461 .666 r
.48458 .34904 .49324 .39104 .50953 .38513 .50077 .3432 Mtetra
.6 .463 .666 r
.50077 .3432 .50953 .38513 .52591 .37871 .51705 .33703 Mtetra
.603 .465 .667 r
.51705 .33703 .52591 .37871 .54238 .37181 .53343 .33055 Mtetra
.606 .468 .668 r
.53343 .33055 .54238 .37181 .55893 .36445 .54989 .32376 Mtetra
.609 .472 .67 r
.54989 .32376 .55893 .36445 .57555 .35664 .56643 .31668 Mtetra
.612 .476 .672 r
.56643 .31668 .57555 .35664 .59224 .34844 .58306 .30933 Mtetra
.615 .481 .675 r
.58306 .30933 .59224 .34844 .609 .33986 .59976 .30173 Mtetra
.618 .486 .679 r
.59976 .30173 .609 .33986 .62582 .33096 .61654 .29392 Mtetra
.622 .492 .683 r
.61654 .29392 .62582 .33096 .64269 .32179 .63339 .28592 Mtetra
.625 .498 .687 r
.63339 .28592 .64269 .32179 .65963 .31238 .65032 .27776 Mtetra
.629 .504 .692 r
.65032 .27776 .65963 .31238 .67662 .30279 .66732 .26946 Mtetra
.632 .512 .698 r
.66732 .26946 .67662 .30279 .69366 .29307 .68439 .26107 Mtetra
.636 .519 .704 r
.68439 .26107 .69366 .29307 .71077 .28325 .70154 .2526 Mtetra
.639 .528 .711 r
.70154 .2526 .71077 .28325 .72793 .27339 .71876 .24409 Mtetra
.643 .537 .719 r
.71876 .24409 .72793 .27339 .74516 .26353 .73607 .23555 Mtetra
.646 .546 .727 r
.73607 .23555 .74516 .26353 .76246 .25369 .75345 .22703 Mtetra
.65 .556 .735 r
.75345 .22703 .76246 .25369 .77983 .24392 .77092 .21852 Mtetra
.653 .566 .744 r
.77092 .21852 .77983 .24392 .79728 .23425 .78848 .21006 Mtetra
.656 .577 .754 r
.78848 .21006 .79728 .23425 .8148 .22468 .80613 .20166 Mtetra
.62 .595 .804 r
.1743 .40143 .18343 .4188 .19751 .4159 .18847 .39761 Mtetra
.617 .584 .795 r
.18847 .39761 .19751 .4159 .21167 .41308 .20272 .39382 Mtetra
.614 .574 .785 r
.20272 .39382 .21167 .41308 .22592 .41032 .21706 .39005 Mtetra
.612 .564 .776 r
.21706 .39005 .22592 .41032 .24027 .40761 .23149 .38629 Mtetra
.609 .554 .768 r
.23149 .38629 .24027 .40761 .25472 .40491 .24602 .38253 Mtetra
.607 .545 .759 r
.24602 .38253 .25472 .40491 .26926 .40222 .26063 .37876 Mtetra
.605 .537 .751 r
.26063 .37876 .26926 .40222 .28392 .3995 .27534 .37496 Mtetra
.604 .529 .744 r
.27534 .37496 .28392 .3995 .29868 .39673 .29015 .37112 Mtetra
.603 .522 .737 r
.29015 .37112 .29868 .39673 .31355 .39387 .30506 .36722 Mtetra
.602 .516 .73 r
.30506 .36722 .31355 .39387 .32853 .39091 .32007 .36323 Mtetra
.601 .511 .724 r
.32007 .36323 .32853 .39091 .34362 .3878 .33519 .35915 Mtetra
.601 .506 .719 r
.33519 .35915 .34362 .3878 .35884 .38452 .3504 .35496 Mtetra
.601 .502 .714 r
.3504 .35496 .35884 .38452 .37416 .38104 .36572 .35064 Mtetra
.601 .498 .71 r
.36572 .35064 .37416 .38104 .3896 .37732 .38115 .34616 Mtetra
.601 .496 .706 r
.38115 .34616 .3896 .37732 .40516 .37336 .39668 .34153 Mtetra
.602 .494 .703 r
.39668 .34153 .40516 .37336 .42083 .36911 .41231 .33672 Mtetra
.603 .492 .701 r
.41231 .33672 .42083 .36911 .43661 .36457 .42805 .33173 Mtetra
.604 .492 .699 r
.42805 .33173 .43661 .36457 .45249 .35972 .44389 .32654 Mtetra
.605 .492 .697 r
.44389 .32654 .45249 .35972 .46848 .35454 .45983 .32115 Mtetra
.607 .492 .697 r
.45983 .32115 .46848 .35454 .48458 .34904 .47586 .31556 Mtetra
.609 .493 .696 r
.47586 .31556 .48458 .34904 .50077 .3432 .492 .30976 Mtetra
.61 .495 .697 r
.492 .30976 .50077 .3432 .51705 .33703 .50822 .30375 Mtetra
.612 .497 .698 r
.50822 .30375 .51705 .33703 .53343 .33055 .52455 .29755 Mtetra
.615 .5 .699 r
.52455 .29755 .53343 .33055 .54989 .32376 .54096 .29115 Mtetra
.617 .503 .701 r
.54096 .29115 .54989 .32376 .56643 .31668 .55746 .28457 Mtetra
.62 .507 .704 r
.55746 .28457 .56643 .31668 .58306 .30933 .57405 .27782 Mtetra
.622 .511 .707 r
.57405 .27782 .58306 .30933 .59976 .30173 .59073 .27091 Mtetra
.625 .516 .71 r
.59073 .27091 .59976 .30173 .61654 .29392 .60749 .26386 Mtetra
.628 .522 .715 r
.60749 .26386 .61654 .29392 .63339 .28592 .62434 .25669 Mtetra
.631 .528 .719 r
.62434 .25669 .63339 .28592 .65032 .27776 .64128 .2494 Mtetra
.634 .535 .725 r
.64128 .2494 .65032 .27776 .66732 .26946 .6583 .24202 Mtetra
.637 .542 .731 r
.6583 .24202 .66732 .26946 .68439 .26107 .67541 .23457 Mtetra
.64 .55 .737 r
.67541 .23457 .68439 .26107 .70154 .2526 .6926 .22706 Mtetra
.643 .558 .744 r
.6926 .22706 .70154 .2526 .71876 .24409 .70988 .2195 Mtetra
.646 .566 .751 r
.70988 .2195 .71876 .24409 .73607 .23555 .72726 .21192 Mtetra
.648 .575 .759 r
.72726 .21192 .73607 .23555 .75345 .22703 .74473 .20432 Mtetra
.651 .585 .767 r
.74473 .20432 .75345 .22703 .77092 .21852 .76229 .19672 Mtetra
.654 .594 .776 r
.76229 .19672 .77092 .21852 .78848 .21006 .77994 .18913 Mtetra
.657 .604 .784 r
.77994 .18913 .78848 .21006 .80613 .20166 .7977 .18156 Mtetra
.637 .638 .835 r
.1648 .38676 .1743 .40143 .18847 .39761 .17905 .38231 Mtetra
.635 .629 .828 r
.17905 .38231 .18847 .39761 .20272 .39382 .19339 .37786 Mtetra
.633 .621 .82 r
.19339 .37786 .20272 .39382 .21706 .39005 .2078 .37342 Mtetra
.631 .612 .813 r
.2078 .37342 .21706 .39005 .23149 .38629 .22231 .36896 Mtetra
.629 .604 .806 r
.22231 .36896 .23149 .38629 .24602 .38253 .2369 .36449 Mtetra
.628 .596 .799 r
.2369 .36449 .24602 .38253 .26063 .37876 .25158 .36 Mtetra
.626 .589 .792 r
.25158 .36 .26063 .37876 .27534 .37496 .26635 .35549 Mtetra
.625 .581 .785 r
.26635 .35549 .27534 .37496 .29015 .37112 .28121 .35093 Mtetra
.623 .575 .779 r
.28121 .35093 .29015 .37112 .30506 .36722 .29616 .34632 Mtetra
.622 .569 .773 r
.29616 .34632 .30506 .36722 .32007 .36323 .31121 .34166 Mtetra
.621 .563 .768 r
.31121 .34166 .32007 .36323 .33519 .35915 .32636 .33693 Mtetra
.621 .558 .763 r
.32636 .33693 .33519 .35915 .3504 .35496 .3416 .33213 Mtetra
.62 .554 .758 r
.3416 .33213 .3504 .35496 .36572 .35064 .35694 .32724 Mtetra
.62 .55 .754 r
.35694 .32724 .36572 .35064 .38115 .34616 .37237 .32226 Mtetra
.62 .547 .751 r
.37237 .32226 .38115 .34616 .39668 .34153 .3879 .31717 Mtetra
.62 .544 .748 r
.3879 .31717 .39668 .34153 .41231 .33672 .40354 .31198 Mtetra
.62 .542 .745 r
.40354 .31198 .41231 .33672 .42805 .33173 .41927 .30668 Mtetra
.621 .541 .743 r
.41927 .30668 .42805 .33173 .44389 .32654 .43509 .30125 Mtetra
.622 .541 .742 r
.43509 .30125 .44389 .32654 .45983 .32115 .45102 .2957 Mtetra
.623 .541 .741 r
.45102 .2957 .45983 .32115 .47586 .31556 .46704 .29003 Mtetra
.624 .541 .741 r
.46704 .29003 .47586 .31556 .492 .30976 .48315 .28423 Mtetra
.625 .543 .741 r
.48315 .28423 .492 .30976 .50822 .30375 .49937 .2783 Mtetra
.627 .544 .742 r
.49937 .2783 .50822 .30375 .52455 .29755 .51567 .27225 Mtetra
.628 .547 .744 r
.51567 .27225 .52455 .29755 .54096 .29115 .53207 .26609 Mtetra
.63 .55 .746 r
.53207 .26609 .54096 .29115 .55746 .28457 .54857 .25981 Mtetra
.632 .554 .748 r
.54857 .25981 .55746 .28457 .57405 .27782 .56516 .25342 Mtetra
.634 .558 .751 r
.56516 .25342 .57405 .27782 .59073 .27091 .58184 .24693 Mtetra
.636 .562 .755 r
.58184 .24693 .59073 .27091 .60749 .26386 .59862 .24035 Mtetra
.638 .568 .759 r
.59862 .24035 .60749 .26386 .62434 .25669 .61549 .23369 Mtetra
.64 .573 .763 r
.61549 .23369 .62434 .25669 .64128 .2494 .63245 .22694 Mtetra
.643 .579 .768 r
.63245 .22694 .64128 .2494 .6583 .24202 .6495 .22013 Mtetra
.645 .586 .774 r
.6495 .22013 .6583 .24202 .67541 .23457 .66666 .21327 Mtetra
.647 .593 .78 r
.66666 .21327 .67541 .23457 .6926 .22706 .6839 .20635 Mtetra
.65 .6 .786 r
.6839 .20635 .6926 .22706 .70988 .2195 .70125 .19939 Mtetra
.652 .608 .792 r
.70125 .19939 .70988 .2195 .72726 .21192 .71869 .1924 Mtetra
.654 .616 .799 r
.71869 .1924 .72726 .21192 .74473 .20432 .73623 .18539 Mtetra
.656 .624 .806 r
.73623 .18539 .74473 .20432 .76229 .19672 .75388 .17835 Mtetra
.658 .632 .813 r
.75388 .17835 .76229 .19672 .77994 .18913 .77162 .1713 Mtetra
.659 .64 .82 r
.77162 .1713 .77994 .18913 .7977 .18156 .78948 .16424 Mtetra
.65 .677 .863 r
.15499 .37417 .1648 .38676 .17905 .38231 .16931 .36933 Mtetra
.648 .671 .858 r
.16931 .36933 .17905 .38231 .19339 .37786 .18371 .36448 Mtetra
.647 .665 .853 r
.18371 .36448 .19339 .37786 .2078 .37342 .19819 .35961 Mtetra
.646 .659 .848 r
.19819 .35961 .2078 .37342 .22231 .36896 .21276 .35473 Mtetra
.645 .653 .843 r
.21276 .35473 .22231 .36896 .2369 .36449 .22741 .34982 Mtetra
.644 .647 .838 r
.22741 .34982 .2369 .36449 .25158 .36 .24215 .34488 Mtetra
.643 .641 .833 r
.24215 .34488 .25158 .36 .26635 .35549 .25697 .33992 Mtetra
.642 .635 .828 r
.25697 .33992 .26635 .35549 .28121 .35093 .27189 .33492 Mtetra
.641 .63 .823 r
.27189 .33492 .28121 .35093 .29616 .34632 .28689 .32988 Mtetra
.64 .625 .819 r
.28689 .32988 .29616 .34632 .31121 .34166 .30198 .3248 Mtetra
.639 .62 .815 r
.30198 .3248 .31121 .34166 .32636 .33693 .31717 .31967 Mtetra
.639 .616 .811 r
.31717 .31967 .32636 .33693 .3416 .33213 .33245 .31448 Mtetra
.638 .612 .807 r
.33245 .31448 .3416 .33213 .35694 .32724 .34782 .30924 Mtetra
.638 .609 .804 r
.34782 .30924 .35694 .32724 .37237 .32226 .36328 .30394 Mtetra
.638 .606 .801 r
.36328 .30394 .37237 .32226 .3879 .31717 .37884 .29857 Mtetra
.638 .603 .798 r
.37884 .29857 .3879 .31717 .40354 .31198 .3945 .29312 Mtetra
.638 .602 .796 r
.3945 .29312 .40354 .31198 .41927 .30668 .41025 .28761 Mtetra
.638 .6 .795 r
.41025 .28761 .41927 .30668 .43509 .30125 .42609 .28202 Mtetra
.639 .6 .794 r
.42609 .28202 .43509 .30125 .45102 .2957 .44203 .27635 Mtetra
.639 .599 .793 r
.44203 .27635 .45102 .2957 .46704 .29003 .45807 .2706 Mtetra
.64 .6 .793 r
.45807 .2706 .46704 .29003 .48315 .28423 .4742 .26478 Mtetra
.641 .601 .793 r
.4742 .26478 .48315 .28423 .49937 .2783 .49043 .25887 Mtetra
.642 .602 .794 r
.49043 .25887 .49937 .2783 .51567 .27225 .50675 .25289 Mtetra
.643 .604 .795 r
.50675 .25289 .51567 .27225 .53207 .26609 .52317 .24683 Mtetra
.644 .606 .797 r
.52317 .24683 .53207 .26609 .54857 .25981 .53969 .2407 Mtetra
.645 .609 .799 r
.53969 .2407 .54857 .25981 .56516 .25342 .5563 .2345 Mtetra
.647 .613 .801 r
.5563 .2345 .56516 .25342 .58184 .24693 .57301 .22822 Mtetra
.648 .617 .804 r
.57301 .22822 .58184 .24693 .59862 .24035 .58982 .22189 Mtetra
.649 .621 .808 r
.58982 .22189 .59862 .24035 .61549 .23369 .60673 .21549 Mtetra
.651 .625 .811 r
.60673 .21549 .61549 .23369 .63245 .22694 .62374 .20904 Mtetra
.652 .63 .815 r
.62374 .20904 .63245 .22694 .6495 .22013 .64084 .20253 Mtetra
.654 .636 .82 r
.64084 .20253 .6495 .22013 .66666 .21327 .65805 .19598 Mtetra
.655 .641 .824 r
.65805 .19598 .66666 .21327 .6839 .20635 .67535 .18938 Mtetra
.656 .647 .829 r
.67535 .18938 .6839 .20635 .70125 .19939 .69276 .18274 Mtetra
.658 .653 .834 r
.69276 .18274 .70125 .19939 .71869 .1924 .71028 .17607 Mtetra
.659 .659 .838 r
.71028 .17607 .71869 .1924 .73623 .18539 .72789 .16936 Mtetra
.66 .664 .843 r
.72789 .16936 .73623 .18539 .75388 .17835 .74562 .16262 Mtetra
.661 .67 .848 r
.74562 .16262 .75388 .17835 .77162 .1713 .76345 .15586 Mtetra
.662 .676 .853 r
.76345 .15586 .77162 .1713 .78948 .16424 .78139 .14907 Mtetra
.657 .706 .883 r
.14492 .36295 .15499 .37417 .16931 .36933 .1593 .35788 Mtetra
.657 .702 .881 r
.1593 .35788 .16931 .36933 .18371 .36448 .17375 .35279 Mtetra
.656 .699 .878 r
.17375 .35279 .18371 .36448 .19819 .35961 .18829 .34767 Mtetra
.655 .695 .875 r
.18829 .34767 .19819 .35961 .21276 .35473 .20292 .34253 Mtetra
.655 .691 .872 r
.20292 .34253 .21276 .35473 .22741 .34982 .21762 .33736 Mtetra
.654 .688 .869 r
.21762 .33736 .22741 .34982 .24215 .34488 .23242 .33217 Mtetra
.654 .684 .866 r
.23242 .33217 .24215 .34488 .25697 .33992 .2473 .32694 Mtetra
.653 .68 .863 r
.2473 .32694 .25697 .33992 .27189 .33492 .26226 .32168 Mtetra
.653 .677 .86 r
.26226 .32168 .27189 .33492 .28689 .32988 .27732 .31638 Mtetra
.653 .674 .857 r
.27732 .31638 .28689 .32988 .30198 .3248 .29246 .31105 Mtetra
.652 .67 .855 r
.29246 .31105 .30198 .3248 .31717 .31967 .30769 .30568 Mtetra
.652 .667 .852 r
.30769 .30568 .31717 .31967 .33245 .31448 .32302 .30027 Mtetra
.652 .665 .85 r
.32302 .30027 .33245 .31448 .34782 .30924 .33843 .29481 Mtetra
.651 .662 .848 r
.33843 .29481 .34782 .30924 .36328 .30394 .35394 .2893 Mtetra
.651 .66 .846 r
.35394 .2893 .36328 .30394 .37884 .29857 .36954 .28375 Mtetra
.651 .659 .844 r
.36954 .28375 .37884 .29857 .3945 .29312 .38523 .27815 Mtetra
.651 .657 .843 r
.38523 .27815 .3945 .29312 .41025 .28761 .40102 .27249 Mtetra
.652 .656 .842 r
.40102 .27249 .41025 .28761 .42609 .28202 .4169 .26679 Mtetra
.652 .656 .841 r
.4169 .26679 .42609 .28202 .44203 .27635 .43288 .26103 Mtetra
.652 .655 .84 r
.43288 .26103 .44203 .27635 .45807 .2706 .44895 .25521 Mtetra
.653 .656 .84 r
.44895 .25521 .45807 .2706 .4742 .26478 .46512 .24934 Mtetra
.653 .656 .841 r
.46512 .24934 .4742 .26478 .49043 .25887 .48138 .24342 Mtetra
.653 .657 .841 r
.48138 .24342 .49043 .25887 .50675 .25289 .49774 .23744 Mtetra
.654 .658 .842 r
.49774 .23744 .50675 .25289 .52317 .24683 .5142 .2314 Mtetra
.655 .66 .843 r
.5142 .2314 .52317 .24683 .53969 .2407 .53076 .22532 Mtetra
.655 .662 .844 r
.53076 .22532 .53969 .2407 .5563 .2345 .54742 .21918 Mtetra
.656 .664 .846 r
.54742 .21918 .5563 .2345 .57301 .22822 .56418 .21299 Mtetra
.657 .667 .848 r
.56418 .21299 .57301 .22822 .58982 .22189 .58104 .20675 Mtetra
.657 .67 .85 r
.58104 .20675 .58982 .22189 .60673 .21549 .59799 .20046 Mtetra
.658 .673 .853 r
.59799 .20046 .60673 .21549 .62374 .20904 .61506 .19412 Mtetra
.659 .676 .855 r
.61506 .19412 .62374 .20904 .64084 .20253 .63222 .18775 Mtetra
.659 .679 .858 r
.63222 .18775 .64084 .20253 .65805 .19598 .64949 .18132 Mtetra
.66 .683 .861 r
.64949 .18132 .65805 .19598 .67535 .18938 .66686 .17486 Mtetra
.661 .687 .864 r
.66686 .17486 .67535 .18938 .69276 .18274 .68434 .16836 Mtetra
.661 .69 .866 r
.68434 .16836 .69276 .18274 .71028 .17607 .70192 .16182 Mtetra
.662 .694 .869 r
.70192 .16182 .71028 .17607 .72789 .16936 .71961 .15524 Mtetra
.662 .698 .872 r
.71961 .15524 .72789 .16936 .74562 .16262 .73741 .14862 Mtetra
.663 .701 .875 r
.73741 .14862 .74562 .16262 .76345 .15586 .75533 .14198 Mtetra
.663 .705 .878 r
.75533 .14198 .76345 .15586 .78139 .14907 .77335 .13529 Mtetra
.661 .724 .896 r
.13465 .3525 .14492 .36295 .1593 .35788 .14908 .34729 Mtetra
.661 .722 .895 r
.14908 .34729 .1593 .35788 .17375 .35279 .16359 .34205 Mtetra
.66 .72 .893 r
.16359 .34205 .17375 .35279 .18829 .34767 .17818 .33679 Mtetra
.66 .718 .892 r
.17818 .33679 .18829 .34767 .20292 .34253 .19285 .33149 Mtetra
.66 .717 .89 r
.19285 .33149 .20292 .34253 .21762 .33736 .20761 .32617 Mtetra
.66 .715 .889 r
.20761 .32617 .21762 .33736 .23242 .33217 .22246 .32082 Mtetra
.66 .713 .887 r
.22246 .32082 .23242 .33217 .2473 .32694 .23739 .31543 Mtetra
.659 .711 .886 r
.23739 .31543 .2473 .32694 .26226 .32168 .25241 .31002 Mtetra
.659 .709 .884 r
.25241 .31002 .26226 .32168 .27732 .31638 .26752 .30457 Mtetra
.659 .707 .883 r
.26752 .30457 .27732 .31638 .29246 .31105 .28271 .29908 Mtetra
.659 .705 .882 r
.28271 .29908 .29246 .31105 .30769 .30568 .29799 .29357 Mtetra
.659 .704 .88 r
.29799 .29357 .30769 .30568 .32302 .30027 .31337 .28801 Mtetra
.659 .702 .879 r
.31337 .28801 .32302 .30027 .33843 .29481 .32883 .28242 Mtetra
.659 .701 .878 r
.32883 .28242 .33843 .29481 .35394 .2893 .34439 .27678 Mtetra
.659 .7 .877 r
.34439 .27678 .35394 .2893 .36954 .28375 .36004 .27111 Mtetra
.659 .699 .876 r
.36004 .27111 .36954 .28375 .38523 .27815 .37578 .2654 Mtetra
.659 .698 .875 r
.37578 .2654 .38523 .27815 .40102 .27249 .39161 .25965 Mtetra
.659 .697 .875 r
.39161 .25965 .40102 .27249 .4169 .26679 .40754 .25385 Mtetra
.659 .697 .874 r
.40754 .25385 .4169 .26679 .43288 .26103 .42357 .24801 Mtetra
.42357 .24801 .43288 .26103 .44895 .25521 .43969 .24213 Mtetra
.43969 .24213 .44895 .25521 .46512 .24934 .45591 .2362 Mtetra
.45591 .2362 .46512 .24934 .48138 .24342 .47222 .23024 Mtetra
.66 .698 .874 r
.47222 .23024 .48138 .24342 .49774 .23744 .48864 .22422 Mtetra
.66 .698 .875 r
.48864 .22422 .49774 .23744 .5142 .2314 .50515 .21817 Mtetra
.66 .699 .875 r
.50515 .21817 .5142 .2314 .53076 .22532 .52176 .21207 Mtetra
.66 .7 .876 r
.52176 .21207 .53076 .22532 .54742 .21918 .53847 .20592 Mtetra
.661 .702 .877 r
.53847 .20592 .54742 .21918 .56418 .21299 .55529 .19973 Mtetra
.661 .703 .878 r
.55529 .19973 .56418 .21299 .58104 .20675 .5722 .1935 Mtetra
.661 .705 .879 r
.5722 .1935 .58104 .20675 .59799 .20046 .58922 .18723 Mtetra
.662 .706 .88 r
.58922 .18723 .59799 .20046 .61506 .19412 .60635 .18092 Mtetra
.662 .708 .882 r
.60635 .18092 .61506 .19412 .63222 .18775 .62358 .17456 Mtetra
.662 .71 .883 r
.62358 .17456 .63222 .18775 .64949 .18132 .64091 .16817 Mtetra
.662 .712 .885 r
.64091 .16817 .64949 .18132 .66686 .17486 .65835 .16173 Mtetra
.663 .714 .886 r
.65835 .16173 .66686 .17486 .68434 .16836 .6759 .15525 Mtetra
.663 .716 .888 r
.6759 .15525 .68434 .16836 .70192 .16182 .69356 .14874 Mtetra
.663 .718 .889 r
.69356 .14874 .70192 .16182 .71961 .15524 .71133 .14218 Mtetra
.663 .72 .891 r
.71133 .14218 .71961 .15524 .73741 .14862 .72921 .13559 Mtetra
.663 .721 .892 r
.72921 .13559 .73741 .14862 .75533 .14198 .7472 .12895 Mtetra
.663 .723 .893 r
.7472 .12895 .75533 .14198 .77335 .13529 .7653 .12228 Mtetra
.662 .734 .903 r
.12422 .34239 .13465 .3525 .14908 .34729 .13869 .33709 Mtetra
.662 .733 .902 r
.13869 .33709 .14908 .34729 .16359 .34205 .15325 .33176 Mtetra
.662 .732 .901 r
.15325 .33176 .16359 .34205 .17818 .33679 .16789 .3264 Mtetra
.662 .731 .901 r
.16789 .3264 .17818 .33679 .19285 .33149 .18262 .32101 Mtetra
.662 .73 .9 r
.18262 .32101 .19285 .33149 .20761 .32617 .19743 .31558 Mtetra
.19743 .31558 .20761 .32617 .22246 .32082 .21233 .31013 Mtetra
.662 .729 .899 r
.21233 .31013 .22246 .32082 .23739 .31543 .22731 .30465 Mtetra
.662 .728 .898 r
.22731 .30465 .23739 .31543 .25241 .31002 .24238 .29913 Mtetra
.662 .727 .898 r
.24238 .29913 .25241 .31002 .26752 .30457 .25754 .29358 Mtetra
.662 .726 .897 r
.25754 .29358 .26752 .30457 .28271 .29908 .27278 .288 Mtetra
.662 .725 .896 r
.27278 .288 .28271 .29908 .29799 .29357 .28812 .28238 Mtetra
.28812 .28238 .29799 .29357 .31337 .28801 .30355 .27673 Mtetra
.662 .724 .895 r
.30355 .27673 .31337 .28801 .32883 .28242 .31906 .27104 Mtetra
.662 .723 .895 r
.31906 .27104 .32883 .28242 .34439 .27678 .33467 .26532 Mtetra
.662 .723 .894 r
.33467 .26532 .34439 .27678 .36004 .27111 .35038 .25956 Mtetra
.662 .722 .894 r
.35038 .25956 .36004 .27111 .37578 .2654 .36617 .25376 Mtetra
.662 .722 .893 r
.36617 .25376 .37578 .2654 .39161 .25965 .38206 .24793 Mtetra
.38206 .24793 .39161 .25965 .40754 .25385 .39804 .24205 Mtetra
.662 .721 .893 r
.39804 .24205 .40754 .25385 .42357 .24801 .41412 .23614 Mtetra
.41412 .23614 .42357 .24801 .43969 .24213 .4303 .2302 Mtetra
.4303 .2302 .43969 .24213 .45591 .2362 .44658 .22421 Mtetra
.44658 .22421 .45591 .2362 .47222 .23024 .46295 .21818 Mtetra
.662 .722 .893 r
.46295 .21818 .47222 .23024 .48864 .22422 .47942 .21212 Mtetra
.47942 .21212 .48864 .22422 .50515 .21817 .49599 .20601 Mtetra
.662 .722 .894 r
.49599 .20601 .50515 .21817 .52176 .21207 .51267 .19987 Mtetra
.662 .723 .894 r
.51267 .19987 .52176 .21207 .53847 .20592 .52944 .19368 Mtetra
.663 .723 .894 r
.52944 .19368 .53847 .20592 .55529 .19973 .54632 .18745 Mtetra
.663 .724 .895 r
.54632 .18745 .55529 .19973 .5722 .1935 .5633 .18119 Mtetra
.663 .725 .895 r
.5633 .18119 .5722 .1935 .58922 .18723 .58038 .17488 Mtetra
.663 .726 .896 r
.58038 .17488 .58922 .18723 .60635 .18092 .59757 .16854 Mtetra
.59757 .16854 .60635 .18092 .62358 .17456 .61487 .16215 Mtetra
.663 .727 .897 r
.61487 .16215 .62358 .17456 .64091 .16817 .63228 .15572 Mtetra
.663 .728 .898 r
.63228 .15572 .64091 .16817 .65835 .16173 .64979 .14926 Mtetra
.663 .729 .898 r
.64979 .14926 .65835 .16173 .6759 .15525 .66741 .14275 Mtetra
.663 .73 .899 r
.66741 .14275 .6759 .15525 .69356 .14874 .68514 .1362 Mtetra
.663 .731 .9 r
.68514 .1362 .69356 .14874 .71133 .14218 .70299 .12961 Mtetra
.663 .732 .9 r
.70299 .12961 .71133 .14218 .72921 .13559 .72095 .12298 Mtetra
.663 .732 .901 r
.72095 .12298 .72921 .13559 .7472 .12895 .73902 .11631 Mtetra
.663 .733 .902 r
.73902 .11631 .7472 .12895 .7653 .12228 .7572 .1096 Mtetra
.663 .738 .906 r
.11365 .3324 .12422 .34239 .13869 .33709 .12817 .32703 Mtetra
.12817 .32703 .13869 .33709 .15325 .33176 .14278 .32162 Mtetra
.663 .738 .905 r
.14278 .32162 .15325 .33176 .16789 .3264 .15747 .31619 Mtetra
.663 .737 .905 r
.15747 .31619 .16789 .3264 .18262 .32101 .17225 .31072 Mtetra
.17225 .31072 .18262 .32101 .19743 .31558 .18711 .30523 Mtetra
.18711 .30523 .19743 .31558 .21233 .31013 .20205 .2997 Mtetra
.663 .736 .904 r
.20205 .2997 .21233 .31013 .22731 .30465 .21709 .29414 Mtetra
.21709 .29414 .22731 .30465 .24238 .29913 .23221 .28854 Mtetra
.23221 .28854 .24238 .29913 .25754 .29358 .24742 .28291 Mtetra
.663 .735 .904 r
.24742 .28291 .25754 .29358 .27278 .288 .26272 .27725 Mtetra
.663 .735 .903 r
.26272 .27725 .27278 .288 .28812 .28238 .27811 .27156 Mtetra
.27811 .27156 .28812 .28238 .30355 .27673 .29359 .26583 Mtetra
.663 .734 .903 r
.29359 .26583 .30355 .27673 .31906 .27104 .30916 .26007 Mtetra
.30916 .26007 .31906 .27104 .33467 .26532 .32482 .25427 Mtetra
.663 .734 .902 r
.32482 .25427 .33467 .26532 .35038 .25956 .34058 .24844 Mtetra
.34058 .24844 .35038 .25956 .36617 .25376 .35643 .24257 Mtetra
.35643 .24257 .36617 .25376 .38206 .24793 .37238 .23667 Mtetra
.663 .733 .902 r
.37238 .23667 .38206 .24793 .39804 .24205 .38842 .23072 Mtetra
.38842 .23072 .39804 .24205 .41412 .23614 .40456 .22475 Mtetra
.40456 .22475 .41412 .23614 .4303 .2302 .4208 .21873 Mtetra
.4208 .21873 .4303 .2302 .44658 .22421 .43713 .21268 Mtetra
.43713 .21268 .44658 .22421 .46295 .21818 .45356 .20659 Mtetra
.45356 .20659 .46295 .21818 .47942 .21212 .4701 .20046 Mtetra
.663 .734 .902 r
.4701 .20046 .47942 .21212 .49599 .20601 .48673 .19429 Mtetra
.48673 .19429 .49599 .20601 .51267 .19987 .50347 .18809 Mtetra
.50347 .18809 .51267 .19987 .52944 .19368 .52031 .18184 Mtetra
.663 .734 .903 r
.52031 .18184 .52944 .19368 .54632 .18745 .53725 .17556 Mtetra
.53725 .17556 .54632 .18745 .5633 .18119 .5543 .16924 Mtetra
.663 .735 .903 r
.5543 .16924 .5633 .18119 .58038 .17488 .57145 .16287 Mtetra
.57145 .16287 .58038 .17488 .59757 .16854 .58871 .15647 Mtetra
.58871 .15647 .59757 .16854 .61487 .16215 .60608 .15003 Mtetra
.663 .736 .904 r
.60608 .15003 .61487 .16215 .63228 .15572 .62356 .14354 Mtetra
.62356 .14354 .63228 .15572 .64979 .14926 .64115 .13702 Mtetra
.64115 .13702 .64979 .14926 .66741 .14275 .65884 .13045 Mtetra
.663 .737 .904 r
.65884 .13045 .66741 .14275 .68514 .1362 .67665 .12384 Mtetra
.663 .737 .905 r
.67665 .12384 .68514 .1362 .70299 .12961 .69457 .1172 Mtetra
.69457 .1172 .70299 .12961 .72095 .12298 .71261 .1105 Mtetra
.663 .738 .905 r
.71261 .1105 .72095 .12298 .73902 .11631 .73076 .10377 Mtetra
.664 .738 .905 r
.73076 .10377 .73902 .11631 .7572 .1096 .74903 .09699 Mtetra
.663 .74 .907 r
.10296 .32239 .11365 .3324 .12817 .32703 .11753 .31696 Mtetra
.11753 .31696 .12817 .32703 .14278 .32162 .13218 .31149 Mtetra
.13218 .31149 .14278 .32162 .15747 .31619 .14692 .30599 Mtetra
.14692 .30599 .15747 .31619 .17225 .31072 .16175 .30046 Mtetra
.16175 .30046 .17225 .31072 .18711 .30523 .17666 .2949 Mtetra
.17666 .2949 .18711 .30523 .20205 .2997 .19165 .2893 Mtetra
.663 .739 .907 r
.19165 .2893 .20205 .2997 .21709 .29414 .20674 .28367 Mtetra
.20674 .28367 .21709 .29414 .23221 .28854 .22191 .27801 Mtetra
.663 .739 .906 r
.22191 .27801 .23221 .28854 .24742 .28291 .23717 .27232 Mtetra
.23717 .27232 .24742 .28291 .26272 .27725 .25253 .26659 Mtetra
.25253 .26659 .26272 .27725 .27811 .27156 .26797 .26083 Mtetra
.26797 .26083 .27811 .27156 .29359 .26583 .2835 .25504 Mtetra
.2835 .25504 .29359 .26583 .30916 .26007 .29913 .2492 Mtetra
.29913 .2492 .30916 .26007 .32482 .25427 .31485 .24334 Mtetra
.31485 .24334 .32482 .25427 .34058 .24844 .33066 .23744 Mtetra
.33066 .23744 .34058 .24844 .35643 .24257 .34657 .2315 Mtetra
.663 .738 .906 r
.34657 .2315 .35643 .24257 .37238 .23667 .36258 .22553 Mtetra
.36258 .22553 .37238 .23667 .38842 .23072 .37868 .21952 Mtetra
.37868 .21952 .38842 .23072 .40456 .22475 .39488 .21347 Mtetra
.39488 .21347 .40456 .22475 .4208 .21873 .41118 .20739 Mtetra
.41118 .20739 .4208 .21873 .43713 .21268 .42757 .20127 Mtetra
.42757 .20127 .43713 .21268 .45356 .20659 .44407 .19511 Mtetra
.44407 .19511 .45356 .20659 .4701 .20046 .46067 .18892 Mtetra
.663 .739 .906 r
.46067 .18892 .4701 .20046 .48673 .19429 .47736 .18268 Mtetra
.47736 .18268 .48673 .19429 .50347 .18809 .49417 .17641 Mtetra
.49417 .17641 .50347 .18809 .52031 .18184 .51107 .1701 Mtetra
.51107 .1701 .52031 .18184 .53725 .17556 .52808 .16375 Mtetra
.52808 .16375 .53725 .17556 .5543 .16924 .5452 .15736 Mtetra
.5452 .15736 .5543 .16924 .57145 .16287 .56242 .15092 Mtetra
.56242 .15092 .57145 .16287 .58871 .15647 .57976 .14445 Mtetra
.57976 .14445 .58871 .15647 .60608 .15003 .5972 .13794 Mtetra
.5972 .13794 .60608 .15003 .62356 .14354 .61475 .13139 Mtetra
.61475 .13139 .62356 .14354 .64115 .13702 .63241 .12479 Mtetra
.663 .74 .907 r
.63241 .12479 .64115 .13702 .65884 .13045 .65018 .11816 Mtetra
.65018 .11816 .65884 .13045 .67665 .12384 .66807 .11148 Mtetra
.664 .74 .907 r
.66807 .11148 .67665 .12384 .69457 .1172 .68607 .10476 Mtetra
.68607 .10476 .69457 .1172 .71261 .1105 .70418 .09799 Mtetra
.70418 .09799 .71261 .1105 .73076 .10377 .72241 .09118 Mtetra
.72241 .09118 .73076 .10377 .74903 .09699 .74076 .08433 Mtetra
.664 .741 .908 r
.09215 .31231 .10296 .32239 .11753 .31696 .10677 .30682 Mtetra
.10677 .30682 .11753 .31696 .13218 .31149 .12147 .30129 Mtetra
.663 .741 .908 r
.12147 .30129 .13218 .31149 .14692 .30599 .13626 .29573 Mtetra
.13626 .29573 .14692 .30599 .16175 .30046 .15113 .29014 Mtetra
.15113 .29014 .16175 .30046 .17666 .2949 .16609 .28451 Mtetra
.16609 .28451 .17666 .2949 .19165 .2893 .18114 .27885 Mtetra
.663 .741 .907 r
.18114 .27885 .19165 .2893 .20674 .28367 .19627 .27316 Mtetra
.19627 .27316 .20674 .28367 .22191 .27801 .2115 .26744 Mtetra
.2115 .26744 .22191 .27801 .23717 .27232 .22681 .26168 Mtetra
.22681 .26168 .23717 .27232 .25253 .26659 .24222 .25589 Mtetra
.24222 .25589 .25253 .26659 .26797 .26083 .25771 .25006 Mtetra
.25771 .25006 .26797 .26083 .2835 .25504 .2733 .2442 Mtetra
.663 .74 .907 r
.2733 .2442 .2835 .25504 .29913 .2492 .28899 .2383 Mtetra
.28899 .2383 .29913 .2492 .31485 .24334 .30476 .23237 Mtetra
.30476 .23237 .31485 .24334 .33066 .23744 .32063 .2264 Mtetra
.32063 .2264 .33066 .23744 .34657 .2315 .3366 .2204 Mtetra
.3366 .2204 .34657 .2315 .36258 .22553 .35267 .21436 Mtetra
.35267 .21436 .36258 .22553 .37868 .21952 .36883 .20828 Mtetra
.36883 .20828 .37868 .21952 .39488 .21347 .38509 .20217 Mtetra
.38509 .20217 .39488 .21347 .41118 .20739 .40144 .19602 Mtetra
.40144 .19602 .41118 .20739 .42757 .20127 .4179 .18983 Mtetra
.4179 .18983 .42757 .20127 .44407 .19511 .43446 .1836 Mtetra
.43446 .1836 .44407 .19511 .46067 .18892 .45113 .17734 Mtetra
.45113 .17734 .46067 .18892 .47736 .18268 .46789 .17103 Mtetra
.46789 .17103 .47736 .18268 .49417 .17641 .48476 .16469 Mtetra
.48476 .16469 .49417 .17641 .51107 .1701 .50173 .1583 Mtetra
.664 .74 .907 r
.50173 .1583 .51107 .1701 .52808 .16375 .51881 .15188 Mtetra
.51881 .15188 .52808 .16375 .5452 .15736 .536 .14542 Mtetra
.664 .741 .907 r
.536 .14542 .5452 .15736 .56242 .15092 .55329 .13891 Mtetra
.55329 .13891 .56242 .15092 .57976 .14445 .5707 .13237 Mtetra
.5707 .13237 .57976 .14445 .5972 .13794 .58821 .12578 Mtetra
.58821 .12578 .5972 .13794 .61475 .13139 .60583 .11915 Mtetra
.60583 .11915 .61475 .13139 .63241 .12479 .62357 .11248 Mtetra
.62357 .11248 .63241 .12479 .65018 .11816 .64142 .10577 Mtetra
.64142 .10577 .65018 .11816 .66807 .11148 .65938 .09902 Mtetra
.664 .741 .908 r
.65938 .09902 .66807 .11148 .68607 .10476 .67746 .09222 Mtetra
.67746 .09222 .68607 .10476 .70418 .09799 .69566 .08537 Mtetra
.69566 .08537 .70418 .09799 .72241 .09118 .71397 .07849 Mtetra
.71397 .07849 .72241 .09118 .74076 .08433 .7324 .07156 Mtetra
.08123 .30213 .09215 .31231 .10677 .30682 .09589 .29658 Mtetra
.09589 .29658 .10677 .30682 .12147 .30129 .11064 .29099 Mtetra
.11064 .29099 .12147 .30129 .13626 .29573 .12548 .28537 Mtetra
.12548 .28537 .13626 .29573 .15113 .29014 .1404 .27972 Mtetra
.1404 .27972 .15113 .29014 .16609 .28451 .15541 .27403 Mtetra
.15541 .27403 .16609 .28451 .18114 .27885 .1705 .26831 Mtetra
.1705 .26831 .18114 .27885 .19627 .27316 .18569 .26256 Mtetra
.18569 .26256 .19627 .27316 .2115 .26744 .20097 .25677 Mtetra
.20097 .25677 .2115 .26744 .22681 .26168 .21633 .25095 Mtetra
.21633 .25095 .22681 .26168 .24222 .25589 .23179 .24509 Mtetra
.23179 .24509 .24222 .25589 .25771 .25006 .24734 .2392 Mtetra
.24734 .2392 .25771 .25006 .2733 .2442 .26299 .23327 Mtetra
.26299 .23327 .2733 .2442 .28899 .2383 .27873 .22731 Mtetra
.27873 .22731 .28899 .2383 .30476 .23237 .29456 .22131 Mtetra
.29456 .22131 .30476 .23237 .32063 .2264 .31049 .21528 Mtetra
.31049 .21528 .32063 .2264 .3366 .2204 .32652 .20921 Mtetra
.32652 .20921 .3366 .2204 .35267 .21436 .34264 .2031 Mtetra
.34264 .2031 .35267 .21436 .36883 .20828 .35886 .19695 Mtetra
.35886 .19695 .36883 .20828 .38509 .20217 .37518 .19077 Mtetra
.37518 .19077 .38509 .20217 .40144 .19602 .3916 .18455 Mtetra
.3916 .18455 .40144 .19602 .4179 .18983 .40812 .17829 Mtetra
.40812 .17829 .4179 .18983 .43446 .1836 .42475 .17199 Mtetra
.42475 .17199 .43446 .1836 .45113 .17734 .44148 .16565 Mtetra
.44148 .16565 .45113 .17734 .46789 .17103 .45831 .15928 Mtetra
.45831 .15928 .46789 .17103 .48476 .16469 .47524 .15286 Mtetra
.47524 .15286 .48476 .16469 .50173 .1583 .49228 .1464 Mtetra
.49228 .1464 .50173 .1583 .51881 .15188 .50943 .13991 Mtetra
.50943 .13991 .51881 .15188 .536 .14542 .52669 .13337 Mtetra
.52669 .13337 .536 .14542 .55329 .13891 .54406 .12679 Mtetra
.54406 .12679 .55329 .13891 .5707 .13237 .56153 .12017 Mtetra
.56153 .12017 .5707 .13237 .58821 .12578 .57912 .11351 Mtetra
.57912 .11351 .58821 .12578 .60583 .11915 .59682 .1068 Mtetra
.59682 .1068 .60583 .11915 .62357 .11248 .61463 .10005 Mtetra
.61463 .10005 .62357 .11248 .64142 .10577 .63255 .09326 Mtetra
.63255 .09326 .64142 .10577 .65938 .09902 .6506 .08642 Mtetra
.6506 .08642 .65938 .09902 .67746 .09222 .66875 .07954 Mtetra
.66875 .07954 .67746 .09222 .69566 .08537 .68703 .07262 Mtetra
.68703 .07262 .69566 .08537 .71397 .07849 .70542 .06565 Mtetra
.70542 .06565 .71397 .07849 .7324 .07156 .72394 .05864 Mtetra
.07019 .29185 .08123 .30213 .09589 .29658 .0849 .28624 Mtetra
.0849 .28624 .09589 .29658 .11064 .29099 .09969 .28059 Mtetra
.09969 .28059 .11064 .29099 .12548 .28537 .11458 .27491 Mtetra
.11458 .27491 .12548 .28537 .1404 .27972 .12955 .26919 Mtetra
.12955 .26919 .1404 .27972 .15541 .27403 .14461 .26344 Mtetra
.14461 .26344 .15541 .27403 .1705 .26831 .15975 .25766 Mtetra
.15975 .25766 .1705 .26831 .18569 .26256 .17499 .25184 Mtetra
.17499 .25184 .18569 .26256 .20097 .25677 .19032 .24599 Mtetra
.19032 .24599 .20097 .25677 .21633 .25095 .20574 .24011 Mtetra
.20574 .24011 .21633 .25095 .23179 .24509 .22125 .23419 Mtetra
.22125 .23419 .23179 .24509 .24734 .2392 .23686 .22823 Mtetra
.23686 .22823 .24734 .2392 .26299 .23327 .25256 .22224 Mtetra
.25256 .22224 .26299 .23327 .27873 .22731 .26835 .21621 Mtetra
.26835 .21621 .27873 .22731 .29456 .22131 .28424 .21014 Mtetra
.28424 .21014 .29456 .22131 .31049 .21528 .30023 .20404 Mtetra
.30023 .20404 .31049 .21528 .32652 .20921 .31632 .1979 Mtetra
.31632 .1979 .32652 .20921 .34264 .2031 .3325 .19172 Mtetra
.3325 .19172 .34264 .2031 .35886 .19695 .34878 .1855 Mtetra
.34878 .1855 .35886 .19695 .37518 .19077 .36516 .17925 Mtetra
.36516 .17925 .37518 .19077 .3916 .18455 .38165 .17296 Mtetra
.38165 .17296 .3916 .18455 .40812 .17829 .39823 .16663 Mtetra
.39823 .16663 .40812 .17829 .42475 .17199 .41492 .16026 Mtetra
.41492 .16026 .42475 .17199 .44148 .16565 .43171 .15385 Mtetra
.43171 .15385 .44148 .16565 .45831 .15928 .44861 .1474 Mtetra
.44861 .1474 .45831 .15928 .47524 .15286 .46562 .14091 Mtetra
.46562 .14091 .47524 .15286 .49228 .1464 .48273 .13437 Mtetra
.48273 .13437 .49228 .1464 .50943 .13991 .49994 .1278 Mtetra
.49994 .1278 .50943 .13991 .52669 .13337 .51727 .12119 Mtetra
.51727 .12119 .52669 .13337 .54406 .12679 .53471 .11453 Mtetra
.53471 .11453 .54406 .12679 .56153 .12017 .55226 .10783 Mtetra
.55226 .10783 .56153 .12017 .57912 .11351 .56992 .10109 Mtetra
.56992 .10109 .57912 .11351 .59682 .1068 .58769 .09431 Mtetra
.58769 .09431 .59682 .1068 .61463 .10005 .60558 .08748 Mtetra
.60558 .08748 .61463 .10005 .63255 .09326 .62358 .0806 Mtetra
.62358 .0806 .63255 .09326 .6506 .08642 .6417 .07369 Mtetra
.6417 .07369 .6506 .08642 .66875 .07954 .65994 .06672 Mtetra
.65994 .06672 .66875 .07954 .68703 .07262 .6783 .05972 Mtetra
.6783 .05972 .68703 .07262 .70542 .06565 .69678 .05266 Mtetra
.69678 .05266 .70542 .06565 .72394 .05864 .71537 .04557 Mtetra
.05902 .28146 .07019 .29185 .0849 .28624 .07378 .27578 Mtetra
.07378 .27578 .0849 .28624 .09969 .28059 .08863 .27007 Mtetra
.08863 .27007 .09969 .28059 .11458 .27491 .10356 .26433 Mtetra
.10356 .26433 .11458 .27491 .12955 .26919 .11858 .25855 Mtetra
.11858 .25855 .12955 .26919 .14461 .26344 .13369 .25274 Mtetra
.13369 .25274 .14461 .26344 .15975 .25766 .14889 .2469 Mtetra
.14889 .2469 .15975 .25766 .17499 .25184 .16417 .24101 Mtetra
.16417 .24101 .17499 .25184 .19032 .24599 .17956 .2351 Mtetra
.17956 .2351 .19032 .24599 .20574 .24011 .19503 .22915 Mtetra
.19503 .22915 .20574 .24011 .22125 .23419 .2106 .22316 Mtetra
.2106 .22316 .22125 .23419 .23686 .22823 .22626 .21714 Mtetra
.22626 .21714 .23686 .22823 .25256 .22224 .24201 .21107 Mtetra
.24201 .21107 .25256 .22224 .26835 .21621 .25786 .20498 Mtetra
.25786 .20498 .26835 .21621 .28424 .21014 .27381 .19884 Mtetra
.27381 .19884 .28424 .21014 .30023 .20404 .28986 .19267 Mtetra
.28986 .19267 .30023 .20404 .31632 .1979 .306 .18646 Mtetra
.306 .18646 .31632 .1979 .3325 .19172 .32224 .18021 Mtetra
.32224 .18021 .3325 .19172 .34878 .1855 .33859 .17393 Mtetra
.33859 .17393 .34878 .1855 .36516 .17925 .35503 .1676 Mtetra
.35503 .1676 .36516 .17925 .38165 .17296 .37158 .16124 Mtetra
.37158 .16124 .38165 .17296 .39823 .16663 .38823 .15483 Mtetra
.38823 .15483 .39823 .16663 .41492 .16026 .40498 .14839 Mtetra
.40498 .14839 .41492 .16026 .43171 .15385 .42184 .14191 Mtetra
.42184 .14191 .43171 .15385 .44861 .1474 .4388 .13538 Mtetra
.4388 .13538 .44861 .1474 .46562 .14091 .45588 .12881 Mtetra
.45588 .12881 .46562 .14091 .48273 .13437 .47306 .12221 Mtetra
.47306 .12221 .48273 .13437 .49994 .1278 .49034 .11556 Mtetra
.49034 .11556 .49994 .1278 .51727 .12119 .50774 .10886 Mtetra
.50774 .10886 .51727 .12119 .53471 .11453 .52525 .10213 Mtetra
.52525 .10213 .53471 .11453 .55226 .10783 .54287 .09535 Mtetra
.54287 .09535 .55226 .10783 .56992 .10109 .56061 .08853 Mtetra
.56061 .08853 .56992 .10109 .58769 .09431 .57846 .08166 Mtetra
.57846 .08166 .58769 .09431 .60558 .08748 .59643 .07475 Mtetra
.59643 .07475 .60558 .08748 .62358 .0806 .61451 .0678 Mtetra
.61451 .0678 .62358 .0806 .6417 .07369 .63271 .0608 Mtetra
.63271 .0608 .6417 .07369 .65994 .06672 .65103 .05375 Mtetra
.65103 .05375 .65994 .06672 .6783 .05972 .66946 .04666 Mtetra
.66946 .04666 .6783 .05972 .69678 .05266 .68802 .03952 Mtetra
.68802 .03952 .69678 .05266 .71537 .04557 .70671 .03234 Mtetra
.04774 .27095 .05902 .28146 .07378 .27578 .06255 .26522 Mtetra
.06255 .26522 .07378 .27578 .08863 .27007 .07744 .25944 Mtetra
.07744 .25944 .08863 .27007 .10356 .26433 .09242 .25364 Mtetra
.09242 .25364 .10356 .26433 .11858 .25855 .10749 .2478 Mtetra
.10749 .2478 .11858 .25855 .13369 .25274 .12265 .24192 Mtetra
.12265 .24192 .13369 .25274 .14889 .2469 .1379 .23601 Mtetra
.1379 .23601 .14889 .2469 .16417 .24101 .15324 .23006 Mtetra
.15324 .23006 .16417 .24101 .17956 .2351 .16867 .22408 Mtetra
.16867 .22408 .17956 .2351 .19503 .22915 .1842 .21806 Mtetra
.1842 .21806 .19503 .22915 .2106 .22316 .19982 .21201 Mtetra
.19982 .21201 .2106 .22316 .22626 .21714 .21553 .20592 Mtetra
.21553 .20592 .22626 .21714 .24201 .21107 .23135 .19979 Mtetra
.23135 .19979 .24201 .21107 .25786 .20498 .24725 .19362 Mtetra
.24725 .19362 .25786 .20498 .27381 .19884 .26326 .18742 Mtetra
.26326 .18742 .27381 .19884 .28986 .19267 .27936 .18118 Mtetra
.27936 .18118 .28986 .19267 .306 .18646 .29557 .1749 Mtetra
.29557 .1749 .306 .18646 .32224 .18021 .31187 .16858 Mtetra
.31187 .16858 .32224 .18021 .33859 .17393 .32828 .16222 Mtetra
.32828 .16222 .33859 .17393 .35503 .1676 .34478 .15582 Mtetra
.34478 .15582 .35503 .1676 .37158 .16124 .36139 .14938 Mtetra
.36139 .14938 .37158 .16124 .38823 .15483 .37811 .14291 Mtetra
.37811 .14291 .38823 .15483 .40498 .14839 .39493 .13639 Mtetra
.39493 .13639 .40498 .14839 .42184 .14191 .41185 .12983 Mtetra
.41185 .12983 .42184 .14191 .4388 .13538 .42888 .12323 Mtetra
.42888 .12323 .4388 .13538 .45588 .12881 .44602 .11658 Mtetra
.44602 .11658 .45588 .12881 .47306 .12221 .46327 .1099 Mtetra
.46327 .1099 .47306 .12221 .49034 .11556 .48063 .10317 Mtetra
.48063 .10317 .49034 .11556 .50774 .10886 .4981 .0964 Mtetra
.4981 .0964 .50774 .10886 .52525 .10213 .51568 .08958 Mtetra
.51568 .08958 .52525 .10213 .54287 .09535 .53338 .08272 Mtetra
.53338 .08272 .54287 .09535 .56061 .08853 .55119 .07582 Mtetra
.55119 .07582 .56061 .08853 .57846 .08166 .56912 .06887 Mtetra
.56912 .06887 .57846 .08166 .59643 .07475 .58716 .06188 Mtetra
.58716 .06188 .59643 .07475 .61451 .0678 .60532 .05484 Mtetra
.60532 .05484 .61451 .0678 .63271 .0608 .6236 .04775 Mtetra
.6236 .04775 .63271 .0608 .65103 .05375 .642 .04062 Mtetra
.642 .04062 .65103 .05375 .66946 .04666 .66052 .03344 Mtetra
.66052 .03344 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.03634 .26033 .04774 .27095 .06255 .26522 .05119 .25453 Mtetra
.05119 .25453 .06255 .26522 .07744 .25944 .06613 .2487 Mtetra
.06613 .2487 .07744 .25944 .09242 .25364 .08116 .24283 Mtetra
.08116 .24283 .09242 .25364 .10749 .2478 .09628 .23692 Mtetra
.09628 .23692 .10749 .2478 .12265 .24192 .11148 .23098 Mtetra
.11148 .23098 .12265 .24192 .1379 .23601 .12679 .225 Mtetra
.12679 .225 .1379 .23601 .15324 .23006 .14218 .21899 Mtetra
.14218 .21899 .15324 .23006 .16867 .22408 .15767 .21294 Mtetra
.15767 .21294 .16867 .22408 .1842 .21806 .17325 .20686 Mtetra
.17325 .20686 .1842 .21806 .19982 .21201 .18892 .20073 Mtetra
.18892 .20073 .19982 .21201 .21553 .20592 .20469 .19457 Mtetra
.20469 .19457 .21553 .20592 .23135 .19979 .22056 .18838 Mtetra
.22056 .18838 .23135 .19979 .24725 .19362 .23652 .18214 Mtetra
.23652 .18214 .24725 .19362 .26326 .18742 .25259 .17587 Mtetra
.25259 .17587 .26326 .18742 .27936 .18118 .26875 .16955 Mtetra
.26875 .16955 .27936 .18118 .29557 .1749 .28501 .1632 Mtetra
.28501 .1632 .29557 .1749 .31187 .16858 .30138 .15681 Mtetra
.30138 .15681 .31187 .16858 .32828 .16222 .31785 .15038 Mtetra
.31785 .15038 .32828 .16222 .34478 .15582 .33442 .14391 Mtetra
.33442 .14391 .34478 .15582 .36139 .14938 .35109 .13739 Mtetra
.35109 .13739 .36139 .14938 .37811 .14291 .36787 .13084 Mtetra
.36787 .13084 .37811 .14291 .39493 .13639 .38475 .12424 Mtetra
.38475 .12424 .39493 .13639 .41185 .12983 .40174 .11761 Mtetra
.40174 .11761 .41185 .12983 .42888 .12323 .41884 .11093 Mtetra
.41884 .11093 .42888 .12323 .44602 .11658 .43605 .10421 Mtetra
.43605 .10421 .44602 .11658 .46327 .1099 .45337 .09744 Mtetra
.45337 .09744 .46327 .1099 .48063 .10317 .4708 .09063 Mtetra
.4708 .09063 .48063 .10317 .4981 .0964 .48835 .08378 Mtetra
.48835 .08378 .4981 .0964 .51568 .08958 .506 .07688 Mtetra
.506 .07688 .51568 .08958 .53338 .08272 .52377 .06994 Mtetra
.52377 .06994 .53338 .08272 .55119 .07582 .54166 .06296 Mtetra
.54166 .06296 .55119 .07582 .56912 .06887 .55966 .05592 Mtetra
.55966 .05592 .56912 .06887 .58716 .06188 .57778 .04885 Mtetra
.57778 .04885 .58716 .06188 .60532 .05484 .59602 .04172 Mtetra
.59602 .04172 .60532 .05484 .6236 .04775 .61438 .03455 Mtetra
.61438 .03455 .6236 .04775 .642 .04062 .63286 .02733 Mtetra
.63286 .02733 .642 .04062 .66052 .03344 .65147 .02007 Mtetra
.65147 .02007 .66052 .03344 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonDo`0003?oooooU?l0000Kooooo`006_oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool02_ooool30000
00[ooooo0`00000;ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool03_l0000:01TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<
C4`01@1<C4`00ol00000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00L0Ogmo0`00000@09VIV@<0
00002@1oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00L0C4a<00?o000003<c<`0c
<c<01@0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000X000000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00ol0003oooooooooo`0=o`0000X06ATI00?o000003<c<`0c<c<01`0c<c<00ol00000C4a<
04a<C00404a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI
09VIV@0D09VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH00ol00000C4a<
04a<C00604a<C003o`00000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT0200I6AT00ol000000000
00000009000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`0000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool03Ol0000:01TI6@03o`00000c
<c<0<c<c00H0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0506IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT05P2IVIT00`000000Ogmo07moO`0707moO`030000001V
IVH0IVIV00D0IVIV00?o000004a<C01<C4`01@1<C4`00ol00000<c<c03<c<`0603<c<`03o`00000I
6AT06ATI00P06ATI00?o00000000000000002@000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00go00002P0I6AT00ol00000<c<c03<c<`0603<c<`03o`00001<C4`0C4a<00D0C4a<00?o0000
06IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0707moO`0300000?l00000VIVI01L0VIVI00?o0000
0000001oOgl01`1oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00D0C4a<00?o0000
03<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000T000000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0=o`0000X06ATI00?o000003<c<`0c<c<01@0c<c<00ol0
0000C4a<04a<C00504a<C003o`00001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01P1oOgl00`00
0000VIVI09VIV@0J09VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01@1VIVH00ol0
0000C4a<04a<C00504a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I6AT00ol0
0000000000000009000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=o`00
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool03?l0000:01TI6@03
o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0702IVIT00`000000Ogmo07moO`0507moO`03
0000001VIVH0IVIV00D0IVIV00?o000004a<C01<C4`01@1<C4`00ol00000<c<c03<c<`0603<c<`03
o`00000I6AT06ATI00P06ATI00?o000000000000000020000003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00co00002P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00D0C4a<
00?o000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI01h0VIVI
00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00D0C4a<
00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000P00000
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`0<o`0000X06ATI00?o000003<c<`0c<c<01@0c
<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1o
Ogl00`000000VIVI09VIV@0P09VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1V
IVH00ol00000C4a<04a<C00504a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I
6AT00ol00000000000000008000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02ol0000:
01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0302IVIT8000000h0VIVI00<00000
07moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00D0C4a<00?o0000
03<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000P000000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0;o`0000X06ATI00?o000003<c<`0c<c<01@0c<c<00ol0
0000C4a<04a<C00404a<C003o`00001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`00
0000VIVI09VIV@0909VIV@@00000202c/k<4000000/0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol0
00006ATI01TI6@0801TI6@03o`0000000000000000L000000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`0;o`0000X06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003
o`00001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0809VIV@03
0000002c/k<0/k>c00h0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0507moO`03
o`00001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03
o`00000I6AT06ATI00P06ATI00?o00000000000000001`000003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00_o00002P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<
00?o000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI
0P00000B0;>c/`800000202IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV
00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00P06ATI
00?o00000000000000001`000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00[o00002P0I
6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0101V
IVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0502c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101V
IVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I
6AT00ol00000000000000006000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02_l0000:
01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`0F
0;>c/`03o`00002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP04
06IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@08
01TI6@03o`0000000000000000H000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0:o`00
00X06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV
00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c
01H0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00@0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00P06ATI00?o00000000000000001P000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00[o
00002P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c
/k<0602c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH00`1VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT0200I6AT00ol00000000000000006000000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
2_l0000901TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c
0;>c/`0J0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV
06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI
01TI6@0701TI6@03o`0000000000000000H000000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`0:o`0000T06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c
/k<0/k>c01`0/k>c00?o000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001V
IVH0IVIV00<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I
6AT06ATI00L06ATI00?o00000000000000001P000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00[o00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00?o0000
0;>c/`2c/k<02P2c/k<8000000`0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`04
07moO`03o`00001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`05
03<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000001P000003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo00Wo00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<
00@0C4a<00?o000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
00@0VIVI00<000000;>c/`2c/k<0202c/k<3000000P0c<c<0`00000:0;>c/`030000002IVIT0VIVI
00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<
00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0701TI6@03o`00000000000000
00D000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09o`0000T06ATI00?o000003<c<`0c
<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<
c<`0303<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0306IVIP;o00001@1<C4`00ol00000<c<c03<c<`0503<c<`03
o`00000I6AT06ATI00L06ATI00?o00000000000000001@000003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00Wo00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<
00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00>0<c<c0030000002c/k<0/k>c00L0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV
00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI
00?o00000000000000001@000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Wo00002@0I
6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0101V
IVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01`2c
/k<00`000000c<c<0<c<c00@0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT0102I
VIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`0101<
C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000001@00
0003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`05
03<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00B
0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`05
03<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<
00<0C4a<00?o000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
00<0VIVI00?o00000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00D0<c<c003o`00002c/k<0/k>c
00D0/k>c00?o00000000002IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV
00@0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00L06ATI00?o000000000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So
00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1V
IVH0101VIVH00`000000Ogmo07moO`0207moO`03o`00002IVIT0VIVI00@0VIVI00<000000;>c/`2c
/k<01@2c/k<00ol00000c<c<0<c<c00F0<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2I
VIT0102IVIT00ol00000Ogmo07moO`0207moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000
000010000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c
03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<
0<c<c00F0<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c00H0<c<c0030000002c
/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`030000001V
IVH0IVIV00<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I
6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00So00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<0102c/k<00`000000c<c<0<c<c00J0<c<c0030000002c/k<0/k>c00@0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o0000
04a<C01<C4`0101<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o0000
00000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol0
0000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00P1VIVH00ol0
0000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`00
0000c<c<0<c<c00J0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`00
0000Ogmo07moO`0307moO`03o`00001VIVH0IVIV0080IVIV00?o000004a<C01<C4`0101<C4`00ol0
0000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000000010000003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00Oo00002@0I6AT00ol00000<c<c03<c<`0403<c<`03
o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0090<c<c0P0
00002`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000<000000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00ol0003oooooooooo`07o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<
04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01`3<c<`00`00003o0000
000000080>KViP<000002@3<c<`00`000000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00@0C4a<
00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`0000000000000000<00000
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`07o`0000T06ATI00?o000003<c<`0c<c<0100c
<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1o
Ogl00`000000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<
c<`00`000000i^KV0>KViP0<0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0102c
/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1V
IVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I
6AT00ol00000000000000003000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01ol00009
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`03
0;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c006
0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`04
03<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000000`000003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo00Oo0000200I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<
00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI
00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV
0100i^KV00?o00000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI
00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<
00<0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0601TI6@03o`00000000000000
00<000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`07o`0000P06ATI00?o000003<c<`0c
<c<01@0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<
c<`01P3<c<`00ol00000i^KV0>KViP0@0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c
/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00`1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT01P0I6AT00ol00000000000000003000000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
1ol0000801TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H04P3Vi^H00`000000c<c<
0<c<c0050<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0503<c<`03o`00000I6AT06ATI00H06ATI00?o00000000000000000`000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00Ko00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c0030000003V
i^H0i^KV01@0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`030;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<
C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`000000
00000000008000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go00000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`06o`0000T06ATI00?o0000
03<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<00000
0<c<c03<c<`0103<c<`00`000000i^KV0>KViP0F0>KViP03o`00003<c<`0c<c<00@0c<c<00?o0000
0;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@03o`00001oOgl0Ogmo0080Ogmo00<00000
06IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o0000
01TI6@0I6AT01`0I6AT00ol00000000000000002000000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool01_l0000901TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol0
0000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`00
0000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H05P3Vi^H00`00
0000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`00
0000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol0
0000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000000P000003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00Ko00002@0I6AT00ol00000<c<c03<c<`0403<c<`03
o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003
0000003Vi^H0i^KV01H0i^KV00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`03
0000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03
o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03
o`00000000000000008000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08go
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`06o`0000T06ATI
00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV
00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c
00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP0H0>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT01P0I6AT00ol00000000000000002000000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool01_l0000801TI6@;o00001P0c<c<00ol00000C4a<04a<C00304a<C003o`00001V
IVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c
/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP0J0>KViP030000003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001o
Ogl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c
<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01P0I6AT00ol00000000000000002000000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0ho`0001h06ATI=ol00003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Ko0000200I6AT00ol00000<c<c03<c<`05
03<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c003
0<c<c0030000003Vi^H0i^KV01X0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@06
01TI6@03o`00000000000000008000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo02;o0000BP0I6ATQo`0000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool01_l0000801TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<C4`00ol0
0000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00D0000009VIV@2IVIT0VIVI00000006
0;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H02@3Vi^H6o`0000/0i^KV00<00000
0<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`040;>c/`050000002IVIT0VIVI09VIV@0000001@1o
Ogl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<01@0c
<c<00ol000006ATI01TI6@0601TI6@03o`00000000000000008000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01_o0000G00I6ATFo`0000?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool01_l0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o0000
04a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00<00000
0>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`040?ooo`03o`00003Vi^H0i^KV00T0i^KV00<00000
0<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00<0C4a<00?o0000
03<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@03o`00000000000000008000000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo013o0000KP0I6AT?o`0000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool01_l0000801TI6@03o`00000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo
0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<
00<0c<c<00<000000>KViP3Vi^H01`3Vi^H2o`0000P0oooo0_l000090>KViP030000003<c<`0c<c<
00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c
00@0<c<c00?o000001TI6@0I6AT01P0I6AT00ol00000000000000002000000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0:o`0002/06ATI9Ol0000[01TI6@So00000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`06o`0000P06ATI00?o000003<c<`0c
<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<
c<`00`3<c<`00`000000i^KV0>KViP070>KViP03o`00003oool0oooo00P0oooo00?o00000>KViP3V
i^H01`3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0307moO`03o`00001VIVH0IVIV0080IVIV00?o000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00?o000000000000
00000P000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_l0000T01TI6@oo
00009@0c<c<>o`0002@06ATI0_l00002ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00Go00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<
00?o000006IVIP1VIVH00`1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c
/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3o
ool02P3oool00ol00000i^KV0>KViP070>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c
/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I
6AT01`0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool06`0I6AT;o`000480<c<c2ol0000J01TI6@?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool01Ol0000901TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<
C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H01P3Vi^H00ol00000oooo0?ooo`0<0?ooo`03o`00003Vi^H0i^KV00H0i^KV00<000000<c<c03<
c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c
<c<0100c<c<00ol000006ATI01TI6@0701TI6@04o`00000000000000000000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0D01TI6@Oo00007@0c<c<No`0001d0<c<c1ol0000C01TI
6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol0000901TI6@03
o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`03
0000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01P3Vi^H00ol00000oooo0?ooo`0<0?ooo`03
o`00003Vi^H0i^KV00H0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`03
0000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03
o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@04
o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@01TI
6@Co00005P0c<c<>o`0001h0C4a<3ol0000E03<c<`Co00003`0I6AT3ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00Go00002@0I6AT00ol00000<c<c03<c<`0403<c<`03
o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`03
0000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003
0000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV0>KViP050>KViP03
0000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003
o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT01?l000000000000000000003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool02@0I6AT7o`000180<c<c2?l0000k04a<
C0Oo00004P0c<c<7o`0000P06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`05o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003
o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@03
0000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP050>KViP03
o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0030<c<c003
0000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03
0000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0403<c<`03
o`00000I6AT06ATI00L06ATI00Co000000000000000000000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00H06ATI0ol0000B03<c<`Oo00003`1<C4`/o`0000l0C4a<1ol0000B03<c
<`Co0000100I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Go
00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1V
IVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c
/k<00P2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3o
ool0403oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00?o00000;>c/`2c
/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00`1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I
6AT01`0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool00P0I6AT4o`0000h0<c<c1ol0000;04a<C0_o0000;01VIVH;o`0000/0C4a<1ol0000?03<c
<`?o000000D06ATIooooooooooooooooo`00000Kooooo`006_ooool00ol0003oooooooooo`05o`00
00T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV
0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c
0080/k>c00?o00000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo
0100oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c
0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
00<0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI
00L06ATI00Co000000000000000000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00;o00003P0c<c<4o`0000/0C4a<1ol0000?06IVIRD000003P1VIVH7o`0000/0C4a<1?l0000>
03<c<`;o00000_ooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`05o`00
00P06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<00000
0<c<c03<c<`00P3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo0180oooo00?o0000
0>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o0000
04a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co0000
00000000000000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00d0<c<c0ol0
000;04a<C0Co00002`1VIVH;000002D0Ogmo2`00000:06IVIPCo00002`1<C4`3o`0000`0<c<c0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`05o`0000P06ATI00?o0000
03<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<c<`00P3<
c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H01@3V
i^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<
C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co00000000000000000000
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00L0<c<c1_l0000704a<C0Oo0000
1`1VIVH00`00003o0000o`000005000000X0Ogmo9@0000000ol00000Ogmo07moO`0907moO`@00000
00?o00000000000000001`1VIVH8o`0000H0C4a<1_l0000603<c<`?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o
000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00D0
000009VIV@2IVIT0VIVI000000050;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0
1@3Vi^H00ol00000oooo0?ooo`0B0?ooo`03o`00003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`0
0P3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0
100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0603<c<`;o0000201<C4`4o`0000/0IVIV0`00000807moO`T0
000000?o000009VIV@2IVIT0902IVIT;000000L0Ogmo0`00000<06IVIP?o0000201<C4`3o`0000@0
<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`05o`0000P06ATI
00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV
00<0000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<
c<`00P3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3V
i^H01@3Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co000000000000
000000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0080<c<c1?l0000704a<
C0?o0000201VIVH7000000L0Ogmo1000000;09VIVBD000002`2IVIT3000000L0Ogmo2000000706IV
IP?o0000201<C4`3o`00000503<c<oooooooooooooooool000006oooool001[ooooo00?o0000oooo
ooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol0
0000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`00
0000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H0103Vi^H00ol0
0000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00`3<c<`00`00
0000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`00
0000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol0
00006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`02o`0000P0C4a<0ol0000806IVIP<000001`1oOgl7000000L0VIVI2000000U
0;>c/`L000001`2IVIT7000000P0Ogmo0P00000806IVIP?o0000201<C4`2o`0000;ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<
00<0c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV
00@0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<
00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000
000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0804a<C0;o00002@1VIVH2
000000H0Ogmo0P0000000ol00000000009VIV@0609VIV@80000000?o00000000000000000P000008
0;>c/`@000000_l0000H00000003o`0000000000000000@000001`2c/k<300000004o`0000000000
0000000000L0VIVI00Co000000000000000000001P1oOgl2000000T0IVIV0_l0000704a<C0?ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c
<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<00<0c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003V
i^H0i^KV00@0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<
C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`000000
00000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0604a<C0;o0000
201VIVH200000003o`00001oOgl0Ogmo00<0Ogmo0`00000709VIV@@000001`2c/k<8000000h0c<c<
2?l0000?0<c<c0L000001`2c/k<4000000L0VIVI0`00000507moO`<00000201VIVH2o`0000D0C4a<
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`05o`0000P06ATI00?o
000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<0
00000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo01@0oooo00?o
00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0
000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o
000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co
000000000000000000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00D0C4a<
00?o000006IVIP1VIVH01@1VIVH3000000L0Ogmo00<0000009VIV@2IVIT01@2IVIT3000000P0/k>c
0`00000;0<c<c0_o0000203Vi^H;o`0000/0c<c<100000070;>c/`800000202IVIT00`000000Ogmo
07moO`0507moO`800000201VIVH00ol00000C4a<04a<C00204a<C0?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o
000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<0
00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<0
00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0304a<C0;o00001`1VIVH00`000000Ogmo
07moO`0607moO`8000001`2IVIT00`000000/k>c0;>c/`060;>c/`<00000203<c<`6o`0001h0i^KV
1_l000090<c<c08000001`2c/k<2000000L0VIVI0P00000707moO`030000001VIVH0IVIV00H0IVIV
0_l0000204a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol0
000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000oooo0?oo
o`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c
/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IV
IP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI
6@0601TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0204a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01@1oOgl2000000L0VIVI
0P0000050;>c/`@000001`3<c<`4o`0000d0i^KV4?l0000=0>KViPCo00001`3<c<`3000000H0/k>c
0P00000709VIV@8000001P1oOgl00ol00000000006IVIP0706IVIP03o`00001<C4cooooo00;ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c
<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<00<0c<c<00<000000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00003V
i^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<
C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`000000
00000000000000?ooooo00?o0000ooooooooool0<Oooool01Ol0003oooooooooo`1<C4co000000P0
IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@8000001P2c/k<00`000000
c<c<0<c<c0070<c<c0;o00002P3Vi^H7o`000100oooo1ol0000:0>KViP;o0000203<c<`00`000000
/k>c0;>c/`050;>c/`8000001`2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00H0
IVIV00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00ol0003oooooooooo`05o`0000P0
6ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080
/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo01H0
oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080
IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H0
6ATI00Co000000000000000000000oooool00ol0003oooooooooo`0aooooo`04o`000?oooooooooo
o`0000P0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0
/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`2o`0000T0i^KV0ol0000N0?ooo`Co0000203Vi^H2
o`0000L0c<c<00<000000;>c/`2c/k<01P2c/k<00ol00000VIVI09VIV@0509VIV@030000001oOgl0
Ogmo00D0Ogmo00<0000006IVIP1VIVH01P1VIVH01?l0003oooooooooool0000Kooooo`006_ooool0
0ol0003oooooooooo`05o`0000P06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C003
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP04
0>KViP03o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c002
0<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`04
03<c<`03o`00000I6AT06ATI00H06ATI00Co000000000000000000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00P0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0509VIV@03o`00002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`2o`0000T0i^KV0_l0
000U0?ooo`03o`00003Vi^H0i^KV00L0i^KV00?o00000<c<c03<c<`01@3<c<`00ol0000000000;>c
/`060;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0506IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol00008
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F
0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@06
01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0806IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H0203Vi^H00ol00000oooo0?oo
o`0T0?ooo`03o`00003Vi^H0i^KV00L0i^KV00?o00000<c<c03<c<`01P3<c<`00`000000/k>c0;>c
/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0506IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol00008
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F
0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@06
01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0806IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H0203Vi^H00ol00000oooo0?oo
o`0T0?ooo`03o`00003Vi^H0i^KV00L0i^KV00?o00000<c<c03<c<`01P3<c<`00`000000/k>c0;>c
/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0506IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol00008
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F
0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@06
01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0806IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H0203Vi^H00ol00000oooo0?oo
o`0T0?ooo`03o`00003Vi^H0i^KV00L0i^KV00?o00000<c<c03<c<`01P3<c<`00`000000/k>c0;>c
/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IV
IP0506IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol00008
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP02
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F
0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`02
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@06
01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0806IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<00D0c<c<0_l000090>KViP?o00008`3oool2o`0000T0i^KV00?o
00000<c<c03<c<`01P3<c<`00ol00000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0
000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o0000
04a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080c<c<00<00000
0>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<00000
0<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o0000
03<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo00?o
0000ooooooooool0<Oooool01?l0003oooooooooool0000806IVIP030000001oOgl0Ogmo00D0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`03o`0000000000c<c<00L0c<c<
00?o00000>KViP3Vi^H02@3Vi^H3o`0001`0oooo1?l0000:0>KViP03o`00003<c<`0c<c<00D0c<c<
0P0000080;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV
06IVIP0606IVIP04o`000?ooooooooooo`0001_ooooo000Jooooo`03o`000?oooooooooo00Go0000
200I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0
5P3oool00ol00000i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<0
0P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0
1P0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooo
oooo00002@1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI0P0000070;>c
/`8000001`3<c<`3o`0000/0i^KV1?l0000D0?ooo`Co00002`3Vi^H3o`0000L0c<c<00<000000;>c
/`2c/k<01P2c/k<2000000H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0706IV
IP04o`000?ooooooooooo`0001_ooooo000Jooooo`03o`000?oooooooooo00Go0000200I6AT00ol0
0000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool05@3oool00ol0
0000i^KV0>KViP040>KViP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`00
0000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol0
0000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01P0I6AT01?l0
00000000000000000003ooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooool0C4a<o`00
000906IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01@2IVIT2000000L0/k>c0P00
00080<c<c0?o0000303Vi^HDo`0000`0i^KV0ol000080<c<c08000001`2c/k<2000000L0VIVI00<0
000007moO`1oOgl01@1oOgl00ol00000IVIV06IVIP0706IVIP05o`000?ooooooooooooooool00000
6oooool001[ooooo00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o
000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<0
00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0E0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<0
00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0204a<C0;o00001`1VIVH00ol000000000
0000000607moO`@000001@2IVIT3000000H0/k>c1@0000060<c<c0Go00008`3Vi^H4o`0000L0c<c<
100000060;>c/`<000001@2IVIT4000000H0Ogmo0P00000806IVIP;o000000D0C4a<oooooooooooo
ooooo`00000Kooooo`006_ooool00ol0003oooooooooo`05o`0000P06ATI00?o000003<c<`0c<c<0
100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl0
0P1oOgl00ol00000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0
0`3<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0oooo01D0oooo00?o00000>KViP3Vi^H0
103Vi^H00`000000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT0
0P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`0
0`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co0000000000000000
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00@0C4a<0_l0000806IVIP80
0000201oOgl00`000000VIVI09VIV@0509VIV@<00000202c/k<3000000P0c<c<1ol0000D0>KViPSo
00001`3<c<`4000000L0/k>c0`00000709VIV@030000001oOgl0Ogmo00D0Ogmo0`00000806IVIP;o
00000`1<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Go0000
200I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0
503oool00ol00000i^KV0>KViP040>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT0
1P0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01P1<C4`00ol00000IVIV06IVIP0706IVIP8000001`1oOgl3000000L0VIVI100000070;>c/`@0
00002`3<c<`Do`0000/0c<c<100000070;>c/`@000001`2IVIT3000000L0Ogmo00<0000006IVIP1V
IVH0201VIVH00ol00000C4a<04a<C00304a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo
00?o0000ooooooooool01Ol0000801TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`0
0`1<C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT0
0P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H0
103Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`0
0`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00?o000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0
100c<c<00ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0704a<C0Co00001`1VIVH01000003o000000000000000607mo
O`80000000?o00000000002IVIT01P2IVIT200000003o`0000000000/k>c00H0/k>c200000000ol0
000000000000000D0<c<c0<0000000?o00000000000000001@0000070;>c/`80000000?o00000000
002IVIT01P2IVIT200000003o`0000000000Ogmo00D0Ogmo1000000706IVIPCo00001P1<C4`3oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Go0000200I6AT00ol00000
<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0503oool00ol00000
i^KV0>KViP040>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000
C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01P0I6AT01?l00000
0000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_l0000904a<
C0?o0000201VIVH3000000L0Ogmo0`00000809VIV@L000002`2c/k<D000000/0/k>c1`00000809VI
V@<00000201oOgl2000000P0IVIV0ol0000904a<C0;o00000_ooool00ol0003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`05o`0000P06ATI00?o000003<c<`0c<c<0100c<c<00ol00000
C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000
i^KV0>KViP040>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000
c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000
<c<c03<c<`0403<c<`03o`00000I6AT06ATI00H06ATI00Co000000000000000000000oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo0080<c<c0_l0000:04a<C0?o0000201VIVH30000
00L0Ogmo2000000709VIV@/00000502c/k<;000000P0VIVI1`00000707moO`@000001`1VIVH3o`00
00X0C4a<0_l000001@0c<c?ooooooooooooooooo000001_ooooo000Jooooo`03o`000?oooooooooo
00Go0000200I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?oo
o`3oool04P3oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<0080c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI
6@0I6AT01P0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0100c<c<3o`0000X0C4a<1?l0000706IVIPL00000201oOgl7000000/0VIVI5000000;
09VIV@P000001`1oOgl7000000P0IVIV0ol0000;04a<C0;o00000`0c<c<3ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo00Go0000200I6AT00ol00000<c<c03<c<`0403<c
<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<
c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool04P3oool00ol00000i^KV0>KViP050>KV
iP030000003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VI
V@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<
C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01P0I6AT01?l000000000000000000003
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01`0c<c<3o`0000/0C4a<1?l0000:
06IVIP0400000?l000000000000000/0Ogmo0P0000000ol00000000000000009000000h0VIVI3000
00000ol00000000007moO`0:07moO`<0000000?o000006IVIP1VIVH02@1VIVH4o`0000X0C4a<1?l0
000503<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01Ol00008
01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0B
0?ooo`03o`00003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP02
06IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@06
01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0:03<c<`Co00002`1<C4`7o`0000L0IVIV2`00000>07moO`h000003P1oOgl;000000L0IVIV2?l0
000:04a<C0Co00002@0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00Go00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o0000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<00000
0;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00D0i^KV00?o0000
0?ooo`3oool0403oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<00000
0;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<00000
06IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c00D0<c<c00?o0000
01TI6@0I6AT01P0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool03P0c<c<7o`0000/0C4a<0ol0000?06IVIQ8000001P1oOglB000000l0IVIV0ol0
000;04a<C0Oo00002`0c<c<3o`0000;ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000
ooooooooool01Ol0000901TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`0
0ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H0
0ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`00`3<c<`0
0`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<01@0c<c<0
0ol000006ATI01TI6@0601TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`07o`0000h0<c<c1?l0000:04a<C0co00005@1VIVH6000001H0IVIV2ol0
000:04a<C0Co00003`0c<c<3o`0000806ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`05o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C003
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP05
0>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c003
0<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`05
03<c<`03o`00000I6AT06ATI00H06ATI00Co000000000000000000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00L06ATI0ol0000?03<c<`Oo00003`1<C4`>o`0001@0IVIV3ol0
000>04a<C0Oo00003`0c<c<4o`0000D06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`05o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C003
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP05
0>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c003
0<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`05
03<c<`03o`00000I6AT06ATI00H06ATI00Co000000000000000000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00X06ATI1?l0000B03<c<`Oo00005P1<C4`Do`0001H0C4a<1ol0
000B03<c<`Co00002@0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00Go00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o0000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<00000
0;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00D0i^KV00?o0000
0?ooo`3oool03P3oool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<00000
0;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<00000
06IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o0000
01TI6@0I6AT01`0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool03P0I6AT7o`000180<c<c3ol0000S04a<C0ko00004P0c<c<7o`0000d06ATI0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`05o`0000T06ATI00?o0000
03<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<00000
0<c<c03<c<`00`3<c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo00`0oooo00?o0000
0>KViP3Vi^H01P3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o0000
04a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00Co0000
00000000000000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01D06ATI1ol0
000J03<c<b?o00006@0c<c<7o`0001@06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`05o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C003
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP06
0>KViP03o`00003oool0oooo00`0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c003
0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`04
03<c<`03o`00000I6AT06ATI00L06ATI00Co000000000000000000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01`06ATI1ol0001803<c<`Oo00006`0I6AT3ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Go00002@0I6AT00ol00000<c<c03<c<`04
03<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH01@000000Ogmo07moO`1o
Ogl0000000@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003V
i^H0i^KV00L0i^KV00?o00000?ooo`3oool02P3oool00ol00000i^KV0>KViP070>KViP030000003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001o
Ogl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00304a<C003o`00000c
<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT01?l000000000000000000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool00ol0000P01TI6@oo0000:P0c<c<?o`0002006ATI
0ol00002ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Ko0000200I
6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c
/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0203o
ool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1V
IVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I
6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
0`000004o`0002/06ATI:_l0000Z01TI6@Go00000P000003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00Ko0000200I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003V
i^H0i^KV00P0i^KV0ol000050?ooo`;o00002P3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c
/k<0/k>c00<0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03o`00001V
IVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I
6AT06ATI00L06ATI00Co000000000000000000000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00L000001ol0001b01TI6@Ko00001`000003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00Ko0000200I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI0080VIVI00?o00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003V
i^H0i^KV00/0i^KV1Ol0000<0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1V
IVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I
6AT01?l000000000000000000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
3P00000;o`0005d06ATI2_l0000=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool01_l0000801TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<
C4`00ol00000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00D0000009VIV@2IVIT0VIVI
000000060;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H06P3Vi^H00`000000c<c<
0<c<c0030<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0503<c<`03o`00000I6AT06ATI00H06ATI00?o00000000000000000P000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool06@000007o`0004h06ATI2?l0000G000000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01_l0000801TI6@;o00001P0c
<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1o
Ogl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<
c<`00`000000i^KV0>KViP0I0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1V
IVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01P0I
6AT00ol00000000000000002000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0P000000ko0000<P0I6AT>o`0001l000000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`06o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C003
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP0I
0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@03
09VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C003
04a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01P0I6AT00ol00000000000000002
000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0^000003;o0000;@000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Ko00002@0I6AT00ol0
0000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0102c/k<00`00
0000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV01L0i^KV00<000000<c<c03<c<`00`3<c<`00`00
0000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`00
0000IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<01@0c<c<00ol0
00006ATI01TI6@0601TI6@03o`00000000000000008000000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`06o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00304a<C003
o`00001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@03
0000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP0F0>KViP03
o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00304a<C003
o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT00ol00000000000000002000000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool01_l0000901TI6@03o`00000c<c<0<c<c00@0<c<c
00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00@0c<c<
00?o00000>KViP3Vi^H05P3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV
00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI
00?o00000000000000000P000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Ko00002@0I
6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c
/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV01H0i^KV00<000000<c<c03<c<`0103<
c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1o
Ogl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<0100c
<c<00ol000006ATI01TI6@0701TI6@03o`00000000000000008000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`06o`0000T06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C004
04a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP0D
0>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@02
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C004
04a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT00ol00000000000000002
000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool01ol0000901TI6@03o`00000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo
0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H04P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c
00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00H06ATI00?o00000000000000000`000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Oo
00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c
/k<00`2c/k<00`000000c<c<0<c<c0060<c<c0800000403Vi^H2000000P0c<c<00<000000;>c/`2c
/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1V
IVH00`1VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT01P0I6AT00ol00000000000000003000000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
1ol0000901TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H0303Vi^H00`000000c<c<
0<c<c0080<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0503<c<`03o`00000I6AT06ATI00H06ATI00?o00000000000000000`000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00Oo00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0080<c<c0030000003V
i^H0i^KV00X0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`030;>c/`030000002I
VIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP03o`00001<
C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0701TI6@03o`000000
0000000000<000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08d000000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`07o`0000T06ATI00?o0000
03<c<`0c<c<0100c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<00000
0<c<c03<c<`0203<c<`2000000P0i^KV0P00000:0<c<c003o`00002c/k<0/k>c00@0/k>c00<00000
09VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV00?o0000
04a<C01<C4`0101<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o0000
0000000000000`000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Oo00002@0I6AT00ol0
0000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00ol0
0000c<c<0<c<c00:0<c<c0800000103Vi^H2000000`0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00ol0
0000C4a<04a<C00404a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01`0I6AT00ol0
0000000000000003000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=0000
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool01ol0000901TI6@03
o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0306IVIP03
0000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`03
0000003<c<`0c<c<00`0c<c<1000000>0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<
C4`0101<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000
00000`000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c
03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<
0<c<c00L0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0307moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c
03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<
C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002I
VIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c00J0<c<c0030000002c
/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`03o`00001V
IVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I
6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00So00002@0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c00H0<c<c0030000002c/k<0/k>c00D0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00?o0000
04a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o0000
00000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol0
0000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`00
0000c<c<0<c<c00F0<c<c003o`00002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`00
0000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00?o000004a<C01<C4`00`1<C4`00ol0
0000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000000010000003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`0503<c<`03
o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`03
o`00002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01P2c/k<00ol00000c<c<0<c<c00D0<c<c003
0000002c/k<0/k>c00H0/k>c00?o000009VIV@2IVIT00`2IVIT00ol00000000007moO`0307moO`03
0000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03
o`00000I6AT06ATI00L06ATI00?o000000000000000010000003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00So00002@0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<
00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI
00?o00000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c00D0<c<c0030000002c/k<0/k>c00D0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV
00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI
00?o000000000000000010000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00So00002@0I
6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c
/k<00`000000c<c<0<c<c00B0<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT0102I
VIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`00`1<
C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000001000
0003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Wo00002@0I6AT00ol00000<c<c03<c<`04
03<c<`03o`00001<C4`0C4a<00D0C4a<00?o000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<200000100c<c<0P000008
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP04
06IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@07
01TI6@03o`0000000000000000D000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09o`00
00T06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c
00L0/k>c0P00000<0<c<c08000002P2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo
00<0Ogmo00<0000006IVIP1VIVH0101VIVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c
00D0<c<c00?o000001TI6@0I6AT01`0I6AT00ol00000000000000005000000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool02Ol0000901TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<
C4`0101<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT01@2IVIT00`000000/k>c0;>c/`090;>c/`<000001P3<c<`3000000`0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<
C4`00`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI00?o000000000000
00001@000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Wo00002@0I6AT00ol00000<c<c
03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<02`2c/k<6000000h0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV
00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00L06ATI
00?o00000000000000001@000003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00[o00002@0I
6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<07P2c
/k<00ol00000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101V
IVH00ol00000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I
6AT00ol00000000000000005000000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02_l00009
01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT01@2IVIT00ol00000/k>c0;>c/`0L
0;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101oOgl00ol00000IVIV06IVIP03
06IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@08
01TI6@03o`0000000000000000D000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0:o`00
00T06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c
01X0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00<0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI
00P06ATI00?o00000000000000001@000003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00[o
00002P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00@0C4a<00?o000006IVIP1V
IVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c
/k<0602c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH00`1VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I
6AT0200I6AT00ol00000000000000006000000?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
2_l0000:01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c
0;>c/`0F0;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV
06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI
01TI6@0801TI6@03o`0000000000000000H000000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`0:o`0000X06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00404a<C003o`00001V
IVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0709VIV@030000002c
/k<0/k>c01@0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0407moO`030000001V
IVH0IVIV00@0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I
6AT06ATI00P06ATI00?o00000000000000001P000003ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0S@000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooo
oooo00[o00002P0I6AT00ol00000<c<c03<c<`0603<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00L0VIVI00<00000
0;>c/`2c/k<04P2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00D0Ogmo00<00000
06IVIP1VIVH0101VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o0000
01TI6@0I6AT0200I6AT00ol00000000000000006000000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool02ol0000:01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol0
0000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01`2IVIT20000
0100/k>c0P00000909VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00ol0
0000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I6AT00ol0
0000000000000007000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=0000
00?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02ol0000:01TI6@03
o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0506IVIP03
o`00001oOgl0Ogmo00D0Ogmo00?o000009VIV@2IVIT0202IVIT2000000`0/k>c0P00000;09VIV@03
o`00001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00ol00000C4a<04a<C00404a<C003
o`00000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT0200I6AT00ol00000000000000007000000?o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00?o0000ooooooooool02ol0000:01TI6@03o`00000c<c<0<c<c00D0<c<c
00?o000004a<C01<C4`0101<C4`00ol00000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo
00<0000009VIV@2IVIT02P2IVIT3000000H0/k>c0`00000<09VIV@030000001oOgl0Ogmo00H0Ogmo
00<0000006IVIP1VIVH0101VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT0200I6AT00ol00000000000000007000000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool03?l0000:01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<
C4`00ol00000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0302I
VIT6000000h0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0406IVIP03o`00001<
C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0801TI6@03o`000000
0000000000P000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08d000000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0<o`0000X06ATI00?o0000
03<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00D0IVIV00<00000
07moO`1oOgl01@1oOgl00`000000VIVI09VIV@0N09VIV@030000001oOgl0Ogmo00H0Ogmo00<00000
06IVIP1VIVH0101VIVH00ol00000C4a<04a<C00504a<C003o`00000c<c<0<c<c00D0<c<c00?o0000
01TI6@0I6AT0200I6AT00ol00000000000000008000000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool03?l0000:01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`01@1<C4`00ol0
0000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0702IVIT00`00
0000Ogmo07moO`0707moO`030000001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01@1<C4`00ol0
0000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00P06ATI00?o000000000000000020000003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0S@000003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00co00002P0I6AT00ol00000<c<c03<c<`0603<c<`03
o`00001<C4`0C4a<00D0C4a<00?o000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`03
0000002IVIT0VIVI01X0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0506IVIP03
o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0801TI6@03
o`0000000000000000P000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08d0
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0=o`0000X06ATI
00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00D0IVIV
00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0H09VIV@030000001oOgl0Ogmo00L0Ogmo
00<0000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C00504a<C003o`00000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT0200I6AT00ol00000000000000009000000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool03Ol0000:01TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`01@1<
C4`00ol00000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo00L0Ogmo0P00000F09VIV@8000002@1o
Ogl00ol00000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<01P0c
<c<00ol000006ATI01TI6@0801TI6@03o`0000000000000000T000000oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0ol0003oooooooooo`0=o`0000X06ATI00?o000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C005
04a<C003o`00001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl02@1oOgl00`000000VIVI09VIV@0B
09VIV@030000001oOgl0Ogmo00T0Ogmo00<0000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C005
04a<C003o`00000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT0200I6AT00ol00000000000000009
000000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool03Ol0000:01TI6@03o`00000c<c<0<c<c
00L0<c<c00?o000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0506IVIP030000001oOgl0Ogmo
00T0Ogmo0P00000@09VIV@8000002`1oOgl00`000000IVIV06IVIP0606IVIP03o`00001<C4`0C4a<
00D0C4a<00?o000003<c<`0c<c<01P0c<c<00ol000006ATI01TI6@0801TI6@03o`00000000000000
00T000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08d000000oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0>o`0000X06ATI00?o000003<c<`0c
<c<01P0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl02P1oOgl2000000d0VIVI00<0000007moO`1oOgl02`1oOgl00`000000IVIV06IVIP0506IVIP03
o`00001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0801TI6@03
o`0000000000000000X000000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08d0
00000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0>o`0000X06ATI
00?o000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00604a<C003o`00001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00/0Ogmo
00<0000006IVIP1VIVH01P1VIVH00ol00000C4a<04a<C00504a<C003o`00000c<c<0<c<c00H0<c<c
00?o000001TI6@0I6AT0200I6AT00ol0000000000000000:000000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2=000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o
0000ooooooooool0T?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool06Oooool001[oooooU?l0000coooooiCo00006oooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oo
ooooTOooool00?ooooooTOooool00?ooooooTOooool008Gooooo0_l00035ooooo`;o0000@_ooool0
08;ooooo0ol000000ooooooo0000ooooo`31ooooo`?o000000?oooooo`000?ooool0@Oooool0083o
oooo0_l00003ooooo`030;Vog_l0003o00000;oooooo0_l00002ooooo`;oZKgX0_l00011ooooo`00
OOooool3o`0000?ooooo0`2i_mh00ol0003oooooo`00002kooooo`?o000000?oooooojVmj?nY_NP0
0onY_NP00ol0003oooooo`000010ooooo`00N_ooool3o`0000Cooooo00<0_;oM0;VogP2i_mh00P2i
_mh00ol0003oooooo`00002hooooo`?o00000oooool6ojVmj003o`000?oooooo0000043ooooo001h
ooooo`;o00001_ooool30;bog@<0^KoN00Co00000;[0g_oooooo0000]Oooool2o`0000?ooooo2OnY
_NP01?l0003oZKgXooooool0000oooooo`00MOooool3o`0000Kooooo00<0_[oJ0;bog@2l_md00`2l
_md00`2i_mh0^/3No`0000020;[0gP03ooooool0003ooooo0;3ooooo0ol00002ooooo`coZKgX00Go
0000ojVmj?nY_NSoooooo`00000nooooo`00Loooool2o`0000Sooooo0`2n_mX30;bog@80_L3L00H0
^/3No`00002j`=h0^l3Nooooool0002_ooooo`;o00000_ooool?ojVmj005o`000?nY_NSoZKgXoooo
ool00000?_ooool0073ooooo0ol00008ooooo`030<6of02n_mX0_[oJ00<0_[oJ00<0_;oM0;g0g02m
`=`00P2m`=`01_l00000^l3N0;_0gP2k`=koooooo`000:_ooooo0ol00003oooooa3oZKgX00Ko0000
ojVmj?nY_NSoZKgXooooool0000mooooo`00K_ooool2o`0000[ooooo0`31_mP30;jofP030;nofP2m
`=`0_L3L0080_L3L00<0_/3Lo`00002k`=h00`2k`=h00ol0003oooooooooo`2Wooooo`;o00001?oo
oolBojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000?Oooool006_ooooo0ol0000;ooooo`@0`KoH
00<0_[oJ0;nofP2o_mX00P2o_mX01@2m`=`0_/3L0;k0g02n`=co000000<0^l3N00<0_<7Mooooool0
0000YOooool3o`0000;ooooo5_nY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03_o
oooo001Xooooo`?o00003?ooool20<>neP<0`KoH00<0`[oH0;nofP2o_mX00`2o_mX40;k0g003o`00
002k`=h0_<7M00<0_<7M00?oooooo`000?ooool0X?ooool3o`0000;ooooo6OnY_NP00ol0003oZKgX
ojVmj003ojVmj003ooooool0003ooooo03[ooooo001Vooooo`;o00003_ooool40<>neP040<6of032
_mP0`[oH0<:of0<0_koJ0P30`=T30;k0g0030;o1fol00000_<7M0080_<7M00<0_L7Mooooool00000
Woooool2o`0000Cooooo6onY_NP00ol0003oZKgXojVmj002ojVmj003ooooool0003ooooo03[ooooo
001Sooooo`?o00003oooool50<>nePD0`[oH00<0_koJ0<30f@30`=T00P30`=T01P2n`=`0_l7K0;o1
fol00000_l7K0;c1g@<0_L7M00?oooooo`000?ooool0V_ooool3o`0000Cooooo7OnY_NP00ol0003o
ZKgXojVmj003ojVmj003ooooool0003ooooo03Wooooo001Qooooo`;o00004Oooool20<Bmd`<0`kkF
0P34_]D30<:of080`koG0`30`=T01P31`MT0_l7K0;o1f`2o`M_o00000;o1f`D0_L7M00?oooooo`00
0?ooool0Uoooool2o`0000Cooooo8?nY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo
03Sooooo001Nooooo`?o00004_ooool40<Bmd`030<>neP34_]D0a;kE0080a;kE00<0`[oH0<>oe`33
_mL00P33_mL01030`=T0`L7I0<71f@31`MT20;o1f`03o`00002o`M/0_l7K00@0_L7M00?oooooo`00
0?ooool0U?ooool3o`0000;ooooo9?nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?oooooooooo
03Oooooo001Looooo`;o00004oooool00`36_=40a;gC0<Bmd`020<Bmd`030<Fmd`34_]D0a;kE0080
a;kE00<0aKoD0<>oe`33_mL00P33_mL00`34`=L0`L7I0<71f@020<71f@80_l7K00?o00000;o1f`2o
`M/01@2m`Md00ooooooo0000ooooo`2Aooooo`;o00000_oooolWojVmj003o`000?nY_NSoZKgX00Go
ZKgX00?oooooo`000?ooool0=oooool005Wooooo0ol0000Cooooo`@0a[cA00<0a;gC0<Fmd`35_M<0
0P35_M<00`34_]D0aKoD0<Foe0020<Foe080`koG0`34`=L20<71f@80`/7I00<0_l7Ko`00002o`M/0
0P30`M/30;g1g@040;k2gOooooooooooo`0008kooooo0ol00003ooooobSoZKgX00?o0000ojVmj?nY
_NP01_nY_NP00ooooooo0000ooooo`0fooooo`00Eoooool2o`0001Gooooo1@36_=450<Fmd`D0aKoD
00<0`koG0<C0e`34`=L00P34`=L00`31`MT0`/7I0<;1f@020<;1f@03o`000030`M/0`<7K0080`<7K
00H0_L7M0;k2g@2n`]d0_/;Mooooool0002<ooooo`;o00001?oooolZojVmj003o`000?nY_NSoZKgX
00KoZKgX00?oooooo`000?ooool0=_ooool005Cooooo0ol0000Fooooo`80a[_?0`36_=420<Nld0<0
aKgC0P37_]830<Foe080a[oD0`34`=L20<G1eP<0`/7I00<0`l7Ho`000030`M/00P30`M/00`31`]X0
_/;M0;k2g@030;k2g@03ooooool0003ooooo08Oooooo0ol00003ooooobgoZKgX00?o0000ojVmj?nY
_NP01OnY_NP2ojVli`03ooooool0003ooooo03Gooooo001Aooooo`?o00006?ooool40<Jkc`030<Jl
d@37_=00akc@0080akc@00<0aKgC0<NndP37_]800P37_]800`35_m@0a[oD0<Joe0020<Joe0030<C0
e`35`MH0aL7F0080aL7F00H0`/7I0<?1f033`MSo00000<?1f030`M/30<72fP<0_/;M00@0_l;Loooo
oooooooo0000Q?ooool3o`0000?ooooo<?nY_NP00ol0003oZKgXojVmj002ojVmj0KoZKcW00?ooooo
o`000?ooool0=?ooool004oooooo0_l0000Jooooo`D0a[_?1@37_=050<NndPD0a[oD1@35`MH30<?1
f003o`000034`]P0`L;J00<0`L;J00<0_/;M0;o2g02o`]`00P2o`]`00ooooooo0000ooooo`21oooo
o`;o00000ooooolcojVmj003o`000?nY_NSoZKcW00OoZKcW00<0ZK_Vooooool00000=Oooool004co
oooo0ol0000Kooooo`80akW=0`36^ll20<RkcP<0akc@0P38_M030<NndP80b;kA0`36_m@20<O0d`<0
aL7F0P36`MH20<?1f003o`000034`]P0a<;H0080`L;J0P32`]X30;o2g080`<?L00?oooooo`000?oo
ool0OOooool3o`0000;ooooo=OnY_NP00onY_>Oo0000ojVli`04ojVli`H0ZK_V00?oooooo`000?oo
ool0<oooool004[ooooo0_l0000Mooooo`@0akW=00<0a[_?0<RkcP38^lh00P38^lh00`37_=00b;g@
0<Rmd0020<Rmd0030<NndP38_]40b;kA0080b;kA00<0a[oD0<O0d`37`=<00P37`=<01`35`MH0a/7F
0<K1eP36`MH0`l7H0<C2f?l000000P34`]P00`31`]X0`/;J0<;2fP020<;2fP030;o2g030`m`0`<?L
0080`<?L00?o0000ooooooooool0N_ooool2o`0000Cooooo=?nY_NP3ojVli`03o`000?nY_>OoZKcW
00P0ZK_V00<0ZKWTooooool00000=?ooool004Oooooo0ol0000Nooooo`D0akW=1@38^lh50<Rmd0@0
b;kA00<0bKoA0<O0d`37`=<00P37`=<01038`M<0a/7F0<K1eP36`MH20<O2e@030<C2f?l00000a<;H
0080aL;G0`32`]X00`33`mX0`<?L0<33g0030<33g003ooooool0003ooooo07Oooooo0ol00004oooo
obcoZKgX0_nY_NL6ojVmj080ZKcW0onY_>L00ol0003oZKcW0:VkiP050:VkiP030:Vhi02Y^N@0ZKWT
0080ZKWT00?oooooo`000?ooool0<_ooool004Gooooo0_l0000Pooooo`80akS<0`37^Ld20<Rjc0<0
b;_>0P39_<d30<Rmd080bKg?0P38_]430<Vod@030<O0d`38`M<0b<7C0080b<7C00<0a/7F0<O2e@37
`]D00P37`]D00ol00000aL;G0<G2e`020<G2e`040<;2fP33`mX0`l?J0<?3fPD0`<?L00?oooooo`00
0?ooool0M?ooool2o`0000Cooooo;?nY_NP6ojVmi`;oZKgX1P2Y_>L2ojVli`03o`00002Y^nH0ZK_V
00@0ZK_V0`2Y^>@40:Vii003ooooool0003ooooo037ooooo0012ooooo`?o00008Oooool40<Nhc003
0<Nic@38^/`0b;[<0080b;[<00<0b;_>0<Vlc@39_<d00P39_<d01@38_M00bKg?0<Vmc`39_Ll0b;kA
00@0bKoA1@38`M<50<O2e@05o`000035`]L0aL;G0<G2e`36`mL01033`mX50<33g003ooooool0003o
oooo077ooooo0ol00002ooooobgoZKgX2?nY_NL80:Vli`040:VjiP2Y^nH0ZK_Vo`0000@0ZK_V1P2Y
^>@20:Vii0030:Vdh?oooooo000003;ooooo000oooooo`?o00008_ooool00`36]/X0akS<0<Nhc002
0<Nhc0030<Rhb`38^/`0b;[<0080b;[<00<0bK[<0<Vlc@39_<d00P39_<d0103:_<d0bKg?0<Vmc`39
_Ll20<^ncP<0bKoA0P3:_m030<S1d`80bL7B0`37`]D01038`]Co00000<G2e`35`]L30<K3e`80`l?J
0P34`mT30<33g0040<73g?ooooooooooo`0006kooooo0ol00002ooooobgoZKgX2?nY_NL80:Vli`03
0:Vji@2Y^^H0ZK[V0080ZK[V00@0ZK_Vo`00002Y]n<0ZKOS1P2Y^>@20:Vcg`@0ZKCP00?oooooo`00
0?ooool0<?ooool003gooooo0_l0000Tooooo`<0a[K:0P37^<`30<Rhb`80b;[<0`39^/`20<Vlc@<0
b[c=00<0bKg?0<^ncP3;_/h00P3;_/h00`39_m40b[o@0<Zod0020<Zod0030<S1d`39`M80bL7B0080
bL7B00D0al;E0<S2e038`]Co00000<G2e`040<K3e`030<?3fP34`mT0a<?I0080a<?I00@0`<?L0<73
g031`m`0`L?L0_ooool00ol0003oooooooooo`1Yooooo`;o00000_ooool]ojVmj0OoZKgW202Y_>L6
0:Vji@80ZK[V0P2Y]n<01?l00000ZKOS0:Vgh`2Y]n<20:Vhi0030:Vbg`2Y/ml0ZK?O00<0ZK?O0P2Y
]>00102Y[M[oooooooooool0000`ooooo`00>_ooool3o`0002Gooooo1036]/X00`37^<`0b;S;0<Rh
b`020<Rhb`030<Rjc039^/`0bK[<0080bK[<00<0bKc=0<Zlc@3:_<d00P3:_<d50<^ncPD0b[o@00D0
bl3@0<W1dP39`M80bL7B0<_2dP030<S2e003o`000039`m@0a/?G0080a/?G0P37`mL30<C3f@040<C4
f@31`m`0`L?L0<73g080`/CL00?oooooo`000?ooool0Ioooool3o`0000;ooooo;_nY_NP5ojVmi`P0
ZKcW202Y^^D00`2Y]^80ZKOS0:Vgh`020:Vgh`04o`00002Y]n<0ZKOS0:VagP@0ZK;O0`2Y/ml00`2Y
ZmT0ZJgJ0:V]fP020:V]fP03ooooool0003ooooo02oooooo000hooooo`;o00009oooool50<JfbPD0
b;S;1@39^/`0103;^l/0b[c=0<Zlc@3:_<d20<bmc0<0bkk>0P3<_/h30<Zod0<0bl3@00L0bL7B0<_2
dP3;`]80bl;B0<S2e039`mCo00000080bL?D00<0a/?G0<O3e`37`mL00P37`mL01@34`mT0a<CI0<C4
f@34a=T0`L?L00@0`/CL00?oooooo`000?ooool0I?ooool2o`0000Cooooo;OnY_NP6ojVmi`H0ZKcW
00<0ZKWU0:Vji@2Y^^D01@2Y^^D50:VfhP<0ZKOS00?o00000:VagP2Y/Mh00P2Y/Mh40:Vbg`040:Vc
g`2YZmT0ZJ_I0:V[f@@0ZJgJ00?oooooo`000?ooool0;_ooool003Gooooo0ol0000Xooooo`80aKC9
0`36]/X20<Nfb@<0b;S;0P39^LX30<Vjc0<0bk_;00<0b[c=0<bmc03<_L`00P3<_L`00`3;_/h0c;k>
0<bncP020<bncP050<Zod03;`=00bl3@0<_0d03=`Ll0103;`]820<W3e004o`000039`m@0bL?D0<[3
e0<0al?G00@0b<CG0<C4f@34a=T0a<CI0P35a=T40<;4g0;ooooo00?o0000ooooooooool0Goooool3
o`0000Cooooo:onY_NP8ojVmi`L0ZKcW0`2Y^ND50:Vji@L0ZKKR00@0ZKOS0:V`gOl00000ZK3M102Y
/Mh20:Vbg`030:RYe`2YZmT0ZJ_I00<0ZJ_I0P2Y[MX0102XXm7oooooooooool0000^ooooo`00<ooo
ool2o`0002[ooooo1035]<T00`36]/X0akK90<Nfb@020<Nfb@030<Rhb`39^LX0bKW:0080bKW:00<0
bK[<0<^kb`3;^l/00P3;^l/50<bmc0D0c;k>0`3;`=030<g1c`80bl;B0P3<`]400`39`mCo00000<W3
e0030<[3e0050<O3e`38a=L0b<CG0<S4e`34a=T01035a=T40<;4g003ooooool0003ooooo05kooooo
0_l00004ooooob_oZKgX2?nY_NL20:Vki`H0ZKcW1P2Y^ND20:Vji@030:VehP2Y]^80ZKKR00D0ZKKR
00D0ZJoM0:V`g@2Y/=go00000:V`g@020:VagP80Z:SF102XZML20:V[f@80Z:7@102XXm400ooooooo
0000ooooo`0]ooooo`00<?ooool3o`0002[ooooo00<0`k;90<Fdb@35]<T00`35]<T50<Nfb@D0bKW:
1@3;^l/0103<^lX0c;g<0<bmc03<_L`20<fmb`<0c;k>0P3=_ld00`3;`=00cL7?0<g1c`020<g1c`03
0<_2dP3<`]40c<;A0080c<;A00Go00000<[3e03:`m@0b/?D0<_4e0040<S4e`050<S5e`35a=T0aLCI
0<G4f@36aMT00`32a=`20<?5g003ooooool0003ooooo05[ooooo0ol00003ooooob_oZKgX2?nY_NL6
0:Vki`80ZKcW202Y^ND00`2Y]N40ZKGR0:VehP020:VehP80ZKKR0P2X[]`40:V_g@030:V`gOl00000
Z:OE00D0Z:SF0P2XZML00`2WWlh0Z:7@0:RQd0030:RQd0<0Z:?A0_ooool00ol0003oooooooooo`0[
ooooo`00;Oooool3o`0002cooooo0`33//T30<Fdb@80a[C90`37]/T20<Vgb@<0bKW:0P3;^LT30<^k
b`<0c;_:00<0c;g<0<fmb`3=_L/00P3=_L/0103<_/h0cKo=0<foc@3=_ld50<g1c`060<k2c`3<`]40
c<;A0<c2d@3=`m7o00000P3:`m@30<_4e080b<CG0`38aML01@35a=T0a/GI0<K5f@36aMT0`/CL00@0
`lGL00?o0000ooooooooool0E_ooool3o`0000?ooooo:onY_NP8ojVmi`80ZK_V1P2Y^nL80:Vii@03
0:Vdh@2Y]N40ZKGQ0080ZKGQ0P2Y]N800`2X[M/0Z:kL0:R^g0030:R^g080ZJoM00<0YjGD0:RWeOl0
00000P2XYmD40:RXeP040:RYe`2WWlh0Yio>0:NOcP@0Z:7@0P2XXm40102XV/Soooooooooool0000]
ooooo`00:oooool2o`0002gooooo00<0`K390<>bb@33//T00`33//T00`35]<T0a[C90<Jdb@020<Jd
b@030<Nfb@39]lT0bKO90080bKO900<0bKW:0<^ib@3;^LT00P3;^LT00`3;^l/0c;_:0<bkbP020<bk
bP@0cKg;00@0c[k;0<foc@3=_ld0cKo=0P3>`<d30<g1c`<0c/;?00D0c<;A0<g3d@3=`m40cL?Ao`00
00040<_4e0050<S4e`38aML0b<GG0<S5e`39aMH01036aMT50<?5g003ooooool0003ooooo05Cooooo
0_l00003ooooob_oZKgX0_nY_>L6ojVmi`H0ZK_V0P2Y^nL00`2Y^N@0ZKWU0:Vii@040:Vii@H0ZKCQ
0P2Y]N400`2X[MX0Z:gK0:R]f`020:R]f`<0Z:kL00<0YjCB0:NUe02WYM@00P2WYM@0102XYmGo0000
0:RWe@2XYmD20:RXeP030:NMc02WWlh0Yio>0080Yio>0`2XXM000`2WV<H0Z9[80:RJb0020:RJb0;o
oooo00?o0000ooooooooool0:_ooool002Sooooo0ol0000^ooooo`<0`K391033//T50<Jdb@D0bKO9
1@3;^LT0103<^/P0c;_:0<bkbP3<^lX20<flb@80cKg;0`3>_//00`3=_ld0c/3=0<k0c@020<k0c@03
0<g1c`3>`/l0c/;?0080c/;?103=`m401Ol00000blCD0<_4e03;a=@0c<GC00<0b<GG0`39aMH40<K5
f@D0`lGL00?oooooo`000?ooool0D?ooool3o`0000;ooooo:onY_NP6ojVli`;oZKgW202Y^nH50:Vi
i080ZKWU00<0ZK?P0:Vdh@2Y]>401@2Y]>400`2X[=X0Z:gJ0:R]fP020:R]fP@0Z:gK00@0Z:kL0:NT
dP2WY=80YjCB102WYM@00ol00000Z:OE0:JKbP040:NMc0@0Yio>00@0Z:7@0:NHaP2WV<H0YiS60`2X
V/P3ooooo`03o`000?oooooooooo02Wooooo000Vooooo`;o0000<?ooool40<6`b@<0`k;90P34//P3
0<Jdb@80akG80`39]lT20<Zgb0<0bkW90`3<^/P01@3<^lX0cKc90<flb@3=_<T0cKg;00@0c[k;1@3>
`<d0103?`L`0c/;?0<k2c`3>`/l20<o2cP80cL?A00@0cLCAo`00003=a=40blCD0`3<aM<00`38aML0
bLGF0<W5eP020<W5ePD0a/GI1033aM`00ooooooo0000ooooo`1>ooooo`;o00000_ooool]ojVmj0Ko
ZKcW202Y^nH00`2Y^>@0ZKWT0:Vii0040:Vii0D0ZK?P0`2Y]>400`2XZmT0Z:cJ0:R/fP020:R/fP@0
Z:gJ0P2X[M/00`2WX]40YjCB0:NTdP030:NTdP80YjGD00<0YYW9o`00002VVlX00P2VVlX40:NMc080
Yio>00<0YYG40:NHaP2WV<H00P2WV<H40:RJb0;ooooo00?o0000ooooooooool0:Oooool002?ooooo
0ol0000aooooo`H0`K3900<0`k;90<Bbb034//P00P34//P00`36]<T0akG80<Neb0020<Neb0030<Vg
b@3:]lP0b[O80080b[O800<0bkW90<bjb03<^/P00P3<^/P40<flb@D0c[k;00@0cko:0<k0c@3>`<d0
c/3=0`3?`L`01@3>`/l0cl;>0<o2cP3?`/h0cL?A0080cLCA00?o00000<g4d@3<aM<0103<aM<30<W5
eP030<[6eP36aMT0a/GI0080a/GI00D0alKI0<?5g033aM`0`lGL0<C6g002ooooo`03o`000?oooooo
oooo04Wooooo0ol00003ooooobcoZKgX1OnY_>L80:VkiPD0ZKST0P2Y^N@00`2X/n00ZK?P0:Vch006
0:Vch0040:Vdh@2XZmT0Z:_I0:R[f@@0Z:cJ0P2X[MX00`2VXM00Yj;A0:NRd@020:NRd@<0YjCB00D0
YIO70:JIb@2VVLT0YYW9o`0000040:JKbP80Yig<00@0YI?20:JEa02VUL@0YYG41@2WV<H20:RJb005
0:NC`Oooooooooooooooool00000:_ooool0027ooooo0_l0000cooooo`80_Zg91031/<T00`32/<P0
a;;80<Bbb0020<Bbb0030<Jcb037]LP0akG80080akG800<0bKK70<Zgb03:]lP00P3:]lP00`3;^<L0
c;[80<bjb0020<bjb080cK[80P3=_<T20<nmb@<0c[k;0`3?_lX00`3>`<d0cl7<0<o1c0020<o1c0@0
cl;>00@0d<?>0<g4d@3=a=7o00000P3>a=450<c5d`050<W5eP3:a]H0b/KF0<[6eP36aMT01037a]T0
1033aM`0a<KL0<C6g034a]`2ooooo`03o`000?oooooooooo04Kooooo0_l00004ooooob_oZKgX1onY
_>L60:VkiPL0ZKST00<0Z;;O0:Rch02X/n000P2X/n060:Vch080Z:[I102XZmT20:R/fP030:JOc`2V
XM00YZ7@0080YZ7@102WX]400`2WY=80YIO70:FGa`030:JIb@05o`00002VVlX0YY_:0:JKbP2UT<00
0`2UTl840:JEa0<0YiS600@0Yi2n0:NC`@2WTl40Yi?11?ooool00ol0003oooooooooo`0Wooooo`00
7_ooool3o`0003Cooooo102n[LT00`31/<T0`[380<:`b0020<:`b080a;;80`36/lP20<Neb0<0bKK7
0P3:]lP30<^ha`80c;[80`3=^/P00`3=_<T0ckg90<nmb@020<nmb@030<jnb`3?_lX0cko:0080cko:
103?`L`20=32c080cl;>0`3@`lh0103=a=7o00000<k4d@3>a=450<c5d`<0b/KF0P3;amH30<O6f@03
0<O7f@34a]`0a<KL00<0a<KL00?oooooo`000?ooool0A?ooool3o`0000Cooooo:_nY_NP8ojVli`L0
ZK_V1`2Y^>@30:Rbg`@0Z;?P0P2Y/n020:NYf0@0Z:[I0P2XZmT00`2VW/h0YYo?0:JOc`020:JOc`<0
YZ7@0P2WX]420:FFaP@0YIO70P2VVLT00ol00000YY_:0:F@`0020:F@`0@0YI?20`2VUL@0102WV<H0
Yi2n0:N@_P2WT;h40:NC`@?ooooo00?o0000ooooooooool09oooool001cooooo0_l0000eooooo`03
0;Z[b`2n[LT0_Zg900<0_Zg91@32/<P00`34//P0a[?80<Jcb0020<Jcb0030<Neb039]/L0bKK70080
bKK700<0b[O80<^ha`3;^<L00P3;^<L00`3<^/P0cK[80<fjb0020<fjb0D0ckg900@0d;g80<nobP3?
_lX0cko:0P3@`<X20<o1c0<0d<;<00<0cl;>0=33cP3@`lh00P3@`lh01@3>a=7o00000<k4d@3>a=40
clG@00<0c<GC0P3=a]<00`3:a]H0blOF0<_7eP020<_7eP040<O6f@37amT0alOI0<O7f@D0a<KL00?o
ooooo`000?ooool0@Oooool2o`0000Cooooo:onY_NP7ojVli`P0ZK_V1`2Y^>@60:Rbg`80Z;?P1P2W
ZMP20:RZf@030:FMc@2VW/h0YYk>0080YYk>0`2VWll20:JQd0030:BDa02UU/H0YIK60080YIK6102U
UlL20:JIb@03o`00002UT<00YI3000<0YI300`2UTl820:JEa0030:J>_02WT;h0Yi2n00<0Yi2n0`2W
Tl44ooooo`03o`000?oooooooooo02Kooooo000Iooooo`?o0000=_ooool30;Z[b`<0_Zg90P2o[/T4
0<:`b0D0a[?81@39]/L50<^ha`D0cK[800@0ck_70<nmb@3?_LT0ckg90`3@_LP01@3?_lX0d<3:0=30
bP3@`<X0cl7<00@0d<;<00@0d/;<0=33cP3@`lh0d<?>0P3Aa<h00ol00000c/CA0<o5d0020<o5d005
0<c5d`3=a]<0cLKC0<g6d`3>am<0103;amH30<O7f@80b<OI0`34a]`01034amcoooooooooool0000n
ooooo`?o00000oooool[ojVmj0OoZKcW202Y^nH70:Vhi0P0Z;;O00<0YjSG0:NYf02WZMP01@2WZMP0
102UW<d0YIg=0:FMc@2UWLd40:JNcP80YYo?00<0Xi;30:BDa02TU<@00P2TU<@40:FFaP80YIO700D0
Xhbl0:B>_P2TS[ko00000:B>_P040:F@`080YI?200<0YH^j0:J>_02VS[`00P2VS[`40:N@_P80Yi?1
00<0ZI2kooooooooool00oooool00ol0003oooooooooo`0Uooooo`005_ooool3o`0003Oooooo00<0
]JS<0;Z[b`2jZl/00`2jZl/0102n[LT0_jk90;n^b@2o[/T30<:`b080`k780`36/lP20<Nca`<0bKK7
0P3:]/L30<^ha`80cKW70`3=^/P30<nka`030<nmb@3@_LP0d;g80080d;g8103@`<X0103B`LT0d<;<
0=32c03@`/`30=;2c0050=33cP3Aa<h0dLC>0=74c_l00000103?aM030<g6d`<0c/OC103;amH00`37
amT0b<OI0<S7f@020<S7f@060<C6g034am`0a<OL0<C7g?oooooo0000>oooool3o`0000?ooooo:onY
_NP00onY_NOoZKcWojVli`04ojVli`P0ZK_V1`2Y^>@80:Rbg`D0YjSG1@2WZMP20:FLc@@0YIg=0P2V
W/h00`2STL80Xi;30:>B``020:>B``<0Y9C4102UU/H01`2UUlL0Xhbl0:><_02SS;`0Y8jno`00002T
S[h0102UT<00102UTl80YH^j0:F;^P2URkX30:J>_0<0Yi2n00<0Z8fi0:V@^`2YT;/00P2YT;/4oooo
o`03o`000?oooooooooo02Gooooo000Dooooo`;o0000>Oooool30;FXc0<0^Z_;00<0^j_:0;n^b@2o
[/T00`2o[/T00`32/<P0`k780<>ab0020<>ab0030<Jcb037/lL0ak?70080ak?700<0bKK70<Zfa`3:
]/L00P3:]/L00`3;^<L0cKW70<fia`020<fia`030<fjb03?^lL0ck_70080ck_71@3@_LP00`3A_/P0
d<3:0=30bP030=;1b@030=32c03B`/`0d/;<0080d/;<103Aa<h01?l00000clG@0<o5d03?aM020=36
d0030<g6d`3>am<0c/OC0080c/OC103;amH01@3<b=L0b<OI0<S7f@38amT0b<SI00<0a<OL00@0aLOL
oooooooooooo0000>?ooool2o`0000?ooooo:onY_NP5ojVmi`;oZKcW202Y^nH70:Vhi0P0Z;;O2@2W
Z=L20:NYf0030:FKc02UW<d0YIc=0080YIc=0`2UWLd0102VW/h0Xi720:>A`P2STL830:>B``@0Y9C4
0P2UU/H00`2SR[/0Xhbl0:><_0020:><_0040:B>__l00000Y8jn0:B>_P80YI3000<0Y8Vh0:F;^P2U
RkX00P2URkX40:J>_0040:N@_P2XSKT0Z8fi0:R=^@<0ZI2k1Oooool00ol0003oooooooooo`0Toooo
o`004Oooool3o`0003Wooooo00<0/:G=0;FXc02eZ<`00`2eZ<`0102jZl/0^j_:0;^[bP2kZlX30;n^
b@030<2^b033/LP0`k7800<0`k781@37/lL50<Zfa`D0cKW700@0c[[60<nka`3?^lL0ck_70P3@_<L3
0=2mb080dKk800<0d<3:0=;1b@3B`LT00P3B`LT50=;2c0030=?3b`3Aa<h0dLC>00;o000000<0d/G>
0<o5d03@a]000P3@a]00103Aam00c/OC0<k7d`3>am<20<o8d`80blOF0`3<b=L01@38amT0b<SI0<S8
f@38b=T0a<OL00<0aLOL0_ooool00ol0003oooooooooo`0booooo`?o00000ooooolZojVmj0OoZKgW
202Y^nH80:Vhi0L0Z;;O00<0YjOG0:NXe`2WZ=L0202WZ=L00`2TVl`0YI_<0:FKc0020:FKc0<0YIc=
0P2UWLd00`2RSl40Xi720:>A`P020:>A`P@0Xi;30P2TU<@00`2RR;T0XhZk0:>:^`020:>:^`<0Xhbl
0_l000000`2TS[h0XhNf0:B9^0030:B9^0<0YH^j0`2VS[`00`2WR[L0Z8fi0:R=^@020:R=^@@0ZI2k
1Oooool00ol0003oooooooooo`0Sooooo`004?ooool2o`0003Wooooo102`YLd40;FXc0D0^j_:00@0
_jk90<2^b030[/P0`:k80`33/LP20<Baa`<0ak?70P38]<H30<Zfa`80c;O60`3=^LL30<jjaP030<nk
a`3@_<L0d;c70080d;c700D0d;g80=6nb03A_/P0dKk80=:ob0030=;1b@80dl;90`3B`/`01`3C`l_o
0000o`000?l00000d/G>o`00003BaLh00`3@a]030=77d0050<k7d`3?b=<0clSC0<o8d`3;amH0103<
b=L30<S8f@040<S8fP35am`0aLOL0<G7g080aLSL00?oooooo`000?ooool0<_ooool2o`0000;ooooo
:_nY_NP8ojVmi`L0ZK_V202Y^>@70:Rbg`D0YjOG1P2WZ=L00`2TV//0Y9_<0:BKc0020:BKc0<0YI_<
0P2UW<d00`2RS/00XXo10::?`@020::?`@<0Xi720`2ST/<00`2QQkP0XXRi0::8^@020::8^@<0XhZk
0ol000000`2SS;co00000:>7]P020:>7]P<0Y8Vh102URkX0102VS[`0YhZg0:N:]`2WR[L30:R=^@<0
ZI2k00<0[96jooooooooool00oooool00ol0003oooooooooo`0Sooooo`004?ooool01Ol0003ooooo
o`000?ooool0RJk^00@0PZ[^0P1kY^h307>QkP0406bKk01UU^/0IIK[06FFjbOooooo00<0ZZ;?0;2U
c@2`YLd00`2`YLd30;FXc080]ZW;102kZlX50<2^b0030<>ab034/LL0a;770080a;7700<0ak?70<Rd
aP38]<H00P38]<H00`3:]/L0c;O60<bgaP020<bgaP030<fia`3>^/H0c[[60080c[[6103@_<L0103A
_LH0dKk80=6nb03A_/P30=:ob0030=;1b@3C`/T0dl;90080dl;90ol000000`3C`l/0e<C;0=;5cP02
0=;5cP03o`00003Ca/h0d<K@00@0dLO@1@3?b=<30<c8e`80c<WG00D0b<SI0<S8fP38b=X0b<SJ0<G7
g0040<G8g003ooooool0003ooooo037ooooo00?o0000ojVmj?nY_NP0:?nY_NP8ojVmi`80ZK_W1@2Y
^nH80:Vhi0L0Z;;O00<0YZOG0:NWe`2WYmL01P2WYmL20:NXe`D0Y9[;0`2TVl`20:FKc0030:6=_`2R
S/00XXk00080XXk00`2RSl440:>A`P040:>B``2QQkP0XHNh0:67^0<0XXRi0ol000001P2SR[/0Xhbl
0:><_02RQ;@0XhNfo`000080XhNf0`2TRKP30:F;^P030:J8]02WR[L0YhZg0080YhZg102XSKT0102Y
T;/0[96j0:bA^P2/TKX5ooooo`03o`000?oooooooooo02;ooooo000@ooooo`03o`00002?/Nh0Sk7^
00<0RJk^1022Z^h207^VkP<0Lj7^00@0K9_/06FFj`1UU^/0IIK[0P1OTNT205^<i`<0FXWU7?ooool0
0`2SWm40ZZ;?0:ZRc`020:ZRc`D0/:G=00@0]JS<0;JYb`2fZL/0]ZW;0`2kZlX20;b/b@@0`:k81@34
/LL50<RdaPD0c;O61@3>^/H00`3?^lH0d;c70=2la`030=6maP030=6nb03B_lP0d[o80080d[o80P3C
`/T3o`0000<0dl?;0`3Da</01@3BaLh0dlK>0=?6c_l00000dlO>00<0dLO@0P3Bb=050<o8d`040<c8
e`3<bML0c<WG0<c9e`<0b<SJ0P39bMX40<G8g003ooooool0003ooooo037ooooo00?o0000ojVmj?nY
_NP09OnY_NP8ojVmi`H0ZK_W00<0ZK_V0:Vii02Y^N@01P2Y^>@70:Rbg`D0YZOG1P2WYmL00`2TVL/0
Y9[;0:BJb`050:BJb`80Y9_<00<0XHbn0:6=_`2QSKl00P2QSKl30::>`0@0XXo10P2STL800`2PQKL0
XHNh0:67^0020:67^0?o00000`2SR[/00`2QPk80XXBd0::4]0020::4]0030:>7]_l00000XhNf00@0
Y8Vh00@0YH^j0:J8]02VR;@0YXRd0`2WR[L30:R=^@030:^>^02/TKX0[96j0080[96j1Oooool00ol0
003oooooooooo`0Rooooo`004?ooool01?l0003ooooo08nakP2?/Nh308V^kP80PZ[^00<0OjW_07RT
kP1hY>h00`1_Wnh206NIk0<0IIK[0P1OTNT205^<i`80FXWU0`1KQn<305j7hQ?ooooo00<0VYcD0:>O
d@2SWm400P2SWm440:ZRc`80/:G=0P2aY/d50;JYb`040;^[bP2l[<T0_:c90;b/b@<0`:k80P31[lP3
0<Baa`80a[;71038]<H0103:]LH0c;O60<bgaP3<]lH20<fhaP<0c[[60P3?^lH00`3@_<L0dKg60=6m
aP020=6maP@0d[o80ol000020=?2b@80e<?900<0dl?;0=C4b`3Da</00P3Da</30=?6cP040=?7c_l0
0000dlO>0=77d0<0d/S@00D0d/WA0<o8d`3?b=<0clSC0=39e0030<c9e`80cLWG00<0b<SJ0<W9fP39
bMX00P39bMX40<G8g003ooooool0003ooooo033ooooo00?o0000oooooonY_NP08onY_NP7ojVmi`80
ZKcW1P2Y^nL00`2Y^ND0ZKWT0:Vii0020:Vii080ZKST0P2X/^050:Rbg`T0YZOG0P2WYmL00`2SVL/0
Y9W;0:BIb`020:BIb`D0Y9[;00<0X8bn0:6<_P2QS;h00P2QS;h30:6=_`@0XXk00P2RSl400`2OQ;D0
X8Fg0:25]`020:25]`?o0000102RR;T00`2SR[/0XH>b0:63/P040::4]080XhNf00Go00000:>7]P2T
RKP0Y8Vh0:F5/P040:J8]0@0YhZg00<0Z8fi0:^>^02[S[P0102/TKX6ooooo`03o`000?oooooooooo
027ooooo000?ooooo`04o`000?ooooooooooooooo`80SK7^0`27[Nl307nYk`80N:C^0`1_Wnh206NI
k080Gi?[0`1IS^T205^<i`80FXWU0`1KQn<205j7hP80I8OP0`1[RMh;ooooo`03096HeP2JW=@0VYcD
0080VYcD0`2SWm430:ZRc`030:ZSc`2aY/d0/JK=00<0/JK=0`2fZL/00`2gZL/0_:c90;b/b@030;b/
b@030<2^b031[lP0`Jo80080`Jo800@0a;770<Jba`36//L0a[;70`38]<H30<ZeaP030<bgaP3=^<H0
cKS60080cKS600@0c[[60<nkaP3?^lH0ck_61@3A_LH0103B_/Ko0000o`000?l000030=C1a`050=?2
b@3D`lT0e<?90=C3b@3Ea<T00`3Da</20=G5b`050=?6cP3Calh0dlO>o`00003Calh00`3Bb=030=;9
d@050<o8d`3@bM@0d<WD0=39e03<bML00`3=bML00`3=b]L0bLWJ0<W9fP020<W9fP<0aLSL0P35bMd0
0ooooooo0000ooooo`0^ooooo`04o`000?ooooooooooooooob3oZKgX1onY_NL60:Vli`80ZK_W1@2Y
^ND20:Vii080Z;?P102X/^020:Rbg`030:JXe`2VYmL0YZOG00L0YZOG102SVL/40:BIb`80Y9[;00<0
X8^m0:2<_P2PS;h00P2PS;h30:6<_P@0XHfo0P2RS/000`2OP[@0WhBe09n4]@0209n4]@?o0000102Q
QkP20::8^@040:61/@2QPk80XH>b0:63/P@0XXBd0P2SQkH00ol00000XhNf0:B9^0020:F5/P@0YXRd
0`2WR[L00`2ZS;D0Zhjh0:^>^0020:^>^0@0[96j1_ooool00ol0003oooooooooo`0Pooooo`003ooo
ool00ol0003oooooooooo`02ooooo`80SK7^0`27[Nl207nYk`<0N:C^0`1_Wnh206NIk080Gi?[0`1I
S^T0101ERNH0DhGU05>5i@1CQND305^7h`80GXOR0P1TQn0206^9gP<0M8gM0`1nT=/308RDf@@0TISF
0`2JW=@40:>Od@040:ZRc`2ZXll0ZZ??0:ZSc`@0/JK=00<0]ZW;0;NYb`2gZL/00P2gZL/30;b/b@03
0;f]b@31[lP0`Jo80080`Jo800<0`[380<Jba`36//L00`36//L00`38]<H0b[G60<ZeaP020<ZeaP@0
cKS600<0c[W50<nkaP3?^lH00P3?^lH00`3A_<H0dKg60=6maP03o`0000030=:naP3B_lP0e<7700<0
e<770`3D`lT30=G4b@050=C4b`3EaL/0eLG;0=G5b`3Fa//00`3Calh00ol00000e<S>0=;8d0040=;9
d@<0d<WD00@0d<[D0<g9e`3=bML0cLWG0`3=b]L40<W9fP060<G8g035bMd0aLWM0<G9gOoooooo0000
;oooool00ol0003oooooooooo`02oooooakoZKgX1_nY_NL70:Vli`L0ZKWU1P2X/n020:Rbh0030:JX
f02VZ=L0YZSG0080YZSG1@2VYmL80:>Ib`80Y9W;00<0Wh^m0:2;_@2PRkd00P2PRkd30:2<_P<0XHbn
0`2QSKl01@2NPK@0Wh:d09n2]02OP[@0WhBe00?o00000`2PQKL30:67^00409mo[`2QPK40XH6a0:61
/@@0XH>b102RQ;@20:>7]P03o`00002UQK80YHFb0080YHFb102VR;@00`2WR[L0ZXbe0:Z<]@040:^>
^0<0[96j00<0/iVmooooooooool01?ooool00ol0003oooooooooo`0Pooooo`003oooool00ol0003o
ooooooooo`03ooooo`80Rk3_0`24[>l207bXk`<0M:?_0`1[WNh206:Fk080FY3Z0`1IS^T00`1ERNH0
DhGU05>5i@0305B4h`80F8?Q0P1TQn0306^9gP<0M8gM0`1nT=/308RDf@<0TISF102JW=@20:>Od@03
0:>OdP2ZXll0ZZ??0080ZZ??102aY/d50;NYb`030;b/b@2m[LT0_Jg90080_Jg90P31[lP20<:`b0@0
a[;700<0ak?60<ZeaP3:]LH00P3:]LH20<^faP80cKS60`3>^LD20<nkaP040=6la_l0003o0000o`00
00@0d[k6103D`LL20=G2a`030=C3b@3Ea<T0eLC90080eLC90`3EaL/30=K6b`050=?7cP3Db<h0e<S>
o`00003EbLh00`3BbM420=?9d@050=39e03@b]@0d<[D0=3:e03=bML0103=b]L30<W9fP030<W:fP35
bMd0aLWM00<0aLWM00?oooooo`000?ooool0;Oooool00ol0003oooooooooo`03oooooakoZKgX0_nY
_NL70:Vli`L0ZKWU0P2X/n460:Rch0D0YZSH0`2VZ=L20:JWe`/0XiW;00@0Y9W;09n;_@2ORkd0Wh^m
0`2PRkd30:2<_P@0XHbn00@0XHfo09j1]02NPK@0Wh:d0ol0000309n4]@@0X8Fg00<0XHNh09mo[`2O
Ojl00`2QPK440:63/P<0XXBd00D0Xh6_0:B3/@2TPk40Y8>ao`0000030:F5/P<0YXRd00<0ZHVc0:Z<
]@2ZS;D00P2ZS;D30:^>^0040:bA^P2cVKd0/iVm0;>I_@Oooooo00?o0000ooooooooool07oooool0
00oooooo00?o0000ooooooooool01?ooool208^`k`<0Q:c_0P1lZ>l307BSk`<0Jig^0P1RU^`205Z@
jP80Dh[X0P1>QNH205>5i@<0E8CS00@0F8?Q05j5h01NQN00GXGP0`1[RMh307B=g@<0OY3K0`28U=T3
096HeP80VYcD00<0VY_D0:>OdP2SWm800P2SWm840:ZSc`@0/JK=0`2gZL/00`2hZ//0_Jg90;f]b@03
0;f]b@030<6_b032/<P0`[380080`[380P36//L30<NcaP80b[G60`3;]/H00`3=^<H0c[W50<jia@02
0<jia@?o00000P3A_<H50=:naP030=BoaP3D`LL0e<7700<0eL;71@3Ea<T00`3FaLT0eLG;0=K6b`03
0=K6b`<0e<S>00@0eLW>o`00003EbLh0d/WA0`3CbM430=3:e080d<_D0`3=b]L20<g;e`040<W9fP39
b]X0bL[J0<W:fPD0aLWM00?oooooo`000?ooool0;?ooool00ol0003oooooooooo`04oooooacoZKgX
1`2Y_>L80:Vii@030:Rdh@2X/n40Z;?Q0080Z;?Q0P2X/n000`2VZMT0YZSH0:JXf0050:JXf080YZSG
00<0Xi[;0:>Ib`2SVL/02P2SVL/00`2OR[d0Wh^m09n;_@0209n;_@<0X8^m102PS;h20:6<_P0309f0
/`2NPKCo000000;o00000`2OP[@409n4]@80X8Fg00@0Wgf^09mo[`2OOjl0Wgn_102QPK430:63/P04
0::4]02SPJl0Xh6_0:>1[`<0Y8>a00D0YHFbo`00002UQK80YHFb0:J8]0030:V9/`@0ZXbe0P2[S[P0
0`2bU[/0/iVm0;>I_@030;>I_@Oooooo00?o0000ooooooooool07_ooool000oooooo00?o0000oooo
ooooool01Oooool208V_k`<0PZc_0P1iYnl3072Qk`<0IY_^00@0G9C/05>=jP1CSNX0DhgZ0P1CR^P2
04j5iP80CH;T0`1DQ><00`1HPn40GXGP05j5h00306N7gP<0LH_M0`1kSm/308JCf@<0T9OG102JVm@4
0:>OdP80ZZ??00<0Zj??0;6Vc@2aY/d00`2aY/d0102gZL/0^:[;0;RZb`2hZ//40;f]b@D0`[3800<0
a[;70<NcaP37/lH00P37/lH00`3:]LH0bkK60<^faP020<^faP<0c[W50_l000050=6laP040=:ma@3B
_/H0d[k60=:naP80e;o600<0e<770=G2a`3E`/L00P3E`/L0103F`lL0eLC90=G4b@3Ea<T20=K5b@D0
e/K;00H0elO;0=C8cP3EbLh0eLW>o`00003EbLh30=?9d@80dl_A00<0d<[D0=3;e03@bm@00P3@bm@0
103=b]L0cL_G0<g;e`3=bmP30<W:fP80bL_K1@35bMd00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Gooooo6?nY_NP80:Vli`030:Vji@2Y^ND0ZKWU00@0ZKWU1@2X]>420:Rch@030:JZf@2V
ZMT0YZWI0080YZWI1@2VZ=P00`2SV/`0Xi[;0:>Jb`020:>Jb`P0XiW;1@2OR[d309n;_@@0X8^m0P2P
S;h00`2MOk80WH2c09f0/`02o`0000<0WX6d0`2OP[@309n4]@0409il[@2OOJh0Wgf^09mm[P@0Wgn_
0`2QPK420:63/P030:9o[@2SPJl0Xh6_0080Xh6_102TPk400ol00000YHFb0:F5/P040:V9/`@0ZXbe
00@0Zhjh0;:F^`2bU[/0/YJk102cVKd7ooooo`03o`000?oooooooooo01kooooo000?ooooo`03o`00
0?oooooooooo00Kooooo0P29[nl308:/k`80NJO_0`1`XNl306JKkP0505bDk01CSNX0DhgZ05>=jP1<
QnL00`1>QNH204f2i080CX3R0P1BP>4205j5h0<0IhON0`1aRmd307^?f`<0QY?I0`2@UmL409ZKe0<0
XioB102[Xll30;6Vc@030;:Wc@2hZ//0^:[;0080^:[;0`2m[LT20;j^b@<0`[3800<0a;770<NcaP37
/lH00`37/lH50<^faP?o000000<0c[W50=2ja@3@^/D00`3A_<H30=:ma@050=:naP3D_lH0e;o60=Bo
aP3E`LH00`3E`/L30=K3a`050=G4b@3FaLT0e/G90=K5b@3Ga/T00`3Fa//20=O7b`070=O8b`3EbLh0
eLW>0=G9c_l00000e/[>0=?9d@030=?;d@040=C;d@3@bm@0d<_D0=3;e080dLcD00D0cL_G0<g;f03=
bmP0cL_H0<W:fP040<W;f`<0aLWM00<0aL[Nooooool00000;?ooool00ol0003oooooooooo`06oooo
oaGoZKgX1`2Y_>L50:Vji@80ZKWU0P2X]>850:Rdh@030:JZfP2VZ]T0YZ[I0080YZ[I102VZMT20:JX
f0040:>Kc@2SV/`0Xi[<0:>Jc0<0Xi[;1P2SVL/709n:_@@0Wh^m0P2PRkd00`2LOk80WGnb09eo/P03
o`000080WH2c0`2NPK@309n2]00409n4]@2NO:d0WWb]09il[@<0Wgf^102OOjl30:61/@030:63/P2R
Ojd0XWn]00D0Xh6_0`2TPk40102UQK;o00000:R7/@2XQk440:V9/`<0ZXbe102bU[/40;>I_@Sooooo
00?o0000ooooooooool07Oooool000kooooo00?o0000ooooooooool02?ooool208N_k`<0Oj_`0P1f
YO0306bOk`80HIS^0P1GTN`305>=jP0304b7i`17P^D0Ah;U00<0AGkS0P1>P>80101BP>40FH;O05V2
g`1IP]l306N7gP80LH_M0`1kSm/308JCf@@0T9OG0P2JVm@00`2IVm@0XioB0:>OdP020:>OdP@0Zj??
00@0/JK=0;:Wc@2bYld0/ZO=102hZ//00`2m[LT0_Zk90;j^b@020;j^b@040<:`b034/LL0a;770<Ba
a`<0ak?60P38]<H0103;]/Ko0000o`000?l000020<bga@030<jia@3@^/D0d;[50080d;[500<0dKc6
0=:ma@3B_LD00P3B_LD30=BoaP<0eL7600<0eL;70=K3a`3F`lL00P3F`lL30=K5b@<0elK900@0e/K;
0=O7b`3Gal/0elO;0P3Gb</0103EbLh0e/[>0=K:c_l000030=?;d@<0e<_A00@0d<_D0=7<e03Ac=@0
dLcD0`3=bmP00`3=c=P0bL_K0<W;f`040<W;f`060<G9g@35b]h0aL[N0<G:g_oooooo0000:_ooool0
0ol0003oooooooooo`08oooooa7oZKgX1`2Y_>L20:VjiPD0ZK[U0P2X]N840:RdhP80Z;CQ00@0YZ_J
0:JZfP2VZ]X0YZ[J102VZ]T20:JYf@D0Xi_=0P2SV/`40:>Jb`80XiW;00<0WXZn09n:_@2OR[d0202O
R[d209n;_@0309an/P2LOk80W7nb00?o000000<0WGnb09f0/`2MP;<00P2MP;<309j1]080Wh:d00<0
WG^/09il[@2NO:d00P2NO:d409mm[P<0Wgn_0P2QPK400`2QOJ`0XWn]0:9o[@020:9o[@@0Xh6_0`2T
Pk40102UQK80Z8Nao`00002XQk440:V9/`80ZXbe0P2aU;T30;:F^`<0/iVm0P2nZlH8ooooo`03o`00
0?oooooooooo01cooooo000>ooooo`03o`000?oooooooooo00Wooooo0P27[nl307n[l080MZG`0`1/
Wnl2066HkP80Ei7/0P1=R^T204F3i`80Ah;U0P15O^<204Mlh@80DX3Q0P1IP]l306:5gP<0KHWM0`1k
Sm/308JCf@80T9OG00<0SiOG09VKe02IVm@00P2IVm@30:>OdP<0Zj??00<0ZjC?0;:Wc@2bYld00P2b
Yld30;RZb`030;V[b`2n[/T0_Zk900<0_Zk91@34/LL00`37/lH0b;C6o`000002o`0000030<^faP3<
]lD0c;O50080c;O51@3@^/D0103A^lD0d[g50=:ma@3B_LD20=>na@030=BoaP3E`LH0eL760080eL76
00@0e/;60=K3a`3F`lL0e/?70P3Ga<L00`3FaLT0elK90=O6b@020=O6b@<0elO;0`3Gb</30=K:cP03
0=K;c_l00000dl_A00@0e<_A0`3Ac=@20=7<e@040<g;f03=c=P0cLcH0<g<f0@0bL_K00<0bLcL0<G:
gP35b]h00P35b]h00ooooooo0000ooooo`0Yooooo`03o`000?oooooooooo00Wooooo3OnY_NP70:Vl
i`H0ZK[V0P2Y^^D00`2X]^80Z;GR0:RehP020:RehP80Z;CR00<0YjcK0:J[fP2VZmX00P2VZmX30:JZ
fP80YZ[I00<0Xic>0:>Kc@2SVld01@2SVld30:>Jc080Xi[;102NR[h909n:_@0309]n/P2LO[80W7jb
00?o000000<0W7nb09eo/P2MOk800P2MOk8309f0/`80WX6d00@0W7V/09ek[02MNj`0WG^/1@2NO:d3
09mm[P<0Wgn_00<0XH6a0:5m[02QOJ`0102ROjd40:>1[`80Y8>a00D0YhF_0:R7/@2XQk40Z8Nao`00
00040:V9/`040:Z<]@2aU;T0/IBi0;6D^@@0/YJk00<0/iVm0;j[aP2nZlH00P2nZlH7ooooo`03o`00
0?oooooooooo01cooooo000>ooooo`03o`000?oooooooooo00[ooooo0P26[_0307fZl080LjC`0`1X
WNl0101LU^h0Ei7/05NAk01GTN`204f:j@0404F3i`10O^@0@7kT041ni080AGkS00@0AgcQ04]lh01;
O>00BgcP0P1IP]l306:5gP80KHWM0`1iS]/308BBf@@0SiOG0`2IVm@40:>OdP040:^Sc`2[Y<l0ZjC?
0:^Tc`@0/ZO=00@0^:[;0;V[b`2iZl/0^J_;0`2n[/T20;n^b@<0a;770ol000030<RdaPD0c;O500@0
c[S50=2ja@3@^/D0d;[50`3A^lD0103B_LD0dkk50=>na@3C_/D50=G1aP80e/;600D0e/?70=O4a`3G
a<L0elC70=S5a`030=O6b@80f<O900<0elO;0=O8b`3Gb</00P3Gb</01P3Hb/`0e/[>0=K;cP3Fblko
00000=O<c`<0e<_A0P3Dc=801@3Ac=@0dLcE0=7<e@3Ac=D0dLgF00<0cLcH0P3=cMT01039bm/0bLcL
0<W<g039c=`40<G:gP03ooooool0003ooooo02Sooooo00?o0000ooooooooool02oooool8ojVmj0P0
ZKcW1`2Y^^H20:Rfh`<0Z;KR0P2X]N800`2W[M`0YjcK0:N/f`020:N/f`<0YZ_J0P2VZ]X00`2SWLl0
Xic>0:>LcP020:>LcPD0Xi_=00@0WXc009j;_`2NRkl0WX^o1`2NR[h509n:_@0309]m/P2KO[80Vgjb
00?o00000P2LO[8309ao/P<0WGnb0P2MP;<0102KN:/0W7V/09ai[02LNJ`409ek[0@0WWb]0`2OOJh2
09mo[`030:1kZ`2QOJ`0XGf/0080XGf/0`2ROjd40:>1[`040:B3/@2WQJl0YhF_0:N5[`80Z8Na00Go
00000:R7/@2YRK<0ZHVc0;2A]`040;6D^@<0/YJk00<0_JS40;j[aP2nZlH00`2nZlH8ooooo`03o`00
0?oooooooooo01_ooooo000>ooooo`03o`000?oooooooooo00_ooooo0P26[_0307fZl080LjC`0`1X
WNl0101LU^h0DHk/056>k01AS^`204J6j@0304F3i`10O^@0@7kT00<0?W[R00<0AgcQ04]lh01;O>00
0`1COml306:5gP80KHWM0`1iS]/308BBf@<0SiOG102IVm@20:>OdP030:>PdP2[Y<l0ZjC?0080ZjC?
0`2bYld00`2cZ<d0^J_;0;V[b`030;V[b`040;j^b@2o[/T0_jk90;n^b@?o00000P35//L30<RdaP80
b[G60`3<]lD30<jha@030=2ja@3A^lD0dK_50080dK_5103C_/D0103E_lD0eL760=G1aP3E`LH30=K2
aP@0elC70P3HaLL01@3Ga/T0f<O90=S7b@3HalT0fLS900<0elS;0P3Hb/`30=K;cP040=O<col00000
elc?0=C;d@<0e<cB0`3Ac=D30=7=eP040<g<f03=cMT0cLgI0<g=f@@0bLcL0`35b]h01034bmoooooo
ooooool0000Xooooo`03o`000?oooooooooo00cooooo1OnY_NP70:Vli`80ZK_V1@2Y^^H20:Rgh`@0
Z;KS00<0Z;KR0:N^g02W[M`00`2W[M`40:N/f`030:J[fP2SW]00Xig?00<0Xig?102SW<h00`2SVld0
WXc109j<`00309j<`0<0WX^o1P2NR[h209n:_@0309Ym/P2KOK80Vgfb00?o00000P2KO[8309an/P<0
W7nb0`2MOk800`2MP;<0VgR[09]hZ`0409ai[0<0WG^/102NO:d209mm[P0409mjZP2PNj/0X7^[0:1k
Z`@0XGf/102ROjd20:>1[`030:J2[P2WQJl0YhF_0080YhF_0`2XQk400ol00000ZHVc0;2A]`020;2A
]`@0/IBi00@0/YJk0;fXa02mZ<@0_JS40`2nZlH20<k=f0?ooooo00H0000008o^j02Vj?/0Y^Skoooo
ool0000Looooo`003_ooool00ol0003oooooooooo`0<ooooo`80Q:k`0`1jZO02072Sl0<0I9c_00@0
EiC^056>k01AS^`0DHk/0P16Q^T00`0nOnH0@7kT041ni00203ijhP80?gSP0P1;O>0205=og`<0GH;N
0`1YQmd307V>f`<0Q9;I0`2?UmL209VKe00309VKe@2SX=80Xj3B0080Xj3B102[Y<l0102bYld0/jS=
0;>Xc@2cZ<d30;V[b`030;Z/b`2o[/Wo000000;o000000<0_jk90<Baa`35//L00`35//L00`38]<H0
b[G60<ZeaP020<ZeaP030<bga@3>^<D0c[S50080c[S5103A^lD20=:la@80dkk50`3E_lD00`3E`LH0
e/;60=K2aP020=K2aP030=S3aP3Ga<L0elC700<0f<G70`3HalT30=W8b@060=O8b`3Hb/`0f<[<0=S:
c03Ibl`0e/_>0`3Gc<l01?l00000e<cB0=C<dP3Dc=820=G=dP030=7<e@3AcMH0dLgF0080dLgF1@3=
cMT40<W<g0060<G:gP34bml0a<_O0<C;gooooooo0000:?ooool00ol0003oooooooooo`0=ooooo`03
ojVmj02Y_>L0ZKcW00D0ZKcW1P2Y^nH20:VjiPD0Z;OS0P2X]^<0102W[md0YjkL0:N^g02W[]`40:N]
g080YjcK00@0XioA0:>Nd02SW]00Xik@102SWLl20:>LcP0409j=`P2NS<40WXc109j<`@<0WXc00`2N
Rkl509j:_P<0VWfb0ol0000209]m/P<0Vgjb102LO[8209ao/P80WGnb00<0VgN[09]hZ`2KN:/00P2K
N:/309ai[0<0WG^/102NO:d00`2OOJh0WgZZ09mjZP040:1kZ`<0XGf/102ROjd0102SPJl0YX:^0:J2
[P2VPZh30:N5[`@0Z8Na00Co00000;2A]`2`TKL0/96g102aU;T50;fXa0080;j[aP3>cMP0c/gH0<k=
f03BnN?ooooo0000002?k^P20:KXn`030:_Fmooooooo000001cooooo000>ooooo`03o`000?oooooo
oooo00gooooo0P24[_0307ZYl080L:?`0`1TW>l00`1GU>h0Bhc[04^<j`0303n3j00303ioiP0hN^<0
>7[S0080?W[R00@0?gSP04Aig`14NMl0A7WO0P1COml305f2gP80JHOM0`1fS=`308:BfP<0SYOG102I
VmD40:>PdP80ZjC?00<0[:C@0;>Xc@2cZ<d00`2cZ<d0102iZl_o0000o`000?l000030;n^b@030<6`
b@35//L0aK;700<0aK;71@3:]LH50<jha@030<nja@3A^lD0dK_500<0d[c500<0dkk50=Foa@3E_lD0
0P3E_lD0103F`LD0e/;60=K2aP3F`/H20=S3aP030=O4a`3HaLL0f<G70080f<G700<0fLK70=S7b@3I
b<T00`3Ib<T30=S:c080fL_<00L0f/c<0=O<c`3Gc<l0elc?o`00003HcLl0e<cB00<0eLgB00@0eLkC
0=7=eP3AcMH0dLgF0P3Ac]H30<g=f@040<g>fP39c=`0bLcL0<W<g080bLcM1034bml00ooooooo0000
ooooo`0Vooooo`03o`000?oooooooooo00gooooo1P2Y_>L70:VkiP80Z;OT1@2X]n<20:N`gP<0YjoM
0`2W[]`20:N]g0030:BQdP2SWm40XioA0080XioA0`2SW]020:>Mc`0409j>``2NSL80WXg209j=`P<0
WXc10`2NS<0409j;_`0409j:_P2JOK<0VWfb09Ym/P?o00000P2JOK8309]m/P@0Vgjb0`2LO[800`2L
Ok80VWNZ09]gZ`0209]gZ`@0VgR[0`2LNJ`409ek[080WWb]00<0WWRY09mjZP2ONZX00P2ONZX30:1k
Z`@0XGf/0P2ROjd00`2UPJ`0YX:^0:J2[P020:J2[P@0YhF_0P2XQk400`2_SkGo00000;2A]`020;2A
]`<0/IBi0P2mY/<30;fXa0090<o=e`3>cMP0c/gH0<k=f03BnN<0T^V_083XfP2RjoX0Z]Wh00@0ZmKg
00?oooooo`000?ooool06_ooool000gooooo00?o0000ooooooooool03_ooool308:]l0<0N:Sa0P1/
X_03062Jk`0305:Bk@1;S>/0Bhc[0080?h?X0P0fNn@203Qjh`80=WKQ00<0?gSP04Aig`14NMl00`1=
O=l205f2gP<0JHOM0`1fS=`308:BfP<0SYOG102IVmD30:>PdP@0[:C@0P2cZ<d3o`0000@0^Zc;00@0
_jk90<6`b@31/<T0`K390`35//L20<Jca`<0b[G60P3;]lH30<jha@80ck[500<0dK_50=:la@3B_<D0
0P3B_<D0103D_/D0eKo50=Foa@3E_lD30=K1a@050=K2aP3H`lH0f<?60=S3aP3Ia<H00`3HaLL20=W6
a`040=[8a`3Ib<T0fLS90=W8b@80f/W900@0f<[<0=W;c03Ibl`0fL_<0P3Jc<`0103Gc<l0f<g?0=S=
col000030=G=dP<0eLkC00<0dLgF0=7>eP3Ac]H00P3AcmL01@3=cMT0cLkJ0<g>fP3=c]X0bLcL00<0
bLcM00H0b<gM0<C;g`34bml0a<_O0<C;h?l0000Vooooo`03o`000?oooooooooo00oooooo0P2Y_>L2
0:Vki`D0ZK_V0P2X^>@40:Rgi0030:Rgh`2W/=l0Yk3O00@0Yk3N0P2W[md20:N^g0030:BRd`2TXM80
Y:7B0080Y:7B0`2SWm420:>Nd00409j@a02NS/<0WXk309j>``@0WXg20P2NS<4409j<`080WX^o00<0
VWjc09Ym/ol000000_l0000509Ym/P@0Vgfb0`2KO[8209an/P0309UfZP2JMjX0VWNZ00@0VgN[0`2K
N:/409ai[0<0WG^/00<0WWb]09ihZ@2NN:T0102ONZX30:1kZ`@0XGf/00@0XWn]0:F1[02UPJ`0YH6/
0`2VPZh40:N5[`050:R7/@2_SkD0[hne0:n?]Ol000000`2`TKL01@2aU;T0_JK30;fV``2mY/<0_JS4
00@0clgG00D0c/gH0=;ih`2BjJl0WNgh0:;[nP030:[In080ZmKg0P2[b_000ol0003oooooooooo`0I
ooooo`003Oooool00ol0003oooooooooo`0?ooooo`<0PZg`0`1hZ?4206bRl0<0H9[_00<0DY;]04F8
jP15R>X00P0oPnP203Iki080<7GQ00<0=WKQ03Mdg`0gM=l00P14NMl204elg`<0F83N0`1YQmd307J<
g080PY;J102>UmL209VKe@0309VLe@2SX=80Xj3B0080Xj3B0`2/Y=02o`0000<0]:W=102j[</50<6`
b@030<Fba`36/lL0a[?70080a[?700<0b[G60<^gaP3;]lH00P3;]lH0103>^<D0ck[50<nja@3?^/D5
0=:la@80e;k500<0eKo50=K1a@3F`LD00P3F`LD30=S3aP<0fLC600@0f<G70=W6a`3Ia/L0fLK70P3J
b<L0103Ib<T0f/W90=[9b@3JbLT30=W;c0<0f/c<0`3HcLl00`3Hc]3o00000=G=dP030=G>d`80eLoC
00@0dLkF0=7?e`3AcmL0dLoG103=c]X30<W<g@<0b<gM00D0a<_O0<C;h034bn00a<_Po`00000Uoooo
o`03o`000?oooooooooo013ooooo102Y^nL20:VkiP030:Vhi@2X^>@0Z;ST0080Z;ST0P2X]n@00`2W
/Ml0Yk3O0:N`g`020:N`g`80Yk3N00@0Y:GF0:BTe@2TY=D0Y:CE0`2TX]<40:BQdP030:>Od@2OTLD0
WY3400<0WY340`2NS/<309j=`P<0WXc10P2NS<000`2IO[@0VWjc09Yn/`02o`000080VWfc1`2JOK83
09]m/P80Vgjb102IMZX309YgZP<0VgN[0`2KN:/409ai[080WG^/00<0WGNX09ihZ@2NN:T00P2NN:T3
09mjZP@0X7^[0P2QOJ`00`2TOZ/0YH6/0:F1[0020:F1[0@0YX:^0P2WQJl00`2^SK<0[hne0:n?]@02
0:n?]@040;2A]ol00000/96g0;bT`@@0_JK300@0d<gF0<o=e`3?cML0clgG0P3Bo>0209g]n080ZM_i
0P2ZfOP20:_;l@80Zl[`0P2Z`n`00ol0003oooooooooo`0Hooooo`003Oooool00ol0003ooooooooo
o`0@ooooo`<0P:ca0P1eYo4306VPl@80FiS_0P1=Snd204F8jP0503Qoi`0^Mn<0;WOS02igh`0`MN40
0P0]LMl203Mdg`80?GGN0P1=O=l205R0gP<0IHGM0`1bRm`2082AfP@0SIOH0`2IW=D40:>PdP?o0000
00<0[:G@0;BYc@2dZLd00P2dZLd30;Z/b`80^jg;1031/<T50<Jca`@0bkO600@0cKS60<nja@3?^/D0
ck[50P3@^lD30=:la@<0e;k5103F`LD20=O2a@030=S3aP3Ia<H0fLC60080fLC60`3Ia/L30=[8a`<0
f/W90P3KblT00`3Ibl`0f/c<0=[<c0020=[<c0030=[=c@3HcLl0f<k@0080f<k@00?o00000=S?d03E
c]<00`3Ecm<50=7?e`@0cLkJ00D0bLcM0<S=g@38cMd0b<gM0<S=gP030<C;h0030<?;h?oooooo0000
02Cooooo00?o0000ooooooooool04Oooool20:Vki`80ZKWU0`2Y^>D20:Rhi080Yk;P0`2W/Ml20:N`
g`030:FWe`2TYMH0Y:GF0080Y:GF0`2TY=D30:BRd`80Y:7B00@0Wi?709nAa@2OTLD0Wi750`2NT<@3
09j>``<0WXg20P2NS<400`2IOkD0VGjd09Un]003o`00000409Yn/`2JOK<0VWfc09Ym/`L0VWfb0P2K
OK800`2HMJX0VGJZ09UfZP0409UfZP<0VWNZ0`2KMj/409]hZ`80W7V/00@0W7JW09egZ02MMjP0WGNX
102NN:T309mjZP@0X7^[00<0XGf/0:AnZ`2TOZ/0102UPJ`40:J2[P040:N5[`2^SK<0[Xfc0:j=/`@0
[hne00@0/96go`00002lY<40_:C10P2mY/<30=3=eP030<o=e`3Bo>00d_cP0080Z=kj0P2YfoT20:_=
lP80Zl_a0P2Za>`40:[3k003o`000?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo017o
oooo0`20[?4207FWl@<0JJ3a0P1KV>l204f?k@80?XGY00<0>7oW02igh`0^Mn<00P0WLN001@0]LMl0
;g3N02m`gP0_L=h0?GGN00<0AWSN0P1HP=h306F5g@80LX_L0`20TMX408fGf0<0VIcE0ol00000102S
X=80[:C@0:bUd02/YM050;BYc@040;Z/b`2k[L/0^jg;0;^]b`<0`K390P32/LT30<Jca`80b;C70P3;
]lH30<fhaP030<nja@3@^lD0d;_50080d;_500<0d[c50=Bna@3D_/D00P3D_/D00`3E_lD0e/750=K1
a@030=O2a@D0fLC600<0f/K60=W6a`3Jb<L00`3Jb<L00`3KbLL0f/W90=_;b@020=_;b@040=_<bP3J
c<`0f/c<0=[<c080f/g=00H0flo=0=S>d03Hc]00f<k@o`00003Hcm030=G?d`80eM3D103AcmL0103A
d=P0cLkJ0<g>fP3=c]X20<g?f`050<S=g@38cMh0b<gN0<S=gP34bn000`33bn000ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01;ooooo102Y^ND00`2Y^>D0Z;?Q0:Rch@040:Nbh0030:Nag`2U
Z=T0YJOG00<0YJOG102TYMH00`2TY=D0X9K:09nDb00209nDb0<0Wi?70`2OTLD409j@a00309j>``2I
PKP0VH2f0080VH2f0P2IOkD3o`00000309Un]02JO[<0VWjc0080VWjc0`2JOK<509Ym/P0409MeZP2H
MJX0V7FZ09QeZPH0VGJZ0`2JMjX409]gZ`<0VgR[00<0W7V/09afY`2LMZL0102MMjP309ihZ@@0WgZZ
0P2PNj/00`2ROJX0Y7j[0:AnZ`020:AnZ`@0YH6/0P2VPZh00`2]R[40[Xfc0:j=/`020:j=/`@0[hne
00D0_:C1o`00002lY<40_:C10;fV``040=3=eP040=3ng03Bo>00Z=kj0:SNnP80Z/kc0P2[cO820:[4
k@@0Z/C/0P2Z`n`00`2Z`>[o0000ooooo`0Hooooo`003Oooool00ol0003oooooooooo`0Booooo`<0
OZca0P1cY_4306JOl@0405NGk`1=Snd0CHo]04f?k@80?XGY00<0<GcU02igh`0^Mn<00P0WLN000`0]
LMl0;g3N02m`gP0203Eag@80AWSN0`1BOMh206F5g@<0LX_L0P20TMX408fGf0?o00000P2SX=820:>Q
d`@0[:G@0`2dZLd00`2eZ/h0^jg;0;^]b`030;^]b`030<6`b@32/LT0`[790080`[7900D0a[?70<Rd
a`38]<L0b;C70<^gaP040<fhaPD0d;_500@0d[g50=Bna@3D_/D0e;k50P3E_lD00`3F`LD0el;50=O2
a@020=O2a@040=W4a@3Ia<H0fLC60=W4aP80f/K600@0flO60=[8a`3Jb<L0f/S70P3KbLL0103LblP0
fl_90=_;b@3KblT20=_<bP030=[<c03JcLd0f/g=00<0flo=00H0f<k@0=S?d03Hcm3o00000=S@d@3E
cm<30=G@e0<0dLoG0`3Ad=P0103=c]X0cLoK0<g?f`3<cm`30<S=gP80algN0P33bn020<?;h@03o`00
0?oooooooooo027ooooo00?o0000ooooooooool04oooool20:Vii@80Z;CR0`2X/n420:Nbh0040:FZ
fP2UZ=T0YJSI0:FXf@@0YJOG0P2TYMH0102PV<`0X9K:0:2FbP2PU/X309nDb0<0Wi?70`2OTLD209j@
a00509V2^@2IPKP0VH6h09V1^02IP;H00ol0000209Uo]@<0VGjd0`2JO[<309Ym/`80VWfb00@0UgB[
09MeZP2GMJX0UgFZ0`2HMJX709UfZP<0VWNZ0`2KMj/209]hZ`0309]dY`2LMZL0W7JW0080W7JW0`2M
MjP309ihZ@@0WgZZ00<0X7^[0:9mZP2ROJX0102TOZ/40:F1[0040:J2[P2]R[40[HZa0:f:/@<0[Xfc
0`2_SkD01P2lX[l0_:C10;bT`Ol00000_:C10=7=eP<0d<gF00@0d?kL0:OQn`2Zd?<0Z]3c0P2Zc_<2
0:[5k@@0Z/C]0P2Za>`40:[0jP030:VnjOl0003ooooo01Oooooo000=ooooo`03o`000?oooooooooo
01?ooooo0`1n[?4207>Vl@<0IYoa00@0EiO_04R=k@18SNd0B8g]0P0hPnP0100aO>D09W?Q02Ich@0W
LN0202E]g@80;g3N0P0eLMd204IhgP80DWgN0P1PPmh306n:g@<0P97J0ol0000309RLePD0Xj7C0`2/
YM000`2dZLd0]J[>0;FZcP020;FZcP<0^jg;00<0_:k<0<:ab@32/LT00P32/LT00`33//T0b;C70<Rd
a`020<Rda`D0cKS600@0c[W60=2ka@3@^lD0d;_50`3B_LD01@3D_/D0eKo50=Foa@3E_lD0e/7500<0
el;50`3Ia<D0103Ia<H0f/K60=[6aP3Ja/H20=_7aP040=[8a`3KbLL0flW70=_9a`80g<_800H0fl_9
0=_<bP3Kc<X0flc:0=c>b`3JcLd40=_?c@<0f<o@00<0f=3Ao`00003Ed=@00P3Ed=@20=GAe@040=7?
e`3Ad=P0dM3H0=7@f080dM3I00D0cLoK0<c?g03<cm`0c<oL0<S=gP020<O=gP070<O=g`33bn40`l_Q
0<?;h@32bn7oooooo`00000Rooooo`03o`000?oooooooooo01Cooooo102X]>800`2X/n40YJ_K0:F[
f`030:FZfP<0YJSI0P2UYmL0102QV/h0X9S<0:2Hc02PV<`30:2FbP<0WiC80`2OTlL209nAa@0509Z4
^P2IP[T0VH:i09V2^@2IPKP00ol0000209V0]P<0VGne0`2IO[@309Yn/`80VWfc00@0UWB[09MdZ`2G
M:/0UgB[0`2GMJX309QeZPL0VGJZ0`2JMjX209]gZ`0409YcYP2KM:L0VgBW09]dY`@0W7JW0`2MMjP4
09ihZ@80WgZZ00<0XG^Y0:9mZP2ROJX00P2ROJX30:AnZ`@0YH6/102]R[440:j=/`040:n?]@2lX[l0
_::o0;bR_`80_:C100Go00000=7=eP3AcMH0d<gF0=3ng0020:[Am0040:[@l`2Za^h0Z/K^0:[6kP<0
Z/G]0P2Za>d40:[0jPD0ZKkY00?o0000ooooooooool05Oooool000cooooo00?o0000ooooooooool0
5_ooool307b[l@05072UlP1SW_40Hika06>Nl@1CUNl00`18SNd00`0hPnP0:WST02Yhi00202Ich@03
01m/gP0UKMd09FgM00809VcL0P0eLMd203megP80DWgN0P1PPmh206n:g@?o0000102<UmT309RLeP@0
Xj7C0P2/YM000`2]Y]40]J[>0;FZcP030;FZcP030;^]b`2l[/`0_:k<0080_:k<0P32/LT30<>bb@80
b;C70P39]/L30<fhaP<0c[W600<0d;_50=:ma@3B_LD00P3B_LD40=Foa@80e/7500<0el;50=W4a@3I
a<D00P3Ia<D30=[6aP<0flO60`3KbLL30=c;b0<0flc:0P3Lc//0103Mcl/0flo=0=_?c@3Kcld20=_@
cP060=S?d03Hd=40f=3A0=WAdOl00000eM3D0`3EdMD20=GAeP040=7@f03Ad=T0dM3I0=7@f@<0c<oL
0P3<cmd01@37cMh0algO0<O=g`37cMl0`l_Q00<0`/_Q00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Fooooo`80Z;CR00<0YZgL0:F[f`2UZm/00P2UZm/30:FZfP030:FXf@2QW=00XI[>00<0
XI[>0`2PV<`30:2FbP0309nDb02JQkh0VXFl0080VXFl0`2JQ;X0102IP[Wo0000o`000?l0000209V1
^0<0VH2f0`2IOkD309Un]080VWjc00@0UWF/09IdZ`2FM:/0UWB[0`2GM:/309MeZP@0V7FZ1P2IMZX2
09YgZP0409UcYP2JLjH0VW>V09YcYP@0VgBW0`2LMZL409egZ0<0WWRY00<0WgZZ0:5kZ@2QNjT0102R
OJX40:AnZ`80YH6/0P2[R;030:f:/@@0[Xfc102lX[l01P2lY<40dLgF0=7=e_l00000dLgF0<coeP80
Z]7d102Za^h00`2Z`N/0Z/7Z0:[1jP020:[1jP80Z/3Z1`2Y_^T00`2Y_^So0000ooooo`0Fooooo`00
3?ooool00ol0003oooooooooo`0Gooooo`80NZ_b0P1^YO8306>Nl@80DiG_0P13Rn`00`0bOnL0:WST
02Yhi00201i_g`0401m/gP0LJ=/076SK02I/g0<0;FgL00@0?gGN04akgP1<Nmh0H8?N0ol00000101_
R]d0OY7K07jAf`1nTM/308bGf@@0V9cF0P2SXM<00`2SX]@0[JKA0:fVd@020:fVd@<0]J[>00<0]Z_>
0;b^c02l[/`00`2l[/`00`32/LT0`k;90<>bb@020<>bb@030<Rda`39]/L0bKK70080bKK700<0cKS6
0<jiaP3>^LH00P3>^LH50=:ma@030=>na@3E_lD0eKo500<0e/751@3Ia<D00`3JaLD0f/K60=_7aP03
0=_7aP030=c9aP3KbLL0g<_800<0g<_800<0gLc80=_<bP3Lc//00P3Lc//20=g?b`060=_?c@3Kd<h0
fm3>0=_@cP3KdLh0f=3A0P3IdM401?l00000fM;B0=WBdP3EdMD30=GAeP<0dM3I0P3@dMX0103<cm`0
c<oM0<c?g@3<cmd30<O=g`040<K>h032bn40`/_Q0<;;h@80`L_R00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Gooooo`<0YZgL0P2UZm/0102RXM<0XYkA0::Nd@2RW]430:6Ld0@0XI[>0P2P
V<`20:2FbP0409Z9`02JQkh0VXNn09Z7_P<0VXFl0ol0000309V2^@<0VH6h0`2IP;H00`2IOkD0UGJ]
09Ie[00509Ie[0<0UWB[0`2GM:/409MeZP<0V7FZ1P2IMZX00`2JMjX0VG>V09UcYP0409YcYP<0VgBW
0`2LMZL409egZ080WWRY00<0X7VX0:5kZ@2QNjT00P2QNjT30:9mZP@0Y7j[00@0YH6/0:^8/02[R;00
ZhR`102]R[420:j=/`030;^P_P2lX[l0_::o0080_::o00D0d/gE0=7=eP3AcMKo00000<coeP020:[7
k`80Z/K^1@2Z`N/20:[1jPL0ZKkY1@2Y_^P00ol0003oooooooooo`0Dooooo`003?ooool00ol0003o
ooooooooo`0Hooooo`80NZ_b0`1^YO80101OWO40Ci?_04nCk`1?Tnl203f8j`04039oi`0SM>808gCR
01i_g`805VSK00<076SK01eWfP0MImX00P0]KM`0100hL]go0000o`000?l0000205b2gP<0K8WN0`1n
TM/308bGf@80V9cF00<0V9gG0:>Re02SX]@00P2SX]@40:fVd@040;FZcP2fZlh0]Z_>0;J[cP<0_:k<
00<0_[3<0<>bb@33//T00`33//T50<Vfa`D0c[W600@0ck_60=:ma@3B_LD0d[g50P3C_/D00`3E_lD0
e/750=K1a@020=K1a@040=S3a@3Ia<D0fLC50=W4a@80f/G5103KalH20=c9aP040=g;a`3LblP0g<_8
0=c;b080gLc80`3Lc//30=g?b`<0fm3>0P3KdLh30=WAd@030=WBd_l00000fM;B00<0eM7F0P3Ed]L0
103Ad=T0d=7J0=3AfP3@dMX30<c?g@80bm3M00D0algO0<K>h036c^00a/kP0<;;h@030<7;hP03oooo
ool0003ooooo01kooooo00?o0000ooooooooool06?ooool00`2V[M`0Xj?E0::Qd`030::Qd`<0XYkA
0`2QW=020:6JcP0309^=a02KRl80Vh_200<0VXW00`2JQkh3o`0000<0VXBj0`2IP[T309V1^080VH2f
00<0UGJ^09Ef[@2EMZd01`2FMJ`209IdZ`@0UgB[0`2GMJX309QeZPD0VGJZ00<0V7:V09UcYP2ILjH0
0P2ILjH309YcYP<0VgBW102LMZL209egZ00409mhY`2PNJP0X7VX0:1iZ0@0XG^Y102ROJX20:AnZ`03
0:Z6[`2[R;00ZhR`0080ZhR`102]R[40102^SK<0^j2n0;^P_P2kX;h20;bR_`<0d/gE00@0dLgF0<co
e_l00000Z/O_1`2Z`N/00`2Y_nT0ZKkY0:Vnj@040:Vnj@L0ZKkX0P2Y_NP00ol0003oooooooooo`0C
ooooo`003?ooool00ol0003oooooooooo`0Iooooo`80N:[b0`1/Y?801@1LW?40Ci?_04nCk`1?Tnl0
?HS[0080;7cV0P0SM>80100FJmd05VSK019Sf@0BHmT201eWfP;o000000<0>7;M04akgP1<Nmh00`1L
P]h206b9gP<0O93L0`2;UmX409RMe`@0Xj;D0P2]Y]400`2]Ym40]Z_>0;J[cP030;J[cP040;b^c02n
/<`0_[3<0;j`c0<0`k;90P35]<X30<Vfa`80bkS80`3>^LH30<nkaP050=:ma@3C_/D0dkk50=>na@3E
`<H00`3F`LD30=S3a@040=W4a@3JaLD0f/G50=[5a@<0flO60`3LbLH20=g;a`060=c;b03Mc<P0gLc8
0=g<b03Nc/T0g<k;103Mcl/0103Md<`0fm3>0=_AcP3KdLh20=_Bc`070=WAd@3Id]80fM;B0=WBd_l0
0000f=?C0=GAeP020=GBe`80e=?G103@dMX00`3<cmd0bm3M0<_@g@020<[@gP80a/kP0P35c^440<7;
hP03o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool30:>Se@@0XZ7C0P2RW]420:6L
d00409b@aP2KSL@0Vhg409^=a0<0Vh_20`2JRL02o`0000@0VXFl0P2JQ;X209V2^@0409Ah/@2EMjl0
UGN_09Eg[`<0UGJ^0`2EMZd609Ie[0<0UWB[0`2GM:/309MeZP<0V7FZ0P2IMZX0102GLJH0V7:V09Qb
YP2HLZH409UcYP<0VW>V0`2KM:L409afY`0309egZ02ON:L0WgRW00@0X7VX0`2QNjT40:9mZP040:An
Z`2ZQZl0ZXJ_0:Z6[`@0ZhR`0P2]R[400`2iW[`0^j2n0;^P_P020;^P_P030;bR_`3BcMD0d/gE0080
d/gE00@0Z/S_0:[2j`2Z`N_o0000102Z`N/50:Voj@80ZKkY1`2Y_^P50:Vmj003o`000?oooooooooo
01?ooooo000<ooooo`03o`000?oooooooooo01[ooooo0P1hZ_8306bTlP0505bLl@1;T^l0Bi;_04^B
k`0hQ^/00P0/O>H201]ah@803F?I0ol00000100MImX096WK03Qbg@0hL]d204IhgP<0G8;N0P1/RMh3
07b@g0<0RiOJ102HWML20:>Re0030:>Se@2]Ym40[JOA0080[JOA0`2fZlh00`2g[Ll0_[3<0;j`c003
0;j`c0030<>bb@35]<X0aKC:0080aKC:00<0bKK70<^hb03;^<P00P3;^<P00`3>^LH0ck_60<nkaP02
0<nkaP<0dkk50`3E`<H00`3F`LD0f<?50=S3a@020=S3a@<0f/G50`3KalH30=c9aP<0gL_70`3Mc<P2
0=k>b@040=k?b@3Mcl/0gLo;0=g?b`80gM3<00<0g];<0=_AcP3Kd/l00P3Kd/l20=cCd0060=WBdP3H
dm<0f=?Co`00003He=@0eM;G0`3DdmL30=3AfP80cm;K00@0bm3M0<[@gP3:d=h0b]3N1035c^430<7;
hP030<3;hooooooo000001kooooo00?o0000ooooooooool06Oooool30:>Se@80XZ7C00<0WIG;09fB
b02MT/P00`2LT<H409^=a080Vh_20ol0000309Z7_P80VXFl00<0UG^d09Ai/P2DNK800`2DN;4309Eg
[`<0UGJ^0`2EMZd609Ie[0<0UWB[0`2GM:/309MeZP80V7FZ00@0UW6V09MaYP2GLJH0Ug6V102HLZH3
09UcYP<0VW>V102KM:L209afY`0309egY`2ON:L0WgRW0080WgRW0`2PNJP40:5kZ@80XWfZ00<0Z8B^
0:Z6[`2ZQZl00P2ZQZl40:^8/0030:f:/@2iW[`0^Ijl00@0^j2n103BcMD40:[2j`030:[1jol00000
ZKoY00H0ZKoY102Y_^P<0:Vmj003o`000?oooooooooo01;ooooo000<ooooo`03o`000?oooooooooo
01_ooooo0P1gZ_8206VSlP80FI_a0`1;T^l00`0hQ^/09G[U02Eji@03o`00000300eSf@0BHmT04V?I
008056;H0`0`K]`204IhgP80Eh3O0`1XR=l307b@g0<0RiOJ0P2HWML00`2GW]P0Xj?E0:>Se@020:>S
e@@0[JOA00@0]Z_>0;N]c`2g[Ll0]jg?0`2n/<`00`2o/L`0aKC:0<FdbP030<FdbPD0bkS800@0c;W8
0<nkaP3?^lH0ck_60P3A_LL00`3C_/D0eL360=G0aP020=G0aP040=K2aP3H`lD0f<?50=S3a@80fLC5
00<0f/G50=_7aP3KalH00P3KalH00`3Lb<H0g<W60=g;a`030=g;a`030=k<a`3Mc<P0g/k90080g/k9
0P3NclT00`3Mcl/0gM3<0=g@c0020=kBc0040=kCc@3Kd/l0fm;?0=_Bc`80g=?@0`3Hdm<00ol00000
f=CD0=CCe`020=CCe`80e=CH00@0d=7J0<oBf`3?d]/0cm;L0`3:d=h20<W@g`@0aLkQ00D0`L_R0<3;
h`30bn<0`<_So`00000Nooooo`03o`000?oooooooooo01[ooooo00<0Xj?E09jHc@2MUL/00P2MUL/3
09fBb0<0W9360P2KSL@3o`00000309^;`P2JRL00UGjh00<0UGbf0`2ENk@309Ai/P<0U7Ra0P2EMjl4
09Ef[P80UGJ]1`2FMJ`209IdZ`<0UgB[0P2GMJX0102EL:H0UW6V09IaYP2FLJH409MaYP<0V7:V0`2I
LjH309YcYP@0VgBW00<0W7JW09egY`2MMjL0102ON:L30:1iZ0@0XG^Y00<0XWfZ0:R4[P2XQ:h0102Z
QZl40:^8/0@0^Ijl0P2kX;h40=;=e@@0Z/;[0P2Y_nT00ol00000ZKoY0:Voj@020:Voj@@0ZKkX3`2Y
_NP00ol0003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0Looooo`80Mj[b0P1YXo83
05VKl@0704N@kol0003o0000o`00000UN^D056gN00eVf`0200eSf@802EkF00@056;H01]Uf@0`K]`0
<6kL0`0oM]h205N0g`80J8SO0`1iT=d308VGf`@0UikH102SXmD20:fWd@030:jYdP2g[Ll0]jg?00<0
]jg?00@0_[3<0;nac02o/L`0_k7<0`35]<X20<JfbP<0bkS80`3<^LP0103?^lH0dKg70=6ma`3A_LL5
0=G0aP80e/;600D0f<?50=W4a@3Ia<D0fLC50=[6aP030=_7aP80g<S600@0gL[60=g;a`3MblL0gL_7
0P3Nc<L30=k>b@<0g/o900<0gm7:0=g@c03Nd/`00P3Nd/`20=kCc@030=_Bc`3Ldm00g=?@0080g=CA
00H0f=?C0=SDe03He=Co00000=SEe@3DdmL30=CDf0030=?Df@3?d]/0cm;L0080cm;L00<0b]3N0<W@
g`39d=l00`39d=l00`35c^40a<kR0<C>hP020<3;h`80_l_S00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Jooooo`<0WYS=0`2MUL/309fBb00509b@a_l0003o0000o`00002FPk`00`2FP;X3
09En^0<0UGbf0P2ENk@309Ai/P<0U7Ra0`2EMjl309Ef[P<0UGJ]1P2FMJ`209IdZ`80UgB[00@0U72V
09E`YP2EL:H0UG2V102FLJH309MaYP<0V7:V0`2ILjH409YcYP80VgBW00<0W7FV09egY`2MMjL00P2M
MjL309mhY`<0X7VX102QNjT30:R4[PD0ZXJ_0P2[R;000`2hW;/0^Ijl0;VN_0020;VN_0050;^P_P3B
cMD0d/gE0=;=e@2no<L00P2Z`^/40:Voj@80ZKkX00?o00000:Vnj02Y_^P00P2Y_^PC0:Vmj003o`00
0?oooooooooo017ooooo000;ooooo`03o`000?oooooooooo01kooooo0P1eZ_<206NSl`?o000000<0
@ho^03>4jP0cQ>X00P0OMn@0200DKMh01F;H00ANeP04G]H02EkF00]MeP0DH]P06fGI0P0`K]`203mf
gP<0DGkO0P1XR=l307V@g@<0RIOK0`2GW]P30:>Se@030:BTeP2^ZM80[ZWB0080[ZWB0`2g[Ll00`2h
[]00_k7<0;nac0030;nac0030<FdbP36]/X0a[K:0080a[K:00D0bkS80<bib03<^LP0c;W80<jkb@04
0=6ma`040=:oa`3E`<H0eL360=G0aP<0e/;6103Ia<D20=[6aP040=_7aP3Lb<H0g<S60=c8aP80gL[6
00H0gL_70=k<a`3Nc<L0g/c70=o>b03Nc/T30=k?b@80gm7:0`3Nd/`30=kCc@030=kDcP3Ldm00g=CA
0080g=CA00D0fmKB0=SDe03HeMD0f=GEo`0000020=SFeP040=CDf03Ce=T0dmCI0=;EfP<0cm;L0P3>
d]d30<W@g`050<S@h034c^80a<kR0<C>hP33cN800`2obn<00ooooooo0000ooooo`0Jooooo`03o`00
0?oooooooooo01cooooo0`2NV<d209fEb`0509fBb?l0003o0000o`00002GQKh0102FPk`209J0^P<0
UGjh0`2EO;H309Ek]080U7Vb0`2DN;4309Eg[`<0UGJ^0`2EMZd509Ie[00309=_Y`2DL:L0U72W00<0
U72V102EL:H309IaYP<0Ug6V0`2HLZH409UcYP<0VW>V00<0VgBW09aeYP2LMJH0102MMjL309mhY`@0
X7VX0P2QNjT00`2WPZd0Z8B^0:R4[P020:R4[P@0ZXJ_00@0ZhR`0;RL^`2hW;/0^9bk0P2iW[`40=;=
e@030;kla`2Y_nT0ZKoY00<0ZKoY1@2Y_^P00ol00000ZKgX0:Vmj00E0:Vmj003o`000?oooooooooo
013ooooo000;ooooo`03o`000?oooooooooo01oooooo0ol000001@1WXo<0Ei[a05NJl@1GV_40@ho^
0080;h;Y00@07gOT00eZg00=J]`01F;H0P04G]H01009G]H02egF01]Uf@0KIMT202M[f`80?gKN0P1A
O]l306B7h0<0NI3M0`29Um/309NNf0040:>Se@2TY=H0Y:CF0:BTeP@0[ZWB00@0]jg?0;R^d02h[]00
^:k@0`2o/L`00`30/ld0a[K:0<JfbP030<JfbP<0c;W80`3>^lT20=6ma`<0d[o700<0eL360=K2aP3F
`/H00P3F`/H00`3Ha<H0fLC50=W4a@030=[6aP<0g<S60`3Mb/H30=k<a`80glk80P3Od<P01P3NclT0
gm7:0=oAbP3OdLX0gm;;0=kBc0<0g]?=0P3Ne<h30=cDd@80fmKB00H0fmOC0=SEe@3HeMD0f=GEo`00
003He]H30=?Df@80d]GJ00<0cm;L0<kBg@3>d]d00P3=dmh01@39d=l0b=3P0<S@h038d>00a<kR00<0
`lgR00@0_l_S0;k;i02nbnCo00006oooool00ol0003oooooooooo`0Looooo`80WYS=00@0VHk6o`00
0?l0003o00000P2GR<4309N5_P<0UX>l0`2FP;X209En^0<0UGbf0`2ENk@309Ai/P<0U7Ra0P2EMjl3
09Ef[P80UGJ]00@0TW2Y099`Z02BL:P0TW2X0`2CKjL209A`Y`@0U72V0`2EL:H309IaYP<0Ug6V102H
LZH309UcYP80VW>V00@0VgBV09aeYP2LMJH0W7FV102MMjL309mhY`@0X7VX00<0XG^Y0:N2[@2WPZd0
102XQ:h30:Z6[`030;NJ^P2hW;/0^9bk0080^9bk00<0^Ijl0=;=e@3BcMD00P3BcMD0102cn;d0ZKoY
0:Voj@2Y_nT70:Vnj080ZKgX00?o00000:Vmj02Y_NP0502Y_NP00ol0003oooooooooo`0@ooooo`00
2oooool00ol0003oooooooooo`0Looooo`?o000000Gooooo07BYl`1dZO<0M:Wc06FRl`0205BIl@80
@8k^0P0_P^T0100IM>803F[L00eZg000G]D2001Id`802egF0P0BH=L0100WJm/0>7?N03QcgP0hLmh2
055ng`80I8OP0`1gT=l308RHg0<0UioI102TY=H30:jYdP030:n[d`2h[]00^:k@00<0^:k@00@0_k7<
0<2cc@30/ld0`;?=0`36]/X20<Ngb`030<bib03>^lT0c[_90080c[_900<0dKg70=:oa`3B_lL00P3B
_lL0103D`LL0e/;60=K2aP3F`/H20=S4aP030=W4a@3Ja/H0f/K60080f/K600<0flS60=c8aP3Mb/H0
0`3Mb/H20=k<a`<0glk80P3Od<P30=oAbP80gm;;0P3Pe<`01P3Ndld0g]C>0=kDcP3Ne<h0g]K?0=cD
d@80fmKB0`3Kem<00`3HeMD0f=KFo`0000020=OFe`030=?Df@3BeMX0d]GJ0080d]GK00@0c];M0<gC
gP3=dmh0c=?O0`38d>020<O@h@80`lgR0P32cN<0102nbn@0_L_T0;g;i?l0000Jooooo`03o`000?oo
oooooooo01cooooo0ol0000309R;a0<0UhS10P2GQKh309J3_0<0UX2j0`2EO[P309El]P80UG^d0`2D
NK8309Ah/@0309Eg[`2ALJ/0TG2Y0080TG2Y0`2BL:T3099`Z0<0TfnW0`2DL:L309A`YP<0UG2V0`2F
LJH309MaYP@0V7:V0P2ILjH0102JLjD0VgBV09]dYP2KM:H309aeYP@0WGNW102ON:L20:1iZ0030:F0
[02WPZd0Yh:]0080Yh:]0`2XQ:h0102ZQZl0]iZj0;NJ^P2gV[X40;RL^`060=7=e@3BcMD0d/gE0=;=
e@2cn;d0ZKoY1`2Y_^P50:Vmj003o`00002Y_NP0ZKgX01D0ZKgX00?o0000ooooooooool03oooool0
00_ooooo00?o0000ooooooooool06Oooool3o`0000Gooooo0P1cZO<206BRl`80E9Wa0P10S^h202Z0
j00601UdhP06I]X01VKJ001Ne@00FM<005C@0P01F=<00`0BH=L07fOJ01mWfP0203QcgP<0BgcP0P1T
Qn0307N@g`<0R9SL0`2GWmT40:BTeP040:jYdP2_Zm<0[j_C0:n[d`<0^:k@00<0^K3A0<2cc@30/ld0
0`30/ld01036]/X0akO;0<Ngb`37]l/50<jkb@040<nmb@3B_lL0d[o70=:oa`<0e<7700D0e/;60=S4
aP3Ha<H0f<C60=W6a`030=[6aP80flS600@0gL[70=g:aP3Mb/H0gL[60P3Nc<L20=o>a`060=o>b03O
d<P0gm380=o@b03PdLT0gm7:0`3Od//20>3Dc0<0g]C>0P3Ne/l00`3Nem00fmKB0=_Gd`030=_Gd`04
0=_He03He]H0emKGo`000080e]OH00<0d]GJ0=;Ef`3BeM/00P3AeM`01@3=dmh0c=?O0<cCg`3<dml0
b=3P0080am3Q00D0a]3R0<;=h`32cN<0`/gS0<7=i0030;g;i0030;g:iOl0003ooooo01Sooooo00?o
0000ooooooooool06Oooool3o`000004ooooo`2IS/H0VHk609V>aP80V8_40`2GR<4309N5_P<0UX>l
0P2FP;X309En^0<0UGbf00<0UG^d091c[`2@LZd00P2@LZd3091a[080TG6[0`2AL:T3099`Z@<0TW2X
0`2CKjL309A`Y`<0U72V0`2EL:H309IaYP@0Ug6V0P2HLZH0102ILZD0VW>U09YcY@2JLjD309]dYP@0
W7FV0`2MMjL409mhY`030:1iZ02UP:`0YH2/00@0Yh:]0`2XQ:h50;NJ^P80^9bk0`3AcMD00`3BcMD0
/oRm0:Vnj0050:Vnj0T0ZKgX00?o00000:Vmj02Y_NP0502Y_NP2o`00013ooooo000;ooooo`03o`00
0?oooooooooo01Kooooo0ol00009ooooo`80LjWc0`1TX_<0101BVO40?Hg^03f=kP0ZP>P201Abh@80
1VKJ00@005[B001Ed000E=000ESC0P08G=@201mWfP80>7?N0P1;O>030627h@<0Mi3O0`28V=`309NO
f@80Y:CF00<0Y:KG0:n[d`2_Zm<00`2_Zm<0102h[]00^K3A0;V`d@2i/=430<2cc@040<:ecP37]l/0
akO;0<Ngb`80bKW;0`3>^lT30<nmb@030=:oa`3D`LL0e<770080e<770`3Ha<H30=W6a`040=[6aP3K
b<H0flS60=_8aP80gL[700<0gL[60=k<a`3Nc<L00`3Oc/L30=o@b080h=790P3QdlX01P3Od//0h=C<
0>3Dc03Pe<`0h=K=0=kDcP80g]K?0P3Nem00103Nf=40fmOC0=_Gd`3Kem<20=_He0070=[Ie@3Ge]L0
e]OHo`00003FemP0e]SJ0=;Ef`030=7Eg0<0c=?O0P3;dn001@37d>40a]3R0<K@hP36d>80`/gS00<0
`LgT00@0_L_T0;g:i@2mb^Go00006Oooool00ol0003oooooooooo`0Fooooo`?o00001?ooool309V>
aP<0V8_40P2GR<4209N5_P04095m^P2@NkL0T7^g091k]`80T7Ve0`2@Mk<3091e/@80T7>_0`2@LZd3
091a[0<0TG6[0`2AL:T2099`Z@<0TW2X102CKjL209A`Y`<0U72V0`2EL:H409IaYP<0Ug6V00<0V7:V
09UbY@2ILZD00`2JLjD309]dYP@0W7FV102MMjL209mhY`040:AoZ`2UP:`0YH2/0:F0[0@0Yh:]0P2X
Q:h20;FH^@@0]iZj00<0^9bk0=7=e@3AcMD00P3AcMD50:Vnj0d0ZKgX00?o00000:Vmj02Y_NP0502Y
_NP00ol0003oooooooooo`0>ooooo`002oooool00ol0003oooooooooo`0Dooooo`;o00003_ooool0
0`1bZO@0HZ;c06:Rl`02052HlP<0?Hg^0P0DL^42001Sf004001JdP00EM0004o<001Cc`8025cD0P0O
ImX2031`g@80BgcP0P1PQn4307B@h0<0QYWN0`2FX=/40:BVe`<0[j_C00<0/:cD0;V`d@2i/=400P2i
/=400`30/ld0`[G>0<:ecP020<:ecP030<Ngb`39^L/0bKW;0080bKW;00<0c[_90<nmb@3?_LT00P3?
_LT40=C1a`80eL?800<0f<C60=W6a`3Ia/L00P3Ia/L30=_8aP<0gL[70P3Nc<L40=o>a`030>3@b03O
d<P0h=790080h=790P3QdlX30>3Dc080h=K=00<0h=O>0=kFc`3Nem000P3Nem020=kHd@030=_Gd`3K
f=@0fmSD0080f]WE0`3FemP00ol00000e]SJ0=7Eg0020=7Eg080d=KM00@0c=?O0<_Ch03;dn00b]?Q
0`36d>820<G@h`80`LgT0P30cN@20;g:i@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5?ooool2o`0000Sooooo00<0VHk609>6`P2BPkl00P2BPkl20960_@<0TGfj0`2@NkL3091i]@80T7Nc
0`2@MK43091c[`80T7:]0`2@LJ`3095aZ`<0TG2Y0`2BL:T3099`Z0<0TfnW0P2DL:L409A`YP<0UG2V
0`2FLJH209MaYP0409MaY@2ILZD0VG:U09UbY@<0VW>U102KM:H309aeYP@0WGNW00<0WgRW0:AoZ`2T
Oj/0102UP:`30:N2[@040:R4[P2eV;T0]IRi0;FH^@@0]iZj00D0dLgF0=7=e@3AcMD0dLgE0:Vnj00C
0:Vmj003o`00002Y_NP0ZKgX0180ZKgX00?oooooo`000?ooool03oooool000[ooooo00?o0000oooo
ooooool04_ooool3o`00013ooooo0P1aZO@206:Rl`<0D9Sb00H0>Xc^029mi`0RONL03foO001Sf000
E/l2001@c004001?c000Dll025cD00QLe0805V?H00<0<73M04Ekh@15Nn400`1PQn4307B@h0<0QYWN
0`2FX=/30:BVe`030:n[d`2`[=@0/:cD0080/:cD0P2i/=400`2j/]80`[G>0<:ecP030<:ecPD0bKW;
1@3?_LT00`3@_lX0e<770=C1a`030=G3b0040=O5b@3Ia/L0fLK70=W6a`80f/S700<0flS60=g:a`3M
b/L00P3Mb/L00`3Nc<L0glk80=o>a`020=o>a`80h=380`3PdLT30>7CbP040>7Eb`3Pe<`0h=K=0>3F
c@80h=O>0P3QfLl01P3Nem00g]SA0=kHd@3Nf=40g][B0=_He080f]WE0P3JfML00`3FemP0e]SJo`00
00020=CHf`030=7Eg03@e]d0d=KM0080cmKN00D0bm?P0<[Ch@3:dn40b]?Q0<K@hP020<G@h`040<C?
h`30cN@0`<gT0<3=i0?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`?o
00002_ooool309>6`P80TX>o0`2AP;d2095m^P<0T7^g0`2@NKD2091g/`<0T7Fa0`2@Ljl3091b[@<0
T76/0P2ALJ/3095`Z@<0TW2Y0`2BL:P309=_Y`<0U72W0`2DL:H309E`YP80UW6V00@0UW2U09MaY@2G
LJD0Ug6U0`2ILZD409YcY@<0VgBV0`2LMJH309egY`040:9mZ`2TOj/0Y7n[0:AoZ`@0YH2/0P2WPZd0
0`2cU[T0]IRi0;FH^@020;FH^@<0]iZj0`3AcMH00`3AcMD0ZKgX0:Vmj00C0:Vmj003o`00002Y_NP0
ZKgX00d0ZKgX1_ooool00ol0003oooooooooo`0>ooooo`002_ooool00ol0003oooooooooo`0?oooo
o`?o00005?ooool3076Ym080HJ;d0P1>V?801P0hRnd08WgW029mi`0:K]h0063F001Fc`80053<00P0
04_8001>c000Em8005OB01ISf00XKMd0<73M04Ekh@<0FhKR0`1dT>0308JIgP<0UZ3K0P2TY]L20:BW
f@@0/:cD00@0^K3A0;ZbdP2j/]80^[;B0`32]Lh20<>gc`<0bKW;0P3;_<`30<nmb@80d;o:00<0e<77
0=G3b03E`lP00P3E`lP20=O5b@050=W6a`3Jb<L0f/S70=[8a`3Kb/P00`3Mb/L20=k<a`80glk800H0
glk70>3@b03Pd<P0h=380>7Bb@3PdLT30>7CbP80hMG;00<0h]O<0>3Fc@3Pelh00P3Pelh20>7Ic`<0
g]SA0P3Nf]80103Mfm@0f]WE0=[Ie`3JfML20=WJf0030=KHfP3Df=_o00000080dmSL00<0d=KM0<oF
gP3?e]h00P3>e]l20<[Ch@80b=?R00D0aM3S0<C?h`34cn<0a<oS0<3=i005ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03oooool3o`0000gooooo0`2CQ/8309:3_`80TH2m0`2AOKX3
091k]`80T7Ve0`2@Mk<3091e/@80T7>_0`2@LZd3091a[080TG6[0`2AL:T3099`Z@<0TW2X0`2CKjL3
09A`Y`80U72V00@0U6nV09E_Y@2EKjD0UFnU0`2FL:D309MaY@@0VG:U0`2JLjD309]dYP<0W7FV00@0
WGNW0:9mZ`2ROJ/0XWf[102TOj/30:F0[0040:N2[@2cU[T0/iJi0;>F^@@0]IRi00<0]iZj0=7=eP3A
cMH00P3AcMHG0:Vmj003o`00002Y_NP0ZKgX00T0ZKgX2_ooool00ol0003oooooooooo`0=ooooo`00
2_ooool00ol0003oooooooooo`0<ooooo`?o00006?ooool2076Ym0<0H:;d0P1=V?801P0hRnd07gcV
01mliP0:K]h0063F001Bc08004c800H004_8001>c000Em8035kF01ISf00XKMd204Ekh@80FhKR0`1a
TN8308FJh0@0UZ;M102TYmT20;2/e0030;2^eP2j/]80^[;B00<0^[;B00<0`[G>0<>gc`33]ll00P33
]ll00`39^L/0bkc<0<^lc0020<^lc0050<nmb@3@_lX0d;o:0=2obP3B`//00`3E`lP30=O5b@<0f/S7
0`3Kb/P00`3Mb/L0g/c70=k<a`030=o>b0<0h=380P3Qd/T20>;DbP030>7CbP3QeL/0hMG;0080h]O<
0P3RfLd01P3Pelh0hMW?0>7Ic`3QfLl0h=[@0=kHd@80g][B0P3Mfm@00`3Mg=D0f]WG0=WJf0020=WJ
f0070=SKf@3Df=/0dmSLo`00003Cf=`0d]WM0<oFgP030<kFg`<0b=?R0P37d^820<C?h`Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0<ooooo`?o00004Oooool309>6`P80TX>o0P2A
P;d3095m^P<0T7^g0`2@NKD2091g/`<0T7Fa0`2@Ljl2091b[@<0T76/0`2ALJ/3095`Z@80TW2Y0`2B
L:P309=_Y`80U72W00@0TVjV09A_YP2DKjH0U6nV0`2EKjD309I`Y@<0Ug6U102ILZD309YcY@<0VgBV
0P2LMJH00`2PNjX0XWf[0:9mZ`020:9mZ`@0Y7n[0`2UP:`40;>F^@@0]IRi00@0d<gG0=7=eP3AcMH0
dLgF6@2Y_NP00ol00000ZKgX0:Vmj0050:Vmj0gooooo00?o0000ooooooooool03Oooool000[ooooo
00?o0000ooooooooool02Oooool3o`0001cooooo0P1aZO@3062Rm00304fHlP0fRnd0=X_]00807gcV
00<01VcM001Ne000D/`00P00C<P01000A/@005;>001BcP0<G]H202Q]g@80?WWQ0P1KQ^83076AhP<0
QI[P102FX]d20:BWf@030:BYfP2`[]H0/:kF0080/:kF0`2j/]820;^dd`<0`kO?0P34^]030<^lc004
0<bnc@3@_lX0d;o:0=2obP<0d/;;00<0eL?80=O5b@3GaLT00P3GaLT00`3HalT0f/S70=_:b0030=_:
b0030=g<b@3Nc<L0glk800<0glk800<0h=390>3@b03Qd/T00P3Qd/T20>;DbP030>;Fb`3QeL/0h]O<
0080h]O<0P3RfLd30>7Ic`80h=[@00@0h=_A0=kJdP3Mfm@0gM_D0P3Mg=D01@3Lg=L0fM[H0=WJf03I
f]P0f=_I0080em_K00Co00000=;Ig@3BfMd0dMWN0`3>e]l0103<e^40b=?R0<OBhP37d^8:ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool3o`0001Cooooo0P2CQ/800`2<P/<0
S7jo08an_`030960_@80TGfj0`2@NkL3091i]@80T7Nc0`2@MK43091c[`80T7:]0`2@LJ`3095aZ`<0
TG2Y0P2BL:T2099`Z004091^Y`2AKZL0TFjW095^Y`<0TVjV0`2DKjH309E_Y@<0UW2U102GLJD309Ub
Y@<0VW>U0P2KM:H0102ONZX0X7^Z0:1kZP2PNjX50:9mZ`<0Y7n[0P2UP:`20;6C^0<0/iJi0`2eV;T3
0=3=e`030=7=eP2Y_NP0ZKgX01P0ZKgX00?o00000:Vmj02Y_NP00P2Y_NP@ooooo`03o`000?oooooo
oooo00gooooo000:ooooo`03o`000?oooooooooo00Kooooo0ol0000Qooooo`80L:[d0P1PX_@01`1<
V?80=X_]03J;k@0fRnd077cV00I/g@00Fm400P00ClT00`00B<D004K4001BcP0200=Je08086WL0P0n
NN4205J5h`<0LI7R0`25V^0209JRg@0309FSgP2TZMX0Y:WJ0080Y:WJ102`[]H00`2j/]80^kCC0;^d
d`020;^dd`030<>gc`34^]00a;[@0080a;[@00D0bkc<0<bnc@3<_/d0c;k=0=2obP040=;2b`040=?4
b`3GaLT0elG90=O5b@80f<O900@0fL[:0=_:b03Kb/P0fl[80P3Mc<T0103NclT0glk80=o>b03Oc/P2
0>3@b@80hM?:00D0hM;90>;DbP3Re<X0h]C:0>;Fb`030>;Gc0<0h]W=00@0h][>0>7Ic`3Pf]00h=[@
0P3Pfm400`3PgM80gM_D0=gLe@020=gLe@80g=cG00<0fM[H0=SKf@3HfmT00P3Gfm/00`3BfMgo0000
0=;Ig@020=7IgP050<kFg`3<e^40c=KQ0<_EhP37d^802oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo0ol0000Gooooo`<0S8;30P2<O[l308]k_@80RgVj0`2:M[L308Yd]@80
Rg>b0`2;LK0308]`[`80S6n]0`2=KZ`308e^ZP<0SVjY0P2?KZP3091^Y`<0TFjW102BKZH209A_YP<0
UFnU102FL:D309MaY@<0VG:U0`2JLjD00`2KM:H0WgZZ09mjZP040:1kZP@0XWf[0`2TOj/0102UP:`0
/I>h0;6C^02aTkP40;>F^@040;FH^@3@cML0d<gG0=3=ead0ZKgX00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`03ooooo`?o00009?ooool3072Z
m@80Gj?d0P1<V?802P0dRnd06W_U01Yki@02Jm`005_A001?b@00A<4004700015``00CL/200=Je004
021Yg00gMn40=gOQ03Mgh@80EXGS0P1^TN@308>KhP@0UJ?N102TZMX20;2^eP80/K7H0`2k]=<00`2l
]m@0a;[@0<Bjd0030<Bjd0@0c;k=00@0cL7>0=;2b`3B`//0d/;;0`3Ca</0103GaLT0f<O90=S7b@3H
alT20=W:bP040=_:b03Mc<T0gLc90=g<b@80g/o900@0glk80>3@b@3Pd<T0h=390P3QdlX30>;DbP80
h]K;00<0hmS<0>;Gc03RfLd00P3RfLd20>;JcP040>;Lc`3Pf]00h=_A0>3Kd@80h=gB0P3Og]@00`3M
g=D0g=cG0=cLe`020=_Mf0030=SKf@3Gfm/0em_K0080e]_L00<0d]WMo`00003AfMh00P3@fMl00`3<
e^40bmGR0<_EhP0<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool3o`00
01_ooooo0`2<P/<208an_`80Rg^m0`2;NKX208Yf]`<0RWBe0`2;Lk8208]a/0<0Rg2_0P2<Kjd308e^
[0<0SFjZ0`2>KZT208m^Z0@0T6jW0`2AKZL3099^YP<0U6nV0`2EKjD309I`Y@<0Ug6U0`2ILZD209Yc
Y@0309ehZ@2ONZX0WgZZ0080WgZZ0`2PNjX40:9mZ`80Y7n[00<0[i:h0;6C^02aTkP00P2aTkP30;>F
^@<0c/gH00<0d<gG0:Vmj02Y_NP0602Y_NP5ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03Oooool000Wooooo00Co0000oooooooooooooooo0ol0000Xooooo`<0L:[e0P1OXo@204^H
lP0303>;k@0JNnD06W_U008006[K00D005[@0014`@00@L0004G3001=b`0200=Je00301MVf`0gMn40
=gOQ00<0DHGU0P1^TN@308>KhP@0UJ?N0P2TZMX00`2U[=`0/K7H0;6af0030;6af0040;^dd`2l]m@0
_;OD0;bge0<0a;[@0P36_=420<bnc@<0cL7>00<0d/;;0=?4b`3Ca</00P3Ca</30=S7b@<0fL[:0`3M
c<T30=k?b@<0h=390`3QdlX0103ReL/0h]C:0>;Fb`3Re//20>?Hc080hm[=00<0h]W=0>;JcP3Rf/h0
0P3Rg<l00`3RgM40h=_A0>3MdP020>3MdP80gmkD00@0g]oF0=cLe`3KgMP0fmgH0P3Jg]T00`3Gfm/0
e]_L0=KKg0020=CLg@030=7Ig_l00000d=WO0080c]WQ00<0bmGRooooooooool02oooool00ol0003o
ooooooooo`0Dooooo`04o`000?ooooooooooooooo`?o00007_ooool308b2``80S7jo0`2;Nkd208]i
^P<0RWJg0P2:M;D308]c/P80Rg6`0`2;L:l308a_[@80SFj/0`2=KZX308i^Z@<0SfjX0`2@KZL3095^
Y`<0TVjV0`2DKjH309E_Y@<0UW2U0`2GLJD209UbY@0409]gZ@2MN:T0WGRY09ehZ@@0WgZZ0`2PNjX4
0:9mZ`040:AoZ`2_T[P0[i:h0:nB^0@0/I>h00D0/iJi0<k=f03>cMP0c/gH0000000H0:Vmj0Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool4o`0002gooooo0P1`
ZoD205nSm@80BiWc0P0cRnd0200INnD006[K001HcP00B/@0046m000m^`00@;l004S70P00E]400`0G
I]/0=gOQ03Mgh@020565i@<0JY7V0`23Vn8209FSgP0309BUh@2U[=`0YJcL0080YJcL0`2a/MP00`2b
/mT0_;OD0;bge0030;bge0050<Bjd036_=40a[cA0<Jld@3<_/d0103=`Lh0103?`ll0dlC;0=?4b`3C
a</20=G7c0030=S7b@3Ib/X0fL[:0080fL[:00<0flc;0=g<b@3NclT00`3NclT00`3OdLX0h=390>7C
bP020>7CbP80h]G;00<0h]O<0>;Fb`3Sf<`00P3Sf<`20>?Jc@040>?LcP3Rf/h0h]c?0>;Lc`80h]gA
0P3Rgm800`3PgM80gmkD0=oNe0020=kOeP040=gPe`3KgMP0f]kI0=[Nf@80fMkK00<0e]_L0=CLg@3D
g=d00P3Cg=h00ol00000c]WQ0<kIh@0?ooooo`03o`000?oooooooooo01Cooooo1?l0000Rooooo`80
S8;30`2<O[l208]k_@80RgVj0`2:M[L308Yd]@80Rg>b0`2;LK0308]`[`80S6n]0P2=KZ`308e^ZP<0
SVjY0`2?KZP3091^Y`<0TFjW0`2BKZH309A_YP<0UFnU0`2FL:D309MaY@0309UbY@2KMjT0VgNY00@0
WGRY0`2ONZX40:1kZP80XWf[00<0[I2h0:nB^02_T[P00P2_T[P40;6C^0<0c/gH00<000000:Vmj02Y
_NP0502Y_NP<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo
0_l0000`ooooo`80LJ_e0P1PY?D204^Il`80<hc^0P0HO>D01`00F<h004[40011_@00?K/0042o0018
a`00E]400P0=HmT2031eh@80DHGU0`1ZTNH3086Li0<0U:GQ102U[=`0102a/MP0/[?I0;:cf@2b/mT3
0;bge0040;jjeP36_=40a[cA0<Jld@80akoB0`3=`Lh30<o3c`050=?4b`3Eal`0eLO<0=G7c03FbLd0
0`3Ib/X20=_<b`040=c?c03NclT0g/o90=k?b@80gm7:0P3Pdl/00`3QdlX0h]G;0>;Eb`020>;Gc080
hmW=00<0hmS<0>?Jc@3Sf/d00P3Sg<h00`3Sg/l0h]c?0>;Md@020>;Md@80h]oB00@0hN3C0=oNe03N
gmH0g]oF0P3Mh=L0103LhMT0f]kI0=WNf`3Ig]/20=SOg0030=CLg@3Cg=h0dmcN0080d]cP00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Cooooo`;o00009?ooool208>2b@<0PWk60P22Nl<3
089i`080RWJg0`2:M;D308]c/P80Rg6`0`2;L:l208a_[@<0SFj/0`2=KZX308i^Z@80SfjX0`2@KZL3
095^Y`<0TVjV0`2DKjH309E_Y@<0UW2U0P2GLJD00`2IMZT0VgNY09]gZ@0209]gZ@<0WGRY0`2ONZX4
0:1kZP040:9mZ`2]T;P0[I2h0:f@^0<0[i:h0`2aTkP20<c<fP030<k=f02Y_NP0ZKgX01@0ZKgX3ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo000;ooooo`03o`000?oooooo
oooo02kooooo0P1aZoD2062Tm@80Bi[c0P0cSNh02@0HO>D006[J001Hc@00F<d004S1000i]`00>kX0
04C2001AcP0200eSf@80<7GQ0P1;Q>H306ZAiP<0PIcT0`2DYN420:F/g0030:F^gP2b/mT0/[?I0080
/[?I00<0_;OD0;jjeP2n^]H00P2n^]H00`36_=40akoB0<NodP020<NodP030<g1cP3?`ll0cl??0080
cl??0`3Eal`30=K9c@040=W:bP3Kc</0flc;0=_<b`80g<o<00<0g/o90=oAbP3OdLX00`3Pdl/00`3Q
e/`0h]G;0>;Gc0020>;Gc080hmW=00@0hmc>0>?Jc@3Sg<h0hmc>0P3Sg/l20>?Od@030>;Md@3Rgm80
h]oB0080hN3C00@0h>;E0=kOeP3Mh=L0gN3G0P3LhMT0103KhMX0fMkK0=SOg03Hgm`20=KOgP030=?L
gP3Bg>00d]cP00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo02;ooooo0P23P/T2089naP<0PW_30P22NL02089f_@<0PgBk0`2;Lk8208]a/0<0Rg2_
0`2<Kjd208e^[0<0SFjZ0`2>KZT208m^Z0<0T6jW102AKZL3099^YP80U6nV0`2EKjD209I`Y@0409Qd
ZP2IMZT0VGJY09UfZ@@0VgNY0`2MN:T409mjZP80X7^Z00<0Zhjg0:f@^02]T;P00P2]T;P40:nB^004
0;6C^03<c=X0c<cJ000001@0ZKgX4oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00cooooo000<ooooo`03o`000?oooooooooo02kooooo0`1a[?D2066Um@0504bKl`0cSNh0<hg^01Mm
iP00J]X00P00F<d01P00>kH003Vg000k^P00A<80057>00eSf@<0:7?Q00@0BhCV06JBj01VT^P0IY;X
0`1oW^H309BWh`@0YJkN0P2b/mT20;>ff`<0_[[F00<0_kgH0<NodP37_m800`37_m801039`]@0cl??
0<o3c`3?`ll20=36d0030=G7c03FbLd0e/W=0080e/W=0`3Kc</30=c?c0030=gBc@3OdLX0h=?;00<0
h=?;00@0hMK<0>;Gc03Rel`0h]O<0`3SfLd00`3Sg<h0hmk?0>?LcP030>?Nc`80hmoA00@0hn7B0>;O
dP3Qh=<0hN3C0P3Ph]D0103OhmL0gN3G0=cQf@3LhMT20=_QfP030=[Rg03Hgm`0e]oN0080e]oN00<0
e=oO0=;Lh?ooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08Oooool208>2b@<0PWk60P22Nl<2089i`0<0PWJm0P23M;/308=c^080Q76f0`2;
L:l308a_[@80SFj/0`2=KZX308i^Z@<0SfjX0`2@KZL3095^Y`<0TVjV00<0U6nV09AbZP2FLjX00P2F
LjX309QdZP@0VGJY0`2KMjT309ehZ@@0WgZZ00@0X7^Z0:^>]`2[S[L0Zhjg0`2]T;P30:nB^080b/cK
00<0c<cJ0:Vmj02Y_NP03P2Y_NPJooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool0;_ooool207:/mP<0HJGf0P1=W?@02@0cS^l067kV01Qn
iP00J]X005O<000k]P00=kD003nm001=b@0200AOe`80:7?Q0P15PnL306JBj0<0OikV0`2DYn<20:F^
gP030:Fah@2c]]/0/kKK00<0/kKK00@0_[[F0;nmf02o_MP0_kgH0`37_m830<W2e0050<o3c`3@a]00
d<K@0=36d03BbM400`3FbLd20=S<cP040=_<b`3Lcl`0g<o<0=c?c080gM;=00@0g]C>0>3Cb`3Pdl/0
h=?;0P3Qe/`00`3RfLd0h]O<0>?Ic@020>?Ic@80hmc>00@0hmk?0>?Pd03Sh=00hmk?0P3Sgm420>?Q
dP040>;Sd`3Qh=<0h>;E0>3Re@80gn?G00<0g^CH0=cQf@3KhMX00P3KhMX0103Jh]`0fN;M0=WRg@3F
gmh20=COg`Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo023ooooo0`1bR=X2089naP80PW_30`22NL02089f_@<0PgBk0P23LkP208Aa]P<0QG6d0`27
L;8208Q`/@<0SFjZ0`2>KZT308m^Z0<0T6jW0P2AKZL0102@LJ/0TW:[099bZ`2BLZ/209AbZP<0UW>Z
102HM:X309UfZ@<0VgNY102MN:T209mjZP030:R<]`2[S[L0Zhjg0080Zhjg102]T;P0102_T[P0b/cK
0<[<f`3:c=/?0:Vmj1cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`00
3_ooool2o`0002oooooo0P1b[?H3066UmP80CIcd00T0=8o_01QniP00K=X006cJ001Hb`00A[d003Ne
000o_@00CLT00P04GmL201m`h080AH?W0P1RTnX307nNiP80U:OS00<0Tj[V0:Fah@2U/N400P2U/N43
0;>ff`030;Big@2o_MP0_kgH00<0_kgH00<0akoB0<W2e039`]@00P39`]@30=36d0<0d/WA00@0e/W=
0=S<cP3Hc<h0f<c>0P3Icm00103Lcl`0gM;=0=gBc@3Md/d20=kDcP030>3Cb`3Qe/`0hMK<0080h]W=
0P3Rfll00`3SfLd0hmc>0>?LcP020>?Nc`80hn3@00@0hn;B0>?Od@3ShM80hn7B0P3Rhm<00`3Qi=D0
h>;E0=oSe`020=oSe`040=kTf03Mi=X0gNCJ0=_QfP80f^;L0P3Ih]d00`3Gh]l0e=oOooooo`06oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool2o`00027ooooo0P1bR=X20725
f0<0L8;E0P22NL02089f_@<0PgBk0P23LkP308Aa]P<0QG6d0P27L;8208Q`/@<0RFn_0`2;L:h308e`
[@<0Sg2/0`2@LJ/3099bZ`<0U7:Z0`2FLjX309QdZP<0VGJY102KMjT309ehZ@0409mjZP2XS;L0Z8bg
0:R<]`<0Zhjg0`2]T;P01037c=d0b/cK0<[<f`3:c=/=0:Vmj23ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003oooooooooo`0]ooooo`<0Ljgf0P1SY_H2
04jMm080=Y7`0P00K=X01@00F</004Jl000c[`00<k0004W5008005cD00@07g3P03j3j00nPnP0?X?X
0P1RTnX307fPj@<0Tj[V102U/N40102c]]/0];WM0;Big@2d^Md30;nmf080`<3I0`39`]@20<[5e@03
0=36d03BbM40d/WA0080d/WA0`3Hc<h30=W?d0<0gM;=0`3Ne<h00`3Oell0hMK<0>;Ic@020>;Ic@80
h]_?00@0hmg@0>?LcP3Sg/l0hmk?0`3Sh=000`3Sh]80hnCC0>?QdP020>;Sd`80hNCE0P3Qi]L00`3O
hmL0g^CH0=kTf0020=gTfP040=cUf`3Jh]`0fN;M0=WRg@80en;O2Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07oooool207:8fP80L8GH0P1`P]D2
071odP<0PWJm0P23M;/308=c^080Q76f0`25LK@208M`/P<0R72a0P29Kjl308]`[P<0SG2]0`2?L:`3
091aZ`<0TW:[0`2DLZX309IcZP<0V7BZ102IMZT309]gZ@80WGRY00<0YHZh0:R<]`2XS;L00P2XS;L4
0:^>]`050:f@^037c=d0alcM0<O<g@3:c=/02`2Y_NPTooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool0;_ooool207B^mP80I:Sf0P1@WoD2
03JAl00701^1j000KMX005S;0016_000>;40032/0019a@02001Le00301I^g`0nPnP0?X?X00<0GIC/
0`1mX>T309>ZiP80YK7Q0P2U]><40;Big@030;nmf030`=T0`<3I0080`<3I00D0bL;D0<[5e@3:aMD0
b/GE0<c8e`030=;9d@80dlcC00@0f<c>0=W?d03Icm00fLo@0P3Jd]40103Md/d0g]C>0=kDcP3Ne<h2
0=oGc`80h=[@00<0h]W=0>;Kc`3Rfll00P3SgM020>?Pd@030>?Nc`3Sh=00hn3@0080hn;B00<0hnCC
0>;Ue03Rhm<00`3Qi=D20>7Ve`050=oWf03Ni=P0gNCJ0=gTfP3LiM/00P3Ji]d00`3Ih]d0en;O0=OR
g`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Oooooo`80?I;`0P1`QMP20722e@04071odP1`OM00L7g@071md0<0LW_=0P23LkP208Aa]P<0QG6d
0`27L;8208Q`/@<0RFn_0`2;L:h208e`[@<0Sg2/0`2@LJ/3099bZ`<0U7:Z0`2FLjX309QdZP@0VGJY
0P2KMjT00`2SR;P0YHZh0:F:^0020:F:^0<0Z8bg0`2[S[L01033bn00alcM0<O<g@37c=d80:Vmj2[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`004_ooool00ol0003ooooo
ooooo`0^ooooo`80MZof0P1VZOL2052Om@80>9?a0P0MQ>T02000Km/004Nk000_Y`00<:`003Nc0014
`@00F=405VkO0P0nPnP305fDk0<0NZ;/0`2B[NP40:Fdh`80];WM00<0]KcO0<30f@30`=T00P30`=T0
1032`m/0b/GE0<[5e@3:aMD30<c8e`040=;9d@3Cc=<0dlcC0=?<d`80e=3D00@0fLo@0=[Bd@3Jd]40
f];A0P3Ke]800`3Ne<h0gmO?0=oGc`030>3Jd0040>7MdP3Rfll0hmg@0>?Md0<0hn3A00D0hn;B0>?P
d03Sh]80hn;B0>?Td`020>;Ue080h^OF00<0hNCE0>7Ve`3Qi]L00P3OimP00`3Nj=X0gNCJ0=cUf`02
0=[Vg@80fNKO00<0en;Oooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool07oooool203fBl080=Xk_0P0_R^d0101`Om80L7g@071md01`
OM02079kc@80Lg[;0`24LKH308Ea]080Qg2b0P28L;4308U_[`<0Rg2^0`2=L:d308m`[0<0T76[0`2B
LZ/209AbZP<0UW>Z102HM:X209UfZ@030:26^02SR;P0XhRh0080XhRh0`2UR[P40:R<]`050:^>]`33
bn00`l_P0<?;h037c=d01`2Y_NP/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool001?ooooo0_l0000_ooooo`80MZof0P1VZOL305>QmP0803^ElP0MQ>T07HCY001bg@00G<`0
02nW000c[P00@;/2001Dc@0300e[g@0gP^P0=h;X00<0GIC/0`1jX^`309:]j080YKCS00<0YKOV0;Fl
g`2e_=l00P2e_=l00`30`=T0`/?K0<;3f`020<;3f`050<[5e@3<b=L0c<SG0<c8e`3=c=T00`3Cc=<3
0=C@e0<0f];A0`3Ke]800`3LfM<0gmO?0>3Jd0020>3Jd080hMgB00<0hMoC0>?Md03Sh=400P3Sh=42
0>?RdP030>?Te03Sh]80hnCC00<0h^GD0P3RimH01@3QjMP0hNKG0=oWf03OimP0g^SJ0080gNSL00@0
fnWM0=[Vg@3Ii]l0fNKO3oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo
0_l0000Tooooo`0302n:k@0ZQn/0:XO[0080L7g@0P1bNld207=jb`<0MWW90`1hNLL208M`/P<0R72a
0P29Kjl308]`[P<0SG2]0`2?L:`3091aZ`<0TW:[0`2DLZX309IcZP<0V7BZ00@0VGJY0:26^02PQ[P0
X8Jh0`2SR;P30:F:^0<0Z8bg00@0_l[S0<?;h033bn00`l_P1P2Y_NP`ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02oooool001Gooooo00?o0000ooooooooool0;Oooool307N`mP80
J:[g00<0EJ;f03jHlP0nV?800P0PQ^X200=egP03000h[@00<jh0042k008005C=00<03F_M03N2j00g
P^P00P1IU>h307NTkP<0TK3[102U]nH20;Flg`80]/3R0`32`m/30<?7g@050<c8e`3=c=T0cLcI0<g<
f@3Cc=<00`3Dd=@20=KCeP040=[Bd@3Ke]80fmKB0=_FdP80g=WC0P3Mg=D00`3Pf]00hMgB0>7MdP02
0>7Od`80hN;D00<0hn3A0>?RdP3Sh]800P3Si=@0103Ri]D0h^SG0>;Xe`3RiM@20>;WeP80hNWH00<0
gn[I0=oWf03Nj=X00P3Mj=`20=_Yg@030=[Yg`3Ii]oooooo013ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02?ooooo0`0ZQn/00`0WQNX0LW_=079k
c@0207=jb`80MWW90`1hNLL207]ia@<0R72a0`29Kjl308]`[P80SG2]0`2?L:`3091aZ`<0TW:[0`2D
LZX309IcZP80V7BZ00<0WHBi0:26^02PQ[P00P2PQ[P30:>8^0@0YHZh00D0Z8bg0;o:h`2ob^<0_l[S
0<?;h0020:Vmj3Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`005_oo
ool00ol0003oooooooooo`0^ooooo`80NK7f00<0JZcg05RTm`1HY?L00`0nV?801`0TRN`00gGN001R
c`00B[`003V/000`Z@00D<P00P04J=/202n1j080FIC^0`1gY>h3096`j`80YKOV0P2U^nT40;K0hP05
0<;3f`33amd0`lOM0<?7g@34bml00`3=c=T30<k?fP040=C@e03FdmH0e]?F0=KCeP80emKG00<0fmKB
0=cId`3LfM<00`3Mg=D00`3NgmH0hMgB0>7Od`020>7Od`80hN;D00@0hNGF0>?RdP3Si=@0hnCD0P3R
i]D20>;Xe`050>7Zf03RimH0hNWH0>7Yf03Oj]T00P3Njm/0103Mk=d0gNSL0=_Yg@3KjMd20=[Yga?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oo
oooo00@09HCZ07=jb`1cN//0Lg[;0P1fNLT207Qia`80NgW50`1nNL<3089i`@<0Rg2^0P2=L:d308m`
[0<0T76[0`2BLZ/209AbZP0409J1^P2JPkT0VX>i09Z3^@@0WHBi0`2PQ[P40:>8^080YHZh00D0^/WV
0;o:h`2ob^<0_l[S0:Vmj00jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool001Oooooo00?o0000ooooooooool0;Oooool307^bmP0406f]m`1HY?L0F:Cg05RTm`80@Y[c00L0
:8g]00Mih000H/l004bm000j[000:Yl00538008016SK00@09h3X05>Ek`1CUNl0DiG_0`1dY_43092c
kP@0YK_Y0P2f`>830;K4i0050<?7g@34bml0a<_O0<C;g`3=c=T0103>cmX30=KCeP<0emKG00<0f=[I
0=cId`3Mg=D00P3Mg=D20=kOeP80g^;H00<0hMoC0>7Re03Qh]@00P3QiMH0103QimL0hnCD0>;Ve@3R
i]D20>;Xe`80hN[H00<0h>cJ0>7Yf03Oj]T00`3Njm/00`3Mk=d0fncO0=_Yg@020=[YgaCooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Wooooo0P0V
Q>X0100XQ^/0N7W707Qia`1hNLL207]ia@<0OWW30P22NL4308Ej_`80R7^n0`2<O;d308mn_0<0Tgnk
102FPKX309Z3^@<0WHBi102PQ[P20:>8^0030;C7j02jbNH0^/WV0080^/WV00<0_l[Sooooooooool0
>_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Hooooo`;o0000;_oo
ool307^bmP80KJgg0P1KY_L204JMm080;I3_00P037gS001VdP00D;h002^P000i/@00CL<006KH02N0
j0<0DiG_0`1dY_43092ckP80YK_Y0P2U_n`30;K4i0040;O8i`34bml0a<_O0<C;g`80aLoR0`3>cmX2
0<oCg0040=KCeP3Ge]L0emKG0=OFe`80f=[I0P3IgMX00`3Mg=D0g]oF0=kOeP030=kRf0040=kUf@3Q
h]@0hNGF0>7UeP80hNOG0P3QjMP01@3Ri]D0h^SG0>7Zf03Qj]P0h>cJ0080g^gK0P3Mk]d0103Njm/0
gNcM0=_/g`3Kk=l20=W]hAKooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qoooo
o`;o0000;?ooool00`0XQ^/0;HW/02f9k00207]ia@<0OWW30P22NL4308Ej_`<0R7^n0`2<O;d308mn
_0<0Tgnk0`2FPKX309Z3^@<0WHBi102PQ[P0102SR;P0]<OX0;C7j02danP20;[9iSoooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`0]oooo
o`80OK?f0P1_[oL305nXn00804ZOmP0]T>l0;I3_0161i@00Jm@005C1000[X000BKh2001Se0807WkW
0P1=U_43072Ym0<0S[Ka102U_n`01@2fa>@0]lSW0;O8i`2gb>L0a<_O00@0aLoR00<0c/oJ0<oCg03?
dm`00`3@emh00`3Ge]L0f=[I0=SJf@030=WMfP030=WQg03NgmH0g^;H0080g^;H0P3NiMT00`3NimX0
hNGF0>7We`020>7We`060>7Yf03Pk=X0h>cJ0=o^f`3Qj]P0h>cJ0`3NkM/01@3Mk]d0fnoO0=__g`3J
l>40fncO0080fNgQ6?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0:oooool202f9k080=8g^0P1nNL<3089i`@<0QGZo0P28Nkh308al_@<0Sgjl0`2C
Ok/309J1^P<0VX>i102MQ;T20:26^080[LG/0P2danQ3ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0;Oooool307ndmP80L[3g0P1RZ_P0
201?X_L0<YC`03:Dl00bU?005hGX001_f000<J0004Vn0P00Hm@201ini`80AYOb0`1`ZO@308jfl@80
YKo/00@0YL?_0;O8i`2gb>L0]lSW0P2gc>X30<G?hP80a];T00@0cm?L0=3GgP3@emh0d=ON0P3Afn00
103Hf]T0fMgJ0=WMfP3IgMX20=WQg080fNCN00<0g^;H0=kUf@3NiMT00P3NimX20=gZg0050>7We`3Q
jMP0h>cJ0>3/fP3Ok]/00P3Mkmd20=cagP050=k]f`3Mk]d0fnoO0=__g`3Jl>400P3Hl>800`3IkN7o
ooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0]ooooo`80=8g^0P0mT_02089i`@<0QGZo0P28Nkh308al_@<0Sgjl0`2COk/409J1^P<0
VX>i0P2MQ;T0102U`nl0[LG/0:g5k02]aNa7ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool001cooooo00?o0000ooooooooool0;_ooool2086emP80MK7g0P1V[?P205BUm`80
>9Sb00H07X[Z001ef`00G/L0036R0016^@00Gm0201Imi@0404JGlP1/ZoH0K:_f06b[mP@0S;[d0`2U
`nl00`2gb>L0]lcZ0;O<jP020;O<jP030<G?hP36d^@0a];T00<0a]OV00@0d=ON0=7Kh03Afn00dM_P
0P3Agn800`3IgMX0fN7L0=WQg0030=WTgP040=WWg`3NiMT0g^OJ0=kWfP80gN[L0P3MkMd00`3Lkmh0
h>cJ0=o^f`030=g_g@060=cagP3Jl^00f_;P0=WchP3Kkml0f_3Q0P3Hl>8Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0^ooooo`030:Vmj00mT_00
?I;`0080B9Sb0P1DWo@308Qk_P<0S7bm0`2?O[`309=o^`80UX6j00<0TKcc09bol@2L_o400P2L_o43
0:G3k`030:g5k?oooooooooo04Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`007Oooool00ol0003oooooooooo`0]ooooo`80PkKf0`1h/oL206Z^n080E:Gg0`0nVo@01@0U
Snd00W_O000aXP00<J8005c;00803G_S00@0?iOb06b[mP1/ZoH0K:_f0P2<^_@208Zmm`@0Y<Ob0P2g
c>X20;S@k0040<KBi036enH0a]OV0<KGiP<0a]_X00H0dM_P0=7OhP3Agn80dMoR0=;Ri03IhM`30=WT
gP80fNOO00@0fN[Q0=kWfP3Mj]`0gN[L0P3MkMd20=c_gP050=_ah03Il^40fO;Q0=g_g@3LlMh00P3J
l^001@3Iln80eo?S0=Och`3DlnD0f?3R01kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02kooooo1@2Y_NP305BOm080H:Gf0`1][?L207ZbmP<0Q[Oe
102A_?<209bolDkooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`007_oo
ool2o`0002kooooo0P23]_H307Rcm`80JZkh0`1IZ?P204BOm@0502bDl00:PN8006[@000`W@00G</0
0P0=Nn<203RGlP<0J:gh0`2:_OL20:C7lP<0Xl_d00D0^=3/0;OEk`2geNl0]mG_0<KGiP030<KKj005
0<KOj`3Agn80dMoR0=7OhP3Bh^@00`3Ai^D00`3Ii=h0fNOO0=WWg`020=WZh@80f>gR00@0eo3S0=g]
g@3Lkmh0g>oN0P3KlN001P3Il^40eoCR0=OdhP3EmN@0f_;P0=WchP80eo?S0P3DlnDPooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09_ooool2o`0002kooooo2`2Y_NP306f/m`80N[;f
0`26]oD2096lle;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`008?oo
ool00ol0003oooooooooo`0]ooooo`80QKOe0P1k]?L306j`n@80GZ[i0P1:XoL203BIlP0501>7iP00
LMD005[6001JaP04NMl00`0hUo8206:_nP@0Ql7j0P2Sbo@0102RcoL0]mG_0;OEk`2geNl30;OIl@06
0<KKj036gn/0a]o[0<KOj`3Agn80d^;T0`3Ai^D20=7Yi`030=WWg`3Ij^40fN[Q0080f>gR00@0eo3S
0=Gbi03El^@0g>oN0P3KlN00103Il^40eoCR0=OdhP3EmN@20=?fi@040=7fiP3Gln<0e??U0=CciB7o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02co
oooo302Y_NQJooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0027ooooo
00?o0000ooooooooool0;Oooool208Nhm@<0O[Gg0P1b/_T206>]n@80DJKh0P0dVO801@0LSNX007SJ
06<00000El0007OK0080<9Oa0`1M/O/208O1nP0308C4o02RcoL0X/og0080X/og00@0]mG_0;OIl@2g
fO40]mWa0P2fgO@20<KOj`80a^?/0P35inh00`3Ai^D0dNWW0=7Yi`020=3]j080cnoY00<0f>gR0=O`
h`3El^@00P3El^@01P3Dm>D0d_GV0=;eiP3?mnL0eoCR0=Gei080doKU0P3Am^H00`3?m^Sooooooooo
o`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0]ooooo`L0ZKgXG_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo000R
ooooo`03o`000?oooooooooo02gooooo0`29^?D2086fm`80MK?h0`1X[oT0101GZOT0?9gd03bMm00U
Tnd200=og`8005Bj00<007CF02RFk`1M/O/00P1M/O/308C4o080X/og0`2PdoX00`2gfO40]]gd0;KM
m0030;GQmP030<KSk035inh0aNO^0080a>[`00<0dNWW0=3]j03@kNP00P3?knT01P3=l^X0boC[0<_d
j`3;m>/0eO;T0=Cdi@80d_GV00@0coOW0<ggj03=mnP0boSY0P38n>X00`3Am^H0coKXooooo`0Uoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0]oooo
o`@0ZKgXHOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000Sooooo`;o
0000;Oooool00ol0003oooooooooo`09ooooo`<0A:;f00@0;YWa00f6i00=Q^@005>e0P00L]40100P
UN`0Ek;k05Nbn`1G/_/30837oP80X=?j0P2Neo`0102fgO@0]N7f0;GQmP2ehOH20;?Um`030<GWkP34
j_00a>[`0080`nga0P31l?400`3?knT0cO;Z0<_dj`020<_dj`050<Wfk036mn`0a_O/0=;eiP3?mnL0
0P3=mnP0103;n>T0b?SZ0<ShjP36n>/Yooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:_ooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
4Oooool00`03P]h0073;01RCi`03052cnP<0O<[o0P2Neo`309_Jo@030;GQmP2ciOL0/nGg0080/NSh
00<0a>[`0<?]l@33kO400P31l?420;kblP80^oCb00@0boC[0<Wfk036mn`0a_O/0P33n>d01P31n>d0
__S]0;_hkP2kn>h0b?SZ0<Khjb[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool04oooool2001^aP04016Bh`19/oP0BK?h04Vcn080Mlco0P1acOh209SMoP<0Tmon00<0/NSh
0:k[n@2^joT00P2[kOT00`31l?40__;b0;kblP020;_dlP030;SelP2dmO40]?Ga0080/OKa00<0`oS]
0<7hk@2nn>d00P2kn>h00`2hn>koooooooooo`0[ooooo`05o`000?ooooooooooooooool00000;ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000oooooooooooooooo
o`00000;ooooo`009oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Kooooo0P00
K;`01005S]P0>k;b03^blP0k/_8306c>o@80Tmon0P2?hOd00`2^joT0Zngi0:_]n@020:O^n0040:?_
m`2OkoH0Wnof0;SelP80]?Ga0P2am_401@2^m_40ZoG`0:Sel02XmO00Y_C`033ooooo00Co0000oooo
oooooooo0000<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06Gooooo00Co0000
oooooooooooo00002oooool002Sooooo0_l0000Xooooo`03o`000?oooooooooo01Wooooo00@008gC
03Fak@0e/Nd0=K7]0P1Vc_X3063>m`0308_Ro026h_X0Q^;j0080PN;g00<0Xnog09o_mP2OkoH00P2K
ko@0102Gk_<0Tnka097]l02AkO0208k/l0030:Sel02Vm?3ooooo037ooooo00?o0000ooooool00000
<Oooool2o`0002Sooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`00:_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo0P00RlL302J]g`0505K<l01A
b^`0DL[/057:k01lhO@00P1hhO800`1dgnl0L]k^073Nk002073Nk004097]l02>k?00S^c`08g/l3Co
oooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooool000002oooool002_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Qooooo`8008:k0P0Q[=H202:/e080B/SS00<0B/SR04_9hP1<b^80>oooool00ol0003ooooo
o`00000cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
o`00000:ooooo`00;?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo0_l0
000dooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo000]
ooooo`;o00008oooool00ol0003oooooooooo`1Wooooo`?o0000=Oooool2o`0002?ooooo00?o0000
ooooooooool0Ioooool3o`0000[ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0Hoooool4o`0003[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Soooo
o`Co00003Oooool0033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o
0000?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo0ol0000Aooooo`00
<Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l00013ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0G?ooool4o`0001Cooooo000booooo`;o00007_oo
ool00ol0003oooooooooo`1Hooooo`Co0000B?ooool2o`0001kooooo00?o0000ooooooooool0F?oo
ool4o`0001Sooooo000dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4
o`0004kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co00007?ooool0
03Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o0000Doooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`00=_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0001Gooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0COooool4o`0002?ooooo000gooooo`;o00006Oooool00ol0003ooooo
ooooo`19ooooo`Co0000G?ooool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oooooo
000iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0006;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:oooool003[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000Ioooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04?ooooo0ol0000_ooooo`00>oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo03oooooo1?l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0?oooool4o`0003;ooooo000looooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co
0000L?ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`0003Kooooo000nooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0007Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool003oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0cooooo`Co0000Noooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03?ooooo1?l0000nooooo`00@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo033ooooo0ol00020ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3
o`0004;ooooo0011ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`00
08Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool004;o
oooo0_l0000=ooooo`03o`000?oooooooooo02Sooooo1?l00029ooooo`;o00003Oooool00ol0003o
ooooooooo`0Xooooo`Co0000BOooool004Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Tooooo`Co0000Soooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo
1?l0001=ooooo`00AOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0
002Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0016
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0009Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool004Oooooo0_l00008oooo
o`03o`000?oooooooooo01Wooooo1?l0002Mooooo`;o00002?ooool00ol0003oooooooooo`0Ioooo
o`Co0000F?ooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co
0000Xoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`00
B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0002Xooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo001;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000:cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0>ooooo`Co0000Hoooool004cooooo0_l00003ooooo`03o`000?oooooo
oooo00[ooooo1?l0002aooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000Ioooool0
04kooooo00Co0000oooooooooooo00002?ooool4o`000;Oooooo00Co0000oooooooooooo00002?oo
ool4o`0006_ooooo001?ooooo`03o`000?oooooo000000Gooooo0ol0002looooo`03o`000?oooooo
000000Gooooo0ol0001_ooooo`00D?ooool2o`000003ooooool0003o000000;o0000`?ooool2o`00
0003ooooool0003o000000;o0000L_ooool0057ooooo0_l00035ooooo`;o0000M_ooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-141.844, \
-114.991, 1.418, 1.418}, {{208.5, 389.375}, {315.688, 169}} -> {-423.892, \
-114.991, 1.418, 1.418}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute decision regions", "Subsection"],

Cell[BoxData[
    \(\(dec = 
        ShowTwoClassificationRegions[p1, p2, pr, x, y, classColors, False, 
          Axes \[Rule] False, Frame \[Rule] True, \ FrameTicks \[Rule] None, 
          nS];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show decision regions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{dec, distrr}}], 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0049995 0.5 0.0049995 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
5e-05 5e-05 m
.04061 5e-05 L
.08485 5e-05 L
.1264 5e-05 L
.16635 5e-05 L
.20888 5e-05 L
.24982 5e-05 L
.29333 5e-05 L
.33526 5e-05 L
.37559 5e-05 L
.41849 5e-05 L
.45981 5e-05 L
.49953 5e-05 L
.54183 5e-05 L
.58253 5e-05 L
.62581 5e-05 L
.6675 5e-05 L
.7076 5e-05 L
.75028 5e-05 L
.79136 5e-05 L
.83502 5e-05 L
.87708 5e-05 L
.91756 5e-05 L
.9606 5e-05 L
.99995 5e-05 L
s
5e-05 .29997 m
.04061 .30798 L
.08485 .31628 L
.1264 .32362 L
.16635 .3302 L
.20888 .33663 L
.24982 .34219 L
.29333 .34735 L
.33526 .35152 L
.37559 .35471 L
.396 .35601 L
.41849 .35718 L
.43982 .35803 L
.44938 .35833 L
.45981 .3586 L
.46546 .35872 L
.4707 .35882 L
.47614 .3589 L
.48106 .35896 L
.48591 .359 L
.48813 .35902 L
.49048 .35903 L
.49167 .35904 L
.49299 .35904 L
.4942 .35905 L
.4953 .35905 L
.4966 .35905 L
.49732 .35906 L
.49799 .35906 L
.4992 .35906 L
.50051 .35906 L
.50179 .35906 L
.50296 .35905 L
.50425 .35905 L
.5056 .35905 L
.50788 .35904 L
.51038 .35902 L
.51311 .359 L
.51602 .35898 L
.52127 .35892 L
.52722 .35884 L
.53283 .35874 L
.54333 .35851 L
.56434 .35786 L
.58372 .35705 L
.62508 .35462 L
.66486 .35144 L
.70721 .34721 L
.74798 .34238 L
.79131 .33649 L
Mistroke
.83306 .33017 L
.87321 .32354 L
.91594 .31598 L
.95707 .30825 L
.99995 .29979 L
Mfstroke
1 1 .5 r
5e-05 5e-05 m
.04061 5e-05 L
.08485 5e-05 L
.1264 5e-05 L
.16635 5e-05 L
.20888 5e-05 L
.24982 5e-05 L
.29333 5e-05 L
.33526 5e-05 L
.37559 5e-05 L
.41849 5e-05 L
.45981 5e-05 L
.49953 5e-05 L
.54183 5e-05 L
.58253 5e-05 L
.62581 5e-05 L
.6675 5e-05 L
.7076 5e-05 L
.75028 5e-05 L
.79136 5e-05 L
.83502 5e-05 L
.87708 5e-05 L
.91756 5e-05 L
.9606 5e-05 L
.99995 5e-05 L
.99995 .29979 L
.95707 .30825 L
.91594 .31598 L
.87321 .32354 L
.83306 .33017 L
.79131 .33649 L
.74798 .34238 L
.70721 .34721 L
.66486 .35144 L
.62508 .35462 L
.58372 .35705 L
.56434 .35786 L
.54333 .35851 L
.53283 .35874 L
.52722 .35884 L
.52127 .35892 L
.51602 .35898 L
.51311 .359 L
.51038 .35902 L
.50788 .35904 L
.5056 .35905 L
.50425 .35905 L
.50296 .35905 L
.50179 .35906 L
.50051 .35906 L
.4992 .35906 L
.49799 .35906 L
.49732 .35906 L
.4966 .35905 L
.4953 .35905 L
.4942 .35905 L
.49299 .35904 L
.49167 .35904 L
.49048 .35903 L
.48813 .35902 L
.48591 .359 L
.48106 .35896 L
.47614 .3589 L
.4707 .35882 L
.46546 .35872 L
.45981 .3586 L
.44938 .35833 L
.43982 .35803 L
.41849 .35718 L
.396 .35601 L
.37559 .35471 L
.33526 .35152 L
.29333 .34735 L
.24982 .34219 L
.20888 .33663 L
.16635 .3302 L
.1264 .32362 L
.08485 .31628 L
.04061 .30798 L
5e-05 .29997 L
F
0 g
5e-05 5e-05 m
.04061 5e-05 L
.08485 5e-05 L
.1264 5e-05 L
.16635 5e-05 L
.20888 5e-05 L
.24982 5e-05 L
.29333 5e-05 L
.33526 5e-05 L
.37559 5e-05 L
.41849 5e-05 L
.45981 5e-05 L
.49953 5e-05 L
.54183 5e-05 L
.58253 5e-05 L
.62581 5e-05 L
.6675 5e-05 L
.7076 5e-05 L
.75028 5e-05 L
.79136 5e-05 L
.83502 5e-05 L
.87708 5e-05 L
.91756 5e-05 L
.9606 5e-05 L
.99995 5e-05 L
s
5e-05 .29997 m
.04061 .30798 L
.08485 .31628 L
.1264 .32362 L
.16635 .3302 L
.20888 .33663 L
.24982 .34219 L
.29333 .34735 L
.33526 .35152 L
.37559 .35471 L
.396 .35601 L
.41849 .35718 L
.43982 .35803 L
.44938 .35833 L
.45981 .3586 L
.46546 .35872 L
.4707 .35882 L
.47614 .3589 L
.48106 .35896 L
.48591 .359 L
.48813 .35902 L
.49048 .35903 L
.49167 .35904 L
.49299 .35904 L
.4942 .35905 L
.4953 .35905 L
.4966 .35905 L
.49732 .35906 L
.49799 .35906 L
.4992 .35906 L
.50051 .35906 L
.50179 .35906 L
.50296 .35905 L
.50425 .35905 L
.5056 .35905 L
.50788 .35904 L
.51038 .35902 L
.51311 .359 L
.51602 .35898 L
.52127 .35892 L
.52722 .35884 L
.53283 .35874 L
.54333 .35851 L
.56434 .35786 L
.58372 .35705 L
.62508 .35462 L
.66486 .35144 L
.70721 .34721 L
.74798 .34238 L
.79131 .33649 L
Mistroke
.83306 .33017 L
.87321 .32354 L
.91594 .31598 L
.95707 .30825 L
.99995 .29979 L
Mfstroke
5e-05 .70021 m
.04061 .69219 L
.08485 .68388 L
.1264 .67652 L
.16635 .66993 L
.20888 .66348 L
.24982 .6579 L
.29333 .65273 L
.33526 .64855 L
.37559 .64533 L
.396 .64403 L
.41849 .64285 L
.43982 .64199 L
.44938 .64169 L
.45981 .64141 L
.46546 .64129 L
.4707 .64119 L
.47614 .64111 L
.48106 .64105 L
.48591 .641 L
.49048 .64097 L
.49299 .64096 L
.4953 .64095 L
.49651 .64095 L
.49783 .64095 L
.49922 .64094 L
.50051 .64094 L
.50184 .64094 L
.5025 .64094 L
.50324 .64095 L
.50455 .64095 L
.50577 .64095 L
.50852 .64096 L
.51149 .64098 L
.51413 .641 L
.51691 .64102 L
.52188 .64108 L
.53118 .64122 L
.54136 .64142 L
.55215 .64171 L
.56195 .64203 L
.58395 .64293 L
.60409 .64399 L
.62592 .64539 L
.66888 .64886 L
.71025 .65304 L
.75003 .65779 L
.79238 .66355 L
.83315 .66972 L
.87648 .67688 L
Mistroke
.91823 .68428 L
.95838 .69183 L
.99995 .70003 L
Mfstroke
5e-05 .99995 m
.04061 .99995 L
.08485 .99995 L
.1264 .99995 L
.16635 .99995 L
.20888 .99995 L
.24982 .99995 L
.29333 .99995 L
.33526 .99995 L
.37559 .99995 L
.41849 .99995 L
.45981 .99995 L
.49953 .99995 L
.54183 .99995 L
.58253 .99995 L
.62581 .99995 L
.6675 .99995 L
.7076 .99995 L
.75028 .99995 L
.79136 .99995 L
.83502 .99995 L
.87708 .99995 L
.91756 .99995 L
.9606 .99995 L
.99995 .99995 L
s
1 1 .5 r
5e-05 .70021 m
.04061 .69219 L
.08485 .68388 L
.1264 .67652 L
.16635 .66993 L
.20888 .66348 L
.24982 .6579 L
.29333 .65273 L
.33526 .64855 L
.37559 .64533 L
.396 .64403 L
.41849 .64285 L
.43982 .64199 L
.44938 .64169 L
.45981 .64141 L
.46546 .64129 L
.4707 .64119 L
.47614 .64111 L
.48106 .64105 L
.48591 .641 L
.49048 .64097 L
.49299 .64096 L
.4953 .64095 L
.49651 .64095 L
.49783 .64095 L
.49922 .64094 L
.50051 .64094 L
.50184 .64094 L
.5025 .64094 L
.50324 .64095 L
.50455 .64095 L
.50577 .64095 L
.50852 .64096 L
.51149 .64098 L
.51413 .641 L
.51691 .64102 L
.52188 .64108 L
.53118 .64122 L
.54136 .64142 L
.55215 .64171 L
.56195 .64203 L
.58395 .64293 L
.60409 .64399 L
.62592 .64539 L
.66888 .64886 L
.71025 .65304 L
.75003 .65779 L
.79238 .66355 L
.83315 .66972 L
.87648 .67688 L
.91823 .68428 L
.95838 .69183 L
.99995 .70003 L
.99995 .99995 L
.9606 .99995 L
.91756 .99995 L
.87708 .99995 L
.83502 .99995 L
.79136 .99995 L
.75028 .99995 L
.7076 .99995 L
.6675 .99995 L
.62581 .99995 L
.58253 .99995 L
.54183 .99995 L
.49953 .99995 L
.45981 .99995 L
.41849 .99995 L
.37559 .99995 L
.33526 .99995 L
.29333 .99995 L
.24982 .99995 L
.20888 .99995 L
.16635 .99995 L
.1264 .99995 L
.08485 .99995 L
.04061 .99995 L
5e-05 .99995 L
F
0 g
5e-05 .70021 m
.04061 .69219 L
.08485 .68388 L
.1264 .67652 L
.16635 .66993 L
.20888 .66348 L
.24982 .6579 L
.29333 .65273 L
.33526 .64855 L
.37559 .64533 L
.396 .64403 L
.41849 .64285 L
.43982 .64199 L
.44938 .64169 L
.45981 .64141 L
.46546 .64129 L
.4707 .64119 L
.47614 .64111 L
.48106 .64105 L
.48591 .641 L
.49048 .64097 L
.49299 .64096 L
.4953 .64095 L
.49651 .64095 L
.49783 .64095 L
.49922 .64094 L
.50051 .64094 L
.50184 .64094 L
.5025 .64094 L
.50324 .64095 L
.50455 .64095 L
.50577 .64095 L
.50852 .64096 L
.51149 .64098 L
.51413 .641 L
.51691 .64102 L
.52188 .64108 L
.53118 .64122 L
.54136 .64142 L
.55215 .64171 L
.56195 .64203 L
.58395 .64293 L
.60409 .64399 L
.62592 .64539 L
.66888 .64886 L
.71025 .65304 L
.75003 .65779 L
.79238 .66355 L
.83315 .66972 L
.87648 .67688 L
Mistroke
.91823 .68428 L
.95838 .69183 L
.99995 .70003 L
Mfstroke
5e-05 .99995 m
.04061 .99995 L
.08485 .99995 L
.1264 .99995 L
.16635 .99995 L
.20888 .99995 L
.24982 .99995 L
.29333 .99995 L
.33526 .99995 L
.37559 .99995 L
.41849 .99995 L
.45981 .99995 L
.49953 .99995 L
.54183 .99995 L
.58253 .99995 L
.62581 .99995 L
.6675 .99995 L
.7076 .99995 L
.75028 .99995 L
.79136 .99995 L
.83502 .99995 L
.87708 .99995 L
.91756 .99995 L
.9606 .99995 L
.99995 .99995 L
s
5e-05 .29997 m
.04061 .30798 L
.08485 .31628 L
.1264 .32362 L
.16635 .3302 L
.20888 .33663 L
.24982 .34219 L
.29333 .34735 L
.33526 .35152 L
.37559 .35471 L
.396 .35601 L
.41849 .35718 L
.43982 .35803 L
.44938 .35833 L
.45981 .3586 L
.46546 .35872 L
.4707 .35882 L
.47614 .3589 L
.48106 .35896 L
.48591 .359 L
.48813 .35902 L
.49048 .35903 L
.49167 .35904 L
.49299 .35904 L
.4942 .35905 L
.4953 .35905 L
.4966 .35905 L
.49732 .35906 L
.49799 .35906 L
.4992 .35906 L
.50051 .35906 L
.50179 .35906 L
.50296 .35905 L
.50425 .35905 L
.5056 .35905 L
.50788 .35904 L
.51038 .35902 L
.51311 .359 L
.51602 .35898 L
.52127 .35892 L
.52722 .35884 L
.53283 .35874 L
.54333 .35851 L
.56434 .35786 L
.58372 .35705 L
.62508 .35462 L
.66486 .35144 L
.70721 .34721 L
.74798 .34238 L
.79131 .33649 L
Mistroke
.83306 .33017 L
.87321 .32354 L
.91594 .31598 L
.95707 .30825 L
.99995 .29979 L
Mfstroke
5e-05 .70021 m
.04061 .69219 L
.08485 .68388 L
.1264 .67652 L
.16635 .66993 L
.20888 .66348 L
.24982 .6579 L
.29333 .65273 L
.33526 .64855 L
.37559 .64533 L
.396 .64403 L
.41849 .64285 L
.43982 .64199 L
.44938 .64169 L
.45981 .64141 L
.46546 .64129 L
.4707 .64119 L
.47614 .64111 L
.48106 .64105 L
.48591 .641 L
.49048 .64097 L
.49299 .64096 L
.4953 .64095 L
.49651 .64095 L
.49783 .64095 L
.49922 .64094 L
.50051 .64094 L
.50184 .64094 L
.5025 .64094 L
.50324 .64095 L
.50455 .64095 L
.50577 .64095 L
.50852 .64096 L
.51149 .64098 L
.51413 .641 L
.51691 .64102 L
.52188 .64108 L
.53118 .64122 L
.54136 .64142 L
.55215 .64171 L
.56195 .64203 L
.58395 .64293 L
.60409 .64399 L
.62592 .64539 L
.66888 .64886 L
.71025 .65304 L
.75003 .65779 L
.79238 .66355 L
.83315 .66972 L
.87648 .67688 L
Mistroke
.91823 .68428 L
.95838 .69183 L
.99995 .70003 L
Mfstroke
.5 1 1 r
5e-05 .29997 m
.04061 .30798 L
.08485 .31628 L
.1264 .32362 L
.16635 .3302 L
.20888 .33663 L
.24982 .34219 L
.29333 .34735 L
.33526 .35152 L
.37559 .35471 L
.396 .35601 L
.41849 .35718 L
.43982 .35803 L
.44938 .35833 L
.45981 .3586 L
.46546 .35872 L
.4707 .35882 L
.47614 .3589 L
.48106 .35896 L
.48591 .359 L
.48813 .35902 L
.49048 .35903 L
.49167 .35904 L
.49299 .35904 L
.4942 .35905 L
.4953 .35905 L
.4966 .35905 L
.49732 .35906 L
.49799 .35906 L
.4992 .35906 L
.50051 .35906 L
.50179 .35906 L
.50296 .35905 L
.50425 .35905 L
.5056 .35905 L
.50788 .35904 L
.51038 .35902 L
.51311 .359 L
.51602 .35898 L
.52127 .35892 L
.52722 .35884 L
.53283 .35874 L
.54333 .35851 L
.56434 .35786 L
.58372 .35705 L
.62508 .35462 L
.66486 .35144 L
.70721 .34721 L
.74798 .34238 L
.79131 .33649 L
.83306 .33017 L
.87321 .32354 L
.91594 .31598 L
.95707 .30825 L
.99995 .29979 L
.99995 .70003 L
.95838 .69183 L
.91823 .68428 L
.87648 .67688 L
.83315 .66972 L
.79238 .66355 L
.75003 .65779 L
.71025 .65304 L
.66888 .64886 L
.62592 .64539 L
.60409 .64399 L
.58395 .64293 L
.56195 .64203 L
.55215 .64171 L
.54136 .64142 L
.53118 .64122 L
.52188 .64108 L
.51691 .64102 L
.51413 .641 L
.51149 .64098 L
.50852 .64096 L
.50577 .64095 L
.50455 .64095 L
.50324 .64095 L
.5025 .64094 L
.50184 .64094 L
.50051 .64094 L
.49922 .64094 L
.49783 .64095 L
.49651 .64095 L
.4953 .64095 L
.49299 .64096 L
.49048 .64097 L
.48591 .641 L
.48106 .64105 L
.47614 .64111 L
.4707 .64119 L
.46546 .64129 L
.45981 .64141 L
.44938 .64169 L
.43982 .64199 L
.41849 .64285 L
.396 .64403 L
.37559 .64533 L
.33526 .64855 L
.29333 .65273 L
.24982 .6579 L
.20888 .66348 L
.16635 .66993 L
.1264 .67652 L
.08485 .68388 L
.04061 .69219 L
5e-05 .70021 L
F
0 g
5e-05 .29997 m
.04061 .30798 L
.08485 .31628 L
.1264 .32362 L
.16635 .3302 L
.20888 .33663 L
.24982 .34219 L
.29333 .34735 L
.33526 .35152 L
.37559 .35471 L
.396 .35601 L
.41849 .35718 L
.43982 .35803 L
.44938 .35833 L
.45981 .3586 L
.46546 .35872 L
.4707 .35882 L
.47614 .3589 L
.48106 .35896 L
.48591 .359 L
.48813 .35902 L
.49048 .35903 L
.49167 .35904 L
.49299 .35904 L
.4942 .35905 L
.4953 .35905 L
.4966 .35905 L
.49732 .35906 L
.49799 .35906 L
.4992 .35906 L
.50051 .35906 L
.50179 .35906 L
.50296 .35905 L
.50425 .35905 L
.5056 .35905 L
.50788 .35904 L
.51038 .35902 L
.51311 .359 L
.51602 .35898 L
.52127 .35892 L
.52722 .35884 L
.53283 .35874 L
.54333 .35851 L
.56434 .35786 L
.58372 .35705 L
.62508 .35462 L
.66486 .35144 L
.70721 .34721 L
.74798 .34238 L
.79131 .33649 L
Mistroke
.83306 .33017 L
.87321 .32354 L
.91594 .31598 L
.95707 .30825 L
.99995 .29979 L
Mfstroke
5e-05 .70021 m
.04061 .69219 L
.08485 .68388 L
.1264 .67652 L
.16635 .66993 L
.20888 .66348 L
.24982 .6579 L
.29333 .65273 L
.33526 .64855 L
.37559 .64533 L
.396 .64403 L
.41849 .64285 L
.43982 .64199 L
.44938 .64169 L
.45981 .64141 L
.46546 .64129 L
.4707 .64119 L
.47614 .64111 L
.48106 .64105 L
.48591 .641 L
.49048 .64097 L
.49299 .64096 L
.4953 .64095 L
.49651 .64095 L
.49783 .64095 L
.49922 .64094 L
.50051 .64094 L
.50184 .64094 L
.5025 .64094 L
.50324 .64095 L
.50455 .64095 L
.50577 .64095 L
.50852 .64096 L
.51149 .64098 L
.51413 .641 L
.51691 .64102 L
.52188 .64108 L
.53118 .64122 L
.54136 .64142 L
.55215 .64171 L
.56195 .64203 L
.58395 .64293 L
.60409 .64399 L
.62592 .64539 L
.66888 .64886 L
.71025 .65304 L
.75003 .65779 L
.79238 .66355 L
.83315 .66972 L
.87648 .67688 L
Mistroke
.91823 .68428 L
.95838 .69183 L
.99995 .70003 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0049995 0.5 0.0049995 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.005 0.5 0.005 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.008 w
.87 .6 Mdot
.20125 .55125 Mdot
.6875 .455 Mdot
.35375 .4075 Mdot
.70375 .39625 Mdot
.0175 .35 Mdot
.95125 .3275 Mdot
.20625 .36625 Mdot
.42375 .39125 Mdot
.97875 .5425 Mdot
.0375 .51625 Mdot
.69125 .45125 Mdot
.54625 .4025 Mdot
.63125 .40875 Mdot
.44625 .4075 Mdot
.12875 .46 Mdot
.75625 .51375 Mdot
.5975 .54375 Mdot
.26875 .54375 Mdot
.015 .55375 Mdot
.88625 .5675 Mdot
.19375 .55875 Mdot
.12625 .5375 Mdot
.3 .4225 Mdot
.5075 .4075 Mdot
.69125 .47 Mdot
.55 .45125 Mdot
.955 .47125 Mdot
.54125 .46625 Mdot
.28875 .45625 Mdot
.2825 .465 Mdot
.655 .48875 Mdot
.34125 .4875 Mdot
.64875 .5075 Mdot
.40375 .54 Mdot
.5525 .56375 Mdot
.36375 .56625 Mdot
.53875 .5975 Mdot
.6225 .61625 Mdot
.51 .59625 Mdot
.7375 .55875 Mdot
.41 .57625 Mdot
.17375 .49375 Mdot
.63875 .5425 Mdot
.56875 .5025 Mdot
.055 .56625 Mdot
.49 .53 Mdot
.7925 .54125 Mdot
.02875 .4575 Mdot
.92 .45125 Mdot
.24125 .45 Mdot
.41375 .415 Mdot
.62375 .4125 Mdot
.85625 .4275 Mdot
.22375 .39625 Mdot
.09375 .375 Mdot
.865 .4125 Mdot
.35625 .45375 Mdot
.8075 .45625 Mdot
.59625 .50375 Mdot
.12375 .52125 Mdot
.5025 .51125 Mdot
.2225 .49125 Mdot
.7775 .48875 Mdot
.56625 .49375 Mdot
.93125 .495 Mdot
.32625 .45375 Mdot
.49125 .445 Mdot
.87875 .43 Mdot
.32375 .43625 Mdot
.17625 .42875 Mdot
.26 .4675 Mdot
.46875 .43 Mdot
.18625 .43625 Mdot
.69625 .43375 Mdot
.51625 .43625 Mdot
.81625 .44875 Mdot
.61875 .47375 Mdot
.83375 .49625 Mdot
.45375 .55125 Mdot
.845 .56 Mdot
.3925 .58 Mdot
.17125 .61125 Mdot
.65 .64875 Mdot
.585 .62625 Mdot
.45 .57375 Mdot
.42625 .505 Mdot
.6875 .47 Mdot
.11875 .435 Mdot
.79375 .38625 Mdot
.34875 .4225 Mdot
.79125 .43625 Mdot
.3925 .40125 Mdot
.3875 .3825 Mdot
.68375 .41375 Mdot
.21375 .45375 Mdot
.73 .4825 Mdot
.48 .545 Mdot
.205 .53625 Mdot
.88625 .49125 Mdot
.37375 .44875 Mdot
.11125 .4675 Mdot
.63625 .465 Mdot
.80375 .5075 Mdot
.44375 .54 Mdot
.5775 .5375 Mdot
.40875 .55125 Mdot
.4125 .56875 Mdot
.5425 .57375 Mdot
.37125 .57125 Mdot
.8925 .41875 Mdot
.19125 .4825 Mdot
.6975 .59625 Mdot
.33125 .66 Mdot
.75375 .6975 Mdot
.1925 .6875 Mdot
.40625 .635 Mdot
.96375 .48375 Mdot
.77625 .55875 Mdot
.49375 .55 Mdot
.65625 .5475 Mdot
.44875 .53625 Mdot
.1225 .48625 Mdot
.695 .42125 Mdot
.625 .47 Mdot
.32 .4725 Mdot
.955 .4725 Mdot
.07125 .46625 Mdot
.86125 .46375 Mdot
.18875 .4425 Mdot
.1175 .45125 Mdot
.97875 .48875 Mdot
.29875 .49 Mdot
.55125 .5175 Mdot
.97625 .505 Mdot
.6925 .50125 Mdot
.54 .5425 Mdot
.97375 .5275 Mdot
.52 .5575 Mdot
.275 .61375 Mdot
.35 .605 Mdot
.5875 .55625 Mdot
.3375 .55 Mdot
.66125 .5175 Mdot
.4275 .4375 Mdot
.56125 .38 Mdot
.3425 .35125 Mdot
.55875 .30375 Mdot
.57875 .255 Mdot
.52375 .27375 Mdot
.7375 .32625 Mdot
.42625 .34375 Mdot
.135 .47625 Mdot
.75625 .45625 Mdot
.44 .4875 Mdot
.01125 .4725 Mdot
.545 .42 Mdot
.77 .435 Mdot
.055 .55875 Mdot
.90125 .5675 Mdot
.28375 .545 Mdot
.3325 .545 Mdot
.68875 .56375 Mdot
.85875 .545 Mdot
.25375 .56875 Mdot
.0225 .60125 Mdot
.89875 .6025 Mdot
.37625 .54 Mdot
.69125 .52 Mdot
.735 .48875 Mdot
.09125 .46375 Mdot
.51125 .47375 Mdot
.1525 .47375 Mdot
.87625 .495 Mdot
.5575 .465 Mdot
.26875 .465 Mdot
.46375 .46625 Mdot
.855 .47875 Mdot
.38375 .46875 Mdot
.16625 .50875 Mdot
.245 .475 Mdot
.515 .43 Mdot
.1325 .42375 Mdot
.79375 .37125 Mdot
.44125 .375 Mdot
.83125 .40375 Mdot
.57875 .43875 Mdot
.85625 .4675 Mdot
.455 .43875 Mdot
.8 .4425 Mdot
.4625 .44875 Mdot
.2 .4775 Mdot
.56875 .515 Mdot
.60875 .5425 Mdot
.44 .585 Mdot
.44125 .62625 Mdot
.6825 .5825 Mdot
.11 .52625 Mdot
.7875 .5475 Mdot
.39125 .49625 Mdot
.73125 .47375 Mdot
.42875 .51875 Mdot
.3875 .49125 Mdot
.71375 .43 Mdot
.11 .335 Mdot
.84375 .2275 Mdot
.35875 .07875 Mdot
.3525 .12 Mdot
.8 .2025 Mdot
.39875 .31875 Mdot
.10875 .345 Mdot
.6225 .44125 Mdot
.80125 .48625 Mdot
.455 .4625 Mdot
.54375 .4775 Mdot
.46625 .5 Mdot
.36875 .4875 Mdot
.58625 .4425 Mdot
.3275 .4525 Mdot
.87375 .64875 Mdot
.17 .6375 Mdot
.73625 .55875 Mdot
.31125 .51375 Mdot
.78875 .475 Mdot
.2025 .49125 Mdot
.38625 .5225 Mdot
.925 .63875 Mdot
.89375 .63375 Mdot
.38875 .615 Mdot
.71125 .585 Mdot
.46 .57875 Mdot
.12875 .595 Mdot
.6425 .62125 Mdot
.625 .585 Mdot
.34625 .565 Mdot
.95625 .53125 Mdot
.07125 .515 Mdot
.8625 .4975 Mdot
.205 .49125 Mdot
.0775 .5025 Mdot
.98 .5075 Mdot
.26 .545 Mdot
.6 .55 Mdot
.94875 .54625 Mdot
.7 .535 Mdot
.53875 .5025 Mdot
.9825 .52625 Mdot
.515 .53875 Mdot
.27375 .50625 Mdot
.37375 .515 Mdot
.58 .52625 Mdot
.3275 .51 Mdot
.655 .5025 Mdot
.435 .56 Mdot
.58 .60375 Mdot
.31375 .6325 Mdot
.5725 .645 Mdot
.55625 .6775 Mdot
.53375 .64 Mdot
.74 .5975 Mdot
.405 .55375 Mdot
.03625 .53 Mdot
.8825 .55375 Mdot
.3775 .5675 Mdot
.015 .5825 Mdot
0 .61875 Mdot
.55875 .59625 Mdot
.75 .5725 Mdot
.07375 .4525 Mdot
.86125 .485 Mdot
.3275 .53375 Mdot
.3325 .5475 Mdot
.66625 .5375 Mdot
.85375 .59 Mdot
.29125 .555 Mdot
.88375 .50875 Mdot
.44 .5325 Mdot
.60875 .49125 Mdot
.765 .4875 Mdot
.08125 .5225 Mdot
.55875 .465 Mdot
.10125 .495 Mdot
.92875 .495 Mdot
.98125 .50125 Mdot
.53125 .585 Mdot
.22125 .61125 Mdot
.4675 .595 Mdot
.82625 .56 Mdot
.465 .5575 Mdot
.09875 .5 Mdot
.255 .48875 Mdot
.4025 .5975 Mdot
.11 .59625 Mdot
.9025 .63875 Mdot
.39375 .625 Mdot
.8225 .595 Mdot
.56125 .52125 Mdot
.85125 .51 Mdot
.48625 .50125 Mdot
.7325 .49375 Mdot
.5475 .48 Mdot
.2 .4625 Mdot
.5225 .4175 Mdot
.63875 .445 Mdot
.42375 .46875 Mdot
.405 .49875 Mdot
.69375 .55125 Mdot
.11625 .635 Mdot
.82 .63375 Mdot
.37375 .61 Mdot
.69 .61125 Mdot
.45875 .54375 Mdot
.39125 .59 Mdot
.73625 .66375 Mdot
.055 .8125 Mdot
.93125 .8975 Mdot
.76875 .93875 Mdot
.40125 .78875 Mdot
.1125 .72125 Mdot
.59625 .5775 Mdot
.815 .49 Mdot
.46625 .50125 Mdot
.53625 .4775 Mdot
.4125 .4875 Mdot
.455 .53625 Mdot
.57375 .5875 Mdot
.31 .585 Mdot
.8825 .38625 Mdot
.15625 .3575 Mdot
.74875 .4225 Mdot
.3425 .45875 Mdot
.8025 .49875 Mdot
.14 .48375 Mdot
.43 .455 Mdot
.95375 .3225 Mdot
.9675 .3225 Mdot
.3725 .37875 Mdot
.66375 .4225 Mdot
.45 .495 Mdot
.23125 .4925 Mdot
.54375 .51125 Mdot
.64 .49625 Mdot
.365 .5075 Mdot
.92875 .52625 Mdot
.12 .56375 Mdot
.8475 .545 Mdot
.20625 .5625 Mdot
.05125 .54 Mdot
.96625 .49625 Mdot
.22625 .46 Mdot
.62375 .42 Mdot
.94625 .41625 Mdot
.675 .41125 Mdot
.54 .4125 Mdot
.48 .42125 Mdot
.24875 .43 Mdot
.38 .425 Mdot
.5825 .43875 Mdot
.30875 .4625 Mdot
.65 .505 Mdot
.49625 .48625 Mdot
.52875 .46875 Mdot
.30875 .455 Mdot
.61125 .4675 Mdot
.50875 .45625 Mdot
.58375 .50625 Mdot
.7125 .54625 Mdot
.40875 .585 Mdot
.08 .515 Mdot
.865 .48875 Mdot
.3725 .44625 Mdot
.04375 .43625 Mdot
.5225 .43875 Mdot
.74125 .47125 Mdot
.07875 .5325 Mdot
.84375 .4875 Mdot
.33875 .43625 Mdot
.30625 .42625 Mdot
.6975 .42375 Mdot
.82 .33375 Mdot
.37125 .3675 Mdot
.91125 .3775 Mdot
.4575 .39125 Mdot
.59 .475 Mdot
.74125 .5375 Mdot
.0975 .58375 Mdot
.61 .6325 Mdot
.04 .62875 Mdot
.9825 .6075 Mdot
.8775 .55625 Mdot
.53625 .47 Mdot
.17875 .44125 Mdot
.51625 .44875 Mdot
.805 .495 Mdot
.495 .505 Mdot
.05 .585 Mdot
.27625 .59625 Mdot
.39 .58375 Mdot
.06375 .62375 Mdot
.99875 .5925 Mdot
.3375 .61 Mdot
.81625 .6025 Mdot
.5525 .6125 Mdot
.835 .59875 Mdot
.5225 .60625 Mdot
.64 .58875 Mdot
.615 .57375 Mdot
.26375 .54375 Mdot
.43875 .5425 Mdot
.66125 .505 Mdot
.43625 .4675 Mdot
.3475 .43875 Mdot
.7625 .41375 Mdot
.08 .41375 Mdot
.80375 .4125 Mdot
.4025 .51875 Mdot
.67875 .5725 Mdot
.43 .6425 Mdot
.4625 .615 Mdot
.74 .585 Mdot
.10125 .29375 Mdot
.59125 .26375 Mdot
.72 .28625 Mdot
.44125 .34375 Mdot
.0925 .3875 Mdot
.5575 .45125 Mdot
.8125 .4975 Mdot
.5125 .48625 Mdot
.5425 .50125 Mdot
.37375 .47125 Mdot
.45875 .44 Mdot
.56625 .425 Mdot
.31875 .41375 Mdot
.87375 .5125 Mdot
.125 .5175 Mdot
.795 .4575 Mdot
.34125 .42875 Mdot
.7975 .38 Mdot
.1925 .3675 Mdot
.38875 .40125 Mdot
.99875 .5125 Mdot
.40125 .4625 Mdot
.62125 .44875 Mdot
.455 .40625 Mdot
.22375 .43375 Mdot
.5475 .42125 Mdot
.62125 .44 Mdot
.4275 .44875 Mdot
.83875 .435 Mdot
.2 .41375 Mdot
.825 .45375 Mdot
.21875 .4625 Mdot
.0175 .485 Mdot
.95375 .58875 Mdot
.21125 .59625 Mdot
.6525 .62375 Mdot
.9325 .59125 Mdot
.695 .53 Mdot
.54875 .4925 Mdot
.49625 .37625 Mdot
.2375 .36 Mdot
.34625 .40125 Mdot
.58875 .45 Mdot
.33125 .47375 Mdot
.6275 .50375 Mdot
.52875 .52625 Mdot
.47125 .50875 Mdot
.3625 .49625 Mdot
.615 .4775 Mdot
.49625 .4825 Mdot
.60625 .44375 Mdot
.66875 .4175 Mdot
.4075 .405 Mdot
.115 .47375 Mdot
.84625 .4975 Mdot
.37875 .51 Mdot
.1 .47375 Mdot
.45625 .48 Mdot
.7425 .45 Mdot
.055 .4225 Mdot
.84125 .49125 Mdot
.35625 .5425 Mdot
.29125 .565 Mdot
.70375 .5475 Mdot
.7875 .615 Mdot
.425 .56 Mdot
.85375 .58375 Mdot
.485 .59375 Mdot
.61625 .5375 Mdot
.69875 .46125 Mdot
.16375 .39125 Mdot
.5575 .32875 Mdot
.06875 .31875 Mdot
.95 .38 Mdot
.8625 .4675 Mdot
.52125 .5125 Mdot
.14125 .49 Mdot
.5475 .46375 Mdot
.78625 .4125 Mdot
.49375 .38125 Mdot
.08375 .405 Mdot
.26375 .43125 Mdot
.415 .43625 Mdot
.055 .45625 Mdot
.32375 .4225 Mdot
.81 .43625 Mdot
.5575 .455 Mdot
.80375 .43 Mdot
.57 .42375 Mdot
.56625 .42125 Mdot
.6675 .4375 Mdot
.29625 .44375 Mdot
.405 .455 Mdot
.66875 .455 Mdot
.4175 .47375 Mdot
.3575 .475 Mdot
.77375 .51375 Mdot
.0675 .4675 Mdot
.785 .4725 Mdot
.45 .38625 Mdot
.6525 .31625 Mdot
.435 .22875 Mdot
.4575 .23875 Mdot
.7425 .22 Mdot
.7 .49375 Mdot
.68625 .5375 Mdot
.40875 .54 Mdot
.1325 .545 Mdot
.555 .545 Mdot
.80875 .54875 Mdot
.5175 .50875 Mdot
.57125 .535 Mdot
.35125 .5375 Mdot
.41 .54875 Mdot
.65125 .53375 Mdot
.27625 .56875 Mdot
.8925 .45125 Mdot
.07375 .4975 Mdot
.885 .57125 Mdot
.32125 .61625 Mdot
.8075 .6925 Mdot
.2325 .66 Mdot
.39125 .6075 Mdot
.46875 .5725 Mdot
.5325 .56375 Mdot
.4975 .555 Mdot
.20625 .50875 Mdot
.54625 .5225 Mdot
.585 .51625 Mdot
.49625 .505 Mdot
.76875 .53625 Mdot
.27875 .52625 Mdot
.78625 .51125 Mdot
.235 .51625 Mdot
.9875 .4125 Mdot
.22375 .42 Mdot
.62 .42125 Mdot
.93 .48125 Mdot
.73875 .61 Mdot
.54125 .70375 Mdot
.49125 .825 Mdot
.2625 .83 Mdot
.3325 .745 Mdot
.60375 .6325 Mdot
.3275 .55875 Mdot
.62875 .46375 Mdot
.53 .42 Mdot
.44125 .44 Mdot
.40875 .445 Mdot
.57125 .45875 Mdot
.52625 .4875 Mdot
.63625 .53625 Mdot
.605 .5325 Mdot
.4225 .52125 Mdot
.13625 .49875 Mdot
.84 .5 Mdot
.39125 .52125 Mdot
.1675 .52 Mdot
.39875 .52125 Mdot
.7575 .5475 Mdot
.04875 .58625 Mdot
.8275 .52375 Mdot
.3575 .50375 Mdot
.27 .4725 Mdot
.7075 .4875 Mdot
.825 .45875 Mdot
.39625 .52125 Mdot
.82625 .495 Mdot
.52625 .47125 Mdot
.59 .49875 Mdot
.71375 .535 Mdot
.18125 .56625 Mdot
.55 .6125 Mdot
.09125 .61125 Mdot
.88625 .54625 Mdot
.8275 .485 Mdot
.5175 .43875 Mdot
.97875 .43375 Mdot
.14875 .465 Mdot
.58375 .48625 Mdot
.775 .52625 Mdot
.5125 .60375 Mdot
.07625 .475 Mdot
.22375 .44625 Mdot
.36625 .3875 Mdot
.06375 .3175 Mdot
.9775 .40875 Mdot
.41375 .4325 Mdot
.80375 .435 Mdot
.57375 .4775 Mdot
.785 .51 Mdot
.59 .5175 Mdot
.53 .5275 Mdot
.6925 .50875 Mdot
.285 .4725 Mdot
.44625 .45125 Mdot
.6125 .44125 Mdot
.4975 .42125 Mdot
.285 .42 Mdot
.8225 .41375 Mdot
.04375 .44 Mdot
.7775 .46625 Mdot
.485 .4975 Mdot
.61 .5475 Mdot
.475 .66625 Mdot
.39 .71125 Mdot
.79 .7625 Mdot
.86375 .5725 Mdot
.57 .48125 Mdot
.41375 .48125 Mdot
.2 .4675 Mdot
.50125 .465 Mdot
.83875 .4675 Mdot
.50375 .57625 Mdot
.5775 .55375 Mdot
.34375 .545 Mdot
.43 .5025 Mdot
.62125 .49125 Mdot
.27125 .40875 Mdot
.885 .64 Mdot
.04 .57875 Mdot
.9325 .47625 Mdot
.295 .4125 Mdot
.77125 .315 Mdot
.99625 .375 Mdot
.2875 .42625 Mdot
.385 .46875 Mdot
.5325 .5775 Mdot
.42 .53875 Mdot
.5425 .53375 Mdot
.205 .5275 Mdot
.54375 .4875 Mdot
.59375 .4725 Mdot
.50875 .51125 Mdot
.7325 .5075 Mdot
.35875 .5325 Mdot
.71 .52375 Mdot
.26375 .50875 Mdot
.9825 .48875 Mdot
.2525 .46375 Mdot
.56 .44375 Mdot
.97375 .42375 Mdot
.71125 .35125 Mdot
.55625 .30125 Mdot
.50625 .285 Mdot
.26625 .29 Mdot
.31875 .37 Mdot
.63375 .45 Mdot
.3225 .4925 Mdot
.62375 .515 Mdot
.5075 .5375 Mdot
.43375 .52 Mdot
.4625 .5475 Mdot
.51 .5875 Mdot
.5775 .6075 Mdot
.61625 .61125 Mdot
.5975 .65625 Mdot
.44125 .65875 Mdot
.1875 .56875 Mdot
.74 .52625 Mdot
.4875 .50875 Mdot
.195 .5525 Mdot
.395 .55625 Mdot
.77 .55 Mdot
.0625 .5225 Mdot
.80875 .545 Mdot
.34125 .51125 Mdot
.3525 .52 Mdot
.64375 .50625 Mdot
.81625 .52125 Mdot
.37875 .48 Mdot
.71375 .44375 Mdot
.62875 .43125 Mdot
.55 .43 Mdot
.6875 .40625 Mdot
.2525 .42125 Mdot
.4725 .435 Mdot
.16375 .4475 Mdot
.8325 .4525 Mdot
.79 .4875 Mdot
.05375 .47125 Mdot
.46375 .52125 Mdot
.8575 .53125 Mdot
.2425 .51 Mdot
.5625 .49625 Mdot
.78625 .51 Mdot
.525 .4725 Mdot
.0675 .54625 Mdot
.21875 .55 Mdot
.2975 .5875 Mdot
.13 .595 Mdot
.86625 .54 Mdot
.53 .5525 Mdot
.7975 .545 Mdot
.52625 .5075 Mdot
.785 .50125 Mdot
.6025 .49125 Mdot
.5325 .4675 Mdot
.67 .49125 Mdot
.315 .56875 Mdot
.45375 .5825 Mdot
.57625 .6 Mdot
.51375 .62625 Mdot
.27875 .62375 Mdot
.8325 .5625 Mdot
.07375 .5475 Mdot
.73 .535 Mdot
.5025 .5825 Mdot
.6475 .58125 Mdot
.41875 .54125 Mdot
.41 .49875 Mdot
.8 .4425 Mdot
.99375 .35625 Mdot
.5075 .38875 Mdot
.39125 .39625 Mdot
.28 .38375 Mdot
.49 .4025 Mdot
.81 .45 Mdot
.5025 .42625 Mdot
.5625 .42 Mdot
.36375 .4725 Mdot
.4625 .54 Mdot
.57375 .57125 Mdot
.29375 .6275 Mdot
.8775 .30875 Mdot
.00125 .3725 Mdot
.99125 .46875 Mdot
.275 .55875 Mdot
.7425 .6575 Mdot
.935 .6175 Mdot
.29375 .58125 Mdot
.39625 .54125 Mdot
.65875 .39 Mdot
.25375 .4325 Mdot
.61 .45625 Mdot
.20125 .4825 Mdot
.54 .5125 Mdot
.60125 .53375 Mdot
.54 .4925 Mdot
.64875 .4575 Mdot
.45375 .43625 Mdot
.64375 .44375 Mdot
.295 .44125 Mdot
.96125 .51875 Mdot
.3225 .55875 Mdot
.52625 .60875 Mdot
.9675 .62625 Mdot
.70625 .595 Mdot
.54125 .5325 Mdot
.5075 .425 Mdot
.23375 .38875 Mdot
.33375 .34125 Mdot
.6125 .3575 Mdot
.325 .3825 Mdot
.66 .42625 Mdot
.49625 .47375 Mdot
.4 .50125 Mdot
.53625 .47375 Mdot
.44125 .4275 Mdot
.6275 .36125 Mdot
.60375 .2725 Mdot
.57625 .25875 Mdot
.49625 .2775 Mdot
.24625 .43 Mdot
.675 .44625 Mdot
.5225 .4375 Mdot
.27 .4375 Mdot
.35875 .41875 Mdot
.8 .40375 Mdot
.04375 .40375 Mdot
.79875 .43625 Mdot
.3275 .4875 Mdot
.32875 .52875 Mdot
.69 .54125 Mdot
.85125 .55625 Mdot
.305 .55625 Mdot
.02875 .575 Mdot
.64 .575 Mdot
.68625 .595 Mdot
.57625 .54875 Mdot
.66375 .5725 Mdot
.32625 .5675 Mdot
.34125 .555 Mdot
.24875 .53 Mdot
.7825 .56625 Mdot
.755 .5825 Mdot
.18 .5775 Mdot
.46375 .5625 Mdot
.67375 .56875 Mdot
.35125 .58625 Mdot
.57625 .5775 Mdot
.75375 .545 Mdot
.58125 .50625 Mdot
.06125 .4925 Mdot
.21625 .48875 Mdot
.37375 .42875 Mdot
.13375 .445 Mdot
.75625 .45 Mdot
.6475 .42375 Mdot
.79 .42375 Mdot
.4325 .475 Mdot
.82 .4775 Mdot
.5725 .475 Mdot
.58125 .45625 Mdot
.6425 .41125 Mdot
.29875 .3325 Mdot
.5 .3075 Mdot
.51 .29875 Mdot
.5525 .3375 Mdot
.3 .37375 Mdot
.78375 .48625 Mdot
.17375 .5225 Mdot
.61625 .515 Mdot
.5875 .4325 Mdot
.58625 .37125 Mdot
.44625 .27 Mdot
.44375 .25125 Mdot
.72625 .28 Mdot
.0075 .3725 Mdot
.45125 .6825 Mdot
.36375 .6575 Mdot
.32875 .6425 Mdot
.495 .59875 Mdot
.73375 .50375 Mdot
.565 .43125 Mdot
.5125 .45625 Mdot
.47125 .405 Mdot
.35 .34875 Mdot
.595 .34125 Mdot
.3175 .325 Mdot
.855 .64625 Mdot
.24 .36875 Mdot
.7275 .2825 Mdot
.0075 .26625 Mdot
.8675 .2975 Mdot
.3725 .3575 Mdot
.3575 .38875 Mdot
.7575 .54375 Mdot
.1575 .51 Mdot
.6325 .48 Mdot
.15625 .455 Mdot
.6025 .44625 Mdot
.57625 .4475 Mdot
.57625 .495 Mdot
.58375 .545 Mdot
.53875 .555 Mdot
.56875 .55625 Mdot
.31625 .575 Mdot
.94375 .48625 Mdot
.3775 .41625 Mdot
.51 .3525 Mdot
.94125 .325 Mdot
.6675 .405 Mdot
.56125 .50375 Mdot
1 .5725 Mdot
.5425 .61375 Mdot
.20625 .66875 Mdot
.35875 .705 Mdot
.61125 .68375 Mdot
.32 .66125 Mdot
.64375 .66125 Mdot
.50875 .6125 Mdot
.4 .5825 Mdot
.5475 .5825 Mdot
.38375 .57 Mdot
.715 .57625 Mdot
.56 .65875 Mdot
.5575 .64625 Mdot
.5225 .62875 Mdot
.26 .5175 Mdot
.7 .53 Mdot
.475 .5325 Mdot
.02625 .52375 Mdot
.34125 .485 Mdot
.3375 .495 Mdot
.77 .495 Mdot
.03375 .44 Mdot
.77375 .3875 Mdot
.3675 .38125 Mdot
.34875 .35 Mdot
.59875 .3475 Mdot
.955 .34875 Mdot
.2375 .34 Mdot
.1125 .30375 Mdot
.5025 .35625 Mdot
.73375 .38125 Mdot
.63375 .45125 Mdot
.63375 .475 Mdot
.36625 .46625 Mdot
.2525 .44625 Mdot
.34125 .47625 Mdot
.69625 .4675 Mdot
.7625 .46125 Mdot
.315 .48 Mdot
.38375 .495 Mdot
.53375 .46 Mdot
.52125 .4225 Mdot
.49625 .3925 Mdot
.8 .40875 Mdot
.56875 .4175 Mdot
.04625 .4675 Mdot
.2625 .45875 Mdot
.3375 .58625 Mdot
.23625 .5975 Mdot
.605 .545 Mdot
.7375 .60125 Mdot
.82125 .5775 Mdot
.33625 .5325 Mdot
.8375 .57875 Mdot
.57375 .57875 Mdot
.62 .64625 Mdot
.61875 .69375 Mdot
.27 .7675 Mdot
.565 .7475 Mdot
.44 .7375 Mdot
.575 .6125 Mdot
.33 .555 Mdot
.74 .425 Mdot
.295 .40125 Mdot
.47125 .405 Mdot
.65 .49 Mdot
.56125 .58125 Mdot
.49625 .71625 Mdot
.405 .8 Mdot
.6375 .81125 Mdot
.17125 .76375 Mdot
.37625 .35 Mdot
.35125 .37125 Mdot
.38 .43625 Mdot
.52 .47375 Mdot
.63 .5125 Mdot
.59625 .54 Mdot
.5125 .49 Mdot
.5 .48125 Mdot
.35 .51625 Mdot
.605 .5575 Mdot
.31875 .6175 Mdot
.835 .44375 Mdot
.21125 .5825 Mdot
.6875 .6325 Mdot
.08125 .67 Mdot
.835 .64625 Mdot
.3525 .5575 Mdot
.38875 .56375 Mdot
.01125 .51125 Mdot
.9475 .49375 Mdot
.97875 .45875 Mdot
.83 .49 Mdot
.0375 .52875 Mdot
.71875 .57625 Mdot
.15 .61875 Mdot
.6 .65125 Mdot
.5375 .64375 Mdot
.62625 .5875 Mdot
.53125 .5175 Mdot
.59375 .485 Mdot
.5175 .4475 Mdot
.3325 .41875 Mdot
.94625 .515 Mdot
.39125 .58625 Mdot
.5325 .64875 Mdot
.885 .69375 Mdot
.6275 .67125 Mdot
.5675 .64625 Mdot
.55 .595 Mdot
.18625 .5525 Mdot
.39625 .49 Mdot
.60375 .43875 Mdot
.31875 .41625 Mdot
.63625 .37625 Mdot
.50875 .38375 Mdot
.40875 .4075 Mdot
.5175 .4225 Mdot
.37375 .44 Mdot
.77625 .46875 Mdot
.50875 .46125 Mdot
.575 .45625 Mdot
.54375 .4575 Mdot
.2425 .46125 Mdot
.7425 .50125 Mdot
.4225 .52 Mdot
.0925 .58 Mdot
.90875 .5975 Mdot
.44875 .6225 Mdot
.3475 .61125 Mdot
.72625 .6475 Mdot
.0275 .78125 Mdot
.7225 .78625 Mdot
.415 .7225 Mdot
.37625 .72125 Mdot
.5575 .69 Mdot
.94375 .62375 Mdot
.24625 .64875 Mdot
.175 .6675 Mdot
.42 .6125 Mdot
.7275 .58375 Mdot
.725 .57875 Mdot
.56375 .53625 Mdot
.41375 .55125 Mdot
.20375 .53875 Mdot
.3325 .505 Mdot
.7075 .47125 Mdot
.7875 .48 Mdot
.39 .465 Mdot
.30625 .42625 Mdot
.42 .44875 Mdot
.65875 .455 Mdot
.46875 .47 Mdot
.82125 .46875 Mdot
.5225 .535 Mdot
.05375 .51875 Mdot
.29 .59875 Mdot
.26625 .55 Mdot
.30875 .5375 Mdot
.475 .585 Mdot
.8225 .5275 Mdot
.8225 .55375 Mdot
.19125 .56125 Mdot
.88875 .51125 Mdot
.5875 .52875 Mdot
.60625 .49375 Mdot
.645 .4775 Mdot
.22 .43625 Mdot
.58375 .46375 Mdot
.42 .4625 Mdot
.615 .53 Mdot
.335 .57375 Mdot
.68625 .6725 Mdot
.40875 .7025 Mdot
.39125 .66 Mdot
.625 .6025 Mdot
.56375 .5475 Mdot
.51625 .44125 Mdot
.43625 .3475 Mdot
.5675 .2975 Mdot
.33 .28 Mdot
.825 .28625 Mdot
.29875 .60125 Mdot
.36 .66125 Mdot
.42125 .64 Mdot
.4875 .62875 Mdot
.6175 .6 Mdot
.6075 .61 Mdot
.445 .6375 Mdot
.60875 .6675 Mdot
.32625 .655 Mdot
.5625 .605 Mdot
.3525 .51125 Mdot
.73125 .55 Mdot
.175 .52 Mdot
.6725 .475 Mdot
.1275 .4375 Mdot
.83875 .4375 Mdot
.32875 .47125 Mdot
.42625 .50375 Mdot
.9525 .53375 Mdot
.1125 .545 Mdot
.8225 .5375 Mdot
.9375 .4825 Mdot
.86875 .4425 Mdot
.7275 .3825 Mdot
.18 .36625 Mdot
.5725 .32625 Mdot
.55875 .31625 Mdot
.6225 .365 Mdot
.495 .43375 Mdot
.6675 .4575 Mdot
.45375 .52125 Mdot
.345 .54625 Mdot
.01625 .5375 Mdot
.93875 .48 Mdot
.35875 .46125 Mdot
.62625 .43375 Mdot
.8075 .38625 Mdot
.53375 .3575 Mdot
.615 .34875 Mdot
.555 .35875 Mdot
.14875 .39875 Mdot
.42625 .475 Mdot
.59625 .50875 Mdot
.3025 .5375 Mdot
.63375 .58 Mdot
.53875 .555 Mdot
.39625 .50875 Mdot
.475 .495 Mdot
.43125 .48625 Mdot
.75375 .445 Mdot
.49 .39375 Mdot
.60125 .38625 Mdot
.54875 .38125 Mdot
.185 .515 Mdot
.80125 .505 Mdot
.375 .5175 Mdot
.14875 .49125 Mdot
.765 .4825 Mdot
.56875 .43375 Mdot
.355 .445 Mdot
.65625 .40125 Mdot
.025 .22 Mdot
.6775 .25375 Mdot
.44 .30125 Mdot
.435 .2925 Mdot
.47625 .37125 Mdot
.93125 .4725 Mdot
.33375 .47875 Mdot
.105 .4975 Mdot
.4525 .56875 Mdot
.67125 .58625 Mdot
.84 .5075 Mdot
.445 .48875 Mdot
.56875 .47625 Mdot
.04875 .485 Mdot
.36125 .50125 Mdot
.72125 .5675 Mdot
.85375 .52125 Mdot
.40375 .525 Mdot
.175 .57625 Mdot
.435 .575 Mdot
.71875 .6225 Mdot
.485 .69375 Mdot
.80875 .7 Mdot
.45125 .66 Mdot
.1375 .61375 Mdot
.31875 .4875 Mdot
.22125 .48375 Mdot
.38625 .46 Mdot
.39 .47 Mdot
.85125 .49875 Mdot
.81375 .475 Mdot
.05125 .44375 Mdot
.89625 .435 Mdot
.62875 .41875 Mdot
.57125 .4125 Mdot
.665 .4175 Mdot
.25875 .3975 Mdot
.5425 .4025 Mdot
.39875 .40125 Mdot
.59125 .4025 Mdot
.40125 .40625 Mdot
.6375 .3975 Mdot
.46375 .3625 Mdot
.36875 .4225 Mdot
.62125 .4575 Mdot
.55625 .44375 Mdot
.545 .465 Mdot
.4525 .515 Mdot
.46375 .5375 Mdot
.46125 .5675 Mdot
.68 .64125 Mdot
.24875 .5375 Mdot
.37 .48125 Mdot
.41875 .46375 Mdot
.5125 .44 Mdot
.55 .46875 Mdot
.61 .45125 Mdot
.46375 .40375 Mdot
.605 .37125 Mdot
.34625 .3775 Mdot
.56875 .3875 Mdot
.4125 .47375 Mdot
.6375 .41375 Mdot
.04 .44125 Mdot
.12875 .54375 Mdot
.6625 .59625 Mdot
.0975 .59375 Mdot
.9075 .57875 Mdot
.30875 .5575 Mdot
.4375 .49875 Mdot
.92125 .445 Mdot
.12375 .44875 Mdot
.7575 .46875 Mdot
.8875 .50625 Mdot
.915 .53125 Mdot
.7325 .57 Mdot
.26125 .57 Mdot
.48 .62125 Mdot
.56875 .6675 Mdot
.62625 .6375 Mdot
.5075 .59875 Mdot
.6625 .60875 Mdot
.45625 .565 Mdot
.35 .5375 Mdot
.0275 .5475 Mdot
.95125 .55375 Mdot
.3475 .52875 Mdot
.7025 .5075 Mdot
.71 .50125 Mdot
.45875 .48125 Mdot
.645 .46625 Mdot
.53375 .47125 Mdot
.1675 .455 Mdot
.41875 .4425 Mdot
.5775 .48125 Mdot
.31125 .495 Mdot
.64875 .47375 Mdot
.5525 .485 Mdot
.38375 .51375 Mdot
.42375 .52 Mdot
.47 .53125 Mdot
.79125 .57375 Mdot
.44375 .65375 Mdot
.60875 .66375 Mdot
.53 .67375 Mdot
.1425 .53625 Mdot
.85 .51125 Mdot
.33 .46125 Mdot
.205 .43875 Mdot
.6375 .45125 Mdot
.695 .5 Mdot
.31625 .52125 Mdot
.6075 .595 Mdot
.03375 .7375 Mdot
.62375 .7025 Mdot
.4775 .7 Mdot
.45375 .65 Mdot
.405 .56875 Mdot
.935 .49125 Mdot
.4425 .4875 Mdot
.00125 .4275 Mdot
.53125 .40875 Mdot
.56375 .39875 Mdot
.96375 .485 Mdot
.3375 .5125 Mdot
.63 .4775 Mdot
.0225 .47125 Mdot
.38875 .5025 Mdot
.69125 .455 Mdot
.8875 .45125 Mdot
.4525 .50125 Mdot
.035 .495 Mdot
.5175 .4975 Mdot
.71 .4825 Mdot
.51875 .44125 Mdot
.78125 .4425 Mdot
.415 .43375 Mdot
.18625 .45875 Mdot
.35125 .5175 Mdot
.975 .5425 Mdot
.29125 .51625 Mdot
.375 .55125 Mdot
.41 .48875 Mdot
.83625 .455 Mdot
.7475 .445 Mdot
.105 .455 Mdot
.8875 .49125 Mdot
.6775 .51 Mdot
.4925 .5425 Mdot
.72375 .53375 Mdot
.2525 .5625 Mdot
.55375 .5875 Mdot
.36375 .59625 Mdot
.62625 .5875 Mdot
.38375 .56 Mdot
.63875 .52625 Mdot
.485 .4925 Mdot
.3625 .44 Mdot
.5675 .38875 Mdot
.5875 .40125 Mdot
.55875 .425 Mdot
.48125 .4575 Mdot
.36125 .47875 Mdot
.5475 .5075 Mdot
.61875 .5025 Mdot
.2675 .38 Mdot
.315 .3375 Mdot
.43125 .32625 Mdot
.5325 .3925 Mdot
.46625 .41 Mdot
.67875 .45 Mdot
.45125 .5425 Mdot
.5775 .56875 Mdot
.3675 .52875 Mdot
.5625 .50625 Mdot
.47 .44625 Mdot
.5575 .53625 Mdot
.0775 .525 Mdot
.10625 .425 Mdot
.63375 .42375 Mdot
.12625 .435 Mdot
.9475 .47125 Mdot
.27125 .50375 Mdot
.47125 .54 Mdot
.86 .575 Mdot
.175 .565 Mdot
.6625 .55125 Mdot
.085 .5125 Mdot
.80625 .52625 Mdot
.88875 .505 Mdot
.03625 .49625 Mdot
.67875 .4475 Mdot
.33875 .46125 Mdot
.36875 .38125 Mdot
.63375 .34 Mdot
.6175 .335 Mdot
.50125 .35875 Mdot
.65875 .34625 Mdot
.4775 .4075 Mdot
.31625 .44875 Mdot
.08125 .45625 Mdot
.95 .475 Mdot
.2975 .51 Mdot
.7925 .56 Mdot
.65 .56 Mdot
.38375 .58125 Mdot
.70125 .565 Mdot
.525 .5675 Mdot
.18125 .57875 Mdot
.44875 .54625 Mdot
.53875 .51625 Mdot
.31625 .50125 Mdot
.6175 .50125 Mdot
.605 .52375 Mdot
.37 .58375 Mdot
.3875 .5925 Mdot
.52 .58375 Mdot
.80625 .55875 Mdot
.415 .475 Mdot
.59625 .4175 Mdot
.51 .41875 Mdot
.05875 .48375 Mdot
.93125 .505 Mdot
.29625 .51625 Mdot
.205 .5175 Mdot
.58 .49 Mdot
.7675 .45625 Mdot
.365 .42375 Mdot
.475 .3675 Mdot
.0825 .4025 Mdot
.5625 .45875 Mdot
.51875 .47 Mdot
.53625 .52125 Mdot
.27625 .56375 Mdot
.875 .5475 Mdot
.67625 .49125 Mdot
.6075 .48 Mdot
.49375 .39125 Mdot
.29375 .38 Mdot
.6325 .42375 Mdot
.05125 .44875 Mdot
.36125 .4825 Mdot
.72625 .4975 Mdot
.84625 .5025 Mdot
.5125 .46 Mdot
.735 .415 Mdot
.6575 .39375 Mdot
.47875 .395 Mdot
.82 .3725 Mdot
.35125 .40875 Mdot
.225 .39875 Mdot
.3825 .3975 Mdot
.8775 .38125 Mdot
.38625 .3875 Mdot
.35375 .35 Mdot
.4 .39 Mdot
.8525 .4075 Mdot
.66625 .47875 Mdot
.20125 .50875 Mdot
.8425 .51375 Mdot
.7025 .47125 Mdot
.44 .435 Mdot
.765 .45875 Mdot
.28625 .46875 Mdot
.505 .44 Mdot
.3925 .4775 Mdot
.61875 .5175 Mdot
.38625 .4725 Mdot
.63875 .465 Mdot
.455 .5325 Mdot
.38375 .58375 Mdot
.5375 .61125 Mdot
.63875 .6775 Mdot
.5275 .67625 Mdot
.51875 .59875 Mdot
.30875 .55375 Mdot
.575 .51125 Mdot
.60875 .485 Mdot
.28 .69375 Mdot
.32125 .73875 Mdot
.41875 .73875 Mdot
.555 .63625 Mdot
.43125 .5825 Mdot
.71625 .4925 Mdot
.42625 .39375 Mdot
.51125 .36 Mdot
.45625 .445 Mdot
.56625 .4625 Mdot
.48875 .50375 Mdot
.46 .50625 Mdot
.115 .47875 Mdot
.08125 .5325 Mdot
.57875 .51375 Mdot
.18625 .53 Mdot
.945 .52875 Mdot
.25625 .57375 Mdot
.5175 .55 Mdot
.7625 .54875 Mdot
.25875 .525 Mdot
.5725 .5025 Mdot
.21125 .49875 Mdot
.6975 .4975 Mdot
.8925 .495 Mdot
.09125 .51875 Mdot
.65625 .5775 Mdot
.36 .56 Mdot
.3325 .5975 Mdot
.66 .6425 Mdot
.60125 .61875 Mdot
.55 .60125 Mdot
.57625 .615 Mdot
.535 .57125 Mdot
.28625 .5175 Mdot
.115 .51125 Mdot
.96125 .48 Mdot
.24375 .46875 Mdot
.855 .45375 Mdot
.615 .5075 Mdot
.37125 .54125 Mdot
.7025 .56 Mdot
.47125 .55 Mdot
.27 .51 Mdot
.42875 .5 Mdot
.4875 .5175 Mdot
.35125 .49875 Mdot
.64625 .51875 Mdot
.57 .52125 Mdot
.3575 .4475 Mdot
.41125 .44 Mdot
.535 .4425 Mdot
.79375 .4375 Mdot
.40625 .47125 Mdot
.60875 .565 Mdot
.48 .5475 Mdot
.9875 .4625 Mdot
.28375 .485 Mdot
.23625 .5025 Mdot
.4925 .5175 Mdot
.8225 .5325 Mdot
.4325 .55 Mdot
.38 .5325 Mdot
.1225 .43125 Mdot
.495 .38125 Mdot
.54375 .38375 Mdot
.5875 .3775 Mdot
.23375 .37375 Mdot
.75375 .41125 Mdot
.905 .47875 Mdot
.69375 .58125 Mdot
.44125 .70125 Mdot
.2725 .61 Mdot
.66875 .5875 Mdot
.05625 .5625 Mdot
.32125 .4625 Mdot
.775 .49625 Mdot
.80625 .515 Mdot
.56625 .51875 Mdot
.93625 .56125 Mdot
.54875 .57125 Mdot
.5 .58875 Mdot
.7875 .6025 Mdot
.32875 .5525 Mdot
.36875 .535 Mdot
.28625 .52 Mdot
.83 .5 Mdot
.435 .52875 Mdot
.34875 .60875 Mdot
.44375 .645 Mdot
.8375 .65625 Mdot
.56625 .61875 Mdot
.2875 .5675 Mdot
.0375 .51 Mdot
.7675 .49875 Mdot
.7075 .5425 Mdot
.45375 .55 Mdot
.7425 .51875 Mdot
.31 .5025 Mdot
.49625 .52625 Mdot
.44 .50375 Mdot
.57625 .48875 Mdot
.39375 .57625 Mdot
.61875 .5975 Mdot
.415 .5375 Mdot
.49875 .51125 Mdot
.44125 .50375 Mdot
.66625 .4425 Mdot
.48625 .44125 Mdot
.61875 .45875 Mdot
.25875 .47625 Mdot
.58375 .5025 Mdot
.5975 .4625 Mdot
.30625 .37 Mdot
.31375 .36875 Mdot
.395 .42125 Mdot
.5675 .49 Mdot
.4375 .5525 Mdot
.76125 .62625 Mdot
.36 .665 Mdot
.52625 .6875 Mdot
.46625 .5925 Mdot
.56625 .55375 Mdot
.5325 .5275 Mdot
.3325 .55875 Mdot
.15625 .54375 Mdot
.08375 .46125 Mdot
.51 .46375 Mdot
.26 .48375 Mdot
.955 .4875 Mdot
.2225 .42625 Mdot
.56375 .455 Mdot
.6675 .445 Mdot
.31625 .48875 Mdot
.53375 .50875 Mdot
.28 .4775 Mdot
.6275 .44 Mdot
.91 .4425 Mdot
.13625 .3775 Mdot
.60875 .315 Mdot
.36875 .3875 Mdot
.3125 .4325 Mdot
.72375 .4075 Mdot
.545 .43875 Mdot
.6025 .4675 Mdot
.5 .4475 Mdot
.6 .43 Mdot
.25875 .48 Mdot
.115 .525 Mdot
.1925 .55875 Mdot
.9125 .51625 Mdot
.6 .46125 Mdot
.31875 .48625 Mdot
.75875 .51125 Mdot
.995 .495 Mdot
.48 .51875 Mdot
.28625 .52625 Mdot
.4175 .52875 Mdot
.4575 .455 Mdot
.35875 .43875 Mdot
.6825 .3575 Mdot
.5675 .30875 Mdot
.3425 .32 Mdot
.42375 .3475 Mdot
.5275 .3925 Mdot
.78875 .46375 Mdot
.40125 .5125 Mdot
.62125 .5075 Mdot
.46 .5625 Mdot
.2525 .51375 Mdot
.29875 .50625 Mdot
.3975 .53625 Mdot
.83625 .54 Mdot
.5 .5675 Mdot
.32 .58875 Mdot
.21 .58625 Mdot
.42875 .5775 Mdot
.555 .5575 Mdot
.64875 .54875 Mdot
.16125 .56125 Mdot
.68875 .56125 Mdot
.8 .4575 Mdot
.43 .4325 Mdot
.3175 .57 Mdot
.66875 .59875 Mdot
.05875 .66875 Mdot
.3725 .69125 Mdot
.7175 .62875 Mdot
.76 .56375 Mdot
.6325 .55125 Mdot
.4825 .4625 Mdot
.49125 .485 Mdot
.7525 .46875 Mdot
.37625 .4675 Mdot
.4375 .49 Mdot
.21625 .54375 Mdot
.7625 .5525 Mdot
.54 .51125 Mdot
.275 .46125 Mdot
.49625 .4425 Mdot
.83875 .3825 Mdot
.51625 .37875 Mdot
.305 .4575 Mdot
.12625 .4825 Mdot
.66375 .48 Mdot
.69125 .495 Mdot
.5325 .505 Mdot
.66375 .48875 Mdot
.36125 .51125 Mdot
.53625 .495 Mdot
.37375 .5025 Mdot
.62 .495 Mdot
.36875 .475 Mdot
.62875 .455 Mdot
.35375 .48625 Mdot
.57625 .4425 Mdot
.42875 .4025 Mdot
.655 .3975 Mdot
.46625 .41125 Mdot
.6875 .42 Mdot
.1575 .44125 Mdot
.62375 .45375 Mdot
.615 .47375 Mdot
.38 .4025 Mdot
.29125 .36875 Mdot
.36625 .3375 Mdot
.5775 .3775 Mdot
.42125 .35375 Mdot
.765 .3475 Mdot
.385 .39625 Mdot
.50625 .4425 Mdot
.48 .5025 Mdot
.60125 .56625 Mdot
.55625 .59625 Mdot
.24375 .44875 Mdot
.24 .48375 Mdot
.1425 .53125 Mdot
.4375 .515 Mdot
.34625 .47125 Mdot
.925 .44625 Mdot
.21 .4375 Mdot
.6025 .43 Mdot
.58875 .47125 Mdot
.3775 .49 Mdot
.4925 .5 Mdot
.34 .60875 Mdot
.56125 .655 Mdot
.93375 .68125 Mdot
.17375 .675 Mdot
.585 .70875 Mdot
.3375 .6075 Mdot
.35125 .525 Mdot
.69875 .49875 Mdot
.56625 .53 Mdot
.615 .50375 Mdot
.43125 .49125 Mdot
.65875 .51 Mdot
.2175 .4475 Mdot
.16 .38125 Mdot
.14875 .42875 Mdot
.95875 .4575 Mdot
.57 .49375 Mdot
.40125 .4675 Mdot
.6925 .43375 Mdot
.48375 .435 Mdot
.27625 .43 Mdot
.39375 .4375 Mdot
.48875 .5425 Mdot
.3675 .57625 Mdot
.6475 .6475 Mdot
.6 .7125 Mdot
.33375 .7375 Mdot
.42875 .665 Mdot
.50625 .59625 Mdot
.82375 .53625 Mdot
.38375 .45375 Mdot
.635 .3925 Mdot
.44375 .34375 Mdot
.24625 .49625 Mdot
.34625 .49 Mdot
.32 .46625 Mdot
.835 .47875 Mdot
.5725 .4425 Mdot
.27875 .44 Mdot
.34 .47375 Mdot
.34375 .49375 Mdot
.61375 .50875 Mdot
.6525 .5 Mdot
.1375 .48 Mdot
.61 .48875 Mdot
.81625 .49875 Mdot
.44 .47625 Mdot
.95875 .40375 Mdot
.3825 .34625 Mdot
.57375 .3125 Mdot
.1725 .26375 Mdot
.345 .30375 Mdot
.72375 .365 Mdot
.65 .43625 Mdot
.76875 .48625 Mdot
.4475 .58375 Mdot
.43375 .50375 Mdot
.73 .5275 Mdot
.4875 .56 Mdot
.4225 .54625 Mdot
.15 .47875 Mdot
.725 .5075 Mdot
.6575 .5125 Mdot
.205 .5 Mdot
.53375 .49375 Mdot
.8175 .5575 Mdot
.50875 .58 Mdot
.30375 .515 Mdot
.17875 .50875 Mdot
.6075 .52375 Mdot
.665 .52125 Mdot
.59375 .4825 Mdot
.65125 .5025 Mdot
.33375 .49625 Mdot
.56625 .48125 Mdot
.345 .4575 Mdot
.6825 .465 Mdot
.32375 .445 Mdot
.62 .49375 Mdot
.35875 .5 Mdot
.59 .55625 Mdot
.39625 .59625 Mdot
.6825 .60875 Mdot
.43375 .56375 Mdot
.7575 .585 Mdot
.11125 .6075 Mdot
.635 .6275 Mdot
.61125 .69125 Mdot
.405 .68375 Mdot
.2925 .66625 Mdot
.33375 .62625 Mdot
.60375 .5375 Mdot
.44125 .505 Mdot
.7325 .53625 Mdot
.39375 .51375 Mdot
.52625 .47625 Mdot
.455 .4725 Mdot
.61875 .465 Mdot
.57125 .4175 Mdot
.1425 .5275 Mdot
.295 .52 Mdot
.225 .525 Mdot
.34875 .56125 Mdot
.405 .58125 Mdot
.9225 .585 Mdot
.15875 .605 Mdot
.675 .56875 Mdot
.47625 .51 Mdot
.4925 .4575 Mdot
.42125 .44875 Mdot
.3975 .41875 Mdot
.52625 .43875 Mdot
.9125 .435 Mdot
.23125 .4975 Mdot
.58125 .505 Mdot
.25 .5325 Mdot
.455 .58375 Mdot
.64875 .6075 Mdot
.57125 .57375 Mdot
.6075 .58 Mdot
.42625 .60625 Mdot
.695 .56875 Mdot
.1725 .615 Mdot
.2225 .62625 Mdot
.0725 .51 Mdot
.5825 .47 Mdot
.4525 .40125 Mdot
.66875 .42375 Mdot
.9875 .39 Mdot
.52375 .4325 Mdot
.2225 .4675 Mdot
.40875 .50125 Mdot
.52625 .42125 Mdot
.35625 .41875 Mdot
.57625 .42125 Mdot
.68375 .39125 Mdot
.295 .38375 Mdot
.46125 .44625 Mdot
.49625 .47 Mdot
.79375 .46 Mdot
.42 .51375 Mdot
.61125 .54 Mdot
.48125 .5425 Mdot
.24875 .55 Mdot
.37875 .5325 Mdot
.255 .49 Mdot
.845 .46125 Mdot
.66 .45625 Mdot
.20625 .4375 Mdot
.06625 .45 Mdot
.46125 .46875 Mdot
.2575 .4525 Mdot
.6525 .46 Mdot
.68125 .4725 Mdot
.10125 .49375 Mdot
.5875 .4825 Mdot
.8875 .47875 Mdot
.4325 .46375 Mdot
.8625 .535 Mdot
.48625 .54875 Mdot
.54875 .58125 Mdot
.2175 .62125 Mdot
.265 .62625 Mdot
.7825 .56875 Mdot
.54625 .555 Mdot
.885 .46625 Mdot
.3325 .37 Mdot
.4675 .4225 Mdot
.675 .4425 Mdot
.5775 .4325 Mdot
.45375 .4575 Mdot
.07125 .55125 Mdot
.685 .5325 Mdot
.7475 .51875 Mdot
.1775 .51625 Mdot
.49875 .505 Mdot
.8275 .45 Mdot
.5875 .42 Mdot
.23625 .4575 Mdot
.205 .4875 Mdot
.59 .475 Mdot
.625 .44375 Mdot
.6525 .47 Mdot
.6525 .50625 Mdot
.335 .5 Mdot
.50875 .5325 Mdot
.38875 .54625 Mdot
.6675 .5525 Mdot
.37375 .53 Mdot
.56625 .4925 Mdot
.34375 .475 Mdot
.62875 .48125 Mdot
.3875 .5125 Mdot
.6825 .54875 Mdot
.41375 .615 Mdot
.78 .60875 Mdot
.12625 .555 Mdot
.63125 .48375 Mdot
.585 .39125 Mdot
.34625 .42875 Mdot
.3525 .4625 Mdot
.28 .51 Mdot
.6 .535 Mdot
.4825 .545 Mdot
.7375 .48875 Mdot
.36125 .47125 Mdot
.56 .47625 Mdot
.4275 .5075 Mdot
.65625 .50375 Mdot
.5875 .53 Mdot
.065 .465 Mdot
.365 .455 Mdot
.24125 .46375 Mdot
.335 .40875 Mdot
.4375 .39125 Mdot
.885 .3875 Mdot
.17375 .3725 Mdot
.7025 .385 Mdot
.39125 .41875 Mdot
.5675 .43875 Mdot
.4 .45875 Mdot
.39375 .43625 Mdot
.54875 .42125 Mdot
.9275 .42875 Mdot
.20375 .43 Mdot
.59125 .45 Mdot
.16375 .4725 Mdot
.57375 .45625 Mdot
.59625 .44125 Mdot
.54875 .45375 Mdot
.64875 .43 Mdot
.415 .415 Mdot
.6975 .48 Mdot
.13875 .46 Mdot
.28125 .45 Mdot
.04875 .46125 Mdot
.59375 .465 Mdot
.46 .54 Mdot
.66 .56875 Mdot
.97875 .63625 Mdot
.53125 .5925 Mdot
.23375 .60125 Mdot
.415 .5925 Mdot
.545 .60125 Mdot
.33 .59625 Mdot
.5825 .6075 Mdot
.6625 .60625 Mdot
.29125 .5875 Mdot
.4875 .57375 Mdot
.47375 .58 Mdot
.775 .6 Mdot
.45125 .58125 Mdot
.60625 .57875 Mdot
.515 .59125 Mdot
.95125 .4625 Mdot
.26625 .42125 Mdot
.4325 .4225 Mdot
.1625 .44875 Mdot
.8675 .4625 Mdot
.70125 .5125 Mdot
.20125 .52875 Mdot
.11625 .53125 Mdot
.5375 .53625 Mdot
.21375 .5175 Mdot
.68375 .50125 Mdot
.67 .5075 Mdot
.07875 .46625 Mdot
.60125 .46 Mdot
.93125 .55375 Mdot
.40125 .61875 Mdot
.7725 .5775 Mdot
.59125 .58375 Mdot
.50875 .52375 Mdot
.28625 .45375 Mdot
.21625 .39 Mdot
.76375 .42125 Mdot
.515 .405 Mdot
.9725 .48 Mdot
.2225 .585 Mdot
.53 .59625 Mdot
.60375 .55375 Mdot
.65625 .52875 Mdot
.5 .485 Mdot
.65125 .385 Mdot
.835 .40625 Mdot
.14375 .4 Mdot
.5175 .43 Mdot
.79375 .49 Mdot
.65 .50875 Mdot
.2025 .49125 Mdot
.18875 .5075 Mdot
.57875 .49125 Mdot
.64625 .48875 Mdot
.65375 .51375 Mdot
.65375 .485 Mdot
.33 .46875 Mdot
.4825 .455 Mdot
.42625 .43875 Mdot
.6525 .41375 Mdot
.3975 .43875 Mdot
.56625 .45875 Mdot
.30875 .475 Mdot
.65625 .46125 Mdot
.3525 .425 Mdot
.745 .37375 Mdot
.35875 .33375 Mdot
.7825 .34 Mdot
.1925 .37375 Mdot
.5525 .4125 Mdot
.6225 .51625 Mdot
.35625 .54 Mdot
.3475 .54375 Mdot
.275 .52375 Mdot
.60625 .52375 Mdot
.5375 .54875 Mdot
.65375 .5875 Mdot
.41 .60625 Mdot
.60375 .5675 Mdot
.34375 .53125 Mdot
.6625 .4875 Mdot
.6425 .49125 Mdot
.4425 .49375 Mdot
.26 .54125 Mdot
.3175 .61125 Mdot
.475 .63875 Mdot
.86875 .645 Mdot
.12375 .65625 Mdot
.7625 .6475 Mdot
.3625 .615 Mdot
.57375 .58 Mdot
.375 .5525 Mdot
.42375 .54875 Mdot
.59875 .53 Mdot
.85375 .51625 Mdot
.23125 .5125 Mdot
.5825 .50625 Mdot
.16625 .50125 Mdot
.595 .5075 Mdot
.55375 .50125 Mdot
.57875 .47875 Mdot
.62375 .4925 Mdot
.44375 .51375 Mdot
.69375 .52 Mdot
.13125 .57 Mdot
.285 .63 Mdot
.03625 .63125 Mdot
.59 .61375 Mdot
.48625 .55625 Mdot
.63625 .48125 Mdot
.99875 .38875 Mdot
.61125 .39625 Mdot
.12125 .3725 Mdot
.45 .3775 Mdot
.57125 .4025 Mdot
.295 .4175 Mdot
.57125 .41 Mdot
.69625 .41375 Mdot
.27375 .41625 Mdot
.49 .42 Mdot
.465 .41875 Mdot
.7875 .3925 Mdot
.44375 .4025 Mdot
.61125 .41375 Mdot
.555 .4125 Mdot
.92 .505 Mdot
.2825 .51375 Mdot
.45 .5075 Mdot
.10125 .51375 Mdot
.88375 .50125 Mdot
.75 .47 Mdot
.18625 .4775 Mdot
.1675 .46625 Mdot
.93375 .4475 Mdot
.555 .43375 Mdot
.235 .46625 Mdot
.67375 .47125 Mdot
.68125 .50875 Mdot
.04375 .53625 Mdot
.6625 .52625 Mdot
.99375 .4325 Mdot
.40625 .38 Mdot
.64 .415 Mdot
.69375 .425 Mdot
.46 .45125 Mdot
.35625 .49375 Mdot
.195 .53125 Mdot
.72125 .5175 Mdot
.4875 .53125 Mdot
.1875 .56 Mdot
.595 .50875 Mdot
.54625 .4825 Mdot
.7225 .51625 Mdot
.4425 .53375 Mdot
.63125 .56125 Mdot
.955 .55375 Mdot
.0275 .56 Mdot
.55375 .56125 Mdot
.77875 .56875 Mdot
.6875 .53 Mdot
.22625 .52875 Mdot
.10375 .515 Mdot
.605 .5125 Mdot
.68 .525 Mdot
.62 .55875 Mdot
.675 .5425 Mdot
.35875 .56875 Mdot
.40875 .55125 Mdot
.465 .57125 Mdot
.645 .54875 Mdot
.425 .57 Mdot
.57875 .52 Mdot
.28875 .52375 Mdot
.57375 .515 Mdot
.43625 .53 Mdot
.765 .53375 Mdot
.35875 .5575 Mdot
.72125 .53 Mdot
.2525 .4975 Mdot
.4775 .47375 Mdot
.6675 .43625 Mdot
.4175 .46625 Mdot
.38125 .4675 Mdot
.23625 .44375 Mdot
.59625 .46625 Mdot
.5475 .4525 Mdot
.64375 .41125 Mdot
.4425 .37875 Mdot
.61 .42625 Mdot
.29625 .38875 Mdot
.69875 .41375 Mdot
.6775 .4125 Mdot
.5 .43125 Mdot
.265 .39 Mdot
.33 .3275 Mdot
.4875 .3275 Mdot
.84125 .3675 Mdot
.1025 .36875 Mdot
.815 .39125 Mdot
.31625 .44875 Mdot
.60625 .47 Mdot
.33375 .4825 Mdot
.4475 .47875 Mdot
.65125 .4925 Mdot
.7725 .48375 Mdot
.30125 .46125 Mdot
.535 .41875 Mdot
.1775 .43 Mdot
.6275 .42625 Mdot
.5 .44 Mdot
.5775 .47 Mdot
.64125 .49625 Mdot
.47125 .465 Mdot
.66625 .4175 Mdot
.13 .385 Mdot
.3275 .35625 Mdot
.04875 .43375 Mdot
.94125 .44125 Mdot
.65875 .465 Mdot
.53125 .4975 Mdot
.65 .5275 Mdot
.92 .54125 Mdot
.67875 .585 Mdot
.09625 .605 Mdot
.46625 .5925 Mdot
.565 .65875 Mdot
.2625 .6725 Mdot
.6175 .62375 Mdot
.64875 .60125 Mdot
.30125 .60375 Mdot
.48875 .55 Mdot
.45375 .53875 Mdot
.785 .57 Mdot
.47375 .57125 Mdot
.5775 .5675 Mdot
.57625 .5725 Mdot
.89625 .51125 Mdot
.32125 .51375 Mdot
.445 .53625 Mdot
.05875 .53875 Mdot
.9075 .55 Mdot
.78 .5425 Mdot
.14375 .54375 Mdot
.24125 .5325 Mdot
.8425 .5575 Mdot
.54625 .575 Mdot
.30875 .575 Mdot
.6425 .545 Mdot
.68625 .52375 Mdot
.00875 .51 Mdot
.76 .52375 Mdot
.99625 .5625 Mdot
.43125 .60125 Mdot
.515 .56375 Mdot
.81125 .53875 Mdot
.3325 .56875 Mdot
.5175 .56375 Mdot
.1175 .53875 Mdot
.68 .5325 Mdot
.485 .50875 Mdot
.11625 .38875 Mdot
.63375 .45625 Mdot
.52625 .5025 Mdot
.7575 .4925 Mdot
.4325 .50625 Mdot
.57125 .51875 Mdot
.00125 .57875 Mdot
.55875 .57875 Mdot
.72625 .5375 Mdot
.715 .585 Mdot
.28625 .58875 Mdot
.00875 .5625 Mdot
.635 .58 Mdot
.71875 .5725 Mdot
.5625 .49875 Mdot
.715 .48875 Mdot
.41125 .45375 Mdot
.24875 .44875 Mdot
.57125 .42875 Mdot
.615 .48875 Mdot
.47625 .5125 Mdot
.54125 .555 Mdot
.3375 .54 Mdot
.4775 .5525 Mdot
.51 .525 Mdot
.77875 .51625 Mdot
.31875 .53625 Mdot
.6975 .55125 Mdot
.35625 .575 Mdot
.3525 .61875 Mdot
.7325 .56375 Mdot
.4425 .3975 Mdot
.4025 .345 Mdot
.20625 .42625 Mdot
.60125 .43125 Mdot
.58125 .47125 Mdot
.61625 .55375 Mdot
.47 .6225 Mdot
.5925 .57625 Mdot
.28375 .595 Mdot
.6575 .5825 Mdot
.75 .54875 Mdot
.515 .69125 Mdot
.2575 .66375 Mdot
.33375 .6925 Mdot
.4825 .64 Mdot
.8575 .56125 Mdot
.1025 .56125 Mdot
.81125 .565 Mdot
.26375 .51 Mdot
.6225 .55125 Mdot
.35375 .595 Mdot
.43875 .595 Mdot
.72 .55875 Mdot
.6625 .55 Mdot
.37 .54875 Mdot
.50875 .545 Mdot
.21 .50125 Mdot
.6 .51125 Mdot
.50375 .53 Mdot
.55625 .5175 Mdot
.6775 .49875 Mdot
.47125 .5475 Mdot
.65 .55 Mdot
.1625 .5375 Mdot
.3325 .50625 Mdot
.1075 .50375 Mdot
.815 .49125 Mdot
.76375 .49375 Mdot
.54125 .42625 Mdot
.72125 .47375 Mdot
.76375 .55375 Mdot
.78625 .53 Mdot
.0825 .53 Mdot
.4925 .52875 Mdot
.51625 .41125 Mdot
.285 .3575 Mdot
.60375 .39 Mdot
.66 .42125 Mdot
.29 .4375 Mdot
.50125 .49625 Mdot
.44375 .505 Mdot
.80125 .50875 Mdot
.48 .50375 Mdot
.53 .495 Mdot
.64375 .47625 Mdot
.87 .51625 Mdot
.34375 .535 Mdot
.45125 .54 Mdot
.02875 .5475 Mdot
.925 .55 Mdot
.8075 .55375 Mdot
.12 .57 Mdot
.24125 .56 Mdot
.84875 .5325 Mdot
.49125 .5125 Mdot
.3925 .50875 Mdot
.6 .51125 Mdot
.69625 .52625 Mdot
.86375 .52875 Mdot
.94125 .50125 Mdot
.475 .48 Mdot
.40875 .46875 Mdot
.955 .46375 Mdot
.21 .41 Mdot
.615 .37125 Mdot
.07375 .38625 Mdot
.62625 .43125 Mdot
.51 .495 Mdot
.09875 .58 Mdot
.68875 .5475 Mdot
.49375 .5725 Mdot
.74875 .58875 Mdot
.44875 .575 Mdot
.5575 .525 Mdot
.5875 .46125 Mdot
.65125 .455 Mdot
.7475 .4225 Mdot
.35125 .385 Mdot
.7 .39375 Mdot
.73125 .39125 Mdot
.52625 .4175 Mdot
.7175 .4575 Mdot
.475 .4825 Mdot
.1125 .495 Mdot
.70625 .505 Mdot
.54375 .47125 Mdot
.52 .44875 Mdot
.47375 .4275 Mdot
.4625 .43375 Mdot
.305 .425 Mdot
.6525 .46625 Mdot
.745 .4675 Mdot
.295 .44 Mdot
.69 .44125 Mdot
.42625 .455 Mdot
.225 .455 Mdot
.85875 .4925 Mdot
.97 .6125 Mdot
.51875 .6575 Mdot
.42625 .6775 Mdot
.1725 .59375 Mdot
.58125 .56 Mdot
.63375 .48 Mdot
.62375 .39625 Mdot
.40625 .31 Mdot
.65375 .38 Mdot
.23625 .43375 Mdot
.66875 .48875 Mdot
.79 .54875 Mdot
.52125 .3025 Mdot
.2575 .37375 Mdot
.34875 .39125 Mdot
.47125 .44125 Mdot
.85625 .5 Mdot
.145 .4925 Mdot
.77875 .47125 Mdot
.2525 .49 Mdot
.635 .44375 Mdot
.34 .385 Mdot
.44625 .40375 Mdot
.77375 .46375 Mdot
.58 .48375 Mdot
.41375 .51375 Mdot
.46 .56625 Mdot
.27 .61375 Mdot
.5525 .58875 Mdot
.565 .56875 Mdot
.52375 .5625 Mdot
.70125 .54125 Mdot
.4125 .48625 Mdot
.66875 .49125 Mdot
.17125 .51125 Mdot
.36375 .53 Mdot
1 .555 Mdot
.1575 .4675 Mdot
.72375 .47375 Mdot
.7975 .45125 Mdot
.60125 .56875 Mdot
.70875 .52125 Mdot
.68 .46875 Mdot
.835 .49625 Mdot
.0725 .4275 Mdot
.5225 .4075 Mdot
.46375 .48375 Mdot
.33625 .5 Mdot
.6125 .49 Mdot
.60375 .47625 Mdot
.3225 .48625 Mdot
.49875 .44625 Mdot
.44 .46 Mdot
.83125 .425 Mdot
.4325 .39375 Mdot
.5525 .38125 Mdot
.6425 .37875 Mdot
.89125 .395 Mdot
.33625 .42125 Mdot
.4825 .4475 Mdot
.94 .46 Mdot
.80125 .46125 Mdot
.12875 .41875 Mdot
.24375 .39625 Mdot
.83375 .3975 Mdot
.44875 .39 Mdot
.49875 .37125 Mdot
.54 .4 Mdot
.68125 .41375 Mdot
.915 .4775 Mdot
.81 .52 Mdot
.5875 .54625 Mdot
.29375 .56125 Mdot
.06875 .64125 Mdot
.68375 .67875 Mdot
.1025 .66375 Mdot
.51875 .62625 Mdot
.58625 .575 Mdot
.17 .47125 Mdot
.66 .43375 Mdot
.5025 .38 Mdot
.71875 .34375 Mdot
.45625 .365 Mdot
.53625 .47 Mdot
.64 .4775 Mdot
.5625 .505 Mdot
.75 .505 Mdot
.4725 .535 Mdot
.73875 .5675 Mdot
.745 .575 Mdot
.52 .59875 Mdot
.68875 .58625 Mdot
.53 .55875 Mdot
.06 .55625 Mdot
.75625 .5425 Mdot
.5 .47625 Mdot
.54375 .42875 Mdot
.44625 .44375 Mdot
.54125 .4575 Mdot
.205 .49 Mdot
.74 .51 Mdot
.68 .545 Mdot
.33375 .57375 Mdot
.6975 .56875 Mdot
.40875 .53125 Mdot
.195 .49875 Mdot
.90625 .50875 Mdot
.825 .44625 Mdot
.6325 .44875 Mdot
.405 .47625 Mdot
.16125 .52125 Mdot
.59 .54375 Mdot
.67125 .61375 Mdot
.57375 .65125 Mdot
.40875 .72875 Mdot
.71 .65375 Mdot
.17875 .57875 Mdot
.6725 .495 Mdot
.815 .42625 Mdot
.55125 .69 Mdot
.26875 .61875 Mdot
.32375 .57875 Mdot
.49625 .59375 Mdot
.8575 .59 Mdot
.11625 .5925 Mdot
.80375 .59 Mdot
.27875 .59875 Mdot
.59125 .565 Mdot
.29875 .565 Mdot
.5 .52375 Mdot
.8225 .49 Mdot
.4775 .46125 Mdot
.48375 .4475 Mdot
.4275 .38875 Mdot
.31875 .35875 Mdot
.505 .37125 Mdot
.57 .3825 Mdot
.525 .38 Mdot
.74375 .40625 Mdot
.32875 .465 Mdot
.7375 .54 Mdot
.18125 .53875 Mdot
.3375 .55125 Mdot
.98125 .54875 Mdot
.20125 .57875 Mdot
.65125 .5775 Mdot
.8525 .63375 Mdot
.6275 .605 Mdot
.7275 .605 Mdot
.6275 .6075 Mdot
.8875 .545 Mdot
.04125 .55125 Mdot
.4775 .5875 Mdot
.4775 .51875 Mdot
.4075 .53 Mdot
.55125 .53875 Mdot
.62625 .54375 Mdot
.3175 .49125 Mdot
.4925 .555 Mdot
.44625 .54875 Mdot
.8425 .575 Mdot
.42875 .62875 Mdot
.55 .6575 Mdot
.6225 .66125 Mdot
.91 .53875 Mdot
.31625 .48375 Mdot
.515 .43625 Mdot
.92625 .4375 Mdot
.81 .4525 Mdot
.14625 .485 Mdot
.24875 .54875 Mdot
.78875 .58375 Mdot
.4425 .59875 Mdot
.57125 .635 Mdot
.495 .6225 Mdot
.67875 .57125 Mdot
.915 .4975 Mdot
.995 .45625 Mdot
.68625 .445 Mdot
.71125 .4375 Mdot
.18875 .43125 Mdot
.705 .36125 Mdot
.1825 .3475 Mdot
.39375 .32625 Mdot
.6425 .36375 Mdot
.21125 .59 Mdot
.67 .6325 Mdot
.47625 .67 Mdot
.725 .67375 Mdot
.48 .65125 Mdot
.565 .55 Mdot
.6375 .53875 Mdot
.4825 .525 Mdot
.77 .52 Mdot
.58875 .505 Mdot
.765 .48 Mdot
.745 .455 Mdot
.52625 .43375 Mdot
.67375 .41375 Mdot
.56 .45375 Mdot
.0625 .48 Mdot
.73 .5125 Mdot
.50875 .5775 Mdot
.51375 .63125 Mdot
.46125 .595 Mdot
.58625 .5675 Mdot
.14 .5125 Mdot
.83125 .47375 Mdot
.55875 .43 Mdot
.4575 .3925 Mdot
.61375 .365 Mdot
.42375 .41125 Mdot
.2125 .44625 Mdot
.90375 .455 Mdot
.01875 .47625 Mdot
.6525 .51375 Mdot
.76 .485 Mdot
.4325 .45 Mdot
.135 .43625 Mdot
.585 .4525 Mdot
.6375 .4025 Mdot
.60375 .39 Mdot
.39375 .35125 Mdot
.765 .38375 Mdot
.09625 .425 Mdot
.73 .5175 Mdot
.82625 .59125 Mdot
.5575 .35125 Mdot
.27625 .3575 Mdot
.32875 .3475 Mdot
.49625 .30625 Mdot
.82875 .2625 Mdot
.1675 .27 Mdot
.775 .305 Mdot
.26125 .33 Mdot
.58625 .39375 Mdot
.305 .4475 Mdot
.5 .51625 Mdot
.87625 .525 Mdot
.3875 .545 Mdot
.5575 .53875 Mdot
.38875 .565 Mdot
.35125 .57125 Mdot
.46625 .6 Mdot
.60875 .64 Mdot
.515 .65 Mdot
.7275 .66625 Mdot
.29125 .6025 Mdot
.79 .49125 Mdot
.20875 .42875 Mdot
.355 .4075 Mdot
.89 .3675 Mdot
.2625 .31625 Mdot
.57 .3025 Mdot
.92375 .28 Mdot
.64375 .2675 Mdot
.76875 .29125 Mdot
.54125 .285 Mdot
.88375 .275 Mdot
.10125 .31 Mdot
.47375 .27375 Mdot
.43875 .33875 Mdot
.465 .35625 Mdot
.505 .4025 Mdot
.6125 .44375 Mdot
.36625 .49875 Mdot
.47 .4825 Mdot
.46125 .485 Mdot
.825 .4875 Mdot
.41375 .465 Mdot
.545 .45625 Mdot
.64875 .45375 Mdot
.88625 .5775 Mdot
.325 .59875 Mdot
.52125 .635 Mdot
.89625 .5875 Mdot
.82 .5625 Mdot
.16625 .52 Mdot
.265 .4575 Mdot
.68375 .43 Mdot
.5325 .43 Mdot
.56875 .3925 Mdot
.505 .42375 Mdot
.6225 .46625 Mdot
.07125 .4825 Mdot
.86875 .46625 Mdot
.975 .48 Mdot
.54375 .44875 Mdot
.82 .4375 Mdot
.1575 .465 Mdot
.72625 .50375 Mdot
.2075 .545 Mdot
.32625 .5625 Mdot
.64625 .53625 Mdot
.25125 .34875 Mdot
.635 .33 Mdot
.47125 .3125 Mdot
.74125 .33 Mdot
.50125 .3525 Mdot
.59 .4375 Mdot
.585 .49 Mdot
.435 .49875 Mdot
.80125 .49 Mdot
.68375 .48625 Mdot
.77375 .4675 Mdot
.73125 .47875 Mdot
.53125 .4725 Mdot
.6525 .49875 Mdot
.6075 .50875 Mdot
.09875 .47625 Mdot
.6425 .46375 Mdot
.5775 .48125 Mdot
.4475 .4325 Mdot
.46875 .465 Mdot
.58375 .51125 Mdot
.2075 .53375 Mdot
.81875 .545 Mdot
.48 .63125 Mdot
.5275 .62125 Mdot
.605 .6675 Mdot
.4 .66 Mdot
.2025 .62875 Mdot
.94625 .58375 Mdot
.0575 .6075 Mdot
.505 .54625 Mdot
.85125 .555 Mdot
.43125 .59 Mdot
.15375 .585 Mdot
.54125 .5325 Mdot
.71 .555 Mdot
.5375 .55125 Mdot
.40625 .52875 Mdot
.78 .5325 Mdot
.0975 .5075 Mdot
.6725 .46125 Mdot
.87125 .4225 Mdot
.51875 .5475 Mdot
.2825 .57625 Mdot
.3525 .63 Mdot
.47 .6475 Mdot
.8325 .68875 Mdot
.2175 .7225 Mdot
.71625 .71375 Mdot
.24875 .6625 Mdot
.5975 .64125 Mdot
.32625 .60125 Mdot
.50125 .49125 Mdot
.92625 .44875 Mdot
.28 .46625 Mdot
.61875 .48375 Mdot
.38125 .505 Mdot
.36 .5375 Mdot
.43625 .50625 Mdot
.64 .43625 Mdot
.49 .39875 Mdot
.78 .36875 Mdot
.1925 .43125 Mdot
.88 .49875 Mdot
.1925 .58125 Mdot
.3825 .63 Mdot
.80625 .66 Mdot
.31625 .6675 Mdot
.545 .70875 Mdot
.94375 .68625 Mdot
.6725 .69875 Mdot
.72 .7 Mdot
.5975 .7125 Mdot
.83 .7875 Mdot
.12625 .82625 Mdot
.46125 .8525 Mdot
.43875 .8225 Mdot
.5425 .77625 Mdot
.38875 .70125 Mdot
.6725 .6275 Mdot
.3525 .56625 Mdot
.48375 .49625 Mdot
.46375 .4675 Mdot
.82 .46625 Mdot
.39875 .45875 Mdot
.56375 .4575 Mdot
.6525 .50375 Mdot
.8575 .49 Mdot
.30875 .485 Mdot
.53 .44875 Mdot
.00875 .44 Mdot
.85625 .44625 Mdot
.84375 .46375 Mdot
.18125 .48 Mdot
.28875 .52375 Mdot
.6025 .53875 Mdot
.58875 .5375 Mdot
.56875 .5475 Mdot
.5325 .535 Mdot
.51625 .51625 Mdot
.1825 .5275 Mdot
.82625 .53 Mdot
.9 .52625 Mdot
.3975 .53 Mdot
.93625 .53875 Mdot
.135 .54 Mdot
.66125 .58 Mdot
.28 .56125 Mdot
.28125 .56 Mdot
.64 .58 Mdot
.2425 .49875 Mdot
.63375 .48875 Mdot
.45625 .4675 Mdot
.77 .44625 Mdot
.505 .44 Mdot
.62875 .4725 Mdot
.51625 .4775 Mdot
.4475 .4475 Mdot
.83 .46625 Mdot
.71875 .49375 Mdot
.74125 .5125 Mdot
.7275 .55 Mdot
.53125 .53125 Mdot
.66 .54375 Mdot
.62375 .5225 Mdot
.195 .565 Mdot
.50625 .5475 Mdot
.625 .58375 Mdot
.41125 .59875 Mdot
.50375 .60125 Mdot
.54625 .54875 Mdot
.24625 .535 Mdot
.84 .5125 Mdot
.365 .42125 Mdot
.655 .42875 Mdot
.57875 .3925 Mdot
.335 .38 Mdot
.26375 .3725 Mdot
.95375 .35 Mdot
.085 .25625 Mdot
.36125 .26875 Mdot
.95875 .28625 Mdot
.4225 .29 Mdot
.17125 .36125 Mdot
.51125 .45125 Mdot
.745 .49375 Mdot
.47125 .5375 Mdot
.46 .55375 Mdot
.765 .55875 Mdot
.09625 .59625 Mdot
.66 .58 Mdot
.88625 .54875 Mdot
.46 .54 Mdot
.2825 .56625 Mdot
.35375 .53375 Mdot
.46375 .5325 Mdot
.82125 .52125 Mdot
.23 .45375 Mdot
.7125 .41125 Mdot
.285 .43875 Mdot
.58125 .44 Mdot
.2575 .4425 Mdot
.6 .51375 Mdot
.88125 .54375 Mdot
.2525 .49875 Mdot
.67375 .45375 Mdot
.35125 .3975 Mdot
.355 .35 Mdot
.4525 .3825 Mdot
.65125 .395 Mdot
.46875 .42375 Mdot
.805 .41875 Mdot
.115 .38 Mdot
.97125 .34 Mdot
.1375 .31625 Mdot
.415 .29 Mdot
.7825 .31625 Mdot
.35375 .5025 Mdot
.56 .4925 Mdot
.93625 .525 Mdot
.62625 .465 Mdot
.72 .3975 Mdot
.65875 .365 Mdot
.75125 .32375 Mdot
.1875 .29125 Mdot
.4275 .27375 Mdot
.45375 .30125 Mdot
.5575 .32625 Mdot
.38 .34625 Mdot
.6475 .38 Mdot
.36125 .44625 Mdot
.5 .5075 Mdot
.4525 .53125 Mdot
.82875 .49375 Mdot
.36875 .46875 Mdot
.5875 .4425 Mdot
.645 .38625 Mdot
0 .47375 Mdot
.86375 .46 Mdot
.285 .47125 Mdot
.5325 .47 Mdot
.04125 .49875 Mdot
.8375 .5025 Mdot
.8075 .52375 Mdot
.2225 .52875 Mdot
.30375 .52625 Mdot
.535 .4975 Mdot
.64625 .51375 Mdot
.56375 .50875 Mdot
.55375 .5275 Mdot
.4275 .52125 Mdot
.32125 .5375 Mdot
.75 .53625 Mdot
.82625 .53125 Mdot
.335 .485 Mdot
.12375 .44 Mdot
.62 .5 Mdot
.38375 .51625 Mdot
.22 .52875 Mdot
.61375 .49875 Mdot
.21125 .63875 Mdot
.65875 .66875 Mdot
.4475 .7125 Mdot
.77625 .725 Mdot
.49875 .715 Mdot
.66875 .57375 Mdot
.36875 .45625 Mdot
.53625 .48125 Mdot
.8025 .4925 Mdot
.75875 .50125 Mdot
.6675 .53125 Mdot
.73125 .4925 Mdot
.5 .48625 Mdot
.72125 .48125 Mdot
.66125 .46375 Mdot
.215 .4575 Mdot
.3675 .51 Mdot
.7225 .4875 Mdot
.38125 .4525 Mdot
.54875 .4775 Mdot
.44625 .47375 Mdot
.3425 .48 Mdot
.785 .4725 Mdot
.325 .54125 Mdot
.79375 .52875 Mdot
.51 .525 Mdot
.2625 .51 Mdot
.37375 .565 Mdot
.8375 .6275 Mdot
.20375 .71625 Mdot
.2425 .76875 Mdot
.375 .71125 Mdot
.26 .63125 Mdot
.44 .56 Mdot
.7825 .52375 Mdot
.415 .46625 Mdot
.52625 .5225 Mdot
.71125 .505 Mdot
.09625 .465 Mdot
.655 .4725 Mdot
.8625 .5225 Mdot
.43375 .44875 Mdot
.29375 .41 Mdot
.37125 .4075 Mdot
.43 .40875 Mdot
.83875 .41125 Mdot
.22375 .4 Mdot
.68875 .40625 Mdot
.31625 .38875 Mdot
.5725 .37875 Mdot
.24125 .39625 Mdot
.655 .4525 Mdot
.82 .5175 Mdot
.2325 .58 Mdot
.75 .6275 Mdot
.36 .68125 Mdot
.2775 .7025 Mdot
.50875 .63625 Mdot
.63125 .65 Mdot
.445 .6525 Mdot
.85125 .66875 Mdot
.08 .66 Mdot
.1425 .66625 Mdot
.365 .66625 Mdot
.79375 .62875 Mdot
.9325 .5325 Mdot
.40875 .4575 Mdot
.52 .42125 Mdot
.9875 .38625 Mdot
.59875 .4175 Mdot
.78375 .48125 Mdot
.61375 .50625 Mdot
.7225 .505 Mdot
.275 .505 Mdot
.38875 .50875 Mdot
.435 .4725 Mdot
.53375 .47625 Mdot
.385 .4875 Mdot
.6875 .49 Mdot
.34 .45625 Mdot
.51875 .43875 Mdot
.43625 .4425 Mdot
.82 .5075 Mdot
.39625 .565 Mdot
.585 .61 Mdot
.6075 .615 Mdot
.04 .45125 Mdot
.8525 .44375 Mdot
.29 .465 Mdot
.51125 .485 Mdot
.08375 .46625 Mdot
.7825 .4525 Mdot
.84375 .42875 Mdot
.225 .4525 Mdot
.3175 .45125 Mdot
.49625 .49375 Mdot
.6675 .5175 Mdot
.565 .5275 Mdot
.57125 .49 Mdot
.355 .5225 Mdot
.42625 .4775 Mdot
.695 .45875 Mdot
.77 .46625 Mdot
.31125 .50625 Mdot
.1425 .5725 Mdot
.53875 .4275 Mdot
.52375 .41 Mdot
.16875 .365 Mdot
.54625 .38875 Mdot
.2225 .35375 Mdot
.6775 .315 Mdot
.43625 .2475 Mdot
.7925 .2475 Mdot
.4875 .29375 Mdot
.71875 .46 Mdot
.05 .5125 Mdot
.22875 .54875 Mdot
.69875 .54625 Mdot
.6875 .55375 Mdot
.81625 .57125 Mdot
.545 .5175 Mdot
.73125 .535 Mdot
.51125 .55125 Mdot
.6925 .56375 Mdot
.7375 .5825 Mdot
.22625 .57 Mdot
.27125 .52125 Mdot
.825 .47875 Mdot
.32 .5 Mdot
.5975 .455 Mdot
.3725 .49875 Mdot
.37375 .50625 Mdot
.79 .5225 Mdot
.26625 .47 Mdot
.87125 .48625 Mdot
.49625 .505 Mdot
.2625 .52625 Mdot
.36625 .47375 Mdot
.785 .45625 Mdot
.37875 .4475 Mdot
.04375 .40375 Mdot
.405 .48 Mdot
.2775 .51375 Mdot
.37 .505 Mdot
.85125 .51625 Mdot
.3575 .52375 Mdot
.595 .46125 Mdot
.6625 .44 Mdot
.1 .4525 Mdot
.58625 .4575 Mdot
.9175 .4475 Mdot
.41625 .51375 Mdot
.315 .52375 Mdot
.33125 .52875 Mdot
.4025 .505 Mdot
.865 .46875 Mdot
.2625 .53 Mdot
.66 .5875 Mdot
.27875 .6 Mdot
.605 .64625 Mdot
.26625 .62625 Mdot
.65 .51875 Mdot
.79625 .4225 Mdot
.2375 .38625 Mdot
.74125 .33375 Mdot
.34375 .33375 Mdot
.285 .35 Mdot
.58625 .40875 Mdot
.56375 .42375 Mdot
.46 .455 Mdot
.84375 .47125 Mdot
.08625 .49375 Mdot
.15875 .49375 Mdot
.3575 .49125 Mdot
.76 .495 Mdot
.0675 .5075 Mdot
.85 .50625 Mdot
.46375 .52625 Mdot
.4825 .5425 Mdot
.64125 .58375 Mdot
.78 .5625 Mdot
.55875 .55375 Mdot
.71375 .565 Mdot
.35875 .5675 Mdot
.38 .5775 Mdot
.4175 .6125 Mdot
.49875 .6275 Mdot
.405 .6375 Mdot
.70625 .63125 Mdot
.34 .63625 Mdot
.52125 .65 Mdot
.425 .63 Mdot
.825 .575 Mdot
.3725 .525 Mdot
.6 .5 Mdot
.60125 .50375 Mdot
.11375 .555 Mdot
.8025 .56 Mdot
.34 .52625 Mdot
.475 .56875 Mdot
.12125 .5825 Mdot
.735 .62875 Mdot
.8975 .61875 Mdot
.195 .58875 Mdot
.32875 .55625 Mdot
.475 .5275 Mdot
.6525 .45625 Mdot
.605 .4675 Mdot
.5925 .49125 Mdot
.2725 .465 Mdot
.525 .49625 Mdot
.63875 .53 Mdot
.7275 .55375 Mdot
.0075 .55875 Mdot
.2625 .585 Mdot
.16375 .515 Mdot
.4825 .5275 Mdot
.53 .56125 Mdot
.21375 .61875 Mdot
.485 .61875 Mdot
.30125 .5725 Mdot
.63125 .6325 Mdot
.47125 .695 Mdot
.7775 .69125 Mdot
.4775 .62375 Mdot
.75 .4125 Mdot
.195 .405 Mdot
.07 .40875 Mdot
.8425 .45125 Mdot
.58 .45125 Mdot
.92375 .4525 Mdot
.4375 .465 Mdot
.775 .44875 Mdot
.4925 .485 Mdot
.67375 .435 Mdot
.80375 .40625 Mdot
.2 .4225 Mdot
.245 .455 Mdot
.84625 .46 Mdot
.37875 .5025 Mdot
.50875 .54375 Mdot
.3975 .50125 Mdot
.4 .47375 Mdot
.7575 .47625 Mdot
.26625 .49 Mdot
.86 .47375 Mdot
.535 .51875 Mdot
.24375 .48875 Mdot
.3975 .4475 Mdot
.7125 .42625 Mdot
.485 .39625 Mdot
.3325 .3625 Mdot
.35875 .365 Mdot
.2725 .43375 Mdot
.93125 .475 Mdot
.3125 .51125 Mdot
.65625 .5375 Mdot
.61625 .57375 Mdot
.15 .53875 Mdot
.51125 .52625 Mdot
.9525 .5 Mdot
.4125 .5225 Mdot
.325 .54375 Mdot
.31125 .54375 Mdot
.4 .58375 Mdot
.9025 .6 Mdot
.2475 .55375 Mdot
.645 .50375 Mdot
.28 .51125 Mdot
.60875 .465 Mdot
.28375 .47 Mdot
.65375 .5325 Mdot
.74375 .57 Mdot
.29375 .5725 Mdot
.73125 .585 Mdot
.35625 .58125 Mdot
.1725 .57 Mdot
.7125 .56 Mdot
.5425 .5275 Mdot
.415 .51125 Mdot
.91125 .4975 Mdot
.01375 .51 Mdot
.13375 .49 Mdot
.3625 .47 Mdot
.745 .46625 Mdot
.0975 .43375 Mdot
.8025 .43375 Mdot
.48875 .4325 Mdot
.465 .4175 Mdot
.6525 .42625 Mdot
.80625 .42875 Mdot
.49 .46375 Mdot
.70625 .48 Mdot
.4375 .4625 Mdot
.34 .43 Mdot
.4425 .38625 Mdot
.435 .3425 Mdot
.455 .30625 Mdot
.73 .2925 Mdot
.305 .305 Mdot
.5425 .32125 Mdot
.375 .35375 Mdot
.86875 .405 Mdot
.41125 .43125 Mdot
.53875 .465 Mdot
.6025 .49 Mdot
.19625 .49625 Mdot
.7775 .49125 Mdot
.39125 .50125 Mdot
.4325 .44125 Mdot
.1575 .4425 Mdot
.67625 .4 Mdot
.9375 .40125 Mdot
.2 .4175 Mdot
.35125 .46625 Mdot
.42875 .48125 Mdot
.65125 .5225 Mdot
.67 .51625 Mdot
.5375 .4925 Mdot
.22 .48625 Mdot
.6225 .465 Mdot
.595 .4325 Mdot
.7 .4075 Mdot
.05875 .40375 Mdot
.23375 .40875 Mdot
.23 .485 Mdot
.40375 .5125 Mdot
.58125 .48875 Mdot
.23875 .45125 Mdot
.4525 .48125 Mdot
.3025 .52 Mdot
.60625 .46625 Mdot
.5 .475 Mdot
.78625 .50375 Mdot
.46875 .56375 Mdot
.7925 .685 Mdot
.91375 .66625 Mdot
.26625 .645 Mdot
.9625 .49 Mdot
.45125 .47375 Mdot
.98125 .46125 Mdot
.31 .5 Mdot
.8125 .52625 Mdot
.5 .46375 Mdot
.665 .4375 Mdot
.78375 .455 Mdot
.20375 .37125 Mdot
.2825 .355 Mdot
.74375 .3925 Mdot
.50125 .40875 Mdot
.45375 .38375 Mdot
.47 .43125 Mdot
.3125 .4575 Mdot
.80625 .40875 Mdot
.215 .38 Mdot
.87875 .4025 Mdot
.53 .32625 Mdot
.3075 .3225 Mdot
.36375 .45875 Mdot
.6625 .5425 Mdot
.53875 .57375 Mdot
.27 .63375 Mdot
.4775 .58 Mdot
.165 .5125 Mdot
.975 .4275 Mdot
.27625 .41 Mdot
.725 .4275 Mdot
.55 .425 Mdot
.1575 .47625 Mdot
.51625 .49875 Mdot
.96125 .53 Mdot
.455 .53375 Mdot
.3825 .49375 Mdot
.2375 .5 Mdot
.40875 .4725 Mdot
.91375 .4875 Mdot
.235 .52375 Mdot
.655 .54625 Mdot
.3 .56375 Mdot
.55875 .56875 Mdot
.29375 .55125 Mdot
.70875 .54125 Mdot
.65 .53625 Mdot
.36125 .47625 Mdot
.73125 .475 Mdot
.3575 .46375 Mdot
.11125 .41625 Mdot
.79125 .405 Mdot
.515 .44375 Mdot
.41375 .445 Mdot
.91625 .4175 Mdot
.1075 .47125 Mdot
.37375 .50375 Mdot
.75125 .525 Mdot
.0925 .56 Mdot
.775 .5475 Mdot
.5275 .52875 Mdot
.42 .53625 Mdot
.62375 .4525 Mdot
.8675 .43375 Mdot
.39125 .3825 Mdot
.74875 .33375 Mdot
.4875 .355 Mdot
.295 .40125 Mdot
.4775 .46 Mdot
.33125 .515 Mdot
.55375 .57 Mdot
.7075 .60125 Mdot
.29875 .6025 Mdot
.56875 .5825 Mdot
.34375 .56875 Mdot
.90875 .54 Mdot
.37875 .5425 Mdot
.52625 .52 Mdot
.58875 .50375 Mdot
.21125 .49875 Mdot
.77625 .5075 Mdot
.49 .50625 Mdot
.31625 .50625 Mdot
.26625 .5325 Mdot
.60875 .5625 Mdot
.925 .5825 Mdot
.22125 .58375 Mdot
.34 .55125 Mdot
.4575 .51625 Mdot
.64625 .4925 Mdot
.6775 .4825 Mdot
.51125 .49125 Mdot
.20125 .5125 Mdot
.6875 .54625 Mdot
.52625 .5825 Mdot
.7275 .58625 Mdot
.0875 .57125 Mdot
.215 .56625 Mdot
.9825 .54125 Mdot
.39 .49125 Mdot
.03875 .5275 Mdot
.335 .52125 Mdot
.6025 .535 Mdot
.26875 .535 Mdot
.41875 .47375 Mdot
.36875 .4775 Mdot
.57125 .47875 Mdot
.525 .44875 Mdot
.78 .40625 Mdot
.44125 .39625 Mdot
.8325 .3925 Mdot
.82375 .4275 Mdot
.31625 .4325 Mdot
.045 .45 Mdot
.9 .52875 Mdot
.45375 .52375 Mdot
.26 .49625 Mdot
.80125 .4925 Mdot
.53 .5225 Mdot
.645 .58125 Mdot
.75625 .58375 Mdot
.1825 .61375 Mdot
.3975 .59875 Mdot
.60625 .56 Mdot
.62125 .52375 Mdot
.38125 .53125 Mdot
.52 .52875 Mdot
.295 .53625 Mdot
.77625 .62 Mdot
.235 .645 Mdot
.85375 .6275 Mdot
.57625 .67875 Mdot
.3 .705 Mdot
.36375 .59 Mdot
.58375 .53375 Mdot
.6325 .54875 Mdot
.18625 .49875 Mdot
.5775 .515 Mdot
.07125 .47 Mdot
.31 .41875 Mdot
.6975 .36625 Mdot
.525 .40375 Mdot
.18375 .4625 Mdot
.525 .48625 Mdot
.9525 .4925 Mdot
.48375 .37875 Mdot
.40125 .38375 Mdot
.25875 .38875 Mdot
.4125 .40375 Mdot
.86875 .4275 Mdot
.23125 .44375 Mdot
.6625 .445 Mdot
.30125 .425 Mdot
.53625 .455 Mdot
.37125 .4775 Mdot
.64375 .47875 Mdot
.66625 .5025 Mdot
.34625 .6175 Mdot
.74125 .625 Mdot
.38875 .6075 Mdot
.05375 .6525 Mdot
.85 .64875 Mdot
.4825 .57125 Mdot
.4175 .54125 Mdot
.895 .58125 Mdot
.02625 .545 Mdot
.0975 .5 Mdot
.37125 .4825 Mdot
.765 .47375 Mdot
.06625 .48625 Mdot
.76375 .5075 Mdot
.58 .54 Mdot
.37625 .5725 Mdot
.68 .65875 Mdot
.8675 .67125 Mdot
.285 .69125 Mdot
.8125 .715 Mdot
.53375 .70375 Mdot
.25 .65 Mdot
.5025 .6175 Mdot
.2575 .58625 Mdot
.6475 .55875 Mdot
.64125 .5475 Mdot
.33875 .545 Mdot
.57375 .52375 Mdot
.3075 .53875 Mdot
.945 .52875 Mdot
.35625 .50875 Mdot
.5675 .54125 Mdot
.47625 .5575 Mdot
.10375 .5325 Mdot
.8925 .55125 Mdot
.29375 .565 Mdot
.69 .5325 Mdot
.66875 .5325 Mdot
.15875 .53375 Mdot
.39 .48375 Mdot
.48125 .43875 Mdot
.1825 .42625 Mdot
.35625 .45625 Mdot
.4525 .535 Mdot
.63 .58625 Mdot
.69375 .57 Mdot
.50875 .57875 Mdot
.205 .5275 Mdot
.7225 .47875 Mdot
.45 .455 Mdot
.765 .475 Mdot
.11625 .475 Mdot
.18875 .5225 Mdot
.9175 .4975 Mdot
.57375 .46375 Mdot
.81875 .39875 Mdot
.185 .38375 Mdot
.3075 .335 Mdot
.545 .3625 Mdot
.3225 .38875 Mdot
.40125 .41375 Mdot
.95875 .435 Mdot
.4125 .4375 Mdot
.52125 .45875 Mdot
.5625 .4375 Mdot
.78875 .45 Mdot
.43375 .44875 Mdot
.8275 .46875 Mdot
.75 .4975 Mdot
.3075 .53125 Mdot
.19125 .56625 Mdot
.77 .48375 Mdot
.43875 .515 Mdot
.175 .49625 Mdot
.8075 .5675 Mdot
.59125 .56625 Mdot
.58625 .56375 Mdot
.6525 .59 Mdot
.28125 .57 Mdot
.48 .495 Mdot
.45875 .47875 Mdot
.725 .465 Mdot
.3175 .42375 Mdot
.61625 .4275 Mdot
.18875 .46125 Mdot
.845 .44875 Mdot
.23625 .435 Mdot
.71375 .4725 Mdot
.705 .42875 Mdot
.35375 .43625 Mdot
.275 .47375 Mdot
.5875 .48375 Mdot
.67625 .41625 Mdot
.10875 .4125 Mdot
.66875 .46625 Mdot
.3725 .72875 Mdot
.67 .7375 Mdot
.495 .65875 Mdot
.25 .54125 Mdot
.45 .46 Mdot
.9925 .4375 Mdot
.5275 .59 Mdot
.39875 .665 Mdot
.22625 .6925 Mdot
.43625 .71375 Mdot
.865 .67875 Mdot
.195 .62625 Mdot
.7225 .57625 Mdot
.26125 .525 Mdot
.54375 .49 Mdot
.36625 .4675 Mdot
.63375 .44875 Mdot
.7075 .44 Mdot
.3325 .39 Mdot
.715 .415 Mdot
.385 .4525 Mdot
.09 .45125 Mdot
.865 .44875 Mdot
.4275 .515 Mdot
.45375 .51875 Mdot
.89375 .49625 Mdot
.01125 .50125 Mdot
.06125 .5025 Mdot
.4525 .5 Mdot
.72 .48875 Mdot
.04 .48875 Mdot
.77625 .50125 Mdot
.58125 .48625 Mdot
.38625 .49375 Mdot
.66125 .47625 Mdot
.865 .5175 Mdot
.24875 .525 Mdot
.8425 .54625 Mdot
.57375 .57125 Mdot
.22 .6075 Mdot
.5125 .58125 Mdot
.22375 .545 Mdot
.73 .50375 Mdot
.5525 .46 Mdot
.3725 .455 Mdot
.60125 .48 Mdot
.2825 .4575 Mdot
.94375 .48875 Mdot
.33125 .49625 Mdot
.59875 .465 Mdot
.41625 .43625 Mdot
.23 .45 Mdot
.76 .43 Mdot
.385 .46125 Mdot
.55375 .46375 Mdot
.88375 .47 Mdot
.5325 .565 Mdot
.38875 .5575 Mdot
.16625 .5175 Mdot
.3525 .47625 Mdot
.45125 .415 Mdot
.64 .395 Mdot
.6925 .47 Mdot
.51 .475 Mdot
.2025 .5075 Mdot
.78375 .5425 Mdot
.3175 .5675 Mdot
.83625 .56875 Mdot
.17875 .54375 Mdot
.1125 .4875 Mdot
.8575 .535 Mdot
.75625 .5825 Mdot
.61 .59625 Mdot
.3075 .63625 Mdot
.30875 .6725 Mdot
.4475 .62375 Mdot
.43375 .58875 Mdot
.38125 .57375 Mdot
.90375 .5475 Mdot
.44625 .54875 Mdot
.47375 .55875 Mdot
.59375 .595 Mdot
.815 .6025 Mdot
.385 .5775 Mdot
.85375 .47125 Mdot
.675 .4475 Mdot
.295 .34375 Mdot
.385 .34375 Mdot
.52125 .40875 Mdot
.615 .405 Mdot
.91625 .3925 Mdot
.03625 .4575 Mdot
.12375 .415 Mdot
.83625 .34125 Mdot
.60125 .375 Mdot
.6225 .36125 Mdot
.51625 .36625 Mdot
.35875 .445 Mdot
.55625 .5475 Mdot
.33625 .58625 Mdot
.78125 .60375 Mdot
.27375 .64 Mdot
.74 .60125 Mdot
.0625 .55125 Mdot
.8825 .5125 Mdot
.3075 .5725 Mdot
.5925 .53125 Mdot
.745 .58125 Mdot
.38875 .54875 Mdot
.29625 .52375 Mdot
.5375 .47875 Mdot
.615 .55125 Mdot
.0875 .5675 Mdot
.01 .61625 Mdot
.73875 .565 Mdot
.97625 .4075 Mdot
.46375 .385 Mdot
.62375 .4025 Mdot
.44625 .465 Mdot
.31 .5125 Mdot
.47625 .56125 Mdot
.985 .575 Mdot
.5375 .435 Mdot
.40125 .38625 Mdot
.24875 .34875 Mdot
.42375 .305 Mdot
.8325 .33 Mdot
.2 .3475 Mdot
.685 .35375 Mdot
.33375 .4125 Mdot
.50875 .425 Mdot
.3875 .47 Mdot
.62875 .47 Mdot
.6925 .4425 Mdot
.3425 .4025 Mdot
.7325 .3975 Mdot
.38625 .3725 Mdot
.0425 .38625 Mdot
.9075 .42625 Mdot
.4175 .40125 Mdot
.4425 .41875 Mdot
.91875 .41625 Mdot
.0075 .43125 Mdot
.03625 .45625 Mdot
.54375 .45 Mdot
.68375 .44375 Mdot
.01875 .4225 Mdot
.78 .4125 Mdot
.5775 .415 Mdot
.4025 .36625 Mdot
.66875 .405 Mdot
.83625 .36125 Mdot
.22875 .3775 Mdot
.88375 .34125 Mdot
.56375 .3 Mdot
.22 .3175 Mdot
.495 .38625 Mdot
.19375 .43875 Mdot
.83 .5025 Mdot
.455 .56 Mdot
.41375 .545 Mdot
.62875 .50875 Mdot
.25625 .4875 Mdot
.90125 .4675 Mdot
.3575 .43125 Mdot
.6375 .42625 Mdot
.3325 .42625 Mdot
.37625 .44875 Mdot
.56875 .4225 Mdot
.55 .42125 Mdot
.39875 .4625 Mdot
.67125 .49625 Mdot
.34375 .56375 Mdot
.9975 .60125 Mdot
.2 .59375 Mdot
.31375 .6025 Mdot
.5025 .55 Mdot
.64625 .46125 Mdot
.6825 .38875 Mdot
.47875 .37375 Mdot
.22375 .37875 Mdot
.8375 .4 Mdot
.185 .41 Mdot
.92125 .39 Mdot
.215 .425 Mdot
.09875 .4675 Mdot
.75875 .4675 Mdot
.92875 .46 Mdot
.43 .5125 Mdot
.3925 .4975 Mdot
.29625 .49375 Mdot
.44 .5175 Mdot
.45125 .565 Mdot
.4075 .56 Mdot
.87875 .5275 Mdot
.475 .51125 Mdot
.4525 .48125 Mdot
.60375 .44625 Mdot
.83375 .4575 Mdot
.34 .48 Mdot
.82125 .565 Mdot
.66 .6175 Mdot
.22125 .72 Mdot
.62125 .7175 Mdot
.2675 .69125 Mdot
.78125 .69375 Mdot
.73625 .68125 Mdot
.17375 .61 Mdot
.10625 .62875 Mdot
.8175 .6575 Mdot
.62625 .605 Mdot
.62875 .59 Mdot
.44125 .54375 Mdot
.41375 .50625 Mdot
.62375 .4625 Mdot
.255 .46375 Mdot
.7175 .49875 Mdot
.35875 .48 Mdot
.7975 .4775 Mdot
.9125 .50625 Mdot
.40125 .39875 Mdot
.44375 .44125 Mdot
.82 .425 Mdot
.39625 .415 Mdot
.27375 .45625 Mdot
.5475 .54125 Mdot
.58375 .50375 Mdot
.19875 .48875 Mdot
.03 .44 Mdot
.74625 .43 Mdot
.96125 .505 Mdot
.5475 .53125 Mdot
.505 .56625 Mdot
.4375 .55375 Mdot
.3925 .52 Mdot
.44625 .52125 Mdot
.99125 .5075 Mdot
.53 .6975 Mdot
.4225 .6275 Mdot
.255 .61125 Mdot
.38875 .585 Mdot
.76125 .5225 Mdot
.30625 .51125 Mdot
.59875 .5875 Mdot
.4325 .565 Mdot
.46875 .54875 Mdot
.40125 .50375 Mdot
.58125 .5425 Mdot
.74 .53375 Mdot
.34 .5525 Mdot
.69875 .55875 Mdot
.37 .5875 Mdot
.14 .54625 Mdot
.8975 .5175 Mdot
.34 .58875 Mdot
.46 .60875 Mdot
.91375 .6225 Mdot
.05625 .62875 Mdot
.04375 .5925 Mdot
.57875 .57125 Mdot
.64125 .58375 Mdot
.045 .5625 Mdot
.75 .52375 Mdot
.58375 .5175 Mdot
.405 .56125 Mdot
.6625 .52 Mdot
.775 .515 Mdot
.2325 .46125 Mdot
.92375 .4825 Mdot
.56125 .5 Mdot
.235 .465 Mdot
.44125 .43 Mdot
.215 .43 Mdot
.8525 .405 Mdot
.42125 .41875 Mdot
.4325 .48125 Mdot
.64875 .5425 Mdot
.2775 .58125 Mdot
.80625 .58875 Mdot
.3725 .62875 Mdot
.73375 .59 Mdot
.19125 .5825 Mdot
.52375 .5675 Mdot
.45625 .59625 Mdot
.63875 .555 Mdot
.2825 .53625 Mdot
.75 .405 Mdot
.36 .36125 Mdot
.88625 .35 Mdot
.27375 .37625 Mdot
.23625 .4 Mdot
.59625 .47375 Mdot
.6175 .555 Mdot
.65375 .58875 Mdot
.47 .62375 Mdot
.28875 .60875 Mdot
.815 .56125 Mdot
.13 .53875 Mdot
.97625 .54625 Mdot
.23625 .53 Mdot
.07875 .50125 Mdot
.70375 .505 Mdot
.39125 .42 Mdot
.38375 .35875 Mdot
.28 .3625 Mdot
.4725 .3475 Mdot
.42625 .32 Mdot
.4525 .3825 Mdot
.8975 .505 Mdot
.49625 .55375 Mdot
.455 .5925 Mdot
.60875 .64625 Mdot
.8525 .63125 Mdot
.2625 .6175 Mdot
.08125 .59625 Mdot
.74125 .5575 Mdot
.69875 .495 Mdot
.19 .4425 Mdot
.76 .4925 Mdot
.035 .51875 Mdot
.56 .50625 Mdot
.22 .53125 Mdot
.145 .46375 Mdot
.79125 .39875 Mdot
.605 .41375 Mdot
.67875 .42375 Mdot
.40875 .4575 Mdot
.39875 .4875 Mdot
.73875 .5175 Mdot
.18125 .50125 Mdot
.655 .48625 Mdot
.435 .495 Mdot
.74375 .47625 Mdot
.00375 .45625 Mdot
.82125 .50375 Mdot
.5575 .56125 Mdot
.33 .51125 Mdot
.81 .5325 Mdot
.41875 .57125 Mdot
.31875 .50625 Mdot
.47375 .47375 Mdot
.5875 .5175 Mdot
.33875 .54 Mdot
.91125 .49 Mdot
.09 .54125 Mdot
.6975 .545 Mdot
.00125 .52125 Mdot
.94125 .475 Mdot
.6075 .49 Mdot
.40875 .4025 Mdot
.51875 .40125 Mdot
.405 .46375 Mdot
.42375 .47375 Mdot
.9875 .51125 Mdot
.53625 .23625 Mdot
.9825 .30875 Mdot
.40875 .38375 Mdot
.305 .41375 Mdot
.3775 .4925 Mdot
.68875 .52 Mdot
.42125 .52 Mdot
.46875 .44125 Mdot
.55625 .47125 Mdot
.4425 .47875 Mdot
.40875 .5225 Mdot
.51375 .50125 Mdot
.7825 .565 Mdot
.38875 .585 Mdot
.58875 .5475 Mdot
.3825 .53625 Mdot
.20125 .57 Mdot
.93 .56125 Mdot
.2825 .49 Mdot
.5 .505 Mdot
.89375 .4925 Mdot
.03375 .475 Mdot
.09875 .49875 Mdot
.5875 .51875 Mdot
.56 .53125 Mdot
.105 .57 Mdot
.72 .6 Mdot
.5875 .5825 Mdot
.425 .53375 Mdot
.72875 .5225 Mdot
.66125 .5875 Mdot
.275 .645 Mdot
.92 .64375 Mdot
.5875 .6625 Mdot
.26375 .67375 Mdot
.33875 .64875 Mdot
.2625 .62875 Mdot
.89125 .61625 Mdot
.4025 .5775 Mdot
.43125 .53 Mdot
.675 .45 Mdot
.255 .405 Mdot
.7175 .3775 Mdot
.42625 .36 Mdot
.81625 .39 Mdot
.05 .39375 Mdot
.70375 .4 Mdot
.325 .39375 Mdot
.71875 .4025 Mdot
.1325 .40625 Mdot
.7775 .5325 Mdot
.40875 .55125 Mdot
.7875 .5225 Mdot
.37125 .50875 Mdot
.1675 .4525 Mdot
.605 .43375 Mdot
.64 .4025 Mdot
.63 .40625 Mdot
.45625 .3675 Mdot
.345 .36625 Mdot
.775 .37375 Mdot
.1175 .35625 Mdot
.995 .36125 Mdot
.25625 .3925 Mdot
.08375 .41375 Mdot
.71125 .43 Mdot
.95375 .4825 Mdot
.41125 .53125 Mdot
.375 .61625 Mdot
.31125 .63625 Mdot
.47875 .6475 Mdot
.4 .6525 Mdot
.5025 .6 Mdot
.8625 .43875 Mdot
.555 .38875 Mdot
.435 .3575 Mdot
.63625 .32875 Mdot
.84875 .35625 Mdot
.185 .37125 Mdot
.1975 .41875 Mdot
.65125 .47875 Mdot
.73125 .5175 Mdot
.16375 .54875 Mdot
.86625 .50375 Mdot
.4625 .42 Mdot
.3125 .39375 Mdot
.14 .4525 Mdot
.74875 .4775 Mdot
.6175 .50125 Mdot
.6875 .5175 Mdot
.385 .50875 Mdot
.4125 .50875 Mdot
.7875 .4975 Mdot
.2025 .51125 Mdot
.54625 .48375 Mdot
.5175 .495 Mdot
.69875 .49875 Mdot
.0325 .54 Mdot
.77 .53 Mdot
.64625 .55125 Mdot
.2825 .575 Mdot
.74125 .535 Mdot
.52125 .49875 Mdot
.28375 .53125 Mdot
.46375 .5225 Mdot
.56 .45625 Mdot
.4625 .4675 Mdot
.77125 .51875 Mdot
.17 .46875 Mdot
.60625 .465 Mdot
.125 .49625 Mdot
.85875 .4725 Mdot
.64875 .405 Mdot
.32125 .44875 Mdot
.60625 .4225 Mdot
.38875 .355 Mdot
.4425 .3575 Mdot
.945 .34 Mdot
.55125 .6775 Mdot
.955 .61 Mdot
.425 .535 Mdot
.305 .455 Mdot
.38 .39125 Mdot
.58625 .3775 Mdot
.575 .3825 Mdot
.36 .4225 Mdot
.6425 .4675 Mdot
.42875 .48125 Mdot
.385 .47625 Mdot
.5075 .48875 Mdot
.785 .43 Mdot
.48 .38 Mdot
.465 .41625 Mdot
.36625 .4225 Mdot
.22625 .41 Mdot
.22625 .45 Mdot
.48125 .3775 Mdot
.8975 .3575 Mdot
.00625 .3775 Mdot
.12125 .4075 Mdot
.60375 .45125 Mdot
.50125 .46125 Mdot
.14875 .44375 Mdot
.71125 .4325 Mdot
.5675 .4575 Mdot
.41875 .48875 Mdot
.735 .4825 Mdot
.60125 .425 Mdot
.32125 .38125 Mdot
.925 .3725 Mdot
.5575 .3575 Mdot
.32625 .36875 Mdot
.22125 .3875 Mdot
.2825 .40875 Mdot
.92375 .42 Mdot
.49875 .435 Mdot
.34875 .4475 Mdot
.70875 .51375 Mdot
.26375 .55375 Mdot
.60625 .58625 Mdot
.50875 .6 Mdot
.83875 .59 Mdot
.795 .62625 Mdot
.2475 .6525 Mdot
.76125 .63 Mdot
.03875 .63875 Mdot
.7925 .47625 Mdot
.51375 .49625 Mdot
.5925 .53875 Mdot
.53875 .57 Mdot
.075 .6225 Mdot
.6525 .65875 Mdot
.64375 .6675 Mdot
.62375 .6325 Mdot
.40125 .5875 Mdot
.43 .55625 Mdot
.7025 .5675 Mdot
.1175 .6 Mdot
.285 .60625 Mdot
.06 .58 Mdot
.75375 .54125 Mdot
.82875 .48625 Mdot
.5025 .47125 Mdot
.35375 .445 Mdot
.32625 .4525 Mdot
.4675 .46375 Mdot
.39125 .48125 Mdot
.575 .47125 Mdot
.8175 .47625 Mdot
.635 .475 Mdot
.39 .525 Mdot
.68375 .515 Mdot
.8625 .50875 Mdot
.08625 .4725 Mdot
.275 .4325 Mdot
.57625 .4025 Mdot
.78375 .36875 Mdot
.16875 .335 Mdot
.89 .3625 Mdot
.3875 .48 Mdot
.3375 .54 Mdot
.16625 .54 Mdot
.68625 .5475 Mdot
.65125 .53875 Mdot
.67625 .515 Mdot
.39875 .5225 Mdot
.39375 .51375 Mdot
.86125 .5275 Mdot
.12125 .55875 Mdot
.5425 .55375 Mdot
.59625 .57125 Mdot
.59375 .60375 Mdot
.1475 .555 Mdot
.66 .54875 Mdot
.6925 .555 Mdot
.33625 .52375 Mdot
.6875 .5475 Mdot
.51875 .575 Mdot
.3 .5275 Mdot
.45 .5275 Mdot
.54625 .5225 Mdot
.53375 .47625 Mdot
.6275 .4575 Mdot
.33375 .4675 Mdot
.45875 .49 Mdot
.28625 .46 Mdot
.765 .48 Mdot
.655 .54125 Mdot
.255 .55875 Mdot
.68375 .58875 Mdot
.38625 .6725 Mdot
.48125 .715 Mdot
.89125 .705 Mdot
.51125 .42375 Mdot
.96625 .45625 Mdot
.4225 .50625 Mdot
.32125 .56625 Mdot
.36 .6175 Mdot
.53125 .66875 Mdot
.67125 .6975 Mdot
.25125 .69625 Mdot
.77125 .625 Mdot
.36625 .61625 Mdot
.41625 .59375 Mdot
.45125 .61375 Mdot
.78625 .63875 Mdot
.56 .6625 Mdot
.41375 .5975 Mdot
.34375 .54375 Mdot
.21 .47375 Mdot
.2175 .4925 Mdot
.44875 .54625 Mdot
.86875 .59125 Mdot
.04 .60875 Mdot
.155 .53125 Mdot
.6025 .5 Mdot
.46375 .4925 Mdot
.1875 .50125 Mdot
.65625 .52875 Mdot
.5925 .5425 Mdot
.3875 .53875 Mdot
.75875 .52375 Mdot
.545 .53125 Mdot
.33125 .565 Mdot
.97125 .585 Mdot
.49625 .58875 Mdot
.37875 .54375 Mdot
.13625 .5125 Mdot
.3525 .4775 Mdot
.8625 .4475 Mdot
.595 .45125 Mdot
.3025 .46375 Mdot
.7175 .44125 Mdot
.30625 .405 Mdot
.45125 .3825 Mdot
.6375 .34 Mdot
.85 .385 Mdot
.87625 .45 Mdot
.18375 .45 Mdot
.79125 .53 Mdot
.7875 .49875 Mdot
.59375 .44 Mdot
.4075 .43 Mdot
.7175 .41625 Mdot
.685 .42 Mdot
.6175 .4625 Mdot
.6375 .5025 Mdot
.36875 .56125 Mdot
.5125 .615 Mdot
.6125 .60875 Mdot
.16375 .57125 Mdot
.265 .57 Mdot
.0925 .53625 Mdot
.79 .53 Mdot
.695 .5275 Mdot
.57125 .515 Mdot
.36625 .4675 Mdot
.38125 .45375 Mdot
.41625 .46125 Mdot
.35625 .46 Mdot
.63875 .5025 Mdot
.8025 .5825 Mdot
.7225 .62 Mdot
.32625 .5725 Mdot
.725 .5875 Mdot
.875 .56875 Mdot
.38375 .585 Mdot
.44875 .55375 Mdot
.87875 .55875 Mdot
.1475 .5775 Mdot
.91625 .525 Mdot
.44125 .53625 Mdot
.34125 .48625 Mdot
.18875 .5125 Mdot
.6 .53125 Mdot
.69875 .51 Mdot
.6575 .4925 Mdot
.4175 .44 Mdot
.39 .415 Mdot
.895 .405 Mdot
.07625 .37125 Mdot
.52875 .3775 Mdot
.65125 .39375 Mdot
.49 .4 Mdot
.325 .3775 Mdot
.5525 .365 Mdot
.67125 .35625 Mdot
.36875 .4 Mdot
.6675 .38 Mdot
.575 .4 Mdot
.21125 .4525 Mdot
.54125 .43875 Mdot
.515 .47625 Mdot
.5125 .51875 Mdot
.57 .5025 Mdot
.4825 .5425 Mdot
.32125 .5675 Mdot
.38625 .5925 Mdot
.70625 .61375 Mdot
.64625 .6275 Mdot
.20875 .5725 Mdot
.8175 .545 Mdot
.325 .45125 Mdot
.475 .3775 Mdot
.8575 .4025 Mdot
.065 .5175 Mdot
.45875 .49875 Mdot
.37625 .4725 Mdot
.3375 .47125 Mdot
.3875 .42625 Mdot
.49875 .4125 Mdot
.6625 .385 Mdot
.26375 .34875 Mdot
.8175 .37125 Mdot
.34 .405 Mdot
.3975 .42875 Mdot
.445 .41875 Mdot
.785 .45625 Mdot
.6075 .52375 Mdot
.38625 .5875 Mdot
.28625 .65 Mdot
.265 .76 Mdot
.225 .65875 Mdot
.43625 .62625 Mdot
.825 .5775 Mdot
.03125 .48875 Mdot
.17125 .50125 Mdot
.58 .4925 Mdot
.44 .47 Mdot
.2225 .4775 Mdot
.6125 .46375 Mdot
.62625 .45375 Mdot
.37 .4575 Mdot
.76875 .5125 Mdot
.5525 .53375 Mdot
.275 .52125 Mdot
.4725 .49 Mdot
.395 .49125 Mdot
.0625 .43625 Mdot
.415 .4425 Mdot
.81 .45625 Mdot
.70125 .4275 Mdot
.24625 .41875 Mdot
.71375 .475 Mdot
.34 .5225 Mdot
.35625 .5625 Mdot
.72125 .65 Mdot
.8375 .63625 Mdot
.935 .52875 Mdot
.185 .49875 Mdot
.71375 .43125 Mdot
.00375 .465 Mdot
.78875 .585 Mdot
.6525 .62625 Mdot
.2825 .605 Mdot
.855 .59125 Mdot
.70375 .5325 Mdot
.60625 .47375 Mdot
.61625 .49875 Mdot
.35875 .51 Mdot
.61375 .51 Mdot
.45125 .525 Mdot
.265 .57375 Mdot
.24625 .515 Mdot
.06875 .5425 Mdot
.84375 .54875 Mdot
.57 .54625 Mdot
.635 .5925 Mdot
.39625 .59625 Mdot
.41125 .575 Mdot
.34875 .55 Mdot
.405 .51875 Mdot
.65125 .45 Mdot
.79 .40125 Mdot
.75875 .385 Mdot
.3125 .4175 Mdot
.7375 .4425 Mdot
.885 .4625 Mdot
.465 .4875 Mdot
.3425 .52625 Mdot
.95 .5225 Mdot
.14375 .5225 Mdot
.9175 .545 Mdot
.4975 .55875 Mdot
.35875 .5925 Mdot
.17125 .605 Mdot
.525 .59375 Mdot
.7475 .61 Mdot
.68 .63625 Mdot
.39875 .69875 Mdot
.37625 .6525 Mdot
.9175 .6125 Mdot
.04375 .59125 Mdot
.5575 .57 Mdot
.6525 .47875 Mdot
.405 .48625 Mdot
.48625 .48875 Mdot
.46125 .44875 Mdot
.5975 .4525 Mdot
.48 .45625 Mdot
.67125 .48125 Mdot
.545 .5 Mdot
.22625 .5675 Mdot
.49875 .56625 Mdot
.5625 .505 Mdot
.44625 .46125 Mdot
.5775 .46625 Mdot
.59 .395 Mdot
.18625 .3775 Mdot
.55625 .42375 Mdot
.55375 .4575 Mdot
.66 .4425 Mdot
.22875 .51 Mdot
.8675 .53125 Mdot
.285 .57625 Mdot
.48 .6 Mdot
.8125 .56375 Mdot
.12125 .425 Mdot
.4175 .49375 Mdot
.30625 .46625 Mdot
.3775 .515 Mdot
.41 .51625 Mdot
.5125 .47125 Mdot
.5775 .48125 Mdot
.33 .5575 Mdot
.8 .5225 Mdot
.3425 .46625 Mdot
.37125 .41375 Mdot
.495 .34375 Mdot
.73875 .2725 Mdot
.63375 .21125 Mdot
.40625 .22625 Mdot
.2275 .225 Mdot
.25875 .215 Mdot
.275 .30125 Mdot
.4025 .32625 Mdot
.785 .38625 Mdot
.0425 .4775 Mdot
.19125 .5725 Mdot
.575 .5975 Mdot
.445 .6175 Mdot
.2275 .59 Mdot
.57125 .5575 Mdot
.65125 .52 Mdot
.37 .4925 Mdot
.81 .47 Mdot
.5575 .45875 Mdot
.20625 .44375 Mdot
.4025 .42875 Mdot
.39625 .51625 Mdot
.03125 .6225 Mdot
.44625 .6425 Mdot
.80625 .6775 Mdot
.76 .71125 Mdot
.20875 .67875 Mdot
.68875 .59625 Mdot
.375 .575 Mdot
.2875 .5375 Mdot
.79 .50625 Mdot
.82125 .44625 Mdot
.91875 .4825 Mdot
.19875 .5125 Mdot
.705 .48375 Mdot
.77 .35375 Mdot
.72125 .3525 Mdot
.17875 .37375 Mdot
.94125 .37625 Mdot
.75875 .36375 Mdot
.58 .3775 Mdot
.615 .31375 Mdot
.34375 .29 Mdot
.71 .3 Mdot
.30625 .32625 Mdot
.33125 .305 Mdot
.23625 .37375 Mdot
.08 .3875 Mdot
.8825 .3825 Mdot
.43625 .415 Mdot
.67375 .40875 Mdot
.475 .4575 Mdot
.4225 .51375 Mdot
.2475 .55625 Mdot
.5025 .6 Mdot
.605 .6425 Mdot
.74 .66 Mdot
.8225 .6575 Mdot
.28125 .6325 Mdot
.7675 .6025 Mdot
.845 .5675 Mdot
.51375 .51125 Mdot
.25125 .48125 Mdot
.095 .48875 Mdot
.945 .49625 Mdot
.9375 .47 Mdot
.59125 .45375 Mdot
.40875 .40625 Mdot
.095 .3725 Mdot
.49125 .35375 Mdot
.805 .34875 Mdot
.66875 .355 Mdot
.4125 .34 Mdot
.355 .4225 Mdot
.86125 .47875 Mdot
.12375 .475 Mdot
.5525 .4725 Mdot
.60375 .535 Mdot
.41875 .53375 Mdot
.54875 .585 Mdot
.4375 .655 Mdot
.51625 .64375 Mdot
.5175 .62125 Mdot
.73 .54875 Mdot
.53125 .50625 Mdot
.2225 .46375 Mdot
.48625 .49875 Mdot
.61125 .58125 Mdot
.29875 .67125 Mdot
.69125 .675 Mdot
.6075 .69875 Mdot
.08875 .68 Mdot
.70875 .56875 Mdot
.41 .4675 Mdot
.7325 .46 Mdot
.2275 .40875 Mdot
.835 .39125 Mdot
.28125 .39625 Mdot
.4925 .4075 Mdot
.79125 .375 Mdot
.1775 .55375 Mdot
.3425 .51375 Mdot
.215 .56125 Mdot
.39125 .56375 Mdot
.45 .57125 Mdot
.5125 .63 Mdot
.485 .655 Mdot
.4475 .61 Mdot
.7275 .6025 Mdot
.37875 .64875 Mdot
.36625 .685 Mdot
.5025 .71375 Mdot
.7275 .75125 Mdot
.59875 .745 Mdot
.49875 .69375 Mdot
.155 .65125 Mdot
.2625 .62625 Mdot
.2975 .64 Mdot
.37125 .6375 Mdot
.76 .60875 Mdot
.10125 .57875 Mdot
.1625 .45125 Mdot
.59125 .4125 Mdot
.44375 .385 Mdot
.255 .395 Mdot
.51625 .45 Mdot
.6825 .49875 Mdot
.34875 .5275 Mdot
.75875 .50375 Mdot
.605 .48875 Mdot
.15625 .515 Mdot
.3325 .55 Mdot
.42125 .50125 Mdot
.52 .47625 Mdot
.725 .465 Mdot
.85625 .44875 Mdot
.15625 .46 Mdot
.62125 .47625 Mdot
.5025 .46375 Mdot
.17875 .43875 Mdot
.855 .4175 Mdot
.80625 .4675 Mdot
.79875 .4275 Mdot
.27 .45625 Mdot
.69875 .52625 Mdot
.015 .56 Mdot
.76 .68875 Mdot
.745 .6775 Mdot
.1375 .6575 Mdot
.95875 .66625 Mdot
.84125 .69625 Mdot
.5375 .695 Mdot
.60375 .74125 Mdot
.325 .7025 Mdot
.825 .6225 Mdot
.20875 .57375 Mdot
.37125 .5725 Mdot
.2175 .535 Mdot
.085 .5525 Mdot
.8675 .56125 Mdot
.4025 .53625 Mdot
.68375 .485 Mdot
.53 .4475 Mdot
.44 .415 Mdot
.10625 .38375 Mdot
.68 .3475 Mdot
.49125 .36875 Mdot
.7275 .41625 Mdot
.835 .41375 Mdot
.27375 .38875 Mdot
.7875 .3675 Mdot
.81375 .40375 Mdot
.5125 .45875 Mdot
.20125 .50375 Mdot
.07875 .5 Mdot
.89875 .49625 Mdot
.85625 .50375 Mdot
.6225 .53125 Mdot
.47625 .555 Mdot
.53375 .59875 Mdot
.8075 .63 Mdot
.67375 .6575 Mdot
.435 .6575 Mdot
.35 .6525 Mdot
.7875 .62625 Mdot
.17875 .6275 Mdot
.545 .6325 Mdot
.59125 .61375 Mdot
.43125 .5625 Mdot
.575 .48625 Mdot
.45375 .42625 Mdot
.4625 .4375 Mdot
.48125 .425 Mdot
.81625 .5175 Mdot
.49 .52875 Mdot
.25625 .52 Mdot
.44625 .43875 Mdot
.70375 .3925 Mdot
.1 .28125 Mdot
.80875 .29875 Mdot
.6525 .33875 Mdot
.0275 .3725 Mdot
.74 .4475 Mdot
.37125 .54625 Mdot
.7275 .5475 Mdot
.315 .555 Mdot
.7525 .5725 Mdot
.32375 .56 Mdot
.5125 .52875 Mdot
.72625 .57125 Mdot
.21875 .54125 Mdot
.30625 .53125 Mdot
.165 .4675 Mdot
.33625 .41375 Mdot
.53 .42 Mdot
.58125 .4325 Mdot
.335 .415 Mdot
.55125 .42875 Mdot
.6825 .4625 Mdot
.35375 .4575 Mdot
.42125 .45125 Mdot
.485 .4725 Mdot
.71 .46375 Mdot
.6 .49625 Mdot
.54375 .50875 Mdot
.12375 .5 Mdot
.2625 .49625 Mdot
.295 .415 Mdot
.40625 .3925 Mdot
.75625 .38625 Mdot
.095 .37875 Mdot
.14875 .46625 Mdot
.59125 .5025 Mdot
.4325 .545 Mdot
.29 .56125 Mdot
.45875 .55 Mdot
.71125 .54125 Mdot
.35375 .525 Mdot
.705 .52 Mdot
.61625 .5325 Mdot
.1825 .52625 Mdot
.34625 .50625 Mdot
.47375 .50375 Mdot
.57875 .4975 Mdot
.635 .51 Mdot
.875 .505 Mdot
.195 .51 Mdot
.52125 .5075 Mdot
.63625 .505 Mdot
.05 .5125 Mdot
.91625 .5375 Mdot
.84875 .5125 Mdot
.69125 .53 Mdot
.35125 .515 Mdot
.70125 .46125 Mdot
.0275 .4775 Mdot
.7425 .4175 Mdot
.71125 .4075 Mdot
.21125 .37 Mdot
.88125 .3475 Mdot
.8825 .3175 Mdot
.47 .3375 Mdot
.6325 .3375 Mdot
.28625 .38875 Mdot
.93625 .455 Mdot
.09875 .48125 Mdot
.45 .48125 Mdot
.17 .505 Mdot
.13875 .48125 Mdot
.79625 .47375 Mdot
.4025 .5025 Mdot
.68875 .53875 Mdot
.57625 .54625 Mdot
.43 .5525 Mdot
.025 .54 Mdot
.8475 .545 Mdot
.36 .50625 Mdot
.71375 .47375 Mdot
.835 .49125 Mdot
.29 .53 Mdot
.76125 .5525 Mdot
.805 .53875 Mdot
.525 .49875 Mdot
.16625 .485 Mdot
.11625 .4775 Mdot
.8625 .4875 Mdot
.0675 .4575 Mdot
.755 .45125 Mdot
.5975 .43375 Mdot
.59 .42625 Mdot
.6275 .40625 Mdot
.7775 .37875 Mdot
.69125 .37125 Mdot
.4525 .3325 Mdot
.34125 .3075 Mdot
.68875 .33375 Mdot
.315 .34 Mdot
.49375 .35 Mdot
.55375 .4075 Mdot
.4575 .45625 Mdot
.6575 .52125 Mdot
.38375 .57 Mdot
.4875 .52375 Mdot
.40125 .5175 Mdot
.81375 .47 Mdot
.54875 .44875 Mdot
.3 .45 Mdot
.39 .52875 Mdot
.77375 .57125 Mdot
.58125 .5175 Mdot
.03125 .49 Mdot
.7025 .4475 Mdot
.35 .45375 Mdot
.76625 .46625 Mdot
.40875 .5025 Mdot
.63375 .5125 Mdot
.34 .53625 Mdot
.57375 .5375 Mdot
.6675 .5275 Mdot
.2425 .50625 Mdot
.2725 .49875 Mdot
.13125 .51875 Mdot
.32375 .5175 Mdot
.6125 .49125 Mdot
.56875 .44375 Mdot
.24875 .41125 Mdot
.64875 .36875 Mdot
.60125 .365 Mdot
.34625 .365 Mdot
.49375 .375 Mdot
.45875 .4025 Mdot
.735 .43 Mdot
.56625 .41 Mdot
.5375 .425 Mdot
.0975 .45 Mdot
.30875 .4275 Mdot
.295 .4675 Mdot
.485 .475 Mdot
.685 .4975 Mdot
.10625 .53375 Mdot
.10625 .51125 Mdot
.6225 .495 Mdot
.3875 .455 Mdot
.33875 .45125 Mdot
.40875 .44375 Mdot
.755 .445 Mdot
.37375 .485 Mdot
.7025 .45375 Mdot
.59625 .45 Mdot
.2575 .40125 Mdot
.38 .445 Mdot
.49125 .45625 Mdot
.6425 .5075 Mdot
.59 .505 Mdot
.89 .51375 Mdot
.2025 .52625 Mdot
.44 .55875 Mdot
.715 .55875 Mdot
.0175 .5925 Mdot
.90625 .63375 Mdot
.8975 .67 Mdot
.61 .69625 Mdot
.40875 .66125 Mdot
.68875 .6375 Mdot
.09375 .545 Mdot
.67875 .51625 Mdot
.7225 .54125 Mdot
.2675 .60125 Mdot
.8175 .60625 Mdot
.88 .58375 Mdot
.4725 .52875 Mdot
.605 .45625 Mdot
.255 .4275 Mdot
.57625 .49 Mdot
.17375 .55875 Mdot
.13375 .54375 Mdot
.79 .56375 Mdot
.3525 .54 Mdot
.74125 .525 Mdot
.5875 .52625 Mdot
.465 .535 Mdot
.25625 .5425 Mdot
.72 .575 Mdot
.8075 .575 Mdot
.33125 .55875 Mdot
.71125 .55375 Mdot
.81375 .525 Mdot
.0475 .5375 Mdot
.47125 .5225 Mdot
.15375 .5175 Mdot
.1425 .5025 Mdot
.76375 .495 Mdot
.1725 .50875 Mdot
.71125 .4925 Mdot
.545 .465 Mdot
.6975 .48375 Mdot
.76125 .45625 Mdot
.7075 .435 Mdot
.7325 .43875 Mdot
.44625 .455 Mdot
.36375 .4725 Mdot
.5375 .46 Mdot
.47875 .48875 Mdot
.44625 .49875 Mdot
.54375 .46125 Mdot
.4825 .46625 Mdot
.655 .49875 Mdot
.35 .51125 Mdot
.5625 .57 Mdot
.28 .6175 Mdot
.87 .62125 Mdot
.5375 .5925 Mdot
.37 .56625 Mdot
.255 .50125 Mdot
.94625 .45625 Mdot
.455 .4775 Mdot
.11375 .4825 Mdot
.6575 .46 Mdot
.33125 .39875 Mdot
.78375 .32875 Mdot
.50875 .3025 Mdot
.46125 .32 Mdot
.42125 .35625 Mdot
.6125 .40875 Mdot
.61375 .47875 Mdot
.25875 .40875 Mdot
.24875 .4375 Mdot
.14 .42375 Mdot
.295 .435 Mdot
.67375 .4775 Mdot
.5425 .49875 Mdot
.2325 .57875 Mdot
.67375 .605 Mdot
.56625 .60125 Mdot
.3375 .5875 Mdot
.57625 .56625 Mdot
.4475 .52875 Mdot
.67125 .53125 Mdot
.56375 .5725 Mdot
.53875 .5875 Mdot
.1225 .62125 Mdot
.31625 .6275 Mdot
.31625 .59625 Mdot
.48375 .59 Mdot
.66 .56 Mdot
.1625 .54375 Mdot
.10625 .54875 Mdot
.65875 .5475 Mdot
.34375 .55125 Mdot
.38875 .53125 Mdot
.355 .52125 Mdot
.765 .5175 Mdot
.40125 .50125 Mdot
.655 .61125 Mdot
.60375 .56625 Mdot
.2875 .54125 Mdot
.4125 .47875 Mdot
.5125 .4375 Mdot
.74625 .43875 Mdot
.505 .44875 Mdot
.9175 .42875 Mdot
.1975 .4125 Mdot
.38375 .39625 Mdot
.76125 .42125 Mdot
.02 .43875 Mdot
.8675 .4075 Mdot
.97125 .38125 Mdot
.5225 .37125 Mdot
.46375 .365 Mdot
.69875 .40125 Mdot
.1125 .4675 Mdot
.56375 .4775 Mdot
.75 .445 Mdot
.32375 .4275 Mdot
.7575 .4425 Mdot
.855 .525 Mdot
.4325 .58625 Mdot
.6425 .665 Mdot
.22375 .6725 Mdot
.66 .63125 Mdot
.85125 .5475 Mdot
.265 .545 Mdot
.0775 .555 Mdot
.81 .53375 Mdot
.33 .52875 Mdot
.785 .50875 Mdot
.565 .485 Mdot
.53 .45125 Mdot
.1725 .46375 Mdot
.7375 .41 Mdot
.79375 .3625 Mdot
.33375 .34125 Mdot
.72 .33375 Mdot
.80375 .3675 Mdot
.07375 .40875 Mdot
.445 .4275 Mdot
.135 .4425 Mdot
.1625 .49875 Mdot
.65875 .49125 Mdot
.25625 .54 Mdot
.69875 .565 Mdot
.49625 .57125 Mdot
.79 .55 Mdot
.89375 .55125 Mdot
.635 .57 Mdot
.75875 .55875 Mdot
.4825 .56125 Mdot
.32375 .51625 Mdot
.4675 .50125 Mdot
.595 .48125 Mdot
.41875 .4725 Mdot
.51 .505 Mdot
.49375 .515 Mdot
.70875 .49125 Mdot
.2625 .4875 Mdot
.66875 .45875 Mdot
.16125 .39625 Mdot
.855 .42 Mdot
.61625 .4625 Mdot
.3675 .4825 Mdot
.2775 .52 Mdot
.96625 .555 Mdot
.33 .5525 Mdot
.23875 .5575 Mdot
.485 .5975 Mdot
.485 .6575 Mdot
.735 .68625 Mdot
.58375 .69 Mdot
.3175 .66125 Mdot
.47125 .59875 Mdot
.68 .525 Mdot
.56125 .46 Mdot
.28 .60625 Mdot
.24625 .585 Mdot
.1625 .59375 Mdot
.25125 .62 Mdot
.7175 .61875 Mdot
.535 .62375 Mdot
.2025 .56125 Mdot
.71875 .55875 Mdot
.5475 .54625 Mdot
.30375 .50875 Mdot
.65625 .5125 Mdot
.4125 .52875 Mdot
.65875 .49125 Mdot
.55625 .4175 Mdot
.505 .4075 Mdot
.175 .33 Mdot
.32875 .29125 Mdot
.30125 .35375 Mdot
.5075 .36375 Mdot
.68 .41125 Mdot
.0975 .42125 Mdot
.0625 .4225 Mdot
.69625 .42375 Mdot
.30375 .41625 Mdot
.42375 .41875 Mdot
.31625 .415 Mdot
.7875 .4125 Mdot
.41625 .3875 Mdot
.605 .38625 Mdot
.5725 .45875 Mdot
.37 .585 Mdot
.405 .64625 Mdot
.5525 .68625 Mdot
.84625 .6225 Mdot
.385 .5925 Mdot
.9775 .6375 Mdot
.1825 .61125 Mdot
.34875 .5925 Mdot
.78875 .55125 Mdot
.04875 .48125 Mdot
.81375 .4175 Mdot
.47375 .34 Mdot
.4925 .3875 Mdot
.6875 .3975 Mdot
.16125 .40625 Mdot
.4725 .39 Mdot
.74875 .41 Mdot
.42 .425 Mdot
.68125 .43 Mdot
.035 .4475 Mdot
.7875 .4625 Mdot
.40625 .47375 Mdot
.66375 .4375 Mdot
.22375 .46125 Mdot
.73375 .42375 Mdot
.71125 .4 Mdot
.36125 .39625 Mdot
.01375 .35375 Mdot
.84 .355 Mdot
.3075 .35 Mdot
.84125 .4425 Mdot
.53 .48125 Mdot
.60375 .5275 Mdot
.13125 .53625 Mdot
.71375 .54375 Mdot
.805 .5625 Mdot
.3075 .58375 Mdot
.72375 .61375 Mdot
.82625 .5875 Mdot
.08875 .5075 Mdot
.43875 .53125 Mdot
.12375 .55 Mdot
.24 .5075 Mdot
.57375 .54875 Mdot
.3025 .4975 Mdot
.70625 .45625 Mdot
.43625 .44875 Mdot
.8475 .47625 Mdot
.99875 .5 Mdot
.56875 .5125 Mdot
.7675 .545 Mdot
.52125 .54875 Mdot
.30125 .59625 Mdot
.4475 .6 Mdot
.6475 .5975 Mdot
.3775 .6 Mdot
.51375 .5575 Mdot
.50625 .5175 Mdot
.695 .52 Mdot
.2675 .48125 Mdot
.73 .46375 Mdot
.01125 .50875 Mdot
.96625 .47125 Mdot
.58625 .3975 Mdot
.36875 .38 Mdot
.255 .36875 Mdot
.3 .51875 Mdot
.30875 .55 Mdot
.33875 .545 Mdot
.62375 .545 Mdot
.6775 .6025 Mdot
.61375 .61 Mdot
.21875 .59625 Mdot
.59 .61375 Mdot
.69125 .64375 Mdot
.485 .6175 Mdot
.25625 .3525 Mdot
.2425 .3775 Mdot
.19125 .43125 Mdot
.21 .40125 Mdot
.735 .39375 Mdot
.55375 .3625 Mdot
.18125 .36375 Mdot
.70875 .36625 Mdot
.5825 .4025 Mdot
.2575 .50625 Mdot
.695 .54875 Mdot
.42375 .51625 Mdot
.61875 .5025 Mdot
.595 .50875 Mdot
.46125 .425 Mdot
.205 .46375 Mdot
.30875 .58625 Mdot
.2775 .61375 Mdot
.4925 .6575 Mdot
.7125 .61 Mdot
.04625 .54875 Mdot
.0225 .535 Mdot
.71875 .5225 Mdot
.29 .5775 Mdot
.44 .60625 Mdot
.26875 .635 Mdot
.825 .61 Mdot
.44375 .61 Mdot
.61625 .49625 Mdot
.5225 .4775 Mdot
.41625 .415 Mdot
.9625 .3975 Mdot
.44875 .36125 Mdot
.535 .38 Mdot
.88375 .4225 Mdot
.30125 .42875 Mdot
.22 .42 Mdot
.28625 .42625 Mdot
.77625 .4325 Mdot
.1175 .455 Mdot
.78125 .48875 Mdot
.4175 .62125 Mdot
.54625 .6325 Mdot
.66 .63875 Mdot
.21625 .64375 Mdot
.3225 .65875 Mdot
.76875 .65375 Mdot
.525 .62125 Mdot
.59375 .625 Mdot
.16375 .565 Mdot
.665 .52 Mdot
.40125 .495 Mdot
.70375 .44875 Mdot
.22625 .4025 Mdot
.81 .4325 Mdot
.57 .495 Mdot
.475 .4675 Mdot
.9175 .53 Mdot
.23625 .5275 Mdot
.86875 .4675 Mdot
.5325 .47875 Mdot
.65625 .45 Mdot
.15625 .445 Mdot
.71125 .455 Mdot
.7975 .4775 Mdot
.3025 .4925 Mdot
.71 .4675 Mdot
.86375 .50875 Mdot
.0875 .5875 Mdot
.4125 .5825 Mdot
.12125 .56 Mdot
.31125 .56125 Mdot
.53125 .51375 Mdot
.33625 .5225 Mdot
.66875 .54375 Mdot
.44875 .575 Mdot
.8575 .565 Mdot
.51625 .56125 Mdot
.78125 .49875 Mdot
.5375 .51375 Mdot
.27625 .51625 Mdot
.4725 .545 Mdot
.6525 .53125 Mdot
.36125 .5325 Mdot
.5225 .52875 Mdot
.4825 .49625 Mdot
.705 .4075 Mdot
.23625 .39875 Mdot
.82375 .4075 Mdot
.97875 .36875 Mdot
.64125 .51 Mdot
.37625 .54375 Mdot
.27 .59625 Mdot
.995 .60125 Mdot
.305 .45375 Mdot
.405 .4025 Mdot
.16375 .4175 Mdot
.77 .39375 Mdot
.655 .32875 Mdot
.57 .35 Mdot
.2025 .3425 Mdot
.64375 .3075 Mdot
.65125 .2975 Mdot
.52125 .33 Mdot
.2325 .63125 Mdot
.25125 .595 Mdot
.1775 .53375 Mdot
.235 .52125 Mdot
.70375 .49375 Mdot
.555 .51875 Mdot
.1825 .52875 Mdot
.7175 .5575 Mdot
.57875 .54875 Mdot
.26875 .48875 Mdot
.68375 .4625 Mdot
.4675 .4925 Mdot
.5625 .5025 Mdot
.6025 .5525 Mdot
.45125 .66375 Mdot
.2125 .68 Mdot
.3425 .60625 Mdot
.2825 .565 Mdot
.47375 .465 Mdot
.7275 .455 Mdot
.04125 .48875 Mdot
.0875 .47125 Mdot
.71375 .515 Mdot
.2575 .48 Mdot
.4625 .46625 Mdot
.24 .45625 Mdot
.84375 .48375 Mdot
.47875 .50125 Mdot
.59125 .505 Mdot
.495 .5075 Mdot
.44625 .50625 Mdot
.97125 .47125 Mdot
.43375 .54875 Mdot
.5325 .5525 Mdot
.88625 .50125 Mdot
.2725 .50875 Mdot
.22625 .49625 Mdot
.2775 .53 Mdot
.71625 .58125 Mdot
.26 .59875 Mdot
.69125 .61125 Mdot
.9925 .5825 Mdot
.06 .55875 Mdot
.3575 .51625 Mdot
.57375 .5 Mdot
.635 .46625 Mdot
.2575 .4375 Mdot
.0925 .41125 Mdot
.1775 .40375 Mdot
.84125 .41875 Mdot
.56625 .45375 Mdot
.5125 .45625 Mdot
.29375 .49875 Mdot
.52125 .51625 Mdot
.45625 .53125 Mdot
.69125 .60875 Mdot
.26625 .655 Mdot
.86625 .58875 Mdot
.425 .505 Mdot
.6375 .50625 Mdot
.1775 .52875 Mdot
.90625 .55875 Mdot
.57 .55375 Mdot
.57625 .57 Mdot
.1875 .58125 Mdot
.72125 .5775 Mdot
.7925 .55625 Mdot
.31375 .5125 Mdot
.70625 .4875 Mdot
.8625 .4425 Mdot
.125 .40875 Mdot
.3425 .38375 Mdot
.1225 .37875 Mdot
.25875 .42875 Mdot
.47625 .45375 Mdot
.39875 .48625 Mdot
.63 .50625 Mdot
.47 .5025 Mdot
.85375 .48625 Mdot
.47875 .415 Mdot
.7775 .41625 Mdot
.55375 .40125 Mdot
.2825 .39 Mdot
.47125 .38875 Mdot
.7025 .4275 Mdot
.2875 .465 Mdot
.53125 .4525 Mdot
.50375 .49625 Mdot
.65375 .57875 Mdot
.28625 .5725 Mdot
.80375 .58125 Mdot
.625 .545 Mdot
.29125 .50375 Mdot
.36375 .46 Mdot
.91875 .39875 Mdot
.35875 .52875 Mdot
.4625 .54125 Mdot
.0825 .55875 Mdot
.845 .53125 Mdot
.6 .53 Mdot
.53 .51875 Mdot
.265 .55 Mdot
.67625 .58125 Mdot
.53875 .60875 Mdot
.60875 .63875 Mdot
.215 .46125 Mdot
.27875 .51125 Mdot
.1925 .54875 Mdot
.2375 .57875 Mdot
.675 .615 Mdot
.55125 .59375 Mdot
.215 .57125 Mdot
.695 .54375 Mdot
.6 .51375 Mdot
.31 .49375 Mdot
.57375 .48625 Mdot
.5725 .5125 Mdot
.48625 .5675 Mdot
.6125 .5925 Mdot
.4525 .5625 Mdot
.2725 .59125 Mdot
.3225 .5975 Mdot
.28 .52125 Mdot
.4275 .57375 Mdot
.77875 .58875 Mdot
.08625 .585 Mdot
.99 .58 Mdot
.16625 .5825 Mdot
.72125 .5425 Mdot
.25125 .505 Mdot
.4825 .485 Mdot
.25375 .48375 Mdot
.79 .4725 Mdot
.52125 .46125 Mdot
.53375 .5075 Mdot
.48375 .48375 Mdot
.4875 .49375 Mdot
.96 .52 Mdot
.43625 .49625 Mdot
.51375 .4625 Mdot
.83625 .4925 Mdot
.285 .50375 Mdot
.22625 .49625 Mdot
.2825 .46625 Mdot
.6475 .44625 Mdot
.45125 .44 Mdot
.58375 .465 Mdot
.925 .48375 Mdot
.15625 .53 Mdot
.3025 .5525 Mdot
.60875 .5225 Mdot
.63 .5225 Mdot
.2525 .53 Mdot
.975 .53375 Mdot
.19 .5425 Mdot
.095 .58375 Mdot
.88875 .57125 Mdot
.60125 .5625 Mdot
.41625 .5375 Mdot
.43125 .53 Mdot
.39125 .51 Mdot
.51875 .5125 Mdot
.65375 .46625 Mdot
.30875 .455 Mdot
.89875 .4275 Mdot
.315 .4725 Mdot
.7925 .49375 Mdot
.21125 .505 Mdot
.91875 .46625 Mdot
.5575 .43875 Mdot
.5775 .385 Mdot
.255 .2975 Mdot
.735 .35625 Mdot
.76 .44375 Mdot
.335 .55375 Mdot
.73625 .64625 Mdot
.84 .69 Mdot
.11 .70125 Mdot
.3375 .68125 Mdot
.155 .62125 Mdot
.33 .49375 Mdot
.435 .4275 Mdot
.4625 .385 Mdot
.545 .36625 Mdot
.52375 .36 Mdot
.83625 .385 Mdot
.50875 .50375 Mdot
.7225 .5225 Mdot
.61375 .53375 Mdot
.2675 .535 Mdot
.50375 .51125 Mdot
.6875 .52625 Mdot
.31375 .5025 Mdot
.47125 .5075 Mdot
.48875 .48625 Mdot
.64625 .4625 Mdot
.31625 .48875 Mdot
.78 .44375 Mdot
.68125 .46375 Mdot
.18375 .4825 Mdot
.46875 .55375 Mdot
.8325 .6175 Mdot
.915 .57125 Mdot
.565 .49375 Mdot
.4525 .47125 Mdot
.01875 .45375 Mdot
.9475 .46125 Mdot
.56875 .48 Mdot
.36625 .48375 Mdot
.4 .455 Mdot
.705 .46125 Mdot
.43875 .47875 Mdot
.68375 .44875 Mdot
.16 .445 Mdot
.30625 .4275 Mdot
.21125 .45625 Mdot
.2425 .43125 Mdot
.67375 .4 Mdot
.52 .4325 Mdot
.24 .4525 Mdot
.68375 .44 Mdot
.6325 .45375 Mdot
.32375 .48625 Mdot
.50875 .4775 Mdot
.5975 .43375 Mdot
.525 .385 Mdot
.6125 .33875 Mdot
.40125 .33 Mdot
.305 .2875 Mdot
.2975 .28 Mdot
.2775 .3525 Mdot
.41875 .38 Mdot
.83625 .35875 Mdot
.08 .39 Mdot
.9125 .41875 Mdot
.18375 .44875 Mdot
.74375 .43125 Mdot
.2425 .515 Mdot
.47625 .53625 Mdot
.26625 .53625 Mdot
.79 .555 Mdot
.56875 .60125 Mdot
.4975 .63875 Mdot
.43125 .64 Mdot
.59625 .5625 Mdot
.88875 .53 Mdot
.43125 .525 Mdot
.5275 .485 Mdot
.0275 .46625 Mdot
.72875 .495 Mdot
.31 .46375 Mdot
.19625 .43375 Mdot
.32875 .445 Mdot
.57625 .4425 Mdot
.625 .46375 Mdot
.45125 .4475 Mdot
.8825 .45875 Mdot
.225 .42 Mdot
.28375 .43375 Mdot
.645 .45 Mdot
.60875 .47 Mdot
.2075 .44875 Mdot
.9425 .45125 Mdot
.31375 .4525 Mdot
.05375 .44375 Mdot
.8675 .43875 Mdot
.645 .44375 Mdot
.35125 .44625 Mdot
.52 .425 Mdot
.255 .4225 Mdot
.65375 .40875 Mdot
.56 .42875 Mdot
.355 .43125 Mdot
.9025 .5325 Mdot
.235 .53875 Mdot
.925 .53375 Mdot
.1975 .5475 Mdot
.93625 .52875 Mdot
.5875 .57625 Mdot
.55 .6425 Mdot
.35 .8 Mdot
.74875 .685 Mdot
.7275 .54625 Mdot
.375 .415 Mdot
.7075 .3425 Mdot
.85125 .31125 Mdot
.11875 .2875 Mdot
.29875 .35 Mdot
.2075 .45375 Mdot
.37125 .5575 Mdot
.41 .6225 Mdot
.50375 .5925 Mdot
.5 .53875 Mdot
.575 .53125 Mdot
.775 .51125 Mdot
.93125 .47375 Mdot
.55875 .4825 Mdot
.6575 .4875 Mdot
.6475 .47 Mdot
.31125 .46 Mdot
.46875 .475 Mdot
.7075 .4525 Mdot
.3325 .45625 Mdot
.435 .5025 Mdot
.50875 .5525 Mdot
.5525 .53125 Mdot
.43625 .555 Mdot
.675 .66 Mdot
.02625 .76625 Mdot
.96125 .7775 Mdot
.77375 .81375 Mdot
.12625 .81875 Mdot
.4375 .72875 Mdot
.8325 .635 Mdot
.64875 .6 Mdot
.76875 .675 Mdot
.41875 .7 Mdot
.05 .685 Mdot
.86125 .67875 Mdot
.59 .69125 Mdot
.295 .65 Mdot
.55625 .605 Mdot
.685 .56125 Mdot
.3475 .50875 Mdot
.76125 .485 Mdot
.085 .54625 Mdot
.34 .55125 Mdot
.2075 .51875 Mdot
.275 .52875 Mdot
.66625 .56625 Mdot
.49125 .54375 Mdot
.3 .54 Mdot
.58625 .60375 Mdot
.70125 .60375 Mdot
.325 .545 Mdot
.45625 .54 Mdot
.65375 .53 Mdot
.5125 .45375 Mdot
.6375 .4525 Mdot
.3625 .49 Mdot
.3175 .50125 Mdot
.27875 .5225 Mdot
.24875 .59375 Mdot
.45625 .6425 Mdot
.82625 .71875 Mdot
.1625 .6925 Mdot
.7625 .64875 Mdot
.22875 .60875 Mdot
.76 .54 Mdot
.2225 .47125 Mdot
.49875 .45875 Mdot
.285 .44625 Mdot
.735 .44 Mdot
.6525 .39875 Mdot
.945 .34875 Mdot
.415 .32375 Mdot
.44375 .33375 Mdot
.67625 .42875 Mdot
.76875 .46 Mdot
.48 .455 Mdot
.56375 .485 Mdot
.045 .5025 Mdot
.65 .46875 Mdot
.36375 .48125 Mdot
.99625 .5275 Mdot
.14 .5175 Mdot
.3975 .51875 Mdot
.5275 .53625 Mdot
.75875 .5275 Mdot
.33375 .5075 Mdot
.8575 .48625 Mdot
.2925 .46375 Mdot
.28 .43 Mdot
.64125 .44125 Mdot
.5925 .455 Mdot
.1525 .4725 Mdot
.965 .48375 Mdot
.365 .4825 Mdot
.0675 .46 Mdot
.8075 .465 Mdot
.71875 .4875 Mdot
.27875 .5 Mdot
.6025 .55 Mdot
.115 .5925 Mdot
.7975 .6125 Mdot
.4875 .60375 Mdot
.38875 .605 Mdot
.9725 .5725 Mdot
.88 .505 Mdot
.16 .54 Mdot
.26875 .4775 Mdot
.905 .51 Mdot
.5675 .50625 Mdot
.56 .46625 Mdot
.47125 .365 Mdot
.755 .445 Mdot
.71375 .525 Mdot
.42375 .60375 Mdot
.64625 .605 Mdot
.895 .6025 Mdot
.1025 .6325 Mdot
.24875 .545 Mdot
.28625 .46125 Mdot
.41375 .45625 Mdot
.3725 .42875 Mdot
.5575 .53375 Mdot
.435 .62625 Mdot
.65125 .6575 Mdot
.73125 .64875 Mdot
.82625 .61 Mdot
.63625 .5825 Mdot
.61125 .5775 Mdot
.65625 .61375 Mdot
.36125 .60125 Mdot
.4325 .64375 Mdot
.71625 .66625 Mdot
.33875 .65125 Mdot
.44375 .59375 Mdot
.465 .55 Mdot
.5525 .5125 Mdot
.48125 .44125 Mdot
.55875 .32375 Mdot
.2525 .24 Mdot
.76375 .21625 Mdot
.855 .12125 Mdot
.115 .10875 Mdot
.4525 .17 Mdot
.80625 .18125 Mdot
.02 .18125 Mdot
.47375 .19125 Mdot
.915 .14125 Mdot
.41875 .1475 Mdot
.0975 .27125 Mdot
.75375 .3225 Mdot
.60125 .37625 Mdot
.27625 .41875 Mdot
.6925 .465 Mdot
.6125 .4475 Mdot
.2475 .48125 Mdot
.89375 .51 Mdot
.08625 .475 Mdot
.36 .43875 Mdot
.2175 .39375 Mdot
.2775 .39125 Mdot
.66625 .375 Mdot
.4725 .36625 Mdot
.32625 .3825 Mdot
.5425 .31 Mdot
.76375 .3475 Mdot
.3025 .42625 Mdot
.4075 .51 Mdot
.66875 .58625 Mdot
.5775 .7425 Mdot
.59 .75625 Mdot
.3 .7075 Mdot
.4 .67 Mdot
.31 .625 Mdot
.2825 .48 Mdot
.45 .41875 Mdot
.80125 .3925 Mdot
.265 .39625 Mdot
.5975 .43 Mdot
.2825 .4575 Mdot
.815 .53375 Mdot
.17375 .50875 Mdot
.52125 .49 Mdot
.31 .49875 Mdot
.645 .47125 Mdot
.77625 .48375 Mdot
.87375 .55875 Mdot
.32875 .59 Mdot
.485 .59875 Mdot
.74625 .55125 Mdot
.66625 .53125 Mdot
.49375 .52 Mdot
.6075 .53 Mdot
.075 .5125 Mdot
.57625 .55625 Mdot
.395 .55125 Mdot
.04125 .5725 Mdot
.5325 .59375 Mdot
.44 .55125 Mdot
.8775 .5525 Mdot
.20375 .52875 Mdot
.86375 .5175 Mdot
.335 .535 Mdot
.3275 .5725 Mdot
.57 .5425 Mdot
.61875 .5075 Mdot
.10125 .50125 Mdot
.98 .51 Mdot
.41375 .5175 Mdot
.08 .55875 Mdot
.76125 .63875 Mdot
.74375 .63125 Mdot
.25125 .60125 Mdot
.6525 .5575 Mdot
.965 .48625 Mdot
.4225 .47625 Mdot
.415 .4975 Mdot
.9025 .54625 Mdot
.02375 .5525 Mdot
.8375 .56 Mdot
.1575 .5275 Mdot
.97 .47 Mdot
.38625 .52 Mdot
.8675 .515 Mdot
.56375 .49625 Mdot
.53625 .49 Mdot
.53625 .47625 Mdot
.73375 .47375 Mdot
.725 .45125 Mdot
.45875 .41625 Mdot
.58125 .41625 Mdot
.925 .43125 Mdot
.1075 .4125 Mdot
.22125 .4975 Mdot
.36 .54375 Mdot
.3825 .4725 Mdot
.335 .45625 Mdot
.62375 .3725 Mdot
.3975 .30125 Mdot
.68625 .30625 Mdot
.67375 .36 Mdot
.7425 .4175 Mdot
.72 .47375 Mdot
.53875 .46 Mdot
.69375 .42625 Mdot
.37375 .43 Mdot
.4225 .36125 Mdot
.7125 .31375 Mdot
.34 .33625 Mdot
.45375 .38 Mdot
.45625 .43125 Mdot
.52875 .4925 Mdot
.51125 .59 Mdot
.4825 .62125 Mdot
.43625 .60375 Mdot
.62625 .62 Mdot
.85125 .66875 Mdot
.1775 .62625 Mdot
.37375 .605 Mdot
.8175 .6725 Mdot
.10375 .65625 Mdot
.39125 .66875 Mdot
.925 .72 Mdot
.42875 .66875 Mdot
.2475 .4625 Mdot
.5475 .3675 Mdot
.65 .28625 Mdot
.26875 .22375 Mdot
.7725 .2775 Mdot
.56875 .435 Mdot
.16 .48875 Mdot
.96875 .48875 Mdot
.085 .52875 Mdot
.3525 .5275 Mdot
.20875 .54875 Mdot
.305 .55625 Mdot
.6475 .58625 Mdot
.49125 .635 Mdot
.29875 .635 Mdot
.505 .66875 Mdot
.8475 .6175 Mdot
.315 .53625 Mdot
.335 .44125 Mdot
.63375 .365 Mdot
.69375 .28125 Mdot
.5325 .29 Mdot
.26625 .3125 Mdot
.45 .36125 Mdot
.3 .38 Mdot
.99 .455 Mdot
.35375 .45375 Mdot
.4375 .42375 Mdot
.7475 .38625 Mdot
.375 .41 Mdot
.46125 .395 Mdot
.285 .4 Mdot
.88 .44125 Mdot
.15 .525 Mdot
.535 .55375 Mdot
.33125 .5625 Mdot
.57375 .59625 Mdot
.8725 .6 Mdot
.81375 .54125 Mdot
.29125 .51 Mdot
.52375 .5175 Mdot
.77375 .53625 Mdot
.6225 .59375 Mdot
.51875 .62625 Mdot
.57875 .63 Mdot
.09625 .6375 Mdot
.5775 .625 Mdot
.3675 .58875 Mdot
.6575 .52625 Mdot
.38625 .535 Mdot
.94 .52625 Mdot
.0925 .57375 Mdot
.8575 .595 Mdot
.39875 .6175 Mdot
.38 .59875 Mdot
.48 .62125 Mdot
.64 .6375 Mdot
.09625 .5925 Mdot
.965 .55125 Mdot
.4725 .50875 Mdot
.11625 .46 Mdot
.6875 .36125 Mdot
.7275 .35125 Mdot
.29625 .36625 Mdot
.64375 .385 Mdot
.34875 .45625 Mdot
.4125 .435 Mdot
.81125 .395 Mdot
.13875 .38125 Mdot
.76625 .37375 Mdot
.17875 .37625 Mdot
.92125 .4875 Mdot
.5075 .47 Mdot
.78875 .46875 Mdot
.52625 .47375 Mdot
.64625 .4525 Mdot
.64875 .49125 Mdot
.74125 .55375 Mdot
.75 .57125 Mdot
.44 .5925 Mdot
.56625 .6175 Mdot
.92875 .61125 Mdot
.0925 .62125 Mdot
.22875 .60125 Mdot
.39625 .595 Mdot
.95125 .62625 Mdot
.4375 .69625 Mdot
.2875 .72 Mdot
.67375 .75625 Mdot
.375 .815 Mdot
.71125 .7875 Mdot
.63 .70375 Mdot
.655 .60875 Mdot
.81 .51625 Mdot
.48125 .5025 Mdot
.72125 .52375 Mdot
.39875 .54625 Mdot
.4075 .5425 Mdot
.685 .5625 Mdot
.34375 .51875 Mdot
.49 .47625 Mdot
.4275 .4225 Mdot
.52625 .415 Mdot
.4925 .38 Mdot
.5 .46125 Mdot
.5225 .49125 Mdot
.47875 .48 Mdot
.8575 .48125 Mdot
.3275 .52875 Mdot
.23125 .4875 Mdot
.87625 .485 Mdot
.10625 .525 Mdot
.37375 .5275 Mdot
.93375 .48 Mdot
.44375 .53625 Mdot
.32375 .62625 Mdot
.41 .715 Mdot
.70375 .775 Mdot
.29125 .845 Mdot
.7525 .7925 Mdot
.5725 .69 Mdot
.14875 .59125 Mdot
.96875 .55 Mdot
.10125 .46875 Mdot
.34 .52875 Mdot
.21375 .62 Mdot
.2875 .63875 Mdot
.6425 .595 Mdot
.49375 .52875 Mdot
.27875 .51125 Mdot
.50125 .51375 Mdot
.9075 .5225 Mdot
.25875 .54625 Mdot
.4025 .57625 Mdot
.56375 .57875 Mdot
.75125 .52375 Mdot
.485 .45125 Mdot
.295 .4525 Mdot
.42 .41875 Mdot
.31375 .455 Mdot
.97875 .47375 Mdot
.38875 .5175 Mdot
.39375 .52875 Mdot
.75 .5425 Mdot
.40625 .47 Mdot
.47375 .46375 Mdot
.2525 .4625 Mdot
.89375 .45625 Mdot
.14375 .4325 Mdot
.5225 .445 Mdot
.3475 .45375 Mdot
.56875 .4625 Mdot
.91125 .44875 Mdot
.76875 .45625 Mdot
.2525 .45375 Mdot
.56375 .42 Mdot
.79 .4225 Mdot
.6125 .38625 Mdot
.48375 .3675 Mdot
.615 .36375 Mdot
.09 .3425 Mdot
.54875 .32 Mdot
.35125 .37 Mdot
.7925 .4575 Mdot
.35125 .46375 Mdot
.91625 .4775 Mdot
.02875 .44875 Mdot
.88625 .4375 Mdot
.455 .425 Mdot
.4175 .425 Mdot
.36375 .40875 Mdot
.66625 .42 Mdot
.145 .47 Mdot
.895 .51875 Mdot
.56625 .59 Mdot
.14 .61875 Mdot
.6125 .63375 Mdot
.70125 .59625 Mdot
.36125 .555 Mdot
.5925 .50625 Mdot
.3 .5125 Mdot
.43125 .55 Mdot
.70375 .57375 Mdot
.2575 .5975 Mdot
.69125 .58125 Mdot
.205 .565 Mdot
.9275 .46375 Mdot
.62125 .485 Mdot
.69125 .4675 Mdot
.5275 .46 Mdot
.63125 .5025 Mdot
.73625 .46 Mdot
.715 .395 Mdot
.80125 .41125 Mdot
.40625 .39625 Mdot
.56625 .37625 Mdot
.92125 .3475 Mdot
.10875 .3175 Mdot
.23375 .32625 Mdot
.38 .33625 Mdot
.97375 .3425 Mdot
.425 .3375 Mdot
.2575 .375 Mdot
.69375 .355 Mdot
.4 .32125 Mdot
.715 .3075 Mdot
.57875 .3575 Mdot
.5875 .41625 Mdot
.8575 .4825 Mdot
.46375 .51375 Mdot
.71 .50875 Mdot
.415 .485 Mdot
.44 .48 Mdot
.63 .46 Mdot
.31375 .49 Mdot
.56625 .4925 Mdot
.4 .47375 Mdot
.5575 .50125 Mdot
.43625 .5025 Mdot
.51625 .4375 Mdot
.61625 .395 Mdot
.34375 .44125 Mdot
.78375 .40125 Mdot
.53625 .3475 Mdot
.1775 .34375 Mdot
.81125 .405 Mdot
.1275 .3775 Mdot
.4325 .36875 Mdot
.88375 .4425 Mdot
.41875 .47875 Mdot
.425 .47375 Mdot
.27125 .485 Mdot
.7175 .48625 Mdot
.4275 .44625 Mdot
.6975 .44625 Mdot
.5275 .39375 Mdot
.16875 .4025 Mdot
.94875 .43 Mdot
.1375 .60625 Mdot
.33875 .53125 Mdot
.22375 .41875 Mdot
.28375 .40375 Mdot
.6225 .38625 Mdot
.52 .42125 Mdot
.2775 .405 Mdot
.46625 .4025 Mdot
.9525 .4175 Mdot
.23875 .45375 Mdot
.36625 .4725 Mdot
.57625 .515 Mdot
.7875 .605 Mdot
.45125 .675 Mdot
.3075 .6775 Mdot
.4425 .6725 Mdot
.35625 .64125 Mdot
.90625 .5875 Mdot
.39875 .52625 Mdot
.40125 .5575 Mdot
.69375 .57 Mdot
.46875 .63 Mdot
.47 .61625 Mdot
.27 .6 Mdot
.87125 .53625 Mdot
.14 .52 Mdot
.51375 .50125 Mdot
.40375 .4825 Mdot
.51625 .45875 Mdot
.9225 .45625 Mdot
.76625 .4675 Mdot
.2275 .465 Mdot
.61375 .49 Mdot
.8075 .5125 Mdot
.595 .52375 Mdot
.4675 .51625 Mdot
.62375 .53 Mdot
.0675 .54375 Mdot
.54 .53 Mdot
.34625 .50375 Mdot
.87 .4575 Mdot
.35375 .46625 Mdot
.83 .44125 Mdot
.0475 .44375 Mdot
.92 .42 Mdot
.475 .3825 Mdot
.4275 .355 Mdot
.24625 .37375 Mdot
.755 .37125 Mdot
.19 .36125 Mdot
.815 .385 Mdot
.60375 .42375 Mdot
.15 .43375 Mdot
.61125 .47875 Mdot
.6325 .52625 Mdot
.435 .54875 Mdot
.54875 .56375 Mdot
.26 .49125 Mdot
.4875 .44375 Mdot
.54625 .415 Mdot
.41875 .405 Mdot
.54 .43 Mdot
.33125 .46625 Mdot
.875 .56 Mdot
.76875 .5625 Mdot
.5875 .59875 Mdot
.4975 .60375 Mdot
.67875 .5625 Mdot
.98 .6025 Mdot
.8125 .5775 Mdot
.665 .5175 Mdot
.88125 .475 Mdot
.3325 .48625 Mdot
.61125 .505 Mdot
.89125 .5375 Mdot
.10625 .5575 Mdot
.245 .495 Mdot
.3925 .4775 Mdot
.96875 .44125 Mdot
.45 .4025 Mdot
.23125 .38875 Mdot
.70375 .42 Mdot
.40875 .435 Mdot
.69125 .47625 Mdot
.575 .48875 Mdot
.57875 .515 Mdot
.86125 .49875 Mdot
.4725 .50625 Mdot
.67875 .5125 Mdot
.455 .53625 Mdot
.49625 .56125 Mdot
.51875 .58875 Mdot
.31125 .5775 Mdot
.62375 .62 Mdot
.3725 .655 Mdot
.62875 .65375 Mdot
.33125 .6525 Mdot
.585 .6725 Mdot
.64375 .68375 Mdot
.295 .6375 Mdot
.6925 .63 Mdot
.6375 .67 Mdot
.20375 .65375 Mdot
.74875 .55 Mdot
.15125 .55375 Mdot
.5075 .5725 Mdot
.7975 .49375 Mdot
.4125 .45875 Mdot
.44875 .4725 Mdot
.28625 .4675 Mdot
.7075 .415 Mdot
.51625 .4375 Mdot
.55875 .48125 Mdot
.57375 .56625 Mdot
.12125 .585 Mdot
.965 .605 Mdot
.14875 .4275 Mdot
.36 .50625 Mdot
.29 .5925 Mdot
.235 .58375 Mdot
.625 .605 Mdot
.5 .56375 Mdot
.2725 .56375 Mdot
.51 .5175 Mdot
.95 .51125 Mdot
.25125 .50375 Mdot
.35 .47 Mdot
.52375 .41625 Mdot
.84375 .41875 Mdot
.4425 .4075 Mdot
.2875 .39625 Mdot
.48125 .435 Mdot
.37375 .46625 Mdot
.8275 .4525 Mdot
.47 .46125 Mdot
.35375 .405 Mdot
.68875 .39625 Mdot
.50125 .395 Mdot
.46 .45 Mdot
.275 .49 Mdot
.8575 .55125 Mdot
.16375 .54125 Mdot
.4725 .5475 Mdot
.435 .545 Mdot
.50625 .55125 Mdot
.93 .56875 Mdot
.78625 .575 Mdot
.1975 .585 Mdot
.67875 .60625 Mdot
.80125 .60125 Mdot
.5625 .60875 Mdot
.48625 .63375 Mdot
.595 .61125 Mdot
.10125 .58875 Mdot
.51125 .59 Mdot
.33875 .57125 Mdot
.9225 .52 Mdot
.34375 .50375 Mdot
.735 .5125 Mdot
.09125 .5125 Mdot
.955 .50875 Mdot
.47125 .52375 Mdot
.4425 .52875 Mdot
.15375 .54 Mdot
.8075 .51875 Mdot
.2775 .51125 Mdot
.71875 .47875 Mdot
.62375 .43125 Mdot
.18375 .38375 Mdot
.62375 .3575 Mdot
.48125 .33375 Mdot
.595 .37625 Mdot
.45 .41375 Mdot
.17625 .48625 Mdot
.5625 .48125 Mdot
.415 .4925 Mdot
.56875 .51125 Mdot
.42125 .51125 Mdot
.40375 .5 Mdot
.78375 .4825 Mdot
.89375 .475 Mdot
.49875 .45375 Mdot
.4575 .49375 Mdot
.75 .54125 Mdot
.905 .55125 Mdot
.8325 .60125 Mdot
.635 .60875 Mdot
.92875 .61875 Mdot
.28 .59625 Mdot
.66375 .57875 Mdot
.8475 .59 Mdot
.12375 .6125 Mdot
.245 .64875 Mdot
.36875 .65125 Mdot
.45 .65875 Mdot
.20125 .62875 Mdot
.70125 .6125 Mdot
.46375 .5975 Mdot
.62625 .5575 Mdot
.58 .55125 Mdot
.55625 .53125 Mdot
.86625 .54875 Mdot
.49 .53875 Mdot
.6175 .54875 Mdot
.48875 .53375 Mdot
.56 .53625 Mdot
.4425 .52375 Mdot
.29375 .52125 Mdot
.65 .48375 Mdot
.4025 .4825 Mdot
.65125 .45125 Mdot
.23375 .44125 Mdot
.68875 .44125 Mdot
.5625 .42875 Mdot
.31375 .39 Mdot
.7325 .44125 Mdot
.60125 .46 Mdot
.2275 .515 Mdot
.65875 .58375 Mdot
.215 .67625 Mdot
.59375 .61625 Mdot
.74 .60375 Mdot
.365 .585 Mdot
.4525 .565 Mdot
.3225 .495 Mdot
.71 .56 Mdot
.58125 .55125 Mdot
.45 .50875 Mdot
.61 .465 Mdot
.11375 .47125 Mdot
.955 .42875 Mdot
.13 .50125 Mdot
.4025 .43375 Mdot
.3375 .35125 Mdot
.24375 .335 Mdot
.605 .3775 Mdot
.47375 .44375 Mdot
.3125 .50125 Mdot
.52125 .57 Mdot
.92875 .565 Mdot
.2525 .52375 Mdot
.36 .5125 Mdot
.52625 .51375 Mdot
.81875 .43125 Mdot
.46875 .41875 Mdot
.29125 .44375 Mdot
.46625 .4525 Mdot
.3675 .43375 Mdot
.78875 .49 Mdot
.52625 .5175 Mdot
.3525 .51625 Mdot
.65875 .47375 Mdot
.52375 .45875 Mdot
.48375 .40375 Mdot
.26375 .3725 Mdot
.78625 .34 Mdot
.2175 .36625 Mdot
.45 .36 Mdot
.4875 .3575 Mdot
.495 .3375 Mdot
.88375 .325 Mdot
.79875 .3125 Mdot
.19 .33125 Mdot
.71 .32875 Mdot
.7825 .34375 Mdot
.57625 .3525 Mdot
.4475 .33875 Mdot
.6275 .3525 Mdot
.11625 .38625 Mdot
.43875 .40875 Mdot
.38 .45125 Mdot
.9825 .50625 Mdot
.32 .50125 Mdot
.64375 .52 Mdot
.185 .5325 Mdot
.9175 .545 Mdot
.51125 .575 Mdot
.43625 .63625 Mdot
.07625 .61375 Mdot
.88 .64375 Mdot
.31625 .68125 Mdot
.6575 .68625 Mdot
.6275 .66 Mdot
.21625 .6625 Mdot
.67 .6425 Mdot
.28125 .615 Mdot
.7825 .605 Mdot
.36625 .57 Mdot
.0775 .54375 Mdot
.64 .58875 Mdot
.3675 .59375 Mdot
.6725 .6 Mdot
.30125 .57375 Mdot
.49625 .58875 Mdot
.67 .505 Mdot
.39125 .4675 Mdot
.44625 .43875 Mdot
.84 .42375 Mdot
.785 .42625 Mdot
.88625 .4075 Mdot
.60125 .44125 Mdot
.99625 .44625 Mdot
.21375 .445 Mdot
.73875 .425 Mdot
.79125 .3725 Mdot
.145 .345 Mdot
.25125 .34375 Mdot
.325 .3425 Mdot
.50125 .4125 Mdot
.16125 .45125 Mdot
.70625 .46375 Mdot
.49625 .48 Mdot
.565 .4975 Mdot
.59875 .5075 Mdot
.53125 .48875 Mdot
.8425 .46875 Mdot
.5325 .45375 Mdot
.53875 .43125 Mdot
.53875 .43125 Mdot
.59875 .41875 Mdot
.385 .41 Mdot
.29 .42 Mdot
.64375 .43 Mdot
.46375 .44375 Mdot
.6725 .45625 Mdot
.17875 .47875 Mdot
.69125 .48375 Mdot
.5175 .545 Mdot
.3625 .59 Mdot
.72875 .555 Mdot
.54625 .51625 Mdot
.36 .49625 Mdot
.53625 .44 Mdot
.26375 .36375 Mdot
.5975 .4475 Mdot
.7675 .4725 Mdot
.315 .46875 Mdot
.39 .46 Mdot
.43 .52875 Mdot
.67625 .47 Mdot
.6275 .53125 Mdot
.38 .55625 Mdot
.59875 .5725 Mdot
.1875 .53625 Mdot
.92125 .5625 Mdot
.1425 .53875 Mdot
.4175 .56625 Mdot
.37 .5925 Mdot
.21125 .5775 Mdot
.615 .5225 Mdot
.4175 .4825 Mdot
.41875 .41625 Mdot
.475 .365 Mdot
.9475 .40375 Mdot
.19875 .4625 Mdot
.38 .48875 Mdot
.56625 .55875 Mdot
.7525 .63375 Mdot
.4975 .65375 Mdot
.30875 .63375 Mdot
.4725 .6 Mdot
.36125 .57125 Mdot
.78375 .54375 Mdot
.535 .53125 Mdot
.31375 .57375 Mdot
.675 .6475 Mdot
.5175 .6725 Mdot
.5675 .7 Mdot
.2025 .70375 Mdot
.725 .725 Mdot
.29125 .695 Mdot
.39125 .66875 Mdot
.5475 .66 Mdot
.5075 .66875 Mdot
.82125 .67 Mdot
.8225 .6775 Mdot
.15125 .68125 Mdot
.7425 .62125 Mdot
.76375 .5425 Mdot
.58125 .48125 Mdot
.43 .44125 Mdot
.66375 .40375 Mdot
.12125 .395 Mdot
.37875 .38375 Mdot
.4075 .37875 Mdot
.99875 .3875 Mdot
.32125 .42625 Mdot
.51625 .4225 Mdot
.345 .43 Mdot
.86 .44875 Mdot
.52375 .47875 Mdot
.42125 .43625 Mdot
.04125 .45375 Mdot
.93625 .465 Mdot
.335 .42125 Mdot
.6125 .39875 Mdot
.6075 .43125 Mdot
.235 .4275 Mdot
.7175 .4275 Mdot
.1525 .46875 Mdot
.925 .46875 Mdot
.28375 .4975 Mdot
.01125 .53375 Mdot
.0575 .52375 Mdot
.735 .47875 Mdot
.2975 .475 Mdot
.72 .45625 Mdot
.22375 .4725 Mdot
.55375 .47375 Mdot
.5475 .55375 Mdot
.28875 .54 Mdot
.46375 .50125 Mdot
.8975 .4725 Mdot
.64625 .41375 Mdot
.90375 .41 Mdot
.50625 .44375 Mdot
.16875 .475 Mdot
.7925 .51375 Mdot
.76875 .575 Mdot
.16125 .58 Mdot
.27625 .6 Mdot
.28 .6075 Mdot
.47875 .53375 Mdot
.19125 .51125 Mdot
.66625 .4775 Mdot
.55 .46625 Mdot
.55625 .46375 Mdot
.55625 .43 Mdot
.55375 .45375 Mdot
.83 .455 Mdot
.5475 .45 Mdot
.50375 .45125 Mdot
.54875 .47125 Mdot
.64 .4575 Mdot
.33125 .4575 Mdot
.315 .47125 Mdot
.61625 .49125 Mdot
.5075 .47 Mdot
.6725 .49 Mdot
.17875 .4475 Mdot
.68 .41 Mdot
.49625 .4475 Mdot
.375 .48375 Mdot
.7975 .5075 Mdot
.39125 .565 Mdot
.52125 .5775 Mdot
.41375 .51875 Mdot
.32125 .4875 Mdot
.61375 .42625 Mdot
.76125 .41 Mdot
.2675 .4225 Mdot
.33 .435 Mdot
.57125 .37125 Mdot
.6475 .3775 Mdot
.6175 .33375 Mdot
.365 .3475 Mdot
.5875 .3925 Mdot
.18875 .45375 Mdot
.92375 .4825 Mdot
.18625 .41 Mdot
.38375 .40875 Mdot
.35875 .43875 Mdot
.26 .45875 Mdot
.6225 .4875 Mdot
.41 .52875 Mdot
.43125 .58 Mdot
.4475 .61375 Mdot
.9575 .5825 Mdot
.215 .56625 Mdot
.33625 .56625 Mdot
.58875 .53 Mdot
.78125 .5275 Mdot
.465 .5225 Mdot
.26375 .4875 Mdot
.535 .46125 Mdot
.36 .4625 Mdot
.76375 .44875 Mdot
.56375 .45625 Mdot
.27875 .44625 Mdot
.665 .4475 Mdot
.5525 .44375 Mdot
.58125 .42 Mdot
.18125 .39375 Mdot
.6575 .38625 Mdot
.375 .39125 Mdot
.37125 .4225 Mdot
.565 .45625 Mdot
.50375 .46375 Mdot
.7975 .445 Mdot
.8075 .425 Mdot
.00375 .37875 Mdot
.11875 .34625 Mdot
.77125 .41625 Mdot
.72625 .48125 Mdot
.5775 .5375 Mdot
.42375 .615 Mdot
.73 .67625 Mdot
.10625 .67875 Mdot
.3025 .71875 Mdot
.4125 .72 Mdot
.95 .6675 Mdot
.33875 .6375 Mdot
.39625 .61 Mdot
.52875 .57 Mdot
.785 .5525 Mdot
.5275 .51625 Mdot
.39375 .50625 Mdot
.06875 .47625 Mdot
.96375 .45375 Mdot
.28875 .4775 Mdot
.645 .4925 Mdot
.56 .48625 Mdot
.255 .51875 Mdot
.76875 .50875 Mdot
.01 .48625 Mdot
.21 .43125 Mdot
.06375 .37375 Mdot
.05 .33125 Mdot
.79 .33375 Mdot
.29875 .32375 Mdot
.72875 .36 Mdot
.125 .41875 Mdot
.645 .42125 Mdot
.35625 .415 Mdot
.2325 .4575 Mdot
.49375 .5075 Mdot
.9075 .5475 Mdot
.55875 .63125 Mdot
.94375 .6375 Mdot
.45875 .59375 Mdot
.15625 .57 Mdot
.8025 .56 Mdot
.7475 .52375 Mdot
.20125 .52 Mdot
.26875 .49 Mdot
.2825 .47125 Mdot
.45875 .4775 Mdot
.2 .46625 Mdot
.66 .46375 Mdot
.58 .4425 Mdot
.55875 .425 Mdot
.50625 .44625 Mdot
.565 .46 Mdot
.81875 .48875 Mdot
.5575 .515 Mdot
.485 .49375 Mdot
.56125 .45625 Mdot
.6575 .4525 Mdot
.31375 .435 Mdot
.31375 .42 Mdot
.575 .41 Mdot
.575 .4625 Mdot
.66 .48 Mdot
.19625 .53625 Mdot
.625 .58 Mdot
.50125 .4775 Mdot
.43375 .37875 Mdot
.83375 .35625 Mdot
.2625 .3325 Mdot
.58625 .35375 Mdot
.35625 .51625 Mdot
.37375 .60375 Mdot
.65375 .65125 Mdot
.70625 .68125 Mdot
.3075 .67875 Mdot
.21625 .685 Mdot
.67 .70625 Mdot
.62875 .68625 Mdot
.6175 .6025 Mdot
.335 .5275 Mdot
.64625 .42 Mdot
.19125 .38375 Mdot
.87625 .36625 Mdot
.25625 .51375 Mdot
.32875 .52 Mdot
.31 .51625 Mdot
.2675 .545 Mdot
.64375 .52625 Mdot
.4175 .48625 Mdot
.4225 .47875 Mdot
.44125 .4725 Mdot
.965 .47875 Mdot
.2175 .4625 Mdot
.31375 .45 Mdot
.5975 .39125 Mdot
.8 .34375 Mdot
.4925 .33125 Mdot
.18875 .3475 Mdot
.55625 .40625 Mdot
.39125 .48875 Mdot
.7125 .525 Mdot
.60875 .52625 Mdot
.2875 .55 Mdot
.63625 .5175 Mdot
.575 .49375 Mdot
.62375 .50875 Mdot
.1 .5525 Mdot
.63875 .54375 Mdot
.45375 .5375 Mdot
.32375 .5425 Mdot
.58 .53125 Mdot
.515 .5275 Mdot
.76 .5725 Mdot
.80625 .61875 Mdot
.03625 .645 Mdot
.11875 .65375 Mdot
.795 .5825 Mdot
.685 .52625 Mdot
.565 .4725 Mdot
.42625 .3875 Mdot
.7775 .355 Mdot
.1075 .34625 Mdot
.23625 .295 Mdot
.41125 .29875 Mdot
.89875 .3575 Mdot
.34625 .395 Mdot
.31375 .415 Mdot
.7 .45875 Mdot
.655 .44625 Mdot
.5975 .4575 Mdot
.355 .46375 Mdot
.12 .4775 Mdot
.91 .48375 Mdot
.31375 .47625 Mdot
.62625 .45625 Mdot
.54375 .40875 Mdot
.28625 .38125 Mdot
.74125 .38375 Mdot
.155 .41 Mdot
.07375 .4525 Mdot
.06125 .5675 Mdot
.78375 .58 Mdot
.375 .6475 Mdot
.66125 .62125 Mdot
.14125 .5475 Mdot
.6575 .49625 Mdot
.23125 .4475 Mdot
.23625 .4525 Mdot
.485 .4375 Mdot
.92 .425 Mdot
.4275 .3975 Mdot
.505 .47875 Mdot
.99875 .46 Mdot
.16125 .43 Mdot
.81125 .39125 Mdot
.73625 .4075 Mdot
.2175 .43625 Mdot
.2675 .4875 Mdot
.24625 .5175 Mdot
.41125 .54 Mdot
.2525 .53625 Mdot
.615 .5725 Mdot
.6025 .6375 Mdot
.60375 .645 Mdot
.445 .6425 Mdot
.55625 .5825 Mdot
.85375 .53 Mdot
.52875 .54375 Mdot
.49125 .57625 Mdot
.55375 .59125 Mdot
.65875 .64 Mdot
.3125 .67375 Mdot
.345 .65875 Mdot
.52 .64 Mdot
.63 .58375 Mdot
.6425 .53375 Mdot
.20875 .5025 Mdot
.61 .49375 Mdot
.4575 .61375 Mdot
.47 .72 Mdot
.87375 .74125 Mdot
.225 .73125 Mdot
.61375 .67625 Mdot
.325 .52375 Mdot
.365 .43125 Mdot
.67875 .39125 Mdot
.7075 .3275 Mdot
.31125 .32 Mdot
.17 .32 Mdot
.73875 .34125 Mdot
.56625 .36625 Mdot
.565 .49625 Mdot
.41125 .56125 Mdot
.62125 .6 Mdot
.31375 .60375 Mdot
.7525 .575 Mdot
.38375 .53125 Mdot
.235 .47125 Mdot
.2 .3675 Mdot
.29625 .375 Mdot
.63875 .3925 Mdot
.4675 .4325 Mdot
.3775 .4275 Mdot
.44375 .4475 Mdot
.95375 .42625 Mdot
.2375 .4275 Mdot
.31 .48625 Mdot
.5975 .59375 Mdot
.8325 .625 Mdot
.465 .61875 Mdot
.1875 .64875 Mdot
.5175 .58 Mdot
.43375 .48625 Mdot
.68375 .4475 Mdot
.62375 .42375 Mdot
.3275 .3925 Mdot
.57125 .385 Mdot
.6075 .38375 Mdot
.69375 .38 Mdot
.005 .365 Mdot
.6025 .38 Mdot
.57375 .4125 Mdot
.245 .42 Mdot
.62 .44875 Mdot
.545 .47625 Mdot
.6675 .44875 Mdot
.79125 .43125 Mdot
.1075 .44875 Mdot
.15375 .48875 Mdot
.745 .5575 Mdot
.6725 .60375 Mdot
.57 .655 Mdot
.40625 .71125 Mdot
.8375 .6975 Mdot
.09625 .6525 Mdot
.185 .6725 Mdot
.415 .66375 Mdot
.85 .635 Mdot
.325 .60875 Mdot
.2725 .58125 Mdot
.84625 .55875 Mdot
.5425 .55125 Mdot
.64375 .5575 Mdot
.32875 .57875 Mdot
.16125 .58375 Mdot
.88625 .57625 Mdot
.2925 .6025 Mdot
.64375 .61875 Mdot
.56375 .65 Mdot
.225 .67125 Mdot
.7375 .70375 Mdot
.055 .74 Mdot
.15875 .7675 Mdot
.0475 .765 Mdot
.13125 .67875 Mdot
.7475 .67875 Mdot
.44 .61875 Mdot
.57 .625 Mdot
.18 .64875 Mdot
.6925 .68 Mdot
.1775 .63125 Mdot
.25375 .6375 Mdot
.56375 .62 Mdot
.83125 .615 Mdot
.29 .53125 Mdot
.475 .4125 Mdot
.9875 .435 Mdot
.1675 .47625 Mdot
.83625 .49375 Mdot
.72 .47375 Mdot
.19625 .43625 Mdot
.31 .38625 Mdot
.21625 .385 Mdot
.38875 .4025 Mdot
.3025 .4225 Mdot
.5625 .43375 Mdot
.61125 .40125 Mdot
.655 .43125 Mdot
.32625 .445 Mdot
.11875 .45375 Mdot
.45375 .48375 Mdot
.8725 .5225 Mdot
.5125 .5025 Mdot
.51375 .50375 Mdot
.54625 .52375 Mdot
.65375 .5275 Mdot
.3 .5175 Mdot
.36875 .5175 Mdot
.505 .5175 Mdot
.63125 .51875 Mdot
.66625 .48 Mdot
.2075 .4475 Mdot
.605 .45125 Mdot
.42875 .355 Mdot
.46375 .30875 Mdot
.86125 .33375 Mdot
.27125 .37 Mdot
.61875 .39 Mdot
.33875 .4875 Mdot
.37 .53125 Mdot
.6475 .555 Mdot
.6675 .6375 Mdot
.37625 .6625 Mdot
.16375 .62875 Mdot
.78 .56875 Mdot
.43 .5125 Mdot
.595 .3775 Mdot
.45125 .35375 Mdot
.595 .3825 Mdot
.39625 .44875 Mdot
.64375 .5025 Mdot
.48875 .61625 Mdot
.10125 .7175 Mdot
.1025 .84375 Mdot
.32625 .8275 Mdot
.63875 .80875 Mdot
.5175 .74875 Mdot
.275 .74375 Mdot
.52625 .71375 Mdot
.9125 .6925 Mdot
.2275 .64875 Mdot
.3325 .54125 Mdot
.57375 .4675 Mdot
.8725 .4475 Mdot
.43 .4525 Mdot
.24 .47375 Mdot
.47375 .54625 Mdot
.4675 .53375 Mdot
.66125 .54625 Mdot
.595 .585 Mdot
.4075 .56875 Mdot
.46 .6 Mdot
.71 .65125 Mdot
.6775 .67 Mdot
.58 .69625 Mdot
.6825 .6675 Mdot
.1475 .65125 Mdot
.66625 .57625 Mdot
.56125 .48875 Mdot
.64 .43375 Mdot
.73625 .39 Mdot
.18 .35875 Mdot
.15 .35 Mdot
.74375 .335 Mdot
.6425 .375 Mdot
.55125 .37125 Mdot
.46375 .345 Mdot
.785 .3575 Mdot
.10875 .4175 Mdot
.20625 .43125 Mdot
.36625 .46375 Mdot
.7675 .495 Mdot
.35625 .47875 Mdot
.205 .47875 Mdot
.9925 .4775 Mdot
.45625 .50875 Mdot
.64875 .52125 Mdot
.30625 .5125 Mdot
.23375 .54125 Mdot
.83625 .54 Mdot
.2525 .52125 Mdot
.6775 .49375 Mdot
.5925 .42875 Mdot
.20625 .39 Mdot
.6675 .38125 Mdot
.16375 .36875 Mdot
.11 .4 Mdot
.07 .39625 Mdot
.16625 .3525 Mdot
.75 .3225 Mdot
.4575 .34 Mdot
.5325 .3275 Mdot
.16625 .3325 Mdot
.74 .325 Mdot
.19875 .39375 Mdot
.3925 .38375 Mdot
.57125 .41125 Mdot
.74625 .43125 Mdot
.16625 .5375 Mdot
.5325 .565 Mdot
.90875 .56625 Mdot
.185 .635 Mdot
.85125 .665 Mdot
.73 .69 Mdot
.1625 .69625 Mdot
.3725 .69875 Mdot
.17375 .6325 Mdot
.355 .5925 Mdot
.3775 .5775 Mdot
.475 .54625 Mdot
.65125 .555 Mdot
.6975 .52375 Mdot
.21125 .5075 Mdot
.265 .51125 Mdot
.365 .525 Mdot
.8825 .515 Mdot
.49 .49875 Mdot
.5525 .48 Mdot
.54375 .42375 Mdot
.6175 .3875 Mdot
.32875 .37875 Mdot
.385 .39875 Mdot
.51 .42875 Mdot
.555 .47 Mdot
.74375 .5425 Mdot
.18125 .5825 Mdot
.58375 .53 Mdot
.4975 .4875 Mdot
.38625 .47 Mdot
.9075 .38875 Mdot
.25625 .35625 Mdot
.6425 .4075 Mdot
.29625 .4125 Mdot
.3725 .4275 Mdot
.67375 .45 Mdot
.66125 .42125 Mdot
.3575 .44 Mdot
.19625 .515 Mdot
.83375 .56125 Mdot
.285 .61875 Mdot
.62875 .66 Mdot
.51125 .635 Mdot
.5625 .59875 Mdot
.45875 .565 Mdot
.56 .555 Mdot
.555 .29875 Mdot
.01125 .275 Mdot
.07875 .30375 Mdot
.33 .31625 Mdot
.62875 .3 Mdot
.57375 .32125 Mdot
.1825 .26 Mdot
.59625 .22875 Mdot
.865 .2725 Mdot
.25875 .34125 Mdot
.3275 .41875 Mdot
.5525 .4825 Mdot
.9175 .56625 Mdot
.4125 .59375 Mdot
.2375 .55375 Mdot
.45375 .5025 Mdot
.5325 .5275 Mdot
.5825 .50875 Mdot
.55625 .46125 Mdot
.56125 .46875 Mdot
.3075 .4525 Mdot
.7925 .425 Mdot
.6675 .38375 Mdot
.5675 .3875 Mdot
.7775 .4075 Mdot
.05625 .43875 Mdot
.71625 .52 Mdot
.55125 .5775 Mdot
.62 .64875 Mdot
.695 .7225 Mdot
.2475 .72625 Mdot
.14375 .70375 Mdot
.75 .6825 Mdot
.605 .60375 Mdot
.545 .5325 Mdot
.49375 .5125 Mdot
.7625 .4975 Mdot
.10875 .49875 Mdot
.22375 .48625 Mdot
.335 .46375 Mdot
.71 .44625 Mdot
.36625 .46875 Mdot
.18625 .49875 Mdot
.38375 .5 Mdot
.67 .47625 Mdot
.2975 .46375 Mdot
.25125 .405 Mdot
.8225 .41125 Mdot
.205 .415 Mdot
.69 .4225 Mdot
.68 .45875 Mdot
.135 .50125 Mdot
.63375 .4625 Mdot
.23 .415 Mdot
.13875 .33625 Mdot
.03375 .3325 Mdot
.15625 .44625 Mdot
.75375 .485 Mdot
.49 .51 Mdot
.53875 .52625 Mdot
.155 .51625 Mdot
.755 .52375 Mdot
.95 .56875 Mdot
.23125 .61 Mdot
.8825 .65 Mdot
.57 .6375 Mdot
.55875 .59625 Mdot
.65125 .615 Mdot
.00875 .61875 Mdot
.10875 .56125 Mdot
.60375 .54125 Mdot
.79875 .53625 Mdot
.25375 .44625 Mdot
.835 .4225 Mdot
.73625 .43125 Mdot
.1225 .455 Mdot
.425 .47375 Mdot
.1375 .5275 Mdot
.32 .585 Mdot
.4625 .59 Mdot
.34625 .57875 Mdot
.75875 .48625 Mdot
.635 .50625 Mdot
.2025 .49375 Mdot
.37375 .465 Mdot
.315 .475 Mdot
.83625 .5375 Mdot
.49625 .52 Mdot
.55625 .51875 Mdot
.545 .58125 Mdot
.63625 .56375 Mdot
.33 .57625 Mdot
.3875 .5575 Mdot
.50625 .53625 Mdot
.495 .48375 Mdot
.83625 .4925 Mdot
.1525 .46875 Mdot
.51875 .50125 Mdot
.5725 .5575 Mdot
.335 .5625 Mdot
.92375 .55 Mdot
.295 .52125 Mdot
.5875 .4925 Mdot
.35 .4525 Mdot
.385 .41 Mdot
.5925 .39 Mdot
.67125 .42125 Mdot
.39 .415 Mdot
.295 .35375 Mdot
.7625 .39375 Mdot
.15 .44125 Mdot
.72625 .48625 Mdot
.54375 .47375 Mdot
.5025 .49875 Mdot
.58875 .4425 Mdot
.4475 .38125 Mdot
.58375 .6175 Mdot
.05875 .465 Mdot
.32125 .45875 Mdot
.63375 .4825 Mdot
.57125 .5375 Mdot
.175 .63 Mdot
.61875 .65375 Mdot
.8325 .61125 Mdot
.2675 .58875 Mdot
.34125 .51 Mdot
.555 .38125 Mdot
.89125 .3 Mdot
.4375 .2775 Mdot
.2725 .28125 Mdot
.3975 .34 Mdot
.60375 .41125 Mdot
.49 .48125 Mdot
.52 .52125 Mdot
.7275 .5725 Mdot
.16 .56625 Mdot
.85375 .5625 Mdot
.66875 .56875 Mdot
.57625 .51 Mdot
.83625 .5075 Mdot
.775 .46625 Mdot
.55125 .49 Mdot
.55625 .4925 Mdot
.7275 .44375 Mdot
.26125 .47375 Mdot
.14625 .45625 Mdot
.765 .465 Mdot
.56 .53 Mdot
.56625 .59625 Mdot
.50625 .6075 Mdot
.73375 .63 Mdot
.09875 .605 Mdot
.2775 .56125 Mdot
.3175 .55 Mdot
.68625 .51375 Mdot
.34875 .51 Mdot
.19875 .52 Mdot
.32125 .5375 Mdot
.67625 .5575 Mdot
.32875 .57125 Mdot
.255 .55125 Mdot
.76625 .5225 Mdot
.225 .505 Mdot
.665 .5375 Mdot
.77625 .57375 Mdot
.06625 .61625 Mdot
.57125 .69875 Mdot
.34 .7675 Mdot
.12875 .82 Mdot
.01875 .79375 Mdot
.2 .70125 Mdot
.74 .69 Mdot
.49375 .6075 Mdot
.54875 .59625 Mdot
.15875 .57625 Mdot
.76875 .54 Mdot
.87625 .47375 Mdot
.33875 .40375 Mdot
.6825 .385 Mdot
.68875 .375 Mdot
.5675 .34625 Mdot
.58 .3325 Mdot
.13625 .34625 Mdot
.00125 .38 Mdot
.73625 .42375 Mdot
.67875 .40875 Mdot
.32375 .45125 Mdot
.8075 .44625 Mdot
.77625 .43125 Mdot
.04625 .43625 Mdot
.49875 .455 Mdot
.10375 .4575 Mdot
.275 .4275 Mdot
.61875 .41875 Mdot
.15375 .4125 Mdot
.8975 .47875 Mdot
.5575 .44125 Mdot
.195 .47 Mdot
.48625 .48 Mdot
.23625 .465 Mdot
.83 .4025 Mdot
.51125 .43875 Mdot
.53125 .39625 Mdot
.5575 .35125 Mdot
.62125 .3725 Mdot
.36625 .3925 Mdot
.3825 .39875 Mdot
.52125 .43125 Mdot
.445 .48375 Mdot
.89625 .4325 Mdot
.14 .45375 Mdot
.4675 .49125 Mdot
.59875 .51 Mdot
.30125 .52625 Mdot
.94625 .68 Mdot
.3425 .71 Mdot
.53875 .675 Mdot
.38375 .67375 Mdot
.42625 .71 Mdot
.46125 .6325 Mdot
.70375 .56375 Mdot
.43125 .545 Mdot
.38125 .56875 Mdot
.6775 .4875 Mdot
.0825 .44625 Mdot
.8275 .41875 Mdot
.52875 .4575 Mdot
.4425 .46625 Mdot
.64125 .5475 Mdot
.42375 .59125 Mdot
.57 .50125 Mdot
.06375 .5425 Mdot
.3425 .51625 Mdot
.6125 .535 Mdot
.55875 .47125 Mdot
.175 .43 Mdot
.6375 .46625 Mdot
.80875 .53125 Mdot
.25125 .54875 Mdot
.4025 .635 Mdot
.5425 .74125 Mdot
.87875 .745 Mdot
.41625 .7525 Mdot
.315 .77125 Mdot
.37375 .755 Mdot
.59875 .69375 Mdot
.465 .66 Mdot
.5275 .64125 Mdot
.76 .565 Mdot
.13125 .5075 Mdot
.8525 .47625 Mdot
.68375 .46375 Mdot
.5525 .47625 Mdot
.87625 .495 Mdot
.815 .49625 Mdot
.52125 .4775 Mdot
.515 .4825 Mdot
.77375 .5025 Mdot
.255 .4875 Mdot
.13125 .5075 Mdot
.79375 .4825 Mdot
.50375 .40875 Mdot
.5975 .38 Mdot
.53875 .3675 Mdot
.7025 .36875 Mdot
.08 .38875 Mdot
.30625 .42125 Mdot
.34625 .41 Mdot
.66875 .41375 Mdot
.3425 .43125 Mdot
.2025 .42625 Mdot
.2925 .4725 Mdot
.64875 .44625 Mdot
.37625 .44625 Mdot
.24 .50875 Mdot
.72 .52375 Mdot
.22875 .525 Mdot
.6825 .505 Mdot
.85 .48875 Mdot
.00875 .4225 Mdot
.55625 .34625 Mdot
.37 .30125 Mdot
.14625 .2675 Mdot
.0325 .29125 Mdot
.24375 .32 Mdot
.72625 .295 Mdot
.48375 .385 Mdot
.5575 .40625 Mdot
.17625 .44375 Mdot
.74125 .49375 Mdot
.84875 .52 Mdot
.03375 .5075 Mdot
.375 .50875 Mdot
.545 .50875 Mdot
.735 .5225 Mdot
.665 .53 Mdot
.41375 .4925 Mdot
.265 .46875 Mdot
.75875 .46 Mdot
.61625 .50125 Mdot
.3975 .4825 Mdot
.7475 .48625 Mdot
.805 .51 Mdot
.0225 .49 Mdot
.53375 .475 Mdot
.11125 .46125 Mdot
.28375 .42375 Mdot
.6775 .445 Mdot
.0625 .435 Mdot
1 .475 Mdot
.445 .47375 Mdot
.185 .51 Mdot
.7 .5125 Mdot
.09125 .55 Mdot
.81125 .53625 Mdot
.5275 .54875 Mdot
.53 .60125 Mdot
.57875 .63625 Mdot
.58625 .66375 Mdot
.41875 .6575 Mdot
.32375 .67875 Mdot
.55875 .6475 Mdot
.42125 .62125 Mdot
.91375 .6225 Mdot
.1725 .60125 Mdot
.37375 .565 Mdot
.6725 .57 Mdot
.2975 .56625 Mdot
.92625 .4125 Mdot
.35 .40625 Mdot
.4625 .44875 Mdot
.46875 .41125 Mdot
.51125 .31875 Mdot
.295 .39625 Mdot
.7625 .4425 Mdot
.42 .3875 Mdot
.49375 .36625 Mdot
.55375 .47 Mdot
.06875 .49875 Mdot
.95 .505 Mdot
.48125 .54375 Mdot
.41125 .58125 Mdot
.61875 .5325 Mdot
.4525 .53125 Mdot
.53125 .36625 Mdot
.00375 .3575 Mdot
.11375 .37625 Mdot
.3525 .3925 Mdot
.62125 .3975 Mdot
.525 .43875 Mdot
.18625 .45625 Mdot
.63375 .43125 Mdot
.85375 .40875 Mdot
.17375 .39875 Mdot
.41625 .395 Mdot
.57625 .3925 Mdot
.8475 .4225 Mdot
.40625 .4175 Mdot
.365 .405 Mdot
.3675 .36875 Mdot
.61625 .37 Mdot
.39625 .335 Mdot
.56375 .33 Mdot
.75375 .35625 Mdot
.1425 .4075 Mdot
.85625 .43 Mdot
.65125 .4875 Mdot
.51375 .51 Mdot
.91375 .4975 Mdot
.85375 .44875 Mdot
.4975 .45625 Mdot
.47125 .41 Mdot
.825 .38125 Mdot
.24125 .36 Mdot
.10125 .385 Mdot
.89125 .4175 Mdot
.36 .465 Mdot
.68375 .5075 Mdot
.5775 .54625 Mdot
.6475 .54625 Mdot
.05875 .5275 Mdot
.36875 .5375 Mdot
.325 .54 Mdot
.62375 .5575 Mdot
.38 .54125 Mdot
.18625 .52125 Mdot
.28 .41125 Mdot
.61875 .42125 Mdot
.38125 .4 Mdot
.28875 .395 Mdot
.65125 .425 Mdot
.2475 .46 Mdot
.69125 .47 Mdot
.895 .49375 Mdot
.53375 .57875 Mdot
.395 .60375 Mdot
.14625 .58375 Mdot
.05375 .5775 Mdot
.96875 .52 Mdot
.27125 .5525 Mdot
.7125 .57 Mdot
.54875 .53625 Mdot
.53875 .51 Mdot
.16 .49625 Mdot
.725 .45 Mdot
.83 .40875 Mdot
.07125 .44875 Mdot
.4075 .46375 Mdot
.46875 .46125 Mdot
.75125 .4725 Mdot
.74875 .57 Mdot
.29375 .6175 Mdot
.34 .64625 Mdot
.85 .5925 Mdot
.53125 .51375 Mdot
.41 .53 Mdot
.735 .52125 Mdot
.8275 .48375 Mdot
.02875 .48375 Mdot
.50875 .46625 Mdot
.15875 .44625 Mdot
.2825 .4925 Mdot
.70125 .47375 Mdot
.06375 .53 Mdot
.3625 .56 Mdot
.19625 .49625 Mdot
.76625 .4825 Mdot
.07 .435 Mdot
.80375 .4525 Mdot
.49375 .43375 Mdot
.56375 .4375 Mdot
.59375 .4275 Mdot
.545 .395 Mdot
.4525 .36375 Mdot
.31625 .34375 Mdot
.535 .36625 Mdot
.46375 .38875 Mdot
.86875 .42125 Mdot
.22875 .4275 Mdot
.255 .435 Mdot
.78875 .39125 Mdot
.285 .3825 Mdot
.86375 .4575 Mdot
.415 .495 Mdot
.45 .495 Mdot
.44 .5725 Mdot
.58 .6475 Mdot
.175 .62625 Mdot
.81875 .625 Mdot
.42375 .62 Mdot
.5575 .61 Mdot
.40375 .56125 Mdot
.1925 .52625 Mdot
.96 .52875 Mdot
.4225 .5025 Mdot
.4425 .44875 Mdot
.6225 .41375 Mdot
.45875 .38875 Mdot
.47125 .64125 Mdot
.065 .655 Mdot
.17 .66375 Mdot
.3325 .66375 Mdot
.63 .655 Mdot
.47875 .62125 Mdot
.26 .61 Mdot
.54 .58 Mdot
.92625 .545 Mdot
.17125 .5125 Mdot
.4125 .4825 Mdot
.56625 .47 Mdot
.84125 .4675 Mdot
.415 .48625 Mdot
.35125 .47375 Mdot
.37625 .46125 Mdot
.6325 .4425 Mdot
.31625 .41125 Mdot
.64 .41375 Mdot
.71625 .41 Mdot
.19875 .42375 Mdot
.8025 .42 Mdot
.64625 .43875 Mdot
.0175 .425 Mdot
.49875 .44375 Mdot
.95 .46625 Mdot
.8675 .47 Mdot
.47375 .46875 Mdot
.425 .4725 Mdot
.90625 .46125 Mdot
.2125 .48125 Mdot
.12 .4725 Mdot
.8975 .44875 Mdot
.29 .475 Mdot
.73 .4825 Mdot
.61375 .48875 Mdot
.64 .4975 Mdot
.45875 .58625 Mdot
.29875 .61 Mdot
.005 .6225 Mdot
.52 .5875 Mdot
.4575 .5525 Mdot
.195 .5525 Mdot
.28125 .6025 Mdot
.595 .6075 Mdot
.39125 .62 Mdot
.35875 .59125 Mdot
.53625 .5525 Mdot
.345 .50875 Mdot
.59 .4825 Mdot
.9975 .46875 Mdot
.52375 .46875 Mdot
.44 .465 Mdot
.1575 .5075 Mdot
.06375 .50625 Mdot
.91 .5475 Mdot
.3675 .5475 Mdot
.6325 .53625 Mdot
.58625 .545 Mdot
.5275 .51 Mdot
.24 .485 Mdot
.62875 .5275 Mdot
.84 .56 Mdot
.0675 .55625 Mdot
.41 .58875 Mdot
.52375 .62875 Mdot
.6675 .5975 Mdot
.86625 .51875 Mdot
.15375 .4775 Mdot
.4125 .43875 Mdot
.99625 .44875 Mdot
.95625 .52375 Mdot
.405 .595 Mdot
.47625 .56625 Mdot
.6975 .59125 Mdot
.83625 .57625 Mdot
.045 .54375 Mdot
.49375 .5175 Mdot
.23 .54125 Mdot
.93125 .48 Mdot
.34375 .49 Mdot
.655 .4925 Mdot
.1175 .45125 Mdot
.335 .39 Mdot
.19125 .40875 Mdot
.8225 .43125 Mdot
.0325 .46 Mdot
.83125 .5175 Mdot
.41875 .52125 Mdot
.62375 .52625 Mdot
.58625 .53125 Mdot
.5625 .555 Mdot
.42625 .55625 Mdot
.30125 .555 Mdot
.5125 .50875 Mdot
.5375 .46625 Mdot
.825 .4375 Mdot
.275 .45125 Mdot
.1475 .44375 Mdot
.8425 .47875 Mdot
.34 .49375 Mdot
.80625 .4225 Mdot
.4425 .3525 Mdot
.375 .32125 Mdot
.54 .2625 Mdot
.63 .285 Mdot
.02125 .35875 Mdot
.8475 .3925 Mdot
.49 .445 Mdot
.5725 .49625 Mdot
.285 .475 Mdot
.3075 .4975 Mdot
.9725 .52625 Mdot
.3425 .53875 Mdot
.4825 .5675 Mdot
.5875 .60375 Mdot
.5075 .62 Mdot
.41375 .4575 Mdot
.12375 .46 Mdot
.23625 .4375 Mdot
.34375 .42625 Mdot
.61125 .41375 Mdot
.44125 .4275 Mdot
.325 .44875 Mdot
.4925 .4975 Mdot
.9525 .535 Mdot
.1275 .56875 Mdot
.4925 .56875 Mdot
.5275 .51 Mdot
.83375 .4625 Mdot
.3975 .43 Mdot
.38125 .43875 Mdot
.33875 .46625 Mdot
.67125 .5275 Mdot
.2575 .5975 Mdot
.71125 .6275 Mdot
.64875 .67 Mdot
.26875 .69625 Mdot
.7775 .72875 Mdot
.6225 .6875 Mdot
.0525 .705 Mdot
.48375 .67 Mdot
.9475 .62125 Mdot
.86125 .64 Mdot
.46875 .605 Mdot
.38875 .61625 Mdot
.95625 .6475 Mdot
.21 .645 Mdot
.13125 .60125 Mdot
.90875 .5975 Mdot
.18125 .54875 Mdot
.82375 .49625 Mdot
.64 .435 Mdot
.6075 .45375 Mdot
.5075 .39625 Mdot
.3175 .395 Mdot
.115 .38625 Mdot
.40125 .4175 Mdot
.50875 .45875 Mdot
.2525 .475 Mdot
.3325 .455 Mdot
.50125 .42625 Mdot
.45625 .41375 Mdot
.44 .40875 Mdot
.405 .44 Mdot
.42375 .4925 Mdot
.535 .51625 Mdot
.54875 .485 Mdot
.4825 .48375 Mdot
.9925 .4825 Mdot
.16625 .48875 Mdot
.0775 .47875 Mdot
.84625 .445 Mdot
.48 .44375 Mdot
.5375 .46875 Mdot
.67 .47875 Mdot
.455 .5475 Mdot
.30125 .62 Mdot
.5575 .585 Mdot
.87875 .55625 Mdot
.06875 .545 Mdot
.3775 .485 Mdot
.59375 .41125 Mdot
.57875 .4325 Mdot
.97625 .45 Mdot
.0425 .42625 Mdot
.5075 .4525 Mdot
.94875 .4875 Mdot
.33 .46 Mdot
.49 .47 Mdot
.67375 .46375 Mdot
.86625 .46625 Mdot
.04875 .52375 Mdot
.445 .575 Mdot
.3825 .59125 Mdot
.68 .6025 Mdot
.525 .63125 Mdot
.575 .6425 Mdot
.21875 .665 Mdot
.9125 .72125 Mdot
.3825 .69375 Mdot
.2175 .63625 Mdot
.85125 .61625 Mdot
.8475 .50625 Mdot
.385 .51875 Mdot
.68625 .53 Mdot
.56 .52875 Mdot
.53125 .5275 Mdot
.47625 .54125 Mdot
.2825 .56375 Mdot
.4725 .59 Mdot
.6025 .605 Mdot
.7825 .61375 Mdot
.28 .60125 Mdot
.145 .5775 Mdot
.83 .53 Mdot
.395 .5025 Mdot
.7325 .6025 Mdot
.5025 .67125 Mdot
.3675 .70375 Mdot
.53875 .77 Mdot
.665 .7525 Mdot
.8725 .58875 Mdot
.47375 .545 Mdot
.575 .50625 Mdot
.27375 .52375 Mdot
.3525 .4575 Mdot
.9675 .40625 Mdot
.31125 .40375 Mdot
.52875 .38625 Mdot
.4925 .38625 Mdot
.6025 .4325 Mdot
.33875 .4525 Mdot
.175 .475 Mdot
.30875 .52125 Mdot
.3225 .53375 Mdot
.57375 .54875 Mdot
.4375 .53875 Mdot
.37625 .4875 Mdot
.4625 .455 Mdot
.95625 .465 Mdot
.1075 .4625 Mdot
.53875 .4825 Mdot
.50375 .58 Mdot
.80125 .645 Mdot
.41875 .65625 Mdot
.405 .6475 Mdot
.28625 .63625 Mdot
.755 .58375 Mdot
.18125 .555 Mdot
.755 .52875 Mdot
.62 .5075 Mdot
.32 .465 Mdot
.7375 .415 Mdot
.60625 .39625 Mdot
.0875 .38 Mdot
.46375 .39375 Mdot
.9575 .4275 Mdot
.87 .42375 Mdot
.42375 .43375 Mdot
.3925 .41 Mdot
.965 .41 Mdot
.25 .41 Mdot
.15125 .445 Mdot
.87625 .46875 Mdot
.08625 .51 Mdot
.9125 .52125 Mdot
.70625 .565 Mdot
.5 .54 Mdot
.00875 .5275 Mdot
.55125 .51375 Mdot
.29625 .51625 Mdot
.24125 .49125 Mdot
.24375 .49125 Mdot
.6125 .49375 Mdot
.26875 .47625 Mdot
.36375 .50875 Mdot
.42 .535 Mdot
.51 .5425 Mdot
.47875 .57 Mdot
.33 .5325 Mdot
.48625 .48875 Mdot
.46875 .46 Mdot
.58125 .4375 Mdot
.53875 .43375 Mdot
.87125 .41125 Mdot
.24375 .3975 Mdot
.0825 .41875 Mdot
.76625 .45 Mdot
.59125 .4475 Mdot
.46125 .4325 Mdot
.70125 .4275 Mdot
.44625 .39875 Mdot
.35625 .3525 Mdot
.47 .3775 Mdot
.91375 .39875 Mdot
.0625 .405 Mdot
.3625 .42375 Mdot
.65125 .46125 Mdot
.47875 .4625 Mdot
.56625 .51 Mdot
.91 .48125 Mdot
.265 .41875 Mdot
.5325 .4225 Mdot
.64875 .375 Mdot
.885 .4025 Mdot
.05625 .40375 Mdot
.40125 .39125 Mdot
.5025 .415 Mdot
.515 .4675 Mdot
.655 .43 Mdot
.42 .375 Mdot
.37875 .36875 Mdot
.8125 .37125 Mdot
.385 .37875 Mdot
.31875 .46125 Mdot
.8 .53375 Mdot
.795 .5875 Mdot
.39125 .5675 Mdot
.74125 .54125 Mdot
.5375 .52 Mdot
.4975 .505 Mdot
.52125 .5 Mdot
.2825 .47375 Mdot
.43625 .465 Mdot
.62875 .475 Mdot
.765 .475 Mdot
.28375 .47375 Mdot
.15125 .52625 Mdot
.835 .58125 Mdot
.42375 .59375 Mdot
.65625 .54125 Mdot
.53 .51 Mdot
.3925 .48 Mdot
.525 .4225 Mdot
.69125 .41125 Mdot
.8775 .475 Mdot
.45875 .53125 Mdot
.565 .56375 Mdot
.28125 .565 Mdot
.405 .6225 Mdot
.915 .65625 Mdot
.30625 .59625 Mdot
.5775 .5575 Mdot
.44375 .53125 Mdot
.66375 .4625 Mdot
.28625 .54 Mdot
.225 .50375 Mdot
.385 .44 Mdot
.31 .3975 Mdot
.55 .3875 Mdot
.4325 .415 Mdot
.4 .45 Mdot
.4575 .45875 Mdot
.93125 .4725 Mdot
.1275 .50125 Mdot
.5725 .49875 Mdot
.4525 .445 Mdot
.7675 .44125 Mdot
.4 .43125 Mdot
.5625 .43125 Mdot
.19625 .45375 Mdot
.77375 .48875 Mdot
.13375 .5025 Mdot
.7725 .5125 Mdot
.67625 .50875 Mdot
.27 .48875 Mdot
.745 .505 Mdot
.595 .525 Mdot
.10875 .525 Mdot
.425 .50375 Mdot
.845 .45125 Mdot
.44375 .4725 Mdot
.38875 .53375 Mdot
.9275 .565 Mdot
.33 .59375 Mdot
.1325 .565 Mdot
.845 .5475 Mdot
.02375 .48875 Mdot
.96875 .46625 Mdot
.7575 .43875 Mdot
.415 .4475 Mdot
.0625 .46 Mdot
.6075 .4875 Mdot
.25125 .5025 Mdot
.3825 .5175 Mdot
.11875 .51375 Mdot
.7 .48375 Mdot
.27125 .485 Mdot
.39 .46125 Mdot
.30375 .44125 Mdot
.595 .4775 Mdot
.51875 .4725 Mdot
.25875 .54875 Mdot
.54 .56375 Mdot
.43875 .565 Mdot
.5975 .54125 Mdot
.59125 .5475 Mdot
.81125 .59625 Mdot
.29375 .595 Mdot
.07375 .58625 Mdot
.69875 .5975 Mdot
.6625 .6075 Mdot
.42375 .61125 Mdot
.735 .61875 Mdot
.38625 .60375 Mdot
.45125 .6 Mdot
.4175 .57625 Mdot
.89125 .56 Mdot
.055 .535 Mdot
.3925 .54375 Mdot
.66625 .53 Mdot
.4275 .51125 Mdot
.5475 .51875 Mdot
.8575 .49625 Mdot
.19125 .5325 Mdot
.5525 .565 Mdot
.6475 .6575 Mdot
.90625 .67125 Mdot
.06625 .70625 Mdot
.3625 .68625 Mdot
.565 .63 Mdot
.4475 .6 Mdot
.67625 .61 Mdot
.39625 .58875 Mdot
.42375 .56125 Mdot
.775 .59875 Mdot
.3425 .55625 Mdot
.5 .51375 Mdot
.5975 .4375 Mdot
.1075 .45875 Mdot
.725 .42 Mdot
.3925 .42 Mdot
.79 .36875 Mdot
.4825 .39125 Mdot
.525 .41875 Mdot
.525 .43 Mdot
.29875 .4425 Mdot
.44875 .48375 Mdot
.59 .44375 Mdot
.7725 .435 Mdot
.27125 .4225 Mdot
.1975 .38625 Mdot
.79375 .36125 Mdot
.4375 .39875 Mdot
.6575 .39375 Mdot
.4975 .4175 Mdot
.47375 .4425 Mdot
.445 .48125 Mdot
.72125 .5125 Mdot
.8475 .4675 Mdot
.49875 .45875 Mdot
.54125 .41375 Mdot
.26875 .38 Mdot
.445 .3725 Mdot
.88125 .405 Mdot
.3175 .435 Mdot
.5675 .49375 Mdot
.49125 .54 Mdot
.65625 .585 Mdot
.28875 .55125 Mdot
.21125 .5775 Mdot
.42375 .60875 Mdot
.3125 .66125 Mdot
.52 .66375 Mdot
.43125 .63875 Mdot
.43875 .61375 Mdot
.43125 .62625 Mdot
.8875 .57875 Mdot
.205 .53 Mdot
.58375 .47875 Mdot
.43875 .46125 Mdot
.70875 .39375 Mdot
.37625 .3575 Mdot
.64 .35875 Mdot
.165 .36625 Mdot
.77125 .35375 Mdot
.15 .36625 Mdot
.73875 .40625 Mdot
.76 .40875 Mdot
.21375 .4325 Mdot
.74 .45125 Mdot
.56 .455 Mdot
.13625 .45 Mdot
.4475 .46875 Mdot
.78875 .525 Mdot
.4575 .52125 Mdot
.39125 .47625 Mdot
.9175 .4425 Mdot
.385 .42 Mdot
.125 .47 Mdot
.7875 .51125 Mdot
.0425 .585 Mdot
.9625 .605 Mdot
.8125 .64625 Mdot
.315 .6575 Mdot
.15625 .62625 Mdot
.59125 .59 Mdot
.2625 .57375 Mdot
.96625 .55 Mdot
.52125 .535 Mdot
0 .53 Mdot
.7675 .56625 Mdot
.2825 .5725 Mdot
.39375 .61 Mdot
.23875 .6325 Mdot
.715 .58875 Mdot
.46125 .59875 Mdot
.225 .54125 Mdot
.58875 .53375 Mdot
.38875 .56 Mdot
.6175 .53875 Mdot
.615 .50125 Mdot
.7525 .44125 Mdot
.35 .425 Mdot
.08375 .4075 Mdot
.6125 .4025 Mdot
.7425 .38125 Mdot
.3875 .37625 Mdot
.76125 .375 Mdot
.325 .4125 Mdot
.5525 .4275 Mdot
.36125 .46125 Mdot
.8625 .47875 Mdot
.09875 .51625 Mdot
.39125 .5025 Mdot
.63375 .50625 Mdot
.435 .53625 Mdot
.55125 .5475 Mdot
.86625 .5825 Mdot
.08375 .5325 Mdot
.59375 .48375 Mdot
.62125 .41875 Mdot
.92375 .41375 Mdot
.1075 .34 Mdot
.32375 .38625 Mdot
.565 .42875 Mdot
.4525 .43875 Mdot
.675 .39625 Mdot
.40125 .47125 Mdot
.39 .44875 Mdot
.7975 .4125 Mdot
.27875 .4375 Mdot
.71875 .47625 Mdot
.39375 .46625 Mdot
.185 .4425 Mdot
.64375 .45 Mdot
.45125 .4625 Mdot
.8025 .4975 Mdot
.43375 .495 Mdot
.585 .47 Mdot
.45625 .4775 Mdot
.36875 .475 Mdot
.455 .47125 Mdot
.53375 .545 Mdot
.7925 .5875 Mdot
.255 .625 Mdot
.26125 .68875 Mdot
.74875 .71625 Mdot
.4675 .68875 Mdot
.63375 .71625 Mdot
.465 .6825 Mdot
.50625 .62 Mdot
.44625 .58625 Mdot
.69125 .55 Mdot
.815 .5725 Mdot
.49125 .54 Mdot
.57125 .55875 Mdot
.29875 .58125 Mdot
.4025 .55375 Mdot
.85125 .49625 Mdot
.37375 .5375 Mdot
.5275 .52125 Mdot
.525 .50375 Mdot
.65125 .49375 Mdot
.29125 .4475 Mdot
.1925 .40125 Mdot
.44125 .39875 Mdot
.32625 .39875 Mdot
.48875 .4125 Mdot
.43625 .43375 Mdot
.45125 .4625 Mdot
.44625 .44125 Mdot
.84 .44 Mdot
.25 .4375 Mdot
.58 .45 Mdot
.4625 .42 Mdot
.645 .46375 Mdot
.35875 .54875 Mdot
.7125 .555 Mdot
.13125 .53625 Mdot
.7975 .56625 Mdot
.15875 .545 Mdot
.6775 .45875 Mdot
.805 .44 Mdot
.23 .46375 Mdot
.705 .48 Mdot
.54625 .46875 Mdot
.145 .48125 Mdot
.48375 .50875 Mdot
.955 .47625 Mdot
.74375 .50125 Mdot
.52375 .51375 Mdot
.34125 .5325 Mdot
.92875 .53875 Mdot
.4425 .51875 Mdot
.07625 .47875 Mdot
.7675 .41 Mdot
.04 .325 Mdot
.965 .3 Mdot
.875 .25625 Mdot
.19 .19625 Mdot
.30625 .2225 Mdot
.49125 .25625 Mdot
.33625 .255 Mdot
.83 .30875 Mdot
.64375 .37875 Mdot
.74875 .425 Mdot
.31 .49 Mdot
.3975 .455 Mdot
.19 .4375 Mdot
.80375 .42875 Mdot
.39125 .3725 Mdot
.23125 .395 Mdot
.60875 .42125 Mdot
.39875 .43625 Mdot
.66875 .5375 Mdot
.61375 .57375 Mdot
.70375 .60875 Mdot
.41 .6625 Mdot
.0675 .69875 Mdot
.57 .68625 Mdot
.8025 .6925 Mdot
.335 .6375 Mdot
.8375 .57 Mdot
.215 .51625 Mdot
.64875 .45625 Mdot
.31625 .39875 Mdot
.85 .40875 Mdot
.1375 .38375 Mdot
.39 .405 Mdot
.57875 .41875 Mdot
.47 .445 Mdot
.55 .46625 Mdot
.9525 .42375 Mdot
.04875 .44125 Mdot
.6075 .46 Mdot
.5875 .5 Mdot
.975 .48625 Mdot
.1225 .4675 Mdot
.26375 .45375 Mdot
.55125 .4175 Mdot
.50125 .43125 Mdot
.645 .4775 Mdot
.43125 .54 Mdot
.37375 .57125 Mdot
.8125 .6225 Mdot
.155 .6025 Mdot
.9625 .5825 Mdot
.2125 .59625 Mdot
.24625 .60125 Mdot
.5575 .61625 Mdot
.5575 .59375 Mdot
.7675 .6075 Mdot
.4125 .56875 Mdot
.63 .53875 Mdot
.3575 .52 Mdot
.53875 .5425 Mdot
.37625 .5 Mdot
.49625 .4625 Mdot
.80125 .47375 Mdot
.20875 .45375 Mdot
.41625 .37625 Mdot
.6275 .385 Mdot
.52375 .405 Mdot
.62375 .3625 Mdot
.41375 .355 Mdot
.52375 .42125 Mdot
.465 .39625 Mdot
.6825 .40125 Mdot
.78375 .4625 Mdot
.49875 .4875 Mdot
.59625 .49 Mdot
.2875 .48 Mdot
.38375 .51 Mdot
.8325 .4825 Mdot
.41 .46375 Mdot
.53125 .47125 Mdot
.53375 .47 Mdot
.63625 .44875 Mdot
.30375 .5625 Mdot
.19 .59875 Mdot
.39625 .57625 Mdot
.33 .54625 Mdot
.485 .5075 Mdot
.47 .4825 Mdot
.41875 .45625 Mdot
.45375 .48625 Mdot
.80375 .51875 Mdot
.33125 .58375 Mdot
.52125 .67375 Mdot
.48625 .78875 Mdot
.61875 .7675 Mdot
.32375 .72 Mdot
.79125 .65125 Mdot
.1425 .5975 Mdot
.6925 .51375 Mdot
.22625 .53125 Mdot
.71875 .6 Mdot
.75875 .66875 Mdot
.2775 .645 Mdot
.6375 .59625 Mdot
.5775 .58 Mdot
.11125 .5575 Mdot
.5325 .51875 Mdot
.92375 .53375 Mdot
.675 .5425 Mdot
.5375 .5175 Mdot
.3325 .4925 Mdot
.945 .48875 Mdot
.48375 .49625 Mdot
.07375 .5425 Mdot
.69875 .605 Mdot
.13 .6825 Mdot
.87375 .72875 Mdot
.9625 .7925 Mdot
.08375 .82875 Mdot
.41875 .8175 Mdot
.42 .78625 Mdot
.4125 .775 Mdot
.67 .71625 Mdot
.75625 .655 Mdot
.72125 .54875 Mdot
.31375 .44 Mdot
.4 .44375 Mdot
.165 .45 Mdot
.84125 .48 Mdot
.3475 .54625 Mdot
.24375 .535 Mdot
.62625 .4925 Mdot
.385 .475 Mdot
.65875 .47 Mdot
.64375 .4625 Mdot
.6725 .45625 Mdot
.4425 .4075 Mdot
.06875 .36625 Mdot
.525 .3475 Mdot
.82125 .36375 Mdot
.34125 .42625 Mdot
.88125 .49125 Mdot
.14125 .545 Mdot
.71375 .62125 Mdot
.29875 .67125 Mdot
.8175 .6825 Mdot
.1775 .695 Mdot
.40375 .69125 Mdot
.49625 .70625 Mdot
.515 .6525 Mdot
.54 .5425 Mdot
.62375 .57375 Mdot
.58125 .5375 Mdot
.95875 .5225 Mdot
.175 .52625 Mdot
.24625 .51125 Mdot
.49125 .54125 Mdot
.63125 .515 Mdot
.5325 .49625 Mdot
.49625 .4525 Mdot
.31875 .46125 Mdot
.89125 .41625 Mdot
.01125 .4525 Mdot
.0975 .425 Mdot
.27625 .415 Mdot
.52375 .41375 Mdot
.6225 .41125 Mdot
.74 .45625 Mdot
.4075 .5 Mdot
.6675 .53 Mdot
.2475 .53625 Mdot
.65 .52125 Mdot
.38625 .49625 Mdot
.47 .49 Mdot
.7675 .4475 Mdot
.195 .45125 Mdot
.49875 .495 Mdot
.55 .47625 Mdot
.575 .48625 Mdot
.6 .55 Mdot
.36875 .61375 Mdot
.56625 .5775 Mdot
.44 .62875 Mdot
.705 .6225 Mdot
.00125 .5625 Mdot
.77875 .4875 Mdot
.48875 .5075 Mdot
.6325 .5225 Mdot
.24 .53625 Mdot
.42125 .54 Mdot
.785 .59375 Mdot
.435 .55875 Mdot
.50875 .5125 Mdot
.56375 .535 Mdot
.60625 .56375 Mdot
.29 .49 Mdot
.20875 .48625 Mdot
.36625 .50625 Mdot
.35 .5225 Mdot
.49375 .52 Mdot
.46 .5175 Mdot
.4025 .5175 Mdot
.46875 .485 Mdot
.79375 .44875 Mdot
.355 .395 Mdot
.47625 .31625 Mdot
.56875 .26375 Mdot
.54125 .2925 Mdot
.31875 .3125 Mdot
.845 .4075 Mdot
.17 .50375 Mdot
.52 .575 Mdot
.41625 .545 Mdot
.6575 .5325 Mdot
.715 .4725 Mdot
.3775 .455 Mdot
.5425 .445 Mdot
.61 .5 Mdot
.09625 .49125 Mdot
.535 .4675 Mdot
.955 .41625 Mdot
.585 .34 Mdot
.57625 .36625 Mdot
.3475 .4225 Mdot
.965 .47125 Mdot
.46875 .49375 Mdot
.04125 .48125 Mdot
.69125 .465 Mdot
.21625 .45 Mdot
.7475 .43125 Mdot
.52875 .42875 Mdot
.32875 .42125 Mdot
.515 .40875 Mdot
.5025 .42 Mdot
.83375 .44125 Mdot
.0725 .46 Mdot
.64375 .49875 Mdot
.365 .57125 Mdot
.97375 .60125 Mdot
.4225 .585 Mdot
.19125 .58 Mdot
.815 .565 Mdot
.3425 .5325 Mdot
.26625 .5125 Mdot
.59625 .535 Mdot
.43375 .5325 Mdot
.6675 .51 Mdot
.63 .505 Mdot
.6875 .47375 Mdot
.42375 .47875 Mdot
.06875 .51375 Mdot
.53625 .5275 Mdot
.8025 .53625 Mdot
.3225 .55875 Mdot
.95625 .54375 Mdot
.06 .50125 Mdot
.775 .4775 Mdot
.2575 .4475 Mdot
.83125 .415 Mdot
.19375 .405 Mdot
.4225 .39875 Mdot
.405 .35 Mdot
.6 .3425 Mdot
.5425 .39 Mdot
.61 .45125 Mdot
.625 .485 Mdot
.9225 .52125 Mdot
.22625 .55625 Mdot
.19 .55625 Mdot
.455 .5275 Mdot
.75625 .51625 Mdot
.47 .52125 Mdot
.52375 .49875 Mdot
.28125 .505 Mdot
.92375 .49375 Mdot
.0325 .49375 Mdot
.26375 .49875 Mdot
.54125 .515 Mdot
.64875 .5325 Mdot
.7375 .5025 Mdot
.36 .4725 Mdot
.7075 .5 Mdot
.19875 .52125 Mdot
.69625 .52 Mdot
.4125 .55875 Mdot
.43125 .57 Mdot
.7775 .5525 Mdot
.14625 .52125 Mdot
.5575 .505 Mdot
.57375 .515 Mdot
.53875 .51375 Mdot
.63375 .43875 Mdot
.31125 .385 Mdot
.545 .40375 Mdot
.48 .37 Mdot
.725 .38 Mdot
.795 .57 Mdot
.4825 .57125 Mdot
.63 .57875 Mdot
.265 .58875 Mdot
.3825 .56125 Mdot
.785 .54875 Mdot
.46125 .55375 Mdot
.5 .5725 Mdot
.55875 .53375 Mdot
.6075 .50625 Mdot
.2525 .39125 Mdot
.2275 .39125 Mdot
.29375 .4075 Mdot
.38375 .42875 Mdot
.46625 .4525 Mdot
.48125 .47625 Mdot
.4125 .50625 Mdot
.4575 .54875 Mdot
.78 .5725 Mdot
.40875 .56875 Mdot
.3675 .5825 Mdot
.72375 .555 Mdot
.4725 .53 Mdot
.3025 .53875 Mdot
.8375 .475 Mdot
.1725 .375 Mdot
.4925 .3825 Mdot
.52375 .4 Mdot
.5575 .35625 Mdot
.66375 .39875 Mdot
.53375 .4825 Mdot
.44125 .50625 Mdot
.6225 .48875 Mdot
.07375 .5325 Mdot
.56625 .60875 Mdot
.97625 .67 Mdot
.00875 .67375 Mdot
.5175 .67 Mdot
.57875 .61375 Mdot
.3625 .51625 Mdot
.99125 .43 Mdot
.4775 .40125 Mdot
.03875 .395 Mdot
.605 .39375 Mdot
.36875 .38125 Mdot
.6025 .39125 Mdot
.6025 .39375 Mdot
.26125 .44 Mdot
.585 .44625 Mdot
.395 .4725 Mdot
.89125 .4725 Mdot
.135 .47375 Mdot
.55 .44625 Mdot
.45375 .44 Mdot
.8825 .4275 Mdot
.44875 .43125 Mdot
.26 .415 Mdot
.7525 .44625 Mdot
.35 .455 Mdot
.275 .4725 Mdot
.56625 .4725 Mdot
.4575 .48 Mdot
.67875 .43125 Mdot
.61 .43875 Mdot
.67375 .4725 Mdot
.45 .48625 Mdot
.03 .445 Mdot
.5775 .44375 Mdot
.80375 .41 Mdot
.2825 .38 Mdot
.0175 .4325 Mdot
.77 .44875 Mdot
.2425 .49 Mdot
.8725 .51375 Mdot
.165 .525 Mdot
.4575 .5325 Mdot
.3325 .56125 Mdot
.6675 .59375 Mdot
.60375 .62375 Mdot
.6425 .4675 Mdot
.62125 .415 Mdot
.91 .375 Mdot
.27 .385 Mdot
.13125 .37125 Mdot
.4425 .4 Mdot
.83625 .48 Mdot
.465 .505 Mdot
.46 .5075 Mdot
.3225 .515 Mdot
.9025 .55375 Mdot
.255 .49625 Mdot
.535 .47875 Mdot
.7225 .4975 Mdot
.70375 .485 Mdot
.3625 .5275 Mdot
.635 .48625 Mdot
.25625 .45875 Mdot
.70625 .46625 Mdot
.4025 .4975 Mdot
.43375 .48625 Mdot
.765 .54 Mdot
.12 .57 Mdot
.6175 .5325 Mdot
.55375 .46625 Mdot
.5325 .385 Mdot
.64875 .3875 Mdot
.26625 .36375 Mdot
.60125 .3275 Mdot
.44875 .33625 Mdot
.6925 .36875 Mdot
.00375 .3025 Mdot
.8 .28 Mdot
.5025 .29875 Mdot
.5775 .3275 Mdot
.345 .34875 Mdot
.39 .41875 Mdot
.71125 .465 Mdot
.415 .48625 Mdot
.63 .47625 Mdot
.46875 .44375 Mdot
.65 .4125 Mdot
.1675 .5625 Mdot
.29125 .57 Mdot
.23375 .5625 Mdot
.40375 .53875 Mdot
.46625 .5425 Mdot
.465 .53375 Mdot
.425 .52875 Mdot
.46125 .48625 Mdot
.7875 .45 Mdot
.4 .47625 Mdot
.38125 .46 Mdot
.68625 .47 Mdot
.47625 .485 Mdot
.3275 .48875 Mdot
.87625 .4925 Mdot
.11 .6175 Mdot
.48875 .585 Mdot
.60125 .565 Mdot
.48875 .61 Mdot
.59 .59625 Mdot
.67625 .475 Mdot
.36625 .48625 Mdot
.66375 .4675 Mdot
.04 .4425 Mdot
.58625 .41 Mdot
.94125 .4125 Mdot
.07 .42 Mdot
.465 .4925 Mdot
.56625 .58875 Mdot
.43 .665 Mdot
.97 .695 Mdot
.465 .71125 Mdot
.03125 .69625 Mdot
.54875 .62875 Mdot
.49625 .58625 Mdot
.47 .56125 Mdot
.665 .5325 Mdot
.205 .52875 Mdot
.625 .54625 Mdot
.35625 .53875 Mdot
.8525 .53 Mdot
.24 .56875 Mdot
.50125 .5875 Mdot
.52375 .56125 Mdot
.7675 .57375 Mdot
.48375 .55125 Mdot
.30875 .52875 Mdot
.66 .4925 Mdot
.4375 .49625 Mdot
.25375 .4775 Mdot
.5425 .47375 Mdot
.48375 .48 Mdot
.66375 .56625 Mdot
.6225 .5825 Mdot
.65375 .5675 Mdot
.4925 .56625 Mdot
.6475 .6075 Mdot
.79125 .61 Mdot
.24875 .6275 Mdot
.025 .55625 Mdot
.7625 .53625 Mdot
.22125 .50875 Mdot
.90125 .4725 Mdot
.16625 .455 Mdot
.48625 .46625 Mdot
.2525 .45 Mdot
.735 .45125 Mdot
.64375 .48125 Mdot
.69375 .5975 Mdot
.56625 .63875 Mdot
.92 .6575 Mdot
.27875 .6275 Mdot
.1075 .62875 Mdot
.4675 .6225 Mdot
.87 .54625 Mdot
.4275 .5175 Mdot
.43125 .52625 Mdot
.3575 .51125 Mdot
.90125 .4525 Mdot
.29375 .51125 Mdot
.47125 .5425 Mdot
.79625 .5275 Mdot
.68875 .505 Mdot
.35875 .48875 Mdot
.52125 .485 Mdot
.42375 .45875 Mdot
.6275 .4025 Mdot
.425 .40125 Mdot
.4475 .39375 Mdot
.7325 .32625 Mdot
.09125 .355 Mdot
.6775 .4525 Mdot
.53625 .54125 Mdot
.52375 .65125 Mdot
.67 .755 Mdot
.24 .7875 Mdot
.5725 .83 Mdot
.45125 .82625 Mdot
.75125 .75875 Mdot
.83625 .70625 Mdot
.53 .61375 Mdot
.49875 .515 Mdot
.42625 .44375 Mdot
.3675 .3375 Mdot
.6775 .30625 Mdot
.40875 .31375 Mdot
.6975 .3825 Mdot
.3575 .45625 Mdot
.7475 .53625 Mdot
.08125 .5575 Mdot
.36375 .53625 Mdot
.17625 .51 Mdot
.42875 .50625 Mdot
.4775 .4925 Mdot
.4375 .48625 Mdot
.4475 .46 Mdot
.445 .4925 Mdot
.8225 .50125 Mdot
.3725 .46875 Mdot
.3825 .505 Mdot
.6675 .54125 Mdot
.46625 .57 Mdot
.34875 .595 Mdot
.93125 .695 Mdot
.06 .65875 Mdot
.43125 .665 Mdot
.72 .64 Mdot
.42625 .615 Mdot
.55 .53125 Mdot
.7425 .5475 Mdot
.315 .52375 Mdot
.72625 .525 Mdot
0 .52625 Mdot
.59875 .52125 Mdot
.9275 .5 Mdot
.1225 .5125 Mdot
.4125 .475 Mdot
.5025 .4025 Mdot
.52125 .3775 Mdot
.97375 .3975 Mdot
.445 .37 Mdot
.0125 .395 Mdot
.51625 .4775 Mdot
.60125 .55375 Mdot
.35 .59125 Mdot
.69625 .5925 Mdot
.1975 .55375 Mdot
.595 .51375 Mdot
.4 .515 Mdot
.78625 .50875 Mdot
.33125 .48375 Mdot
.455 .46625 Mdot
.59625 .47625 Mdot
.6325 .45875 Mdot
.51125 .49 Mdot
.37125 .55375 Mdot
.6275 .57875 Mdot
.46375 .5725 Mdot
.25125 .5825 Mdot
.50375 .57625 Mdot
.495 .54375 Mdot
.6275 .44 Mdot
.65625 .42 Mdot
.6325 .40375 Mdot
.5125 .40125 Mdot
.63125 .43625 Mdot
.8075 .45625 Mdot
.235 .46 Mdot
.07 .475 Mdot
.74125 .4625 Mdot
.20875 .44625 Mdot
.9125 .45625 Mdot
.16375 .48 Mdot
.49375 .49125 Mdot
.225 .51625 Mdot
.79375 .4975 Mdot
.64875 .34875 Mdot
.95875 .38625 Mdot
.765 .5125 Mdot
.53625 .52125 Mdot
.86875 .52875 Mdot
.345 .5075 Mdot
.05 .525 Mdot
.50625 .5175 Mdot
.88625 .51 Mdot
.43125 .51 Mdot
.395 .49375 Mdot
.35875 .485 Mdot
.88625 .51 Mdot
.37875 .53375 Mdot
.40375 .525 Mdot
.86375 .5725 Mdot
.67875 .58875 Mdot
.33625 .605 Mdot
.435 .625 Mdot
.57875 .655 Mdot
.50125 .68625 Mdot
.50625 .66125 Mdot
.45 .6625 Mdot
.70125 .73 Mdot
.09 .69125 Mdot
.7125 .58375 Mdot
.5125 .54125 Mdot
.51125 .45625 Mdot
.6725 .37125 Mdot
.27625 .3925 Mdot
.55875 .39125 Mdot
.39375 .3775 Mdot
.79625 .415 Mdot
.8425 .37375 Mdot
.51875 .42125 Mdot
.45125 .53 Mdot
.5325 .62125 Mdot
.325 .65125 Mdot
.67 .65875 Mdot
.39875 .6775 Mdot
.72625 .6125 Mdot
.29125 .5525 Mdot
.82125 .53875 Mdot
.02875 .4125 Mdot
.3825 .44625 Mdot
.15375 .4875 Mdot
.445 .4975 Mdot
.50125 .4975 Mdot
.36 .49625 Mdot
.51 .53125 Mdot
.4275 .50375 Mdot
.8625 .615 Mdot
.3125 .65375 Mdot
.40875 .635 Mdot
.65125 .58625 Mdot
.46375 .54625 Mdot
.37375 .39875 Mdot
.94125 .2925 Mdot
.02625 .2525 Mdot
.435 .25125 Mdot
.7975 .2975 Mdot
.3075 .31125 Mdot
.56375 .395 Mdot
.8075 .4525 Mdot
.26375 .4775 Mdot
.7675 .5025 Mdot
.61625 .5125 Mdot
.88125 .51625 Mdot
.18 .51125 Mdot
.3775 .52 Mdot
.4875 .58625 Mdot
.56875 .62 Mdot
.9625 .615 Mdot
.4425 .64875 Mdot
.495 .54625 Mdot
.68625 .4725 Mdot
.29 .43375 Mdot
.75125 .37 Mdot
.19 .415 Mdot
.53125 .4275 Mdot
.48875 .37625 Mdot
.705 .38 Mdot
.3875 .3975 Mdot
.435 .385 Mdot
.67375 .38875 Mdot
.50875 .42125 Mdot
.5375 .38625 Mdot
.40875 .3425 Mdot
.6225 .3225 Mdot
.46125 .34 Mdot
.26125 .37125 Mdot
.47 .4175 Mdot
.525 .46375 Mdot
.60375 .5175 Mdot
.63125 .52125 Mdot
.65125 .54 Mdot
.50375 .5575 Mdot
.63625 .54125 Mdot
.80375 .52 Mdot
.21625 .5 Mdot
.10625 .515 Mdot
.7125 .50375 Mdot
.21625 .54375 Mdot
.89875 .58875 Mdot
.1775 .58875 Mdot
.48125 .57625 Mdot
.23875 .5825 Mdot
.84375 .6 Mdot
.655 .70375 Mdot
.82125 .55375 Mdot
.82 .40875 Mdot
.4875 .40875 Mdot
.87375 .4075 Mdot
.3775 .44375 Mdot
.56875 .49875 Mdot
.8575 .545 Mdot
.49 .5625 Mdot
.28375 .57875 Mdot
.46875 .55625 Mdot
.77875 .555 Mdot
.41875 .51 Mdot
.36125 .4875 Mdot
.90875 .42 Mdot
.68125 .38375 Mdot
.3075 .3675 Mdot
.39 .35375 Mdot
.67625 .35125 Mdot
.43125 .38875 Mdot
.54375 .40875 Mdot
.42375 .41125 Mdot
.70125 .3925 Mdot
.10875 .4125 Mdot
.71 .4625 Mdot
.5475 .4625 Mdot
.4475 .535 Mdot
.7075 .54375 Mdot
.32375 .49375 Mdot
.4775 .46125 Mdot
.42125 .47625 Mdot
.8075 .43 Mdot
.835 .55375 Mdot
.5725 .59375 Mdot
.36 .54625 Mdot
.60875 .48625 Mdot
.32125 .53625 Mdot
.6525 .53125 Mdot
.39875 .45 Mdot
.76125 .46 Mdot
.2225 .50375 Mdot
.8875 .45125 Mdot
.02875 .5575 Mdot
.3875 .52375 Mdot
.12 .4925 Mdot
.4675 .4875 Mdot
.5275 .49 Mdot
.30375 .49375 Mdot
.5425 .48875 Mdot
.40375 .5 Mdot
.9175 .395 Mdot
.2625 .36375 Mdot
.46125 .3475 Mdot
.565 .34625 Mdot
.5325 .34125 Mdot
.32375 .455 Mdot
.98625 .4825 Mdot
.50625 .52375 Mdot
.74875 .54125 Mdot
.2875 .53875 Mdot
.57375 .52625 Mdot
.83375 .515 Mdot
.2525 .5 Mdot
.77375 .48625 Mdot
.6575 .495 Mdot
.805 .49625 Mdot
.22875 .47875 Mdot
.35625 .425 Mdot
.50375 .36625 Mdot
.59 .34375 Mdot
.93125 .32875 Mdot
.45375 .3325 Mdot
.44 .4225 Mdot
.7825 .455 Mdot
.22 .4725 Mdot
.77 .49375 Mdot
.18 .465 Mdot
.4875 .49125 Mdot
.55875 .565 Mdot
.65875 .5925 Mdot
.42125 .6225 Mdot
.41875 .6675 Mdot
.715 .65625 Mdot
.40125 .6025 Mdot
.62625 .635 Mdot
.37125 .64875 Mdot
.65875 .6675 Mdot
.4525 .67875 Mdot
.25 .66125 Mdot
.4675 .59375 Mdot
.52125 .55375 Mdot
.59875 .52375 Mdot
.63375 .51375 Mdot
.65375 .53 Mdot
.51875 .515 Mdot
.59375 .49125 Mdot
.84375 .5175 Mdot
.1925 .50875 Mdot
.11 .52625 Mdot
.70875 .5625 Mdot
.23375 .545 Mdot
.86 .475 Mdot
.23375 .44875 Mdot
.445 .42375 Mdot
.2375 .35 Mdot
.905 .3225 Mdot
.95125 .33375 Mdot
.64875 .34 Mdot
.69875 .5075 Mdot
.83 .56 Mdot
.43625 .54 Mdot
.905 .54 Mdot
.3875 .53125 Mdot
.6275 .4075 Mdot
.805 .3675 Mdot
.5125 .3525 Mdot
.24375 .30875 Mdot
.56 .3825 Mdot
.64375 .41125 Mdot
.12 .40375 Mdot
.465 .44625 Mdot
.33625 .43625 Mdot
.9075 .4475 Mdot
.68125 .50125 Mdot
.3225 .46875 Mdot
.3575 .455 Mdot
.72625 .43625 Mdot
.39875 .38625 Mdot
.54 .32 Mdot
.44875 .3225 Mdot
.62875 .32625 Mdot
.2 .31125 Mdot
.71125 .3275 Mdot
.46125 .34 Mdot
.51625 .325 Mdot
.67625 .345 Mdot
.35625 .41 Mdot
.4375 .4675 Mdot
.44625 .5425 Mdot
.79375 .62625 Mdot
.7825 .57125 Mdot
.62375 .53375 Mdot
.2825 .48625 Mdot
.68875 .4725 Mdot
.31625 .455 Mdot
.60375 .4525 Mdot
.4225 .51 Mdot
.77125 .535 Mdot
.20625 .51625 Mdot
.8825 .53 Mdot
.055 .43875 Mdot
.37375 .44875 Mdot
.10375 .4625 Mdot
.46875 .46125 Mdot
.57375 .47375 Mdot
.23375 .48375 Mdot
.55 .48875 Mdot
.43 .48 Mdot
.97 .5025 Mdot
.16 .50125 Mdot
.57 .52375 Mdot
.445 .54125 Mdot
.57625 .55 Mdot
.32625 .5475 Mdot
.99125 .55875 Mdot
.0075 .51625 Mdot
.45 .49375 Mdot
.81375 .475 Mdot
.27875 .46 Mdot
.55625 .4575 Mdot
.82625 .4625 Mdot
.2525 .46625 Mdot
.765 .48 Mdot
.6925 .4675 Mdot
.71125 .4625 Mdot
.275 .49 Mdot
.3375 .52 Mdot
.51875 .52125 Mdot
.6175 .51625 Mdot
.93375 .52875 Mdot
.42125 .4925 Mdot
.42 .44875 Mdot
.82625 .45 Mdot
.21625 .45125 Mdot
.82125 .5325 Mdot
.14375 .55625 Mdot
.4275 .5575 Mdot
.6325 .52 Mdot
.61875 .47 Mdot
.46 .40125 Mdot
.41625 .3525 Mdot
.74375 .3675 Mdot
.26125 .40125 Mdot
.73125 .42 Mdot
.3575 .4175 Mdot
.6625 .42375 Mdot
.42875 .3825 Mdot
.3125 .3975 Mdot
.43125 .415 Mdot
.5175 .45125 Mdot
.59625 .50375 Mdot
.64 .51375 Mdot
.62875 .495 Mdot
.53375 .475 Mdot
.0225 .45 Mdot
.5375 .44875 Mdot
.86375 .445 Mdot
.1875 .4725 Mdot
.115 .47875 Mdot
.7225 .46875 Mdot
.22125 .4675 Mdot
.81 .48 Mdot
.30625 .49375 Mdot
.38875 .50625 Mdot
.2875 .5375 Mdot
.92875 .55 Mdot
.8075 .57 Mdot
.1475 .585 Mdot
.61625 .59625 Mdot
.535 .53375 Mdot
.79125 .455 Mdot
.4325 .47 Mdot
.9225 .46 Mdot
.36125 .50875 Mdot
.65625 .5725 Mdot
.81375 .5825 Mdot
.4525 .60875 Mdot
.275 .595 Mdot
.6025 .6 Mdot
.5275 .57875 Mdot
.25 .615 Mdot
.51 .55625 Mdot
.3725 .57875 Mdot
.8275 .57875 Mdot
.72 .59375 Mdot
.3025 .63625 Mdot
.3825 .6875 Mdot
.72875 .735 Mdot
.4125 .77 Mdot
.4875 .7975 Mdot
.48375 .78875 Mdot
.595 .735 Mdot
.2625 .715 Mdot
.67 .655 Mdot
.47625 .615 Mdot
.53625 .565 Mdot
.60375 .53375 Mdot
.4625 .49125 Mdot
.32125 .47875 Mdot
.5175 .43 Mdot
.78375 .39125 Mdot
.73125 .4575 Mdot
.62875 .4475 Mdot
.27125 .49625 Mdot
.73125 .53375 Mdot
.30875 .52625 Mdot
.56875 .52125 Mdot
.50875 .525 Mdot
.70875 .48875 Mdot
.19125 .4925 Mdot
.89125 .48375 Mdot
.08625 .59125 Mdot
.3675 .57125 Mdot
.09875 .57 Mdot
.49125 .5825 Mdot
.57875 .5825 Mdot
.17625 .57125 Mdot
.6075 .56 Mdot
.42875 .56 Mdot
.975 .545 Mdot
.11 .56875 Mdot
.60375 .595 Mdot
.46 .60375 Mdot
.555 .61125 Mdot
.36125 .57125 Mdot
.94 .57375 Mdot
.03375 .59125 Mdot
.41125 .57875 Mdot
.85625 .56875 Mdot
.31375 .605 Mdot
.5025 .5975 Mdot
.805 .56875 Mdot
.28 .58375 Mdot
.77 .55625 Mdot
.00375 .55 Mdot
.72 .51 Mdot
.64875 .48875 Mdot
.29375 .45875 Mdot
.32375 .47875 Mdot
.55625 .5 Mdot
.595 .48875 Mdot
.96375 .49625 Mdot
.41125 .5275 Mdot
.36375 .56375 Mdot
.91125 .57125 Mdot
.185 .58375 Mdot
.82625 .525 Mdot
.1625 .52375 Mdot
.34375 .52125 Mdot
.675 .54375 Mdot
.655 .595 Mdot
.46625 .62875 Mdot
.3675 .64625 Mdot
.7775 .63625 Mdot
.16 .62 Mdot
.83625 .56 Mdot
.34 .555 Mdot
.68375 .5525 Mdot
.3775 .56875 Mdot
.35125 .53875 Mdot
.4175 .56875 Mdot
.4775 .535 Mdot
.595 .475 Mdot
.62875 .45875 Mdot
.59125 .47875 Mdot
.55125 .505 Mdot
.02625 .54875 Mdot
.56125 .5675 Mdot
.84 .56125 Mdot
.2075 .535 Mdot
.08 .50125 Mdot
.73875 .48875 Mdot
.22125 .49375 Mdot
.79875 .535 Mdot
.30875 .55125 Mdot
.35625 .5825 Mdot
.35 .6225 Mdot
.95375 .62375 Mdot
.68 .56875 Mdot
.2625 .52375 Mdot
.585 .46625 Mdot
.395 .42375 Mdot
.7525 .5375 Mdot
.45 .51375 Mdot
.92625 .49375 Mdot
.35 .4525 Mdot
.67375 .46125 Mdot
.82875 .48375 Mdot
.4075 .475 Mdot
.29875 .5175 Mdot
.63 .4725 Mdot
.44625 .46375 Mdot
.4275 .4275 Mdot
.5425 .46 Mdot
.485 .46125 Mdot
.69875 .47125 Mdot
.76 .44875 Mdot
.2825 .425 Mdot
.42875 .41125 Mdot
.6875 .39 Mdot
.45625 .38375 Mdot
.43 .4025 Mdot
.4825 .4275 Mdot
.5775 .465 Mdot
.36125 .48875 Mdot
.6125 .575 Mdot
.495 .65125 Mdot
.525 .66875 Mdot
.59 .6675 Mdot
.48 .675 Mdot
.26375 .5975 Mdot
.6275 .5675 Mdot
.71625 .5625 Mdot
.03375 .54125 Mdot
.67125 .5175 Mdot
.64375 .54 Mdot
.285 .50875 Mdot
.6475 .4675 Mdot
.40125 .435 Mdot
.59375 .4325 Mdot
.49125 .445 Mdot
.6475 .47125 Mdot
.27625 .495 Mdot
.8275 .54375 Mdot
.1375 .4625 Mdot
.3325 .51125 Mdot
.095 .53 Mdot
.4875 .515 Mdot
.56625 .47875 Mdot
.23125 .46625 Mdot
.54375 .46 Mdot
.45375 .45875 Mdot
.97125 .445 Mdot
.12125 .4325 Mdot
.575 .37875 Mdot
.46875 .36 Mdot
.5625 .35625 Mdot
.39875 .4275 Mdot
.89875 .42125 Mdot
.04375 .4625 Mdot
.39875 .515 Mdot
.87125 .55625 Mdot
.3125 .53625 Mdot
.52 .5625 Mdot
.775 .57375 Mdot
.30375 .55125 Mdot
.72375 .55375 Mdot
.05875 .56375 Mdot
.7225 .61 Mdot
.6075 .65125 Mdot
.31 .67125 Mdot
.28875 .64875 Mdot
.63875 .64 Mdot
.53625 .66375 Mdot
.96375 .6625 Mdot
.4325 .645 Mdot
.36125 .6 Mdot
.9625 .55125 Mdot
.1675 .50125 Mdot
.815 .4725 Mdot
.145 .45625 Mdot
.32 .44125 Mdot
.6825 .42875 Mdot
.6675 .40375 Mdot
.495 .415 Mdot
.3175 .4175 Mdot
.82375 .41375 Mdot
.08125 .42 Mdot
.92625 .42875 Mdot
.30625 .39125 Mdot
.67 .38 Mdot
.3775 .38375 Mdot
.37125 .385 Mdot
.41375 .37125 Mdot
.465 .42125 Mdot
.59625 .51625 Mdot
.605 .5575 Mdot
.54375 .54625 Mdot
.6275 .5425 Mdot
.63 .47125 Mdot
.7875 .4525 Mdot
.2325 .4525 Mdot
.07 .465 Mdot
.75625 .4675 Mdot
.18625 .44 Mdot
.82875 .3825 Mdot
.285 .35625 Mdot
.38625 .32625 Mdot
.36125 .295 Mdot
.9675 .315 Mdot
.58375 .35875 Mdot
.3425 .40625 Mdot
.58 .4675 Mdot
.31375 .5175 Mdot
.07 .44375 Mdot
.69375 .44375 Mdot
.45375 .475 Mdot
.96375 .50125 Mdot
.29875 .4725 Mdot
.64125 .4875 Mdot
.8125 .5 Mdot
.47125 .5025 Mdot
.32375 .54375 Mdot
.58125 .52375 Mdot
.42375 .535 Mdot
.52125 .495 Mdot
.895 .4825 Mdot
.50625 .45 Mdot
.59375 .45 Mdot
.59875 .4725 Mdot
.7725 .4825 Mdot
.3025 .4675 Mdot
.43625 .4725 Mdot
.685 .455 Mdot
.4675 .44375 Mdot
.3875 .4475 Mdot
.4825 .4475 Mdot
.5775 .42875 Mdot
.38875 .44875 Mdot
.5925 .405 Mdot
.51875 .345 Mdot
.4975 .35125 Mdot
.59625 .395 Mdot
.47375 .40875 Mdot
.20875 .47375 Mdot
.77125 .495 Mdot
.62625 .49375 Mdot
.055 .425 Mdot
.66125 .37875 Mdot
.67875 .325 Mdot
.2725 .345 Mdot
.55125 .35875 Mdot
.53375 .405 Mdot
.53875 .4225 Mdot
.5125 .435 Mdot
.645 .43375 Mdot
.195 .43625 Mdot
.875 .44 Mdot
.145 .475 Mdot
.3425 .4375 Mdot
.09625 .3975 Mdot
.50375 .3575 Mdot
.5275 .38375 Mdot
.30625 .41375 Mdot
.48375 .3975 Mdot
.45875 .4025 Mdot
.9725 .4725 Mdot
.1575 .49 Mdot
.53875 .5075 Mdot
.505 .5775 Mdot
.52125 .6175 Mdot
.41625 .5675 Mdot
.90375 .5525 Mdot
.0225 .50125 Mdot
.4175 .43875 Mdot
.89 .38125 Mdot
.25875 .34375 Mdot
.5675 .3 Mdot
.74875 .31875 Mdot
.3375 .30625 Mdot
.67875 .3025 Mdot
.08125 .32125 Mdot
.74625 .32625 Mdot
.56625 .305 Mdot
.3125 .32375 Mdot
.27875 .35 Mdot
.70875 .3725 Mdot
.49375 .3925 Mdot
.955 .41125 Mdot
.4225 .41125 Mdot
.355 .43125 Mdot
.105 .495 Mdot
.0025 .5075 Mdot
.77125 .54 Mdot
.13125 .55125 Mdot
.31 .56 Mdot
.71 .57625 Mdot
.655 .5775 Mdot
.5425 .5475 Mdot
.28125 .54875 Mdot
.81875 .54125 Mdot
.04375 .5475 Mdot
.96625 .58125 Mdot
.335 .67125 Mdot
.625 .68125 Mdot
.36 .6975 Mdot
.42 .6875 Mdot
.41125 .6225 Mdot
.4225 .53 Mdot
.55875 .39875 Mdot
.68625 .39125 Mdot
.46625 .3475 Mdot
.695 .34625 Mdot
.7075 .4075 Mdot
.73625 .46125 Mdot
.24125 .54125 Mdot
.035 .57125 Mdot
.80375 .585 Mdot
.1275 .6 Mdot
.89 .655 Mdot
.255 .67625 Mdot
.395 .6925 Mdot
.3675 .715 Mdot
.98 .7 Mdot
.52625 .65125 Mdot
.35875 .6375 Mdot
.6125 .6075 Mdot
.27625 .54 Mdot
.15375 .49875 Mdot
.64875 .45375 Mdot
.445 .42125 Mdot
.98625 .40875 Mdot
.27125 .425 Mdot
.0175 .40625 Mdot
.53875 .425 Mdot
.92875 .40375 Mdot
.45 .37 Mdot
.37875 .34875 Mdot
.48875 .415 Mdot
.47875 .445 Mdot
.54 .5175 Mdot
.78875 .57625 Mdot
.51875 .57375 Mdot
.70875 .5675 Mdot
.49 .5475 Mdot
.7975 .565 Mdot
.2975 .5975 Mdot
.45125 .58125 Mdot
.67375 .60625 Mdot
.48 .62 Mdot
.345 .57875 Mdot
.51125 .54375 Mdot
.56 .55375 Mdot
.43625 .5275 Mdot
.54 .52 Mdot
.5525 .57375 Mdot
.5175 .58375 Mdot
.56125 .5225 Mdot
.43125 .485 Mdot
.21625 .46875 Mdot
.8425 .43875 Mdot
.57375 .43875 Mdot
.10875 .5375 Mdot
.6275 .65875 Mdot
.6425 .6875 Mdot
.32125 .6475 Mdot
.51625 .67 Mdot
.59 .655 Mdot
.50125 .5525 Mdot
.51125 .52875 Mdot
.63375 .5625 Mdot
.24125 .52875 Mdot
.84 .49 Mdot
.0825 .4275 Mdot
.38125 .475 Mdot
.105 .495 Mdot
.50125 .605 Mdot
.49875 .6175 Mdot
.33125 .59 Mdot
.49875 .59875 Mdot
.4525 .65375 Mdot
.9475 .535 Mdot
.19 .4625 Mdot
.48375 .4175 Mdot
.5875 .33125 Mdot
.44375 .2425 Mdot
.515 .24625 Mdot
.81 .2875 Mdot
.0625 .35125 Mdot
.3675 .38125 Mdot
.97125 .42875 Mdot
.22875 .4925 Mdot
.565 .5425 Mdot
.7275 .53 Mdot
.3275 .595 Mdot
.70375 .6175 Mdot
.09 .59375 Mdot
.77125 .57875 Mdot
.525 .59125 Mdot
.31625 .57875 Mdot
.25125 .555 Mdot
.77 .50375 Mdot
.46125 .45 Mdot
.94 .38125 Mdot
.46 .37625 Mdot
.36875 .41625 Mdot
.08625 .48 Mdot
.1125 .47125 Mdot
.74625 .44625 Mdot
.11 .4525 Mdot
.295 .4325 Mdot
.73375 .40375 Mdot
.6175 .40875 Mdot
.60875 .42 Mdot
.2525 .4375 Mdot
.80875 .475 Mdot
.05375 .47875 Mdot
.94 .48 Mdot
.3725 .445 Mdot
.62 .41875 Mdot
.31875 .39125 Mdot
.44375 .4175 Mdot
.44375 .5125 Mdot
.37875 .6 Mdot
.4975 .71125 Mdot
.67875 .67625 Mdot
.49 .69875 Mdot
.71625 .685 Mdot
.77 .65625 Mdot
.64125 .585 Mdot
.2975 .49125 Mdot
.02875 .415 Mdot
.82375 .4025 Mdot
.0775 .39875 Mdot
.95625 .37875 Mdot
.20875 .37625 Mdot
.38625 .38375 Mdot
.41875 .36375 Mdot
.95625 .38375 Mdot
.51 .4225 Mdot
.35875 .42125 Mdot
.615 .41375 Mdot
.24625 .4875 Mdot
.2325 .59625 Mdot
.63125 .63875 Mdot
.41875 .6675 Mdot
.2525 .68875 Mdot
.04625 .55 Mdot
.44125 .49375 Mdot
.35375 .48625 Mdot
.45125 .47625 Mdot
.4175 .5175 Mdot
.565 .475 Mdot
.4875 .42 Mdot
.7575 .38625 Mdot
.59125 .39 Mdot
.7325 .40375 Mdot
.44375 .39125 Mdot
.8075 .37 Mdot
.295 .37375 Mdot
.4775 .3675 Mdot
.62 .37625 Mdot
.52375 .37125 Mdot
.30375 .42875 Mdot
.545 .44375 Mdot
.55375 .465 Mdot
.39375 .45375 Mdot
.59875 .4375 Mdot
.52625 .34125 Mdot
.4975 .31375 Mdot
.6 .3075 Mdot
.4475 .32625 Mdot
.16 .3375 Mdot
.91 .3625 Mdot
.4925 .38625 Mdot
.12375 .38 Mdot
.67 .33375 Mdot
.6075 .39125 Mdot
.38625 .51 Mdot
.425 .535 Mdot
.67625 .56125 Mdot
.47625 .71625 Mdot
.50875 .665 Mdot
.60375 .55875 Mdot
.24125 .54125 Mdot
.8975 .51 Mdot
.01125 .6325 Mdot
.44125 .56 Mdot
.18 .50875 Mdot
.48875 .41375 Mdot
.4775 .40625 Mdot
.33375 .42 Mdot
.52375 .42 Mdot
.43625 .37 Mdot
.92625 .4625 Mdot
.25 .55125 Mdot
.3875 .6525 Mdot
.67875 .70125 Mdot
.38125 .76625 Mdot
.605 .775 Mdot
.7075 .72375 Mdot
.075 .65375 Mdot
.39875 .645 Mdot
.95 .60375 Mdot
.235 .5575 Mdot
.59625 .52375 Mdot
.68625 .51875 Mdot
.36125 .47 Mdot
.735 .47625 Mdot
.0225 .4775 Mdot
.80625 .4575 Mdot
.5 .4225 Mdot
.3275 .4225 Mdot
.22875 .43375 Mdot
.8375 .4675 Mdot
.45625 .495 Mdot
.85875 .54875 Mdot
.5175 .5625 Mdot
.39625 .53125 Mdot
.05 .54125 Mdot
.18375 .53875 Mdot
.71875 .5525 Mdot
.1 .5375 Mdot
.29625 .53125 Mdot
.75125 .53 Mdot
.55375 .535 Mdot
.67375 .5225 Mdot
.24875 .495 Mdot
.77 .4625 Mdot
.1075 .4625 Mdot
.8975 .45 Mdot
.395 .41375 Mdot
.63 .4125 Mdot
.2775 .41625 Mdot
.44125 .3925 Mdot
.5125 .35375 Mdot
.32625 .35625 Mdot
.48625 .32625 Mdot
.57125 .35375 Mdot
.69875 .38375 Mdot
.515 .44875 Mdot
.86 .4375 Mdot
.5475 .46625 Mdot
.33 .485 Mdot
.9975 .4875 Mdot
.035 .52625 Mdot
.8325 .5525 Mdot
.06625 .5875 Mdot
.985 .6025 Mdot
.19375 .6025 Mdot
.38 .58375 Mdot
.4075 .58375 Mdot
.975 .51625 Mdot
.5 .5025 Mdot
.34 .5075 Mdot
.61875 .515 Mdot
.26125 .4625 Mdot
.26625 .42625 Mdot
.64375 .43125 Mdot
.40875 .43875 Mdot
.98 .4275 Mdot
.28375 .4275 Mdot
.0525 .54375 Mdot
.3825 .59375 Mdot
.295 .58375 Mdot
.52 .6025 Mdot
.34625 .535 Mdot
.66375 .5675 Mdot
.41125 .59375 Mdot
.72375 .58625 Mdot
.62625 .56 Mdot
.69125 .54125 Mdot
.50625 .565 Mdot
.785 .5975 Mdot
.2375 .59375 Mdot
.55 .60625 Mdot
.5675 .5675 Mdot
.51125 .56125 Mdot
.33375 .51125 Mdot
.565 .5275 Mdot
.48875 .4975 Mdot
.445 .52 Mdot
.59625 .5575 Mdot
.5125 .64375 Mdot
.49 .645 Mdot
.64375 .72 Mdot
.435 .7275 Mdot
.075 .705 Mdot
.41375 .705 Mdot
.1475 .625 Mdot
.6625 .57875 Mdot
.63125 .5425 Mdot
.4075 .445 Mdot
.3675 .3875 Mdot
.645 .36625 Mdot
.5775 .27375 Mdot
.4725 .33625 Mdot
.5575 .4275 Mdot
.27 .46625 Mdot
.94125 .535 Mdot
.49875 .5225 Mdot
.26 .5925 Mdot
.4475 .6075 Mdot
.47375 .61125 Mdot
.37125 .61125 Mdot
.4825 .62625 Mdot
.43125 .6025 Mdot
.94 .5725 Mdot
.30125 .5375 Mdot
.2675 .465 Mdot
.74375 .4675 Mdot
.385 .445 Mdot
.6325 .455 Mdot
.64 .46875 Mdot
.08375 .505 Mdot
.495 .49375 Mdot
.93875 .5325 Mdot
.13 .57375 Mdot
.66625 .57375 Mdot
.6625 .565 Mdot
.36 .555 Mdot
.77125 .5175 Mdot
.81625 .56125 Mdot
.51125 .5975 Mdot
.3075 .58125 Mdot
.2075 .585 Mdot
.88875 .5625 Mdot
.45875 .54375 Mdot
.8075 .52 Mdot
.52625 .51625 Mdot
.4375 .4975 Mdot
.0325 .385 Mdot
.28375 .4175 Mdot
.67375 .43625 Mdot
.0725 .47625 Mdot
.32625 .5125 Mdot
.76625 .52 Mdot
.47875 .5075 Mdot
.75375 .49375 Mdot
.22625 .51 Mdot
.75625 .52875 Mdot
.14125 .5175 Mdot
.855 .51625 Mdot
.4225 .57125 Mdot
.63625 .57 Mdot
.2275 .57875 Mdot
.4675 .615 Mdot
.5775 .62625 Mdot
.2675 .5925 Mdot
.48875 .4775 Mdot
.49 .38375 Mdot
.835 .3275 Mdot
.395 .24 Mdot
.06 .28125 Mdot
.83125 .34125 Mdot
.51375 .4025 Mdot
.32875 .4375 Mdot
.08 .48375 Mdot
.81 .4775 Mdot
.0725 .48125 Mdot
.97625 .46375 Mdot
.21125 .47125 Mdot
.3375 .47625 Mdot
.44875 .50125 Mdot
.9675 .55625 Mdot
.45875 .5525 Mdot
.38625 .53125 Mdot
.6 .5275 Mdot
.275 .525 Mdot
.28375 .53875 Mdot
.66625 .535 Mdot
.39 .50875 Mdot
.9675 .495 Mdot
.3 .53 Mdot
.04125 .5975 Mdot
.36 .59625 Mdot
.2575 .60625 Mdot
.58125 .5725 Mdot
.2875 .47125 Mdot
.74375 .4325 Mdot
.28625 .42875 Mdot
.8025 .47 Mdot
.64375 .525 Mdot
.65 .53125 Mdot
.59875 .53125 Mdot
.72 .47625 Mdot
.19625 .46125 Mdot
.6625 .45625 Mdot
.41875 .4725 Mdot
.5675 .48125 Mdot
.3675 .5175 Mdot
.56375 .48625 Mdot
.4975 .5075 Mdot
.3925 .48375 Mdot
.63125 .4275 Mdot
.47 .3525 Mdot
.53875 .415 Mdot
.635 .385 Mdot
.44875 .42875 Mdot
.01625 .47375 Mdot
.37125 .38875 Mdot
.17375 .39875 Mdot
.66625 .39625 Mdot
.60875 .37875 Mdot
.38375 .42375 Mdot
.465 .47 Mdot
.58375 .485 Mdot
.5225 .525 Mdot
.53125 .51875 Mdot
.55375 .53375 Mdot
.24 .5325 Mdot
.56625 .4925 Mdot
.9775 .5025 Mdot
.3325 .4875 Mdot
.4525 .49375 Mdot
.45375 .50625 Mdot
.32 .5125 Mdot
.5675 .51625 Mdot
.40125 .55 Mdot
.9275 .54625 Mdot
.31875 .54625 Mdot
.2425 .5575 Mdot
.76875 .53625 Mdot
.35 .52125 Mdot
.69 .50625 Mdot
.57125 .52625 Mdot
.055 .49 Mdot
.6475 .46375 Mdot
.86875 .41875 Mdot
.10125 .36875 Mdot
.67125 .35875 Mdot
.64 .42875 Mdot
.36875 .485 Mdot
.83125 .51125 Mdot
.805 .4925 Mdot
.52625 .44 Mdot
.31625 .435 Mdot
.20875 .465 Mdot
.87125 .51 Mdot
.51125 .555 Mdot
.76625 .59125 Mdot
.5075 .60625 Mdot
.42375 .58375 Mdot
.0375 .62625 Mdot
.365 .5925 Mdot
.61 .57875 Mdot
.0725 .5425 Mdot
.35875 .5225 Mdot
.75625 .52125 Mdot
.42625 .5225 Mdot
.82 .53 Mdot
.21375 .4975 Mdot
.72625 .47875 Mdot
.16625 .48625 Mdot
.79625 .47 Mdot
.50375 .42875 Mdot
.61875 .4375 Mdot
.18875 .43625 Mdot
.4775 .42375 Mdot
.6425 .42375 Mdot
.2525 .43875 Mdot
.48375 .64 Mdot
.43375 .70875 Mdot
.9175 .73125 Mdot
.33 .73625 Mdot
.1425 .72375 Mdot
.795 .62125 Mdot
.48 .58625 Mdot
.35 .585 Mdot
1 .5625 Mdot
.0925 .54625 Mdot
.78875 .5125 Mdot
.105 .48375 Mdot
.9625 .49625 Mdot
.25125 .4875 Mdot
.255 .47125 Mdot
.47875 .4575 Mdot
.98875 .44875 Mdot
.44125 .42875 Mdot
.38375 .44625 Mdot
.60875 .445 Mdot
.2725 .50875 Mdot
.3125 .495 Mdot
.6425 .46375 Mdot
.38125 .46125 Mdot
.96375 .47125 Mdot
.30625 .475 Mdot
.03 .44125 Mdot
.395 .4525 Mdot
.0325 .51125 Mdot
.6725 .5275 Mdot
.31125 .58125 Mdot
.79375 .575 Mdot
.1775 .55875 Mdot
.89875 .535 Mdot
.71375 .50875 Mdot
.61875 .585 Mdot
.66375 .58375 Mdot
.6825 .6025 Mdot
.13625 .64625 Mdot
.74875 .62625 Mdot
.30625 .5875 Mdot
.62625 .5975 Mdot
.3725 .56 Mdot
.60625 .59625 Mdot
.43875 .60625 Mdot
.42625 .65 Mdot
.60625 .69625 Mdot
.4575 .79375 Mdot
.59 .75375 Mdot
.5975 .755 Mdot
.47625 .715 Mdot
.31875 .75375 Mdot
.20375 .795 Mdot
.64625 .80875 Mdot
.62125 .82375 Mdot
.3725 .72625 Mdot
.54625 .67625 Mdot
.47875 .6225 Mdot
.55125 .56625 Mdot
.55875 .51625 Mdot
.5075 .505 Mdot
.35 .4975 Mdot
.94 .51625 Mdot
.59875 .49875 Mdot
.92625 .47625 Mdot
.41625 .44 Mdot
.4275 .45125 Mdot
.41 .44 Mdot
.31375 .42625 Mdot
.62875 .41 Mdot
.37875 .4125 Mdot
.90375 .4375 Mdot
.3575 .40875 Mdot
.19625 .40875 Mdot
.7675 .405 Mdot
.33875 .395 Mdot
.8025 .325 Mdot
.45875 .33875 Mdot
.045 .42625 Mdot
.745 .51875 Mdot
.83125 .59375 Mdot
.10375 .68 Mdot
.635 .68875 Mdot
.6325 .575 Mdot
.36875 .5 Mdot
.88125 .46375 Mdot
.76875 .5 Mdot
.57375 .56125 Mdot
.325 .5825 Mdot
.14875 .54625 Mdot
.87375 .5175 Mdot
.5725 .4675 Mdot
.745 .44 Mdot
.4925 .44 Mdot
.42 .48625 Mdot
.09 .51 Mdot
.93125 .49625 Mdot
.445 .47625 Mdot
.5975 .46375 Mdot
.04625 .47 Mdot
.3875 .46125 Mdot
.73875 .47875 Mdot
.38625 .485 Mdot
.8925 .505 Mdot
.17375 .53375 Mdot
.715 .5325 Mdot
.20125 .5275 Mdot
.76375 .5575 Mdot
.56625 .58875 Mdot
.5525 .60375 Mdot
.2175 .6325 Mdot
.445 .625 Mdot
.69625 .5825 Mdot
.25375 .5425 Mdot
.52125 .44 Mdot
.30875 .51125 Mdot
.99625 .58375 Mdot
.29625 .62625 Mdot
.2175 .54625 Mdot
.7575 .6025 Mdot
.47875 .52375 Mdot
.35375 .4525 Mdot
.98875 .4275 Mdot
.12125 .4225 Mdot
.7275 .4575 Mdot
.14375 .48 Mdot
.96375 .46375 Mdot
.2725 .47 Mdot
.19375 .48 Mdot
.53875 .4675 Mdot
.975 .47125 Mdot
.4075 .51 Mdot
.44875 .515 Mdot
.52875 .51875 Mdot
.26875 .4475 Mdot
.28375 .4425 Mdot
.6475 .4775 Mdot
.385 .5 Mdot
.9475 .49375 Mdot
.31625 .485 Mdot
.0025 .47125 Mdot
.46 .4525 Mdot
.725 .37 Mdot
.355 .3775 Mdot
.81875 .41625 Mdot
.0575 .46375 Mdot
.75125 .5225 Mdot
.57375 .4425 Mdot
.755 .41625 Mdot
.62375 .46875 Mdot
.09 .415 Mdot
.85125 .395 Mdot
.18875 .44125 Mdot
.66625 .4225 Mdot
.3925 .43375 Mdot
.60625 .43625 Mdot
.44625 .4425 Mdot
.41375 .3975 Mdot
.59 .4075 Mdot
.4625 .325 Mdot
.61 .2975 Mdot
.6 .25375 Mdot
.515 .22625 Mdot
.2575 .265 Mdot
.23875 .31 Mdot
.64625 .36 Mdot
.65 .3875 Mdot
.37375 .51 Mdot
.53625 .515 Mdot
.45125 .53625 Mdot
.55625 .58375 Mdot
.63125 .615 Mdot
.43375 .55375 Mdot
.3425 .5525 Mdot
.985 .52125 Mdot
.59375 .48 Mdot
.86875 .5275 Mdot
.46625 .5425 Mdot
.42125 .53 Mdot
.35625 .5175 Mdot
.385 .53875 Mdot
.61 .53375 Mdot
.38875 .52125 Mdot
.885 .52375 Mdot
.375 .555 Mdot
.17375 .5275 Mdot
.67875 .52625 Mdot
.455 .57875 Mdot
.8025 .6275 Mdot
.43125 .6225 Mdot
.0525 .585 Mdot
.775 .55375 Mdot
.81375 .5125 Mdot
.06625 .4775 Mdot
.65625 .4725 Mdot
.60625 .53625 Mdot
.39625 .57375 Mdot
.9175 .5725 Mdot
.7675 .46375 Mdot
.59125 .4475 Mdot
.33625 .40625 Mdot
.12 .3925 Mdot
.87875 .4025 Mdot
.6125 .4225 Mdot
.7275 .3975 Mdot
.45625 .39 Mdot
.37125 .4075 Mdot
.1175 .45875 Mdot
.885 .5025 Mdot
.50375 .54 Mdot
.53375 .56 Mdot
.05 .55875 Mdot
.4125 .56 Mdot
.75375 .55375 Mdot
.33875 .56625 Mdot
.94625 .555 Mdot
.15375 .55375 Mdot
.68625 .52625 Mdot
.2175 .49625 Mdot
.73625 .44625 Mdot
.6525 .40375 Mdot
.47875 .3575 Mdot
.245 .3175 Mdot
.43625 .34 Mdot
.71875 .4125 Mdot
.26625 .46625 Mdot
.57125 .505 Mdot
.25375 .43 Mdot
.98875 .3675 Mdot
.255 .35625 Mdot
.29 .395 Mdot
.715 .45625 Mdot
.50375 .52875 Mdot
.33875 .56875 Mdot
.11875 .5625 Mdot
.66625 .53125 Mdot
.2075 .50125 Mdot
.92625 .515 Mdot
.305 .51 Mdot
.1575 .525 Mdot
.57625 .545 Mdot
.9725 .53375 Mdot
.375 .52375 Mdot
.4875 .53125 Mdot
.5025 .5425 Mdot
.25375 .52625 Mdot
.2275 .53 Mdot
.655 .54125 Mdot
.4275 .53 Mdot
.88625 .50375 Mdot
.33875 .4925 Mdot
.5375 .49375 Mdot
.7325 .55625 Mdot
.39 .56875 Mdot
.78625 .56375 Mdot
.03125 .5375 Mdot
.74625 .4825 Mdot
.57 .47375 Mdot
.83625 .49625 Mdot
.5675 .43125 Mdot
.03125 .435 Mdot
.96125 .46375 Mdot
.0925 .44 Mdot
.6675 .435 Mdot
.4525 .45 Mdot
.59125 .4375 Mdot
.4275 .415 Mdot
.46 .435 Mdot
.5225 .40625 Mdot
.52125 .41875 Mdot
.6125 .41875 Mdot
.555 .46 Mdot
.49375 .5025 Mdot
.25125 .44625 Mdot
.28 .36375 Mdot
.5925 .3 Mdot
.6825 .27375 Mdot
.35875 .2275 Mdot
.54375 .28125 Mdot
.46875 .3225 Mdot
.495 .33625 Mdot
.7025 .3575 Mdot
.41625 .40625 Mdot
.32625 .42375 Mdot
.93875 .44625 Mdot
.60875 .46125 Mdot
.84375 .46875 Mdot
.47125 .46625 Mdot
.395 .48625 Mdot
.3325 .5125 Mdot
.45875 .4925 Mdot
.63125 .4825 Mdot
.35125 .50875 Mdot
.7975 .51375 Mdot
.48625 .515 Mdot
.21125 .55875 Mdot
.555 .59 Mdot
.56 .58 Mdot
.72125 .62875 Mdot
.44375 .6075 Mdot
.05375 .58625 Mdot
.8225 .575 Mdot
.84625 .54625 Mdot
.645 .50125 Mdot
.6325 .48625 Mdot
.3625 .46375 Mdot
.94125 .505 Mdot
.7675 .6175 Mdot
.58875 .61875 Mdot
.3275 .65625 Mdot
.1125 .66875 Mdot
.87 .64875 Mdot
.64 .6275 Mdot
.71625 .66 Mdot
.46875 .65625 Mdot
.3175 .63125 Mdot
.1675 .555 Mdot
.765 .535 Mdot
.61875 .51875 Mdot
.4425 .48625 Mdot
.075 .47 Mdot
.43 .48 Mdot
.765 .4625 Mdot
.30125 .435 Mdot
.98875 .415 Mdot
.1325 .40625 Mdot
.6625 .47125 Mdot
.27375 .555 Mdot
.64875 .625 Mdot
.7725 .69125 Mdot
.3725 .7675 Mdot
.33 .77 Mdot
.385 .71125 Mdot
.7125 .6375 Mdot
.31125 .575 Mdot
.57625 .4575 Mdot
.29625 .48 Mdot
.82125 .49125 Mdot
.4025 .48 Mdot
.28375 .48125 Mdot
.63125 .4325 Mdot
.55625 .4375 Mdot
.315 .4825 Mdot
.0875 .53125 Mdot
.6425 .54625 Mdot
.22 .53625 Mdot
.92125 .485 Mdot
.3175 .48 Mdot
.12875 .47375 Mdot
.63875 .44375 Mdot
.92125 .46125 Mdot
.38625 .47 Mdot
.5075 .4525 Mdot
.52125 .445 Mdot
.28875 .5425 Mdot
.2 .5725 Mdot
.6475 .56125 Mdot
.42625 .55375 Mdot
.885 .58125 Mdot
.3475 .57125 Mdot
.55375 .5325 Mdot
.715 .4575 Mdot
.4225 .4475 Mdot
.73125 .42625 Mdot
.0225 .435 Mdot
.70875 .42625 Mdot
.59 .43 Mdot
.84375 .405 Mdot
.55875 .445 Mdot
.01375 .4875 Mdot
.68 .535 Mdot
.495 .5175 Mdot
.58625 .50375 Mdot
.47375 .47125 Mdot
.40625 .4625 Mdot
.47 .4925 Mdot
.59375 .53 Mdot
.6375 .57125 Mdot
.48375 .62375 Mdot
.5 .60625 Mdot
.01625 .59125 Mdot
.27875 .5475 Mdot
.3125 .52625 Mdot
.59125 .56625 Mdot
.67625 .5675 Mdot
.3175 .57875 Mdot
.56125 .55 Mdot
.52875 .5725 Mdot
.40625 .55375 Mdot
.765 .5375 Mdot
.3825 .51125 Mdot
.37875 .49625 Mdot
.875 .45375 Mdot
.64375 .4275 Mdot
.76375 .41125 Mdot
.48375 .4075 Mdot
.4 .38625 Mdot
.30875 .3475 Mdot
.52125 .36875 Mdot
.62 .43625 Mdot
.3575 .44 Mdot
.72375 .425 Mdot
.53125 .3875 Mdot
.2725 .37375 Mdot
.4575 .3125 Mdot
.605 .275 Mdot
.71625 .2725 Mdot
.48875 .325 Mdot
.00875 .335 Mdot
.7925 .32875 Mdot
.87125 .37375 Mdot
.00125 .39 Mdot
.61625 .3825 Mdot
.67375 .3925 Mdot
.34375 .42875 Mdot
.92375 .42625 Mdot
.75 .38625 Mdot
.545 .36625 Mdot
.36875 .36875 Mdot
.11875 .37625 Mdot
.82625 .38875 Mdot
.70875 .40875 Mdot
.66875 .4225 Mdot
.49125 .4175 Mdot
.32375 .3925 Mdot
.2275 .40875 Mdot
.65375 .41 Mdot
.6775 .4025 Mdot
.4075 .4275 Mdot
.065 .4475 Mdot
.48 .4375 Mdot
.7625 .45 Mdot
.25875 .485 Mdot
.17125 .5325 Mdot
.60375 .47875 Mdot
.3475 .39875 Mdot
.5425 .32625 Mdot
.9125 .275 Mdot
.20625 .2275 Mdot
.45625 .25125 Mdot
.34625 .31625 Mdot
.6725 .37125 Mdot
.38875 .415 Mdot
.5425 .55625 Mdot
.32375 .53 Mdot
.7725 .53375 Mdot
.43375 .525 Mdot
.30875 .51875 Mdot
.60625 .48625 Mdot
.56375 .49375 Mdot
.30875 .46125 Mdot
.03875 .4875 Mdot
.64 .50125 Mdot
.23125 .5125 Mdot
.92375 .54125 Mdot
.32 .54125 Mdot
.12125 .5125 Mdot
.675 .54875 Mdot
.88125 .53625 Mdot
.41125 .525 Mdot
.46125 .5275 Mdot
.60625 .53375 Mdot
.35625 .4475 Mdot
.2075 .36625 Mdot
.6125 .36125 Mdot
.475 .34 Mdot
.84625 .32875 Mdot
.37625 .3725 Mdot
.60375 .4025 Mdot
.65 .4725 Mdot
.4775 .49375 Mdot
.64 .51375 Mdot
.03625 .52 Mdot
.6 .5875 Mdot
.61 .58875 Mdot
.845 .59 Mdot
.56875 .54375 Mdot
.00625 .51625 Mdot
.0075 .48875 Mdot
.65375 .52625 Mdot
.4675 .5575 Mdot
.64 .56625 Mdot
.48375 .6325 Mdot
.38875 .67 Mdot
.4425 .6775 Mdot
.59625 .67375 Mdot
.68375 .63875 Mdot
.41375 .58125 Mdot
.5575 .555 Mdot
.0625 .5375 Mdot
.26 .61375 Mdot
.34 .65375 Mdot
.61625 .63125 Mdot
.7075 .58875 Mdot
.2525 .57 Mdot
.55625 .545 Mdot
.55875 .4475 Mdot
.41625 .44625 Mdot
.7625 .47 Mdot
.37 .41875 Mdot
.42375 .40375 Mdot
.805 .45875 Mdot
0 .7675 Mdot
.705 .7925 Mdot
.64125 .71875 Mdot
.53625 .70625 Mdot
.38125 .66875 Mdot
.30375 .6725 Mdot
.56875 .63625 Mdot
.59125 .52875 Mdot
.40375 .4575 Mdot
.63625 .46625 Mdot
.5775 .52875 Mdot
.31375 .59375 Mdot
.41625 .7225 Mdot
.64625 .79375 Mdot
.62125 .74125 Mdot
.545 .6325 Mdot
.04125 .545 Mdot
.69875 .51375 Mdot
.9525 .465 Mdot
.6325 .5125 Mdot
.6925 .49125 Mdot
.3475 .45875 Mdot
.91 .455 Mdot
.76125 .435 Mdot
.51375 .46625 Mdot
.36625 .4725 Mdot
.12375 .48375 Mdot
.84 .4725 Mdot
.735 .51625 Mdot
.61875 .52 Mdot
.51 .5275 Mdot
.31 .595 Mdot
.2575 .56875 Mdot
.5325 .56125 Mdot
.7525 .57 Mdot
.41375 .54125 Mdot
.0175 .5425 Mdot
.5375 .5525 Mdot
.78875 .5575 Mdot
.21625 .52875 Mdot
.9875 .49625 Mdot
.2075 .50875 Mdot
.53875 .5375 Mdot
.44625 .5975 Mdot
.4775 .635 Mdot
.04 .6975 Mdot
.55375 .68 Mdot
.3475 .6425 Mdot
.635 .63375 Mdot
.39875 .60875 Mdot
.01875 .56375 Mdot
.535 .535 Mdot
.33875 .555 Mdot
.77125 .545 Mdot
.3625 .555 Mdot
.37375 .55875 Mdot
.58625 .5675 Mdot
.58375 .5375 Mdot
.295 .51375 Mdot
.02875 .49125 Mdot
.64375 .48 Mdot
.21875 .4775 Mdot
.9025 .5 Mdot
.35375 .495 Mdot
.09375 .4925 Mdot
.7275 .47375 Mdot
.8325 .48 Mdot
.44375 .50375 Mdot
.41875 .49375 Mdot
.645 .47375 Mdot
.3625 .5425 Mdot
.235 .66625 Mdot
.59 .635 Mdot
.56375 .6675 Mdot
.75375 .69625 Mdot
.43625 .64625 Mdot
.66 .6 Mdot
.99875 .5675 Mdot
.0975 .51 Mdot
.535 .5325 Mdot
.575 .54125 Mdot
.54375 .53 Mdot
.06375 .53 Mdot
.515 .53375 Mdot
.62375 .58375 Mdot
.86125 .58375 Mdot
.56125 .57375 Mdot
.005 .50875 Mdot
.6225 .4625 Mdot
.48125 .45625 Mdot
.64375 .47375 Mdot
.52875 .43125 Mdot
.3375 .40625 Mdot
.425 .3825 Mdot
.63 .33875 Mdot
.70125 .3325 Mdot
.37625 .37 Mdot
.60875 .40625 Mdot
.0325 .44 Mdot
.97 .45625 Mdot
.2475 .45625 Mdot
.39 .48125 Mdot
.65125 .49625 Mdot
.66125 .54375 Mdot
.2225 .5225 Mdot
.54 .525 Mdot
.63375 .535 Mdot
.38875 .49125 Mdot
.75125 .4875 Mdot
.38625 .6325 Mdot
.41 .6725 Mdot
.79875 .695 Mdot
.025 .35875 Mdot
.76 .33875 Mdot
.54 .3975 Mdot
.58625 .42875 Mdot
.34375 .48 Mdot
.365 .49625 Mdot
.55875 .53625 Mdot
.56875 .63125 Mdot
.435 .6725 Mdot
.57 .64125 Mdot
.62 .595 Mdot
.36375 .47625 Mdot
.3775 .3275 Mdot
.665 .29875 Mdot
.5425 .3325 Mdot
.58 .41625 Mdot
.08375 .53125 Mdot
.64625 .58125 Mdot
.96125 .56625 Mdot
.61875 .5175 Mdot
.715 .55 Mdot
.3175 .5925 Mdot
.92625 .61125 Mdot
.74375 .6125 Mdot
.5075 .59875 Mdot
.34625 .54625 Mdot
.1675 .51 Mdot
.8475 .53375 Mdot
.735 .48 Mdot
.575 .41 Mdot
.52125 .415 Mdot
.32 .355 Mdot
.255 .43875 Mdot
.48875 .44375 Mdot
.795 .4275 Mdot
.41 .45625 Mdot
.0175 .44875 Mdot
.525 .46875 Mdot
.83375 .4575 Mdot
.1425 .495 Mdot
.23125 .53375 Mdot
.5025 .535 Mdot
.5025 .55875 Mdot
.39875 .555 Mdot
.61125 .4825 Mdot
.32375 .44 Mdot
.64625 .40875 Mdot
.39 .42375 Mdot
.03375 .39625 Mdot
.48875 .4125 Mdot
.40375 .43625 Mdot
.78625 .43875 Mdot
.25125 .4825 Mdot
.47375 .515 Mdot
.545 .5425 Mdot
.595 .54125 Mdot
.29875 .555 Mdot
.0575 .49125 Mdot
.64 .47875 Mdot
.23375 .48375 Mdot
.8575 .4825 Mdot
.365 .50125 Mdot
.09875 .53125 Mdot
.75875 .54125 Mdot
.78625 .5125 Mdot
.505 .47125 Mdot
.3525 .4775 Mdot
.67875 .4625 Mdot
.36125 .46 Mdot
.32875 .38625 Mdot
.55625 .37375 Mdot
.63375 .3725 Mdot
.67 .3575 Mdot
.4575 .4625 Mdot
.69 .575 Mdot
.92375 .6075 Mdot
.17625 .6625 Mdot
.455 .6275 Mdot
.665 .61 Mdot
.455 .53375 Mdot
.11 .5225 Mdot
.39875 .3925 Mdot
.6575 .37375 Mdot
.8825 .35375 Mdot
.5475 .37875 Mdot
.06625 .4775 Mdot
.585 .50125 Mdot
.495 .5075 Mdot
.6825 .48625 Mdot
.51125 .51 Mdot
.32375 .4925 Mdot
.46125 .49 Mdot
.515 .48375 Mdot
.80625 .50875 Mdot
.3275 .445 Mdot
.61625 .46875 Mdot
.05625 .48875 Mdot
.95375 .4975 Mdot
.21875 .495 Mdot
.46125 .505 Mdot
.6475 .49625 Mdot
.67625 .48875 Mdot
.105 .52375 Mdot
.54625 .54125 Mdot
.68 .5425 Mdot
.43625 .5725 Mdot
.6825 .545 Mdot
.435 .4675 Mdot
.445 .44 Mdot
.72125 .42875 Mdot
.79625 .45 Mdot
.47875 .46375 Mdot
.64 .46 Mdot
.31125 .43375 Mdot
.39125 .415 Mdot
.55125 .40125 Mdot
.57125 .36 Mdot
.4175 .35875 Mdot
.52 .38 Mdot
.7 .4525 Mdot
.4 .54875 Mdot
.36375 .615 Mdot
.63375 .59 Mdot
.5075 .58375 Mdot
.62375 .53 Mdot
.035 .4575 Mdot
.6575 .42 Mdot
.98 .485 Mdot
.00625 .5075 Mdot
.57625 .505 Mdot
.7475 .4975 Mdot
.29875 .49125 Mdot
.91125 .4575 Mdot
.6975 .49 Mdot
.5575 .48625 Mdot
.3175 .54125 Mdot
.2025 .5775 Mdot
.83375 .57125 Mdot
.71 .58875 Mdot
.60125 .64625 Mdot
.525 .63375 Mdot
.37375 .65375 Mdot
.27375 .52875 Mdot
.42375 .49875 Mdot
.81625 .45875 Mdot
.4275 .4125 Mdot
.01375 .4175 Mdot
.52625 .43 Mdot
.83125 .45125 Mdot
.1325 .4475 Mdot
.25625 .3975 Mdot
.47625 .36875 Mdot
.52125 .30875 Mdot
.3775 .3225 Mdot
.5975 .39125 Mdot
.34875 .4325 Mdot
.61 .465 Mdot
.39125 .48125 Mdot
.0525 .55375 Mdot
.46125 .575 Mdot
.41625 .545 Mdot
.84375 .54625 Mdot
.16875 .49875 Mdot
.51375 .45625 Mdot
.565 .4375 Mdot
.54375 .42625 Mdot
.35625 .42625 Mdot
.13 .5075 Mdot
.625 .5175 Mdot
.23625 .5575 Mdot
.84625 .5725 Mdot
.365 .5575 Mdot
.095 .55375 Mdot
.785 .57125 Mdot
.73 .6025 Mdot
.5575 .60875 Mdot
.35125 .60125 Mdot
.67125 .6425 Mdot
.40875 .5775 Mdot
.84875 .555 Mdot
.44875 .575 Mdot
.5425 .5725 Mdot
.65125 .5575 Mdot
.615 .51875 Mdot
.49125 .41875 Mdot
.69125 .335 Mdot
.8875 .2925 Mdot
.2275 .28625 Mdot
.4025 .35125 Mdot
.7325 .38625 Mdot
.4 .4925 Mdot
.1075 .515 Mdot
.31125 .59875 Mdot
.64875 .55125 Mdot
.92875 .5925 Mdot
.53375 .58625 Mdot
.95875 .52375 Mdot
.1475 .50625 Mdot
.58375 .5 Mdot
.445 .5 Mdot
.73875 .51 Mdot
.51625 .49875 Mdot
.31 .50875 Mdot
.4875 .5075 Mdot
.4025 .545 Mdot
.90125 .58 Mdot
.315 .62375 Mdot
.66 .595 Mdot
.0225 .57125 Mdot
.9475 .5475 Mdot
.18125 .5275 Mdot
.505 .5025 Mdot
.69125 .50375 Mdot
.63375 .50875 Mdot
.07 .5075 Mdot
.52625 .5 Mdot
.6975 .545 Mdot
.4875 .57625 Mdot
.6325 .56625 Mdot
.4425 .53 Mdot
.50375 .50125 Mdot
.70625 .46625 Mdot
.0275 .49875 Mdot
.77125 .48375 Mdot
.48125 .45375 Mdot
.63 .455 Mdot
.3425 .51 Mdot
.38375 .5625 Mdot
.5275 .5475 Mdot
.57 .55125 Mdot
.42875 .5475 Mdot
.5275 .55 Mdot
.69 .49875 Mdot
.4175 .47625 Mdot
.33625 .49875 Mdot
.645 .51 Mdot
.49875 .51375 Mdot
.67125 .54 Mdot
.0175 .54875 Mdot
.61125 .57875 Mdot
.9775 .56 Mdot
.0425 .57125 Mdot
.58625 .56125 Mdot
.7275 .57625 Mdot
.305 .53625 Mdot
.9225 .53 Mdot
.64875 .49875 Mdot
.62625 .5 Mdot
.3 .495 Mdot
.20375 .49625 Mdot
.8275 .4925 Mdot
.665 .485 Mdot
.67125 .465 Mdot
.49625 .45 Mdot
.4275 .3875 Mdot
.285 .4725 Mdot
.44875 .51875 Mdot
.7775 .63875 Mdot
.45875 .7375 Mdot
.53 .70375 Mdot
.83875 .67625 Mdot
.13625 .59 Mdot
.22875 .5775 Mdot
.53625 .63625 Mdot
.43 .6425 Mdot
.4775 .6575 Mdot
.0025 .62125 Mdot
.56125 .60375 Mdot
.37 .6275 Mdot
.63 .59875 Mdot
.355 .565 Mdot
.04125 .4525 Mdot
.42625 .405 Mdot
.44375 .39875 Mdot
.89125 .405 Mdot
.095 .45125 Mdot
.555 .48875 Mdot
.5925 .51125 Mdot
.4875 .53375 Mdot
.435 .5475 Mdot
.87375 .51125 Mdot
.25625 .4975 Mdot
.55 .4925 Mdot
.2675 .44625 Mdot
.88125 .395 Mdot
.29 .4025 Mdot
.1575 .38125 Mdot
.7475 .33 Mdot
.7075 .34625 Mdot
.62375 .3625 Mdot
.32625 .3775 Mdot
.63625 .38875 Mdot
.4 .45875 Mdot
.68625 .515 Mdot
.55 .5075 Mdot
.56 .57375 Mdot
.68875 .6 Mdot
.51 .645 Mdot
.53 .6275 Mdot
.7275 .60125 Mdot
.84625 .60375 Mdot
.25 .56625 Mdot
.32375 .54875 Mdot
.82375 .50875 Mdot
.37125 .4725 Mdot
.13125 .46875 Mdot
.27375 .43375 Mdot
.68375 .475 Mdot
.99375 .47 Mdot
.4575 .485 Mdot
.01625 .50875 Mdot
.86875 .5275 Mdot
.25875 .51375 Mdot
.57625 .5075 Mdot
.40625 .50875 Mdot
.7325 .53 Mdot
.515 .59375 Mdot
.33375 .60375 Mdot
.5575 .60625 Mdot
.23125 .62375 Mdot
.3325 .46 Mdot
.6125 .435 Mdot
.07125 .4025 Mdot
.92875 .3875 Mdot
.12 .41 Mdot
.58625 .455 Mdot
.6925 .505 Mdot
.58375 .51625 Mdot
.0875 .465 Mdot
.46875 .4625 Mdot
.755 .4125 Mdot
.49625 .34875 Mdot
.58625 .38875 Mdot
.52 .45875 Mdot
.44875 .49625 Mdot
.69625 .47875 Mdot
.08375 .51125 Mdot
.73625 .54625 Mdot
.53 .585 Mdot
.59125 .57125 Mdot
.36625 .5475 Mdot
.36375 .51375 Mdot
.50375 .5075 Mdot
.6175 .48625 Mdot
.405 .4825 Mdot
.5025 .45875 Mdot
.72125 .415 Mdot
.42875 .40375 Mdot
.3375 .38625 Mdot
.665 .4225 Mdot
.39875 .445 Mdot
.73125 .47375 Mdot
.04125 .52125 Mdot
.5825 .51625 Mdot
.9675 .4975 Mdot
.0525 .4925 Mdot
.6075 .52875 Mdot
.72375 .50375 Mdot
.30125 .51125 Mdot
.90625 .485 Mdot
.63 .45125 Mdot
.71 .43875 Mdot
.26125 .42625 Mdot
.21375 .3975 Mdot
.82875 .385 Mdot
.59625 .3825 Mdot
.7375 .38375 Mdot
.5025 .41125 Mdot
.41125 .53875 Mdot
.295 .5525 Mdot
.49125 .52625 Mdot
.73125 .4375 Mdot
.47125 .3575 Mdot
.025 .28125 Mdot
.4975 .2675 Mdot
.8225 .265 Mdot
.1725 .33875 Mdot
.18125 .38875 Mdot
.57375 .34625 Mdot
.36875 .28125 Mdot
.58875 .23875 Mdot
.9425 .22 Mdot
.06 .27625 Mdot
.51125 .3075 Mdot
.38125 .38 Mdot
.65625 .41125 Mdot
.33875 .44625 Mdot
.0025 .51625 Mdot
.4275 .5325 Mdot
.4725 .54375 Mdot
.92875 .54 Mdot
.005 .50375 Mdot
.61875 .49875 Mdot
.59 .50625 Mdot
.44125 .50375 Mdot
.535 .51125 Mdot
.7275 .51 Mdot
.38625 .5225 Mdot
.465 .51625 Mdot
.3 .5375 Mdot
.9325 .56 Mdot
.2075 .5575 Mdot
.21375 .5575 Mdot
.685 .55875 Mdot
.715 .525 Mdot
.6825 .51125 Mdot
.32 .505 Mdot
.59375 .47875 Mdot
.3725 .47875 Mdot
.59375 .46875 Mdot
.62125 .46125 Mdot
.59875 .43 Mdot
.70125 .41125 Mdot
.415 .41125 Mdot
.56125 .44125 Mdot
.7075 .48 Mdot
.9475 .50625 Mdot
.17625 .52625 Mdot
.32625 .515 Mdot
.82375 .515 Mdot
.4025 .5225 Mdot
.18875 .4925 Mdot
.33625 .58 Mdot
.7075 .5925 Mdot
.3575 .61625 Mdot
.06875 .61 Mdot
.76875 .62875 Mdot
.36125 .615 Mdot
.535 .56625 Mdot
.46625 .51375 Mdot
.68875 .4475 Mdot
.505 .34125 Mdot
.35875 .32375 Mdot
.5725 .31375 Mdot
.155 .2925 Mdot
.41125 .47 Mdot
.50625 .525 Mdot
.1275 .605 Mdot
.9275 .64875 Mdot
.07875 .6425 Mdot
.67875 .545 Mdot
.64625 .48125 Mdot
.5325 .4375 Mdot
.14 .50625 Mdot
.415 .5 Mdot
.82125 .5475 Mdot
.45375 .57375 Mdot
.5775 .53125 Mdot
.555 .45375 Mdot
.4325 .45375 Mdot
.665 .47625 Mdot
.13875 .565 Mdot
.64625 .51625 Mdot
.66625 .4925 Mdot
.49 .50375 Mdot
.3825 .4875 Mdot
.39125 .4575 Mdot
.48375 .4775 Mdot
.65375 .49875 Mdot
.3225 .5 Mdot
.56 .53875 Mdot
.69375 .57875 Mdot
.46375 .58375 Mdot
.3025 .55625 Mdot
.67875 .4975 Mdot
.37 .46875 Mdot
.79875 .455 Mdot
.01625 .41 Mdot
.57125 .39 Mdot
.92875 .4075 Mdot
.1025 .38625 Mdot
.61125 .3325 Mdot
.74 .34625 Mdot
.255 .38375 Mdot
.91 .43 Mdot
.59625 .53125 Mdot
.81 .5575 Mdot
.2075 .57125 Mdot
.21375 .58125 Mdot
.83625 .57125 Mdot
.535 .57375 Mdot
.81125 .59 Mdot
.49625 .59125 Mdot
.4025 .52 Mdot
.2625 .47875 Mdot
.63375 .47375 Mdot
.6025 .5125 Mdot
.5075 .55875 Mdot
.06375 .62625 Mdot
.43875 .6825 Mdot
.81 .735 Mdot
.2025 .71 Mdot
.14875 .69875 Mdot
.6175 .71625 Mdot
.2775 .8075 Mdot
.70125 .85625 Mdot
.8225 .87 Mdot
.17375 .81875 Mdot
.4625 .75 Mdot
.3875 .5975 Mdot
.66375 .56625 Mdot
.31625 .52875 Mdot
.38 .52125 Mdot
.51 .495 Mdot
.9925 .46875 Mdot
.6375 .4475 Mdot
.5975 .4475 Mdot
.4025 .4525 Mdot
.63375 .45625 Mdot
.57125 .4825 Mdot
.52625 .465 Mdot
.3575 .48625 Mdot
.3825 .4675 Mdot
.975 .49 Mdot
.05375 .49125 Mdot
.36125 .50375 Mdot
.58375 .51875 Mdot
.70125 .5525 Mdot
.76125 .53625 Mdot
.2925 .54625 Mdot
.59625 .57 Mdot
.42375 .4975 Mdot
.64125 .41875 Mdot
.6225 .40875 Mdot
.6525 .40375 Mdot
.69125 .415 Mdot
.34125 .4375 Mdot
.5675 .44875 Mdot
.6325 .45625 Mdot
.06125 .425 Mdot
.41625 .4225 Mdot
.6975 .465 Mdot
.51625 .5025 Mdot
.27625 .51875 Mdot
.37375 .42625 Mdot
.75 .36375 Mdot
.2725 .31625 Mdot
.06875 .33 Mdot
.78125 .3325 Mdot
.41375 .40375 Mdot
.475 .49 Mdot
.52375 .55 Mdot
.60125 .595 Mdot
.56125 .6375 Mdot
.375 .61875 Mdot
.58875 .62625 Mdot
.0725 .66125 Mdot
.465 .58375 Mdot
.3725 .5575 Mdot
.25875 .4975 Mdot
.88875 .46 Mdot
.03625 .48375 Mdot
.77 .52 Mdot
.61625 .52625 Mdot
.47375 .54875 Mdot
.17875 .49 Mdot
.37625 .48625 Mdot
.8775 .45625 Mdot
.4225 .48 Mdot
.5575 .525 Mdot
.57125 .57375 Mdot
.475 .57 Mdot
.61125 .57375 Mdot
.19875 .37875 Mdot
.61875 .40375 Mdot
.6175 .4325 Mdot
.51875 .4525 Mdot
.4025 .47625 Mdot
.3575 .51875 Mdot
.5175 .54 Mdot
.655 .5525 Mdot
.27625 .5575 Mdot
.62375 .5325 Mdot
.61875 .525 Mdot
.48625 .5075 Mdot
.3325 .495 Mdot
.705 .515 Mdot
.25875 .5075 Mdot
.91125 .4925 Mdot
.6125 .51375 Mdot
.8925 .4875 Mdot
.07125 .51 Mdot
.69 .55375 Mdot
.71 .535 Mdot
.2575 .505 Mdot
.87375 .50375 Mdot
.58375 .4075 Mdot
.8775 .415 Mdot
.1675 .4225 Mdot
.2575 .44875 Mdot
.77125 .49375 Mdot
.49625 .52 Mdot
.915 .5225 Mdot
.46375 .5225 Mdot
.36875 .5175 Mdot
.21 .5425 Mdot
.8 .54625 Mdot
.4325 .53875 Mdot
.5675 .54125 Mdot
.07375 .51125 Mdot
.41375 .47875 Mdot
.795 .44 Mdot
.28625 .45125 Mdot
.13 .405 Mdot
.65 .3925 Mdot
.21125 .38 Mdot
.79 .33125 Mdot
.7425 .35375 Mdot
.23875 .36125 Mdot
.43375 .3975 Mdot
.405 .46 Mdot
.65625 .48625 Mdot
.28625 .505 Mdot
.3925 .53375 Mdot
.51125 .5725 Mdot
.5875 .63875 Mdot
.66375 .6 Mdot
.3425 .575 Mdot
.7275 .53625 Mdot
.4425 .49375 Mdot
.615 .50125 Mdot
.28125 .4975 Mdot
.47375 .52125 Mdot
.515 .54 Mdot
.45375 .54125 Mdot
.70125 .4875 Mdot
.86 .4975 Mdot
.2175 .49 Mdot
.61125 .4525 Mdot
.4425 .455 Mdot
.58375 .50625 Mdot
.67125 .5125 Mdot
.6825 .5325 Mdot
.7 .545 Mdot
.28625 .51375 Mdot
.565 .49125 Mdot
.05 .485 Mdot
.50125 .465 Mdot
.51625 .53 Mdot
.55875 .5475 Mdot
.64125 .5275 Mdot
.36875 .49 Mdot
.79875 .4875 Mdot
.39625 .48 Mdot
.73625 .49 Mdot
.2075 .5175 Mdot
.08625 .48625 Mdot
.85625 .43 Mdot
.3875 .40625 Mdot
.46625 .3925 Mdot
.5125 .405 Mdot
.545 .43625 Mdot
.6225 .4875 Mdot
.36875 .53875 Mdot
.59875 .52625 Mdot
.055 .465 Mdot
.5225 .41125 Mdot
.3 .375 Mdot
.3425 .3975 Mdot
.88 .41375 Mdot
.81 .42 Mdot
.61875 .43625 Mdot
.41 .4525 Mdot
.23125 .505 Mdot
.41875 .53 Mdot
.88375 .55625 Mdot
.34 .53375 Mdot
.56125 .4875 Mdot
.6075 .43 Mdot
.4425 .3975 Mdot
.6275 .37375 Mdot
.265 .57375 Mdot
.64 .5825 Mdot
.5075 .535 Mdot
.56 .4925 Mdot
.44375 .49875 Mdot
.315 .4825 Mdot
.535 .45125 Mdot
.66625 .4875 Mdot
.2475 .49875 Mdot
.6925 .49375 Mdot
.5375 .49625 Mdot
.46875 .4875 Mdot
.43875 .46125 Mdot
.64375 .45125 Mdot
.2 .4475 Mdot
.65875 .49125 Mdot
.80625 .53375 Mdot
.10125 .55375 Mdot
.71625 .53625 Mdot
.6825 .57 Mdot
.26 .6025 Mdot
.88 .58875 Mdot
.54625 .63625 Mdot
.9175 .6 Mdot
.125 .565 Mdot
.3225 .53 Mdot
.725 .48125 Mdot
.4525 .43125 Mdot
.975 .40875 Mdot
.4625 .3825 Mdot
.39125 .3525 Mdot
.18875 .32875 Mdot
.985 .3425 Mdot
.255 .3225 Mdot
.6375 .32375 Mdot
.09375 .34875 Mdot
.35375 .39 Mdot
.81875 .40125 Mdot
.3275 .41625 Mdot
.955 .465 Mdot
.0975 .45875 Mdot
.72625 .445 Mdot
.1075 .39375 Mdot
.90375 .3925 Mdot
.70875 .35625 Mdot
.19 .35875 Mdot
.4725 .37125 Mdot
.39375 .38625 Mdot
.65875 .4075 Mdot
.275 .44875 Mdot
.38875 .455 Mdot
.54625 .45 Mdot
.5575 .38125 Mdot
.7225 .40375 Mdot
.2975 .37875 Mdot
.77875 .38375 Mdot
.3525 .4125 Mdot
.68125 .425 Mdot
.2175 .43875 Mdot
.5425 .43625 Mdot
.665 .47125 Mdot
.3475 .475 Mdot
.69625 .5125 Mdot
.97375 .5 Mdot
.0925 .49375 Mdot
.67625 .50625 Mdot
.43375 .515 Mdot
.5275 .53625 Mdot
.69875 .55625 Mdot
.70375 .59125 Mdot
.73125 .56375 Mdot
.25 .5625 Mdot
.535 .5575 Mdot
.115 .55375 Mdot
.4025 .5425 Mdot
.52625 .45625 Mdot
.5525 .43375 Mdot
.665 .42375 Mdot
.5025 .43 Mdot
.48 .47125 Mdot
.185 .51125 Mdot
.34375 .52375 Mdot
.74125 .5625 Mdot
.11625 .54125 Mdot
.15625 .5625 Mdot
.86625 .60625 Mdot
.41375 .6025 Mdot
.43625 .59875 Mdot
.5625 .5425 Mdot
.42375 .46875 Mdot
.7125 .3875 Mdot
.3275 .34125 Mdot
.62625 .39625 Mdot
.05 .44125 Mdot
.535 .52375 Mdot
.1925 .54875 Mdot
.43875 .515 Mdot
.92875 .49125 Mdot
.895 .5 Mdot
.58 .4875 Mdot
.3675 .48625 Mdot
.25125 .48 Mdot
.45875 .4675 Mdot
.8725 .465 Mdot
.31625 .47875 Mdot
.5475 .49 Mdot
.65625 .53125 Mdot
.44625 .56 Mdot
.5675 .56625 Mdot
.2925 .42875 Mdot
.69625 .42625 Mdot
.345 .46375 Mdot
.68125 .4725 Mdot
.43125 .4075 Mdot
.2675 .46125 Mdot
.5825 .47125 Mdot
.66125 .43625 Mdot
.22 .45 Mdot
.75375 .44 Mdot
.4525 .47125 Mdot
.43375 .55 Mdot
.61375 .615 Mdot
.545 .63625 Mdot
.13125 .66875 Mdot
.7325 .605 Mdot
.72125 .5825 Mdot
.14375 .56125 Mdot
.69 .54625 Mdot
.705 .4925 Mdot
.27375 .445 Mdot
.85375 .43625 Mdot
.56125 .405 Mdot
.92625 .46 Mdot
.12125 .5 Mdot
.35625 .51625 Mdot
.685 .56875 Mdot
.43 .61625 Mdot
.46375 .61375 Mdot
.3925 .615 Mdot
.145 .63875 Mdot
.06125 .6775 Mdot
.72375 .67125 Mdot
.1125 .63375 Mdot
.28875 .61125 Mdot
.835 .6 Mdot
.36625 .56125 Mdot
.8875 .5475 Mdot
.145 .56625 Mdot
.72 .57125 Mdot
.0975 .60625 Mdot
.90625 .62875 Mdot
.7125 .63875 Mdot
.19125 .61375 Mdot
.45 .6 Mdot
.45375 .56 Mdot
.59625 .50875 Mdot
.29125 .435 Mdot
.395 .415 Mdot
.56 .44875 Mdot
.525 .57 Mdot
.8 .57625 Mdot
.225 .6125 Mdot
.84125 .6325 Mdot
.26875 .6 Mdot
.7275 .575 Mdot
.16625 .54875 Mdot
.61125 .51375 Mdot
.73625 .48 Mdot
.2975 .495 Mdot
.67625 .51125 Mdot
.7325 .52625 Mdot
.41625 .575 Mdot
.48125 .565 Mdot
.75375 .54375 Mdot
.67625 .46875 Mdot
.75875 .4875 Mdot
.25 .53 Mdot
.465 .5525 Mdot
.20625 .555 Mdot
.3375 .555 Mdot
.0325 .5275 Mdot
.47625 .54125 Mdot
.6 .54625 Mdot
.63125 .49125 Mdot
.58125 .53625 Mdot
.30375 .5225 Mdot
.29375 .4825 Mdot
.4325 .45625 Mdot
.6375 .47375 Mdot
.0225 .44375 Mdot
.32125 .4375 Mdot
.76375 .4925 Mdot
.425 .51 Mdot
.45625 .535 Mdot
.605 .55625 Mdot
.30625 .60125 Mdot
.8125 .615 Mdot
.27875 .63875 Mdot
.66625 .57625 Mdot
.05125 .54 Mdot
.55875 .495 Mdot
.155 .52375 Mdot
.46375 .58 Mdot
.9225 .54375 Mdot
.565 .5 Mdot
.32875 .48 Mdot
.3025 .47 Mdot
.48625 .5025 Mdot
.83 .51375 Mdot
.3125 .54875 Mdot
.575 .525 Mdot
.66625 .50125 Mdot
.35625 .48375 Mdot
.6175 .5325 Mdot
.3 .7325 Mdot
.72 .705 Mdot
.22375 .6925 Mdot
.8025 .69 Mdot
.4075 .68375 Mdot
.235 .595 Mdot
.63125 .56 Mdot
.62625 .5175 Mdot
.215 .48875 Mdot
.80125 .47875 Mdot
.4125 .45375 Mdot
.36 .385 Mdot
.7725 .37 Mdot
.47 .36625 Mdot
.0975 .39 Mdot
.775 .51 Mdot
.66125 .51375 Mdot
.185 .495 Mdot
.695 .48 Mdot
.69 .50125 Mdot
.26125 .50875 Mdot
.88875 .5175 Mdot
.56625 .56 Mdot
.9275 .51625 Mdot
.11 .48375 Mdot
.38125 .465 Mdot
.6775 .41375 Mdot
.385 .3975 Mdot
.46375 .42625 Mdot
.4075 .46 Mdot
.98125 .4375 Mdot
.10875 .46625 Mdot
.85375 .42875 Mdot
.09 .46125 Mdot
.23625 .4575 Mdot
.855 .46125 Mdot
.41125 .47125 Mdot
.8275 .49125 Mdot
.165 .45125 Mdot
.75375 .44375 Mdot
.065 .43375 Mdot
.885 .42875 Mdot
.7225 .4225 Mdot
.23625 .48875 Mdot
.3975 .50375 Mdot
.50875 .55375 Mdot
.55 .6 Mdot
.285 .6475 Mdot
.4125 .635 Mdot
.575 .55125 Mdot
.45 .45 Mdot
.90625 .455 Mdot
.17875 .4825 Mdot
.8325 .4925 Mdot
.22625 .51375 Mdot
.76375 .50125 Mdot
.125 .49875 Mdot
.65875 .51375 Mdot
.77875 .44875 Mdot
.34625 .44375 Mdot
.5675 .42 Mdot
.7575 .50375 Mdot
.3725 .505 Mdot
.41625 .49 Mdot
.81625 .47875 Mdot
.64875 .5 Mdot
.77125 .465 Mdot
.2575 .4175 Mdot
.425 .4425 Mdot
.25125 .4375 Mdot
.34 .45875 Mdot
.13625 .505 Mdot
.40875 .46875 Mdot
.63375 .4525 Mdot
.62 .46125 Mdot
.5675 .5075 Mdot
.36 .49 Mdot
.225 .5175 Mdot
.5275 .59 Mdot
.5525 .59375 Mdot
.01875 .60375 Mdot
.41875 .58125 Mdot
.70625 .50375 Mdot
.38375 .49 Mdot
.49875 .40625 Mdot
.59875 .435 Mdot
.23375 .4225 Mdot
.88125 .43875 Mdot
.24375 .43 Mdot
.7275 .48625 Mdot
.07375 .51625 Mdot
.93875 .53375 Mdot
.5575 .53625 Mdot
.135 .49875 Mdot
.49875 .42875 Mdot
.92625 .4775 Mdot
.6 .54 Mdot
.26875 .54125 Mdot
.38875 .51 Mdot
.44 .4425 Mdot
.79125 .4 Mdot
.38125 .34625 Mdot
.57125 .42875 Mdot
.6675 .5025 Mdot
.26 .57125 Mdot
.69 .6075 Mdot
.3125 .2875 Mdot
.77375 .32125 Mdot
.10625 .3225 Mdot
.935 .35 Mdot
.3425 .40125 Mdot
.20875 .455 Mdot
.66125 .49125 Mdot
.635 .52375 Mdot
.2 .53 Mdot
.8025 .54375 Mdot
.44875 .5475 Mdot
.24625 .57125 Mdot
.93625 .5675 Mdot
.415 .55875 Mdot
.06375 .5375 Mdot
.77375 .42375 Mdot
.655 .40625 Mdot
.17125 .4225 Mdot
.68875 .4675 Mdot
.68375 .515 Mdot
.3025 .52125 Mdot
.86125 .54875 Mdot
.60375 .52625 Mdot
.895 .5 Mdot
.1375 .51125 Mdot
.39875 .5175 Mdot
.64125 .52125 Mdot
.35875 .485 Mdot
.43625 .5025 Mdot
.4325 .525 Mdot
.91625 .56 Mdot
.0975 .535 Mdot
.93375 .5675 Mdot
.0925 .565 Mdot
.17625 .57 Mdot
.86875 .55625 Mdot
.42375 .555 Mdot
.825 .5275 Mdot
.16875 .57 Mdot
.77625 .59125 Mdot
.06625 .64 Mdot
.83125 .67 Mdot
.76375 .68625 Mdot
.23125 .6275 Mdot
.37125 .6025 Mdot
.54625 .5625 Mdot
.50625 .5125 Mdot
.325 .5 Mdot
.465 .4775 Mdot
.57375 .505 Mdot
.9975 .5125 Mdot
.43375 .51125 Mdot
.995 .525 Mdot
.1225 .52625 Mdot
.8175 .53375 Mdot
.205 .545 Mdot
.77375 .55875 Mdot
.09125 .54375 Mdot
.68125 .545 Mdot
.77 .57875 Mdot
.41625 .57875 Mdot
.46375 .57375 Mdot
.7625 .45375 Mdot
.26125 .415 Mdot
.32625 .44625 Mdot
.9 .4425 Mdot
.595 .4525 Mdot
.78 .46625 Mdot
.315 .45625 Mdot
.37125 .44125 Mdot
.28 .4475 Mdot
.37875 .4775 Mdot
.31125 .5625 Mdot
.28 .59125 Mdot
.77625 .565 Mdot
.485 .6225 Mdot
.57125 .50875 Mdot
.425 .5 Mdot
.22875 .475 Mdot
.5425 .485 Mdot
.4975 .3975 Mdot
.015 .52 Mdot
.54 .525 Mdot
.61 .54125 Mdot
.355 .55625 Mdot
.55875 .5425 Mdot
.5425 .4875 Mdot
.28625 .4975 Mdot
.81 .50875 Mdot
.3 .525 Mdot
.71375 .4925 Mdot
.13 .4875 Mdot
.85375 .48 Mdot
.5875 .48375 Mdot
.09875 .47875 Mdot
.5475 .54 Mdot
.8825 .52 Mdot
.6375 .50875 Mdot
.23 .5125 Mdot
.44375 .5225 Mdot
.49875 .57125 Mdot
.68 .65375 Mdot
.425 .735 Mdot
.595 .6625 Mdot
.6175 .61875 Mdot
.2875 .54125 Mdot
.66375 .4175 Mdot
.30125 .52 Mdot
.7825 .49375 Mdot
.14625 .47875 Mdot
.91375 .46375 Mdot
.3075 .5 Mdot
.23625 .495 Mdot
.63875 .51 Mdot
.69 .50875 Mdot
.15625 .52125 Mdot
.76625 .5325 Mdot
.53625 .51875 Mdot
.13875 .4925 Mdot
.34 .5125 Mdot
.1125 .485 Mdot
.72625 .4625 Mdot
.65 .4725 Mdot
.20625 .47875 Mdot
.65875 .475 Mdot
.715 .4475 Mdot
.2975 .485 Mdot
.875 .48125 Mdot
.6325 .495 Mdot
.8775 .535 Mdot
.15 .53875 Mdot
.39375 .54375 Mdot
.66125 .56125 Mdot
.3175 .59625 Mdot
.4975 .58 Mdot
.46625 .5375 Mdot
.83 .50125 Mdot
.1025 .47375 Mdot
.9575 .385 Mdot
.1025 .35375 Mdot
.14 .345 Mdot
.865 .355 Mdot
.425 .3725 Mdot
.84625 .3775 Mdot
.15375 .39875 Mdot
.80875 .40375 Mdot
.075 .36375 Mdot
.75625 .34375 Mdot
.82375 .36 Mdot
.2175 .36625 Mdot
.365 .4 Mdot
.57625 .44 Mdot
.4425 .4575 Mdot
.405 .4375 Mdot
.51875 .44625 Mdot
.54375 .47625 Mdot
.9775 .50125 Mdot
.46625 .51375 Mdot
.08875 .46625 Mdot
.78125 .45 Mdot
.22375 .44375 Mdot
.78 .42625 Mdot
.0925 .4575 Mdot
.645 .46625 Mdot
.70875 .4625 Mdot
.54875 .46625 Mdot
.36125 .4725 Mdot
.80375 .5475 Mdot
.14125 .54 Mdot
.4275 .51625 Mdot
.8425 .52125 Mdot
.56625 .5 Mdot
.79125 .53 Mdot
.34875 .5225 Mdot
.34125 .515 Mdot
.26 .5225 Mdot
.5525 .51 Mdot
.74375 .4975 Mdot
.51 .46 Mdot
.14125 .45625 Mdot
.9225 .42 Mdot
.29125 .45375 Mdot
.695 .47625 Mdot
.42375 .4725 Mdot
.1925 .455 Mdot
.5875 .43 Mdot
.4625 .4175 Mdot
.65 .42125 Mdot
.54 .46625 Mdot
.30125 .4325 Mdot
.61 .50125 Mdot
.54375 .49 Mdot
.375 .45 Mdot
.6375 .41875 Mdot
.39 .4325 Mdot
.67875 .42375 Mdot
.2675 .4125 Mdot
.71375 .42875 Mdot
.59375 .44875 Mdot
.1075 .45 Mdot
.55375 .43375 Mdot
.7975 .4325 Mdot
.70625 .4725 Mdot
.18375 .49 Mdot
.52 .5225 Mdot
.43 .5325 Mdot
.68375 .50125 Mdot
.44125 .405 Mdot
.65875 .4175 Mdot
.50125 .42875 Mdot
.39625 .44125 Mdot
.60125 .44375 Mdot
.295 .5175 Mdot
.77125 .55 Mdot
.2425 .5575 Mdot
.89 .5675 Mdot
.2475 .54125 Mdot
.285 .51875 Mdot
.59625 .46375 Mdot
.74625 .45625 Mdot
.13125 .44375 Mdot
.7075 .45375 Mdot
.6075 .4575 Mdot
.08375 .465 Mdot
.29375 .4425 Mdot
.1675 .445 Mdot
.7025 .51125 Mdot
.66125 .5525 Mdot
.20125 .5375 Mdot
.6775 .54375 Mdot
.7325 .5075 Mdot
.3 .4575 Mdot
.84875 .43375 Mdot
.6875 .4275 Mdot
.85375 .43875 Mdot
.17 .45375 Mdot
.36125 .47 Mdot
.69125 .5 Mdot
.30625 .48375 Mdot
.5125 .47375 Mdot
.44375 .4725 Mdot
.82625 .475 Mdot
.0925 .51375 Mdot
.98625 .58375 Mdot
.09125 .645 Mdot
.15 .62625 Mdot
.8375 .625 Mdot
.42875 .62 Mdot
.86125 .61 Mdot
.15375 .5725 Mdot
.8175 .585 Mdot
.11125 .5925 Mdot
.67 .5775 Mdot
.8775 .5625 Mdot
.13125 .5525 Mdot
.48125 .51375 Mdot
.56625 .4825 Mdot
.40125 .48125 Mdot
.43875 .48625 Mdot
.535 .48625 Mdot
.54875 .46 Mdot
.9575 .45375 Mdot
.46 .45125 Mdot
.1075 .48 Mdot
.71125 .47875 Mdot
.26625 .49125 Mdot
.76 .51 Mdot
.10375 .4875 Mdot
.62125 .47875 Mdot
.65 .51 Mdot
.66125 .51125 Mdot
.26375 .51875 Mdot
.81125 .4875 Mdot
.11375 .4975 Mdot
.55625 .51375 Mdot
.80375 .50875 Mdot
.515 .55375 Mdot
.775 .53375 Mdot
.4225 .55375 Mdot
.3 .57875 Mdot
.2025 .5975 Mdot
.765 .59 Mdot
.505 .57375 Mdot
.65875 .585 Mdot
.0875 .565 Mdot
.9225 .63375 Mdot
.23 .53375 Mdot
.75125 .5625 Mdot
.48875 .53 Mdot
.0425 .5575 Mdot
.71125 .52625 Mdot
.445 .62375 Mdot
.7025 .52375 Mdot
.55875 .49375 Mdot
.23375 .4825 Mdot
.5875 .52625 Mdot
.5475 .5475 Mdot
.5 .59375 Mdot
.43375 .58375 Mdot
.51625 .57375 Mdot
.6 .55 Mdot
.45125 .56625 Mdot
.5375 .51125 Mdot
.62625 .5075 Mdot
.145 .52125 Mdot
.53375 .5325 Mdot
.6775 .5075 Mdot
.7825 .40125 Mdot
.2025 .39 Mdot
.51625 .405 Mdot
.41875 .395 Mdot
.65625 .3925 Mdot
.525 .4275 Mdot
.6475 .4325 Mdot
.39625 .395 Mdot
.4275 .395 Mdot
.60375 .42625 Mdot
.305 .5475 Mdot
.75375 .52875 Mdot
.31375 .50625 Mdot
.83125 .4875 Mdot
.245 .46875 Mdot
.29625 .49125 Mdot
.59125 .53875 Mdot
.765 .5475 Mdot
.11625 .53875 Mdot
.69 .52 Mdot
.655 .50875 Mdot
.04 .49 Mdot
.2825 .5425 Mdot
.21625 .58375 Mdot
.9725 .60625 Mdot
.67375 .5675 Mdot
.67125 .49125 Mdot
.215 .48125 Mdot
.695 .445 Mdot
.7325 .49375 Mdot
.26 .52875 Mdot
.8575 .55375 Mdot
.7025 .55 Mdot
.81375 .52625 Mdot
.1825 .51125 Mdot
.35875 .50375 Mdot
.68625 .44125 Mdot
.30375 .4525 Mdot
.5075 .46 Mdot
.4275 .51 Mdot
.8175 .51625 Mdot
.10625 .5175 Mdot
.06375 .44875 Mdot
.16 .44875 Mdot
.815 .45 Mdot
.43625 .42875 Mdot
.885 .4275 Mdot
.1175 .43875 Mdot
.84125 .40625 Mdot
.12375 .395 Mdot
.63625 .40625 Mdot
.91 .4125 Mdot
.0675 .4275 Mdot
.56875 .46375 Mdot
.5325 .49 Mdot
.38625 .51375 Mdot
.46 .51625 Mdot
.57875 .535 Mdot
.565 .55125 Mdot
.8975 .575 Mdot
.0425 .5675 Mdot
.445 .54125 Mdot
.99875 .4875 Mdot
.195 .45 Mdot
.58625 .415 Mdot
.35625 .41375 Mdot
.73375 .44 Mdot
.11625 .49 Mdot
.58625 .51125 Mdot
.60625 .455 Mdot
.78125 .455 Mdot
.16625 .44875 Mdot
.8325 .4875 Mdot
.13875 .475 Mdot
.67875 .4825 Mdot
.75625 .50375 Mdot
.47875 .50875 Mdot
.74125 .46625 Mdot
.48375 .43625 Mdot
.29625 .4225 Mdot
.14 .39625 Mdot
.9275 .40125 Mdot
.335 .4275 Mdot
.72125 .45375 Mdot
.13375 .43625 Mdot
.835 .47625 Mdot
.2375 .495 Mdot
.81875 .48875 Mdot
.4375 .51375 Mdot
.06625 .5275 Mdot
.6625 .50125 Mdot
.53 .4875 Mdot
.0225 .48875 Mdot
.66375 .4725 Mdot
.64 .43125 Mdot
.215 .42625 Mdot
.52375 .44875 Mdot
.55625 .46125 Mdot
.61 .47125 Mdot
.26875 .50375 Mdot
.57625 .54 Mdot
.55125 .53375 Mdot
.6075 .50375 Mdot
.4425 .55875 Mdot
.62375 .5675 Mdot
.185 .54 Mdot
.47125 .52875 Mdot
.5675 .52 Mdot
.8325 .62 Mdot
.24875 .57 Mdot
.4475 .5375 Mdot
.5075 .52375 Mdot
.53875 .50625 Mdot
.60625 .4625 Mdot
.6525 .5 Mdot
.26875 .5525 Mdot
.5775 .6 Mdot
.53625 .615 Mdot
.37875 .385 Mdot
.7075 .365 Mdot
.355 .40875 Mdot
.795 .45 Mdot
.22625 .4825 Mdot
.34 .48375 Mdot
.58 .48625 Mdot
.76 .49875 Mdot
.1125 .5075 Mdot
.7075 .53125 Mdot
.63 .55125 Mdot
.06125 .54 Mdot
.25375 .47375 Mdot
.265 .41375 Mdot
.93125 .385 Mdot
.0275 .41375 Mdot
.635 .42375 Mdot
.67125 .45375 Mdot
.20875 .47875 Mdot
.72375 .50875 Mdot
.725 .48 Mdot
.26625 .46625 Mdot
.835 .445 Mdot
.7375 .46 Mdot
.76625 .46375 Mdot
.21375 .46375 Mdot
.35625 .4725 Mdot
.675 .525 Mdot
.2975 .53125 Mdot
.47625 .53 Mdot
.41125 .46875 Mdot
.82625 .46125 Mdot
.11 .45875 Mdot
.06375 .45625 Mdot
.17 .475 Mdot
.825 .4725 Mdot
.40125 .51 Mdot
.9025 .535 Mdot
.1175 .50375 Mdot
.85375 .505 Mdot
.08625 .50875 Mdot
.68 .425 Mdot
.92375 .38375 Mdot
.7125 .40125 Mdot
.4525 .39375 Mdot
.38125 .46375 Mdot
.5075 .51625 Mdot
.62 .4975 Mdot
.5525 .495 Mdot
.90625 .47 Mdot
.04875 .48875 Mdot
.42625 .5475 Mdot
.95375 .61125 Mdot
.2875 .64625 Mdot
.4925 .6775 Mdot
.43625 .67375 Mdot
.68125 .63125 Mdot
.155 .5775 Mdot
.5575 .54 Mdot
.5975 .535 Mdot
.855 .5075 Mdot
.1075 .495 Mdot
.8225 .5 Mdot
.12375 .5575 Mdot
.83875 .54 Mdot
.65125 .51625 Mdot
.48 .5075 Mdot
.72625 .55375 Mdot
.55125 .55 Mdot
.22875 .5325 Mdot
.1575 .5475 Mdot
.985 .51375 Mdot
.27 .48125 Mdot
.715 .45375 Mdot
.17125 .4925 Mdot
.83125 .42625 Mdot
.17875 .46625 Mdot
.9775 .45625 Mdot
.16625 .49375 Mdot
.29375 .49375 Mdot
.5625 .5375 Mdot
.5875 .505 Mdot
.9825 .55 Mdot
.015 .51625 Mdot
.66875 .55875 Mdot
.6125 .635 Mdot
.30625 .6825 Mdot
.44 .61375 Mdot
.59625 .61875 Mdot
.6475 .535 Mdot
.185 .475 Mdot
.6025 .405 Mdot
.53125 .43375 Mdot
.67 .45 Mdot
.39375 .44875 Mdot
.60625 .46625 Mdot
.265 .48625 Mdot
.38375 .475 Mdot
.4825 .47875 Mdot
.85375 .445 Mdot
.30625 .48875 Mdot
.35125 .48625 Mdot
.675 .5525 Mdot
.39 .56125 Mdot
.6425 .655 Mdot
.68375 .6375 Mdot
.195 .61125 Mdot
.7075 .51375 Mdot
.4175 .4575 Mdot
.4525 .6275 Mdot
.67375 .665 Mdot
.35625 .66375 Mdot
.79125 .6125 Mdot
.23125 .5525 Mdot
.34875 .505 Mdot
.58375 .47375 Mdot
.7375 .45375 Mdot
.12125 .47375 Mdot
.70875 .46875 Mdot
.62125 .4825 Mdot
.0975 .56 Mdot
.275 .55875 Mdot
.27625 .57125 Mdot
.955 .57875 Mdot
.02375 .5125 Mdot
.61125 .51375 Mdot
.645 .5275 Mdot
.24 .53375 Mdot
.73875 .50625 Mdot
.72625 .51125 Mdot
.24625 .50125 Mdot
.835 .5225 Mdot
.73875 .53375 Mdot
.76875 .565 Mdot
.1825 .555 Mdot
.385 .50625 Mdot
.68 .4675 Mdot
.26 .4425 Mdot
.505 .45125 Mdot
.41125 .51375 Mdot
.8225 .51125 Mdot
.135 .46875 Mdot
.0525 .4975 Mdot
.19375 .53625 Mdot
.81125 .56 Mdot
.4075 .54375 Mdot
.86125 .53375 Mdot
.16125 .54625 Mdot
.86 .5525 Mdot
.0425 .57125 Mdot
.72 .7025 Mdot
.93375 .76125 Mdot
.86375 .72875 Mdot
.34 .68625 Mdot
.41125 .54375 Mdot
.4925 .465 Mdot
.65 .5375 Mdot
.53 .5575 Mdot
.9225 .585 Mdot
.0825 .555 Mdot
.38625 .48375 Mdot
.91125 .43625 Mdot
.355 .4025 Mdot
.44125 .39125 Mdot
.5025 .41375 Mdot
.64625 .42875 Mdot
.1775 .47 Mdot
.50875 .5025 Mdot
.6125 .5625 Mdot
.9125 .57 Mdot
.07 .57375 Mdot
.78625 .51875 Mdot
.0025 .48125 Mdot
.94875 .48625 Mdot
.58 .50625 Mdot
.47125 .47375 Mdot
.71125 .46125 Mdot
.59375 .50125 Mdot
.1925 .48625 Mdot
.17625 .48125 Mdot
.20125 .5425 Mdot
.7175 .5175 Mdot
.205 .53125 Mdot
.7875 .5425 Mdot
.19125 .54375 Mdot
.01625 .535 Mdot
.4275 .51875 Mdot
.51375 .52 Mdot
.63875 .54375 Mdot
.96375 .52875 Mdot
.78125 .45 Mdot
.47 .39125 Mdot
.48125 .36875 Mdot
.3125 .3375 Mdot
.675 .38125 Mdot
.65125 .44125 Mdot
.13125 .495 Mdot
.5975 .47 Mdot
.57625 .48125 Mdot
.6375 .47375 Mdot
.4075 .49375 Mdot
.5675 .465 Mdot
.36625 .475 Mdot
.27625 .485 Mdot
.36625 .5075 Mdot
.92 .52125 Mdot
.375 .58125 Mdot
.24625 .575 Mdot
.7275 .49875 Mdot
.325 .47625 Mdot
.7075 .42375 Mdot
.7 .3425 Mdot
.18 .33875 Mdot
.73625 .43125 Mdot
.33625 .53 Mdot
.54625 .46375 Mdot
.63 .42 Mdot
.36 .39125 Mdot
.7775 .38875 Mdot
.28625 .4425 Mdot
.3175 .47875 Mdot
.58375 .5025 Mdot
.69 .545 Mdot
.18125 .5175 Mdot
.73125 .5025 Mdot
.53 .49625 Mdot
.16125 .4575 Mdot
.31875 .4925 Mdot
.21875 .515 Mdot
.97625 .54 Mdot
.0375 .6025 Mdot
.64375 .58625 Mdot
.6325 .59125 Mdot
.25875 .5625 Mdot
.725 .5875 Mdot
.68625 .595 Mdot
.28625 .62125 Mdot
.7975 .6075 Mdot
.7275 .53875 Mdot
.78125 .48 Mdot
.16375 .47875 Mdot
.39375 .5 Mdot
.7025 .54125 Mdot
.215 .575 Mdot
.4875 .57 Mdot
.4075 .54 Mdot
.82625 .56375 Mdot
.15125 .62625 Mdot
.02375 .60625 Mdot
.2375 .54375 Mdot
.7675 .51 Mdot
.44625 .5225 Mdot
.79625 .535 Mdot
.22875 .5225 Mdot
.83625 .52375 Mdot
.7925 .45875 Mdot
.9 .445 Mdot
.955 .45125 Mdot
.225 .4825 Mdot
.48625 .54125 Mdot
.42875 .545 Mdot
.6625 .47375 Mdot
.52 .47125 Mdot
.90875 .4475 Mdot
.13375 .45875 Mdot
.3375 .48875 Mdot
.86625 .50125 Mdot
.455 .51 Mdot
.37625 .5125 Mdot
.5575 .495 Mdot
.6375 .5175 Mdot
.13625 .5125 Mdot
.5375 .49125 Mdot
.52375 .46 Mdot
.96875 .46875 Mdot
.03625 .4875 Mdot
.71875 .45625 Mdot
.98375 .43625 Mdot
.5675 .42625 Mdot
.47 .4625 Mdot
.685 .4775 Mdot
.655 .51625 Mdot
.13625 .53875 Mdot
.17875 .56 Mdot
.18875 .5025 Mdot
.6875 .4975 Mdot
.27875 .5075 Mdot
.68375 .51 Mdot
.3325 .48625 Mdot
.935 .49375 Mdot
.46625 .425 Mdot
.5175 .37875 Mdot
.65 .37 Mdot
.9325 .39125 Mdot
.9 .47875 Mdot
.25625 .4875 Mdot
.70125 .49 Mdot
.2125 .475 Mdot
.68 .47375 Mdot
.61875 .50875 Mdot
.18 .595 Mdot
.5875 .67625 Mdot
.555 .7075 Mdot
.64625 .68625 Mdot
.43875 .6475 Mdot
.5025 .58625 Mdot
.4525 .58125 Mdot
.23625 .58 Mdot
.24625 .5675 Mdot
.99625 .5025 Mdot
.45125 .4275 Mdot
.0625 .42375 Mdot
.91875 .41375 Mdot
.17 .405 Mdot
.775 .4125 Mdot
.69125 .4925 Mdot
.2 .495 Mdot
.74 .5125 Mdot
.2625 .50125 Mdot
.63125 .4925 Mdot
.58 .52125 Mdot
.325 .5425 Mdot
.78125 .58 Mdot
.335 .575 Mdot
.2925 .58375 Mdot
.57625 .56125 Mdot
.66375 .49625 Mdot
.19125 .4925 Mdot
.80625 .50625 Mdot
.47125 .46125 Mdot
.17125 .43375 Mdot
.98875 .42875 Mdot
.36875 .39125 Mdot
.14625 .355 Mdot
.0625 .35125 Mdot
.62375 .38875 Mdot
.605 .40875 Mdot
.29875 .43 Mdot
.72625 .4325 Mdot
.67125 .4225 Mdot
.29375 .405 Mdot
.77125 .39125 Mdot
.71375 .4525 Mdot
.78375 .49 Mdot
.155 .5075 Mdot
.415 .52875 Mdot
.67125 .47375 Mdot
.21 .45 Mdot
.46375 .41875 Mdot
.00625 .4075 Mdot
.38125 .43 Mdot
.84875 .4125 Mdot
.125 .38625 Mdot
.30625 .42375 Mdot
.69875 .4175 Mdot
.47375 .40375 Mdot
.77125 .3725 Mdot
.27125 .40125 Mdot
.81125 .4025 Mdot
.00125 .38875 Mdot
.795 .40625 Mdot
.86125 .42375 Mdot
.83125 .45625 Mdot
.1825 .47625 Mdot
.57875 .505 Mdot
.41 .54125 Mdot
.7225 .51625 Mdot
.445 .465 Mdot
.8875 .435 Mdot
.195 .42125 Mdot
.31375 .4 Mdot
.80875 .42125 Mdot
.51625 .43 Mdot
.345 .4475 Mdot
.61125 .4575 Mdot
.65375 .45625 Mdot
.12375 .43 Mdot
.49875 .435 Mdot
.5175 .50875 Mdot
.0225 .52 Mdot
.6025 .5425 Mdot
.56625 .5825 Mdot
.47125 .53125 Mdot
.66625 .50375 Mdot
.6275 .435 Mdot
.155 .44375 Mdot
.1975 .42875 Mdot
.19 .52125 Mdot
.6175 .5475 Mdot
.36875 .53 Mdot
.64 .50625 Mdot
.40125 .4825 Mdot
.875 .45375 Mdot
.6 .495 Mdot
.41625 .6 Mdot
.70625 .5975 Mdot
.93125 .59375 Mdot
.95375 .57375 Mdot
.12875 .54125 Mdot
.81625 .5425 Mdot
.23 .58875 Mdot
.66125 .5575 Mdot
.56125 .525 Mdot
.2275 .47 Mdot
.59875 .44 Mdot
.53 .39875 Mdot
.59375 .445 Mdot
.5125 .44625 Mdot
.48 .49375 Mdot
.51 .51375 Mdot
.15625 .5325 Mdot
.13625 .51 Mdot
.4825 .515 Mdot
.09375 .50625 Mdot
.7625 .4825 Mdot
.68375 .5 Mdot
.25 .52 Mdot
.75875 .485 Mdot
.2 .47125 Mdot
.71125 .44875 Mdot
.5425 .4225 Mdot
.29375 .41625 Mdot
.79875 .4125 Mdot
.35625 .41125 Mdot
.30625 .40375 Mdot
.545 .455 Mdot
.63625 .5125 Mdot
.225 .50375 Mdot
.8225 .4675 Mdot
.42875 .50375 Mdot
.21125 .53125 Mdot
.9525 .49375 Mdot
.40625 .4975 Mdot
.15875 .4925 Mdot
.97125 .45125 Mdot
.0625 .40125 Mdot
.65 .41625 Mdot
.59875 .44125 Mdot
.26875 .49875 Mdot
.76 .54125 Mdot
.64625 .58 Mdot
.3125 .57375 Mdot
.76875 .5625 Mdot
.65375 .52 Mdot
.85125 .49125 Mdot
.12125 .4775 Mdot
.43125 .48 Mdot
.69625 .515 Mdot
.1725 .53 Mdot
.4675 .56875 Mdot
.0125 .56625 Mdot
.39125 .545 Mdot
.855 .54125 Mdot
.09 .5225 Mdot
.385 .52125 Mdot
.59875 .55875 Mdot
.51 .58 Mdot
.765 .5975 Mdot
.305 .61375 Mdot
.77625 .6175 Mdot
.02625 .59875 Mdot
.78125 .61375 Mdot
.78875 .59125 Mdot
.11875 .57125 Mdot
.79625 .54 Mdot
.07 .52 Mdot
.70125 .4475 Mdot
.43875 .41875 Mdot
.755 .5025 Mdot
.335 .56375 Mdot
.94125 .61375 Mdot
.21 .615 Mdot
.31625 .615 Mdot
.75125 .58625 Mdot
.5475 .585 Mdot
.33375 .59375 Mdot
.6675 .60125 Mdot
.6025 .64125 Mdot
.2125 .59625 Mdot
.435 .625 Mdot
.51375 .46125 Mdot
.06625 .49125 Mdot
.05625 .585 Mdot
.47125 .52875 Mdot
.50375 .4325 Mdot
.4925 .48625 Mdot
.695 .51625 Mdot
.59875 .54 Mdot
.14375 .515 Mdot
.18625 .48375 Mdot
.1775 .36375 Mdot
.58375 .33625 Mdot
.41125 .365 Mdot
.59875 .43125 Mdot
.5075 .5075 Mdot
.78625 .545 Mdot
.73 .6025 Mdot
.33875 .49625 Mdot
.72375 .4825 Mdot
.94375 .47125 Mdot
.97 .47 Mdot
.14375 .56125 Mdot
.77875 .55125 Mdot
.23 .53 Mdot
.67 .48875 Mdot
.55375 .5 Mdot
.23625 .38625 Mdot
.66125 .3775 Mdot
.4775 .385 Mdot
.54375 .35 Mdot
.56625 .31875 Mdot
.4325 .37875 Mdot
.56375 .3525 Mdot
.1575 .34375 Mdot
.105 .4575 Mdot
.4825 .56 Mdot
.1875 .68125 Mdot
.6425 .695 Mdot
.7025 .6325 Mdot
.30375 .57125 Mdot
.7575 .5375 Mdot
.1325 .49125 Mdot
.73375 .62625 Mdot
.535 .66625 Mdot
.25875 .675 Mdot
.82375 .66125 Mdot
.37625 .61125 Mdot
.27875 .59 Mdot
.54 .50125 Mdot
.64 .44125 Mdot
.225 .465 Mdot
.82625 .51375 Mdot
.44625 .52625 Mdot
.17625 .56 Mdot
.9625 .64375 Mdot
.4425 .70875 Mdot
.1425 .79375 Mdot
.965 .8475 Mdot
.02375 .88375 Mdot
.695 .80625 Mdot
.6175 .6825 Mdot
.2375 .56 Mdot
.77875 .465 Mdot
.6125 .41125 Mdot
.355 .42875 Mdot
.72 .46125 Mdot
.03125 .4675 Mdot
.57875 .4825 Mdot
.94625 .5125 Mdot
.05 .4875 Mdot
.4525 .4575 Mdot
.70625 .45625 Mdot
.1725 .43625 Mdot
.505 .43875 Mdot
.0025 .47375 Mdot
.4025 .475 Mdot
.85125 .50125 Mdot
.06375 .53875 Mdot
.45 .52625 Mdot
.49875 .50375 Mdot
.5675 .5025 Mdot
.72625 .49375 Mdot
.33 .4825 Mdot
.755 .49875 Mdot
.0975 .4875 Mdot
.725 .49625 Mdot
.70375 .47125 Mdot
.2875 .455 Mdot
.6875 .43125 Mdot
.055 .48 Mdot
.7875 .48375 Mdot
.4175 .52375 Mdot
.9475 .55875 Mdot
.82375 .50875 Mdot
.19375 .4775 Mdot
.2125 .4475 Mdot
.33125 .4425 Mdot
.71375 .435 Mdot
.56 .40875 Mdot
.32375 .35375 Mdot
.74375 .34125 Mdot
.52375 .29375 Mdot
.30375 .43875 Mdot
.4075 .4325 Mdot
.55625 .525 Mdot
.14625 .39375 Mdot
.8725 .37375 Mdot
.25125 .405 Mdot
.3025 .42375 Mdot
.065 .46875 Mdot
.50875 .585 Mdot
.45 .56375 Mdot
.7225 .55125 Mdot
.53625 .5225 Mdot
.18125 .5175 Mdot
.16125 .52125 Mdot
.1 .5425 Mdot
.605 .5825 Mdot
.42 .53375 Mdot
.57 .46875 Mdot
.55875 .42375 Mdot
.7725 .45625 Mdot
.81 .415 Mdot
.31625 .465 Mdot
.72375 .52 Mdot
.93875 .4725 Mdot
.92875 .46625 Mdot
.2475 .4325 Mdot
.6975 .44625 Mdot
.24875 .5025 Mdot
.6775 .53 Mdot
.5175 .5425 Mdot
.255 .625 Mdot
.69625 .59125 Mdot
.41875 .56375 Mdot
.55875 .60375 Mdot
.5925 .66625 Mdot
.4425 .6175 Mdot
.55875 .63625 Mdot
.17125 .6325 Mdot
.01 .5325 Mdot
.145 .4925 Mdot
.49875 .41375 Mdot
.32 .39625 Mdot
.5625 .4275 Mdot
.68 .495 Mdot
.325 .53625 Mdot
.785 .5425 Mdot
.105 .60375 Mdot
.75625 .44875 Mdot
.51875 .4325 Mdot
.22 .4175 Mdot
.8275 .42125 Mdot
.43375 .45 Mdot
.2475 .46 Mdot
.50375 .5325 Mdot
.67125 .5725 Mdot
.24 .56 Mdot
.8375 .53 Mdot
.41625 .5075 Mdot
.13875 .445 Mdot
.4225 .4175 Mdot
.14 .355 Mdot
.9325 .34625 Mdot
.78125 .39875 Mdot
.61875 .4575 Mdot
.215 .535 Mdot
.81 .55 Mdot
.54625 .545 Mdot
.3975 .5375 Mdot
.71875 .5125 Mdot
.0225 .51 Mdot
.555 .53625 Mdot
.99125 .5175 Mdot
.015 .54625 Mdot
.4675 .59625 Mdot
.715 .59125 Mdot
.1875 .60375 Mdot
.515 .58 Mdot
.0425 .5225 Mdot
.38 .52625 Mdot
.86125 .495 Mdot
.02125 .465 Mdot
.51125 .46 Mdot
.41625 .48625 Mdot
.6 .46625 Mdot
.76125 .4525 Mdot
.28875 .43625 Mdot
.735 .4225 Mdot
.18 .4225 Mdot
.69375 .37625 Mdot
.58125 .41125 Mdot
.455 .4225 Mdot
.56625 .4175 Mdot
.09375 .4275 Mdot
.81625 .475 Mdot
.48125 .45625 Mdot
.775 .44375 Mdot
.885 .46625 Mdot
.085 .49125 Mdot
.2475 .53375 Mdot
.34875 .56875 Mdot
.685 .58 Mdot
.55625 .6175 Mdot
.2725 .59625 Mdot
.88 .5875 Mdot
.37875 .58375 Mdot
.4575 .495 Mdot
.3975 .465 Mdot
.92375 .5025 Mdot
.5875 .47875 Mdot
.93875 .58875 Mdot
.2975 .58 Mdot
.65875 .54875 Mdot
.455 .535 Mdot
.10625 .52375 Mdot
.26375 .465 Mdot
.44625 .3575 Mdot
.475 .37375 Mdot
.7925 .3775 Mdot
.405 .4275 Mdot
.23875 .4625 Mdot
.1425 .48 Mdot
.1025 .51125 Mdot
.5875 .46375 Mdot
.415 .4925 Mdot
.625 .51375 Mdot
.49125 .505 Mdot
.85125 .44875 Mdot
.84375 .485 Mdot
.34 .48125 Mdot
.65375 .46 Mdot
.945 .48625 Mdot
.78875 .5675 Mdot
.41625 .545 Mdot
.56125 .51125 Mdot
.31125 .46875 Mdot
.675 .4075 Mdot
.4475 .34625 Mdot
.3425 .37375 Mdot
.68375 .43 Mdot
.34625 .4925 Mdot
.63625 .47625 Mdot
.56625 .4225 Mdot
.45 .4 Mdot
.5625 .3825 Mdot
.18 .33 Mdot
.3125 .425 Mdot
.5325 .47125 Mdot
.42875 .46 Mdot
.47875 .45125 Mdot
.69 .44125 Mdot
.32375 .42875 Mdot
.7825 .46375 Mdot
.1175 .45 Mdot
.76 .48125 Mdot
.51375 .48375 Mdot
.21625 .47875 Mdot
.81875 .45 Mdot
.43875 .46 Mdot
.25375 .475 Mdot
.465 .44875 Mdot
.7325 .4325 Mdot
.18125 .46125 Mdot
.9 .4625 Mdot
.40875 .46375 Mdot
.10375 .4925 Mdot
.42875 .42375 Mdot
.1825 .4275 Mdot
.87375 .395 Mdot
.78625 .37 Mdot
.62 .39125 Mdot
.18625 .3775 Mdot
.88125 .45625 Mdot
.4725 .4825 Mdot
.44875 .4925 Mdot
.71125 .50625 Mdot
.0275 .535 Mdot
.5175 .4825 Mdot
.5 .46 Mdot
.695 .455 Mdot
.20625 .46375 Mdot
.50125 .48625 Mdot
.0725 .5075 Mdot
.385 .50375 Mdot
.84375 .505 Mdot
.54875 .5325 Mdot
.39 .5275 Mdot
.57 .5375 Mdot
.8025 .56375 Mdot
.27 .57625 Mdot
.70375 .575 Mdot
.275 .62125 Mdot
.66875 .6675 Mdot
.50625 .655 Mdot
.50875 .6825 Mdot
.49625 .70625 Mdot
.16625 .6225 Mdot
.80375 .60375 Mdot
.53375 .59875 Mdot
.6125 .55625 Mdot
.09 .50625 Mdot
.84875 .535 Mdot
.005 .49875 Mdot
.2325 .44625 Mdot
.38125 .43375 Mdot
.67125 .43625 Mdot
.51125 .45125 Mdot
.25625 .53 Mdot
.21 .59125 Mdot
.625 .6175 Mdot
.3725 .5925 Mdot
.88375 .55375 Mdot
.7325 .55375 Mdot
.79625 .48875 Mdot
.505 .50625 Mdot
.45 .52125 Mdot
.6325 .48875 Mdot
.51 .51 Mdot
.47625 .64875 Mdot
.42 .63125 Mdot
.93375 .635 Mdot
.18625 .5925 Mdot
.3825 .5575 Mdot
.13875 .5425 Mdot
.14 .565 Mdot
.5775 .605 Mdot
.3875 .55875 Mdot
.705 .55875 Mdot
.36 .5575 Mdot
.89875 .5525 Mdot
.72875 .53125 Mdot
.3825 .52375 Mdot
.62875 .525 Mdot
.95125 .55375 Mdot
.67625 .48125 Mdot
.57875 .4775 Mdot
.465 .51 Mdot
.30625 .50875 Mdot
.75 .6075 Mdot
.36 .64125 Mdot
.40625 .61 Mdot
.66375 .54875 Mdot
.3525 .48375 Mdot
.605 .44625 Mdot
.58375 .495 Mdot
.49 .535 Mdot
.49625 .54625 Mdot
.22125 .5875 Mdot
.59625 .5525 Mdot
.8275 .57125 Mdot
.52625 .5875 Mdot
.985 .57125 Mdot
.53875 .5175 Mdot
.41625 .465 Mdot
.69625 .44625 Mdot
.33625 .4875 Mdot
.76375 .48125 Mdot
.13 .46875 Mdot
.74 .5025 Mdot
.51 .485 Mdot
.235 .48875 Mdot
.81125 .5175 Mdot
.40625 .49375 Mdot
.3275 .47 Mdot
.40125 .47875 Mdot
.75125 .49 Mdot
.1825 .4625 Mdot
.9325 .4825 Mdot
.35125 .51 Mdot
.15125 .5175 Mdot
.39 .54875 Mdot
.26125 .55125 Mdot
.78625 .56125 Mdot
.8 .55625 Mdot
.65125 .57375 Mdot
.1625 .58625 Mdot
.88125 .5275 Mdot
.42875 .54 Mdot
.49625 .51125 Mdot
.71125 .49125 Mdot
.015 .46375 Mdot
.525 .49125 Mdot
.53875 .48625 Mdot
.69625 .49125 Mdot
.19875 .47375 Mdot
.53125 .4775 Mdot
.06625 .4925 Mdot
.4075 .51 Mdot
.7925 .515 Mdot
.0325 .50875 Mdot
.0525 .51 Mdot
.54 .45875 Mdot
.40125 .43375 Mdot
.5625 .43125 Mdot
.81 .41875 Mdot
.225 .42125 Mdot
.705 .465 Mdot
.37625 .43125 Mdot
.60875 .38875 Mdot
.47125 .38 Mdot
.51 .37125 Mdot
.53125 .34625 Mdot
.16875 .3975 Mdot
.77125 .4175 Mdot
.62875 .44 Mdot
.44 .425 Mdot
.24125 .46 Mdot
.7925 .40125 Mdot
.015 .3925 Mdot
.1675 .44375 Mdot
.4675 .44625 Mdot
.65375 .475 Mdot
.4625 .47 Mdot
.26375 .42375 Mdot
.085 .3475 Mdot
.7025 .3325 Mdot
.46375 .37375 Mdot
.72375 .4275 Mdot
.82625 .505 Mdot
.6 .5725 Mdot
.74875 .58 Mdot
.27625 .56125 Mdot
.74375 .6175 Mdot
.7275 .585 Mdot
.50375 .44125 Mdot
.36625 .42125 Mdot
.00375 .47125 Mdot
.45625 .50875 Mdot
.17 .51375 Mdot
.26 .4925 Mdot
.62125 .485 Mdot
.3075 .5125 Mdot
.73875 .485 Mdot
.335 .49625 Mdot
.84875 .525 Mdot
.04875 .5275 Mdot
.52125 .52 Mdot
.5075 .54375 Mdot
.615 .5125 Mdot
.915 .4875 Mdot
.01 .45875 Mdot
.5775 .44375 Mdot
.675 .44625 Mdot
.455 .4225 Mdot
.2825 .42 Mdot
.75375 .39875 Mdot
.30625 .42625 Mdot
.50875 .44875 Mdot
.6025 .52 Mdot
.41875 .58375 Mdot
.56 .62 Mdot
.56625 .58375 Mdot
.5325 .55625 Mdot
.37375 .565 Mdot
.36 .54 Mdot
.88875 .55125 Mdot
.6225 .5175 Mdot
.49125 .51625 Mdot
.925 .51875 Mdot
.5425 .5425 Mdot
.3875 .57 Mdot
.7525 .5575 Mdot
.30875 .52875 Mdot
.765 .5275 Mdot
.14 .5175 Mdot
.71625 .46 Mdot
.47125 .47375 Mdot
.31375 .46625 Mdot
.805 .48 Mdot
.335 .52375 Mdot
.43375 .5525 Mdot
.30875 .53375 Mdot
.77375 .54875 Mdot
.175 .55375 Mdot
.9975 .56375 Mdot
.29 .52375 Mdot
.17875 .52375 Mdot
.3875 .47375 Mdot
.26375 .46875 Mdot
.76625 .4825 Mdot
.04 .4775 Mdot
.745 .48125 Mdot
.685 .46625 Mdot
.17375 .41625 Mdot
.8675 .415 Mdot
.3975 .4025 Mdot
.5625 .4275 Mdot
.67125 .4375 Mdot
.57875 .4625 Mdot
.605 .49125 Mdot
.6475 .5025 Mdot
.24125 .525 Mdot
.995 .5125 Mdot
.51 .51 Mdot
.085 .505 Mdot
.44875 .4775 Mdot
.71625 .4825 Mdot
.08375 .51 Mdot
.96625 .51375 Mdot
.10125 .49875 Mdot
.52 .51125 Mdot
.4175 .51125 Mdot
.55875 .4975 Mdot
.80125 .49 Mdot
.21875 .45375 Mdot
.6725 .39625 Mdot
.48875 .46 Mdot
.53375 .5 Mdot
.505 .52125 Mdot
.44375 .5425 Mdot
.52125 .585 Mdot
.2875 .49 Mdot
.65625 .41125 Mdot
.66 .4175 Mdot
.455 .4375 Mdot
.23125 .43625 Mdot
.7675 .55875 Mdot
.07875 .6625 Mdot
.0875 .67 Mdot
.56875 .65875 Mdot
.635 .60625 Mdot
.4275 .585 Mdot
.28375 .6075 Mdot
.02875 .61125 Mdot
.68125 .59875 Mdot
.6325 .59 Mdot
.54375 .52 Mdot
.94375 .4325 Mdot
.38 .4175 Mdot
.96125 .39125 Mdot
.12 .40375 Mdot
.895 .385 Mdot
.93875 .4275 Mdot
.58 .49125 Mdot
.3125 .45625 Mdot
.46875 .43875 Mdot
.26875 .42875 Mdot
.875 .44125 Mdot
.32875 .48625 Mdot
.66375 .4725 Mdot
.21 .50375 Mdot
.815 .4825 Mdot
.29375 .52875 Mdot
.81375 .5 Mdot
.195 .505 Mdot
.3725 .47 Mdot
.54 .515 Mdot
.67 .4725 Mdot
.865 .48125 Mdot
.05375 .50125 Mdot
.53375 .515 Mdot
.63 .50125 Mdot
.53625 .5125 Mdot
.24375 .52875 Mdot
.78875 .52 Mdot
.26125 .50375 Mdot
.57875 .50625 Mdot
.52125 .49875 Mdot
.50375 .4725 Mdot
.5325 .49625 Mdot
.5125 .4975 Mdot
.625 .50875 Mdot
.22125 .51 Mdot
.50875 .5125 Mdot
.42375 .51375 Mdot
.485 .51875 Mdot
.1075 .5225 Mdot
.80125 .53375 Mdot
.52625 .545 Mdot
.42625 .5475 Mdot
.76125 .5375 Mdot
.305 .5275 Mdot
.745 .5 Mdot
.17125 .47125 Mdot
.67875 .535 Mdot
.4675 .545 Mdot
.38625 .525 Mdot
.78875 .51875 Mdot
.3 .5 Mdot
.4875 .47375 Mdot
.225 .46375 Mdot
.8175 .47 Mdot
.1675 .445 Mdot
.1875 .4925 Mdot
.22375 .4775 Mdot
1 .48875 Mdot
.43375 .5275 Mdot
.25625 .53125 Mdot
.71875 .49 Mdot
.13875 .51875 Mdot
.65125 .54125 Mdot
.69375 .51625 Mdot
.21375 .55 Mdot
.84125 .56625 Mdot
.41 .5625 Mdot
.55 .52625 Mdot
.68625 .57125 Mdot
.6025 .5675 Mdot
.68125 .52875 Mdot
.625 .5 Mdot
.23 .48125 Mdot
.99875 .475 Mdot
.48125 .4675 Mdot
.1125 .44875 Mdot
.505 .46875 Mdot
.6125 .45625 Mdot
.1575 .45125 Mdot
.92125 .4775 Mdot
.1 .47375 Mdot
.54625 .48875 Mdot
.3875 .51875 Mdot
.57625 .525 Mdot
.81625 .545 Mdot
.20375 .59625 Mdot
.5925 .5825 Mdot
.64625 .48125 Mdot
.46 .45 Mdot
.545 .445 Mdot
.345 .41125 Mdot
.53875 .395 Mdot
.395 .5375 Mdot
.52875 .64 Mdot
.76 .6225 Mdot
.41125 .625 Mdot
.23375 .65875 Mdot
.72375 .57 Mdot
.17125 .45125 Mdot
.68375 .41875 Mdot
.6175 .4425 Mdot
.40875 .4475 Mdot
.30125 .4525 Mdot
.105 .4375 Mdot
.5525 .42625 Mdot
.8075 .4425 Mdot
.425 .45375 Mdot
.99375 .50375 Mdot
.165 .50375 Mdot
.05875 .51375 Mdot
.94375 .51 Mdot
.13125 .48875 Mdot
.8825 .50375 Mdot
.6125 .51375 Mdot
.325 .58375 Mdot
.385 .54 Mdot
.3825 .51375 Mdot
.7775 .4475 Mdot
.37375 .39875 Mdot
.6775 .3675 Mdot
.17125 .41 Mdot
.85875 .485 Mdot
.305 .46 Mdot
.69 .47875 Mdot
.36625 .49625 Mdot
.25375 .51 Mdot
.54125 .46625 Mdot
.74625 .54625 Mdot
.81 .5725 Mdot
.00875 .58 Mdot
.68625 .56875 Mdot
.445 .635 Mdot
.62375 .62125 Mdot
.25625 .5875 Mdot
.74875 .585 Mdot
.3075 .5475 Mdot
.5725 .4925 Mdot
.5175 .4775 Mdot
.52875 .495 Mdot
.535 .51375 Mdot
.4575 .53625 Mdot
.6625 .5125 Mdot
.09 .47875 Mdot
.70875 .49125 Mdot
.30375 .44375 Mdot
.465 .41875 Mdot
.26375 .41875 Mdot
.61875 .41375 Mdot
.6225 .39875 Mdot
.3675 .42875 Mdot
.8175 .43625 Mdot
.2825 .46375 Mdot
.74625 .485 Mdot
.17375 .52625 Mdot
.61 .435 Mdot
.47 .44 Mdot
.46125 .46625 Mdot
.79 .47625 Mdot
.26 .50875 Mdot
.515 .52875 Mdot
.18125 .54875 Mdot
.805 .5375 Mdot
.18375 .55625 Mdot
.09 .48875 Mdot
.3125 .50125 Mdot
.9225 .49125 Mdot
.48 .46375 Mdot
.25375 .47125 Mdot
.67875 .5225 Mdot
.25 .495 Mdot
.52875 .48125 Mdot
.71 .49 Mdot
.2575 .4825 Mdot
.7875 .4775 Mdot
.4925 .4975 Mdot
.49 .53 Mdot
.69375 .50375 Mdot
.5775 .445 Mdot
.7325 .3925 Mdot
.59 .42625 Mdot
.255 .43625 Mdot
.975 .44125 Mdot
.50875 .47625 Mdot
.07125 .49 Mdot
.58875 .49125 Mdot
.48625 .52 Mdot
.25625 .50375 Mdot
.85375 .4875 Mdot
.13375 .49 Mdot
.575 .51625 Mdot
.3375 .50875 Mdot
.64375 .52125 Mdot
.7475 .505 Mdot
.24125 .48875 Mdot
.5125 .51625 Mdot
.77875 .61 Mdot
.4025 .63 Mdot
.56125 .62 Mdot
.29 .65625 Mdot
.53875 .66375 Mdot
.48625 .53875 Mdot
.44125 .51625 Mdot
.78 .50875 Mdot
.43625 .45375 Mdot
.23 .39375 Mdot
.68125 .43625 Mdot
.25375 .42875 Mdot
.79 .51125 Mdot
.59375 .54875 Mdot
.4225 .57375 Mdot
.35 .565 Mdot
.90375 .5825 Mdot
.2475 .5625 Mdot
.33625 .52625 Mdot
.32875 .505 Mdot
.9775 .495 Mdot
.05125 .4925 Mdot
.14125 .485 Mdot
.8925 .4875 Mdot
.30625 .57625 Mdot
.7125 .58 Mdot
.65625 .5625 Mdot
.36 .52625 Mdot
.26875 .535 Mdot
.47375 .63375 Mdot
.8025 .685 Mdot
.34 .74125 Mdot
.6425 .77125 Mdot
.2475 .69 Mdot
.755 .66 Mdot
.47125 .60875 Mdot
.54125 .635 Mdot
.425 .6275 Mdot
.22 .6 Mdot
.53 .53875 Mdot
.83125 .51375 Mdot
.73125 .48 Mdot
.87875 .52 Mdot
.2275 .43875 Mdot
.69125 .42375 Mdot
.3275 .41125 Mdot
.645 .395 Mdot
.41125 .41 Mdot
.49 .5 Mdot
.55625 .53375 Mdot
.5525 .5125 Mdot
.52625 .47 Mdot
.43375 .4525 Mdot
.665 .4825 Mdot
.0125 .49375 Mdot
.865 .46625 Mdot
.9225 .49375 Mdot
.25875 .52875 Mdot
.42625 .5775 Mdot
.40875 .59625 Mdot
.4775 .625 Mdot
.6375 .64375 Mdot
.405 .58125 Mdot
.80375 .5625 Mdot
.2875 .52375 Mdot
.70625 .50125 Mdot
.23375 .46 Mdot
.475 .5775 Mdot
.52 .5375 Mdot
.50875 .5475 Mdot
.805 .51625 Mdot
.22125 .47375 Mdot
.5225 .47 Mdot
.17 .47875 Mdot
.75875 .4575 Mdot
.24875 .48875 Mdot
.0275 .4875 Mdot
.34375 .4825 Mdot
.9 .48875 Mdot
.49625 .48375 Mdot
.28875 .5125 Mdot
.63125 .535 Mdot
.30875 .53875 Mdot
.47 .5175 Mdot
.70125 .515 Mdot
.29125 .50625 Mdot
.74625 .49125 Mdot
.5825 .4475 Mdot
.4025 .45 Mdot
.7175 .44125 Mdot
.01875 .45125 Mdot
.59 .46625 Mdot
1 .52125 Mdot
.77625 .5925 Mdot
.5625 .585 Mdot
.26875 .59875 Mdot
.95375 .6125 Mdot
.54375 .5775 Mdot
.035 .57125 Mdot
.6575 .57 Mdot
.37 .53875 Mdot
.37 .5475 Mdot
.82125 .5525 Mdot
.12625 .5575 Mdot
.61 .52875 Mdot
.27875 .5 Mdot
.7275 .5025 Mdot
.6775 .46625 Mdot
.28375 .44625 Mdot
.41375 .44125 Mdot
.91625 .41 Mdot
.3575 .3875 Mdot
.5425 .40125 Mdot
.25625 .38875 Mdot
.57125 .36 Mdot
.54 .40625 Mdot
.38 .41875 Mdot
.79375 .4475 Mdot
.48125 .51875 Mdot
.13 .5675 Mdot
.695 .55 Mdot
.3525 .57375 Mdot
.95 .53125 Mdot
.90875 .46125 Mdot
.565 .44375 Mdot
.44125 .405 Mdot
.4075 .46125 Mdot
.7175 .46875 Mdot
.435 .46375 Mdot
.14625 .47625 Mdot
.26625 .4925 Mdot
.0575 .48875 Mdot
.97125 .4975 Mdot
.24625 .50125 Mdot
.8375 .51375 Mdot
.5075 .43625 Mdot
.6225 .45125 Mdot
.6075 .4225 Mdot
.425 .45625 Mdot
.13 .4475 Mdot
.07375 .39 Mdot
.5675 .37375 Mdot
.87 .33 Mdot
.28625 .3175 Mdot
.6125 .36875 Mdot
.33375 .40375 Mdot
.61875 .42375 Mdot
.6075 .47375 Mdot
.505 .44625 Mdot
.30875 .43375 Mdot
.39125 .45125 Mdot
.415 .48875 Mdot
.89375 .435 Mdot
.65375 .47875 Mdot
.03625 .4525 Mdot
.71625 .53 Mdot
.44 .5325 Mdot
.5325 .54875 Mdot
.50125 .59625 Mdot
.39625 .53 Mdot
.65625 .50375 Mdot
.4575 .49625 Mdot
.6325 .4775 Mdot
.345 .46 Mdot
.6725 .46875 Mdot
.99375 .48375 Mdot
.81375 .4725 Mdot
.30875 .48875 Mdot
.345 .3925 Mdot
.50625 .41 Mdot
.4425 .39 Mdot
.57875 .3625 Mdot
.46625 .36125 Mdot
.79375 .45625 Mdot
.27 .49125 Mdot
.695 .51375 Mdot
.31375 .54 Mdot
.35875 .47 Mdot
.56125 .51625 Mdot
.56125 .5325 Mdot
.79625 .56625 Mdot
.2375 .6 Mdot
.43625 .6 Mdot
.255 .595 Mdot
.685 .56875 Mdot
.315 .5 Mdot
.00875 .49875 Mdot
.34125 .48625 Mdot
.87375 .5025 Mdot
.555 .53 Mdot
.30375 .49375 Mdot
.54875 .4425 Mdot
.4075 .44125 Mdot
.415 .45125 Mdot
.66625 .45375 Mdot
.30375 .48 Mdot
.7625 .485 Mdot
.6425 .51625 Mdot
.31625 .515 Mdot
.7775 .5275 Mdot
0 .52625 Mdot
.5675 .5575 Mdot
.995 .54125 Mdot
.79375 .5 Mdot
.54375 .48 Mdot
.27 .46875 Mdot
.93625 .46875 Mdot
.575 .5025 Mdot
.01875 .5075 Mdot
.71125 .52125 Mdot
.28875 .52625 Mdot
.425 .5275 Mdot
.825 .535 Mdot
.11125 .5275 Mdot
.64875 .52875 Mdot
.2325 .545 Mdot
.78125 .54875 Mdot
.60625 .59875 Mdot
.36625 .62375 Mdot
.28625 .63625 Mdot
.3575 .58375 Mdot
.51125 .5525 Mdot
.22375 .5325 Mdot
.56 .545 Mdot
.62375 .56375 Mdot
.33125 .5325 Mdot
.74375 .51125 Mdot
.5975 .485 Mdot
.02 .45 Mdot
.715 .44 Mdot
.40875 .46625 Mdot
.93125 .48875 Mdot
.94 .4925 Mdot
.57375 .51875 Mdot
.4775 .55 Mdot
.4225 .535 Mdot
.59875 .55625 Mdot
.54875 .58625 Mdot
.0175 .5925 Mdot
.23625 .55375 Mdot
.15375 .5525 Mdot
.91625 .54625 Mdot
.01375 .565 Mdot
.34375 .58125 Mdot
.79625 .53125 Mdot
.8725 .47125 Mdot
.6725 .49625 Mdot
.5725 .50125 Mdot
.58125 .56625 Mdot
.485 .555 Mdot
.93125 .55 Mdot
.28375 .54875 Mdot
.64875 .51 Mdot
.18875 .48375 Mdot
.5325 .4375 Mdot
.4475 .395 Mdot
.52875 .385 Mdot
.69125 .38375 Mdot
.5 .36875 Mdot
.16625 .43 Mdot
.55875 .46875 Mdot
.30375 .44375 Mdot
.95 .4975 Mdot
.62125 .48 Mdot
.7025 .47375 Mdot
.48875 .52125 Mdot
.51 .50875 Mdot
.55125 .495 Mdot
.33875 .4775 Mdot
.74375 .4575 Mdot
.265 .445 Mdot
.79375 .44 Mdot
.2925 .465 Mdot
.68125 .4475 Mdot
.64 .51625 Mdot
.4075 .4825 Mdot
.25375 .55625 Mdot
.595 .5275 Mdot
.3325 .55 Mdot
.6275 .575 Mdot
.48875 .6325 Mdot
.78875 .51625 Mdot
.23625 .53 Mdot
.70875 .50625 Mdot
.37 .4975 Mdot
.2425 .53125 Mdot
.605 .515 Mdot
.59875 .45625 Mdot
.785 .43875 Mdot
.275 .4225 Mdot
.32 .415 Mdot
.38375 .4125 Mdot
.59 .4575 Mdot
.38375 .53 Mdot
.02125 .5375 Mdot
.335 .52375 Mdot
.86625 .50625 Mdot
.55375 .47625 Mdot
.39125 .47875 Mdot
.415 .515 Mdot
.5075 .545 Mdot
.38375 .55 Mdot
.6075 .5575 Mdot
.3525 .55375 Mdot
.76125 .55 Mdot
.67875 .5425 Mdot
.2175 .54125 Mdot
.88 .54 Mdot
.01375 .54625 Mdot
.49625 .5275 Mdot
.80625 .50875 Mdot
.5525 .51625 Mdot
.2425 .50625 Mdot
.915 .48875 Mdot
.66375 .44625 Mdot
.75875 .42875 Mdot
.2225 .41625 Mdot
.4825 .39875 Mdot
.7875 .39 Mdot
.0975 .41375 Mdot
.6925 .4275 Mdot
.195 .41625 Mdot
.80875 .4075 Mdot
.575 .39875 Mdot
.40625 .37375 Mdot
.19875 .37 Mdot
.3825 .4525 Mdot
.435 .4925 Mdot
.2575 .52375 Mdot
.49875 .5575 Mdot
.72625 .52 Mdot
.31 .53875 Mdot
.7 .5425 Mdot
.63125 .53625 Mdot
.73875 .545 Mdot
.43625 .53125 Mdot
.88625 .5275 Mdot
.95125 .5375 Mdot
.57875 .49625 Mdot
.5175 .47 Mdot
.41375 .42875 Mdot
.5575 .41875 Mdot
.58875 .40625 Mdot
.2575 .43125 Mdot
.21875 .42875 Mdot
.8175 .445 Mdot
.16875 .42875 Mdot
.90375 .44 Mdot
.4725 .445 Mdot
.7175 .46875 Mdot
.68 .49875 Mdot
.7325 .52 Mdot
.59375 .50875 Mdot
.5675 .47625 Mdot
.5375 .47875 Mdot
.79375 .48 Mdot
.32375 .475 Mdot
.60375 .50375 Mdot
.105 .61375 Mdot
.4625 .645 Mdot
.5975 .65875 Mdot
.425 .63625 Mdot
.6975 .58125 Mdot
.5475 .57625 Mdot
.07125 .52375 Mdot
.65 .50375 Mdot
.23875 .52375 Mdot
.5725 .48125 Mdot
.64625 .4925 Mdot
.56 .51125 Mdot
.47 .51375 Mdot
.5275 .55875 Mdot
.38 .5725 Mdot
.8025 .5975 Mdot
.06 .6 Mdot
.94125 .62375 Mdot
.2775 .5575 Mdot
.6475 .5675 Mdot
.5 .50625 Mdot
.57125 .53875 Mdot
.21125 .51375 Mdot
.565 .52 Mdot
.315 .47375 Mdot
.65625 .465 Mdot
.52125 .47125 Mdot
.80375 .49375 Mdot
.165 .5 Mdot
.73 .51 Mdot
.43 .5075 Mdot
.12 .465 Mdot
.64875 .44875 Mdot
.6275 .48 Mdot
.76125 .44375 Mdot
.28875 .43375 Mdot
.25875 .42875 Mdot
.49625 .4425 Mdot
.4875 .43375 Mdot
.4525 .4375 Mdot
.08125 .48875 Mdot
.365 .50375 Mdot
.81125 .53375 Mdot
.51 .54375 Mdot
.575 .54 Mdot
.235 .51125 Mdot
.585 .49875 Mdot
.39125 .4725 Mdot
.545 .46375 Mdot
.38625 .44875 Mdot
.7675 .44 Mdot
.59625 .45625 Mdot
.33125 .46625 Mdot
.9075 .46625 Mdot
.49375 .47 Mdot
.965 .44625 Mdot
.79 .45 Mdot
.5375 .455 Mdot
.27875 .44125 Mdot
.86625 .445 Mdot
.7275 .45125 Mdot
.78125 .495 Mdot
.19 .54625 Mdot
.5425 .5675 Mdot
.7525 .5525 Mdot
.12625 .52125 Mdot
.7075 .51625 Mdot
.17 .5325 Mdot
.8275 .5325 Mdot
.56 .54625 Mdot
.43125 .54875 Mdot
.13625 .5225 Mdot
.43625 .48625 Mdot
.33 .46875 Mdot
.3625 .44875 Mdot
.40125 .42625 Mdot
.83125 .4625 Mdot
.29875 .43 Mdot
.60125 .41125 Mdot
.67875 .42875 Mdot
.745 .435 Mdot
.49 .46 Mdot
.82 .4775 Mdot
.96375 .5025 Mdot
.54375 .50875 Mdot
.5475 .52125 Mdot
.43 .54 Mdot
.53875 .54375 Mdot
.56375 .54375 Mdot
.07 .5825 Mdot
.285 .56 Mdot
.29 .55875 Mdot
.69375 .575 Mdot
.41125 .55875 Mdot
.67375 .55125 Mdot
.56375 .53875 Mdot
.64125 .5275 Mdot
.525 .4775 Mdot
.7475 .45875 Mdot
.6175 .48 Mdot
.595 .50375 Mdot
.5475 .515 Mdot
.6975 .5425 Mdot
.27375 .54625 Mdot
.13375 .5175 Mdot
.45375 .47375 Mdot
.03 .3775 Mdot
.44125 .36875 Mdot
.6925 .42875 Mdot
.32625 .45875 Mdot
.7075 .53 Mdot
.59875 .56 Mdot
.0275 .5325 Mdot
.69 .48375 Mdot
.20625 .485 Mdot
.4925 .4875 Mdot
.0075 .56625 Mdot
.55625 .55875 Mdot
.60375 .54 Mdot
.47625 .57125 Mdot
.47875 .50875 Mdot
.41375 .49625 Mdot
.84875 .4325 Mdot
.2875 .47125 Mdot
.62375 .48875 Mdot
.0675 .52875 Mdot
.46 .525 Mdot
.99875 .48 Mdot
.595 .5275 Mdot
.22375 .47375 Mdot
.48875 .47 Mdot
.43125 .47 Mdot
.55375 .4375 Mdot
.6325 .395 Mdot
.73625 .4525 Mdot
.1725 .4275 Mdot
.71125 .44125 Mdot
.52375 .4625 Mdot
.0825 .51125 Mdot
.6325 .525 Mdot
.6975 .52 Mdot
.69375 .54125 Mdot
.3175 .56375 Mdot
.21625 .57875 Mdot
.6025 .57875 Mdot
.4075 .57375 Mdot
.485 .54875 Mdot
.9675 .5225 Mdot
.11375 .5075 Mdot
.38875 .5025 Mdot
.755 .505 Mdot
.4925 .51625 Mdot
.73125 .52 Mdot
.08125 .5225 Mdot
.63 .50625 Mdot
.44 .52875 Mdot
.4675 .54 Mdot
.42875 .54625 Mdot
.7575 .5325 Mdot
.51125 .525 Mdot
.49 .525 Mdot
.83625 .5225 Mdot
.49 .57 Mdot
.9175 .5925 Mdot
.78375 .5975 Mdot
.525 .58875 Mdot
.2925 .63375 Mdot
.86125 .6475 Mdot
.70375 .655 Mdot
.78125 .56375 Mdot
.1775 .48625 Mdot
.61 .46 Mdot
.72125 .5 Mdot
.16375 .53 Mdot
.68125 .51625 Mdot
.20875 .52 Mdot
.7925 .50375 Mdot
.57125 .48625 Mdot
.44375 .48375 Mdot
.07625 .51625 Mdot
.47375 .54 Mdot
.305 .5075 Mdot
.37125 .51625 Mdot
.3125 .52625 Mdot
.9525 .53625 Mdot
.29125 .5625 Mdot
.53875 .60375 Mdot
.685 .60625 Mdot
.78625 .59625 Mdot
.51375 .56 Mdot
.77875 .5625 Mdot
.96 .51 Mdot
.485 .49125 Mdot
.61 .50125 Mdot
.3875 .45125 Mdot
.60125 .46875 Mdot
.47625 .47375 Mdot
.23625 .4875 Mdot
.8775 .4775 Mdot
.3175 .5075 Mdot
.29625 .51625 Mdot
.66125 .48875 Mdot
.60375 .485 Mdot
.495 .4825 Mdot
.57875 .5075 Mdot
.60875 .49 Mdot
.37 .55125 Mdot
.6975 .50375 Mdot
.65 .4725 Mdot
.69 .4425 Mdot
.4775 .39375 Mdot
.65875 .42 Mdot
.26375 .4575 Mdot
.245 .51125 Mdot
.365 .51625 Mdot
.50625 .535 Mdot
.6875 .45625 Mdot
.305 .43375 Mdot
.64875 .40875 Mdot
.6525 .39875 Mdot
.025 .395 Mdot
.7275 .4475 Mdot
.125 .46 Mdot
.3975 .45875 Mdot
.035 .47125 Mdot
.10875 .4225 Mdot
.53 .42125 Mdot
.5725 .40375 Mdot
.53625 .38625 Mdot
.4125 .39125 Mdot
.47375 .46125 Mdot
.84125 .50375 Mdot
.2975 .57625 Mdot
.6225 .545 Mdot
.09875 .55 Mdot
.97625 .5325 Mdot
.385 .565 Mdot
.15 .51875 Mdot
.8275 .535 Mdot
.63 .51125 Mdot
.2475 .53 Mdot
.3725 .52375 Mdot
.54875 .565 Mdot
.5075 .59 Mdot
.68125 .61625 Mdot
.6825 .58375 Mdot
.17125 .58375 Mdot
.755 .585 Mdot
.5275 .54875 Mdot
.12125 .5575 Mdot
.54125 .56875 Mdot
.8275 .5725 Mdot
.565 .56875 Mdot
.38 .53 Mdot
.17375 .51375 Mdot
.70875 .50125 Mdot
.30625 .47875 Mdot
.55125 .46 Mdot
.88375 .4725 Mdot
.1575 .4325 Mdot
.43625 .39125 Mdot
.69 .3925 Mdot
.48625 .4025 Mdot
.82375 .4025 Mdot
.6825 .48625 Mdot
.48125 .47875 Mdot
.4075 .475 Mdot
.4725 .37875 Mdot
.70125 .4 Mdot
.51 .37875 Mdot
.56375 .34875 Mdot
.80125 .345 Mdot
.5 .38 Mdot
.87 .37625 Mdot
.76375 .395 Mdot
.505 .425 Mdot
.35875 .3875 Mdot
.7925 .37625 Mdot
.7025 .375 Mdot
.7725 .41375 Mdot
.1825 .49875 Mdot
.67125 .54 Mdot
.63375 .54875 Mdot
.2275 .5075 Mdot
.64625 .505 Mdot
.2625 .5075 Mdot
.74625 .5325 Mdot
.59125 .52875 Mdot
.4625 .5275 Mdot
.02 .51375 Mdot
.54 .4575 Mdot
.25375 .48375 Mdot
.43875 .50625 Mdot
.2 .51375 Mdot
.25875 .5075 Mdot
.575 .47375 Mdot
.61375 .44 Mdot
.85875 .4175 Mdot
.47875 .445 Mdot
.7625 .44875 Mdot
.92125 .485 Mdot
.44 .5025 Mdot
.6575 .46375 Mdot
.34625 .4725 Mdot
.66875 .46875 Mdot
.3675 .48375 Mdot
.4275 .45375 Mdot
.72 .49 Mdot
.3475 .485 Mdot
.27375 .4625 Mdot
.63375 .47875 Mdot
.7925 .50125 Mdot
.36125 .495 Mdot
.5675 .5075 Mdot
.56875 .53 Mdot
.24125 .53125 Mdot
.5925 .525 Mdot
.67625 .52125 Mdot
.78125 .4725 Mdot
.45875 .44875 Mdot
.6075 .4625 Mdot
.23625 .47875 Mdot
.36625 .49125 Mdot
.2725 .55375 Mdot
.565 .58375 Mdot
.61375 .58125 Mdot
.4 .5625 Mdot
.56375 .5375 Mdot
.7175 .515 Mdot
.73 .575 Mdot
.0975 .59875 Mdot
.28875 .60125 Mdot
.1325 .5475 Mdot
.16 .465 Mdot
.5825 .465 Mdot
.49 .50375 Mdot
.58625 .52125 Mdot
.34375 .5425 Mdot
.55875 .5175 Mdot
.7575 .5075 Mdot
.3875 .4075 Mdot
.57875 .38 Mdot
.17125 .375 Mdot
.90375 .37625 Mdot
.27375 .45 Mdot
.405 .5 Mdot
.6775 .54125 Mdot
.6225 .525 Mdot
.3 .55125 Mdot
.30125 .495 Mdot
.5975 .47875 Mdot
.50625 .42375 Mdot
.6875 .4075 Mdot
.64125 .41125 Mdot
.20625 .42 Mdot
.73 .40625 Mdot
.545 .48625 Mdot
.15375 .41875 Mdot
.46 .39375 Mdot
.9475 .4275 Mdot
.42375 .44 Mdot
.44 .48375 Mdot
.19625 .505 Mdot
.745 .5275 Mdot
.2375 .57 Mdot
.58 .5725 Mdot
.82625 .56375 Mdot
.2225 .58 Mdot
.46625 .62625 Mdot
.61 .575 Mdot
.48625 .55625 Mdot
.90875 .5275 Mdot
.655 .44 Mdot
.56125 .475 Mdot
.32625 .48375 Mdot
.5325 .62375 Mdot
.63125 .68 Mdot
.48125 .6875 Mdot
.7325 .68625 Mdot
.685 .67625 Mdot
.00125 .57125 Mdot
.52625 .535 Mdot
.81375 .55 Mdot
.77875 .5625 Mdot
.48125 .5625 Mdot
.4175 .55875 Mdot
.7575 .5575 Mdot
.66125 .5575 Mdot
.77875 .5625 Mdot
.17875 .5275 Mdot
.7425 .50375 Mdot
.0875 .47125 Mdot
.5025 .44125 Mdot
.29125 .47625 Mdot
.5925 .48125 Mdot
.3325 .47125 Mdot
.69125 .455 Mdot
.61375 .48125 Mdot
.4975 .4875 Mdot
.6225 .5475 Mdot
.23125 .54125 Mdot
.425 .50125 Mdot
.17625 .4875 Mdot
.22125 .46375 Mdot
.62125 .4775 Mdot
.50625 .52125 Mdot
.8975 .52625 Mdot
.42875 .525 Mdot
.7725 .5275 Mdot
.86 .50375 Mdot
.42375 .49125 Mdot
.66125 .5 Mdot
.3475 .49875 Mdot
.70625 .49125 Mdot
.2725 .48125 Mdot
.61125 .51875 Mdot
.60125 .4725 Mdot
.35 .48 Mdot
.2525 .48625 Mdot
.61125 .48625 Mdot
.945 .4725 Mdot
.2425 .51 Mdot
.59125 .47375 Mdot
.49375 .47125 Mdot
.145 .47 Mdot
.48125 .50875 Mdot
.71875 .4925 Mdot
.7725 .5275 Mdot
.54625 .6275 Mdot
.5275 .6 Mdot
.26625 .5825 Mdot
.455 .565 Mdot
.19 .49625 Mdot
.64875 .39375 Mdot
.50625 .4325 Mdot
.51125 .495 Mdot
.42125 .51 Mdot
.86875 .54875 Mdot
.74 .53375 Mdot
.07125 .48375 Mdot
.17 .52375 Mdot
.2425 .525 Mdot
.9925 .55875 Mdot
.135 .59125 Mdot
.64875 .54875 Mdot
.435 .49125 Mdot
.66 .4725 Mdot
.26625 .4125 Mdot
.62 .39 Mdot
.66 .4075 Mdot
.04125 .4425 Mdot
.8675 .47375 Mdot
.46625 .5025 Mdot
.485 .54125 Mdot
.31625 .54375 Mdot
.785 .52625 Mdot
.26625 .4225 Mdot
.5375 .40625 Mdot
.58 .375 Mdot
.565 .4025 Mdot
.40625 .43 Mdot
.22375 .52375 Mdot
.68 .545 Mdot
.4475 .585 Mdot
.7225 .58 Mdot
.59 .55875 Mdot
.23875 .51375 Mdot
.705 .51 Mdot
.56875 .44375 Mdot
.2 .47125 Mdot
.3975 .48875 Mdot
.295 .45875 Mdot
.53 .46625 Mdot
.17625 .4275 Mdot
.775 .42625 Mdot
.205 .42375 Mdot
.62375 .4575 Mdot
.72625 .4725 Mdot
.25875 .52125 Mdot
.5275 .55375 Mdot
.5475 .5925 Mdot
.48 .59625 Mdot
.97875 .62 Mdot
.6175 .615 Mdot
.66375 .60375 Mdot
.2475 .58125 Mdot
.53875 .58 Mdot
.64875 .53 Mdot
.37125 .53 Mdot
.95125 .51375 Mdot
.5175 .52 Mdot
.01375 .4725 Mdot
.5875 .49125 Mdot
.74375 .4625 Mdot
.05 .45875 Mdot
.73375 .46125 Mdot
.5 .4675 Mdot
.46 .5 Mdot
.74875 .515 Mdot
.5425 .51875 Mdot
.03125 .50125 Mdot
.7425 .49625 Mdot
.21125 .4525 Mdot
.80125 .45375 Mdot
.8825 .45875 Mdot
.22 .45375 Mdot
.38375 .465 Mdot
.355 .48 Mdot
.53 .46875 Mdot
.43125 .45875 Mdot
.65875 .47875 Mdot
.5725 .495 Mdot
.555 .48625 Mdot
.6725 .44625 Mdot
.25875 .45 Mdot
.3925 .47 Mdot
.21375 .44375 Mdot
.21125 .47375 Mdot
.6975 .455 Mdot
.36625 .4475 Mdot
.06125 .45625 Mdot
.8625 .455 Mdot
.4175 .44875 Mdot
.77875 .435 Mdot
.04375 .46 Mdot
.75125 .4775 Mdot
.47 .52 Mdot
.57875 .5325 Mdot
.41125 .545 Mdot
.705 .51875 Mdot
.26125 .51125 Mdot
.69125 .46875 Mdot
.5225 .49125 Mdot
.3325 .48375 Mdot
.255 .4775 Mdot
.64 .4725 Mdot
.98375 .475 Mdot
.22 .4575 Mdot
.57875 .47125 Mdot
.43625 .4825 Mdot
.04125 .48375 Mdot
.3925 .5075 Mdot
.78625 .5425 Mdot
.70625 .54125 Mdot
.64625 .4925 Mdot
.42875 .47 Mdot
.36125 .475 Mdot
.415 .44 Mdot
.265 .46375 Mdot
.0375 .485 Mdot
.6975 .4725 Mdot
.38375 .4675 Mdot
.67625 .455 Mdot
.27625 .43875 Mdot
.9625 .4375 Mdot
.62125 .39 Mdot
.1825 .355 Mdot
.09875 .3775 Mdot
.3725 .405 Mdot
.93625 .46875 Mdot
.03625 .5275 Mdot
.765 .57125 Mdot
.4125 .58375 Mdot
.6575 .56875 Mdot
.26625 .5475 Mdot
.6175 .54625 Mdot
.56125 .5375 Mdot
.26625 .5525 Mdot
.69375 .57125 Mdot
.575 .58625 Mdot
.3525 .5925 Mdot
.44375 .575 Mdot
.69375 .575 Mdot
.27125 .61125 Mdot
.6225 .61 Mdot
.53625 .5475 Mdot
.5125 .535 Mdot
.4375 .5225 Mdot
.21875 .50875 Mdot
.74125 .48375 Mdot
.405 .51875 Mdot
.72125 .55125 Mdot
.525 .52125 Mdot
.32375 .51125 Mdot
.6775 .5125 Mdot
.56125 .495 Mdot
.285 .5925 Mdot
.29125 .56625 Mdot
.16125 .52375 Mdot
.60875 .47875 Mdot
.16875 .5 Mdot
.80625 .48125 Mdot
.1575 .475 Mdot
.68 .46125 Mdot
.62125 .4725 Mdot
.295 .44375 Mdot
.58125 .41375 Mdot
.4975 .4125 Mdot
.51375 .4275 Mdot
.9275 .41875 Mdot
.615 .46125 Mdot
.715 .44875 Mdot
.1925 .42125 Mdot
.51875 .33125 Mdot
.68875 .325 Mdot
.35125 .3425 Mdot
.99 .38625 Mdot
.4375 .4225 Mdot
.0225 .555 Mdot
.65375 .57125 Mdot
.67875 .58 Mdot
.08875 .57875 Mdot
.7175 .5375 Mdot
.5325 .5075 Mdot
.47 .48625 Mdot
.7725 .4675 Mdot
.43375 .45625 Mdot
.08375 .5025 Mdot
.73375 .5 Mdot
.2425 .53 Mdot
.79625 .55375 Mdot
.81 .5775 Mdot
.37125 .585 Mdot
.24375 .595 Mdot
.40875 .585 Mdot
.45625 .58125 Mdot
.58125 .56 Mdot
.53375 .52 Mdot
.62 .5225 Mdot
.56 .53125 Mdot
.04 .51375 Mdot
.9325 .53125 Mdot
.6975 .53625 Mdot
.32875 .51 Mdot
.2925 .495 Mdot
.32 .52375 Mdot
.23625 .51875 Mdot
.79875 .5475 Mdot
.19 .55875 Mdot
.19375 .5425 Mdot
.80375 .5525 Mdot
.38375 .5825 Mdot
.80375 .56 Mdot
.11 .5525 Mdot
.67875 .5375 Mdot
.55 .50375 Mdot
.44 .48125 Mdot
.4875 .4925 Mdot
.7375 .46875 Mdot
.18875 .48 Mdot
.7575 .5025 Mdot
.51125 .52 Mdot
.3175 .525 Mdot
.23375 .55 Mdot
.70125 .535 Mdot
.9075 .51625 Mdot
.3225 .4775 Mdot
.49375 .465 Mdot
.38 .46375 Mdot
.39375 .44125 Mdot
.82125 .40625 Mdot
.565 .3875 Mdot
.8075 .39625 Mdot
.355 .39625 Mdot
.4825 .4575 Mdot
.2075 .52 Mdot
.475 .57 Mdot
.8475 .5925 Mdot
.2525 .615 Mdot
.62375 .6175 Mdot
.3025 .57625 Mdot
.81625 .515 Mdot
.20875 .52 Mdot
.9375 .51625 Mdot
.07375 .535 Mdot
.41375 .5925 Mdot
.345 .68875 Mdot
.555 .64625 Mdot
.83875 .56875 Mdot
.885 .43875 Mdot
.34125 .41375 Mdot
.675 .43125 Mdot
.28125 .475 Mdot
.62 .5125 Mdot
.4825 .51875 Mdot
.4825 .52875 Mdot
.54375 .50125 Mdot
.625 .47 Mdot
.265 .43125 Mdot
.49875 .4625 Mdot
.70625 .47 Mdot
.2325 .465 Mdot
.65875 .45 Mdot
.5025 .495 Mdot
.48875 .45625 Mdot
.435 .41625 Mdot
.3325 .3925 Mdot
.685 .4175 Mdot
.38625 .4075 Mdot
.72375 .3975 Mdot
.52 .46375 Mdot
.32 .51875 Mdot
.68375 .53 Mdot
.52875 .57375 Mdot
.40125 .47625 Mdot
.23875 .49 Mdot
.13375 .5625 Mdot
.65125 .56875 Mdot
.1725 .585 Mdot
.8025 .63125 Mdot
.14125 .61625 Mdot
.68125 .5825 Mdot
.685 .53375 Mdot
.2225 .51125 Mdot
.6775 .44875 Mdot
.3925 .405 Mdot
.525 .38625 Mdot
.87875 .3975 Mdot
.045 .39625 Mdot
.55125 .40125 Mdot
.6425 .4075 Mdot
.31375 .51125 Mdot
.50125 .595 Mdot
.605 .615 Mdot
.50125 .60375 Mdot
.7525 .595 Mdot
.5675 .49625 Mdot
.03125 .38875 Mdot
.57125 .37625 Mdot
.78375 .34375 Mdot
.0275 .34375 Mdot
.79625 .395 Mdot
.49 .4575 Mdot
.4875 .47125 Mdot
.84125 .52125 Mdot
.18875 .52875 Mdot
.2325 .4925 Mdot
.69625 .475 Mdot
.4025 .48 Mdot
.74625 .435 Mdot
.67625 .40375 Mdot
.39875 .39875 Mdot
.28625 .39125 Mdot
.4125 .3725 Mdot
.46125 .42 Mdot
.60875 .4725 Mdot
.48875 .49875 Mdot
.56375 .51 Mdot
.5825 .535 Mdot
.18375 .51375 Mdot
.79 .4825 Mdot
.7225 .505 Mdot
.35375 .52 Mdot
.17625 .50875 Mdot
.5625 .5125 Mdot
.8275 .52875 Mdot
.31875 .515 Mdot
.82875 .50375 Mdot
.0425 .47625 Mdot
.43625 .495 Mdot
.6875 .4875 Mdot
.34375 .47 Mdot
.82375 .47125 Mdot
.03375 .5 Mdot
.83 .48125 Mdot
.46375 .48 Mdot
.47625 .485 Mdot
.48125 .5025 Mdot
.6625 .53 Mdot
.265 .53125 Mdot
.7775 .515 Mdot
.4675 .48 Mdot
.27375 .46625 Mdot
.34125 .43125 Mdot
.625 .44 Mdot
.97 .47375 Mdot
.30125 .54 Mdot
.425 .535 Mdot
.39625 .54375 Mdot
.26125 .49875 Mdot
.44 .57625 Mdot
.82375 .62125 Mdot
.4575 .66375 Mdot
.85625 .6625 Mdot
.42 .60625 Mdot
.46 .53625 Mdot
.17 .485 Mdot
.4875 .435 Mdot
.84625 .39125 Mdot
.31625 .415 Mdot
.55875 .41875 Mdot
.28625 .46125 Mdot
.86625 .4675 Mdot
.2525 .53125 Mdot
.7225 .515 Mdot
.22 .50875 Mdot
.405 .43125 Mdot
.445 .3875 Mdot
.54125 .355 Mdot
.79125 .3975 Mdot
.05375 .47 Mdot
.845 .47875 Mdot
.31375 .50125 Mdot
.68875 .51125 Mdot
.2375 .5075 Mdot
.67 .48375 Mdot
.43625 .485 Mdot
.63 .5025 Mdot
.45 .515 Mdot
.595 .53 Mdot
.265 .55375 Mdot
.56125 .55875 Mdot
.645 .52 Mdot
.30125 .5 Mdot
.53875 .515 Mdot
.5975 .50375 Mdot
.45 .53375 Mdot
.35875 .5575 Mdot
.445 .58 Mdot
.71 .55375 Mdot
.3775 .54 Mdot
.70875 .5325 Mdot
.46375 .52375 Mdot
.36125 .49375 Mdot
.6325 .49625 Mdot
.52375 .505 Mdot
.53375 .48 Mdot
.2325 .48125 Mdot
.1925 .43875 Mdot
.67 .4675 Mdot
.135 .47125 Mdot
.82375 .44625 Mdot
.175 .4575 Mdot
.61875 .4925 Mdot
.74875 .5325 Mdot
.1575 .54 Mdot
.7675 .615 Mdot
.31375 .6575 Mdot
.5175 .65625 Mdot
.86875 .67625 Mdot
.1675 .69 Mdot
.4925 .6625 Mdot
.53 .64625 Mdot
.445 .58875 Mdot
.48625 .52 Mdot
.5675 .49375 Mdot
.555 .4675 Mdot
.6425 .45375 Mdot
.63 .5225 Mdot
.0525 .56625 Mdot
.47625 .55375 Mdot
.915 .56375 Mdot
.87 .5 Mdot
.455 .435 Mdot
.45375 .44 Mdot
.94875 .4075 Mdot
.37125 .46 Mdot
.65625 .47 Mdot
.56125 .4775 Mdot
.68 .52625 Mdot
.57875 .5475 Mdot
.38125 .5425 Mdot
.35875 .57625 Mdot
.41375 .6 Mdot
.475 .52375 Mdot
.6075 .5 Mdot
.465 .48125 Mdot
.50875 .45 Mdot
.5825 .41375 Mdot
.35 .48 Mdot
.65125 .4875 Mdot
.725 .475 Mdot
.40875 .475 Mdot
.05 .47 Mdot
.76375 .44875 Mdot
.675 .4275 Mdot
.38 .43375 Mdot
.795 .44125 Mdot
.71625 .4925 Mdot
.50125 .525 Mdot
.3575 .51875 Mdot
.83375 .52625 Mdot
.9575 .5375 Mdot
.39875 .545 Mdot
.5325 .60375 Mdot
.4475 .58875 Mdot
.6075 .55875 Mdot
.33875 .5425 Mdot
.80375 .54875 Mdot
.40125 .56875 Mdot
.23 .62125 Mdot
.49125 .63875 Mdot
.525 .67875 Mdot
.9675 .65 Mdot
.34375 .54875 Mdot
.36125 .5375 Mdot
.3975 .53125 Mdot
.5425 .51875 Mdot
.4875 .4525 Mdot
.85875 .41625 Mdot
.36 .42 Mdot
.86 .4275 Mdot
.51375 .47 Mdot
.40125 .5075 Mdot
.16375 .48 Mdot
.49125 .51375 Mdot
.85625 .50625 Mdot
.36875 .4975 Mdot
.47375 .46125 Mdot
.33 .5375 Mdot
.8425 .50625 Mdot
.3625 .48125 Mdot
.4275 .455 Mdot
.4325 .48 Mdot
.38375 .535 Mdot
.535 .5925 Mdot
.025 .6175 Mdot
.505 .64375 Mdot
.73625 .5825 Mdot
.1675 .50875 Mdot
.77375 .47125 Mdot
.34125 .47375 Mdot
.7225 .43 Mdot
.165 .4325 Mdot
.71625 .455 Mdot
.38875 .50625 Mdot
.73625 .4775 Mdot
.3925 .5125 Mdot
.55875 .48375 Mdot
.3075 .49375 Mdot
.5475 .48625 Mdot
.605 .5325 Mdot
.4175 .57125 Mdot
.39875 .585 Mdot
.67125 .55375 Mdot
.4275 .53125 Mdot
.3075 .5225 Mdot
.50875 .45375 Mdot
.7225 .46375 Mdot
.38875 .50625 Mdot
.6975 .47125 Mdot
.44125 .4725 Mdot
.3725 .49375 Mdot
.6075 .4925 Mdot
.475 .44875 Mdot
.66625 .4575 Mdot
.2125 .47 Mdot
.91 .515 Mdot
.24625 .51875 Mdot
.67625 .4 Mdot
.10375 .35375 Mdot
.85875 .225 Mdot
.20125 .23125 Mdot
.56625 .205 Mdot
.80875 .26125 Mdot
.0925 .3225 Mdot
.85375 .39875 Mdot
.21875 .3125 Mdot
.5575 .33875 Mdot
.77 .28875 Mdot
.31625 .1625 Mdot
.53625 .16 Mdot
.3325 .295 Mdot
.5825 .27 Mdot
.47875 .41875 Mdot
.53875 .5025 Mdot
.6325 .52625 Mdot
.4625 .505 Mdot
.71625 .43125 Mdot
.08375 .30375 Mdot
.37375 .31875 Mdot
.91 .52125 Mdot
.43875 .6 Mdot
.465 .55875 Mdot
.985 .47125 Mdot
.52625 .35125 Mdot
.61 .39625 Mdot
.6775 .5175 Mdot
.645 .47875 Mdot
.495 .53125 Mdot
.32 .5125 Mdot
.47125 .465 Mdot
.41125 .42 Mdot
.5225 .5975 Mdot
.5375 .61625 Mdot
.48375 .595 Mdot
.48 .5225 Mdot
.53875 .5225 Mdot
.49 .46 Mdot
.5625 .4975 Mdot
.7175 .53 Mdot
.43125 .6125 Mdot
.96625 .63625 Mdot
.4675 .5825 Mdot
.4825 .5375 Mdot
.7475 .47125 Mdot
.93625 .45125 Mdot
.32875 .49875 Mdot
.4175 .47875 Mdot
.81125 .49875 Mdot
.30375 .30875 Mdot
.6125 .28625 Mdot
.41125 .25875 Mdot
.55125 .3975 Mdot
.425 .375 Mdot
.815 .305 Mdot
.3125 .35 Mdot
.22 .2675 Mdot
.615 .28875 Mdot
.48 .26 Mdot
.895 .29375 Mdot
.455 .37375 Mdot
.2575 .53875 Mdot
.415 .35375 Mdot
.0575 .395 Mdot
.815 .40875 Mdot
.54 .51 Mdot
.8975 .46375 Mdot
.295 .4725 Mdot
.7875 .425 Mdot
.61125 .46625 Mdot
.37375 .2925 Mdot
.1575 .41625 Mdot
.46625 .35375 Mdot
.87125 .4 Mdot
.45875 .43375 Mdot
.3525 .59375 Mdot
.4175 .5825 Mdot
.785 .6475 Mdot
.5175 .49625 Mdot
.09125 .46375 Mdot
.61375 .4375 Mdot
.41 .2875 Mdot
.59 .29 Mdot
.1175 .32875 Mdot
.405 .345 Mdot
.70625 .4525 Mdot
.28375 .48125 Mdot
.69875 .5825 Mdot
.385 .65125 Mdot
.66875 .6325 Mdot
.17875 .6225 Mdot
.75375 .5475 Mdot
.35 .46625 Mdot
.78125 .40875 Mdot
.3875 .35375 Mdot
.48875 .37 Mdot
.4025 .3525 Mdot
.49875 .37375 Mdot
.60375 .36375 Mdot
.47875 .3325 Mdot
.285 .33 Mdot
.7675 .39125 Mdot
.355 .31875 Mdot
.26375 .36 Mdot
.60375 .44875 Mdot
.745 .46875 Mdot
.36375 .44 Mdot
.6575 .5525 Mdot
.46375 .545 Mdot
.37375 .47625 Mdot
.60625 .425 Mdot
.40125 .49625 Mdot
.78625 .48125 Mdot
.18125 .47875 Mdot
.82 .46625 Mdot
.29875 .48 Mdot
.69875 .56875 Mdot
.04875 .63 Mdot
.90375 .75875 Mdot
.195 .735 Mdot
.51625 .765 Mdot
.93375 .685 Mdot
.00625 .61 Mdot
.9 .5025 Mdot
.13875 .59 Mdot
.635 .5875 Mdot
.64625 .665 Mdot
.47 .785 Mdot
.51625 .785 Mdot
.2025 .63875 Mdot
.6825 .635 Mdot
.5175 .47375 Mdot
.425 .405 Mdot
.81375 .41625 Mdot
.24875 .45375 Mdot
.79375 .5225 Mdot
.12625 .66875 Mdot
.2725 .6925 Mdot
.985 .625 Mdot
.3725 .54875 Mdot
.4775 .57125 Mdot
.615 .7 Mdot
.57875 .67375 Mdot
.81625 .525 Mdot
.5675 .5225 Mdot
.41625 .44625 Mdot
.30625 .46 Mdot
.5625 .49125 Mdot
.36625 .52375 Mdot
.58375 .39 Mdot
.48125 .375 Mdot
.49 .42 Mdot
.45625 .495 Mdot
.51375 .50875 Mdot
.57875 .5375 Mdot
.53 .51125 Mdot
.7225 .4925 Mdot
.4325 .41 Mdot
.29875 .47875 Mdot
.575 .48125 Mdot
.675 .55 Mdot
.185 .43625 Mdot
.45125 .49125 Mdot
.805 .4625 Mdot
.1825 .66 Mdot
.7375 .62625 Mdot
.33375 .65625 Mdot
.48375 .57625 Mdot
.50375 .60875 Mdot
.87125 .67375 Mdot
.255 .6575 Mdot
.14 .73 Mdot
.78375 .66625 Mdot
.39625 .64375 Mdot
.815 .62875 Mdot
.59125 .5925 Mdot
.135 .41875 Mdot
.45875 .6275 Mdot
.185 .62625 Mdot
.58125 .4975 Mdot
.89 .57875 Mdot
.2925 .57875 Mdot
.675 .6375 Mdot
.7375 .625 Mdot
.37 .755 Mdot
.13375 .65875 Mdot
.3675 .685 Mdot
.9675 .6675 Mdot
.505 .6275 Mdot
.2375 .495 Mdot
.54875 .4475 Mdot
.6625 .44 Mdot
.7025 .5575 Mdot
.68125 .6075 Mdot
.56875 .69625 Mdot
.54875 .6125 Mdot
.95625 .51875 Mdot
.20625 .56 Mdot
.29125 .50875 Mdot
.68125 .42875 Mdot
.435 .44625 Mdot
.59125 .40125 Mdot
.37125 .365 Mdot
.69625 .44375 Mdot
.165 .49625 Mdot
.7575 .565 Mdot
.365 .57875 Mdot
.7875 .6125 Mdot
.40875 .6525 Mdot
.38125 .64125 Mdot
.585 .64125 Mdot
.3125 .5975 Mdot
.69625 .61375 Mdot
.48625 .60375 Mdot
.24 .60875 Mdot
.83 .60875 Mdot
.345 .7275 Mdot
.195 .685 Mdot
.65625 .64 Mdot
.74375 .5725 Mdot
.40125 .54 Mdot
.6275 .4525 Mdot
.42 .4275 Mdot
.405 .46625 Mdot
.57125 .52375 Mdot
.37875 .4775 Mdot
0 0 1 r
.3875 .41 Mdot
.4525 .37125 Mdot
.38875 .32375 Mdot
.58625 .3125 Mdot
.23875 .33375 Mdot
.565 .355 Mdot
.0725 .4375 Mdot
.43 .45 Mdot
.5275 .50125 Mdot
.4625 .53875 Mdot
.34125 .55625 Mdot
.3975 .57 Mdot
.99625 .58125 Mdot
.2375 .55 Mdot
.5475 .5275 Mdot
.50125 .5225 Mdot
.54 .53125 Mdot
.55875 .485 Mdot
.1075 .45625 Mdot
.18125 .4225 Mdot
.395 .37875 Mdot
.505 .365 Mdot
.51125 .40875 Mdot
.39 .39125 Mdot
.31 .375 Mdot
.19 .41125 Mdot
.46375 .375 Mdot
.46 .3875 Mdot
.44 .43375 Mdot
.5825 .425 Mdot
.09125 .405 Mdot
.4225 .3825 Mdot
.39875 .36 Mdot
.4675 .41625 Mdot
.50625 .46625 Mdot
.48125 .53375 Mdot
.3675 .54875 Mdot
.24125 .54125 Mdot
.43125 .52875 Mdot
.45875 .5125 Mdot
.53625 .49375 Mdot
.55125 .47375 Mdot
.49375 .475 Mdot
.44625 .465 Mdot
.08375 .48 Mdot
.26 .5 Mdot
.47 .5 Mdot
.45625 .505 Mdot
.51 .51125 Mdot
.205 .58125 Mdot
.485 .59 Mdot
.01375 .58625 Mdot
.45125 .5725 Mdot
.59125 .50875 Mdot
.52125 .49875 Mdot
.165 .4725 Mdot
.49125 .4625 Mdot
.06 .44375 Mdot
.5225 .445 Mdot
.51625 .46 Mdot
.50625 .46375 Mdot
.2025 .49 Mdot
.4925 .5225 Mdot
.97875 .5475 Mdot
.15 .57125 Mdot
.64875 .59875 Mdot
.56375 .58 Mdot
.48375 .52375 Mdot
.29875 .5025 Mdot
.8175 .49625 Mdot
.6825 .48 Mdot
.0975 .47125 Mdot
.5325 .5075 Mdot
.50375 .49875 Mdot
.5 .4975 Mdot
.045 .51375 Mdot
.385 .54125 Mdot
.32625 .53375 Mdot
.52 .55 Mdot
.4725 .5225 Mdot
.45 .5025 Mdot
.15875 .495 Mdot
.115 .475 Mdot
.4425 .49125 Mdot
.53 .47875 Mdot
.4425 .4575 Mdot
.08625 .47 Mdot
.56375 .48375 Mdot
.23375 .50125 Mdot
.53375 .47375 Mdot
.50375 .4325 Mdot
.33125 .39625 Mdot
.6225 .38875 Mdot
.74 .3725 Mdot
.28375 .3975 Mdot
.49375 .42625 Mdot
.50625 .43 Mdot
.49375 .46625 Mdot
0 .51375 Mdot
.37625 .57125 Mdot
.3475 .5825 Mdot
.5075 .535 Mdot
.495 .4825 Mdot
.245 .47125 Mdot
.70875 .4525 Mdot
.8025 .44875 Mdot
.25125 .45 Mdot
.4475 .435 Mdot
.56375 .40625 Mdot
.48875 .41125 Mdot
.175 .4575 Mdot
.485 .48 Mdot
.195 .4675 Mdot
.9975 .43375 Mdot
.81375 .07625 Mdot
.23 .0875 Mdot
.50125 .04625 Mdot
.355 .0575 Mdot
.53125 .05125 Mdot
.4075 .0075 Mdot
.62625 .07875 Mdot
.66 .115 Mdot
.08375 .13125 Mdot
.98375 .1175 Mdot
.3 .10375 Mdot
.42 .04625 Mdot
.43125 .09625 Mdot
.9375 .0975 Mdot
.2775 .01125 Mdot
.32375 .08 Mdot
.7575 .18125 Mdot
.18625 .2375 Mdot
.87125 .305 Mdot
.4725 .2875 Mdot
.40625 .2525 Mdot
.48875 .2425 Mdot
.48375 .305 Mdot
.47375 .25 Mdot
.42875 .19125 Mdot
.8725 .105 Mdot
.30875 .03625 Mdot
.725 .02 Mdot
.485 .0775 Mdot
.38625 .0925 Mdot
.20625 .11 Mdot
.29875 .13 Mdot
.53625 .095 Mdot
.45875 .12 Mdot
.45625 .1825 Mdot
.3225 .14125 Mdot
.445 .15 Mdot
.095 .16375 Mdot
.44625 .12 Mdot
.715 .2075 Mdot
.4175 .2425 Mdot
.24875 .2275 Mdot
.56875 .23125 Mdot
.96625 .22 Mdot
.1675 .19375 Mdot
.4575 .1675 Mdot
.52 .185 Mdot
.57 .21 Mdot
.3275 .125 Mdot
.44625 .12875 Mdot
.84625 .11375 Mdot
.19625 .06875 Mdot
.53125 .03 Mdot
.68125 .18375 Mdot
.52625 .2625 Mdot
.30875 .31625 Mdot
.7225 .39375 Mdot
.62375 .45875 Mdot
.21 .4175 Mdot
.52125 .34875 Mdot
.5025 .3675 Mdot
.495 .33125 Mdot
.1575 .3125 Mdot
.4375 .38375 Mdot
.3325 .4075 Mdot
.4725 .44625 Mdot
.6075 .485 Mdot
.425 .50375 Mdot
.23375 .49375 Mdot
.20125 .49375 Mdot
.44875 .475 Mdot
.54625 .44 Mdot
.42875 .40125 Mdot
.1875 .36875 Mdot
.9925 .3375 Mdot
.56875 .33 Mdot
.29 .34875 Mdot
.505 .37375 Mdot
.49625 .4 Mdot
.47 .45125 Mdot
.5075 .4725 Mdot
.69125 .4925 Mdot
.33125 .53 Mdot
.495 .53875 Mdot
.52125 .535 Mdot
.48625 .48875 Mdot
.09 .4625 Mdot
.41125 .4125 Mdot
.3725 .38625 Mdot
.49875 .41875 Mdot
.49875 .44375 Mdot
.27 .45125 Mdot
.745 .47375 Mdot
.65375 .47625 Mdot
.33375 .4875 Mdot
.46625 .49 Mdot
.56625 .47 Mdot
.5075 .44625 Mdot
.09875 .47 Mdot
.27875 .4575 Mdot
.4825 .36125 Mdot
.39625 .2475 Mdot
.75125 .105 Mdot
.28125 .965 Mdot
.9175 .9325 Mdot
.45 .9525 Mdot
.31625 .965 Mdot
.77875 .92625 Mdot
.3675 .86125 Mdot
.56875 .77 Mdot
.4675 .70125 Mdot
.405 .72625 Mdot
.445 .67125 Mdot
.465 .62625 Mdot
.9575 .59375 Mdot
.1625 .55625 Mdot
.42375 .47 Mdot
.8225 .45125 Mdot
.36375 .51875 Mdot
.33125 .5125 Mdot
.595 .49375 Mdot
.73 .5025 Mdot
.30375 .46875 Mdot
.41375 .3675 Mdot
.51125 .37875 Mdot
.5975 .4125 Mdot
.49 .49375 Mdot
.3825 .57 Mdot
.7125 .65125 Mdot
.29625 .72625 Mdot
.35875 .7725 Mdot
.805 .7075 Mdot
.58125 .63 Mdot
.30375 .495 Mdot
.615 .32875 Mdot
.6 .17625 Mdot
.30375 .13125 Mdot
.5075 .1025 Mdot
.50125 .16 Mdot
.50625 .205 Mdot
.25875 .15625 Mdot
.87625 .05625 Mdot
.39 .005 Mdot
.755 .04375 Mdot
.53125 .11375 Mdot
.38625 .1575 Mdot
.48875 .16625 Mdot
.555 .22125 Mdot
.50875 .1975 Mdot
.20375 .1175 Mdot
.88875 .0375 Mdot
.37625 .28875 Mdot
.47 .56 Mdot
.47625 .90875 Mdot
.4625 .03 Mdot
.0525 .00625 Mdot
.505 .055 Mdot
.20125 .04625 Mdot
.785 .02375 Mdot
.50125 .045 Mdot
.51 .09625 Mdot
.55375 .15625 Mdot
.45 .24125 Mdot
.495 .31625 Mdot
.4775 .35375 Mdot
.07875 .325 Mdot
.1425 .34 Mdot
.485 .29875 Mdot
.57375 .2875 Mdot
.47625 .3275 Mdot
.50625 .3125 Mdot
.4725 .26375 Mdot
.4775 .2625 Mdot
.48 .26375 Mdot
.545 .3375 Mdot
.4825 .5025 Mdot
.55875 .65875 Mdot
.45625 .77 Mdot
.1675 .89 Mdot
.42875 .8275 Mdot
.3475 .82 Mdot
.4175 .88625 Mdot
.5725 .90625 Mdot
.42625 .97125 Mdot
.415 .995 Mdot
.4275 .93875 Mdot
.5175 .82125 Mdot
.53875 .81 Mdot
.50125 .90875 Mdot
.46625 .9675 Mdot
.455 .74375 Mdot
.5375 .4575 Mdot
.4625 .18125 Mdot
.5225 .4325 Mdot
.47375 .43375 Mdot
.10125 .55 Mdot
.515 .52625 Mdot
.62125 .515 Mdot
.425 .47 Mdot
.485 .39875 Mdot
.4825 .35875 Mdot
.5175 .34625 Mdot
.46625 .3375 Mdot
.51125 .32625 Mdot
.51375 .3175 Mdot
.50125 .34375 Mdot
.48875 .37375 Mdot
.13375 .38375 Mdot
.8325 .41 Mdot
.92 .445 Mdot
.11 .4275 Mdot
.5325 .4175 Mdot
.47 .40625 Mdot
.46375 .38375 Mdot
.5175 .35875 Mdot
.5225 .31875 Mdot
.5125 .285 Mdot
.47 .2525 Mdot
.53875 .24 Mdot
.48625 .21375 Mdot
.515 .23375 Mdot
.455 .31375 Mdot
.07 .4925 Mdot
.4325 .52625 Mdot
.6 .4575 Mdot
.4775 .40375 Mdot
.51125 .38 Mdot
.46875 .3675 Mdot
.47125 .36 Mdot
.4975 .3725 Mdot
.47625 .365 Mdot
.52375 .295 Mdot
.58 .27 Mdot
.4525 .2375 Mdot
.04375 .16125 Mdot
.415 .165 Mdot
.3025 .1175 Mdot
.48 .08375 Mdot
.49625 .105 Mdot
.41125 .0725 Mdot
.595 .05875 Mdot
.48875 .0475 Mdot
.41375 .09375 Mdot
.5675 .12375 Mdot
.5075 .19875 Mdot
.53375 .24375 Mdot
.375 .21375 Mdot
.36625 .16125 Mdot
.23875 .06375 Mdot
.5275 .03375 Mdot
.43125 .10125 Mdot
.50125 .1275 Mdot
.13 .14625 Mdot
.2275 .2725 Mdot
.43625 .3625 Mdot
.46125 .47125 Mdot
.46375 .545 Mdot
.57 .505 Mdot
.28875 .415 Mdot
.45625 .4325 Mdot
.7175 .4475 Mdot
.89125 .4975 Mdot
.19625 .59625 Mdot
.41625 .73625 Mdot
.3025 .72375 Mdot
.66875 .7725 Mdot
.765 .83625 Mdot
.28125 .9475 Mdot
.42125 .9575 Mdot
.54875 .87625 Mdot
.53375 .7025 Mdot
.45875 .63375 Mdot
.65375 .58 Mdot
.34875 .505 Mdot
.51375 .55 Mdot
.485 .54625 Mdot
.06875 .54 Mdot
.115 .50375 Mdot
.5525 .505 Mdot
.58875 .51875 Mdot
.4275 .53625 Mdot
.4425 .57375 Mdot
.6075 .58125 Mdot
.475 .58625 Mdot
.465 .5675 Mdot
.5125 .54625 Mdot
.50375 .525 Mdot
.50875 .505 Mdot
.48625 .48625 Mdot
.17 .4975 Mdot
.765 .4925 Mdot
.89 .49125 Mdot
.175 .5025 Mdot
.5 .50125 Mdot
.46375 .49875 Mdot
.46375 .505 Mdot
.58625 .5075 Mdot
.52 .5125 Mdot
.4725 .51625 Mdot
.4775 .51125 Mdot
.5225 .49125 Mdot
.5025 .48 Mdot
.50125 .4825 Mdot
.46875 .4375 Mdot
.0425 .4175 Mdot
.07625 .37875 Mdot
.47 .3425 Mdot
.58625 .38 Mdot
.455 .39125 Mdot
.57875 .3925 Mdot
.47625 .425 Mdot
.425 .46375 Mdot
.49625 .49125 Mdot
.49125 .5 Mdot
.51875 .5025 Mdot
.61 .52625 Mdot
.43375 .51 Mdot
.045 .505 Mdot
.425 .4975 Mdot
.295 .4875 Mdot
.4975 .51125 Mdot
.51375 .5075 Mdot
.43125 .52625 Mdot
.55 .60875 Mdot
.52125 .65375 Mdot
.4175 .66375 Mdot
.5675 .6675 Mdot
.4975 .62625 Mdot
.54875 .53625 Mdot
.35375 .48875 Mdot
.37 .4525 Mdot
.24875 .43875 Mdot
.44625 .45625 Mdot
.66875 .46125 Mdot
.32375 .46125 Mdot
.53125 .475 Mdot
.325 .53625 Mdot
.52 .54625 Mdot
.69125 .5325 Mdot
.735 .53375 Mdot
.24875 .5375 Mdot
.45375 .48375 Mdot
.53125 .47875 Mdot
.67875 .50625 Mdot
.20125 .5125 Mdot
.45375 .52875 Mdot
.53 .54875 Mdot
.51875 .56 Mdot
.51875 .555 Mdot
.48 .56 Mdot
.505 .545 Mdot
.4925 .53 Mdot
.48125 .48875 Mdot
.51875 .465 Mdot
.46375 .44875 Mdot
.13125 .4275 Mdot
.355 .415 Mdot
.35125 .405 Mdot
.4725 .37 Mdot
.53875 .35 Mdot
.5275 .345 Mdot
.50125 .33125 Mdot
.44625 .33 Mdot
.44125 .33625 Mdot
.56875 .345 Mdot
.54875 .315 Mdot
.4575 .3125 Mdot
.48875 .2625 Mdot
.1675 .155 Mdot
.34 .115 Mdot
.455 .0975 Mdot
.51625 .0625 Mdot
.55625 .04 Mdot
.2525 .07 Mdot
.5575 .05 Mdot
.68125 .05375 Mdot
.8575 .07125 Mdot
.24125 .1175 Mdot
.3975 .06625 Mdot
.24625 .06875 Mdot
.795 .06125 Mdot
.7225 .04875 Mdot
.5375 .125 Mdot
.45 .2475 Mdot
.52375 .34125 Mdot
.48875 .43875 Mdot
.51625 .40875 Mdot
.485 .35875 Mdot
.18375 .33125 Mdot
.19875 .325 Mdot
.55 .3 Mdot
.54125 .335 Mdot
.45 .34625 Mdot
.34125 .3425 Mdot
.82125 .37375 Mdot
.38375 .3725 Mdot
.465 .39875 Mdot
.5125 .4075 Mdot
.5075 .41375 Mdot
.50875 .4425 Mdot
.47625 .45875 Mdot
.265 .41875 Mdot
.6825 .39625 Mdot
.79875 .395 Mdot
.26125 .3675 Mdot
.485 .3475 Mdot
.4625 .36375 Mdot
.4 .365 Mdot
.7475 .36625 Mdot
.44875 .355 Mdot
.45375 .365 Mdot
.4775 .37375 Mdot
.53375 .39875 Mdot
.4875 .40125 Mdot
.515 .4425 Mdot
.47 .46 Mdot
.1475 .47875 Mdot
.10375 .52625 Mdot
.4825 .50625 Mdot
.57 .5025 Mdot
.35625 .49625 Mdot
.7625 .49375 Mdot
.405 .46875 Mdot
.4225 .4575 Mdot
.5125 .4475 Mdot
.48875 .43125 Mdot
.50625 .445 Mdot
.605 .43875 Mdot
.42375 .445 Mdot
.16625 .46875 Mdot
.42625 .43875 Mdot
.3575 .44625 Mdot
.49375 .4375 Mdot
.42625 .44125 Mdot
.5925 .4775 Mdot
.50875 .45875 Mdot
.47375 .4575 Mdot
.46 .43875 Mdot
.53625 .3975 Mdot
.55125 .3625 Mdot
.49125 .40375 Mdot
.37125 .40375 Mdot
.39625 .4475 Mdot
.915 .48375 Mdot
.3375 .5075 Mdot
.455 .515 Mdot
.5725 .52375 Mdot
.32875 .5375 Mdot
.6475 .5425 Mdot
.33875 .505 Mdot
.515 .50125 Mdot
.615 .50875 Mdot
.70125 .50125 Mdot
.31 .49375 Mdot
.45625 .53875 Mdot
.525 .55 Mdot
.10625 .55375 Mdot
.9875 .5525 Mdot
.6325 .5525 Mdot
.235 .54 Mdot
.4525 .51 Mdot
.51125 .4825 Mdot
.60125 .46375 Mdot
.49375 .46375 Mdot
.455 .45375 Mdot
.5175 .465 Mdot
.495 .47 Mdot
.49 .47875 Mdot
.51375 .51125 Mdot
.48875 .53625 Mdot
.18875 .54 Mdot
.39125 .54 Mdot
.385 .4975 Mdot
.43375 .47 Mdot
.6075 .465 Mdot
.54375 .46375 Mdot
.465 .46 Mdot
.45125 .43875 Mdot
.435 .4325 Mdot
.57625 .4225 Mdot
.545 .4125 Mdot
.455 .445 Mdot
.50125 .485 Mdot
.01875 .49875 Mdot
.24375 .485 Mdot
.3225 .43875 Mdot
.4175 .40875 Mdot
.5975 .42375 Mdot
.5125 .46125 Mdot
.24625 .55 Mdot
.58125 .57375 Mdot
.66125 .57875 Mdot
.84 .5475 Mdot
.25875 .48625 Mdot
.4 .43875 Mdot
.25375 .4375 Mdot
.80375 .445 Mdot
.63375 .465 Mdot
.3025 .495 Mdot
.46625 .48375 Mdot
.585 .4875 Mdot
.4875 .4975 Mdot
.5025 .4825 Mdot
.4575 .47375 Mdot
.50375 .4725 Mdot
.525 .455 Mdot
.4675 .4425 Mdot
.56375 .43125 Mdot
.43375 .40625 Mdot
.51625 .5675 Mdot
.475 .635 Mdot
.31375 .67375 Mdot
.8625 .675 Mdot
.31375 .67 Mdot
.53125 .57875 Mdot
.52 .43375 Mdot
.47 .3875 Mdot
.2275 .35125 Mdot
.27125 .34125 Mdot
.4675 .39875 Mdot
.505 .40125 Mdot
.5025 .40625 Mdot
.51125 .4425 Mdot
.5 .46125 Mdot
.3475 .51375 Mdot
.59625 .56625 Mdot
.71625 .57 Mdot
.3325 .4775 Mdot
.48 .38625 Mdot
.4675 .3075 Mdot
.31125 .28625 Mdot
.93625 .3 Mdot
.3575 .36875 Mdot
.4475 .42875 Mdot
.4725 .48375 Mdot
.53625 .45 Mdot
.48375 .4475 Mdot
.5125 .49625 Mdot
.48 .42625 Mdot
.2775 .3325 Mdot
.9925 .28 Mdot
.22125 .19625 Mdot
.47875 .04125 Mdot
.5425 .03625 Mdot
.2775 .09375 Mdot
.915 .1525 Mdot
.35125 .21625 Mdot
.40875 .30625 Mdot
.52125 .37375 Mdot
.51125 .40125 Mdot
.4975 .38875 Mdot
.56125 .495 Mdot
.45 .52625 Mdot
.29 .47875 Mdot
.85 .43125 Mdot
.45875 .40625 Mdot
.385 .21875 Mdot
.5 .07125 Mdot
.47375 .05125 Mdot
.38625 .125 Mdot
.4475 .1575 Mdot
.795 .17375 Mdot
.395 .1575 Mdot
.46 .06875 Mdot
.535 .02 Mdot
.745 .005 Mdot
.31875 .0375 Mdot
.52375 .035 Mdot
.5725 .0675 Mdot
.615 .09125 Mdot
.38875 .085 Mdot
.46875 .1075 Mdot
.50875 .1375 Mdot
.22875 .1475 Mdot
.84375 .17375 Mdot
.6025 .185 Mdot
.28625 .14125 Mdot
.45625 .15375 Mdot
.46375 .19625 Mdot
.71125 .2225 Mdot
.43875 .24875 Mdot
.45 .285 Mdot
.5125 .2675 Mdot
.50125 .24625 Mdot
.4925 .25125 Mdot
.5125 .23 Mdot
.49 .215 Mdot
.2775 .25875 Mdot
.88625 .27875 Mdot
.40625 .27125 Mdot
.415 .31625 Mdot
.33625 .355 Mdot
.76375 .37125 Mdot
.545 .385 Mdot
.40875 .43875 Mdot
.4675 .455 Mdot
.4325 .45 Mdot
.56125 .45375 Mdot
.53625 .47 Mdot
.47375 .46375 Mdot
.49625 .45875 Mdot
.10375 .45 Mdot
.33375 .395 Mdot
.325 .35875 Mdot
.32125 .3425 Mdot
.79875 .39125 Mdot
.40625 .485 Mdot
.2775 .5675 Mdot
.59125 .56875 Mdot
.665 .56125 Mdot
.71375 .52125 Mdot
.33 .4975 Mdot
.425 .455 Mdot
.29875 .4725 Mdot
.7275 .50375 Mdot
.605 .5175 Mdot
.36375 .47875 Mdot
.4375 .47875 Mdot
.52875 .485 Mdot
.63125 .48 Mdot
.44375 .48375 Mdot
.45125 .495 Mdot
.50625 .48375 Mdot
.4925 .48375 Mdot
.48875 .46625 Mdot
.6125 .4625 Mdot
.3875 .4825 Mdot
.50875 .7375 Mdot
.475 .72625 Mdot
.43875 .735 Mdot
.6375 .7525 Mdot
.4375 .7675 Mdot
.5225 .91875 Mdot
.475 .98875 Mdot
.51 .97125 Mdot
.49 .92 Mdot
.50875 .93625 Mdot
.46125 .9325 Mdot
.48875 .9075 Mdot
.63 .91875 Mdot
.535 .91625 Mdot
.51625 .8775 Mdot
.52125 .88375 Mdot
.5025 .79375 Mdot
.49125 .7875 Mdot
.37625 .8475 Mdot
.68875 .96125 Mdot
.44625 .9975 Mdot
.405 .925 Mdot
.85125 .8625 Mdot
.37375 .785 Mdot
.45 .7375 Mdot
.5075 .73125 Mdot
.495 .75125 Mdot
.51 .74375 Mdot
.5 .83625 Mdot
.50125 .85875 Mdot
.3625 .75625 Mdot
.72125 .68 Mdot
.44125 .6325 Mdot
.45125 .4725 Mdot
.23625 .415 Mdot
.9075 .39375 Mdot
.56625 .3525 Mdot
.345 .28375 Mdot
.47 .285 Mdot
.445 .27 Mdot
.5325 .245 Mdot
.53875 .22 Mdot
.4875 .36625 Mdot
.4925 .38375 Mdot
.24125 .3825 Mdot
.96375 .42 Mdot
.41 .4775 Mdot
.3575 .42625 Mdot
.21625 .48 Mdot
.99375 .5525 Mdot
.3475 .57875 Mdot
.315 .53 Mdot
.57875 .525 Mdot
.64375 .48375 Mdot
.55875 .41125 Mdot
.42375 .365 Mdot
.45375 .33625 Mdot
.36125 .19375 Mdot
.66125 .0575 Mdot
.4775 .02875 Mdot
.515 .2325 Mdot
.6175 .43125 Mdot
.3725 .63875 Mdot
.525 .21875 Mdot
.48875 .19625 Mdot
.4925 .1675 Mdot
.48125 .1525 Mdot
.51375 .16125 Mdot
.52375 .13875 Mdot
.5 .17875 Mdot
.48375 .19625 Mdot
.01625 .2025 Mdot
.15125 .24625 Mdot
.52625 .20375 Mdot
.465 .16875 Mdot
.47625 .16 Mdot
.49625 .1375 Mdot
.50875 .0875 Mdot
.54625 .07875 Mdot
.43875 .10125 Mdot
.55 .09875 Mdot
.47375 .0825 Mdot
.45375 .14 Mdot
.48625 .1275 Mdot
.18875 .12 Mdot
.22 .13125 Mdot
.44 .085 Mdot
.4875 .08875 Mdot
.53125 .06875 Mdot
.48625 .02125 Mdot
.125 .0475 Mdot
.20125 .17375 Mdot
.41 .14125 Mdot
.525 .19875 Mdot
.525 .20625 Mdot
.5175 .20375 Mdot
.4725 .20625 Mdot
.52875 .2 Mdot
.49 .1775 Mdot
.50875 .1275 Mdot
.50125 .07125 Mdot
.45875 .12875 Mdot
.50125 .11 Mdot
.19 .045 Mdot
.93625 .01375 Mdot
.53375 .02625 Mdot
.46 .10875 Mdot
.46625 .24375 Mdot
.40625 .295 Mdot
.855 .34375 Mdot
.30375 .36875 Mdot
.5175 .325 Mdot
.47875 .3425 Mdot
.51125 .415 Mdot
.505 .485 Mdot
.495 .475 Mdot
.49375 .4075 Mdot
.43375 .36875 Mdot
.57 .35625 Mdot
.5625 .3725 Mdot
.38875 .50125 Mdot
.445 .63125 Mdot
.35 .715 Mdot
.97125 .79875 Mdot
.3075 .86625 Mdot
.45375 .8975 Mdot
.50625 .91 Mdot
.49125 .91 Mdot
.50125 .89375 Mdot
.51875 .77125 Mdot
.495 .7425 Mdot
.43125 .82125 Mdot
.59625 .90125 Mdot
.46875 .9375 Mdot
.34875 .99625 Mdot
.64125 .84125 Mdot
.33625 .51875 Mdot
.51125 .51625 Mdot
.49625 .52625 Mdot
.49875 .52625 Mdot
.5025 .525 Mdot
.51 .52 Mdot
.51625 .52125 Mdot
.51625 .53125 Mdot
.48 .49125 Mdot
.055 .44875 Mdot
.23 .43 Mdot
.48875 .44 Mdot
.4775 .525 Mdot
.48875 .58125 Mdot
.50375 .61375 Mdot
.49625 .62 Mdot
.52625 .595 Mdot
.4975 .545 Mdot
.49625 .53375 Mdot
.4875 .52125 Mdot
.47 .54125 Mdot
.50375 .55375 Mdot
.165 .555 Mdot
.195 .55125 Mdot
.45625 .5275 Mdot
.49875 .5275 Mdot
.5025 .53625 Mdot
.5025 .56875 Mdot
.485 .58625 Mdot
.5375 .58625 Mdot
.4575 .5775 Mdot
.565 .57125 Mdot
.48875 .52875 Mdot
.49125 .49 Mdot
.455 .50375 Mdot
.1625 .50125 Mdot
.16625 .5175 Mdot
.4525 .5375 Mdot
.5075 .52375 Mdot
.5375 .53 Mdot
.51625 .53125 Mdot
.4625 .5025 Mdot
.54625 .49 Mdot
.495 .48375 Mdot
.5 .47625 Mdot
.50875 .4825 Mdot
.47625 .46875 Mdot
.475 .46875 Mdot
.1225 .4575 Mdot
.5125 .4225 Mdot
.32875 .44375 Mdot
.52125 .46 Mdot
.5 .47125 Mdot
.55125 .47875 Mdot
.43875 .4975 Mdot
.52 .51125 Mdot
.495 .51125 Mdot
.495 .51125 Mdot
.48625 .49125 Mdot
.47625 .4525 Mdot
.46125 .39 Mdot
.3975 .33625 Mdot
.94875 .27875 Mdot
.26125 .2575 Mdot
.48625 .245 Mdot
.46 .24125 Mdot
.48875 .23 Mdot
.52125 .2425 Mdot
.53875 .2375 Mdot
.495 .25375 Mdot
.47125 .2825 Mdot
.52375 .30375 Mdot
.50875 .28375 Mdot
.43125 .255 Mdot
.415 .20875 Mdot
.38 .16875 Mdot
.20375 .11 Mdot
.54125 .1125 Mdot
.45375 .1225 Mdot
.4975 .125 Mdot
.53125 .1425 Mdot
.4875 .16625 Mdot
.47625 .155 Mdot
.52 .11625 Mdot
.47125 .08125 Mdot
.51 .09875 Mdot
.495 .05875 Mdot
.08625 .03625 Mdot
.53375 .0425 Mdot
.52125 .02 Mdot
.025 .00375 Mdot
.23 .0225 Mdot
.4625 .0575 Mdot
.56375 .20125 Mdot
.55875 .32 Mdot
.39 .42875 Mdot
.49 .56 Mdot
.4425 .54125 Mdot
.5825 .535 Mdot
.55875 .51875 Mdot
.44625 .48875 Mdot
.52 .46125 Mdot
.515 .43875 Mdot
.46875 .45625 Mdot
.1775 .51875 Mdot
.30625 .59625 Mdot
.4975 .63625 Mdot
.46625 .62125 Mdot
.49875 .57625 Mdot
.49625 .54 Mdot
.48375 .51375 Mdot
.4625 .5175 Mdot
.70125 .53875 Mdot
.38 .54375 Mdot
.49 .55 Mdot
.47125 .51875 Mdot
.5125 .46625 Mdot
.22375 .44375 Mdot
.255 .43625 Mdot
.47375 .4725 Mdot
.5 .515 Mdot
.5025 .52 Mdot
.5175 .52 Mdot
.46625 .52625 Mdot
.46375 .535 Mdot
.6525 .54 Mdot
.47 .5375 Mdot
.4725 .54 Mdot
.48125 .53375 Mdot
.475 .51125 Mdot
.265 .51125 Mdot
.99625 .5425 Mdot
.2525 .56125 Mdot
.45625 .59375 Mdot
.505 .59125 Mdot
.535 .5725 Mdot
.515 .54125 Mdot
.445 .54125 Mdot
.50125 .53125 Mdot
.62125 .5575 Mdot
.44625 .5775 Mdot
.5025 .585 Mdot
.47375 .54875 Mdot
.4775 .52875 Mdot
.20625 .515 Mdot
.9 .51375 Mdot
.52 .51375 Mdot
.3775 .5175 Mdot
.53875 .50875 Mdot
.4875 .4975 Mdot
.54375 .48125 Mdot
.43125 .4725 Mdot
.4625 .46625 Mdot
.59375 .4675 Mdot
.48375 .46875 Mdot
.46625 .4525 Mdot
.48625 .43625 Mdot
.47375 .445 Mdot
.465 .44625 Mdot
.815 .45375 Mdot
.2825 .475 Mdot
.4975 .49875 Mdot
.46625 .52 Mdot
.50125 .5225 Mdot
.5075 .5025 Mdot
.51625 .50375 Mdot
.50625 .49 Mdot
.51375 .45875 Mdot
.4875 .44125 Mdot
.52625 .45625 Mdot
.43875 .48875 Mdot
.43 .49625 Mdot
.39 .50625 Mdot
.935 .52 Mdot
.2825 .52875 Mdot
.52875 .50375 Mdot
.4525 .485 Mdot
.49 .47875 Mdot
.51625 .46875 Mdot
.5275 .45875 Mdot
.46125 .465 Mdot
.49875 .4875 Mdot
.51 .4925 Mdot
.4875 .5075 Mdot
.49875 .54625 Mdot
.14 .5325 Mdot
.49 .5275 Mdot
.28875 .525 Mdot
.505 .4875 Mdot
.46125 .48375 Mdot
.4975 .48875 Mdot
.5025 .49 Mdot
.53875 .47625 Mdot
.4925 .48 Mdot
.50875 .49 Mdot
.50375 .48875 Mdot
.50125 .475 Mdot
.43 .505 Mdot
.085 .50625 Mdot
.24875 .5075 Mdot
.35625 .51625 Mdot
.52625 .49875 Mdot
.53125 .49875 Mdot
.49875 .50375 Mdot
.47875 .50625 Mdot
.5 .50625 Mdot
.48625 .50125 Mdot
.4775 .49625 Mdot
.55125 .495 Mdot
.49125 .515 Mdot
.315 .5025 Mdot
.46625 .505 Mdot
.24125 .50375 Mdot
.4725 .46875 Mdot
.44625 .46 Mdot
.48125 .47375 Mdot
.585 .47375 Mdot
.47625 .48625 Mdot
.4525 .52 Mdot
.5175 .03875 Mdot
.45125 .07 Mdot
.42375 .085 Mdot
.7725 .06625 Mdot
.3925 .03125 Mdot
.48875 .0125 Mdot
.4675 .0775 Mdot
.4825 .1325 Mdot
.26375 .18 Mdot
.81375 .225 Mdot
.50875 .28125 Mdot
.41625 .27125 Mdot
.5325 .24875 Mdot
.4975 .2475 Mdot
.5325 .24625 Mdot
.43375 .22875 Mdot
.35875 .2275 Mdot
.79125 .2275 Mdot
.3925 .21875 Mdot
.46125 .2775 Mdot
.49 .2775 Mdot
.49125 .265 Mdot
.49125 .27375 Mdot
.715 .2725 Mdot
.3325 .19125 Mdot
.5025 .15125 Mdot
.47625 .1025 Mdot
.49 .06875 Mdot
.505 .06375 Mdot
.48125 .0775 Mdot
.47375 .1275 Mdot
.69625 .1925 Mdot
.34875 .24125 Mdot
.585 .215 Mdot
.42875 .21625 Mdot
.425 .22125 Mdot
.4325 .2125 Mdot
.82 .23625 Mdot
.34 .29125 Mdot
.5325 .31375 Mdot
.45 .34375 Mdot
.39625 .38625 Mdot
.5925 .39625 Mdot
.64375 .4125 Mdot
.37 .42 Mdot
.49375 .4275 Mdot
.505 .43125 Mdot
.4825 .435 Mdot
.51 .42875 Mdot
.24625 .45375 Mdot
.95 .46125 Mdot
.47625 .47 Mdot
.355 .47625 Mdot
.4975 .5025 Mdot
.4575 .5025 Mdot
.4125 .49625 Mdot
.62125 .49375 Mdot
.55875 .50625 Mdot
.445 .50125 Mdot
.5025 .495 Mdot
.5225 .4975 Mdot
.49625 .5025 Mdot
.42625 .5125 Mdot
.18375 .5225 Mdot
.335 .55375 Mdot
.3575 .5575 Mdot
.54125 .53875 Mdot
.51375 .5375 Mdot
.43125 .5325 Mdot
.6075 .52125 Mdot
.475 .50125 Mdot
.46125 .4975 Mdot
.5 .5025 Mdot
.53125 .495 Mdot
.4725 .47125 Mdot
.35875 .47625 Mdot
.515 .45 Mdot
.89 .43375 Mdot
.27625 .42125 Mdot
.5075 .4475 Mdot
.45875 .46125 Mdot
.4825 .39 Mdot
.53 .28875 Mdot
.58375 .1675 Mdot
.72375 .99875 Mdot
.495 .94 Mdot
.45 .86875 Mdot
.52625 .8775 Mdot
.49375 .87875 Mdot
.53125 .805 Mdot
.4475 .785 Mdot
.23875 .76 Mdot
.27875 .68125 Mdot
.47625 .71375 Mdot
.4925 .7975 Mdot
.50625 .8 Mdot
.505 .7875 Mdot
.63375 .7575 Mdot
.37625 .76125 Mdot
.50375 .72 Mdot
.48 .75625 Mdot
.4925 .755 Mdot
.50625 .7 Mdot
.445 .65625 Mdot
.45375 .55625 Mdot
.835 .4475 Mdot
.23 .38375 Mdot
.62875 .47125 Mdot
.45 .48125 Mdot
.41 .43125 Mdot
.48875 .44625 Mdot
.6725 .37625 Mdot
.42 .225 Mdot
.5275 .11875 Mdot
.44625 .085 Mdot
.29875 .01 Mdot
.6825 .04 Mdot
.75625 .07 Mdot
.265 .1175 Mdot
.5075 .13375 Mdot
.5025 .1475 Mdot
.4725 .23625 Mdot
.51375 .24375 Mdot
.3525 .17125 Mdot
.79375 .12375 Mdot
.46 .055 Mdot
.41375 .045 Mdot
.42625 .07625 Mdot
.5075 .0875 Mdot
.515 .1225 Mdot
.47625 .12375 Mdot
.39625 .085 Mdot
.54 .0975 Mdot
.745 .10875 Mdot
.355 .10625 Mdot
.52 .1 Mdot
.45125 .1125 Mdot
.48875 .375 Mdot
.46875 .67625 Mdot
.44625 .01125 Mdot
.4625 .02625 Mdot
.495 .05 Mdot
.53 .06625 Mdot
.51375 .13125 Mdot
.495 .085 Mdot
.1025 .04375 Mdot
.54 .0425 Mdot
.425 .095 Mdot
.49125 .1675 Mdot
.485 .21 Mdot
.52125 .27625 Mdot
.48625 .3875 Mdot
.49125 .475 Mdot
.2475 .5675 Mdot
.21875 .72625 Mdot
.46875 .73125 Mdot
.48625 .71375 Mdot
.48625 .7325 Mdot
.4275 .76375 Mdot
.59625 .7975 Mdot
.505 .8325 Mdot
.4725 .92125 Mdot
.51125 .92625 Mdot
.495 .92 Mdot
.52375 .95625 Mdot
.54625 .99125 Mdot
.54125 .9775 Mdot
.45125 .97625 Mdot
.495 .7975 Mdot
.405 .575 Mdot
.77 .3275 Mdot
.33 .13 Mdot
.45 .49625 Mdot
.23625 .4925 Mdot
.9425 .48375 Mdot
.63 .4675 Mdot
.2475 .4725 Mdot
.535 .47625 Mdot
.49375 .45875 Mdot
.44875 .455 Mdot
.52375 .435 Mdot
.50875 .41625 Mdot
.49625 .42875 Mdot
.48625 .44125 Mdot
.4825 .45 Mdot
.4675 .4275 Mdot
.5925 .43625 Mdot
.41875 .4475 Mdot
.17125 .46375 Mdot
.5075 .53125 Mdot
.42875 .5125 Mdot
.52875 .48875 Mdot
.515 .48875 Mdot
.50125 .4675 Mdot
.50375 .48875 Mdot
.4775 .5125 Mdot
.46625 .52125 Mdot
.58 .5025 Mdot
.47625 .4925 Mdot
.52125 .45125 Mdot
.0225 .43 Mdot
.09125 .445 Mdot
.39625 .435 Mdot
.50125 .44625 Mdot
.525 .43875 Mdot
.5375 .415 Mdot
.4775 .41125 Mdot
.4475 .4275 Mdot
.48 .42875 Mdot
.54 .41625 Mdot
.47625 .39125 Mdot
.51125 .37 Mdot
.48 .33625 Mdot
.16875 .275 Mdot
.12375 .18875 Mdot
.465 .1425 Mdot
.48625 .1025 Mdot
.455 .08 Mdot
.5375 .05625 Mdot
.49625 .03 Mdot
.53375 .02125 Mdot
.43625 .00875 Mdot
.5125 .01375 Mdot
.56 .02125 Mdot
.48375 .0575 Mdot
.43875 .03125 Mdot
.09875 .02 Mdot
.075 .0075 Mdot
.52375 .01625 Mdot
.47375 .0225 Mdot
.48875 .025 Mdot
.35 .0275 Mdot
.415 .05 Mdot
.0825 0 Mdot
.57125 .00125 Mdot
.53625 .0025 Mdot
.455 .1475 Mdot
.535 .29875 Mdot
.45 .43 Mdot
.09375 .5175 Mdot
.20375 .69375 Mdot
.38875 .72 Mdot
.51 .7625 Mdot
.46875 .795 Mdot
.495 .755 Mdot
.46875 .7325 Mdot
.55625 .7575 Mdot
.56375 .75375 Mdot
.4525 .73875 Mdot
.52 .75625 Mdot
.46875 .81125 Mdot
.45875 .74125 Mdot
.37125 .66875 Mdot
.93125 .63375 Mdot
.22625 .6025 Mdot
.46125 .46 Mdot
.3125 .4625 Mdot
.85875 .45875 Mdot
.5625 .4675 Mdot
.31875 .47875 Mdot
.53375 .4825 Mdot
.5 .47625 Mdot
.3925 .47375 Mdot
.595 .48 Mdot
.49875 .48625 Mdot
.4975 .4925 Mdot
.4875 .50125 Mdot
.49 .49625 Mdot
.455 .51375 Mdot
.58 .5225 Mdot
.4575 .53 Mdot
.24125 .5225 Mdot
.125 .5325 Mdot
.51125 .5375 Mdot
.42 .535 Mdot
.48875 .5475 Mdot
.545 .54 Mdot
.565 .53 Mdot
.475 .50375 Mdot
.465 .4825 Mdot
.475 .46625 Mdot
.56 .4675 Mdot
.47625 .46125 Mdot
.53375 .4625 Mdot
.08375 .48625 Mdot
.1975 .49375 Mdot
.38875 .52125 Mdot
.5 .5325 Mdot
.52125 .52 Mdot
.4925 .52125 Mdot
.57875 .505 Mdot
.4075 .46875 Mdot
.48625 .46375 Mdot
.5375 .4825 Mdot
.47125 .49625 Mdot
.52375 .4975 Mdot
.48 .4975 Mdot
.23125 .50375 Mdot
.20125 .48125 Mdot
.4675 .48625 Mdot
.48125 .48875 Mdot
.42875 .48 Mdot
.5425 .47625 Mdot
.57 .48375 Mdot
.4975 .48125 Mdot
.41875 .47875 Mdot
.51125 .4775 Mdot
.5575 .4475 Mdot
.47875 .44625 Mdot
.47625 .4475 Mdot
.1375 .46 Mdot
.07125 .47625 Mdot
.49375 .49 Mdot
.60875 .50125 Mdot
.47 .50625 Mdot
.51875 .53375 Mdot
.5 .55 Mdot
.43625 .54625 Mdot
.55375 .5475 Mdot
.46125 .545 Mdot
.4825 .52125 Mdot
.535 .46375 Mdot
.36125 .4425 Mdot
.35875 .4475 Mdot
.11375 .44875 Mdot
.615 .48875 Mdot
.4625 .49125 Mdot
.4525 .4775 Mdot
.50375 .4525 Mdot
.49625 .45875 Mdot
.51625 .4575 Mdot
.49125 .485 Mdot
.48375 .4725 Mdot
.10875 .47375 Mdot
.86 .4975 Mdot
.94125 .51 Mdot
.08875 .49 Mdot
.53 .49875 Mdot
.48125 .50125 Mdot
.505 .48875 Mdot
.49375 .4975 Mdot
.52125 .49125 Mdot
.48875 .4975 Mdot
.50875 .50375 Mdot
.50125 .51 Mdot
.4725 .455 Mdot
.49125 .43625 Mdot
.11375 .4175 Mdot
.62 .385 Mdot
.28375 .42 Mdot
.4525 .44375 Mdot
.61375 .46125 Mdot
.4775 .45 Mdot
.4575 .4575 Mdot
.48625 .43375 Mdot
.45625 .39 Mdot
.55875 .35 Mdot
.45 .3225 Mdot
.55375 .3125 Mdot
.4275 .3 Mdot
.025 .28 Mdot
.18 .21375 Mdot
.34125 .1625 Mdot
.5 .11125 Mdot
.49125 .075 Mdot
.4825 .0525 Mdot
.4925 .04375 Mdot
.56625 .02125 Mdot
.49375 .02625 Mdot
.5 .04625 Mdot
.4975 .06625 Mdot
.49625 .0825 Mdot
.3825 .18375 Mdot
.37875 .27625 Mdot
.98625 .34625 Mdot
.2125 .40125 Mdot
.47875 .2625 Mdot
.36625 .23875 Mdot
.7675 .245 Mdot
.54125 .26875 Mdot
.355 .2375 Mdot
.535 .235 Mdot
.505 .25125 Mdot
.30125 .265 Mdot
.7325 .25875 Mdot
.49375 .24625 Mdot
.44 .2125 Mdot
.53125 .2125 Mdot
.4825 .1825 Mdot
.44875 .1575 Mdot
.56125 .185 Mdot
.45875 .1925 Mdot
.35625 .18375 Mdot
.95 .1975 Mdot
.22625 .205 Mdot
.50875 .1475 Mdot
.44375 .13125 Mdot
.385 .10625 Mdot
.61375 .0825 Mdot
.67 .07625 Mdot
.38875 .08375 Mdot
.47 .08375 Mdot
.5 .08125 Mdot
.52625 .0625 Mdot
.47875 .11125 Mdot
.5275 .09625 Mdot
.18375 .07625 Mdot
.315 .14875 Mdot
.39375 .11375 Mdot
.495 .18875 Mdot
.49 .2475 Mdot
.41875 .26375 Mdot
.8075 .26125 Mdot
.305 .275 Mdot
.46 .25 Mdot
.54 .24125 Mdot
.475 .24125 Mdot
.52 .27 Mdot
.47875 .2825 Mdot
.3275 .3125 Mdot
.9875 .35875 Mdot
.25875 .39125 Mdot
.48 .3775 Mdot
.48375 .3825 Mdot
.42375 .3875 Mdot
.435 .3875 Mdot
.7725 .35875 Mdot
.415 .37125 Mdot
.4075 .41375 Mdot
.52125 .44875 Mdot
.545 .48625 Mdot
.4775 .54 Mdot
.47625 .5775 Mdot
.25875 .56625 Mdot
.16 .52625 Mdot
.4975 .5 Mdot
.61125 .48375 Mdot
.4525 .46625 Mdot
.44375 .45125 Mdot
.66375 .4475 Mdot
.36375 .45125 Mdot
.53875 .47375 Mdot
.475 .4975 Mdot
.49 .50625 Mdot
.52875 .48125 Mdot
.38875 .46375 Mdot
.41125 .445 Mdot
.9275 .44375 Mdot
.265 .4675 Mdot
.54625 .49375 Mdot
.485 .5225 Mdot
.42125 .5225 Mdot
.5275 .515 Mdot
.575 .49625 Mdot
.45625 .48625 Mdot
.49375 .45625 Mdot
.49375 .49 Mdot
.19625 .50125 Mdot
.75875 .49625 Mdot
.845 .49 Mdot
.1825 .50625 Mdot
.5225 .48125 Mdot
.49375 .4725 Mdot
.49875 .47375 Mdot
.4775 .48 Mdot
.45875 .48875 Mdot
.59875 .485 Mdot
.5175 .48 Mdot
.45625 .475 Mdot
.48125 .48875 Mdot
.50375 .49125 Mdot
.2125 .495 Mdot
.885 .50125 Mdot
.58375 .53125 Mdot
.335 .5275 Mdot
.4525 .525 Mdot
.59125 .5225 Mdot
.47625 .53375 Mdot
.4825 .51375 Mdot
.4425 .52 Mdot
.5525 .5225 Mdot
.51625 .52125 Mdot
.46625 .5075 Mdot
.53125 .52375 Mdot
.435 .495 Mdot
.08875 .4775 Mdot
.19875 .4575 Mdot
.37375 .43625 Mdot
.4925 .45875 Mdot
.49625 .465 Mdot
.46875 .4825 Mdot
.4825 .49375 Mdot
.57375 .4975 Mdot
.54 .48375 Mdot
.4825 .485 Mdot
.47375 .4675 Mdot
.49375 .4575 Mdot
.385 .41125 Mdot
.41625 .3625 Mdot
.97125 .29375 Mdot
.1925 .2875 Mdot
.515 .95375 Mdot
.39875 .87875 Mdot
.535 .77625 Mdot
.49875 .73625 Mdot
.22875 .7075 Mdot
.86 .71375 Mdot
.4875 .74125 Mdot
.3775 .82 Mdot
.57375 .855 Mdot
.48 .8975 Mdot
.45 .9225 Mdot
.52625 .935 Mdot
.4975 .8875 Mdot
.4225 .85875 Mdot
.77 .815 Mdot
.31375 .775 Mdot
.5075 .755 Mdot
.46125 .75875 Mdot
.32 .79125 Mdot
.64 .8275 Mdot
.77375 .84625 Mdot
.3125 .88375 Mdot
.47875 .9475 Mdot
.495 .99625 Mdot
.39375 .91 Mdot
.50625 .645 Mdot
.46125 .49 Mdot
.3075 .405 Mdot
.19875 .39125 Mdot
.44875 .4875 Mdot
.53 .5125 Mdot
.495 .52125 Mdot
.52375 .5875 Mdot
.46375 .54875 Mdot
.3975 .4825 Mdot
.83625 .4 Mdot
.3475 .3175 Mdot
.49625 .1775 Mdot
.475 .11125 Mdot
.40625 .0775 Mdot
.31625 .03625 Mdot
.32375 .01375 Mdot
.255 0 Mdot
.52625 .02625 Mdot
.40875 .045 Mdot
.43375 .0575 Mdot
.81375 .06125 Mdot
.36625 .0075 Mdot
.4975 .04125 Mdot
.51125 .05875 Mdot
.29 .04 Mdot
.6475 .0175 Mdot
.435 0 Mdot
.48125 .045 Mdot
.49875 .0325 Mdot
.2725 .04875 Mdot
.8 .06875 Mdot
.56625 .095 Mdot
.36875 .08375 Mdot
.4575 .12125 Mdot
.58125 .1375 Mdot
.4825 .14125 Mdot
.47875 .1425 Mdot
.35375 .15125 Mdot
.7425 .14375 Mdot
.42625 .13625 Mdot
.46625 .13125 Mdot
.53 .165 Mdot
.44125 .14875 Mdot
.195 .18625 Mdot
.26 .26125 Mdot
.40625 .26125 Mdot
.4875 .30625 Mdot
.51 .3425 Mdot
.43875 .345 Mdot
.4825 .34125 Mdot
.565 .34 Mdot
.63125 .3575 Mdot
.43625 .35625 Mdot
.47375 .35625 Mdot
.49625 .38 Mdot
.3775 .49375 Mdot
.4575 .605 Mdot
.89375 .73875 Mdot
.22125 .9075 Mdot
.505 .465 Mdot
.495 .5225 Mdot
.55875 .56875 Mdot
.495 .6175 Mdot
.4625 .71625 Mdot
.52625 .8 Mdot
.48125 .83125 Mdot
.175 .87375 Mdot
.97125 .885 Mdot
.49375 .9 Mdot
.30625 .89375 Mdot
.6175 .875 Mdot
.4625 .865 Mdot
.48 .86625 Mdot
.47125 .7975 Mdot
.53125 .82875 Mdot
.495 .85375 Mdot
.58875 .85125 Mdot
.415 .86625 Mdot
.5075 .91875 Mdot
.46125 .91125 Mdot
.265 .91625 Mdot
.67 .90375 Mdot
.8625 .89125 Mdot
.23625 .87625 Mdot
.51125 .83875 Mdot
.485 .79375 Mdot
.51875 .78125 Mdot
.485 .71 Mdot
.50125 .6975 Mdot
.4375 .685 Mdot
.5875 .705 Mdot
.5475 .75875 Mdot
.42375 .86875 Mdot
.4925 .9725 Mdot
.49875 .97625 Mdot
.46625 .90125 Mdot
.5525 .82375 Mdot
.48625 .72125 Mdot
.5 .7025 Mdot
.255 .6675 Mdot
.9225 .68875 Mdot
.35375 .70375 Mdot
.44375 .775 Mdot
.53125 .83125 Mdot
.45625 .8725 Mdot
.32125 .78875 Mdot
.90875 .71375 Mdot
.37125 .63375 Mdot
.41625 .50875 Mdot
.48875 .385 Mdot
.525 .31125 Mdot
.435 .26625 Mdot
.46875 .26375 Mdot
.5025 .24625 Mdot
.755 .2425 Mdot
.38 .25625 Mdot
.49375 .35375 Mdot
.4875 .39875 Mdot
.385 .4375 Mdot
.49375 .495 Mdot
.815 .57375 Mdot
.245 .50375 Mdot
.51625 .28375 Mdot
.51875 .24625 Mdot
.49125 .2175 Mdot
.495 .2025 Mdot
.5025 .19375 Mdot
.49875 .215 Mdot
.49125 .22125 Mdot
.12625 .19875 Mdot
.46375 .13375 Mdot
.2525 .07125 Mdot
.695 .03375 Mdot
.415 .01375 Mdot
.5 .005 Mdot
.4575 .02 Mdot
.5275 .03 Mdot
.53375 .05125 Mdot
.47125 .08125 Mdot
.5075 .08 Mdot
.48625 .13125 Mdot
.475 .1625 Mdot
.23625 .13625 Mdot
.6375 .14125 Mdot
.99125 .1575 Mdot
.1625 .1 Mdot
.515 .0575 Mdot
.5125 .0525 Mdot
.4825 .02125 Mdot
.49 .01125 Mdot
.52125 .05 Mdot
.5225 .07875 Mdot
.44125 .1325 Mdot
.505 .22875 Mdot
.45625 .21375 Mdot
.0375 .16625 Mdot
.4225 .05 Mdot
.51375 .08875 Mdot
.5425 .16375 Mdot
.46125 .18375 Mdot
.5225 .15875 Mdot
.53625 .1175 Mdot
.48625 .07 Mdot
.51875 .00875 Mdot
.175 .04875 Mdot
.49125 .05375 Mdot
.2925 .0825 Mdot
.69875 .0925 Mdot
.71 .09875 Mdot
.29 .0925 Mdot
.50875 .0125 Mdot
.5625 .02625 Mdot
.4725 .08375 Mdot
.505 .16875 Mdot
.4775 .2725 Mdot
.52 .44 Mdot
.4525 .56 Mdot
.1775 .665 Mdot
.505 .83125 Mdot
.38125 .835 Mdot
.4525 .755 Mdot
.50375 .68375 Mdot
.435 .66 Mdot
.54625 .61375 Mdot
.56875 .5975 Mdot
.4525 .6925 Mdot
.46375 .83375 Mdot
.54 .91125 Mdot
.49125 .9925 Mdot
.52375 .98375 Mdot
.4675 .965 Mdot
.515 .8575 Mdot
.7175 .62625 Mdot
.3 .45 Mdot
.5125 .4575 Mdot
.47625 .44875 Mdot
.5725 .4475 Mdot
.4725 .45875 Mdot
.48375 .4625 Mdot
.49625 .475 Mdot
.4875 .47625 Mdot
.21625 .48125 Mdot
.98625 .49875 Mdot
.44875 .5225 Mdot
.28125 .5325 Mdot
.68625 .55875 Mdot
.41625 .5675 Mdot
.51375 .55625 Mdot
.435 .54625 Mdot
.52 .53 Mdot
.565 .5 Mdot
.4775 .49625 Mdot
.4925 .51125 Mdot
.46625 .4875 Mdot
.4975 .49 Mdot
.2725 .5 Mdot
.60375 .4725 Mdot
.9475 .45625 Mdot
.18125 .49125 Mdot
.5275 .51125 Mdot
.52625 .53125 Mdot
.465 .5675 Mdot
.50625 .56875 Mdot
.49625 .54875 Mdot
.5025 .535 Mdot
.54875 .51125 Mdot
.48 .485 Mdot
.455 .48 Mdot
.5075 .465 Mdot
.4275 .44625 Mdot
.09375 .44375 Mdot
.40125 .4375 Mdot
.49875 .42625 Mdot
.565 .40875 Mdot
.47375 .43 Mdot
.52 .4475 Mdot
.51125 .45625 Mdot
.54 .4775 Mdot
.49125 .49125 Mdot
.49875 .4725 Mdot
.5375 .48 Mdot
.39625 .48375 Mdot
.08375 .49375 Mdot
.19375 .53 Mdot
.43 .505 Mdot
.5325 .50625 Mdot
.5225 .4975 Mdot
.485 .5 Mdot
.47625 .48625 Mdot
.56125 .49875 Mdot
.4575 .48875 Mdot
.46875 .48375 Mdot
.50875 .47375 Mdot
.525 .44625 Mdot
.46625 .42875 Mdot
.1725 .42625 Mdot
.17125 .42375 Mdot
.51125 .4575 Mdot
.5 .46125 Mdot
.51125 .46 Mdot
.485 .47375 Mdot
.51375 .475 Mdot
.49625 .46625 Mdot
.49625 .46875 Mdot
.4975 .47125 Mdot
.50375 .4725 Mdot
.49875 .4825 Mdot
.29125 .4725 Mdot
.7125 .46125 Mdot
.74875 .45875 Mdot
.25375 .43625 Mdot
.4725 .41 Mdot
.53375 .3925 Mdot
.49375 .3875 Mdot
.4775 .3675 Mdot
.52 .34875 Mdot
.49375 .35375 Mdot
.4775 .35625 Mdot
.515 .32 Mdot
.51125 .28625 Mdot
.46 .25875 Mdot
.10125 .2175 Mdot
.4775 .13125 Mdot
.4025 .10125 Mdot
.43625 .0925 Mdot
.5 .09 Mdot
.485 .08375 Mdot
.4775 .125 Mdot
.51875 .14375 Mdot
.49625 .1375 Mdot
.4975 .095 Mdot
.5275 .09125 Mdot
.485 .105 Mdot
.53375 .08125 Mdot
.125 .06625 Mdot
.19125 .05875 Mdot
.4675 .00125 Mdot
.485 .0075 Mdot
.48625 .03125 Mdot
.45625 .07875 Mdot
.545 .13375 Mdot
.495 .18 Mdot
.38875 .20125 Mdot
.45375 .19625 Mdot
.90625 .16 Mdot
.255 .0875 Mdot
.62375 .02625 Mdot
.4375 .06875 Mdot
.48125 .16 Mdot
.54375 .25875 Mdot
.4475 .3575 Mdot
.5 .18875 Mdot
.4 .195 Mdot
.7525 .2125 Mdot
.375 .2225 Mdot
.48625 .2525 Mdot
.50625 .29625 Mdot
.47375 .34 Mdot
.3175 .3575 Mdot
.8475 .3675 Mdot
.4575 .3775 Mdot
.3325 .37125 Mdot
.65625 .355 Mdot
.43 .375 Mdot
.50625 .4075 Mdot
.41875 .4275 Mdot
.45375 .4425 Mdot
.69125 .4725 Mdot
.4575 .4725 Mdot
.53125 .4775 Mdot
.41875 .485 Mdot
.48875 .47 Mdot
.3575 .46 Mdot
.5275 .49 Mdot
.85375 .4925 Mdot
.27 .49 Mdot
.51375 .50625 Mdot
.53625 .50375 Mdot
.46375 .47875 Mdot
.49375 .4725 Mdot
.39625 .49125 Mdot
.73625 .50375 Mdot
.4475 .515 Mdot
.4625 .51125 Mdot
.45875 .50875 Mdot
.50375 .5 Mdot
.46 .5025 Mdot
.15125 .4975 Mdot
.09 .51875 Mdot
.42875 .5125 Mdot
.48625 .5225 Mdot
.56875 .53375 Mdot
.46125 .535 Mdot
.46375 .535 Mdot
.655 .54625 Mdot
.47 .51375 Mdot
.47 .48625 Mdot
.50375 .49625 Mdot
.545 .52625 Mdot
.3975 .5175 Mdot
.1875 .5275 Mdot
.2775 .4975 Mdot
.43375 .45875 Mdot
.54875 .4675 Mdot
.5075 .485 Mdot
.45375 .50375 Mdot
.45 .53125 Mdot
.685 .5425 Mdot
.41125 .53625 Mdot
.45125 .5175 Mdot
.52375 .50875 Mdot
.52 .5025 Mdot
.46125 .485 Mdot
.24625 .48 Mdot
.24 .47375 Mdot
.515 .45 Mdot
.49625 .4625 Mdot
.51 .4675 Mdot
.4725 .475 Mdot
.46375 .4925 Mdot
.585 .515 Mdot
.48875 .5125 Mdot
.47375 .505 Mdot
.5125 .49625 Mdot
.49125 .46 Mdot
.3325 .46125 Mdot
.68625 .46125 Mdot
.6725 .4575 Mdot
.31375 .475 Mdot
.46125 .51375 Mdot
.545 .52625 Mdot
.4975 .52375 Mdot
.43625 .5325 Mdot
.575 .5125 Mdot
.5325 .48875 Mdot
.43125 .46375 Mdot
.505 .46375 Mdot
.53125 .5 Mdot
.475 .5275 Mdot
.15875 .5325 Mdot
.9975 .53875 Mdot
.47625 .5575 Mdot
.46125 .5225 Mdot
.415 .50375 Mdot
.48 .50125 Mdot
.47875 .5125 Mdot
.54375 .4975 Mdot
.49625 .4925 Mdot
.47875 .485 Mdot
.49875 .5 Mdot
.52875 .4775 Mdot
.50375 .48125 Mdot
.52875 .495 Mdot
.1625 .5 Mdot
.2225 .53125 Mdot
.47375 .53625 Mdot
.4525 .5275 Mdot
.5075 .53625 Mdot
.5925 .51625 Mdot
.4775 .505 Mdot
.4575 .47875 Mdot
.50125 .46 Mdot
.44625 .43 Mdot
.54625 .39625 Mdot
.52 .40125 Mdot
.40375 .4075 Mdot
.41625 .40125 Mdot
.8725 .4125 Mdot
.29125 .4625 Mdot
.6325 .45875 Mdot
.43375 .47 Mdot
.4225 .4325 Mdot
.52375 .38625 Mdot
.5575 .3125 Mdot
.41625 .245 Mdot
.485 .5525 Mdot
.3375 .52625 Mdot
.91125 .47 Mdot
.29875 .41875 Mdot
.49 .3775 Mdot
.49125 .3675 Mdot
.47875 .3325 Mdot
.4125 .3075 Mdot
.70375 .3375 Mdot
.485 .33 Mdot
.38375 .26 Mdot
.6075 .225 Mdot
.44 .175 Mdot
.51125 .05375 Mdot
.42125 .0125 Mdot
.495 .05625 Mdot
.385 .07 Mdot
.50625 .06 Mdot
.75 .0475 Mdot
.49125 .04375 Mdot
.505 .07875 Mdot
.22625 .13 Mdot
.20625 .26 Mdot
.43875 .2 Mdot
.51 .23 Mdot
.54375 .23375 Mdot
.465 .22875 Mdot
.37125 .26 Mdot
.8425 .32125 Mdot
.37375 .3375 Mdot
.4575 .33125 Mdot
.49875 .30875 Mdot
.54375 .27 Mdot
.42 .18875 Mdot
.3025 .14 Mdot
.88375 .12875 Mdot
.35375 .125 Mdot
.46875 .13125 Mdot
.565 .12625 Mdot
.48625 .1075 Mdot
.44375 .045 Mdot
.3575 0 Mdot
.525 .03 Mdot
.46625 .095 Mdot
.31125 .15 Mdot
.88125 .23 Mdot
.30625 .31 Mdot
.51625 .32125 Mdot
.5 .32 Mdot
.505 .305 Mdot
.47375 .2675 Mdot
.385 .19625 Mdot
.745 .1525 Mdot
.405 .13625 Mdot
.4725 .1275 Mdot
.51375 .155 Mdot
.49125 .21625 Mdot
.38 .2275 Mdot
.64125 .24875 Mdot
.60875 .26375 Mdot
.37 .24375 Mdot
.46 .235 Mdot
.54 .24625 Mdot
.51625 .25625 Mdot
.275 .2725 Mdot
.82625 .28625 Mdot
.465 .29 Mdot
.39875 .2925 Mdot
.52125 .29125 Mdot
.515 .29375 Mdot
.485 .31 Mdot
.24875 .30125 Mdot
.8625 .28 Mdot
.47625 .24875 Mdot
.485 .23625 Mdot
.41375 .21125 Mdot
.4025 .20125 Mdot
.57375 .18375 Mdot
.6125 .15625 Mdot
.42625 .1525 Mdot
.495 .155 Mdot
.49125 .15125 Mdot
.51875 .17375 Mdot
.49375 .25 Mdot
.54625 .25625 Mdot
.24 .2725 Mdot
.93125 .2925 Mdot
.29375 .275 Mdot
.48875 .2325 Mdot
.43375 .25375 Mdot
.4325 .26125 Mdot
.77 .27125 Mdot
.43125 .30875 Mdot
.42 .3625 Mdot
.5125 .37 Mdot
.455 .3675 Mdot
.5275 .34625 Mdot
.54625 .35625 Mdot
.42 .345 Mdot
.40375 .39 Mdot
.79375 .42875 Mdot
.32625 .485 Mdot
.635 .51 Mdot
.41375 .5225 Mdot
.37375 .52125 Mdot
.69375 .535 Mdot
.47375 .5525 Mdot
.4125 .5375 Mdot
.495 1 Mdot
.51375 .995 Mdot
.4925 .93375 Mdot
.4875 .93375 Mdot
.2925 .97625 Mdot
.91375 .9775 Mdot
.32125 .97 Mdot
.48875 .97875 Mdot
.4225 .91375 Mdot
.57 .82875 Mdot
.60125 .7575 Mdot
.41125 .6925 Mdot
.455 .6125 Mdot
.54875 .515 Mdot
.5125 .45125 Mdot
.13875 .425 Mdot
.36875 .44125 Mdot
.3925 .505 Mdot
.52625 .555 Mdot
.51 .6025 Mdot
.5 .585 Mdot
.35 .61625 Mdot
.70125 .6525 Mdot
.47125 .6775 Mdot
.5225 .61125 Mdot
.43 .59 Mdot
.30125 .6175 Mdot
.6825 .68 Mdot
.675 .7825 Mdot
.3675 .85625 Mdot
.4875 .9225 Mdot
.49875 .935 Mdot
.5025 .9075 Mdot
.5025 .84 Mdot
.52375 .79125 Mdot
.3525 .715 Mdot
.74625 .6025 Mdot
.36125 .54625 Mdot
.5075 .44875 Mdot
.39375 .36625 Mdot
.39375 .3175 Mdot
.94875 .29 Mdot
.35 .21375 Mdot
.4025 .19125 Mdot
.51875 .22875 Mdot
.46 .22875 Mdot
.52 .30625 Mdot
.54625 .35875 Mdot
.4425 .395 Mdot
.44125 .3975 Mdot
.6775 .41125 Mdot
.37875 .305 Mdot
.6125 .205 Mdot
.42125 .13125 Mdot
.31 .29875 Mdot
.85125 .5025 Mdot
.39 .7675 Mdot
.12375 .0325 Mdot
.58125 .00375 Mdot
.46 .05 Mdot
.48375 .08125 Mdot
.47 .14625 Mdot
.5175 .26375 Mdot
.53 .28375 Mdot
.1425 .28 Mdot
.175 .24125 Mdot
.48 .12125 Mdot
.46 .10625 Mdot
.5175 .07625 Mdot
.49875 .03 Mdot
.48375 .01375 Mdot
.555 .1175 Mdot
.48375 .265 Mdot
.43 .3375 Mdot
.14125 .40875 Mdot
.17 .4175 Mdot
.3975 .34125 Mdot
.5775 .3125 Mdot
.49125 .30125 Mdot
.53375 .31625 Mdot
.44375 .3275 Mdot
.58 .35875 Mdot
.4725 .4 Mdot
.475 .41875 Mdot
.5275 .43375 Mdot
.4775 .5175 Mdot
.48125 .605 Mdot
.21875 .6625 Mdot
.2225 .79625 Mdot
.48875 .80125 Mdot
.49625 .7775 Mdot
.49 .8075 Mdot
.47375 .88125 Mdot
.5125 .97125 Mdot
.71625 .97625 Mdot
.28 .9875 Mdot
.49 .99625 Mdot
.97 .8975 Mdot
.355 .56625 Mdot
.3825 .31625 Mdot
.465 .50375 Mdot
.26 .50375 Mdot
.13875 .50625 Mdot
.4775 .515 Mdot
.49 .505 Mdot
.4875 .50375 Mdot
.5225 .50375 Mdot
.5325 .4925 Mdot
.53375 .48875 Mdot
.4675 .495 Mdot
.4825 .495 Mdot
.48 .49 Mdot
.4925 .53 Mdot
.48 .5425 Mdot
.12375 .54 Mdot
.18875 .565 Mdot
.57125 .5125 Mdot
.405 .5 Mdot
.48625 .49125 Mdot
.5025 .4775 Mdot
.48375 .4725 Mdot
.5075 .49375 Mdot
.52 .5025 Mdot
.49 .515 Mdot
.53125 .5025 Mdot
.44 .505 Mdot
.4525 .495 Mdot
.20375 .4925 Mdot
.49125 .48625 Mdot
.48875 .48125 Mdot
.46125 .45625 Mdot
.57625 .44875 Mdot
.46625 .45125 Mdot
.505 .46625 Mdot
.50125 .46 Mdot
.5225 .45875 Mdot
.46125 .43625 Mdot
.505 .43875 Mdot
.51625 .41625 Mdot
.0875 .42375 Mdot
.09375 .43875 Mdot
.47875 .41125 Mdot
.49875 .38875 Mdot
.47375 .365 Mdot
.51375 .34125 Mdot
.495 .38125 Mdot
.4925 .405 Mdot
.50375 .42 Mdot
.52125 .41875 Mdot
.5375 .40625 Mdot
.475 .3675 Mdot
.43 .32875 Mdot
.07 .305 Mdot
.05625 .31375 Mdot
.42375 .28875 Mdot
.5625 .28875 Mdot
.49625 .27625 Mdot
.56875 .28 Mdot
.43625 .285 Mdot
.51875 .3025 Mdot
.51 .30625 Mdot
.4825 .32875 Mdot
.5225 .32 Mdot
.475 .29875 Mdot
.49625 .2425 Mdot
.1375 .1975 Mdot
.15625 .12 Mdot
.48125 .07875 Mdot
.485 .07375 Mdot
.505 .03125 Mdot
.5425 .02375 Mdot
.50625 .065 Mdot
.20625 .125 Mdot
.36125 .02875 Mdot
.51875 .00375 Mdot
.43125 .01625 Mdot
.0825 .065 Mdot
.74125 .12875 Mdot
.21125 .06 Mdot
.27375 .09625 Mdot
.22125 .33125 Mdot
.44375 .3675 Mdot
.60125 .51625 Mdot
.27 .5175 Mdot
.9725 .51875 Mdot
.23875 .49625 Mdot
.455 .4575 Mdot
.41875 .44625 Mdot
.6575 .4525 Mdot
.4875 .46375 Mdot
.49 .47625 Mdot
.51625 .5025 Mdot
.4775 .51125 Mdot
.45625 .51375 Mdot
.44375 .5 Mdot
.6275 .47375 Mdot
.48375 .4425 Mdot
.15125 .43375 Mdot
.20125 .4475 Mdot
.54375 .49125 Mdot
.37625 .525 Mdot
.6375 .54375 Mdot
.4375 .54625 Mdot
.48 .535 Mdot
.50125 .50875 Mdot
.54375 .4975 Mdot
.47625 .505 Mdot
.46625 .5375 Mdot
.5275 .51375 Mdot
.44875 .5225 Mdot
.3125 .52625 Mdot
.065 .4875 Mdot
.45875 .505 Mdot
.52125 .5 Mdot
.55 .485 Mdot
.5325 .4725 Mdot
.44625 .45875 Mdot
.47 .46125 Mdot
.53125 .47625 Mdot
.5225 .49125 Mdot
.3975 .49125 Mdot
.5975 .46375 Mdot
.545 .455 Mdot
.1075 .45 Mdot
.17125 .44875 Mdot
.53 .485 Mdot
.45375 .51375 Mdot
.53875 .53 Mdot
.4725 .57 Mdot
.495 .56375 Mdot
.48625 .5575 Mdot
.52 .53 Mdot
.51875 .50625 Mdot
.5025 .4875 Mdot
.575 .50375 Mdot
.39625 .51125 Mdot
.105 .525 Mdot
.105 .49375 Mdot
.465 .47625 Mdot
.555 .4625 Mdot
.51 .45625 Mdot
.56625 .45125 Mdot
.46 .47375 Mdot
.4825 .48125 Mdot
.50375 .5 Mdot
.495 .49875 Mdot
.5475 .4975 Mdot
.46375 .5075 Mdot
.50375 .51 Mdot
.18 .5075 Mdot
.18125 .50375 Mdot
.49625 .48625 Mdot
.5025 .47875 Mdot
.49125 .51 Mdot
.5 .52875 Mdot
.47875 .5525 Mdot
.48125 .56625 Mdot
.5625 .5675 Mdot
.4875 .5375 Mdot
.51875 .51625 Mdot
.50625 .46 Mdot
.18375 .3725 Mdot
.4125 .36375 Mdot
.50125 .39625 Mdot
.54875 .4125 Mdot
.48125 .45625 Mdot
.5075 .49625 Mdot
.50375 .51625 Mdot
.48375 .51875 Mdot
.5175 .49 Mdot
.46875 .48 Mdot
.055 .46625 Mdot
.685 .44625 Mdot
.24875 .46125 Mdot
.49875 .4525 Mdot
.4875 .44125 Mdot
.51125 .44875 Mdot
.495 .445 Mdot
.49375 .44875 Mdot
.47625 .44375 Mdot
.49375 .4525 Mdot
.46625 .4875 Mdot
.57 .51125 Mdot
.3875 .51 Mdot
.2225 .52375 Mdot
.21375 .46375 Mdot
.44375 .44875 Mdot
.50875 .4325 Mdot
.49375 .42 Mdot
.4725 .4025 Mdot
.525 .385 Mdot
.47375 .37125 Mdot
.51125 .39125 Mdot
.55 .39375 Mdot
.4725 .40875 Mdot
.5 .4375 Mdot
.40875 .45625 Mdot
.27375 .45625 Mdot
.1025 .4975 Mdot
.49625 .51375 Mdot
.42 .0075 Mdot
.98625 .0625 Mdot
.15875 .0875 Mdot
.42375 .12375 Mdot
.44375 .18 Mdot
.7675 .2325 Mdot
.44125 .2825 Mdot
.3975 .3175 Mdot
.48125 .2875 Mdot
.555 .25375 Mdot
.5075 .21 Mdot
.2775 .16375 Mdot
.77875 .17375 Mdot
.54625 .16625 Mdot
.14875 .17625 Mdot
.94375 .19375 Mdot
.265 .2125 Mdot
.5375 .195 Mdot
.32 .20375 Mdot
.76375 .205 Mdot
.3525 .18375 Mdot
.4725 .16625 Mdot
.53 .16 Mdot
.53375 .1825 Mdot
.49875 .20875 Mdot
.48125 .205 Mdot
.73625 .25625 Mdot
.285 .27375 Mdot
.185 .2725 Mdot
.19 .4075 Mdot
.3975 .43375 Mdot
.61875 .475 Mdot
.61 .50625 Mdot
.4975 .49375 Mdot
.4475 .44 Mdot
.4875 .41625 Mdot
.4775 .37375 Mdot
.37875 .34375 Mdot
.76375 .325 Mdot
.435 .33 Mdot
.445 .28875 Mdot
.26125 .25625 Mdot
.975 .235 Mdot
.2375 .20375 Mdot
.3825 .17875 Mdot
.785 .19375 Mdot
.34625 .20375 Mdot
.5025 .20625 Mdot
.4725 .21375 Mdot
.41 .235 Mdot
.6275 .2475 Mdot
.57 .2975 Mdot
.43625 .32625 Mdot
.49 .39125 Mdot
.09125 .465 Mdot
.20375 .57875 Mdot
.61625 .61 Mdot
.4125 .5825 Mdot
.53375 .52125 Mdot
.48875 .45375 Mdot
.49875 .4175 Mdot
.49875 .4125 Mdot
.395 .44125 Mdot
.73 .5025 Mdot
.3675 .525 Mdot
.14875 .52375 Mdot
.9275 .5125 Mdot
.615 .49125 Mdot
.18875 .46125 Mdot
.6625 .4725 Mdot
.51625 .48375 Mdot
.43125 .49 Mdot
.51625 .50125 Mdot
.4925 .49875 Mdot
.48875 .4725 Mdot
.41875 .47125 Mdot
.51125 .4625 Mdot
.6725 .47625 Mdot
.3375 .485 Mdot
.30875 .49125 Mdot
.2375 .50875 Mdot
.415 .4975 Mdot
.66 .5175 Mdot
.4625 .51375 Mdot
.46 .53 Mdot
.51125 .53125 Mdot
.46125 .53 Mdot
.51125 .495 Mdot
.44 .5325 Mdot
.6475 .54375 Mdot
.50125 .5225 Mdot
.3875 .51 Mdot
.3325 .4 Mdot
.94 .2525 Mdot
.18875 .0875 Mdot
.30875 .9875 Mdot
.85875 .96 Mdot
.235 .8625 Mdot
.41 .75875 Mdot
.36375 .72625 Mdot
.9425 .6925 Mdot
.3825 .70875 Mdot
.33375 .76375 Mdot
.4925 .775 Mdot
.5775 .68375 Mdot
.49 .65375 Mdot
.1575 .67125 Mdot
.98875 .71125 Mdot
.51875 .70875 Mdot
.17 .72875 Mdot
.78875 .72375 Mdot
.3525 .64125 Mdot
.5175 .5725 Mdot
.2175 .555 Mdot
.96375 .55625 Mdot
.27375 .54125 Mdot
.43875 .58 Mdot
.52 .53375 Mdot
.54 .46375 Mdot
.5 .4625 Mdot
.5125 .49 Mdot
.8475 .53375 Mdot
.18 .52625 Mdot
.28875 .52875 Mdot
.86625 .4325 Mdot
.285 .32625 Mdot
.32125 .21875 Mdot
.705 .17625 Mdot
.68625 .15625 Mdot
.40625 .17125 Mdot
.46625 .18625 Mdot
.485 .13375 Mdot
.45375 .14 Mdot
.2625 .165 Mdot
.98 .18875 Mdot
.3875 .26375 Mdot
.39375 .31875 Mdot
.36125 .345 Mdot
.81375 .3275 Mdot
.31375 .35125 Mdot
.2775 .31625 Mdot
.995 .30375 Mdot
.24625 .27375 Mdot
.505 .26375 Mdot
.4925 .17875 Mdot
.35375 .0975 Mdot
.5675 .04 Mdot
.5175 .06125 Mdot
.4875 .065 Mdot
.4975 .01625 Mdot
.25125 .065 Mdot
.23875 .11125 Mdot
.8175 .185 Mdot
.56125 .2225 Mdot
.15375 .13125 Mdot
.7675 .0525 Mdot
.55 .0425 Mdot
.39875 .0275 Mdot
.495 .0225 Mdot
.5025 .04 Mdot
.5075 .11875 Mdot
.345 .14 Mdot
.6325 .16375 Mdot
.6725 .18375 Mdot
.32875 .1075 Mdot
.3425 .05375 Mdot
.835 .045 Mdot
.31875 .0075 Mdot
.91875 .03375 Mdot
.37625 .08125 Mdot
.42625 .11 Mdot
.51125 .15375 Mdot
.4475 .18375 Mdot
.5225 .17 Mdot
.3025 .1075 Mdot
.915 .05375 Mdot
.38625 .0325 Mdot
.39375 .23625 Mdot
.785 .47375 Mdot
.25875 .8325 Mdot
.0525 .3775 Mdot
.49 .4075 Mdot
.48 .45125 Mdot
.3675 .49 Mdot
.01625 .42625 Mdot
.2575 .33 Mdot
.3475 .31125 Mdot
.49 .355 Mdot
.48875 .44125 Mdot
.4 .515 Mdot
.075 .50375 Mdot
.22125 .425 Mdot
.31 .42625 Mdot
.52375 .405 Mdot
.43 .4875 Mdot
.4825 .5375 Mdot
.20875 .56375 Mdot
.21625 .61125 Mdot
.355 .6 Mdot
.56125 .63875 Mdot
.51 .73875 Mdot
.4575 .785 Mdot
.19125 .75875 Mdot
.7925 .68875 Mdot
.51125 .665 Mdot
.53875 .62125 Mdot
.69125 .71875 Mdot
.385 .7925 Mdot
.3625 .8975 Mdot
.34 .9225 Mdot
.28 .84375 Mdot
.27 .825 Mdot
.52875 .835 Mdot
.60625 .9 Mdot
.45375 .96625 Mdot
.4775 .9875 Mdot
.3525 .9575 Mdot
.13125 .66625 Mdot
.4275 .0925 Mdot
.52125 .15375 Mdot
.365 .195 Mdot
.2825 .26 Mdot
.25375 .19 Mdot
.4975 .165 Mdot
.525 .23125 Mdot
.36375 .25 Mdot
.18875 .23875 Mdot
.29 .15625 Mdot
.46625 .15625 Mdot
.4475 .175 Mdot
.52 .2025 Mdot
.17125 .245 Mdot
.21625 .35 Mdot
.33875 .37625 Mdot
.525 .42125 Mdot
.52375 .41625 Mdot
.46625 .35625 Mdot
.09 .3175 Mdot
.89625 .28125 Mdot
.485 .22 Mdot
.62125 .175 Mdot
.54875 .145 Mdot
.45875 .20125 Mdot
.3875 .19875 Mdot
.2925 .19875 Mdot
.2475 .2675 Mdot
.22125 .19375 Mdot
.58875 .1975 Mdot
.605 .22125 Mdot
.43375 .2175 Mdot
.035 .205 Mdot
.4825 .14625 Mdot
.25 .06875 Mdot
.4775 0 Mdot
.54 .05375 Mdot
.5025 .05875 Mdot
.0075 .1175 Mdot
.09125 .36 Mdot
.3775 .36375 Mdot
.50375 .4125 Mdot
.54625 .4325 Mdot
.5625 .29375 Mdot
.45375 .18875 Mdot
.25875 .01125 Mdot
.4925 .03875 Mdot
.52125 .125 Mdot
.08625 .15 Mdot
.95625 .2075 Mdot
.6775 .2475 Mdot
.25625 .115 Mdot
.4925 .0525 Mdot
.5225 .15375 Mdot
.5075 .32375 Mdot
.2675 .38625 Mdot
.9175 .44 Mdot
.5475 .4125 Mdot
.31375 .3025 Mdot
.4325 .1625 Mdot
.495 .1975 Mdot
.49625 .23625 Mdot
.1475 .4025 Mdot
.42875 .31875 Mdot
.45125 .25625 Mdot
.47125 .32875 Mdot
.48875 .42875 Mdot
.0075 .44 Mdot
.17125 .36625 Mdot
.41 .245 Mdot
.4725 .14875 Mdot
.525 .1975 Mdot
.49875 .19875 Mdot
.0175 .4825 Mdot
.39625 .46875 Mdot
.6125 .49875 Mdot
.3825 .5075 Mdot
.2775 .53 Mdot
.3175 .5 Mdot
.5175 .45625 Mdot
.52375 .45375 Mdot
.35875 .435 Mdot
.05375 .435 Mdot
.22 .48375 Mdot
.34 .47875 Mdot
.43125 .4725 Mdot
.50625 .505 Mdot
.53875 .5025 Mdot
.2125 .48 Mdot
.27 .39375 Mdot
.37 .33875 Mdot
.505 .29 Mdot
.535 .29875 Mdot
.48125 .37625 Mdot
.12625 .41875 Mdot
.8175 .41375 Mdot
.5025 .3875 Mdot
.59875 .3575 Mdot
.52125 .2675 Mdot
.53625 .2475 Mdot
.45 .27875 Mdot
.23875 .32125 Mdot
.27125 .34125 Mdot
.26625 .35625 Mdot
.5975 .3425 Mdot
.595 .39875 Mdot
.43375 .43375 Mdot
.1125 .435 Mdot
.45875 .4275 Mdot
.305 .38 Mdot
.45875 .3925 Mdot
.5575 .41 Mdot
.51875 .40875 Mdot
.02875 .40875 Mdot
.14875 .415 Mdot
.37625 .445 Mdot
.5075 .49625 Mdot
.5275 .49375 Mdot
.57875 .5175 Mdot
.4575 .50625 Mdot
.025 .42375 Mdot
.47 .43875 Mdot
.5075 .43625 Mdot
.5375 .43 Mdot
.1375 .435 Mdot
.89875 .4575 Mdot
.69875 .4625 Mdot
.27 .44875 Mdot
.4975 .4325 Mdot
.52125 .4125 Mdot
.36625 .39875 Mdot
.10625 .40375 Mdot
.2275 .48125 Mdot
.355 .515 Mdot
.50875 .5 Mdot
.5075 .44625 Mdot
.46 .42375 Mdot
.0775 .40375 Mdot
.09375 .41875 Mdot
.52375 .42 Mdot
.46375 .455 Mdot
.31625 .4825 Mdot
.44625 .49 Mdot
.1725 .58125 Mdot
.51625 .5 Mdot
.5225 .465 Mdot
.45 .43625 Mdot
.22375 .40125 Mdot
.185 .43625 Mdot
.42375 .43875 Mdot
.515 .48375 Mdot
.48625 .48375 Mdot
.4925 .4775 Mdot
.2225 .46625 Mdot
.48375 .43375 Mdot
.48 .39625 Mdot
.52125 .3825 Mdot
.05 .39125 Mdot
.9825 .35625 Mdot
.73875 .35125 Mdot
.22375 .40125 Mdot
.46 .405 Mdot
.53125 .39125 Mdot
.51 .3625 Mdot
.26 .34125 Mdot
.9775 .29875 Mdot
.52 .30125 Mdot
.30875 .2975 Mdot
.45625 .32625 Mdot
.4575 .3475 Mdot
.47875 .33875 Mdot
.11 .28 Mdot
.40125 .26625 Mdot
.44625 .2775 Mdot
.51 .32125 Mdot
.46125 .26875 Mdot
.085 .3075 Mdot
.43875 .29 Mdot
.50875 .36375 Mdot
.4425 .41 Mdot
.49625 .4225 Mdot
.0375 .445 Mdot
.1625 .14875 Mdot
.30375 .16375 Mdot
.83125 .24 Mdot
.32625 .23375 Mdot
.13125 .26 Mdot
.31125 .27875 Mdot
.4025 .24375 Mdot
.5075 .315 Mdot
.52125 .3775 Mdot
.385 .375 Mdot
.1675 .35 Mdot
.2775 .21 Mdot
.425 .125 Mdot
.3575 .16125 Mdot
.61125 .245 Mdot
.59125 .25125 Mdot
.2 .26625 Mdot
.97125 .29 Mdot
.33875 .26375 Mdot
.43 .20125 Mdot
.47 .2275 Mdot
.52625 .3 Mdot
.505 .36 Mdot
.1675 .4775 Mdot
.75 .64375 Mdot
.5175 .8275 Mdot
.575 .90375 Mdot
.425 .9775 Mdot
.665 .93875 Mdot
.49875 .7975 Mdot
.27375 .61125 Mdot
.8475 .52125 Mdot
.335 .42125 Mdot
.34 .3425 Mdot
.57 .325 Mdot
.585 .355 Mdot
.45625 .34 Mdot
.21 .31125 Mdot
.96375 .28875 Mdot
.445 .275 Mdot
.36625 .22625 Mdot
.40375 .19125 Mdot
.60625 .19625 Mdot
.6175 .2725 Mdot
.0725 .30875 Mdot
.26125 .285 Mdot
.415 .23625 Mdot
.46 .20375 Mdot
.52625 .23625 Mdot
.57375 .29625 Mdot
.47125 .3275 Mdot
.87625 .36875 Mdot
.17 .335 Mdot
.46125 .28375 Mdot
.41875 .30625 Mdot
.72125 .29625 Mdot
.1475 .28 Mdot
.815 .275 Mdot
.5875 .2875 Mdot
.34 .285 Mdot
.50375 .29375 Mdot
.5375 .36875 Mdot
.39625 .41 Mdot
.22625 .415 Mdot
.26375 .41875 Mdot
.43 .3875 Mdot
.495 .395 Mdot
.355 .43 Mdot
.625 .40875 Mdot
.30375 .39625 Mdot
.99375 .40625 Mdot
.24875 .40125 Mdot
.51 .385 Mdot
.465 .41625 Mdot
.385 .46125 Mdot
.38625 .48125 Mdot
.935 .4825 Mdot
.23625 .49625 Mdot
.5225 .53125 Mdot
.4625 .51375 Mdot
.6725 .51125 Mdot
.15375 .5275 Mdot
.97375 .53125 Mdot
.25125 .51875 Mdot
.50125 .5625 Mdot
.47125 .54875 Mdot
.51625 .5725 Mdot
.4925 .565 Mdot
.31 .55125 Mdot
.07 .5175 Mdot
.4675 .4925 Mdot
.465 .49 Mdot
.55875 .4825 Mdot
.265 .49625 Mdot
.74125 .5375 Mdot
.6925 .55625 Mdot
.335 .575 Mdot
.4425 .60625 Mdot
.515 .6225 Mdot
.46625 .59125 Mdot
.40375 .57625 Mdot
.92 .58125 Mdot
.3875 .56125 Mdot
.38875 .53 Mdot
.445 .5225 Mdot
.4 .52 Mdot
.6475 .49125 Mdot
.135 .51125 Mdot
.41375 .52375 Mdot
.45125 .5525 Mdot
.55 .5525 Mdot
.50125 .575 Mdot
.04625 .5725 Mdot
.1125 .5475 Mdot
.4875 .55625 Mdot
.49125 .46875 Mdot
.48375 .40125 Mdot
.6125 .34125 Mdot
.03 .25875 Mdot
.9425 .8225 Mdot
.30375 .79625 Mdot
.17375 .71875 Mdot
.25625 .75875 Mdot
.26125 .785 Mdot
.88125 .79 Mdot
.375 .79375 Mdot
.48 .7625 Mdot
.4925 .665 Mdot
.5125 .69875 Mdot
.405 .7075 Mdot
.31625 .70625 Mdot
.92625 .7325 Mdot
.3675 .78875 Mdot
.47 .7925 Mdot
.29375 .795 Mdot
.7275 .7825 Mdot
.62125 .8075 Mdot
.23375 .785 Mdot
.73375 .71875 Mdot
.385 .65 Mdot
.545 .59625 Mdot
.42625 .5 Mdot
.5475 .49375 Mdot
.49375 .515 Mdot
.255 .5675 Mdot
.695 .56 Mdot
.49625 .54375 Mdot
.54875 .5175 Mdot
.3275 .4925 Mdot
.7775 .4925 Mdot
.54125 .56 Mdot
.3 .66875 Mdot
.685 .745 Mdot
.3775 .8 Mdot
.39625 .82625 Mdot
.5675 .82375 Mdot
.5625 .78875 Mdot
.4775 .7375 Mdot
.33125 .69375 Mdot
.7525 .6825 Mdot
.46 .66125 Mdot
.42875 .61125 Mdot
.38125 .5775 Mdot
.63625 .61875 Mdot
.65875 .48375 Mdot
.145 .4075 Mdot
.85 .4575 Mdot
.34375 .48375 Mdot
.45125 .5225 Mdot
.46875 .605 Mdot
.50375 .69375 Mdot
.57625 .6325 Mdot
.43375 .60625 Mdot
.77875 .5375 Mdot
.28 .55125 Mdot
.46125 .5025 Mdot
.29875 .5525 Mdot
.9475 .56125 Mdot
.16125 .545 Mdot
.6775 .52625 Mdot
.53375 .48125 Mdot
.4075 .38 Mdot
.485 .345 Mdot
.555 .37625 Mdot
.42 .3525 Mdot
.37625 .38 Mdot
.9025 .40125 Mdot
.31375 .37 Mdot
.47875 .23 Mdot
.4625 .16875 Mdot
.23375 .1725 Mdot
.8325 .15625 Mdot
.405 .15125 Mdot
.73125 .1325 Mdot
.35125 .10625 Mdot
.5075 .025 Mdot
.4425 .06125 Mdot
.42625 .0175 Mdot
.44875 .015 Mdot
.7775 .03 Mdot
.31125 .02375 Mdot
.40875 .0775 Mdot
.89375 .145 Mdot
.10375 .18125 Mdot
.80125 .22875 Mdot
.32625 .2475 Mdot
.5175 .20375 Mdot
.465 .22375 Mdot
.52125 .285 Mdot
.49125 .3 Mdot
.35 .30125 Mdot
1 .27875 Mdot
.1775 .255 Mdot
.4625 .19 Mdot
.4225 .24625 Mdot
.5625 .32375 Mdot
.47 .3375 Mdot
.565 .3475 Mdot
.6525 .38125 Mdot
.3825 .34 Mdot
.46625 .315 Mdot
.50625 .35625 Mdot
.435 .34375 Mdot
.49125 .2925 Mdot
.7925 .22875 Mdot
.3875 .1675 Mdot
.42125 .09125 Mdot
.4775 .07625 Mdot
.31 .205 Mdot
.80625 .245 Mdot
.04125 .24375 Mdot
.215 .24 Mdot
.4675 .10625 Mdot
.47375 .07125 Mdot
.5325 .15375 Mdot
.4925 .16 Mdot
.185 .1975 Mdot
.24125 .26625 Mdot
.495 .1925 Mdot
.405 .325 Mdot
.55 .51125 Mdot
.71875 .63375 Mdot
.065 .7475 Mdot
.7125 .7475 Mdot
.40375 .8175 Mdot
.065 .9225 Mdot
.18875 .78125 Mdot
.36625 .79125 Mdot
.60375 .77375 Mdot
.46125 .785 Mdot
.52 .89 Mdot
.49375 .98375 Mdot
.51625 .90125 Mdot
.425 .9025 Mdot
.42375 .92 Mdot
.6475 .945 Mdot
.4725 .9275 Mdot
.24125 .98625 Mdot
.83875 .89875 Mdot
.64625 .85125 Mdot
.24375 .875 Mdot
.525 .94 Mdot
.61625 .935 Mdot
.5225 .84 Mdot
.4875 .84 Mdot
.27375 .85125 Mdot
.78 .85 Mdot
.65625 .83375 Mdot
.2575 .85875 Mdot
.5625 .8675 Mdot
.44625 .8725 Mdot
.46625 .92625 Mdot
.5275 .95375 Mdot
.535 .91125 Mdot
.5075 .92875 Mdot
.435 .99125 Mdot
.28875 .98625 Mdot
.45125 .95875 Mdot
.3775 .95875 Mdot
.58 .96625 Mdot
.655 .96625 Mdot
.4625 .97 Mdot
.4925 .935 Mdot
.2175 .9025 Mdot
.98625 .905 Mdot
.1225 .89625 Mdot
.84125 .9075 Mdot
.3125 .865 Mdot
.5175 .81875 Mdot
.52 .7925 Mdot
.49875 .7925 Mdot
.49125 .78 Mdot
.31375 .76 Mdot
.835 .74875 Mdot
.35375 .66375 Mdot
.49875 .58 Mdot
.33625 .5925 Mdot
.62375 .5475 Mdot
.77 .5825 Mdot
.12625 .67125 Mdot
.51375 .2625 Mdot
.49 .25 Mdot
.115 .2 Mdot
.42375 .13375 Mdot
.49125 .1 Mdot
.4375 .08375 Mdot
.6 .0625 Mdot
.48125 .03125 Mdot
.51 .0225 Mdot
.4475 .0275 Mdot
.49875 .05875 Mdot
.47875 .0625 Mdot
.53125 .10625 Mdot
.5125 .13 Mdot
.2 .125 Mdot
.93625 .12125 Mdot
.635 .1325 Mdot
.2475 .07875 Mdot
.45 .0325 Mdot
.55 0 Mdot
.455 .03375 Mdot
.215 .055 Mdot
.83375 .07125 Mdot
.70125 .1025 Mdot
.2475 .08125 Mdot
.4975 .06 Mdot
.48 .06 Mdot
.5 .05625 Mdot
.47625 .0475 Mdot
.53375 .04125 Mdot
.52875 .04375 Mdot
.47625 .03125 Mdot
.5125 .01125 Mdot
.465 .06875 Mdot
.5225 .12625 Mdot
.22625 .085 Mdot
.75125 .04625 Mdot
.84875 .01125 Mdot
.52625 .02875 Mdot
.4575 .01625 Mdot
.0725 .00125 Mdot
.51375 .01125 Mdot
.40875 .15125 Mdot
.02375 .1175 Mdot
.57 .1225 Mdot
.23 .02125 Mdot
.465 .06875 Mdot
.4625 .23125 Mdot
.48375 .27375 Mdot
.31625 .25375 Mdot
.51 .30375 Mdot
.4225 .36375 Mdot
.58375 .445 Mdot
.4375 .425 Mdot
.55875 .2875 Mdot
.40375 .27125 Mdot
.5125 .265 Mdot
.69125 .3075 Mdot
.3875 .43625 Mdot
.4475 .60125 Mdot
.33625 .57625 Mdot
.59125 .50875 Mdot
.84625 .46875 Mdot
.25375 .3675 Mdot
.52875 .2525 Mdot
.51375 .2625 Mdot
.46875 .36625 Mdot
.49375 .33625 Mdot
.43625 .3325 Mdot
.59 .39 Mdot
.52375 .4425 Mdot
.4375 .4375 Mdot
.495 .56875 Mdot
.52875 .645 Mdot
.10375 .5575 Mdot
.2175 .54375 Mdot
.4925 .545 Mdot
.395 .675 Mdot
.57125 .9275 Mdot
.45625 .97 Mdot
.48875 .98875 Mdot
.44375 .9475 Mdot
.56625 .92 Mdot
.47625 .94875 Mdot
.26875 .9275 Mdot
.68 .73 Mdot
.89375 .5375 Mdot
.11625 .3725 Mdot
.5 .45375 Mdot
.5125 .46875 Mdot
.11625 .52875 Mdot
.4325 .53375 Mdot
.49 .54 Mdot
.45125 .54125 Mdot
.57875 .5525 Mdot
.46375 .55875 Mdot
.57125 .54625 Mdot
.465 .53375 Mdot
.4425 .5175 Mdot
.48875 .5075 Mdot
.525 .49875 Mdot
.5025 .4975 Mdot
.245 .51125 Mdot
.91 .5275 Mdot
.60125 .535 Mdot
.29375 .57125 Mdot
.42875 .58 Mdot
.415 .58 Mdot
.69375 .58375 Mdot
.3825 .57875 Mdot
.55625 .55625 Mdot
.50875 .56125 Mdot
.435 .56375 Mdot
.5575 .55875 Mdot
.55 .55625 Mdot
.45625 .51625 Mdot
.2225 .4975 Mdot
.8175 .48625 Mdot
.685 .4875 Mdot
.25375 .46375 Mdot
.5175 .47625 Mdot
.48125 .47625 Mdot
.47375 .47625 Mdot
.4625 .48125 Mdot
.54875 .50125 Mdot
.56875 .505 Mdot
.44125 .51125 Mdot
.5175 .54 Mdot
.46 .48125 Mdot
.51875 .395 Mdot
.255 .39375 Mdot
.73375 .40125 Mdot
.87 .39 Mdot
.16875 .45 Mdot
.4875 .53625 Mdot
.45375 .53 Mdot
.5625 .515 Mdot
.4675 .49375 Mdot
.505 .49 Mdot
.53 .47625 Mdot
.475 .48375 Mdot
.53375 .4875 Mdot
.485 .5275 Mdot
.485 .53125 Mdot
.06125 .53375 Mdot
.15375 .5375 Mdot
.4525 .5025 Mdot
.50625 .50625 Mdot
.51 .52875 Mdot
.445 .53375 Mdot
.56 .52 Mdot
.48625 .505 Mdot
.5825 .48 Mdot
.4125 .47375 Mdot
.51125 .47375 Mdot
.49875 .4925 Mdot
.3975 .46375 Mdot
.02 .4775 Mdot
.57875 .435 Mdot
.185 .41375 Mdot
.51625 .45875 Mdot
.495 .45375 Mdot
.4525 .46125 Mdot
.495 .47 Mdot
.51125 .43875 Mdot
.50375 .43375 Mdot
.48 .43875 Mdot
.4475 .41625 Mdot
.275 .415 Mdot
.4725 .34375 Mdot
.43625 .3225 Mdot
.6 .295 Mdot
.4225 .2925 Mdot
.55375 .36625 Mdot
.4025 .3975 Mdot
.5375 .4225 Mdot
.63125 .41 Mdot
.445 .38125 Mdot
.435 .345 Mdot
.3025 .31625 Mdot
.6 .31 Mdot
.945 .32875 Mdot
.1925 .35875 Mdot
.48125 .35 Mdot
.53125 .34 Mdot
.495 .28875 Mdot
.47375 .2725 Mdot
.4525 .26625 Mdot
.5875 .26125 Mdot
.48875 .2825 Mdot
.4425 .32 Mdot
.49375 .31875 Mdot
.55625 .29875 Mdot
.0575 .31125 Mdot
.225 .3 Mdot
.34 .2725 Mdot
.4475 .20125 Mdot
.59875 .10625 Mdot
.63875 .0575 Mdot
.4425 .0525 Mdot
.49 .0525 Mdot
.4875 .08875 Mdot
.4425 .105 Mdot
.54625 .1325 Mdot
.49125 .15625 Mdot
.215 .215 Mdot
.73875 .29125 Mdot
.8825 .385 Mdot
.12375 .41625 Mdot
.53375 .65375 Mdot
.57375 .63375 Mdot
.06875 .60375 Mdot
.185 .55375 Mdot
.44 .49375 Mdot
.49125 .49 Mdot
.47 .48 Mdot
.545 .4775 Mdot
.37875 .47625 Mdot
.84625 .5025 Mdot
.31375 .5125 Mdot
.435 .5175 Mdot
.495 .5125 Mdot
.53125 .49125 Mdot
.47875 .47 Mdot
.32 .4475 Mdot
.8175 .42875 Mdot
.57125 .415 Mdot
.36375 .425 Mdot
.4 .44625 Mdot
.445 .4675 Mdot
.66875 .5 Mdot
.3175 .51625 Mdot
.71125 .51875 Mdot
.445 .495 Mdot
.4325 .4525 Mdot
.56 .43125 Mdot
.535 .39875 Mdot
.4575 .41375 Mdot
.3 .41375 Mdot
.71 .43625 Mdot
.67 .445 Mdot
.29 .485 Mdot
.52625 .48625 Mdot
.48125 .51125 Mdot
.43 .52125 Mdot
.45625 .52125 Mdot
.695 .51375 Mdot
.4625 .51125 Mdot
.4625 .50125 Mdot
.5 .4675 Mdot
.46125 .45875 Mdot
.52375 .47875 Mdot
.31375 .475 Mdot
.6725 .475 Mdot
.7875 .4975 Mdot
.25875 .50125 Mdot
.49125 .47625 Mdot
.45625 .48 Mdot
.45875 .4725 Mdot
.51 .47875 Mdot
.6625 .475 Mdot
.44 .4875 Mdot
.46125 .48375 Mdot
.54125 .49 Mdot
.47 .4975 Mdot
.49375 .5075 Mdot
.14 .50375 Mdot
.255 .50375 Mdot
.47625 .4975 Mdot
.49875 .49625 Mdot
.49625 .50125 Mdot
.405 .515 Mdot
.575 .52375 Mdot
.575 .53 Mdot
.515 .525 Mdot
.4225 .51375 Mdot
.525 .54375 Mdot
.46875 .56875 Mdot
.405 .5475 Mdot
.16625 .54875 Mdot
.46625 .52625 Mdot
.32875 .49625 Mdot
.49375 .52125 Mdot
.49125 .54125 Mdot
.36875 .5475 Mdot
.6025 .50875 Mdot
.5525 .50375 Mdot
.455 .49125 Mdot
.485 .495 Mdot
.45 .4875 Mdot
.3375 .5025 Mdot
.0875 .465 Mdot
.49875 .42625 Mdot
.46125 .4175 Mdot
.54125 .425 Mdot
.45625 .45875 Mdot
.50125 .5025 Mdot
.35375 .525 Mdot
.6725 .535 Mdot
.6 .5325 Mdot
.44 .52375 Mdot
.4375 .48625 Mdot
.3375 .48125 Mdot
.57125 .4825 Mdot
.845 .48125 Mdot
.25125 .4725 Mdot
.5 .48625 Mdot
.525 .49375 Mdot
.4825 .50375 Mdot
.465 .50125 Mdot
.57625 .505 Mdot
.47625 .49375 Mdot
.495 .47875 Mdot
.4675 .4725 Mdot
.47875 .47875 Mdot
.5675 .48 Mdot
.13625 .48625 Mdot
.28625 .49 Mdot
.39875 .4675 Mdot
.42875 .44375 Mdot
.62125 .42875 Mdot
.615 .415 Mdot
.39875 .40125 Mdot
.5325 .415 Mdot
.44125 .42375 Mdot
.51375 .43125 Mdot
.51625 .4625 Mdot
.49 .48 Mdot
.23125 .5175 Mdot
.7125 .5675 Mdot
.8575 .595 Mdot
.11 .61375 Mdot
.515 .00625 Mdot
.53625 .02375 Mdot
.47875 .065 Mdot
.3775 .07875 Mdot
.7425 .11875 Mdot
.52875 .14375 Mdot
.41625 .08 Mdot
.46 .03375 Mdot
.3875 .0525 Mdot
.6125 .04375 Mdot
.64125 .0725 Mdot
.34 .04375 Mdot
.465 .02625 Mdot
.5275 .105 Mdot
.3275 .13875 Mdot
.62625 .16125 Mdot
.78875 .1625 Mdot
.29375 .04375 Mdot
.25875 .015 Mdot
.91 .06375 Mdot
.36 .1125 Mdot
.495 .13 Mdot
.4975 .13 Mdot
.49 .11 Mdot
.33875 .10125 Mdot
.64875 .0975 Mdot
.61625 .06375 Mdot
.43375 .05125 Mdot
.4525 .03625 Mdot
.45625 .00625 Mdot
.42 .06125 Mdot
.29625 .07375 Mdot
.9525 .09375 Mdot
.47125 .12375 Mdot
.38125 .1075 Mdot
.4975 .05 Mdot
.4975 .02 Mdot
.70125 .055 Mdot
.60875 .10875 Mdot
.38125 .17125 Mdot
.47375 .21125 Mdot
.49375 .22875 Mdot
.3925 .17875 Mdot
.93875 .135 Mdot
.22375 .1 Mdot
.495 .09625 Mdot
.4875 .115 Mdot
.5325 .12 Mdot
.4575 .1175 Mdot
.4775 .10625 Mdot
.2375 .09875 Mdot
.91375 .0925 Mdot
.5175 .1 Mdot
.41625 .1125 Mdot
.4275 .13875 Mdot
.37625 .15 Mdot
.565 .16375 Mdot
.7425 .16875 Mdot
.31 .16 Mdot
.55125 .14875 Mdot
.5025 .14375 Mdot
.4775 .15 Mdot
.3525 .155 Mdot
.745 .16 Mdot
.4575 .1725 Mdot
.44375 .185 Mdot
.4825 .18 Mdot
.48375 .23375 Mdot
.55 .25375 Mdot
.21125 .24125 Mdot
.9225 .21625 Mdot
.43125 .24125 Mdot
.395 .25 Mdot
.41625 .2375 Mdot
.6125 .24625 Mdot
.53 .2725 Mdot
.4725 .2625 Mdot
.615 .20375 Mdot
.37375 .22 Mdot
.5125 .23 Mdot
.50875 .2275 Mdot
.47125 .22875 Mdot
.33 .18375 Mdot
.64875 .09125 Mdot
.74875 .0025 Mdot
.4625 .99 Mdot
.4725 .90125 Mdot
.12 .84375 Mdot
.41125 .7375 Mdot
.385 .79125 Mdot
.44125 .84375 Mdot
.4125 .84625 Mdot
.5575 .8275 Mdot
.675 .78625 Mdot
.36 .7425 Mdot
.5475 .65625 Mdot
.50125 .58125 Mdot
.49 .5625 Mdot
.24375 .60375 Mdot
.905 .615 Mdot
.4225 .6425 Mdot
.41625 .69875 Mdot
.4825 .7275 Mdot
.49625 .74375 Mdot
.53375 .71125 Mdot
.3025 .71 Mdot
.7425 .7675 Mdot
.5175 .80375 Mdot
.41375 .81375 Mdot
.43125 .88875 Mdot
.59 .87875 Mdot
.41375 .83 Mdot
.58375 .78625 Mdot
.68875 .7375 Mdot
.30875 .65875 Mdot
.5175 .65 Mdot
.48125 .6475 Mdot
.4625 .6425 Mdot
.44375 .80125 Mdot
.5625 .97875 Mdot
.52 .0925 Mdot
.61 .05125 Mdot
.56 .08125 Mdot
.56 .2075 Mdot
.41 .1875 Mdot
.06875 .185 Mdot
.5175 .0075 Mdot
.38 .02625 Mdot
.6375 .08125 Mdot
.43375 .05 Mdot
.07875 .0025 Mdot
.48875 .12875 Mdot
.3375 .1075 Mdot
.4825 .11625 Mdot
.91375 .09375 Mdot
.3475 .02375 Mdot
.475 .03875 Mdot
.465 .15625 Mdot
.2675 .17875 Mdot
.5675 .20375 Mdot
.1775 .14875 Mdot
.45 .0075 Mdot
.4425 .05125 Mdot
.55125 .085 Mdot
.52875 .1125 Mdot
.5125 .17875 Mdot
.495 .20125 Mdot
.47125 .28 Mdot
.25 .31 Mdot
.70625 .3375 Mdot
.795 .33 Mdot
.28375 .2775 Mdot
.475 .15 Mdot
.53875 .085 Mdot
.44125 0 Mdot
.525 .0225 Mdot
.55875 .02875 Mdot
.47125 .03 Mdot
.50375 .09125 Mdot
.49625 .18 Mdot
.49625 .19375 Mdot
.12 .21375 Mdot
.9625 .28 Mdot
.63125 .3375 Mdot
.29 .30375 Mdot
.4375 .23 Mdot
.5575 .25 Mdot
.4975 .2625 Mdot
.54375 .27125 Mdot
.44625 .3 Mdot
.485 .39875 Mdot
.56125 .44125 Mdot
.4875 .52125 Mdot
.4725 .59 Mdot
.45875 .6375 Mdot
.00375 .6975 Mdot
.3175 .83125 Mdot
.35375 .8325 Mdot
.445 .80125 Mdot
.445 .7875 Mdot
.57375 .775 Mdot
.585 .8275 Mdot
.40875 .92875 Mdot
.5 .98 Mdot
.5125 .95625 Mdot
.405 .9575 Mdot
.565 .91125 Mdot
.57875 .855 Mdot
.4575 .87125 Mdot
.45625 .82375 Mdot
.56875 .82375 Mdot
.27125 .86875 Mdot
.69375 .945 Mdot
.52875 .90625 Mdot
.5175 .7125 Mdot
.57125 .5425 Mdot
.335 .33375 Mdot
.53875 .42875 Mdot
.57625 .4425 Mdot
.50875 .45 Mdot
.5025 .47625 Mdot
.4825 .48125 Mdot
.38125 .45875 Mdot
.575 .415 Mdot
.54875 .42625 Mdot
.44 .44125 Mdot
.08125 .4375 Mdot
.44 .57 Mdot
.49875 .56125 Mdot
.485 .59625 Mdot
.50125 .58625 Mdot
.54125 .59125 Mdot
.52625 .62625 Mdot
.495 .68625 Mdot
.5125 .65125 Mdot
.3825 .62375 Mdot
.64875 .62 Mdot
.43125 .59 Mdot
.105 .54875 Mdot
.16875 .58 Mdot
.46375 .58125 Mdot
.59 .59875 Mdot
.45125 .5825 Mdot
.42875 .58125 Mdot
.53 .59625 Mdot
.51 .5825 Mdot
.52875 .5625 Mdot
.46125 .5625 Mdot
.47625 .51 Mdot
.5325 .46375 Mdot
.31375 .44125 Mdot
.50875 .4275 Mdot
.895 .41375 Mdot
.33 .44875 Mdot
.44875 .47375 Mdot
.505 .4875 Mdot
.5075 .49625 Mdot
.5 .5225 Mdot
.46875 .525 Mdot
.435 .5325 Mdot
.62875 .53875 Mdot
.5 .52625 Mdot
.475 .4775 Mdot
.48 .455 Mdot
.22875 .42 Mdot
.595 .41125 Mdot
.08625 .42375 Mdot
.49625 .43875 Mdot
.49375 .47375 Mdot
.49375 .475 Mdot
.4975 .4775 Mdot
.47 .46875 Mdot
.48375 .47375 Mdot
.5525 .46 Mdot
.535 .43875 Mdot
.50125 .45125 Mdot
.44125 .41375 Mdot
.2525 .39375 Mdot
.71 .3925 Mdot
.81625 .41 Mdot
.285 .395 Mdot
.505 .45125 Mdot
.4975 .4725 Mdot
.45 .46375 Mdot
.48375 .45 Mdot
.5375 .42625 Mdot
.4825 .41625 Mdot
.48875 .4175 Mdot
.53 .42625 Mdot
.50125 .435 Mdot
.47125 .465 Mdot
.08375 .44 Mdot
.62625 .37 Mdot
.21125 .35125 Mdot
.4475 .31625 Mdot
.595 .31375 Mdot
.53125 .3225 Mdot
.4325 .335 Mdot
.4975 .3275 Mdot
.47 .32125 Mdot
.5875 .30625 Mdot
.46375 .2875 Mdot
.505 .34 Mdot
.42875 .38375 Mdot
.26375 .33875 Mdot
.33375 .245 Mdot
.44625 .18875 Mdot
.4425 .195 Mdot
.6375 .25875 Mdot
.49625 .25875 Mdot
.4475 .225 Mdot
.53875 .14125 Mdot
.515 .115 Mdot
.49375 .06125 Mdot
.0725 .035 Mdot
.3875 .0975 Mdot
.3475 .0675 Mdot
.5 .03875 Mdot
.5 .085 Mdot
.505 .16 Mdot
.4625 .1775 Mdot
.4725 .1825 Mdot
.6275 .19 Mdot
.49125 .17 Mdot
.4275 .1175 Mdot
.55875 .115 Mdot
.21875 .09875 Mdot
.72125 .06875 Mdot
.8475 .0475 Mdot
.63625 .0425 Mdot
.4575 .13375 Mdot
.51125 .2225 Mdot
.385 .3275 Mdot
.52625 .54125 Mdot
.495 .53 Mdot
.46375 .5375 Mdot
.6625 .53375 Mdot
.445 .51625 Mdot
.38875 .4825 Mdot
.56125 .47375 Mdot
.5275 .49125 Mdot
.4725 .4775 Mdot
.175 .4725 Mdot
.075 .57 Mdot
.4525 .5925 Mdot
.485 .62625 Mdot
.49375 .62125 Mdot
.46875 .6 Mdot
.475 .56625 Mdot
.6325 .51625 Mdot
.565 .49625 Mdot
.41375 .49625 Mdot
.3875 .5225 Mdot
.69125 .5325 Mdot
.395 .54375 Mdot
.18 .5075 Mdot
.2325 .51375 Mdot
.4775 .48625 Mdot
.5825 .4625 Mdot
.46125 .47 Mdot
.43625 .44 Mdot
.465 .41125 Mdot
.5475 .42375 Mdot
.60875 .45125 Mdot
.4125 .4675 Mdot
.4475 .5 Mdot
.55 .48875 Mdot
.3725 .455 Mdot
.49625 .4225 Mdot
.76375 .42875 Mdot
.43 .41125 Mdot
.42875 .4325 Mdot
.50375 .4675 Mdot
.53375 .495 Mdot
.47 .4625 Mdot
.42 .47 Mdot
.53875 .47 Mdot
.62625 .465 Mdot
.46375 .465 Mdot
.45875 .5225 Mdot
.4675 .53875 Mdot
.3375 .5325 Mdot
.56 .53 Mdot
.95125 .53625 Mdot
.17125 .51 Mdot
.49875 .4975 Mdot
.4975 .49875 Mdot
.52625 .4925 Mdot
.48 .47125 Mdot
.39 .44875 Mdot
.605 .425 Mdot
.52625 .4125 Mdot
.495 .41125 Mdot
.49875 .4475 Mdot
.47625 .5 Mdot
.31125 .50375 Mdot
.6525 .51 Mdot
.7425 .505 Mdot
.33 .4725 Mdot
.52125 .41625 Mdot
.475 .42 Mdot
.4725 .42375 Mdot
.46875 .425 Mdot
.48875 .4275 Mdot
.63375 .44875 Mdot
.40875 .465 Mdot
.5 .475 Mdot
.51875 .50125 Mdot
.485 .52375 Mdot
.1625 .52375 Mdot
.94625 .52375 Mdot
.58875 .51625 Mdot
.28125 .50875 Mdot
.45375 .4975 Mdot
.59 .49625 Mdot
.46375 .48875 Mdot
.57 .4975 Mdot
.48125 .4925 Mdot
.43 .4875 Mdot
.57375 .4925 Mdot
.4725 .48625 Mdot
.49125 .46125 Mdot
.46125 .445 Mdot
.0125 .4325 Mdot
.30375 .4575 Mdot
.35625 .49125 Mdot
.44875 .53 Mdot
.4275 .54125 Mdot
.57125 .49875 Mdot
.63125 .48125 Mdot
.4325 .47125 Mdot
.515 .455 Mdot
.48375 .455 Mdot
.51625 .49125 Mdot
.10125 .5025 Mdot
.435 .49 Mdot
.3525 .4925 Mdot
.51125 .48875 Mdot
.4925 .47 Mdot
.5025 .44375 Mdot
.405 .42625 Mdot
.5775 .43125 Mdot
.605 .43875 Mdot
.46 .4575 Mdot
.4275 .51375 Mdot
.57125 .545 Mdot
.2475 .55 Mdot
.71875 .55125 Mdot
.7825 .54 Mdot
.2425 .51875 Mdot
.4875 .515 Mdot
.4725 .50125 Mdot
.41375 .4975 Mdot
.64875 .5125 Mdot
.41375 .5025 Mdot
.6 .505 Mdot
.37125 .53875 Mdot
.52625 .06125 Mdot
.4725 .01625 Mdot
.53125 .0125 Mdot
.48875 .075 Mdot
.5075 .07125 Mdot
.31125 .08875 Mdot
.41625 .0375 Mdot
.695 .11125 Mdot
.665 .065 Mdot
.325 .05625 Mdot
.645 .04875 Mdot
.40375 .06125 Mdot
.30375 .1425 Mdot
.9125 .1875 Mdot
.32875 .25375 Mdot
.48625 .21375 Mdot
.5625 .21125 Mdot
.4775 .20625 Mdot
.44125 .2025 Mdot
.39875 .1775 Mdot
.5775 .135 Mdot
.71125 .09125 Mdot
.33 .07625 Mdot
.45125 .115 Mdot
.56 .215 Mdot
.37125 .31625 Mdot
.5425 .385 Mdot
.645 .37125 Mdot
.49375 .33 Mdot
.43875 .225 Mdot
.49625 .14375 Mdot
.52375 .08875 Mdot
.46375 .125 Mdot
.38 .12375 Mdot
.66125 .12875 Mdot
.615 .11375 Mdot
.40125 .115 Mdot
.45875 .0675 Mdot
.43875 .0775 Mdot
.45875 .12375 Mdot
.51875 .13125 Mdot
.8 .14125 Mdot
.275 .17125 Mdot
.49875 .165 Mdot
.49375 .14 Mdot
.53625 .16 Mdot
.48625 .20625 Mdot
.31625 .24625 Mdot
.7475 .27125 Mdot
.45 .3175 Mdot
.48625 .345 Mdot
.49625 .32125 Mdot
.48375 .32625 Mdot
.4 .31875 Mdot
.55875 .29 Mdot
.68875 .27625 Mdot
.39375 .27875 Mdot
.5175 .26625 Mdot
.46875 .27375 Mdot
.48375 .26 Mdot
.45625 .2225 Mdot
.3775 .2025 Mdot
.86875 .15375 Mdot
.28375 .105 Mdot
.50625 .085 Mdot
.53 .09125 Mdot
.47625 .07625 Mdot
.2625 .09375 Mdot
.82625 .1175 Mdot
.53125 .17625 Mdot
.34625 .2025 Mdot
.46 .23 Mdot
.61125 .2375 Mdot
.29375 .25625 Mdot
.83875 .23 Mdot
.42375 .20875 Mdot
.37625 .1875 Mdot
.5575 .175 Mdot
.49 .1425 Mdot
.49 .19125 Mdot
.4775 .20125 Mdot
.13125 .21 Mdot
.33875 .225 Mdot
.39375 .1525 Mdot
.47 .1325 Mdot
.4 .1325 Mdot
.45875 .15 Mdot
.9 .16875 Mdot
.325 .20875 Mdot
.4525 .24 Mdot
.495 .30125 Mdot
.52375 .3075 Mdot
.21625 .305 Mdot
.88375 .29875 Mdot
.46 .29375 Mdot
.4075 .23375 Mdot
.50375 .21875 Mdot
.48625 .2075 Mdot
.49625 .1925 Mdot
.34375 .2075 Mdot
.71875 .2325 Mdot
.56875 .2475 Mdot
.4125 .2525 Mdot
.44375 .27625 Mdot
.56375 .2675 Mdot
.2975 .26875 Mdot
.66125 .2875 Mdot
.72 .30375 Mdot
.3225 .3075 Mdot
.48125 .29875 Mdot
.47375 .31125 Mdot
.4225 .3075 Mdot
.6375 .29 Mdot
.3175 .25375 Mdot
.8075 .2175 Mdot
.2775 .14625 Mdot
.875 .9775 Mdot
.41 .90125 Mdot
.46375 .93375 Mdot
.49125 .99 Mdot
.4975 .98375 Mdot
.4675 .95125 Mdot
.48125 .8575 Mdot
.4425 .90125 Mdot
.3025 .91375 Mdot
.18125 .9975 Mdot
.68875 .94875 Mdot
.49 .84125 Mdot
.41625 .67875 Mdot
.475 .54375 Mdot
.5825 .5425 Mdot
.175 .56625 Mdot
.41125 .72 Mdot
.3125 .88625 Mdot
.53375 .9525 Mdot
.49875 1 Mdot
.275 .96375 Mdot
.9075 .92875 Mdot
.40125 .8825 Mdot
.44375 .86875 Mdot
.46625 .7875 Mdot
.37625 .75875 Mdot
.345 .73625 Mdot
.19625 .58875 Mdot
.46125 .6075 Mdot
.48 .61875 Mdot
.52875 .62 Mdot
.30875 .6225 Mdot
.74375 .625 Mdot
.48 .63875 Mdot
.44625 .635 Mdot
.50125 .64 Mdot
.47 .6125 Mdot
.51375 .58 Mdot
.27 .55 Mdot
.81 .49875 Mdot
.60875 .4375 Mdot
.34625 .4425 Mdot
.455 .48375 Mdot
.5525 .5225 Mdot
.3575 .49875 Mdot
.5775 .4575 Mdot
.6825 .415 Mdot
.39625 .36125 Mdot
.47 .35125 Mdot
.48375 .365 Mdot
.43875 .34125 Mdot
.5975 .52 Mdot
.2475 .70875 Mdot
.9975 .83875 Mdot
.54125 .23875 Mdot
.47375 .2425 Mdot
.04 .2325 Mdot
.38125 .1725 Mdot
.34125 .10875 Mdot
.4725 .0775 Mdot
.48375 .055 Mdot
.5525 .055 Mdot
.51 .06375 Mdot
.525 .0325 Mdot
.455 .01625 Mdot
.50125 .05625 Mdot
.475 .15 Mdot
.19875 .14625 Mdot
.8125 .1925 Mdot
.91125 .23 Mdot
.09375 .1125 Mdot
.5525 .005 Mdot
.52 .01875 Mdot
.4675 .08625 Mdot
.47125 .15625 Mdot
.31375 .1725 Mdot
.60875 .1775 Mdot
.84875 .23625 Mdot
.2375 .27875 Mdot
.44875 .2375 Mdot
.5275 .26125 Mdot
.4675 .2575 Mdot
.57 .22875 Mdot
.4925 .14875 Mdot
.4725 .1575 Mdot
.52125 .10875 Mdot
.49625 .10875 Mdot
.45875 .17375 Mdot
.49125 .22125 Mdot
.26875 .235 Mdot
.965 .2475 Mdot
.55875 .2475 Mdot
.26625 .19625 Mdot
.48125 .1825 Mdot
.40125 .18125 Mdot
.65125 .2525 Mdot
.4325 .30375 Mdot
.56625 .365 Mdot
.4175 .4075 Mdot
.52875 .40125 Mdot
.51875 .3425 Mdot
.50625 .39375 Mdot
.4825 .45 Mdot
.185 .4625 Mdot
.39875 .6275 Mdot
.40375 .6125 Mdot
.495 .5375 Mdot
.50625 .5275 Mdot
.5025 .49875 Mdot
.47375 .46375 Mdot
.565 .47625 Mdot
.47875 .55 Mdot
.51875 .605 Mdot
.46375 .69875 Mdot
.495 .7725 Mdot
.395 .76875 Mdot
.25625 .755 Mdot
.07875 .69125 Mdot
.50125 .62875 Mdot
.51625 .565 Mdot
.5 .58375 Mdot
.46375 .68625 Mdot
.54875 .7775 Mdot
.4875 .8675 Mdot
.115 .9725 Mdot
.43875 .76625 Mdot
.24 .655 Mdot
.5075 .5975 Mdot
.51375 .5825 Mdot
.50625 .505 Mdot
.46625 .51875 Mdot
.43 .5825 Mdot
.64125 .62375 Mdot
.47125 .67375 Mdot
.48375 .77 Mdot
.48125 .80875 Mdot
.38375 .84875 Mdot
.17375 .8625 Mdot
.0675 .95875 Mdot
.4925 .95 Mdot
.50875 .945 Mdot
.41375 .96125 Mdot
.59125 .97875 Mdot
.5075 .97625 Mdot
.165 .84375 Mdot
.0625 .4175 Mdot
.51875 .4125 Mdot
.49125 .41375 Mdot
.01 .41125 Mdot
.36625 .38125 Mdot
.315 .35 Mdot
.47625 .31625 Mdot
.5025 .29875 Mdot
.52875 .30625 Mdot
.495 .325 Mdot
.515 .3775 Mdot
.46 .425 Mdot
.465 .45375 Mdot
.51625 .48375 Mdot
.535 .51 Mdot
.45125 .50375 Mdot
.1875 .52125 Mdot
.82375 .5475 Mdot
.985 .54375 Mdot
.02375 .54125 Mdot
.4525 .565 Mdot
.6325 .5625 Mdot
.38 .5675 Mdot
.51125 .55875 Mdot
.5225 .55625 Mdot
.53125 .54625 Mdot
.52125 .52625 Mdot
.52625 .49875 Mdot
.475 .49 Mdot
.50625 .4825 Mdot
.2375 .445 Mdot
.67875 .43375 Mdot
.8625 .42375 Mdot
.1775 .38625 Mdot
.47875 .35625 Mdot
.4825 .35125 Mdot
.52375 .34625 Mdot
.56 .3475 Mdot
.49875 .3825 Mdot
.42 .3925 Mdot
.56875 .4175 Mdot
.485 .43125 Mdot
.43625 .43375 Mdot
.47875 .4325 Mdot
.27875 .41625 Mdot
.54375 .375 Mdot
.235 .3675 Mdot
.47 .3525 Mdot
.4125 .35375 Mdot
.66375 .345 Mdot
.435 .35 Mdot
.48875 .33625 Mdot
.47125 .345 Mdot
.5175 .38 Mdot
.54125 .4075 Mdot
.4925 .40125 Mdot
.485 .35375 Mdot
.15625 .32 Mdot
.4125 .22125 Mdot
.3975 .195 Mdot
.47 .2325 Mdot
.50625 .225 Mdot
.52125 .225 Mdot
.45375 .23375 Mdot
.6025 .2375 Mdot
.44 .21625 Mdot
.505 .21 Mdot
.4725 .16875 Mdot
.4975 .19875 Mdot
.3325 .18125 Mdot
.32375 .19 Mdot
.53875 .205 Mdot
.48375 .21125 Mdot
.53 .18625 Mdot
.50875 .1325 Mdot
.43875 .10625 Mdot
.5125 .095 Mdot
.47875 .055 Mdot
.4625 .13125 Mdot
.56625 .16 Mdot
.065 .19625 Mdot
.44375 .30125 Mdot
.21375 .2675 Mdot
.47875 .29125 Mdot
.5375 .2875 Mdot
.4775 .29125 Mdot
.46625 .27375 Mdot
.50375 .25625 Mdot
.525 .24875 Mdot
.49375 .22625 Mdot
.5275 .19 Mdot
.4675 .23875 Mdot
.40125 .21625 Mdot
.03375 .19125 Mdot
.01375 .17625 Mdot
.40375 .0825 Mdot
.51875 .0625 Mdot
.50625 .06875 Mdot
.48375 .06375 Mdot
.5025 .06875 Mdot
.51125 .07125 Mdot
.5075 .07375 Mdot
.505 .06875 Mdot
.45875 .10375 Mdot
.525 .1125 Mdot
.14375 .075 Mdot
.85875 .045 Mdot
.4925 .06125 Mdot
.48 .14375 Mdot
.1 .225 Mdot
.0075 .395 Mdot
.49875 .545 Mdot
.5075 .52375 Mdot
.09875 .50875 Mdot
.4 .49875 Mdot
.34375 .44 Mdot
.5075 .45625 Mdot
.505 .45625 Mdot
.5 .4525 Mdot
.405 .4325 Mdot
.61375 .4425 Mdot
.50125 .44875 Mdot
.41 .4575 Mdot
.51125 .45 Mdot
.5475 .45125 Mdot
.48625 .45375 Mdot
.2525 .4375 Mdot
.71625 .42375 Mdot
.895 .42625 Mdot
.12625 .4525 Mdot
.4725 .44875 Mdot
.57 .465 Mdot
.41 .49875 Mdot
.47 .5325 Mdot
.54375 .50875 Mdot
.61 .47375 Mdot
.47125 .44625 Mdot
.52625 .42875 Mdot
.48125 .40125 Mdot
.48875 .42375 Mdot
.295 .4625 Mdot
.65375 .48875 Mdot
.795 .48375 Mdot
.22 .505 Mdot
.50625 .5425 Mdot
.46625 .55375 Mdot
.495 .56125 Mdot
.55125 .5925 Mdot
.55 .57875 Mdot
.4 .535 Mdot
.57375 .5325 Mdot
.4775 .5425 Mdot
.4375 .545 Mdot
.49375 .5625 Mdot
.3425 .56375 Mdot
.9175 .55125 Mdot
.5425 .52875 Mdot
.2575 .5125 Mdot
.48 .48375 Mdot
.45125 .4825 Mdot
.62 .49 Mdot
.41625 .4825 Mdot
.57 .4675 Mdot
.4275 .4675 Mdot
.5125 .45625 Mdot
.54375 .4425 Mdot
.46125 .44125 Mdot
.515 .44875 Mdot
.25375 .4725 Mdot
.94125 .4825 Mdot
.39625 .48875 Mdot
.45 .4975 Mdot
.46875 .475 Mdot
.48625 .435 Mdot
.4625 .44 Mdot
.50625 .43875 Mdot
.6625 .4375 Mdot
.41125 .45 Mdot
.4825 .4825 Mdot
.4775 .4825 Mdot
.50125 .47375 Mdot
.35 .48125 Mdot
.37625 .49375 Mdot
.06125 .49875 Mdot
.5325 .5 Mdot
.47 .4875 Mdot
.52625 .47875 Mdot
.50375 .47625 Mdot
.515 .4825 Mdot
.4775 .45625 Mdot
.455 .46 Mdot
.48 .4825 Mdot
.5625 .485 Mdot
.115 .47625 Mdot
.4625 .50875 Mdot
.2575 .49375 Mdot
.48875 .49 Mdot
.525 .4975 Mdot
.49125 .49375 Mdot
.42125 .5075 Mdot
.5225 .49875 Mdot
.57875 .475 Mdot
.485 .4575 Mdot
.50625 .49 Mdot
.49 .5 Mdot
.39 .51625 Mdot
.11125 .55625 Mdot
.0475 .57 Mdot
.40875 .5725 Mdot
.54625 .595 Mdot
.48625 .59 Mdot
.47625 .5925 Mdot
.5175 .57375 Mdot
.56 .5725 Mdot
.47 .56875 Mdot
.49125 .57 Mdot
.46625 .56875 Mdot
.51625 .5675 Mdot
.215 .555 Mdot
.77875 .54125 Mdot
.77125 .5375 Mdot
.26625 .54 Mdot
.48 .55125 Mdot
.48875 .58875 Mdot
.4725 .59125 Mdot
.44625 .58375 Mdot
.5875 .57625 Mdot
.57125 .56875 Mdot
.43875 .53125 Mdot
.50125 .51625 Mdot
.48875 .4975 Mdot
.48625 .5 Mdot
.135 .49 Mdot
.0925 .4825 Mdot
.5 .13625 Mdot
.51 .1975 Mdot
.215 .20375 Mdot
.975 .205 Mdot
.44 .235 Mdot
.37375 .245 Mdot
.52125 .19 Mdot
.50375 .1725 Mdot
.50375 .165 Mdot
.2925 .165 Mdot
.7575 .1425 Mdot
.52375 .1125 Mdot
.36375 .11 Mdot
.49625 .08875 Mdot
.53 .08125 Mdot
.54125 .1225 Mdot
.30125 .15375 Mdot
.6425 .19625 Mdot
.79625 .24875 Mdot
.22125 .265 Mdot
.48875 .2625 Mdot
.5325 .28875 Mdot
.4325 .27875 Mdot
.39125 .29125 Mdot
.6025 .3175 Mdot
.6875 .335 Mdot
.39375 .3475 Mdot
.54375 .35375 Mdot
.47375 .325 Mdot
.49 .29375 Mdot
.3625 .26 Mdot
.61375 .2125 Mdot
.69625 .18625 Mdot
.29625 .1825 Mdot
.5125 .15375 Mdot
.4525 .12 Mdot
.52 .11 Mdot
.4275 .0825 Mdot
.69875 .07125 Mdot
.41 .07625 Mdot
.5225 .07625 Mdot
.47125 .07625 Mdot
.44 .12625 Mdot
.50875 .1325 Mdot
.39125 .14625 Mdot
.80875 .17 Mdot
.51625 .18875 Mdot
.325 .17125 Mdot
.49 .17375 Mdot
.46875 .18125 Mdot
.56875 .17375 Mdot
.37 .175 Mdot
.7275 .1625 Mdot
.34375 .1425 Mdot
.4975 .11 Mdot
.555 .08125 Mdot
.4575 .0975 Mdot
.5375 .10875 Mdot
.315 .08375 Mdot
.8 .085 Mdot
.45125 .1125 Mdot
.46625 .07625 Mdot
.4575 .0775 Mdot
.49125 .14375 Mdot
.3925 .14625 Mdot
.54875 .145 Mdot
.785 .1525 Mdot
.32 .1425 Mdot
.48125 .1125 Mdot
.47 .1125 Mdot
.50375 .155 Mdot
.37375 .175 Mdot
.46125 .1825 Mdot
.9675 .20625 Mdot
.18375 .25875 Mdot
.5325 .2775 Mdot
.4425 .29625 Mdot
.5325 .31625 Mdot
.4575 .3325 Mdot
.62375 .31375 Mdot
.4425 .31625 Mdot
.46 .36 Mdot
.4725 .3975 Mdot
.5375 .44625 Mdot
.2675 .4775 Mdot
.91625 .46875 Mdot
.535 .43625 Mdot
.32125 .42625 Mdot
.47875 .38875 Mdot
.5075 .36875 Mdot
.4975 .32 Mdot
.33625 .29375 Mdot
.61 .27 Mdot
.61375 .285 Mdot
.4475 .3075 Mdot
.545 .3025 Mdot
.45125 .32875 Mdot
.4025 .30625 Mdot
.20875 .29375 Mdot
.24625 .3075 Mdot
.4 .285 Mdot
.53125 .31125 Mdot
.48 .3025 Mdot
.43625 .31125 Mdot
.55375 .32875 Mdot
.67875 .3375 Mdot
.36875 .33875 Mdot
.48125 .34 Mdot
.48125 .34875 Mdot
.515 .35625 Mdot
.2875 .3675 Mdot
.65375 .38625 Mdot
.7525 .405 Mdot
.3275 .4 Mdot
.48625 .41375 Mdot
.4725 .41 Mdot
.48625 .405 Mdot
.30875 .41 Mdot
.82375 .40125 Mdot
.4825 .38125 Mdot
.425 .38375 Mdot
.50625 .39375 Mdot
.49 .40375 Mdot
.47625 .35875 Mdot
.23125 .32375 Mdot
.18125 .2 Mdot
.3275 .985 Mdot
.495 .90625 Mdot
.51875 .8325 Mdot
.43 .76625 Mdot
.33125 .73625 Mdot
.65375 .7275 Mdot
.7725 .715 Mdot
.30125 .7425 Mdot
.53875 .79375 Mdot
.50625 .8725 Mdot
.47625 .87875 Mdot
.41875 .85875 Mdot
.58375 .8575 Mdot
.615 .86875 Mdot
.3525 .8275 Mdot
.50875 .83375 Mdot
.46875 .82625 Mdot
.54 .81375 Mdot
.3025 .83625 Mdot
.81625 .85625 Mdot
.45375 .86625 Mdot
.44125 .945 Mdot
.5025 .9625 Mdot
.3925 .89125 Mdot
.4925 .8425 Mdot
.5 .7575 Mdot
.49375 .74625 Mdot
.33375 .75875 Mdot
.91625 .79125 Mdot
.2325 .83875 Mdot
.49 .9625 Mdot
.46375 .995 Mdot
.47875 .88875 Mdot
.31875 .83375 Mdot
.62125 .79375 Mdot
.87375 .72125 Mdot
.24 .70875 Mdot
.48 .72125 Mdot
.46 .81125 Mdot
.51875 .87 Mdot
.4 .85875 Mdot
.52125 .86125 Mdot
.7725 .8275 Mdot
.30375 .70375 Mdot
.525 .58625 Mdot
.4275 .5575 Mdot
.51125 .55 Mdot
.43625 .54625 Mdot
.71 .55375 Mdot
.43125 .6175 Mdot
.45125 .655 Mdot
.45625 .6825 Mdot
.55125 .705 Mdot
.37375 .66375 Mdot
.69625 .575 Mdot
.5725 .5125 Mdot
.3875 .395 Mdot
.47875 .31125 Mdot
.505 .25375 Mdot
.48375 .23625 Mdot
.25375 .185 Mdot
.7575 .185 Mdot
.59375 .1475 Mdot
.37375 .1575 Mdot
.59875 .19375 Mdot
.42375 .3225 Mdot
.45625 .38 Mdot
.27625 .40125 Mdot
.90875 .40375 Mdot
.525 .37125 Mdot
.3375 .26875 Mdot
.52625 .19 Mdot
.46625 .16 Mdot
.38375 .15 Mdot
.5725 .13875 Mdot
.81125 .1325 Mdot
.26 .1375 Mdot
.4975 .15375 Mdot
.495 .1775 Mdot
.5025 .26 Mdot
.35375 .2775 Mdot
.53625 .28375 Mdot
.74625 .27875 Mdot
.41625 .23625 Mdot
.4525 .1075 Mdot
.45875 .02125 Mdot
.19875 .01 Mdot
.97875 .02875 Mdot
.43875 .07625 Mdot
.4025 .13 Mdot
.51375 .15 Mdot
.48875 .21125 Mdot
.47375 .39125 Mdot
.31625 .57 Mdot
.92125 .7825 Mdot
.4825 .3975 Mdot
.51875 .36875 Mdot
.47625 .405 Mdot
.5725 .435 Mdot
.47375 .42375 Mdot
.47875 .46375 Mdot
.54625 .445 Mdot
.48125 .43875 Mdot
.50375 .44875 Mdot
.1275 .45125 Mdot
.965 .465 Mdot
.5825 .48625 Mdot
.265 .42375 Mdot
.45375 .34875 Mdot
.565 .26375 Mdot
.56875 .1925 Mdot
.45875 .19125 Mdot
.53375 .23625 Mdot
.515 .30375 Mdot
.47125 .425 Mdot
.47375 .53125 Mdot
.50625 .57875 Mdot
.43875 .64375 Mdot
.2675 .68 Mdot
.70625 .69625 Mdot
.84625 .7325 Mdot
.2375 .74875 Mdot
.54125 .73875 Mdot
.5 .7325 Mdot
.4525 .7675 Mdot
.48375 .81375 Mdot
.5475 .8575 Mdot
.58 .87375 Mdot
.38375 .89 Mdot
.50625 .8975 Mdot
.48875 .87875 Mdot
.535 .8625 Mdot
.19875 .8675 Mdot
.935 .88 Mdot
.46125 .89875 Mdot
.43125 .87125 Mdot
.46875 .82375 Mdot
.44 .70625 Mdot
.525 .65375 Mdot
.5225 .61375 Mdot
.55 .6325 Mdot
.49625 .705 Mdot
.45 .8125 Mdot
.49 .88875 Mdot
.51375 .94125 Mdot
.4425 .95625 Mdot
.30125 .92 Mdot
.145 .8325 Mdot
.4975 .75375 Mdot
.50625 .7025 Mdot
.52875 .62125 Mdot
.58875 .57125 Mdot
.41125 .57625 Mdot
.5275 .58875 Mdot
.50375 .60375 Mdot
.52625 .6675 Mdot
.47375 .755 Mdot
.46625 .8075 Mdot
.25875 .87625 Mdot
.70875 .935 Mdot
.52875 .94 Mdot
.435 .9425 Mdot
.5775 .91875 Mdot
.5675 .925 Mdot
.42375 .985 Mdot
.42 .965 Mdot
.48875 .87625 Mdot
.53 .8075 Mdot
.4325 .8075 Mdot
.55875 .88625 Mdot
.5675 .985 Mdot
.75 .8 Mdot
.3375 .59375 Mdot
.5 .26375 Mdot
.52625 .26625 Mdot
.5175 .2475 Mdot
.47 .24125 Mdot
.4975 .265 Mdot
.50625 .2825 Mdot
.54625 .3 Mdot
.47625 .3625 Mdot
.50875 .40375 Mdot
.07625 .40625 Mdot
.58125 .39125 Mdot
.2375 .36125 Mdot
.45125 .3425 Mdot
.505 .3475 Mdot
.645 .345 Mdot
.47 .36 Mdot
.51375 .35875 Mdot
.435 .34875 Mdot
.515 .3275 Mdot
.505 .30625 Mdot
.515 .30875 Mdot
.4225 .305 Mdot
.20375 .28875 Mdot
.7975 .29375 Mdot
.8475 .28375 Mdot
.215 .25375 Mdot
.52625 .2175 Mdot
.49375 .17125 Mdot
.44 .11 Mdot
.54625 .09125 Mdot
.4725 .06375 Mdot
.59 .0475 Mdot
.4425 .0625 Mdot
.46875 .06 Mdot
.5075 .1225 Mdot
.5175 .15 Mdot
.15 .14125 Mdot
.45875 .11375 Mdot
.42125 .04125 Mdot
.43 .0075 Mdot
.4525 .03875 Mdot
.51375 .07375 Mdot
.55625 .11875 Mdot
.525 .1425 Mdot
.47125 .1325 Mdot
.47375 .11625 Mdot
.49625 .09625 Mdot
.5225 .09625 Mdot
.43625 .09 Mdot
.23 .12125 Mdot
.10875 .16375 Mdot
.51375 .1775 Mdot
.4725 .19625 Mdot
.53625 .20125 Mdot
.60375 .1925 Mdot
.42 .18625 Mdot
.47625 .175 Mdot
.52875 .18125 Mdot
.5125 .1825 Mdot
.48 .19625 Mdot
.47125 .2325 Mdot
.24375 .2125 Mdot
.76625 .18375 Mdot
.7825 .15375 Mdot
.26125 .105 Mdot
.49375 .05125 Mdot
.455 .035 Mdot
.51125 .03125 Mdot
.54375 .01875 Mdot
.49125 .0375 Mdot
.46125 .04375 Mdot
.53125 .06625 Mdot
.4725 .0575 Mdot
.48125 .10375 Mdot
.47125 .105 Mdot
.3825 .10125 Mdot
.78625 .08 Mdot
.495 .0825 Mdot
.39875 .05875 Mdot
.4975 .06 Mdot
.5 .06625 Mdot
.49 .08625 Mdot
.46875 .07375 Mdot
.55625 .04625 Mdot
.475 .0225 Mdot
.455 .06625 Mdot
.16 .12875 Mdot
.46875 .16375 Mdot
.36625 .11875 Mdot
.6175 .06125 Mdot
.38375 .07625 Mdot
.53125 .12625 Mdot
.44625 .24 Mdot
.35875 .3375 Mdot
.96625 .39875 Mdot
.2875 .40375 Mdot
.47 .40875 Mdot
.49 .4125 Mdot
.24 .36125 Mdot
.6375 .28 Mdot
.99375 .2 Mdot
.10375 .095 Mdot
.47125 .0075 Mdot
.50625 .02375 Mdot
.10875 .065 Mdot
.42125 .14125 Mdot
.35 .01 Mdot
.50875 .00875 Mdot
.48125 .07 Mdot
.58 .14125 Mdot
.39875 .1975 Mdot
.50875 .4575 Mdot
.5075 .47125 Mdot
.51375 .4825 Mdot
.59125 .4825 Mdot
.4275 .48125 Mdot
.49125 .5 Mdot
.52875 .49875 Mdot
.4925 .5 Mdot
.51125 .485 Mdot
.1625 .4725 Mdot
.93875 .455 Mdot
.54375 .40875 Mdot
.29375 .365 Mdot
.4875 .3475 Mdot
.47 .3675 Mdot
.6 .395 Mdot
.46375 .42875 Mdot
.62625 .46875 Mdot
.39625 .49625 Mdot
.505 .485 Mdot
.49875 .46875 Mdot
.505 .4725 Mdot
.43875 .47625 Mdot
.24875 .46125 Mdot
.78125 .43625 Mdot
.7625 .44125 Mdot
.25625 .43875 Mdot
.53125 .4275 Mdot
.48875 .42625 Mdot
.415 .435 Mdot
.565 .41875 Mdot
.555 .4225 Mdot
.53875 .43375 Mdot
.41875 .46375 Mdot
.47125 .49875 Mdot
.50875 .49 Mdot
.52625 .4975 Mdot
.19125 .4675 Mdot
.9475 .45875 Mdot
.47 .4525 Mdot
.4425 .48875 Mdot
.43 .4925 Mdot
.43625 .5025 Mdot
.495 .4925 Mdot
.5475 .48 Mdot
.63 .46625 Mdot
.40875 .47125 Mdot
.47375 .49125 Mdot
.51625 .5025 Mdot
.48875 .54375 Mdot
.46625 .5375 Mdot
.245 .50875 Mdot
.17 .52 Mdot
.5125 .4775 Mdot
.45625 .47125 Mdot
.54375 .4875 Mdot
.56625 .51375 Mdot
.43625 .5 Mdot
.52375 .5075 Mdot
.53125 .515 Mdot
.47 .52375 Mdot
.4975 .51875 Mdot
.50125 .53375 Mdot
.27375 .5275 Mdot
.725 .525 Mdot
.70875 .51 Mdot
.30625 .48875 Mdot
.5125 .465 Mdot
.45375 .465 Mdot
.48625 .47125 Mdot
.5175 .48 Mdot
.54125 .4725 Mdot
.50375 .46125 Mdot
.48875 .45375 Mdot
.4575 .46375 Mdot
.48375 .46375 Mdot
.51125 .4775 Mdot
.37 .50125 Mdot
.73125 .51375 Mdot
.5375 .50625 Mdot
.39125 .5125 Mdot
.48875 .51125 Mdot
.50625 .505 Mdot
.48 .50375 Mdot
.40875 .5025 Mdot
.66625 .4925 Mdot
.46 .4825 Mdot
.4925 .4725 Mdot
.47875 .47875 Mdot
.49375 .40875 Mdot
.18 .34625 Mdot
.9875 .33625 Mdot
.42125 .3375 Mdot
.37625 .33625 Mdot
.60875 .38 Mdot
.3725 .44 Mdot
.53625 .47 Mdot
.45375 .43875 Mdot
.38875 .38125 Mdot
.9475 .35625 Mdot
.335 .31125 Mdot
.44 .27625 Mdot
.5125 .29125 Mdot
.22375 .33625 Mdot
.63375 .385 Mdot
.94 .4525 Mdot
.15125 .48375 Mdot
.56875 .51125 Mdot
.4325 .525 Mdot
.50625 .575 Mdot
.4375 .61625 Mdot
.44125 .61375 Mdot
.78375 .6125 Mdot
.3625 .61875 Mdot
.47 .57 Mdot
.46875 .5075 Mdot
.5125 .51375 Mdot
.1425 .5 Mdot
.41625 .48 Mdot
.37875 .48125 Mdot
.45875 .47375 Mdot
.5125 .48625 Mdot
.47 .4825 Mdot
.48125 .47 Mdot
.55625 .4775 Mdot
.42 .47375 Mdot
.51875 .2225 Mdot
.5275 .19375 Mdot
.44375 .18 Mdot
.80125 .16125 Mdot
.29 .135 Mdot
.50125 .10125 Mdot
.50875 .09375 Mdot
.49875 .0725 Mdot
.50125 .115 Mdot
.28625 .16125 Mdot
.7875 .24375 Mdot
.5275 .38375 Mdot
.34125 .4775 Mdot
.5125 .51375 Mdot
.455 .47875 Mdot
.545 .42 Mdot
.46875 .3375 Mdot
.76875 .275 Mdot
.30375 .2225 Mdot
.5 .2625 Mdot
.5 .31 Mdot
.49875 .31625 Mdot
.45625 .39125 Mdot
.31 .4525 Mdot
.7175 .48375 Mdot
.67 .47375 Mdot
.36375 .46125 Mdot
.50125 .42875 Mdot
.49 .3975 Mdot
.35125 .355 Mdot
.55625 .325 Mdot
.775 .31 Mdot
.39 .2875 Mdot
.42875 .265 Mdot
.46 .24 Mdot
.51375 .2675 Mdot
.525 .2925 Mdot
.29125 .33625 Mdot
.81 .36625 Mdot
.4675 .38125 Mdot
.47125 .35 Mdot
.425 .31 Mdot
.46375 .2475 Mdot
.4725 .2125 Mdot
.48 .21875 Mdot
.8075 .22125 Mdot
.34625 .2175 Mdot
.4575 .22625 Mdot
.50125 .2525 Mdot
.5 .265 Mdot
.46625 .26875 Mdot
.3075 .30125 Mdot
.9375 .32125 Mdot
.2675 .3175 Mdot
.50625 .32 Mdot
.44 .3125 Mdot
.56625 .26 Mdot
.4375 .2 Mdot
.50875 .16 Mdot
.625 .12125 Mdot
.48125 .1075 Mdot
.45375 .095 Mdot
.50875 .135 Mdot
.53 .1475 Mdot
.3125 .1425 Mdot
.665 .1475 Mdot
.5875 .18875 Mdot
.43 .20125 Mdot
.495 .205 Mdot
.445 .265 Mdot
.50375 .295 Mdot
.44375 .3075 Mdot
.685 .3075 Mdot
.46 .3125 Mdot
.465 .27125 Mdot
.44875 .27 Mdot
.49125 .2825 Mdot
.51 .2675 Mdot
.4225 .26875 Mdot
.62875 .28625 Mdot
.57375 .29375 Mdot
.3875 .28875 Mdot
.49625 .325 Mdot
.5125 .37 Mdot
.4775 .39875 Mdot
.26125 .4125 Mdot
.9325 .42125 Mdot
.37125 .4175 Mdot
.46625 .39625 Mdot
.49625 .40375 Mdot
.45875 .42875 Mdot
.295 .4325 Mdot
.89125 .4375 Mdot
.3875 .43375 Mdot
.4125 .4125 Mdot
.56625 .39875 Mdot
.3975 .365 Mdot
.55 .36125 Mdot
.33 .37 Mdot
.57 .38875 Mdot
.93125 .375 Mdot
.325 .41875 Mdot
.41 .4175 Mdot
.5175 .46125 Mdot
.26875 .4075 Mdot
.60375 .4 Mdot
.805 .3875 Mdot
.245 .4 Mdot
.57875 .36 Mdot
.43375 .39625 Mdot
.49625 .37375 Mdot
.4425 .36125 Mdot
.41625 .34375 Mdot
.88125 .31875 Mdot
.29875 .275 Mdot
.4475 .23875 Mdot
.49875 .21875 Mdot
.5325 .16875 Mdot
.26625 .2 Mdot
.8875 .26 Mdot
.48875 .34 Mdot
.41 .39 Mdot
.4475 .46625 Mdot
.5275 .49 Mdot
.46 .45125 Mdot
.37375 .4025 Mdot
.705 .34 Mdot
.34875 .2875 Mdot
.50125 .6575 Mdot
.585 .6875 Mdot
.3875 .71125 Mdot
.96375 .76125 Mdot
.1675 .85625 Mdot
.505 .985 Mdot
.68125 .93375 Mdot
.4575 .8025 Mdot
.43875 .7225 Mdot
.55125 .665 Mdot
.42125 .63625 Mdot
.51625 .675 Mdot
.42625 .70375 Mdot
.925 .6575 Mdot
.21 .665 Mdot
.49625 .64 Mdot
.49625 .59125 Mdot
.505 .63 Mdot
.47375 .56625 Mdot
.355 .505 Mdot
.675 .49375 Mdot
.56125 .4875 Mdot
.455 .4225 Mdot
.51 .405 Mdot
.46375 .41125 Mdot
.325 .515 Mdot
.50875 .61875 Mdot
1 .65625 Mdot
.25 .72 Mdot
.43 .77 Mdot
.46125 .74875 Mdot
.5175 .73625 Mdot
.51375 .71625 Mdot
.37375 .6775 Mdot
.715 .63 Mdot
.4375 .5875 Mdot
.52375 .54875 Mdot
.42125 .58 Mdot
.4825 .62375 Mdot
.4175 .68125 Mdot
.4275 .69125 Mdot
.24125 .69125 Mdot
.4575 .67875 Mdot
.495 .63875 Mdot
.4975 .65625 Mdot
.475 .665 Mdot
.39375 .65625 Mdot
.73875 .6375 Mdot
.3775 .635 Mdot
.5075 .60625 Mdot
.4475 .56375 Mdot
.5475 .5425 Mdot
.3375 .5725 Mdot
.57625 .59625 Mdot
.71125 .5975 Mdot
.41125 .62 Mdot
.46625 .68 Mdot
.5075 .695 Mdot
.5575 .68375 Mdot
.3525 .73375 Mdot
.605 .7775 Mdot
.4975 .7325 Mdot
.53875 .6925 Mdot
.49375 .71125 Mdot
.4275 .57625 Mdot
.505 .47375 Mdot
.38125 .4425 Mdot
.805 .4275 Mdot
.4525 .4225 Mdot
.41 .515 Mdot
.4475 .57125 Mdot
.4775 .595 Mdot
.5425 .66625 Mdot
.4775 .65625 Mdot
.5325 .64375 Mdot
.58375 .63125 Mdot
.3925 .61 Mdot
.51375 .52 Mdot
.5075 .39625 Mdot
.47 .30375 Mdot
.1375 .265 Mdot
.28375 .1875 Mdot
.435 .28 Mdot
.5125 .36875 Mdot
.455 .35125 Mdot
.39625 .3575 Mdot
.73125 .385 Mdot
.41125 .36375 Mdot
.48 .32625 Mdot
.50875 .2925 Mdot
.435 .2625 Mdot
.52375 .27 Mdot
.225 .21875 Mdot
.805 .15625 Mdot
.8 .17375 Mdot
.3025 .15 Mdot
.41625 .17875 Mdot
.55375 .2425 Mdot
.34875 .36875 Mdot
.55625 .4575 Mdot
.665 .49125 Mdot
.35375 .43125 Mdot
.56 .38125 Mdot
.435 .2625 Mdot
.4925 .17 Mdot
.4575 .1075 Mdot
.3825 .06625 Mdot
.97875 .07875 Mdot
.195 .135 Mdot
.47625 .23375 Mdot
.51125 .35375 Mdot
.53125 .4975 Mdot
.37375 .51625 Mdot
.71 .48125 Mdot
.53125 .405 Mdot
.425 .36 Mdot
.46 .25625 Mdot
.5275 .19125 Mdot
.45875 .3025 Mdot
.2775 .41125 Mdot
.85375 .49625 Mdot
.2675 .56125 Mdot
.47625 .85 Mdot
.60375 .86 Mdot
.42625 .88 Mdot
.075 .82375 Mdot
.48875 .745 Mdot
.51875 .675 Mdot
.50125 .55875 Mdot
.50375 .50375 Mdot
.43 .52875 Mdot
.5975 .59125 Mdot
.36 .6475 Mdot
.5975 .70125 Mdot
.61625 .76375 Mdot
.31375 .80875 Mdot
.46625 .85 Mdot
.39125 .89875 Mdot
.0825 .9825 Mdot
.43625 .96625 Mdot
.49125 .9525 Mdot
.49375 .92875 Mdot
.53 .91125 Mdot
.445 .945 Mdot
.6125 .97125 Mdot
.4375 .98125 Mdot
.4975 .96125 Mdot
.38125 .91375 Mdot
.35375 .91875 Mdot
.11375 .9725 Mdot
.49875 .9975 Mdot
.56125 .965 Mdot
.4175 .90125 Mdot
.50625 .85875 Mdot
.47625 .8675 Mdot
.61 .89375 Mdot
.50375 .9075 Mdot
.41 .9875 Mdot
.995 .935 Mdot
.18875 .87375 Mdot
.44 .37375 Mdot
.59125 .35 Mdot
.475 .30125 Mdot
.4775 .18375 Mdot
.53375 .20625 Mdot
.51875 .21125 Mdot
.4675 .24375 Mdot
.51375 .19625 Mdot
.4925 .15375 Mdot
.32 .1175 Mdot
.685 .1125 Mdot
.65125 .125 Mdot
.33625 .18375 Mdot
.3375 .1825 Mdot
.4225 .17375 Mdot
.07625 .09625 Mdot
.4975 .05125 Mdot
.5 .05 Mdot
.49875 .03125 Mdot
.51875 .0375 Mdot
.43375 .06625 Mdot
.54 .06 Mdot
.4475 .0575 Mdot
.5975 .0525 Mdot
.4475 .06625 Mdot
.5175 .0925 Mdot
.27375 .07625 Mdot
.50375 .1075 Mdot
.42625 .0625 Mdot
.5175 .09 Mdot
.485 .085 Mdot
.5375 .09375 Mdot
.4875 .075 Mdot
.51375 .07625 Mdot
.51 .12375 Mdot
.45625 .1675 Mdot
.5025 .1775 Mdot
.5025 .2675 Mdot
.375 .3175 Mdot
.30125 .285 Mdot
.035 .19375 Mdot
.4725 .09 Mdot
.49375 .015 Mdot
.54875 .11875 Mdot
.1575 .16625 Mdot
.65375 .1825 Mdot
.83625 .21875 Mdot
.3475 .17125 Mdot
.49875 .07875 Mdot
.49125 .02 Mdot
.5025 .01 Mdot
.61875 .08 Mdot
.46375 .1225 Mdot
.45375 .16 Mdot
.4825 .14375 Mdot
.29875 .1225 Mdot
.4075 .055 Mdot
.52125 .01625 Mdot
.46375 .0525 Mdot
.4675 .08375 Mdot
.52375 .095 Mdot
.5125 .1975 Mdot
.44375 .21375 Mdot
.245 .03625 Mdot
.455 .04875 Mdot
.05875 .1425 Mdot
.5825 .14 Mdot
.435 .06625 Mdot
.1275 .16625 Mdot
.06625 .33 Mdot
.47 .46125 Mdot
.5875 .4725 Mdot
.465 .48625 Mdot
.985 .46 Mdot
.0725 .4925 Mdot
.44 .525 Mdot
.60375 .545 Mdot
.50875 .56875 Mdot
.43875 .56875 Mdot
.54 .5775 Mdot
.4975 .5975 Mdot
.31375 .625 Mdot
.63375 .6275 Mdot
.7075 .60375 Mdot
.37125 .59375 Mdot
.3275 .55625 Mdot
.455 .50625 Mdot
.11875 .49 Mdot
.48 .48125 Mdot
.53125 .47875 Mdot
.49625 .47625 Mdot
.54125 .465 Mdot
.43125 .46 Mdot
.5225 .465 Mdot
.445 .44375 Mdot
.56125 .44 Mdot
.475 .43125 Mdot
.555 .43875 Mdot
.30125 .4525 Mdot
.48875 .47375 Mdot
.4825 .525 Mdot
.55625 .53625 Mdot
.4775 .55125 Mdot
.52375 .56625 Mdot
.485 .56875 Mdot
.515 .5625 Mdot
.49 .52 Mdot
.43625 .48 Mdot
.5575 .46875 Mdot
.53125 .43125 Mdot
.35875 .4075 Mdot
.29625 .40625 Mdot
.105 .41375 Mdot
.40875 .4425 Mdot
.585 .48125 Mdot
.55 .50125 Mdot
.4275 .51875 Mdot
.50125 .52875 Mdot
.47875 .52875 Mdot
.525 .5175 Mdot
.4175 .52 Mdot
.57125 .49625 Mdot
.54375 .44125 Mdot
.18125 .41375 Mdot
.62625 .41875 Mdot
.77875 .425 Mdot
.35625 .465 Mdot
.47875 .53125 Mdot
.56 .59875 Mdot
.5725 .61875 Mdot
.37875 .6225 Mdot
.5 .6075 Mdot
.50125 .575 Mdot
.55875 .51625 Mdot
.47875 .47625 Mdot
.54125 .45375 Mdot
.4625 .46125 Mdot
.30375 .46875 Mdot
.9475 .475 Mdot
.395 .485 Mdot
.34375 .52625 Mdot
.445 .55375 Mdot
.535 .54625 Mdot
.5025 .5575 Mdot
.52 .57 Mdot
.5475 .5425 Mdot
.44625 .50125 Mdot
.465 .52125 Mdot
.47375 .53375 Mdot
.61 .52 Mdot
.44875 .5075 Mdot
.2475 .5275 Mdot
.3425 .545 Mdot
.5475 .56125 Mdot
.48375 .55625 Mdot
.5125 .54625 Mdot
.47625 .55 Mdot
.47125 .5525 Mdot
.55875 .5525 Mdot
.40125 .5375 Mdot
.60125 .51625 Mdot
.445 .44375 Mdot
.02 .3775 Mdot
.6225 .44375 Mdot
.235 .505 Mdot
.42625 .58125 Mdot
.595 .65 Mdot
.51625 .6475 Mdot
.45625 .5975 Mdot
.49125 .55375 Mdot
.48125 .53875 Mdot
.4775 .5225 Mdot
.54625 .49875 Mdot
.47125 .495 Mdot
.46875 .47625 Mdot
.31375 .46375 Mdot
.1775 .43875 Mdot
.4525 .4375 Mdot
.55875 .45875 Mdot
.5525 .46875 Mdot
.45375 .4825 Mdot
.51 .51 Mdot
.4925 .52375 Mdot
.48375 .52375 Mdot
.50625 .53 Mdot
.54875 .545 Mdot
.425 .52125 Mdot
.13625 .50125 Mdot
.12875 .4825 Mdot
.58875 .38125 Mdot
.47125 .35375 Mdot
.53875 .31375 Mdot
.7875 .27 Mdot
.2025 .185 Mdot
.315 .16375 Mdot
.765 .12875 Mdot
.4925 .11125 Mdot
.4075 .12 Mdot
.55625 .2075 Mdot
.50375 .25375 Mdot
.28125 .265 Mdot
.52625 .28625 Mdot
.86375 .2925 Mdot
.43375 .24375 Mdot
.28 .21375 Mdot
.44625 .23 Mdot
.915 .23125 Mdot
.23125 .2275 Mdot
.3525 .22 Mdot
.6625 .22875 Mdot
.54125 .27875 Mdot
.47375 .3275 Mdot
.4325 .3175 Mdot
.5275 .3125 Mdot
.42875 .32375 Mdot
.47125 .2975 Mdot
.56875 .2825 Mdot
.61125 .34625 Mdot
.34 .3375 Mdot
.42375 .33 Mdot
.1 .3375 Mdot
.3425 .30125 Mdot
.745 .28625 Mdot
.4475 .25875 Mdot
.46 .19625 Mdot
.50125 .195 Mdot
.51875 .18 Mdot
.4325 .185 Mdot
.39125 .19 Mdot
.72 .2325 Mdot
.51375 .29875 Mdot
.33875 .31125 Mdot
.34875 .35625 Mdot
.18625 .38625 Mdot
.315 .32125 Mdot
.765 .325 Mdot
.57 .3075 Mdot
.33875 .28875 Mdot
.48 .25875 Mdot
.51125 .23625 Mdot
.5525 .2 Mdot
.2925 .1575 Mdot
.73 .16875 Mdot
.55 .23875 Mdot
.2 .26 Mdot
.58125 .27125 Mdot
.67 .29 Mdot
.42125 .26875 Mdot
.37375 .235 Mdot
.755 .23625 Mdot
.495 .28875 Mdot
.36625 .355 Mdot
.52 .42875 Mdot
.5125 .425 Mdot
.4825 .4475 Mdot
.36625 .43125 Mdot
.8475 .44125 Mdot
.35625 .4325 Mdot
.32875 .43375 Mdot
.8125 .41875 Mdot
.435 .41875 Mdot
.37875 .36 Mdot
.27375 .3275 Mdot
.835 .345 Mdot
.4125 .335 Mdot
.46 .30625 Mdot
.555 .31125 Mdot
.44875 .3025 Mdot
.45875 .2725 Mdot
.35375 .25875 Mdot
.85 .3125 Mdot
.35 .28 Mdot
.115 .27125 Mdot
.3075 .28875 Mdot
.35375 .22 Mdot
.5725 .22 Mdot
.58 .1925 Mdot
.41875 .16875 Mdot
.49375 .115 Mdot
.4675 .0875 Mdot
.55875 .05125 Mdot
.2825 .05 Mdot
.7975 .08 Mdot
.39625 .12625 Mdot
.14875 .20375 Mdot
.985 .30875 Mdot
.555 .39125 Mdot
.2075 .42 Mdot
.43625 .45875 Mdot
.83625 .46625 Mdot
.4225 .46375 Mdot
.405 .45125 Mdot
.4925 .45 Mdot
.47875 .4525 Mdot
.385 .44375 Mdot
.61 .3875 Mdot
.64875 .39125 Mdot
.3425 .3775 Mdot
.34875 .35125 Mdot
.92 .34 Mdot
.24625 .3675 Mdot
.38875 .34 Mdot
.67125 .33875 Mdot
.5425 .34 Mdot
.4675 .34625 Mdot
.47 .36 Mdot
.49875 .37875 Mdot
.44625 .40125 Mdot
.41375 .4 Mdot
.79625 .38125 Mdot
.315 .36875 Mdot
.23625 .355 Mdot
.91 .34375 Mdot
.26125 .3875 Mdot
.7125 .47375 Mdot
.345 .54625 Mdot
.585 .62125 Mdot
.65375 .6225 Mdot
.3075 .58625 Mdot
.1975 .525 Mdot
.86375 .55 Mdot
.59875 .56875 Mdot
.28375 .58375 Mdot
.605 .5775 Mdot
.48625 .51375 Mdot
.33125 .44625 Mdot
.3525 .40375 Mdot
.96 .42375 Mdot
.52875 .47125 Mdot
.22875 .54375 Mdot
.48375 .62375 Mdot
.75375 .6425 Mdot
.34375 .5925 Mdot
.265 .485 Mdot
.75375 .43375 Mdot
.6 .3575 Mdot
.39875 .31625 Mdot
.43125 .36875 Mdot
.51125 .385 Mdot
.45 .40125 Mdot
.39125 .44 Mdot
.64 .51875 Mdot
.6675 .5075 Mdot
.38 .51625 Mdot
.37625 .455 Mdot
.9175 .335 Mdot
.2275 .225 Mdot
.26125 .1625 Mdot
.875 .18625 Mdot
.42375 .275 Mdot
.4275 .42625 Mdot
.4875 .4475 Mdot
.5425 .4625 Mdot
.38625 .46875 Mdot
.33375 .515 Mdot
.85 .53125 Mdot
.5275 .65125 Mdot
.34 .6775 Mdot
.35875 .6775 Mdot
.855 .58375 Mdot
.305 .45 Mdot
.2175 .3575 Mdot
.91125 .33125 Mdot
.60125 .31 Mdot
.26375 .35 Mdot
.46125 .45125 Mdot
.53 .4525 Mdot
.5475 .4875 Mdot
.20375 .545 Mdot
.875 .60625 Mdot
.5675 .66875 Mdot
.205 .8075 Mdot
.53875 .9175 Mdot
.58875 .93125 Mdot
.48375 .94375 Mdot
.2575 .9325 Mdot
.96125 .88625 Mdot
.42 .83 Mdot
.34875 .8425 Mdot
.52125 .775 Mdot
.51625 .725 Mdot
.435 .69 Mdot
.2525 .7075 Mdot
.28 .65 Mdot
.3575 .6025 Mdot
.7025 .545 Mdot
.45125 .38 Mdot
.4175 .32625 Mdot
.12125 .34125 Mdot
.29125 .36 Mdot
.38625 .445 Mdot
.57625 .43125 Mdot
.45875 .3625 Mdot
.43625 .32 Mdot
.25 .3425 Mdot
.28125 .5125 Mdot
.2325 .60125 Mdot
.89875 .6225 Mdot
.37625 .5725 Mdot
.3625 .55125 Mdot
.60875 .5025 Mdot
.66875 .5325 Mdot
.3275 .57875 Mdot
.50125 .66 Mdot
.48 .6525 Mdot
.5375 .67625 Mdot
.15375 .6875 Mdot
.99 .74375 Mdot
.375 .7075 Mdot
.25375 .60375 Mdot
.78625 .4 Mdot
.53625 .18625 Mdot
.7025 .04125 Mdot
.2575 .11625 Mdot
.42875 .19375 Mdot
.7675 .19875 Mdot
.32375 .1275 Mdot
.27625 .09875 Mdot
.8525 .0825 Mdot
.50875 .0975 Mdot
.4525 .13 Mdot
.45625 .1125 Mdot
.49875 .0525 Mdot
.4525 .0425 Mdot
.27625 .05375 Mdot
.2075 .18875 Mdot
.32625 .2525 Mdot
.67875 .33 Mdot
.38875 .43125 Mdot
.8325 .9825 Mdot
.2575 .95125 Mdot
.55875 .995 Mdot
.61375 1 Mdot
.6075 .9525 Mdot
.46 .95875 Mdot
.715 .96625 Mdot
.67625 .8675 Mdot
.40875 .89 Mdot
.5175 .82625 Mdot
.3225 .83375 Mdot
.42125 .8175 Mdot
.60625 .86875 Mdot
.23125 .90625 Mdot
.515 .83875 Mdot
.49375 .73625 Mdot
.50125 .75375 Mdot
.16375 .81375 Mdot
.35125 .91625 Mdot
.30875 .93125 Mdot
.54 .98625 Mdot
.50875 .93875 Mdot
.39625 .9175 Mdot
.12375 .8925 Mdot
.2075 .8725 Mdot
.21 .94875 Mdot
.35625 .9175 Mdot
.64125 .89 Mdot
.47875 .9475 Mdot
.9825 .1925 Mdot
.1925 .15375 Mdot
.515 .05375 Mdot
.50625 .1025 Mdot
.455 .0775 Mdot
.01375 .10875 Mdot
.72125 .16875 Mdot
.155 .13125 Mdot
.6625 .17875 Mdot
.4425 .2575 Mdot
.41125 .29875 Mdot
.67625 .265 Mdot
.12125 .1425 Mdot
.525 .05125 Mdot
.50875 .1375 Mdot
.56 .18625 Mdot
.0075 .14125 Mdot
.9425 .12875 Mdot
.77375 .15125 Mdot
.215 .0575 Mdot
.44 .03625 Mdot
.53125 .1275 Mdot
.46875 .19875 Mdot
.24125 .23125 Mdot
.82125 .28 Mdot
.6775 .355 Mdot
.4025 .32125 Mdot
.33875 .2175 Mdot
.63 .2575 Mdot
.52875 .2125 Mdot
.08 .07 Mdot
.35875 .0275 Mdot
.51375 .05875 Mdot
.3375 .12625 Mdot
.20625 .20625 Mdot
.5725 .30125 Mdot
.235 .24875 Mdot
.45375 .2425 Mdot
.45125 .285 Mdot
.60625 .245 Mdot
.045 .1925 Mdot
.65375 .17 Mdot
.15375 .13 Mdot
.43625 .1175 Mdot
.53875 .19625 Mdot
.565 .22875 Mdot
.05125 .15 Mdot
.56 .11875 Mdot
.195 .07125 Mdot
.5275 .02375 Mdot
.49375 .10125 Mdot
.48 .09375 Mdot
.07875 .08125 Mdot
.29875 .04625 Mdot
.495 .1075 Mdot
.35625 .16375 Mdot
.09125 .1825 Mdot
.1375 .1875 Mdot
.3825 .02125 Mdot
.52125 .04875 Mdot
.48375 .0725 Mdot
.0675 .08125 Mdot
.51625 .07625 Mdot
.395 .1175 Mdot
.03375 .1775 Mdot
.22875 .2375 Mdot
.42875 .16375 Mdot
.51625 .16 Mdot
.4375 .12 Mdot
.3375 .08625 Mdot
.70375 .0725 Mdot
.82125 .075 Mdot
.19125 .06375 Mdot
.47125 .045 Mdot
.50875 .0875 Mdot
.52 .0725 Mdot
.03375 .06625 Mdot
.28375 .02875 Mdot
.505 .085 Mdot
.24 .08625 Mdot
.5325 .025 Mdot
.11625 .045 Mdot
.915 .08875 Mdot
.83125 .095 Mdot
.14125 .035 Mdot
.43875 .05125 Mdot
.02375 .09875 Mdot
.44125 .0275 Mdot
.38875 .00875 Mdot
.27625 .00375 Mdot
.46625 .0475 Mdot
.26625 .075 Mdot
.58375 .13125 Mdot
.96 .50375 Mdot
.20625 .52625 Mdot
.52125 .53875 Mdot
.5425 .50375 Mdot
.45625 .575 Mdot
.0475 .545 Mdot
.99875 .52875 Mdot
.7325 .53 Mdot
.17625 .55375 Mdot
.63625 .44625 Mdot
.45125 .4175 Mdot
.41625 .4475 Mdot
.64875 .49875 Mdot
.13875 .56375 Mdot
.52 .57625 Mdot
.55125 .5275 Mdot
.55125 .5375 Mdot
.03875 .51625 Mdot
.90375 .4625 Mdot
.79125 .39875 Mdot
.18125 .4225 Mdot
.45 .4025 Mdot
.525 .4175 Mdot
.47375 .45375 Mdot
.27875 .475 Mdot
.79125 .415 Mdot
.66625 .39875 Mdot
.36375 .37875 Mdot
.38375 .37 Mdot
.68125 .34375 Mdot
.5075 .41125 Mdot
.0625 .46375 Mdot
.35375 .555 Mdot
.4075 .59875 Mdot
.45375 .59625 Mdot
.515 .55 Mdot
.3475 .5375 Mdot
.20375 .4875 Mdot
.51875 .42 Mdot
.22875 .40625 Mdot
.56125 .37625 Mdot
.4325 .365 Mdot
.54875 .4025 Mdot
.14875 .41375 Mdot
.625 .42625 Mdot
.17875 .40125 Mdot
.43875 .4075 Mdot
.48375 .41125 Mdot
.61625 .4275 Mdot
.0925 .45375 Mdot
.55625 .48 Mdot
.1975 .5 Mdot
.6075 .49375 Mdot
.4775 .49 Mdot
.47625 .49375 Mdot
.10125 .485 Mdot
.3025 .45625 Mdot
.33375 .46 Mdot
.5125 .44375 Mdot
.47625 .39125 Mdot
.42 .3725 Mdot
.07375 .37 Mdot
.16 .40625 Mdot
.38125 .45875 Mdot
.58125 .48375 Mdot
.49875 .4875 Mdot
.4725 .475 Mdot
.0825 .4775 Mdot
.34625 .4875 Mdot
.50125 .5175 Mdot
.52 .52 Mdot
.4 .53625 Mdot
.09 .525 Mdot
.22375 .465 Mdot
.47125 .4875 Mdot
.55 .50875 Mdot
.44 .54875 Mdot
.31625 .57125 Mdot
.7075 .59 Mdot
.8 .55375 Mdot
.20875 .49875 Mdot
.45875 .45375 Mdot
.5475 .46125 Mdot
.505 .51125 Mdot
.0875 .53625 Mdot
.3025 .595 Mdot
.40125 .59375 Mdot
.57625 .5375 Mdot
.47 .525 Mdot
.24125 .48125 Mdot
.54 .4875 Mdot
.435 .475 Mdot
.51625 .5125 Mdot
.48625 .4325 Mdot
.08375 .4225 Mdot
.95125 .42 Mdot
.8075 .43375 Mdot
.13375 .4225 Mdot
.545 .4775 Mdot
.51875 .4775 Mdot
.4375 .4525 Mdot
.02625 .43625 Mdot
.42125 .4825 Mdot
.3675 .47375 Mdot
.43 .37625 Mdot
.5025 .36875 Mdot
.3725 .345 Mdot
.2975 .33875 Mdot
.46625 .4675 Mdot
.29 .49 Mdot
.52875 .48875 Mdot
.82125 .38375 Mdot
.25 .34875 Mdot
.50625 .3375 Mdot
.71375 .365 Mdot
.37375 .28375 Mdot
.15 .2675 Mdot
.855 .32375 Mdot
.7325 .37125 Mdot
.215 .355 Mdot
.61125 .43375 Mdot
.45625 .46875 Mdot
.4375 .41125 Mdot
.115 .40125 Mdot
.59625 .4475 Mdot
.16375 .45875 Mdot
.5725 .48125 Mdot
.6125 .48875 Mdot
.485 .40125 Mdot
.1925 .4 Mdot
.715 .45 Mdot
.785 .5175 Mdot
.26625 .56 Mdot
.43875 .69625 Mdot
.5125 .73 Mdot
.48625 .7225 Mdot
.3225 .73875 Mdot
.76 .78125 Mdot
.5975 .7475 Mdot
.33125 .72875 Mdot
.4975 .72375 Mdot
.6825 .695 Mdot
.44375 .6225 Mdot
.19625 .59 Mdot
.94125 .57125 Mdot
.38 .5275 Mdot
.47 .495 Mdot
.4475 .48875 Mdot
.5025 .49875 Mdot
.4025 .45 Mdot
.255 .46375 Mdot
.97875 .49375 Mdot
.52375 .50125 Mdot
.1325 .5175 Mdot
.78875 .56125 Mdot
.39 .55375 Mdot
.49375 .5 Mdot
.2725 .4675 Mdot
.86125 .43875 Mdot
.63375 .43375 Mdot
.25375 .43625 Mdot
.455 .40875 Mdot
.44875 .42375 Mdot
.58375 .4325 Mdot
.24375 .44375 Mdot
.88625 .41 Mdot
.5425 .42 Mdot
.15 .39375 Mdot
.85375 .40875 Mdot
.36625 .46625 Mdot
.46 .50125 Mdot
.20375 .53375 Mdot
.35125 .5475 Mdot
.38125 .4775 Mdot
.5 .435 Mdot
.47625 .43625 Mdot
.45625 .45 Mdot
.20625 .4525 Mdot
.25 .52875 Mdot
.27875 .55 Mdot
.83875 .545 Mdot
.39375 .56625 Mdot
.46875 .55125 Mdot
.00375 .5275 Mdot
.1825 .4775 Mdot
.37625 .41875 Mdot
.51125 .385 Mdot
.505 .38 Mdot
.41375 .32 Mdot
.22375 .2975 Mdot
.295 .405 Mdot
.4575 .4075 Mdot
.6425 .455 Mdot
.40375 .45625 Mdot
.3175 .4075 Mdot
.68125 .3225 Mdot
.75625 .28625 Mdot
.26 .26 Mdot
.47375 .28 Mdot
.5275 .4 Mdot
.51375 .43625 Mdot
.19625 .48125 Mdot
.925 .53625 Mdot
.36875 .56625 Mdot
.30125 .50375 Mdot
.7925 .5325 Mdot
.38125 .54125 Mdot
.30375 .53625 Mdot
.56125 .53875 Mdot
.06625 .54 Mdot
.49125 .5475 Mdot
.51625 .53375 Mdot
.49 .54125 Mdot
.16875 .52375 Mdot
.89 .51375 Mdot
.6575 .5 Mdot
.175 .50625 Mdot
.60875 .485 Mdot
.58875 .5125 Mdot
.4075 .51125 Mdot
.10875 .54375 Mdot
.40125 .55125 Mdot
.3675 .53875 Mdot
.4725 .66625 Mdot
.4975 .65125 Mdot
.40375 .6525 Mdot
.3925 .64625 Mdot
.11 .49875 Mdot
.39125 .4425 Mdot
.555 .41125 Mdot
.395 .41375 Mdot
.73875 .16375 Mdot
.21375 .09625 Mdot
.79625 .05375 Mdot
.28125 .215 Mdot
.255 .2975 Mdot
.79875 .30375 Mdot
.6225 .26 Mdot
.3175 .1675 Mdot
.57125 .03375 Mdot
.4675 .11625 Mdot
.43875 .2275 Mdot
.24375 .25625 Mdot
.9025 .26375 Mdot
.5275 .2375 Mdot
.19625 .10375 Mdot
.58125 .01125 Mdot
.71125 .1375 Mdot
.4075 .355 Mdot
.2925 .40625 Mdot
.59125 .40875 Mdot
.745 .4525 Mdot
.35125 .35375 Mdot
.45875 .13875 Mdot
.49125 .1425 Mdot
.49 .13625 Mdot
.38125 .05875 Mdot
.53125 .0125 Mdot
.29125 .05625 Mdot
.6575 .05625 Mdot
.63125 .1375 Mdot
.415 .18875 Mdot
.27625 .18125 Mdot
.81375 .1 Mdot
.4 .08625 Mdot
.5025 .05 Mdot
.46125 .04625 Mdot
.475 .165 Mdot
.45875 .29125 Mdot
.30875 .285 Mdot
.85125 .20625 Mdot
.5175 .22375 Mdot
.06875 .155 Mdot
.96875 .05375 Mdot
.34625 .145 Mdot
.45 .25875 Mdot
.3775 .29375 Mdot
.715 .2975 Mdot
.64625 .3475 Mdot
.31 .3125 Mdot
.4525 .36 Mdot
.445 .43 Mdot
.5625 .415 Mdot
.37625 .315 Mdot
.72 .28125 Mdot
.52125 .2475 Mdot
.1375 .15375 Mdot
.30125 .18125 Mdot
.44125 .18375 Mdot
.30625 .12125 Mdot
.8475 .09375 Mdot
.4425 .08 Mdot
.42625 .06125 Mdot
.47875 .11875 Mdot
.48 .22875 Mdot
.47 .21875 Mdot
.32375 .20625 Mdot
.9375 .13375 Mdot
.31625 .02375 Mdot
.4825 .0675 Mdot
.16 .12875 Mdot
.28625 .21875 Mdot
.40125 .17 Mdot
.52125 .18875 Mdot
.52 .31875 Mdot
.43125 .47375 Mdot
.32375 .5525 Mdot
.865 .56375 Mdot
.34875 .52625 Mdot
.46375 .42 Mdot
.7375 .325 Mdot
.36375 .3225 Mdot
.3225 .345 Mdot
.64375 .39 Mdot
.7025 .3975 Mdot
.31375 .385 Mdot
.49 .3375 Mdot
.505 .26375 Mdot
.54625 .215 Mdot
.31375 .1625 Mdot
.725 .04125 Mdot
.99875 .02375 Mdot
.29875 .09125 Mdot
.35 .1775 Mdot
.58375 .22625 Mdot
.8175 .24 Mdot
.22625 .1875 Mdot
.4875 .1275 Mdot
.5175 .1575 Mdot
.4725 .1575 Mdot
.275 .12625 Mdot
.78125 .09625 Mdot
.6225 .07625 Mdot
.16125 .015 Mdot
.64375 .07375 Mdot
.36375 .15 Mdot
.21375 .13375 Mdot
.96875 .1325 Mdot
.425 .14875 Mdot
.385 .08875 Mdot
.48875 .0225 Mdot
.48625 .1075 Mdot
.41375 .07875 Mdot
.52375 .05375 Mdot
.8725 .00625 Mdot
.23 .06625 Mdot
.30625 .12 Mdot
.78625 .16875 Mdot
.28 .16625 Mdot
.5275 .215 Mdot
.165 .2225 Mdot
.66875 .19875 Mdot
.08125 .03 Mdot
.4575 .0475 Mdot
.325 .10125 Mdot
.53 .15875 Mdot
.9325 .18125 Mdot
.25 .16875 Mdot
.52375 .15625 Mdot
.37875 .1325 Mdot
.57 .10625 Mdot
.525 .1 Mdot
.505 .07125 Mdot
.45375 .07875 Mdot
.4475 .085 Mdot
.495 .07875 Mdot
.6325 .10375 Mdot
.5025 .16375 Mdot
.19625 .1125 Mdot
.865 .09 Mdot
.62125 .045 Mdot
.58125 .025 Mdot
.43 .06875 Mdot
.05 .10375 Mdot
.21125 .095 Mdot
.675 .0225 Mdot
.3825 .0375 Mdot
.4875 .05125 Mdot
.44625 .0325 Mdot
.51125 .00625 Mdot
.43 .06 Mdot
.5125 .04375 Mdot
.10125 .04375 Mdot
.1025 .0675 Mdot
.04625 .0675 Mdot
.50875 .01 Mdot
.4675 .00625 Mdot
.54125 .01125 Mdot
.4675 .015 Mdot
.5175 .025 Mdot
.4825 .02125 Mdot
.4725 .01625 Mdot
.57125 .0525 Mdot
.4525 .09875 Mdot
.4525 .1925 Mdot
.49625 .1825 Mdot
.09 .15375 Mdot
.16375 .08125 Mdot
.4975 .03125 Mdot
.49125 .07 Mdot
.505 .09875 Mdot
.47625 .145 Mdot
.475 .1725 Mdot
.505 .1375 Mdot
.44875 .11625 Mdot
.4625 .09 Mdot
.63 .1275 Mdot
.525 .20125 Mdot
.0775 .28125 Mdot
.88375 .3175 Mdot
.75625 .31 Mdot
.2375 .24 Mdot
.4825 .13 Mdot
.54625 .04 Mdot
.22375 .0475 Mdot
.12125 .16125 Mdot
.50625 .41375 Mdot
.1625 .37 Mdot
.6575 .35875 Mdot
.07875 .415 Mdot
.42375 .51125 Mdot
.6 .575 Mdot
.4625 .605 Mdot
.45875 .59375 Mdot
.54125 .59125 Mdot
.505 .5925 Mdot
.49 .5825 Mdot
.47625 .56125 Mdot
.49125 .52375 Mdot
.50625 .50625 Mdot
.36 .4925 Mdot
.50625 .47125 Mdot
.91 .46 Mdot
.275 .49 Mdot
.52 .515 Mdot
.3975 .52625 Mdot
.52375 .52 Mdot
.51875 .54375 Mdot
.51125 .515 Mdot
.4925 .4475 Mdot
.44125 .4025 Mdot
.5375 .40625 Mdot
.57625 .37875 Mdot
.51125 .3525 Mdot
.18375 .4 Mdot
.89125 .41375 Mdot
.575 .42125 Mdot
.28 .43 Mdot
.5 .47125 Mdot
.47625 .46125 Mdot
.50625 .475 Mdot
.46625 .49125 Mdot
.56625 .5025 Mdot
.53 .50375 Mdot
.49625 .5225 Mdot
.47 .5225 Mdot
.545 .47625 Mdot
.41875 .46 Mdot
.11375 .4575 Mdot
.23 .49375 Mdot
.3725 .54625 Mdot
.57375 .55125 Mdot
.45 .5475 Mdot
.645 .54375 Mdot
.37 .5175 Mdot
.5075 .52 Mdot
.53 .5225 Mdot
.43625 .53 Mdot
.58 .5175 Mdot
.44625 .4725 Mdot
.50875 .46 Mdot
.10125 .455 Mdot
.155 .45125 Mdot
.4575 .52875 Mdot
.51625 .5325 Mdot
.455 .5275 Mdot
.58125 .51625 Mdot
.475 .52875 Mdot
.51 .5075 Mdot
.53375 .4975 Mdot
.49375 .50375 Mdot
.46 .525 Mdot
.5125 .5425 Mdot
.48375 .52625 Mdot
.03625 .49125 Mdot
.52125 .4625 Mdot
.48375 .48375 Mdot
.45625 .50875 Mdot
.525 .54375 Mdot
.41 .5625 Mdot
.59125 .5625 Mdot
.52125 .52875 Mdot
.49875 .5 Mdot
.485 .4675 Mdot
.49 .455 Mdot
.41875 .45625 Mdot
.4675 .48 Mdot
.86 .49375 Mdot
.26875 .495 Mdot
.41 .4825 Mdot
.52875 .48 Mdot
.6025 .47 Mdot
.42375 .4675 Mdot
.54625 .46625 Mdot
.48625 .47375 Mdot
.51625 .475 Mdot
.4725 .47875 Mdot
.46875 .49 Mdot
.50875 .49625 Mdot
.11625 .50125 Mdot
.185 .515 Mdot
.5225 .49875 Mdot
.46 .48875 Mdot
.485 .48125 Mdot
.5 .46 Mdot
.5125 .45375 Mdot
.47 .45375 Mdot
.4575 .46125 Mdot
.49375 .46125 Mdot
.61125 .4475 Mdot
.51375 .42375 Mdot
.045 .385 Mdot
.8775 .355 Mdot
.80875 .36125 Mdot
.225 .385 Mdot
.49 .41375 Mdot
.51 .455 Mdot
.48375 .4775 Mdot
.48875 .4875 Mdot
.52875 .49375 Mdot
.48 .5075 Mdot
.51625 .515 Mdot
.49375 .51875 Mdot
.4975 .52875 Mdot
.47875 .5275 Mdot
.21625 .52875 Mdot
.11375 .51375 Mdot
.52125 .59125 Mdot
.20625 .57875 Mdot
.66875 .57 Mdot
.96875 .58 Mdot
.16125 .57375 Mdot
.42875 .54 Mdot
.6025 .52625 Mdot
.465 .50875 Mdot
.38875 .49 Mdot
.62875 .48125 Mdot
.59125 .50875 Mdot
.38875 .525 Mdot
.47625 .53375 Mdot
.505 .5175 Mdot
.4975 .49625 Mdot
.42625 .45 Mdot
.46625 .4425 Mdot
.83 .445 Mdot
.34375 .4425 Mdot
.49 .42875 Mdot
.445 .48375 Mdot
.4875 .53375 Mdot
.37875 .525 Mdot
.65625 .56625 Mdot
.57625 .60125 Mdot
.3725 .57875 Mdot
.55 .56 Mdot
.53875 .565 Mdot
.52625 .54125 Mdot
.245 .51875 Mdot
.825 .5325 Mdot
.47875 .515 Mdot
.36375 .52375 Mdot
.5075 .54 Mdot
.49875 .575 Mdot
.48125 .575 Mdot
.3875 .54125 Mdot
.62125 .515 Mdot
.6775 .49125 Mdot
.37 .45625 Mdot
.47625 .41625 Mdot
.55875 .39875 Mdot
.41 .41125 Mdot
.2325 .4 Mdot
.28875 .3475 Mdot
.4175 .40375 Mdot
.56875 .43 Mdot
.45125 .46875 Mdot
.61375 .51875 Mdot
.32125 .53875 Mdot
.4775 .51375 Mdot
.74125 .4925 Mdot
.34 .46375 Mdot
.56625 .46375 Mdot
.45875 .4475 Mdot
.49875 .42125 Mdot
.2175 .40625 Mdot
.27375 .3625 Mdot
.4725 .34875 Mdot
.51375 .365 Mdot
.47625 .38125 Mdot
.54 .4375 Mdot
.375 .46125 Mdot
.6725 .49625 Mdot
.49375 .53 Mdot
.49625 .54125 Mdot
.45375 .50375 Mdot
.5225 .48625 Mdot
.4925 .48375 Mdot
.0925 .48125 Mdot
.125 .49875 Mdot
.5175 .52125 Mdot
.50625 .515 Mdot
.4825 .49625 Mdot
.4225 .46125 Mdot
.46625 .42125 Mdot
.73875 .39125 Mdot
.40625 .395 Mdot
.49375 .39375 Mdot
.465 .37125 Mdot
.50875 .39375 Mdot
.44375 .41 Mdot
.46875 .40125 Mdot
.77 .39375 Mdot
.32875 .41625 Mdot
.41125 .43125 Mdot
.49375 .44375 Mdot
.58625 .455 Mdot
.43375 .46875 Mdot
.625 .47625 Mdot
.54125 .47625 Mdot
.4 .46625 Mdot
.48875 .465 Mdot
.4775 .45625 Mdot
.50625 .44125 Mdot
.2275 .4225 Mdot
.285 .4025 Mdot
.53125 .4175 Mdot
.465 .44 Mdot
.44125 .4475 Mdot
.49 .45625 Mdot
.6525 .47375 Mdot
.38875 .47125 Mdot
.45875 .46625 Mdot
.48625 .4725 Mdot
.6125 .48125 Mdot
.505 .475 Mdot
.1325 .505 Mdot
.805 .52 Mdot
.7425 .51375 Mdot
.2725 .51125 Mdot
.485 .52375 Mdot
.45875 .50875 Mdot
.455 .52125 Mdot
.7175 .5375 Mdot
.38625 .53625 Mdot
.48875 .52125 Mdot
.5375 .52625 Mdot
.47375 .505 Mdot
.48875 .49125 Mdot
.49125 .5 Mdot
.3075 .5225 Mdot
.97625 .51875 Mdot
.21 .56 Mdot
.5125 .095 Mdot
.29 .1225 Mdot
.5975 .14875 Mdot
.87875 .15375 Mdot
.28375 .12 Mdot
.41125 .0425 Mdot
.55875 .02375 Mdot
.735 .00375 Mdot
.4 .0025 Mdot
.265 .0475 Mdot
.5825 .11625 Mdot
.57125 .20125 Mdot
.5075 .25875 Mdot
.2825 .22 Mdot
.7325 .19125 Mdot
.48125 .1925 Mdot
.38125 .13 Mdot
.53875 .05 Mdot
.48875 .00625 Mdot
.34 .0425 Mdot
.6125 .09875 Mdot
.85 .18 Mdot
.26 .1975 Mdot
.45625 .19 Mdot
.57125 .23 Mdot
.405 .1675 Mdot
.325 .1275 Mdot
.90125 .175 Mdot
.30125 .16625 Mdot
.5125 .03 Mdot
.53875 .00875 Mdot
.475 .05875 Mdot
.49375 .11 Mdot
.305 .15875 Mdot
.86125 .21 Mdot
.345 .27375 Mdot
.47875 .21125 Mdot
.4825 .19125 Mdot
.5625 .1525 Mdot
.4825 .08125 Mdot
.2675 .02 Mdot
.4975 .0225 Mdot
.49375 .00875 Mdot
.25625 .03 Mdot
.99625 .0375 Mdot
.23375 .0525 Mdot
.46125 .01625 Mdot
.895 .0675 Mdot
.2875 .08875 Mdot
.48375 .15 Mdot
.44875 .255 Mdot
.5425 .32125 Mdot
.45625 .295 Mdot
.47625 .2825 Mdot
.67625 .26375 Mdot
.39125 .14625 Mdot
.42 .01 Mdot
.33 .0325 Mdot
.815 .0625 Mdot
.3875 .0775 Mdot
.53 .0175 Mdot
.74625 .02375 Mdot
.3 .06875 Mdot
.47125 .12125 Mdot
.48625 .125 Mdot
.60125 .2125 Mdot
.4825 .24 Mdot
.23375 .17375 Mdot
.7175 .12625 Mdot
.6825 .09 Mdot
.2775 .0325 Mdot
.49625 .07 Mdot
.5475 .05125 Mdot
.45125 .04375 Mdot
.49 .035 Mdot
.4 .015 Mdot
.53 .13375 Mdot
.47875 .2025 Mdot
.25375 .165 Mdot
.78625 .1325 Mdot
.8575 .1 Mdot
.49875 .02 Mdot
.42375 .14875 Mdot
.215 .18 Mdot
.76875 .145 Mdot
.7875 .1575 Mdot
.215 .0225 Mdot
.4575 .04125 Mdot
.55 .03 Mdot
.47625 .0475 Mdot
.28625 .155 Mdot
.33625 .235 Mdot
.02625 .27875 Mdot
.50625 .13125 Mdot
.46625 .0625 Mdot
.49875 .0125 Mdot
.47875 .00625 Mdot
.69 .0025 Mdot
.4475 .0725 Mdot
.075 .1675 Mdot
.99375 .2975 Mdot
.515 .3825 Mdot
.4425 .335 Mdot
.43375 .28375 Mdot
.4675 .165 Mdot
.52125 .0575 Mdot
.50625 .08625 Mdot
.49 .14125 Mdot
.37625 .06125 Mdot
.465 .05375 Mdot
.44625 .1575 Mdot
.52875 .21 Mdot
.21125 .14875 Mdot
.875 .0025 Mdot
.10125 .0225 Mdot
.50875 .095 Mdot
.4175 .10375 Mdot
.23125 .15125 Mdot
.09375 .1375 Mdot
.50125 .595 Mdot
.49375 .60625 Mdot
.52875 .59 Mdot
.50875 .58 Mdot
.56875 .57 Mdot
.41375 .53125 Mdot
.5125 .51125 Mdot
.49125 .495 Mdot
.25625 .4875 Mdot
.79625 .4675 Mdot
.9 .47375 Mdot
.085 .47875 Mdot
.45125 .49625 Mdot
.53625 .49125 Mdot
.4675 .5075 Mdot
.485 .50125 Mdot
.56875 .505 Mdot
.48625 .49375 Mdot
.51625 .4925 Mdot
.505 .47875 Mdot
.47875 .43 Mdot
.4475 .40375 Mdot
.21625 .40125 Mdot
.8 .445 Mdot
.7575 .5 Mdot
.225 .5375 Mdot
.5175 .5425 Mdot
.60125 .5925 Mdot
.44875 .6025 Mdot
.5675 .58875 Mdot
.41875 .66625 Mdot
.48 .7325 Mdot
.49375 .7675 Mdot
.53125 .765 Mdot
.485 .7325 Mdot
.42 .68375 Mdot
.29125 .66125 Mdot
.57375 .6025 Mdot
.0225 .60375 Mdot
.42875 .61 Mdot
.51875 .59875 Mdot
.485 .595 Mdot
.47125 .61375 Mdot
.525 .58625 Mdot
.45375 .575 Mdot
.62125 .56625 Mdot
.4725 .56125 Mdot
.47625 .52375 Mdot
.4425 .49375 Mdot
.36625 .44125 Mdot
.30625 .4225 Mdot
.0175 .3975 Mdot
.4975 .41 Mdot
.45375 .4375 Mdot
.5275 .42375 Mdot
.45875 .40625 Mdot
.55125 .39375 Mdot
.5 .405 Mdot
.51 .42375 Mdot
.37 .42625 Mdot
.705 .4175 Mdot
.44125 .435 Mdot
.08125 .43875 Mdot
.9675 .4525 Mdot
.52875 .455 Mdot
.42375 .48625 Mdot
.46625 .5325 Mdot
.43625 .5625 Mdot
.53125 .56625 Mdot
.58125 .6075 Mdot
.4725 .63875 Mdot
.50875 .6125 Mdot
.44125 .6225 Mdot
.51875 .6175 Mdot
.51625 .61625 Mdot
.33 .57625 Mdot
.54 .50875 Mdot
.10125 .31875 Mdot
.48625 .28875 Mdot
.44 .3025 Mdot
.6775 .365 Mdot
.40875 .445 Mdot
.50875 .50875 Mdot
.5075 .515 Mdot
.4775 .46625 Mdot
.485 .37625 Mdot
.44875 .335 Mdot
.51375 .30875 Mdot
.21625 .3225 Mdot
.485 .4525 Mdot
.23 .485 Mdot
.52125 .5025 Mdot
.49375 .49125 Mdot
.5175 .48875 Mdot
.465 .47625 Mdot
.55 .4775 Mdot
.4825 .49125 Mdot
.5025 .51625 Mdot
.5025 .53375 Mdot
.2325 .57 Mdot
.77625 .6 Mdot
.86375 .605 Mdot
.1275 .5775 Mdot
.49 .5475 Mdot
.475 .52375 Mdot
.505 .50125 Mdot
.52125 .48875 Mdot
.47875 .49625 Mdot
.5525 .5175 Mdot
.485 .52625 Mdot
.465 .50875 Mdot
.5225 .4925 Mdot
.4275 .4875 Mdot
.22125 .4675 Mdot
.0925 .465 Mdot
.5325 .48 Mdot
.505 .48 Mdot
.44625 .48875 Mdot
.48625 .4825 Mdot
.51 .49625 Mdot
.55625 .50875 Mdot
.4375 .52875 Mdot
.47875 .5525 Mdot
.50125 .4675 Mdot
.41125 .5 Mdot
.66125 .515 Mdot
.48875 .51625 Mdot
.505 .51625 Mdot
.47375 .56 Mdot
.5275 .54 Mdot
.46125 .52625 Mdot
.35 .5425 Mdot
.69 .53 Mdot
.77625 .49875 Mdot
.25875 .50875 Mdot
.4175 .52 Mdot
.51375 .52875 Mdot
.485 .52375 Mdot
.34375 .53125 Mdot
.76375 .5225 Mdot
.4675 .52875 Mdot
.50125 .51875 Mdot
.49125 .525 Mdot
.47125 .4875 Mdot
.4475 .49 Mdot
.32875 .475 Mdot
.67875 .47875 Mdot
.68 .4475 Mdot
.3025 .4875 Mdot
.52375 .48875 Mdot
.585 .45875 Mdot
.46875 .4325 Mdot
.45125 .43625 Mdot
.5725 .38875 Mdot
.51125 .3375 Mdot
.43 .3375 Mdot
.53 .3525 Mdot
.4525 .37125 Mdot
.46125 .425 Mdot
.3475 .4575 Mdot
.5325 .49125 Mdot
.13125 .5 Mdot
.44625 .48375 Mdot
.505 .495 Mdot
.4625 .50125 Mdot
.3925 .515 Mdot
.68 .5275 Mdot
.42625 .52125 Mdot
.6075 .5075 Mdot
.4675 .4925 Mdot
.4675 .4925 Mdot
.44875 .47375 Mdot
.4225 .47125 Mdot
.35375 .4375 Mdot
.11125 .39 Mdot
.4875 .405 Mdot
.4725 .385 Mdot
.51625 .42 Mdot
.38375 .44875 Mdot
.745 .46875 Mdot
.41875 .49875 Mdot
.47875 .505 Mdot
.39125 .50375 Mdot
.6875 .52125 Mdot
.4525 .5325 Mdot
.175 .525 Mdot
.82 .545 Mdot
.57125 .56625 Mdot
.41625 .5425 Mdot
.4825 .48875 Mdot
.42125 .455 Mdot
.48375 .46 Mdot
.56625 .455 Mdot
.61125 .47 Mdot
.46375 .49125 Mdot
.4275 .51875 Mdot
.52 .52 Mdot
.49125 .55875 Mdot
.41875 .6275 Mdot
.49875 .745 Mdot
.8575 .88 Mdot
.22875 .94125 Mdot
.49125 .875 Mdot
.445 .77125 Mdot
.66625 .655 Mdot
.27 .50375 Mdot
.68375 .42125 Mdot
.5875 .42625 Mdot
.365 .43375 Mdot
.5 .4125 Mdot
.46125 .3875 Mdot
.52875 .38125 Mdot
.2275 .3825 Mdot
.98125 .385 Mdot
.4375 .3925 Mdot
.33875 .40375 Mdot
.51375 .42125 Mdot
.4925 .4275 Mdot
.49125 .4425 Mdot
.35125 .47 Mdot
.8475 .48375 Mdot
.31625 .47875 Mdot
.505 .52375 Mdot
.50375 .49625 Mdot
.27 .4525 Mdot
.78375 .42375 Mdot
.72875 .4225 Mdot
.20875 .3875 Mdot
.49875 .41375 Mdot
.4875 .4425 Mdot
.4875 .445 Mdot
.51 .43125 Mdot
.415 .42125 Mdot
.71125 .3975 Mdot
.435 .3775 Mdot
.42875 .37125 Mdot
.53625 .37 Mdot
.47125 .38125 Mdot
.26 .41125 Mdot
.225 .475 Mdot
.51875 .50125 Mdot
.5 .5025 Mdot
.4575 .49375 Mdot
.5025 .495 Mdot
.435 .485 Mdot
.68 .4775 Mdot
.40875 .4575 Mdot
.4425 .47625 Mdot
.495 .00125 Mdot
.49375 .00625 Mdot
.37875 .0475 Mdot
.61125 .025 Mdot
.51 .03625 Mdot
.41375 .07625 Mdot
.46 .04875 Mdot
.585 .08 Mdot
.6475 .14875 Mdot
.47125 .17625 Mdot
.3625 .15875 Mdot
.4975 .14625 Mdot
.4875 .10625 Mdot
.20125 .0575 Mdot
.975 .0025 Mdot
.45375 .01625 Mdot
.39 .0475 Mdot
.645 .07875 Mdot
.58375 .15125 Mdot
.40875 .135 Mdot
.485 .14875 Mdot
.5475 .14625 Mdot
.5225 .1325 Mdot
.35375 .06875 Mdot
.70375 .02 Mdot
.4575 .0775 Mdot
.385 .0675 Mdot
.55375 .0425 Mdot
.93125 .0675 Mdot
.2375 .02375 Mdot
.37125 .03375 Mdot
.95625 .0775 Mdot
.24875 .09 Mdot
.635 .0225 Mdot
.45625 .05125 Mdot
.28625 .005 Mdot
.4575 .05875 Mdot
.44875 .10125 Mdot
.51375 .10375 Mdot
.73625 .04125 Mdot
.41875 .00875 Mdot
.64125 .01375 Mdot
.15375 .07375 Mdot
.875 .02375 Mdot
.4875 .05625 Mdot
.4525 .215 Mdot
.545 .2525 Mdot
.32625 .265 Mdot
.8325 .2625 Mdot
.44 .24125 Mdot
.38875 .12875 Mdot
.51 .0725 Mdot
.48625 .01875 Mdot
.51875 .005 Mdot
.50625 .07875 Mdot
.33625 .06 Mdot
.69375 .03625 Mdot
.54625 .055 Mdot
.49125 .10875 Mdot
.33 .13375 Mdot
.8625 .1575 Mdot
.30375 .155 Mdot
.52375 .04125 Mdot
.5025 .02375 Mdot
.4675 .00125 Mdot
.36 .00875 Mdot
.8075 .03125 Mdot
.36375 .0425 Mdot
.4375 .01375 Mdot
.515 .065 Mdot
.18875 .07375 Mdot
.9525 .09 Mdot
.525 .1325 Mdot
.155 .04625 Mdot
.26375 .06 Mdot
.485 .17375 Mdot
.49125 .2225 Mdot
.4375 .0775 Mdot
.50625 .07875 Mdot
.12625 .1125 Mdot
.48625 .1625 Mdot
.31 .07625 Mdot
.455 .11375 Mdot
.47125 .1725 Mdot
.095 .2275 Mdot
.50875 .26125 Mdot
.3575 .1425 Mdot
.52 .04875 Mdot
.44125 .01125 Mdot
.54625 .0475 Mdot
.49875 .05 Mdot
.4625 .105 Mdot
.515 .11 Mdot
.2075 .0825 Mdot
.255 .065 Mdot
.41875 .08 Mdot
.53625 .455 Mdot
.165 .44125 Mdot
.95625 .4725 Mdot
.53625 .505 Mdot
.12125 .55375 Mdot
.91125 .59125 Mdot
.38 .63 Mdot
.4025 .61125 Mdot
.62125 .6425 Mdot
.335 .6275 Mdot
.4675 .59875 Mdot
.8375 .57875 Mdot
.2575 .59 Mdot
.50625 .56375 Mdot
.49125 .54625 Mdot
.45375 .59375 Mdot
.375 .595 Mdot
.56 .63125 Mdot
.39375 .63125 Mdot
.49 .59375 Mdot
.47875 .5825 Mdot
.4775 .565 Mdot
.555 .55375 Mdot
.52625 .5425 Mdot
.47125 .5225 Mdot
.5125 .47 Mdot
.46875 .415 Mdot
.115 .37875 Mdot
.48 .38625 Mdot
.2625 .42125 Mdot
.50375 .46375 Mdot
.46625 .47375 Mdot
.545 .47625 Mdot
.4325 .47125 Mdot
.55125 .46875 Mdot
.4925 .465 Mdot
.51 .47 Mdot
.5525 .45 Mdot
.465 .41 Mdot
.4525 .38875 Mdot
.06875 .36375 Mdot
.51 .37875 Mdot
.3475 .40625 Mdot
.50125 .4025 Mdot
.4575 .4 Mdot
.4725 .39875 Mdot
.5025 .41 Mdot
.50375 .43875 Mdot
.5075 .49125 Mdot
.5075 .53375 Mdot
.515 .56125 Mdot
.48625 .56875 Mdot
.4675 .5425 Mdot
.1625 .5125 Mdot
.1375 .4525 Mdot
.42875 .435 Mdot
.46875 .44875 Mdot
.5825 .4525 Mdot
.41625 .465 Mdot
.4725 .47 Mdot
.525 .45875 Mdot
.50125 .4625 Mdot
.505 .4675 Mdot
.54125 .4925 Mdot
.48375 .4925 Mdot
.39375 .50125 Mdot
.325 .49625 Mdot
.1675 .45125 Mdot
.53 .44875 Mdot
.52875 .45375 Mdot
.445 .4475 Mdot
.54 .4525 Mdot
.49125 .465 Mdot
.44125 .475 Mdot
.51375 .47375 Mdot
.50875 .48375 Mdot
.5175 .48625 Mdot
.48875 .46625 Mdot
.0075 .46125 Mdot
.535 .44 Mdot
.2125 .45125 Mdot
.4925 .47875 Mdot
.46 .4725 Mdot
.535 .49 Mdot
.52125 .49 Mdot
.495 .4775 Mdot
.52 .45375 Mdot
.445 .45375 Mdot
.5175 .45 Mdot
.4975 .4525 Mdot
.41875 .47 Mdot
.08625 .50125 Mdot
.51375 .54 Mdot
.5275 .55125 Mdot
.46625 .5525 Mdot
.42 .54125 Mdot
.57625 .505 Mdot
.51 .485 Mdot
.51 .45625 Mdot
.48875 .435 Mdot
.5375 .435 Mdot
.445 .445 Mdot
.16 .45625 Mdot
.17625 .4825 Mdot
.42625 .48125 Mdot
.5425 .49375 Mdot
.48 .485 Mdot
.4675 .48 Mdot
.56375 .48125 Mdot
.4575 .4775 Mdot
.53125 .46875 Mdot
.50625 .46875 Mdot
.47125 .45625 Mdot
.49125 .43625 Mdot
.21625 .4425 Mdot
.3375 .445 Mdot
.36125 .4375 Mdot
.5425 .5475 Mdot
.24375 .555 Mdot
.825 .5875 Mdot
.55125 .59375 Mdot
.185 .5775 Mdot
.86875 .6025 Mdot
.365 .60375 Mdot
.4375 .58375 Mdot
.60125 .6025 Mdot
.23375 .61375 Mdot
.64375 .6025 Mdot
.78125 .59625 Mdot
.27125 .555 Mdot
.4825 .53 Mdot
.50375 .525 Mdot
.1075 .52125 Mdot
.495 .55375 Mdot
.3725 .5575 Mdot
.57625 .5575 Mdot
.395 .56375 Mdot
.50125 .57875 Mdot
.4775 .60375 Mdot
.4 .6 Mdot
.7575 .585 Mdot
.425 .5725 Mdot
.44625 .5275 Mdot
.5325 .49375 Mdot
.46125 .52 Mdot
.22125 .53375 Mdot
.98625 .52875 Mdot
.48 .5275 Mdot
.32125 .5325 Mdot
.49125 .50875 Mdot
.47125 .51875 Mdot
.5525 .51875 Mdot
.4275 .5225 Mdot
.44375 .54375 Mdot
.655 .535 Mdot
.51 .51125 Mdot
.5075 .51125 Mdot
.4425 .5325 Mdot
.4775 .53125 Mdot
.1675 .51375 Mdot
.98 .51125 Mdot
.525 .4975 Mdot
.38125 .47375 Mdot
.4975 .49125 Mdot
.46375 .53125 Mdot
.4725 .54875 Mdot
.52375 .565 Mdot
.39875 .57 Mdot
.67125 .5275 Mdot
.43375 .5075 Mdot
.51125 .4775 Mdot
.505 .47125 Mdot
.46 .4525 Mdot
.26125 .4525 Mdot
.23 .465 Mdot
.44125 .455 Mdot
.47 .45875 Mdot
.56375 .4675 Mdot
.435 .455 Mdot
.4425 .4575 Mdot
.5475 .46 Mdot
.55375 .465 Mdot
.44375 .45875 Mdot
.5575 .43875 Mdot
.49 .44125 Mdot
.4175 .47 Mdot
.35 .46875 Mdot
.95 .465 Mdot
.235 .495 Mdot
.5675 .51 Mdot
.50125 .475 Mdot
.43875 .47125 Mdot
.4575 .47375 Mdot
.61875 .46375 Mdot
.43875 .44875 Mdot
.4725 .45875 Mdot
.5125 .45125 Mdot
.52625 .44 Mdot
.48625 .42 Mdot
.14875 .395 Mdot
.46625 .3625 Mdot
.315 .36 Mdot
.49125 .3725 Mdot
.4775 .385 Mdot
.46375 .37375 Mdot
.545 .36 Mdot
.58375 .34625 Mdot
.47375 .3475 Mdot
.4525 .35625 Mdot
.50625 .36375 Mdot
.47625 .39875 Mdot
.46375 .39 Mdot
.16625 .36125 Mdot
.16 .355 Mdot
.49125 .34375 Mdot
.5175 .365 Mdot
.52125 .3875 Mdot
.29125 .4175 Mdot
.74125 .44375 Mdot
.38875 .43875 Mdot
.59875 .44625 Mdot
.48375 .4625 Mdot
.525 .4875 Mdot
.4275 .4675 Mdot
.1825 .46625 Mdot
.21875 .475 Mdot
.46875 .45375 Mdot
.54375 .44125 Mdot
.4575 .44 Mdot
.3875 .42125 Mdot
.68375 .4075 Mdot
.46375 .385 Mdot
.495 .37625 Mdot
.49375 .37 Mdot
.4775 .3725 Mdot
.47875 .37 Mdot
.28125 .40625 Mdot
.91125 .45125 Mdot
.4175 .47625 Mdot
.36625 .5225 Mdot
.55875 .08375 Mdot
.3225 .0825 Mdot
.71375 .08875 Mdot
.55625 .04375 Mdot
.49125 .0275 Mdot
.24625 .0475 Mdot
.84125 .04125 Mdot
.5725 .015 Mdot
.31875 .005 Mdot
.4275 .085 Mdot
.53375 .21375 Mdot
.43875 .2325 Mdot
.33625 .2275 Mdot
.85125 .22875 Mdot
.47875 .22125 Mdot
.36625 .14 Mdot
.48125 .1075 Mdot
.465 .085 Mdot
.5675 .0925 Mdot
.435 .09625 Mdot
.3525 .07 Mdot
.84 .08625 Mdot
.40125 .10375 Mdot
.5175 .085 Mdot
.44 .09 Mdot
.4825 .13875 Mdot
.26 .16125 Mdot
.8325 .165 Mdot
.52625 .17625 Mdot
.41125 .15625 Mdot
.51125 .12 Mdot
.44375 .12125 Mdot
.5075 .13875 Mdot
.5475 .16 Mdot
.25 .1725 Mdot
.905 .18375 Mdot
.3175 .145 Mdot
.51125 .1475 Mdot
.49625 .1625 Mdot
.4925 .1375 Mdot
.33625 .09 Mdot
.87625 .04625 Mdot
.37875 .05 Mdot
.82375 .0925 Mdot
.29125 .10625 Mdot
.575 .05125 Mdot
.49375 .0625 Mdot
.45125 .03875 Mdot
.33125 .00625 Mdot
.83125 .01 Mdot
.36375 .0075 Mdot
.51125 .01625 Mdot
.5 .015 Mdot
.89375 .00125 Mdot
.47 .00375 Mdot
.495 .03125 Mdot
.45625 .1225 Mdot
.5275 .16125 Mdot
.2125 .1925 Mdot
.2975 .10375 Mdot
.75625 0 Mdot
.345 .02 Mdot
.785 .03375 Mdot
.49125 .0525 Mdot
.33875 .03 Mdot
.56625 .28125 Mdot
.46625 .31625 Mdot
.51625 .3575 Mdot
.53125 .4 Mdot
.49875 .44 Mdot
.505 .4625 Mdot
.4625 .43375 Mdot
.49875 .46625 Mdot
.55125 .5525 Mdot
.0375 .58375 Mdot
.35125 .61625 Mdot
.4 .54875 Mdot
.49125 .365 Mdot
.45625 .27 Mdot
.4725 .245 Mdot
.5375 .2125 Mdot
.59 .215 Mdot
.47625 .2825 Mdot
.41125 .34 Mdot
.45125 .35375 Mdot
.56 .41125 Mdot
.515 .3825 Mdot
.135 .3575 Mdot
.14 .2975 Mdot
.40875 .1525 Mdot
.49625 .04625 Mdot
.4475 .01 Mdot
.51875 .04375 Mdot
.5 .15625 Mdot
.35625 .17625 Mdot
.47625 .17625 Mdot
.62 .31625 Mdot
.43875 .42875 Mdot
.25125 .44625 Mdot
.20375 .50125 Mdot
.4975 .4275 Mdot
.44375 .325 Mdot
.48 .3375 Mdot
.45125 .41125 Mdot
.5625 .4425 Mdot
.4675 .44375 Mdot
.49875 .47875 Mdot
.5825 .49375 Mdot
.4475 .4625 Mdot
.5425 .485 Mdot
.515 .4725 Mdot
0 .465 Mdot
.08125 .43125 Mdot
.4775 .365 Mdot
.4925 .2975 Mdot
.56125 .23 Mdot
.45 .12625 Mdot
.505 .05625 Mdot
.42875 .00875 Mdot
.285 .065 Mdot
.41375 .03875 Mdot
.505 .03125 Mdot
.6475 .145 Mdot
.3 .23875 Mdot
.56625 .315 Mdot
.4775 .2675 Mdot
.48875 .22 Mdot
.5225 .19125 Mdot
.53375 .16625 Mdot
.485 .1475 Mdot
.4375 .15625 Mdot
.525 .21375 Mdot
.56625 .15125 Mdot
.3625 .13875 Mdot
.39625 .0975 Mdot
.48625 .17625 Mdot
.4625 .215 Mdot
.5025 .22375 Mdot
.47875 .24 Mdot
.57125 .22875 Mdot
.52 .215 Mdot
.4125 .19 Mdot
.415 .20375 Mdot
.58 .24875 Mdot
.54375 .29 Mdot
.08625 .3125 Mdot
.0825 .3575 Mdot
.42625 .33125 Mdot
.48 .30875 Mdot
.48875 .28625 Mdot
.53375 .275 Mdot
.47125 .29125 Mdot
.55125 .28875 Mdot
.53 .29625 Mdot
.33625 .33125 Mdot
.48 .33625 Mdot
.61625 .3025 Mdot
.4425 .2475 Mdot
.25125 .27875 Mdot
.1525 .29 Mdot
.48125 .28375 Mdot
.465 .32 Mdot
.47125 .28 Mdot
.4775 .23 Mdot
.5 .21 Mdot
.49375 .235 Mdot
.485 .2875 Mdot
.60625 .33375 Mdot
.45125 .37 Mdot
.54375 .41625 Mdot
.49375 .43875 Mdot
.485 .41 Mdot
.48625 .3725 Mdot
.555 .34375 Mdot
.475 .345 Mdot
.4775 .3375 Mdot
.56625 .35625 Mdot
.4075 .38875 Mdot
.62875 .425 Mdot
.4175 .42875 Mdot
.42375 .49625 Mdot
.395 .55125 Mdot
.56625 .57125 Mdot
.8525 .58375 Mdot
.2375 .6075 Mdot
.55 .5425 Mdot
.49 .4925 Mdot
.46875 .45625 Mdot
.55 .43 Mdot
.46625 .41625 Mdot
.53 .435 Mdot
.53625 .455 Mdot
.45375 .54625 Mdot
.3875 .53625 Mdot
.24 .52375 Mdot
.37375 .5025 Mdot
.36375 .435 Mdot
.51625 .43 Mdot
.46875 .425 Mdot
.53625 .4125 Mdot
.50125 .40875 Mdot
.445 .40125 Mdot
.54 .40875 Mdot
.5475 .42875 Mdot
.4075 .4475 Mdot
.51625 .49 Mdot
.345 .4875 Mdot
.51875 .505 Mdot
.9575 .5175 Mdot
.185 .5 Mdot
.6175 .535 Mdot
.395 .56 Mdot
.4625 .5975 Mdot
.54125 .61 Mdot
.38875 .64125 Mdot
.625 .6075 Mdot
.53375 .62 Mdot
.43875 .60125 Mdot
.475 .53625 Mdot
.6075 .45625 Mdot
.245 .37125 Mdot
.845 .3875 Mdot
.27375 .43375 Mdot
.4775 .37 Mdot
.425 .41875 Mdot
.36375 .4475 Mdot
.745 .51125 Mdot
.41625 .55375 Mdot
.67 .5625 Mdot
.49875 .515 Mdot
.4075 .52375 Mdot
.12375 .48 Mdot
.995 .4525 Mdot
.48125 .4675 Mdot
.43 .50875 Mdot
.4125 .49125 Mdot
.5275 .4825 Mdot
.54 .44 Mdot
.43625 .40625 Mdot
.49875 .37375 Mdot
.63 .35 Mdot
.32 .32 Mdot
.55375 .51125 Mdot
.49375 .54625 Mdot
.4575 .56 Mdot
.595 .5525 Mdot
.5575 .55625 Mdot
.39 .57375 Mdot
.485 .58875 Mdot
.5125 .58875 Mdot
.55 .65125 Mdot
.135 .67875 Mdot
.32875 .61 Mdot
.42875 .6075 Mdot
.5125 .56375 Mdot
.445 .54625 Mdot
.5025 .54 Mdot
.48625 .545 Mdot
.57125 .5475 Mdot
.58 .515 Mdot
.3475 .49625 Mdot
.42625 .5 Mdot
.57875 .50125 Mdot
.55125 .5075 Mdot
.16875 .54375 Mdot
.18125 .5675 Mdot
.4575 .59875 Mdot
.4375 .63625 Mdot
.50375 .655 Mdot
.52375 .65875 Mdot
.45125 .665 Mdot
.63375 .68375 Mdot
.495 .6625 Mdot
.32625 .62875 Mdot
.49625 .6025 Mdot
.58875 .58875 Mdot
.475 .53875 Mdot
.34 .4625 Mdot
.17125 .4125 Mdot
.50625 .3925 Mdot
.4775 .36875 Mdot
.49625 .4 Mdot
.44875 .41125 Mdot
.47375 .46 Mdot
.58875 .47875 Mdot
.415 .52125 Mdot
.60375 .5225 Mdot
.43375 .505 Mdot
.57125 .50375 Mdot
.50625 .47375 Mdot
.06625 .425 Mdot
.0825 .39 Mdot
.51125 .3525 Mdot
.46125 .38 Mdot
.56875 .43625 Mdot
.40875 .51375 Mdot
.54375 .57875 Mdot
.6075 .59125 Mdot
.37625 .5725 Mdot
.60125 .5375 Mdot
.435 .5075 Mdot
.42375 .44125 Mdot
.41875 .365 Mdot
.55 .3225 Mdot
.78375 .255 Mdot
.2925 .18875 Mdot
.5475 .1925 Mdot
.48875 .2425 Mdot
.47875 .29 Mdot
.46125 .3225 Mdot
.59875 .35625 Mdot
.5175 .35 Mdot
.49875 .31125 Mdot
.45 .2725 Mdot
.4075 .2675 Mdot
.32625 .28125 Mdot
.97 .28125 Mdot
.3825 .33 Mdot
.41125 .37125 Mdot
.485 .42125 Mdot
.4825 .43625 Mdot
.54375 .4675 Mdot
.46625 .4675 Mdot
.38625 .48125 Mdot
.72 .47 Mdot
.46375 .45875 Mdot
.42125 .4375 Mdot
.47625 .45625 Mdot
.41875 .45 Mdot
.515 .4425 Mdot
.835 .45125 Mdot
.2525 .54 Mdot
.595 .5025 Mdot
.41625 .50625 Mdot
.47875 .55625 Mdot
.5175 .54125 Mdot
.30375 .4675 Mdot
.79875 .49125 Mdot
.46375 .485 Mdot
.45125 .4525 Mdot
.48625 .4975 Mdot
.5425 .58125 Mdot
.12375 .60375 Mdot
.95625 .64 Mdot
.35875 .66875 Mdot
.74625 .675 Mdot
.2825 .5725 Mdot
.48875 .56375 Mdot
.44875 .525 Mdot
.35875 .51875 Mdot
.755 .4875 Mdot
.445 .48 Mdot
.6125 .44625 Mdot
.4825 .4425 Mdot
.4425 .395 Mdot
.1675 .44375 Mdot
.925 .50125 Mdot
.51125 .53375 Mdot
.43875 .5225 Mdot
.39375 .55375 Mdot
.535 .51125 Mdot
.5525 .48875 Mdot
.4275 .4775 Mdot
.47625 .50125 Mdot
.63875 .5 Mdot
.32375 .4975 Mdot
.5375 .1325 Mdot
.4775 .14125 Mdot
.34 .1525 Mdot
.75375 .16625 Mdot
.595 .1725 Mdot
.2475 .19125 Mdot
.565 .19375 Mdot
.57 .23875 Mdot
.48875 .22125 Mdot
.27375 .20625 Mdot
.85625 .21375 Mdot
.42375 .21875 Mdot
.42 .17875 Mdot
.52625 .19625 Mdot
.4525 .195 Mdot
.50125 .185 Mdot
.455 .15 Mdot
.64 .1475 Mdot
.605 .18125 Mdot
.28625 .24 Mdot
.44375 .245 Mdot
.56 .3075 Mdot
.56625 .3 Mdot
.26 .255 Mdot
.98125 .19875 Mdot
.27375 .2125 Mdot
.49125 .215 Mdot
.42 .25625 Mdot
.5175 .30375 Mdot
.50625 .34125 Mdot
.36125 .29375 Mdot
.78 .24375 Mdot
.4625 .2475 Mdot
.31375 .25625 Mdot
.505 .29 Mdot
.57375 .38875 Mdot
.48375 .42125 Mdot
.415 .41625 Mdot
.875 .38 Mdot
.29 .33375 Mdot
.48875 .27375 Mdot
.4775 .255 Mdot
.5075 .2175 Mdot
.4525 .245 Mdot
.4325 .2325 Mdot
.705 .215 Mdot
.34125 .15375 Mdot
.59125 .12125 Mdot
.46875 .07875 Mdot
.53125 .07875 Mdot
.4825 .0925 Mdot
.22 .145 Mdot
.1925 .25625 Mdot
.515 .275 Mdot
.4675 .27625 Mdot
.54875 .27375 Mdot
.34875 .21875 Mdot
.61875 .15375 Mdot
.6825 .14375 Mdot
.305 .155 Mdot
.5775 .13625 Mdot
.45125 .17 Mdot
.4375 .23625 Mdot
.44375 .3125 Mdot
.5575 .3725 Mdot
.67 .46625 Mdot
.36 .50375 Mdot
.54125 .5 Mdot
.485 .4575 Mdot
.49 .43375 Mdot
.32625 .425 Mdot
.80875 .40125 Mdot
.5 .3825 Mdot
.435 .37125 Mdot
.46 .34875 Mdot
.40625 .2725 Mdot
.44 .2325 Mdot
.755 .22625 Mdot
.46625 .17625 Mdot
.44125 .08875 Mdot
.44125 .0525 Mdot
.52 .02 Mdot
.4 .00375 Mdot
.4725 .08625 Mdot
.325 .155 Mdot
.8275 .19 Mdot
.44 .14375 Mdot
.55375 .11 Mdot
.43125 .1775 Mdot
.495 .1775 Mdot
.26375 .1225 Mdot
.825 .05625 Mdot
.46625 .00625 Mdot
.73125 .04375 Mdot
.2825 .09625 Mdot
.5275 .6275 Mdot
.47 .56 Mdot
.22625 .56375 Mdot
.90875 .5625 Mdot
.60375 .62 Mdot
.1175 .69125 Mdot
.68 .72125 Mdot
.6075 .72375 Mdot
.41625 .80375 Mdot
.3825 .81375 Mdot
.6875 .8375 Mdot
.45875 .8925 Mdot
.44 .91125 Mdot
.51125 .87875 Mdot
.49625 .87 Mdot
.48125 .88125 Mdot
.4175 .95375 Mdot
.73375 .99375 Mdot
.375 .9675 Mdot
.50625 .8925 Mdot
.40625 .83625 Mdot
.5675 .74125 Mdot
.4725 .69125 Mdot
.26625 .71375 Mdot
.88125 .72375 Mdot
.45 .73375 Mdot
.35375 .8 Mdot
.44625 .84625 Mdot
.60375 .83 Mdot
.46875 .84125 Mdot
.47625 .85875 Mdot
.71125 .87625 Mdot
.3675 .85375 Mdot
.52 .865 Mdot
.4875 .90625 Mdot
.5 .92 Mdot
.46125 .9125 Mdot
.41125 .9475 Mdot
.80875 .97 Mdot
.29375 .9525 Mdot
.51875 .965 Mdot
.3825 .99 Mdot
.76875 .9325 Mdot
.31875 .85 Mdot
.535 .78 Mdot
.48 .76125 Mdot
.53375 .73125 Mdot
.27125 .765 Mdot
.72 .84625 Mdot
.7275 .865 Mdot
.24375 .9275 Mdot
.5025 .96375 Mdot
.1925 .92125 Mdot
.44625 .86625 Mdot
.23 .805 Mdot
.6375 .92 Mdot
.79625 .81875 Mdot
.63 .75625 Mdot
.335 .69 Mdot
.49 .725 Mdot
.53125 .7025 Mdot
.48125 .645 Mdot
.50375 .66375 Mdot
.48125 .69625 Mdot
.5075 .66875 Mdot
.48 .69 Mdot
.3525 .675 Mdot
.87375 .6875 Mdot
.55125 .6875 Mdot
.235 .70875 Mdot
.4525 .69625 Mdot
.54375 .66625 Mdot
.53125 .6775 Mdot
.44625 .69875 Mdot
.58 .70625 Mdot
.4575 .7275 Mdot
.5375 .795 Mdot
.41375 .8075 Mdot
.60125 .82 Mdot
.43125 .81125 Mdot
.2175 .7725 Mdot
.92375 .74125 Mdot
.45125 .6725 Mdot
.38875 .59625 Mdot
.43125 .51875 Mdot
.605 .43 Mdot
.48125 .39 Mdot
.51375 .38125 Mdot
.555 .3875 Mdot
.45625 .45125 Mdot
.51125 .5225 Mdot
.48125 .5475 Mdot
.5025 .58875 Mdot
.48375 .62875 Mdot
.375 .62 Mdot
.9275 .63875 Mdot
.2175 .735 Mdot
.49 .8125 Mdot
.5125 .8225 Mdot
.51 .7775 Mdot
.5025 .83875 Mdot
.4625 .8325 Mdot
.55625 .825 Mdot
.4175 .86125 Mdot
.5575 .9575 Mdot
.49125 .965 Mdot
.52375 .94 Mdot
.1925 .89875 Mdot
.81 .81625 Mdot
.76 .78 Mdot
.205 .70125 Mdot
.5275 .6125 Mdot
.4575 .54 Mdot
.4725 .50625 Mdot
.53625 .48 Mdot
.495 .5 Mdot
.52375 .52875 Mdot
.5 .53125 Mdot
.49 .56125 Mdot
.48625 .60375 Mdot
.50875 .62125 Mdot
.05875 .65125 Mdot
.445 .7025 Mdot
.39875 .6 Mdot
.43125 .455 Mdot
.43625 .31375 Mdot
.5375 .2625 Mdot
.5175 .2 Mdot
.55625 .24 Mdot
.455 .3 Mdot
.3275 .35125 Mdot
.69125 .355 Mdot
.48125 .45875 Mdot
.365 .43125 Mdot
.42 .4325 Mdot
.2 .34375 Mdot
.44375 .1575 Mdot
.47625 .0325 Mdot
.1575 .0325 Mdot
.11375 .09 Mdot
.4925 .0075 Mdot
.4775 .045 Mdot
.47875 .15 Mdot
.48 .14 Mdot
.625 .12125 Mdot
.39375 .075 Mdot
.55875 .0325 Mdot
.29125 .26625 Mdot
.485 .535 Mdot
.9325 .81875 Mdot
.1025 .0225 Mdot
.635 .26875 Mdot
.88625 .2225 Mdot
.5675 .22125 Mdot
.3475 .19625 Mdot
.565 .1275 Mdot
.41625 .13375 Mdot
.48375 .15625 Mdot
.5675 .1925 Mdot
.45875 .2075 Mdot
.49375 .2625 Mdot
.4675 .25375 Mdot
.34625 .23 Mdot
.94875 .18 Mdot
.58 .115 Mdot
.15375 .0275 Mdot
.4325 .01 Mdot
.57625 .08125 Mdot
.4475 .1275 Mdot
.215 .20375 Mdot
.915 .28125 Mdot
.5325 .3375 Mdot
.32875 .3575 Mdot
.44875 .3925 Mdot
.61125 .41625 Mdot
.475 .4225 Mdot
.54 .4375 Mdot
.4475 .4075 Mdot
.51875 .3825 Mdot
.53 .34375 Mdot
.43875 .2875 Mdot
.52875 .27125 Mdot
.50375 .23625 Mdot
.31125 .23 Mdot
.20625 .175 Mdot
.45625 .09625 Mdot
.53875 .0775 Mdot
.49625 .04875 Mdot
.4925 .02125 Mdot
.52375 .0325 Mdot
.425 .05875 Mdot
.48625 .0575 Mdot
.54 .0375 Mdot
.5125 .03375 Mdot
.54875 .085 Mdot
.14125 .11 Mdot
.845 .145 Mdot
.79125 .1725 Mdot
.18375 .195 Mdot
.47875 .18875 Mdot
.4975 .1925 Mdot
.4875 .18875 Mdot
.535 .18625 Mdot
.46625 .16875 Mdot
.4975 .15125 Mdot
.5575 .155 Mdot
.49 .14375 Mdot
.47125 .1975 Mdot
.48875 .2275 Mdot
.47375 .215 Mdot
.37625 .17125 Mdot
.44375 .17125 Mdot
.4775 .2225 Mdot
.48 .24375 Mdot
.5275 .2725 Mdot
.49 .27875 Mdot
.4775 .3 Mdot
.3225 .31125 Mdot
.755 .30875 Mdot
.4225 .2975 Mdot
.3725 .3175 Mdot
.49125 .30375 Mdot
.155 .35375 Mdot
.475 .38875 Mdot
.49375 .42 Mdot
.525 .45 Mdot
.49375 .42625 Mdot
.4625 .42375 Mdot
.4625 .4375 Mdot
.5775 .4125 Mdot
.53125 .37875 Mdot
.38875 .4 Mdot
.4475 .36 Mdot
.155 .32875 Mdot
.0775 .34375 Mdot
.49625 .34 Mdot
.44875 .39875 Mdot
.46875 .43625 Mdot
.5275 .455 Mdot
.49375 .4675 Mdot
.47625 .48875 Mdot
.5 .48875 Mdot
.5 .4625 Mdot
.4925 .47625 Mdot
.46 .465 Mdot
.2575 .4325 Mdot
.455 .46125 Mdot
.325 .4325 Mdot
.52125 .37125 Mdot
.45875 .34625 Mdot
.48875 .36875 Mdot
.6175 .335 Mdot
.375 .36375 Mdot
.55125 .48125 Mdot
.575 .53125 Mdot
.45875 .525 Mdot
.52875 .50625 Mdot
.2875 .4175 Mdot
.5225 .2725 Mdot
.96375 .12625 Mdot
.54 .44125 Mdot
.5825 .4375 Mdot
.085 .4475 Mdot
.98375 .4625 Mdot
.60875 .4925 Mdot
.02 .51625 Mdot
.7975 .55375 Mdot
.63125 .5675 Mdot
.41375 .5825 Mdot
.4775 .5825 Mdot
.41375 .5625 Mdot
.51125 .56 Mdot
.53875 .545 Mdot
.44875 .53375 Mdot
.5075 .525 Mdot
.58 .51 Mdot
.2825 .49125 Mdot
.93375 .47875 Mdot
.5025 .45125 Mdot
.23 .45125 Mdot
.42875 .46125 Mdot
.51 .46625 Mdot
.595 .49625 Mdot
.47125 .5 Mdot
.48375 .495 Mdot
.5025 .5 Mdot
.5275 .48375 Mdot
.4175 .455 Mdot
.55 .4675 Mdot
.56 .47625 Mdot
.19875 .475 Mdot
.82375 .46875 Mdot
.5575 .5075 Mdot
.35375 .49375 Mdot
.40625 .5125 Mdot
.605 .565 Mdot
.565 .65125 Mdot
.50625 .7225 Mdot
.435 .8375 Mdot
.51125 .87875 Mdot
.53625 .87875 Mdot
.36625 .85 Mdot
.55 .76375 Mdot
.62125 .66125 Mdot
.2725 .57125 Mdot
.9375 .50125 Mdot
.2475 .45875 Mdot
.4475 .4425 Mdot
.50875 .44 Mdot
.5475 .45 Mdot
.50875 .45 Mdot
.49 .44375 Mdot
.46625 .42125 Mdot
.44375 .40375 Mdot
.5325 .41 Mdot
.4275 .4325 Mdot
.635 .44125 Mdot
.235 .46 Mdot
.75125 .475 Mdot
.76 .47375 Mdot
.21 .465 Mdot
.4325 .45625 Mdot
.56625 .45625 Mdot
.55625 .45375 Mdot
.47375 .45 Mdot
.4275 .46 Mdot
.53125 .46875 Mdot
.56 .4725 Mdot
.4325 .49 Mdot
.52125 .49375 Mdot
.5225 .45625 Mdot
.02625 .455 Mdot
.48125 .4375 Mdot
.35375 .44 Mdot
.46875 .48375 Mdot
.5475 .485 Mdot
.47 .49625 Mdot
.505 .49875 Mdot
.5025 .50375 Mdot
.46625 .46 Mdot
.25 .41 Mdot
.8625 .425 Mdot
.43375 .445 Mdot
.36 .4625 Mdot
.5475 .515 Mdot
.82 .57375 Mdot
.2325 .55875 Mdot
.42125 .53125 Mdot
.68 .52375 Mdot
.4525 .495 Mdot
.45 .4825 Mdot
.4975 .4525 Mdot
.44375 .42125 Mdot
.50875 .3825 Mdot
.59375 .44625 Mdot
.45625 .5025 Mdot
.4275 .54375 Mdot
.25 .5775 Mdot
.08125 .54875 Mdot
.455 .48125 Mdot
.61 .44875 Mdot
.465 .435 Mdot
.4625 .44 Mdot
.4925 .45875 Mdot
.5525 .4625 Mdot
.435 .49 Mdot
.44125 .51375 Mdot
.6675 .49375 Mdot
.3925 .49625 Mdot
.29375 .50625 Mdot
.9275 .4825 Mdot
.415 .43375 Mdot
.32 .4475 Mdot
.565 .44125 Mdot
.54875 .4175 Mdot
.45375 .40875 Mdot
.57 .47 Mdot
.3575 .49125 Mdot
.56625 .45125 Mdot
.51375 .46125 Mdot
.5775 .47625 Mdot
.50875 .45375 Mdot
.2875 .4225 Mdot
.55125 .44875 Mdot
.83875 .45625 Mdot
.1425 .44375 Mdot
.61625 .23125 Mdot
.7325 .3175 Mdot
.0725 .37375 Mdot
.82125 .49 Mdot
.59875 .54875 Mdot
.17375 .49375 Mdot
.59625 .4275 Mdot
.7125 .43875 Mdot
.535 .39 Mdot
.39125 .36625 Mdot
.43375 .41375 Mdot
.48625 .4275 Mdot
.52875 .40375 Mdot
.3575 .38625 Mdot
.57 .3925 Mdot
.79875 .365 Mdot
.1475 .35625 Mdot
.83625 .37 Mdot
.49125 .43 Mdot
.29625 .4275 Mdot
.35 .445 Mdot
.47125 .4275 Mdot
.865 .39875 Mdot
.33625 .3875 Mdot
.455 .37625 Mdot
.51625 .38625 Mdot
.52 .36875 Mdot
.3825 .33375 Mdot
.50125 .2625 Mdot
.75375 .20125 Mdot
.19375 .15125 Mdot
.6625 .1475 Mdot
.62125 .17 Mdot
.35875 .20375 Mdot
.3575 .215 Mdot
.63625 .19 Mdot
.655 .12875 Mdot
.44 .03375 Mdot
.56625 .07 Mdot
.80625 .1275 Mdot
.17625 .1725 Mdot
.82125 .1775 Mdot
.35125 .175 Mdot
.42625 .18875 Mdot
.39875 .185 Mdot
.66625 .18625 Mdot
.5875 .2175 Mdot
.4025 .24625 Mdot
.47875 .27 Mdot
.43625 .3 Mdot
.4975 .30875 Mdot
.3525 .325 Mdot
.8125 .32125 Mdot
.24875 .3025 Mdot
.675 .295 Mdot
.6825 .28375 Mdot
.2575 .2525 Mdot
.44375 .2325 Mdot
.5275 .22125 Mdot
.715 .2025 Mdot
.36125 .2075 Mdot
.44 .17375 Mdot
.525 .15875 Mdot
.51125 .15125 Mdot
.4325 .1475 Mdot
.5925 .20625 Mdot
.55 .295 Mdot
.09125 .34125 Mdot
.9325 .345 Mdot
.54 .35625 Mdot
.3925 .325 Mdot
.34625 .2775 Mdot
.77875 .255 Mdot
.35625 .2575 Mdot
.50125 .25625 Mdot
.52375 .28 Mdot
.44375 .30125 Mdot
.19375 .33125 Mdot
.96375 .32375 Mdot
.435 .32375 Mdot
.36125 .22 Mdot
.5625 .14 Mdot
.68 .0525 Mdot
.2825 .025 Mdot
.8975 .0275 Mdot
.37 .065 Mdot
.425 .17 Mdot
.485 .25875 Mdot
.45625 .33125 Mdot
.41375 .4125 Mdot
.72125 .4275 Mdot
.495 .36 Mdot
.3825 .27375 Mdot
.3475 .20375 Mdot
.9875 .10875 Mdot
.14375 .0625 Mdot
.36875 .04 Mdot
.87875 .05 Mdot
.40875 .06 Mdot
.4025 .0725 Mdot
.49 .0725 Mdot
.55875 .0875 Mdot
.39875 .05875 Mdot
.3375 .05875 Mdot
.945 .14125 Mdot
.25125 .1725 Mdot
.36875 .18625 Mdot
.81875 .23 Mdot
.41875 .23875 Mdot
.2575 .19125 Mdot
.63375 .21625 Mdot
.6825 .21875 Mdot
.3425 .2525 Mdot
.58375 .255 Mdot
.37375 .1725 Mdot
.53125 .10625 Mdot
.3775 .0525 Mdot
.42625 .00875 Mdot
.315 .09 Mdot
.55 .125 Mdot
.73625 .13625 Mdot
.10375 .1775 Mdot
.69875 .7125 Mdot
.87375 .675 Mdot
.08875 .645 Mdot
.65125 .54125 Mdot
.56125 .365 Mdot
.3025 .29625 Mdot
.43125 .31875 Mdot
.8075 .30375 Mdot
.6675 .32625 Mdot
.25875 .43625 Mdot
.455 .41375 Mdot
.495 .32125 Mdot
.50625 .27375 Mdot
.275 .32125 Mdot
.59875 .3775 Mdot
.02875 .57 Mdot
.71 .6325 Mdot
.495 .51125 Mdot
.36 .3425 Mdot
.27 .21375 Mdot
.455 .23625 Mdot
.18375 .325 Mdot
.43125 .4575 Mdot
.52375 .50625 Mdot
.5275 .54625 Mdot
.36 .6775 Mdot
.42125 .805 Mdot
.9725 .9375 Mdot
.605 .97625 Mdot
.36625 .8475 Mdot
.35875 .7475 Mdot
.61375 .72125 Mdot
.79875 .725 Mdot
.3825 .78625 Mdot
.41 .87625 Mdot
.46625 .84625 Mdot
.55375 .79 Mdot
.18875 .7575 Mdot
.61625 .7875 Mdot
.99125 .8075 Mdot
.0725 .8625 Mdot
.70375 .95625 Mdot
.42375 .88375 Mdot
.45 .75 Mdot
.29 .74 Mdot
.7875 .7425 Mdot
.64125 .73 Mdot
.3225 .8125 Mdot
.4925 .905 Mdot
.43125 .84 Mdot
.4725 .7575 Mdot
.2725 .7225 Mdot
.97375 .68 Mdot
.27125 .59375 Mdot
.61375 .59375 Mdot
.59 .57875 Mdot
.28 .52625 Mdot
.445 .57125 Mdot
.5975 .645 Mdot
.77125 .7125 Mdot
.28875 .82125 Mdot
.45125 .9125 Mdot
.51875 .855 Mdot
.49375 .8025 Mdot
.33375 .78625 Mdot
.73875 .765 Mdot
.55375 .7675 Mdot
.14375 .81375 Mdot
.77 .83 Mdot
.5775 .72375 Mdot
.3825 .63625 Mdot
.31625 .59 Mdot
.95125 .5625 Mdot
.26375 .575 Mdot
.4575 .6925 Mdot
.54125 .695 Mdot
.48125 .7025 Mdot
.1375 .8175 Mdot
.4825 .88 Mdot
.2875 .82 Mdot
.835 .79875 Mdot
.56375 .8875 Mdot
.21125 .98875 Mdot
.27625 .91125 Mdot
.3625 .73 Mdot
.3425 .84125 Mdot
.49125 .8775 Mdot
.5675 .7925 Mdot
.3775 .8725 Mdot
.17125 .99625 Mdot
.71875 .9375 Mdot
.855 .91875 Mdot
.19625 .94875 Mdot
.62 .99125 Mdot
.07 .85 Mdot
.07125 .945 Mdot
.535 .97125 Mdot
.49875 .985 Mdot
.3375 .92375 Mdot
.36625 .79125 Mdot
.13 .58 Mdot
.4525 .5275 Mdot
.6175 .51875 Mdot
.3975 .60875 Mdot
.3175 .695 Mdot
.59375 .7 Mdot
.94375 .705 Mdot
.3 .68875 Mdot
.3975 .60125 Mdot
.45375 .615 Mdot
.56625 .6525 Mdot
.14875 .71375 Mdot
.6175 .72875 Mdot
.6 .78625 Mdot
.4625 .84625 Mdot
.49875 .95 Mdot
.18 .97375 Mdot
.88875 .96125 Mdot
.7075 .91 Mdot
.25375 .81625 Mdot
.49875 .70625 Mdot
.41375 .705 Mdot
.46375 .8175 Mdot
.1725 .87125 Mdot
.22625 .91625 Mdot
.465 .84625 Mdot
.5225 .87375 Mdot
.43375 .91125 Mdot
.3 .89125 Mdot
.86375 .8075 Mdot
.5275 .74625 Mdot
.2325 .7025 Mdot
.62 .76 Mdot
.56875 .83625 Mdot
.415 .945 Mdot
.535 .8775 Mdot
.5325 .8675 Mdot
.10625 .755 Mdot
.5525 .51625 Mdot
.29375 .4275 Mdot
.5325 .39875 Mdot
.445 .4975 Mdot
.45875 .6 Mdot
.16 .65625 Mdot
.145 .5725 Mdot
.4125 .485 Mdot
.47625 .495 Mdot
.51125 .5975 Mdot
.13 .6625 Mdot
.9925 .6775 Mdot
.605 .605 Mdot
.315 .5325 Mdot
.415 .4725 Mdot
.57125 .5425 Mdot
.27125 .6875 Mdot
.2375 .88375 Mdot
.3525 .9425 Mdot
.04375 .7075 Mdot
.085 .3725 Mdot
.46 .285 Mdot
.5375 .28 Mdot
.45375 .36625 Mdot
.13 .4975 Mdot
.7925 .595 Mdot
.99125 .64375 Mdot
.0775 .6375 Mdot
.5 .5975 Mdot
.485 .595 Mdot
.5025 .58375 Mdot
.09125 .525 Mdot
.31375 .385 Mdot
.35125 .5175 Mdot
.5325 .64125 Mdot
.52125 .75375 Mdot
.04375 .9325 Mdot
.8675 .075 Mdot
.01375 .16125 Mdot
.51625 .10125 Mdot
.4825 .17375 Mdot
.46 .17375 Mdot
.1525 .14125 Mdot
.95875 .1075 Mdot
.885 .0825 Mdot
.14625 .0025 Mdot
.66625 .04375 Mdot
.43 .01 Mdot
.4475 .12625 Mdot
.2575 .11625 Mdot
.3525 .10875 Mdot
.51 .0925 Mdot
.26875 .15375 Mdot
.435 .225 Mdot
.11125 .38 Mdot
.445 .37 Mdot
.54625 .3925 Mdot
.4625 .37 Mdot
.235 .285 Mdot
.62625 .27125 Mdot
.23375 .27 Mdot
.42125 .31375 Mdot
.43375 .35 Mdot
.545 .3575 Mdot
.10125 .29875 Mdot
.65125 .25125 Mdot
.48 .0975 Mdot
.5 .135 Mdot
.5425 .16375 Mdot
.05625 .145 Mdot
.9775 .16375 Mdot
.76625 .20375 Mdot
.21 .18875 Mdot
.47375 .1975 Mdot
.44375 .26 Mdot
.44875 .21625 Mdot
.105 .16 Mdot
.26 .12875 Mdot
.3725 .07125 Mdot
.51375 .01 Mdot
.3925 .075 Mdot
.46875 .0525 Mdot
.61375 .04125 Mdot
.925 .0175 Mdot
.15375 .0975 Mdot
.47 .13125 Mdot
.53125 .17 Mdot
.3925 .1975 Mdot
.245 .2125 Mdot
.9825 .21875 Mdot
.52375 .18 Mdot
.27375 .15375 Mdot
.52375 .05 Mdot
.5675 .1025 Mdot
.39875 .08 Mdot
.15 .06375 Mdot
.30125 .13 Mdot
.35125 .0975 Mdot
.5225 .15125 Mdot
.56375 .15875 Mdot
.05125 .19625 Mdot
.9825 .25875 Mdot
.66625 .28625 Mdot
.3125 .2675 Mdot
.4175 .25125 Mdot
.44625 .2825 Mdot
.4675 .30125 Mdot
.135 .29875 Mdot
.11375 .3875 Mdot
.40375 .36875 Mdot
.47125 .39125 Mdot
.51125 .37625 Mdot
.105 .32375 Mdot
.5875 .26875 Mdot
.31375 .215 Mdot
.4425 .22 Mdot
.4625 .28 Mdot
.2525 .2325 Mdot
.26125 .16375 Mdot
.27 .02 Mdot
.50625 .0075 Mdot
.54875 .10875 Mdot
.3575 .15875 Mdot
.06625 .4 Mdot
.4625 .3475 Mdot
.46625 .37625 Mdot
.47625 .41 Mdot
.09375 .37375 Mdot
.775 .33875 Mdot
.47625 .17 Mdot
.49375 .18875 Mdot
.51375 .18 Mdot
.05375 .21 Mdot
.25875 .275 Mdot
.37375 .1725 Mdot
.49375 .15375 Mdot
.495 .13875 Mdot
.04125 .07375 Mdot
.80875 .51625 Mdot
.92 .4925 Mdot
.10125 .4775 Mdot
.57625 .48375 Mdot
.46 .49625 Mdot
.48875 .52375 Mdot
.15625 .52875 Mdot
.90625 .53375 Mdot
.8075 .52625 Mdot
.24625 .505 Mdot
.44375 .49 Mdot
.51 .5075 Mdot
.445 .5025 Mdot
.15375 .48875 Mdot
.655 .47875 Mdot
.0875 .4725 Mdot
.48375 .47 Mdot
.45625 .47875 Mdot
.42625 .485 Mdot
.31625 .4825 Mdot
.33875 .48375 Mdot
.4225 .555 Mdot
.545 .57625 Mdot
.49125 .60125 Mdot
.3125 .57625 Mdot
.43625 .5425 Mdot
.18125 .42875 Mdot
.54125 .43375 Mdot
.48875 .475 Mdot
.44125 .5125 Mdot
.2675 .62375 Mdot
.63125 .6675 Mdot
.9675 .65625 Mdot
.25875 .62875 Mdot
.435 .595 Mdot
.4325 .59875 Mdot
.54 .62375 Mdot
.19 .62 Mdot
.6025 .59375 Mdot
.02125 .5375 Mdot
.55 .495 Mdot
.49125 .5 Mdot
.53375 .49875 Mdot
.12375 .50125 Mdot
.89875 .5125 Mdot
.73 .52125 Mdot
.22625 .51875 Mdot
.46375 .52375 Mdot
.48 .505 Mdot
.46125 .535 Mdot
.20875 .59 Mdot
.18 .545 Mdot
.43625 .56875 Mdot
.56 .57 Mdot
.35375 .4725 Mdot
.5525 .46625 Mdot
.51125 .47 Mdot
.88 .43125 Mdot
.2225 .36 Mdot
.49875 .3075 Mdot
.49875 .3275 Mdot
.4075 .35 Mdot
.295 .38375 Mdot
.91375 .44 Mdot
.48875 .5275 Mdot
.24375 .535 Mdot
.63625 .585 Mdot
.565 .56125 Mdot
.4275 .515 Mdot
.14625 .505 Mdot
.30125 .50375 Mdot
.3825 .54 Mdot
.4975 .57 Mdot
.5725 .555 Mdot
.18125 .51375 Mdot
.8375 .4675 Mdot
.64625 .4475 Mdot
.305 .4625 Mdot
.41 .49875 Mdot
.5875 .4925 Mdot
.395 .49125 Mdot
.23125 .49625 Mdot
.16375 .4425 Mdot
.4225 .46125 Mdot
.465 .43375 Mdot
.50125 .44875 Mdot
.23125 .4725 Mdot
.50625 .485 Mdot
.29125 .50375 Mdot
.4325 .48 Mdot
.59125 .54 Mdot
.3225 .57625 Mdot
.25875 .59625 Mdot
.2625 .62375 Mdot
.3425 .55125 Mdot
.5075 .48 Mdot
.47125 .47625 Mdot
.41625 .50125 Mdot
.075 .49125 Mdot
.1125 .51125 Mdot
.4425 .53 Mdot
.54625 .545 Mdot
.51625 .57125 Mdot
.11 .5675 Mdot
.755 .55125 Mdot
.05375 .4075 Mdot
.4625 .35625 Mdot
.46625 .36 Mdot
.53875 .38375 Mdot
.19625 .40625 Mdot
.22 .48375 Mdot
.30375 .49125 Mdot
.6275 .5 Mdot
.55625 .52625 Mdot
.0125 .53375 Mdot
.74375 .365 Mdot
.6875 .4025 Mdot
.31875 .42 Mdot
.625 .43375 Mdot
.38625 .44625 Mdot
.55 .425 Mdot
.22375 .33625 Mdot
.765 .3275 Mdot
.695 .30875 Mdot
.33875 .28625 Mdot
.49625 .30625 Mdot
.50875 .38875 Mdot
.49625 .39875 Mdot
.2025 .2775 Mdot
.5825 .21875 Mdot
.865 .23 Mdot
.31875 .23625 Mdot
.72125 .15375 Mdot
.29875 .2525 Mdot
.41 .32875 Mdot
.39875 .3275 Mdot
.375 .3125 Mdot
.04625 .3575 Mdot
.4425 .32125 Mdot
.5425 .28875 Mdot
.52375 .28625 Mdot
.3275 .2375 Mdot
.4875 .18875 Mdot
.83 .215 Mdot
.26125 .25125 Mdot
.83625 .24375 Mdot
.26875 .28875 Mdot
.45875 .38 Mdot
.30625 .33875 Mdot
.58625 .305 Mdot
.92 .29375 Mdot
.33625 .29375 Mdot
.40375 .25625 Mdot
.45375 .21125 Mdot
.51875 .19625 Mdot
.2725 .17875 Mdot
.5775 .17375 Mdot
.92125 .155 Mdot
.045 .24 Mdot
.84875 .29 Mdot
.3325 .33 Mdot
.52 .35375 Mdot
.22625 .3375 Mdot
.79 .285 Mdot
.68625 .2275 Mdot
.29375 .205 Mdot
.455 .185 Mdot
.45625 .25125 Mdot
.54125 .26125 Mdot
.30625 .26 Mdot
.99125 .25875 Mdot
.175 .25875 Mdot
.44875 .24125 Mdot
.73125 .34 Mdot
.24125 .42625 Mdot
.55625 .49625 Mdot
.52875 .55375 Mdot
.76625 .56375 Mdot
.3325 .505 Mdot
.47625 .49625 Mdot
.5125 .445 Mdot
.445 .375 Mdot
.3075 .34625 Mdot
.835 .33875 Mdot
.45 .3 Mdot
.19125 .2975 Mdot
.805 .28875 Mdot
.5375 .2775 Mdot
.38875 .1475 Mdot
.29375 .06875 Mdot
.8925 .00625 Mdot
.415 .005 Mdot
.475 .11 Mdot
.58 .145 Mdot
.28875 .115 Mdot
.69125 .11375 Mdot
.64375 .105 Mdot
.3425 .08125 Mdot
.35 .08875 Mdot
.7175 .2175 Mdot
.32125 .16125 Mdot
.36375 .1025 Mdot
.43625 .0225 Mdot
.25375 .02375 Mdot
.33625 .05625 Mdot
.32875 .08625 Mdot
.4 .1225 Mdot
.505 .125 Mdot
.4575 .1925 Mdot
.46125 .1725 Mdot
.18125 .18375 Mdot
.2675 .1925 Mdot
.355 .10625 Mdot
.65125 .13375 Mdot
.50625 .09 Mdot
.1775 .0725 Mdot
.70125 .08125 Mdot
.8925 .13375 Mdot
.15 .1925 Mdot
.445 .295 Mdot
.44625 .395 Mdot
.53375 .41125 Mdot
.4475 .37375 Mdot
.965 .29375 Mdot
.26125 .2225 Mdot
.17625 .16 Mdot
.82125 .17875 Mdot
.57875 .24375 Mdot
.0375 .315 Mdot
.675 .265 Mdot
.46125 .125 Mdot
.63375 .165 Mdot
.25125 .37625 Mdot
.6475 .42125 Mdot
.58875 .425 Mdot
.44 .3675 Mdot
.55375 .22875 Mdot
.48625 .1625 Mdot
.52375 .3375 Mdot
.2725 .52125 Mdot
.54125 .5475 Mdot
.51875 .47625 Mdot
.56375 .33875 Mdot
.8925 .29125 Mdot
.17875 .18375 Mdot
.3975 .255 Mdot
.49 .30375 Mdot
.39125 .36 Mdot
.96875 .255 Mdot
.2025 .22875 Mdot
.4625 .17375 Mdot
.52 .32 Mdot
.55875 .4425 Mdot
.34375 .5575 Mdot
.54125 .59625 Mdot
.5625 .62875 Mdot
.335 .53 Mdot
.1225 .3575 Mdot
.4625 .32875 Mdot
.34625 .28875 Mdot
.5225 .26 Mdot
.85125 .2725 Mdot
.42 .22375 Mdot
.385 .215 Mdot
.48125 .335 Mdot
.49375 .4875 Mdot
.3675 .5475 Mdot
.5425 .54 Mdot
.7075 .54875 Mdot
.04875 .43 Mdot
.1825 .245 Mdot
.51875 .3375 Mdot
.305 .42375 Mdot
.66375 .4725 Mdot
.6825 .55 Mdot
.35125 .52 Mdot
.45125 .48625 Mdot
.45375 .5075 Mdot
.5575 .49125 Mdot
.42125 .4175 Mdot
.80875 .4175 Mdot
.1775 .4775 Mdot
.405 .4525 Mdot
.94 .4525 Mdot
.175 .565 Mdot
.515 .57375 Mdot
.4925 .505 Mdot
.7175 .4925 Mdot
.41375 .52375 Mdot
.47375 .50625 Mdot
.515 .64125 Mdot
.45 .75 Mdot
.4175 .7775 Mdot
.68125 .705 Mdot
.445 .67875 Mdot
.1375 .58375 Mdot
.93875 .5575 Mdot
.52 .6875 Mdot
.2875 .9275 Mdot
.8575 .77125 Mdot
.22375 .8375 Mdot
.445 .975 Mdot
.39875 .9875 Mdot
.3825 .99625 Mdot
.4475 .88625 Mdot
.52625 .86375 Mdot
.4525 .8975 Mdot
.46625 .975 Mdot
.3475 .99 Mdot
.8825 .91625 Mdot
.365 .8725 Mdot
.2625 .8425 Mdot
.83625 .8025 Mdot
.4675 .9225 Mdot
.435 .95875 Mdot
.425 .90875 Mdot
.5075 .91 Mdot
.6875 .9325 Mdot
.72375 .8875 Mdot
.28125 .90125 Mdot
.09125 .83375 Mdot
.98875 .76625 Mdot
.575 .6325 Mdot
.09375 .455 Mdot
.48125 .94625 Mdot
.46625 .92125 Mdot
.56375 .91 Mdot
.4625 .88 Mdot
.06875 .945 Mdot
.5375 .75125 Mdot
.38625 .48875 Mdot
.41125 .3275 Mdot
.5 .20125 Mdot
.60625 .17125 Mdot
.46 .28375 Mdot
.4625 .38 Mdot
.535 .3575 Mdot
.4825 .3225 Mdot
.4625 .39625 Mdot
.58125 .49625 Mdot
.4725 .6175 Mdot
.25875 .79 Mdot
.98125 .845 Mdot
.14375 .81875 Mdot
.51875 .725 Mdot
.695 .68375 Mdot
.37875 .62 Mdot
.51875 .69 Mdot
.41875 .59875 Mdot
.50625 .5675 Mdot
.5675 .54875 Mdot
.65125 .63625 Mdot
.36625 .69 Mdot
.44875 .86375 Mdot
.0675 .8125 Mdot
.1675 .56875 Mdot
.4575 .52875 Mdot
.605 .46625 Mdot
.4125 .57125 Mdot
.48125 .735 Mdot
.525 .8225 Mdot
.46625 .7 Mdot
.4825 .61 Mdot
.465 .6025 Mdot
.61125 .64875 Mdot
.485 .68625 Mdot
.1825 .81875 Mdot
.40125 .67625 Mdot
.315 .5725 Mdot
.52375 .47375 Mdot
.69 .41875 Mdot
.36625 .44625 Mdot
.45875 .565 Mdot
.3775 .53625 Mdot
.475 .49375 Mdot
.8775 .47625 Mdot
.50625 .50625 Mdot
.325 .54125 Mdot
.02 .71375 Mdot
.55875 .93125 Mdot
.51875 .08875 Mdot
.0925 .13 Mdot
.9725 .1475 Mdot
.76625 .13625 Mdot
.06125 .06 Mdot
.49 .1025 Mdot
.78 .07 Mdot
.48625 .04 Mdot
.27625 .03 Mdot
.3175 .02875 Mdot
.48625 .04 Mdot
.37875 .02375 Mdot
.0825 .00375 Mdot
.0375 .0375 Mdot
.4375 .0025 Mdot
.50125 .045 Mdot
.65625 .0525 Mdot
.40125 .08875 Mdot
.47375 .08875 Mdot
.42625 .05875 Mdot
.60125 .0275 Mdot
.63875 .0175 Mdot
.3825 .01125 Mdot
.0675 .0075 Mdot
.48125 .02625 Mdot
.53125 .04 Mdot
.48 .11875 Mdot
.46125 .19 Mdot
.04 .21125 Mdot
.5475 .30125 Mdot
.39125 .2875 Mdot
.52125 .28125 Mdot
.3975 .30875 Mdot
.47375 .27375 Mdot
.55125 .26625 Mdot
.45625 .255 Mdot
.5125 .245 Mdot
.56375 .23 Mdot
.45 .2075 Mdot
.49875 .20375 Mdot
.5175 .2025 Mdot
.21 .21125 Mdot
.09125 .23375 Mdot
.53125 .21875 Mdot
.63625 .1975 Mdot
.39125 .1925 Mdot
.54 .1575 Mdot
.4 .2 Mdot
.505 .20625 Mdot
.63875 .20375 Mdot
.52625 .14625 Mdot
.4275 .18875 Mdot
.4425 .08375 Mdot
.15875 .2075 Mdot
.41375 .1725 Mdot
.49 .245 Mdot
.4325 .24125 Mdot
.56125 .20625 Mdot
.51625 .1625 Mdot
.46125 .1825 Mdot
.49375 .23 Mdot
.495 .225 Mdot
.4875 .2025 Mdot
.5475 .2075 Mdot
.2025 .1775 Mdot
.40125 .16875 Mdot
.3775 .205 Mdot
.50375 .2325 Mdot
.545 .25625 Mdot
.45875 .28875 Mdot
.475 .31375 Mdot
.3625 .32375 Mdot
.465 .3525 Mdot
.92875 .35375 Mdot
.42875 .39625 Mdot
.3475 .39375 Mdot
.0075 .3325 Mdot
.625 .1925 Mdot
.12375 .115 Mdot
.5375 .55125 Mdot
.1325 .50625 Mdot
.945 .47 Mdot
.72375 .47 Mdot
.09 .495 Mdot
.79125 .55125 Mdot
.34625 .59 Mdot
.46125 .615 Mdot
.44375 .63375 Mdot
.42125 .60125 Mdot
.7925 .5825 Mdot
.395 .58375 Mdot
.5825 .5575 Mdot
.41375 .5225 Mdot
.4975 .45875 Mdot
.055 .445 Mdot
.71 .4375 Mdot
.45625 .50625 Mdot
.4925 .515 Mdot
.4925 .5075 Mdot
.45375 .50125 Mdot
.57125 .5025 Mdot
.4175 .51375 Mdot
.48875 .5125 Mdot
.625 .50625 Mdot
.45875 .525 Mdot
.485 .51875 Mdot
.33125 .52125 Mdot
.3025 .5125 Mdot
.49375 .5225 Mdot
.47875 .5225 Mdot
.42 .5375 Mdot
.58375 .55125 Mdot
.71125 .5475 Mdot
.3175 .53125 Mdot
.48875 .5275 Mdot
.50875 .52 Mdot
.49375 .49625 Mdot
.48625 .49875 Mdot
.4275 .5025 Mdot
.1075 .51625 Mdot
.03375 .55625 Mdot
.48 .57875 Mdot
.44625 .60375 Mdot
.465 .60375 Mdot
.6775 .615 Mdot
.4575 .57 Mdot
.4325 .535 Mdot
.43 .52375 Mdot
.59625 .5025 Mdot
.625 .48875 Mdot
.405 .52625 Mdot
.28375 .51375 Mdot
.50625 .48625 Mdot
.10875 .5225 Mdot
.4475 .52625 Mdot
.4775 .5725 Mdot
.575 .60875 Mdot
.56375 .59875 Mdot
.51625 .605 Mdot
.46375 .5825 Mdot
.49375 .55 Mdot
.50625 .5225 Mdot
.4775 .50375 Mdot
.47375 .45625 Mdot
.1 .4525 Mdot
.5275 .4775 Mdot
.43 .5 Mdot
.485 .54 Mdot
.39375 .53875 Mdot
.495 .54375 Mdot
.625 .53125 Mdot
.41125 .52375 Mdot
.51 .515 Mdot
.53375 .5575 Mdot
.4825 .56 Mdot
.48875 .5375 Mdot
.55875 .505 Mdot
.21875 .47875 Mdot
.98125 .42125 Mdot
.18625 .43125 Mdot
.51625 .46375 Mdot
.635 .505 Mdot
.34625 .5125 Mdot
.6325 .525 Mdot
.3925 .5125 Mdot
.49625 .505 Mdot
.5875 .5025 Mdot
.52125 .5175 Mdot
.46625 .505 Mdot
.465 .5425 Mdot
.03125 .545 Mdot
.14875 .52875 Mdot
.4575 .5575 Mdot
.51375 .5475 Mdot
.38875 .5425 Mdot
.63875 .55625 Mdot
.505 .57125 Mdot
.45375 .55625 Mdot
.49375 .50125 Mdot
.45625 .46875 Mdot
.50625 .49875 Mdot
.585 .49125 Mdot
.205 .4975 Mdot
.935 .55 Mdot
.3825 .61875 Mdot
.4225 .60125 Mdot
.51 .60125 Mdot
.48375 .61625 Mdot
.4775 .5825 Mdot
.59625 .5475 Mdot
.33375 .535 Mdot
.4375 .525 Mdot
.8775 .515 Mdot
.4325 .53125 Mdot
.38125 .51875 Mdot
.1 .53625 Mdot
.5225 .58 Mdot
.2525 .58625 Mdot
.53625 .32 Mdot
.21375 .32125 Mdot
.8675 .35 Mdot
.6575 .36 Mdot
.1525 .39375 Mdot
.7125 .3875 Mdot
.395 .3875 Mdot
.38625 .36625 Mdot
.47875 .3325 Mdot
.6325 .32125 Mdot
.62 .3125 Mdot
.4 .2975 Mdot
.5525 .31625 Mdot
.47 .35125 Mdot
.50375 .365 Mdot
.1525 .3575 Mdot
.66 .3575 Mdot
.115 .29 Mdot
.46125 .27375 Mdot
.50125 .255 Mdot
.4825 .2475 Mdot
.32 .2625 Mdot
.8525 .2925 Mdot
.28 .28375 Mdot
.4925 .29 Mdot
.57125 .285 Mdot
.4925 .24625 Mdot
.4925 .255 Mdot
.41375 .25625 Mdot
.33375 .2625 Mdot
.0875 .2825 Mdot
.49625 .26125 Mdot
.47375 .29 Mdot
.39625 .29125 Mdot
.48 .2725 Mdot
.92875 .2775 Mdot
.21875 .2375 Mdot
.4975 .185 Mdot
.50375 .14875 Mdot
.48125 .12125 Mdot
.45 .15 Mdot
.535 .1475 Mdot
.2 .1625 Mdot
.17125 .16875 Mdot
.4875 .14125 Mdot
.46625 .15875 Mdot
.39 .15875 Mdot
.7 .1425 Mdot
.56875 .19375 Mdot
.35875 .1975 Mdot
.455 .17625 Mdot
.53875 .19 Mdot
.62 .18125 Mdot
.42625 .195 Mdot
.355 .23 Mdot
.50625 .2525 Mdot
.8775 .275 Mdot
.24625 .33625 Mdot
.4375 .345 Mdot
.4675 .30625 Mdot
.475 .285 Mdot
.70125 .24125 Mdot
.52625 .1675 Mdot
.4075 .09875 Mdot
.50125 .0725 Mdot
.48625 .06875 Mdot
.51 .1175 Mdot
.46 .195 Mdot
.21 .24875 Mdot
.90625 .26375 Mdot
.49375 .28375 Mdot
.50375 .28375 Mdot
.45625 .27375 Mdot
.37625 .31375 Mdot
.44625 .37875 Mdot
.80125 .37875 Mdot
.30375 .325 Mdot
.51375 .26375 Mdot
.52875 .11625 Mdot
.495 .0575 Mdot
.47875 .02 Mdot
.84625 .07375 Mdot
.295 .0625 Mdot
.475 .07125 Mdot
.6 .08125 Mdot
.28125 .1 Mdot
.82 .0875 Mdot
.36 .085 Mdot
.4375 .07625 Mdot
.5925 .07125 Mdot
.4825 .07125 Mdot
.505 .125 Mdot
.46625 .125 Mdot
.165 .1475 Mdot
.28375 .1525 Mdot
.49125 .05875 Mdot
.53875 .03625 Mdot
.24375 .0325 Mdot
.79875 .02125 Mdot
.50375 .01125 Mdot
.405 .04875 Mdot
.485 .05125 Mdot
.4575 .0425 Mdot
.4975 .12125 Mdot
.59625 .12375 Mdot
.26625 .1275 Mdot
.835 .14 Mdot
.39 .125 Mdot
.42875 .05625 Mdot
.58625 .0675 Mdot
.3525 .04125 Mdot
.5025 .05375 Mdot
.755 .1025 Mdot
.2475 .08875 Mdot
.49 .065 Mdot
.7575 .0575 Mdot
.46125 .06375 Mdot
.3925 .00875 Mdot
.2475 .07625 Mdot
.855 .14 Mdot
.46875 .21375 Mdot
.38 .2175 Mdot
.5675 .25 Mdot
.3075 .24625 Mdot
.7475 .28 Mdot
.62125 .26625 Mdot
.24625 .12125 Mdot
.6325 .0025 Mdot
.52 .16875 Mdot
.265 .21375 Mdot
.58375 .23625 Mdot
.92125 .3075 Mdot
.2325 .26375 Mdot
.475 .13 Mdot
.48375 .13125 Mdot
.48625 .175 Mdot
.2125 .18375 Mdot
.2075 .25 Mdot
.46375 .30875 Mdot
.53125 .34375 Mdot
.48625 .40625 Mdot
.51 .4975 Mdot
.505 .46375 Mdot
.36125 .4475 Mdot
.9225 .405 Mdot
.255 .35 Mdot
.49875 .225 Mdot
.5 .205 Mdot
.37875 .18375 Mdot
.35375 .1975 Mdot
.19875 .2675 Mdot
.495 .32 Mdot
.4875 .385 Mdot
.51625 .47 Mdot
.425 .565 Mdot
.57625 .6075 Mdot
.3075 .595 Mdot
.88375 .54125 Mdot
.2925 .5075 Mdot
.4925 .425 Mdot
.485 .32625 Mdot
.34875 .31875 Mdot
.6375 .34625 Mdot
.7075 .3025 Mdot
.31375 .34125 Mdot
.445 .4225 Mdot
.5475 .45375 Mdot
.5825 .56625 Mdot
.4525 .62625 Mdot
.41625 .59125 Mdot
.51125 .53 Mdot
.6925 .44625 Mdot
.37125 .2725 Mdot
.47 .15625 Mdot
.45 .1625 Mdot
.39125 .2 Mdot
.75875 .2725 Mdot
.57375 .40625 Mdot
.36 .5725 Mdot
.5225 .6475 Mdot
.44625 .69 Mdot
.53 .69875 Mdot
.45875 .69125 Mdot
.33125 .63625 Mdot
.76625 .645 Mdot
.49875 .5925 Mdot
.515 .5275 Mdot
.4825 .45625 Mdot
.33625 .43 Mdot
.42375 .38875 Mdot
.925 .47625 Mdot
.23125 .63875 Mdot
.50375 .825 Mdot
.395 .9325 Mdot
.46 .7525 Mdot
.56625 .7075 Mdot
.215 .74875 Mdot
.99875 .7875 Mdot
.27625 .82 Mdot
.4325 .9025 Mdot
.575 .95125 Mdot
.4875 .9225 Mdot
.52 .93125 Mdot
.4575 .925 Mdot
.295 .875 Mdot
.84375 .835 Mdot
.3775 .8175 Mdot
.50875 .7475 Mdot
.54625 .71875 Mdot
.14875 .7325 Mdot
.94625 .775 Mdot
.485 .8175 Mdot
.3625 .90125 Mdot
.44625 .9975 Mdot
.45 .985 Mdot
.6325 .87875 Mdot
.2175 .87875 Mdot
.56125 .925 Mdot
.8575 .93625 Mdot
.67375 .9225 Mdot
.4475 .63375 Mdot
.43125 .49625 Mdot
.54125 .89125 Mdot
.50375 .81875 Mdot
.4825 .73625 Mdot
.5675 .78 Mdot
.37875 .91125 Mdot
.39875 .995 Mdot
.5575 .945 Mdot
.48375 .95625 Mdot
.54125 .89375 Mdot
.44375 .8725 Mdot
.445 .8475 Mdot
.58 .8475 Mdot
.47 .8725 Mdot
.5425 .9875 Mdot
.30375 .89625 Mdot
.49875 .7375 Mdot
.4575 .5625 Mdot
.47 .4575 Mdot
.63 .40125 Mdot
.435 .43375 Mdot
.495 .495 Mdot
.51 .56375 Mdot
.45375 .6475 Mdot
.66875 .73 Mdot
.13125 .7375 Mdot
.585 .68625 Mdot
.925 .63875 Mdot
.17875 .54375 Mdot
.59875 .39875 Mdot
.4875 .27625 Mdot
.53625 .1925 Mdot
.485 .1275 Mdot
.4425 .3975 Mdot
.51375 .69625 Mdot
.4825 .06125 Mdot
.36875 .10375 Mdot
.24125 .14625 Mdot
.1075 .10875 Mdot
.0275 .02 Mdot
.04375 .00875 Mdot
.45875 .00375 Mdot
.06 .03 Mdot
.20375 .06875 Mdot
.3525 .02 Mdot
.5425 .015 Mdot
.485 .045 Mdot
.54 .06875 Mdot
.41 .125 Mdot
.58125 .21125 Mdot
.4175 .27625 Mdot
.50125 .2525 Mdot
.575 .28 Mdot
.53625 .26 Mdot
.0125 .1675 Mdot
.51375 .1275 Mdot
.275 .115 Mdot
.48375 .14625 Mdot
.4825 .2075 Mdot
.47625 .2625 Mdot
.57625 .27875 Mdot
.4425 .26875 Mdot
.515 .285 Mdot
.49125 .2775 Mdot
.45875 .2625 Mdot
.66 .30875 Mdot
.115 .305 Mdot
.6325 .2925 Mdot
.9425 .29 Mdot
.17125 .2725 Mdot
.6 .22625 Mdot
.4675 .2475 Mdot
.53875 .24 Mdot
.505 .26 Mdot
.45125 .22875 Mdot
.46625 .13625 Mdot
.41125 .01 Mdot
.61875 .54625 Mdot
.5075 .56875 Mdot
.42375 .53875 Mdot
.55875 .50625 Mdot
.49125 .48875 Mdot
.45875 .4025 Mdot
.4825 .39625 Mdot
.40125 .3875 Mdot
.23375 .38125 Mdot
.1 .41 Mdot
.45375 .42125 Mdot
.4775 .45375 Mdot
.45625 .48 Mdot
.545 .49875 Mdot
.4425 .52375 Mdot
.5175 .53625 Mdot
.5725 .5225 Mdot
.51625 .5275 Mdot
.47375 .5275 Mdot
.43125 .5175 Mdot
.47 .51375 Mdot
.2275 .48 Mdot
.075 .455 Mdot
.4825 .46875 Mdot
.47625 .4575 Mdot
.435 .50625 Mdot
.54125 .53375 Mdot
.59375 .56 Mdot
.47875 .56875 Mdot
.47375 .5925 Mdot
.50125 .57 Mdot
.47125 .51625 Mdot
.53125 .50125 Mdot
.35875 .59875 Mdot
.23 .67125 Mdot
.07375 .92 Mdot
.525 .95375 Mdot
.45 .8475 Mdot
.45625 .74875 Mdot
.5025 .64 Mdot
.63 .5025 Mdot
.3775 .4675 Mdot
.545 .44875 Mdot
.5075 .4425 Mdot
.53 .43625 Mdot
.475 .4925 Mdot
.28125 .55375 Mdot
.54 .60375 Mdot
.925 .6575 Mdot
.235 .685 Mdot
.48375 .6875 Mdot
.49125 .6525 Mdot
.50875 .6225 Mdot
.51875 .59 Mdot
.565 .58875 Mdot
.435 .57875 Mdot
.4825 .57375 Mdot
.5525 .54125 Mdot
.44 .47875 Mdot
.49375 .50625 Mdot
.255 .5125 Mdot
.9025 .52 Mdot
.56 .54 Mdot
.32 .60375 Mdot
.515 .595 Mdot
.47125 .59125 Mdot
.47875 .59375 Mdot
.47875 .625 Mdot
.515 .60375 Mdot
.615 .57625 Mdot
.42375 .55125 Mdot
.52375 .53625 Mdot
.515 .4725 Mdot
.315 .48 Mdot
.3925 .4775 Mdot
.095 .4875 Mdot
.4675 .53375 Mdot
.53875 .52625 Mdot
.48625 .54125 Mdot
.48125 .55 Mdot
.54375 .54125 Mdot
.5075 .5275 Mdot
.455 .5275 Mdot
.5675 .51375 Mdot
.42625 .4675 Mdot
.5075 .42875 Mdot
.1 .44 Mdot
.22875 .47875 Mdot
.36375 .53125 Mdot
.55125 .57875 Mdot
.4925 .56625 Mdot
.46375 .555 Mdot
.51 .52375 Mdot
.58625 .48 Mdot
.3925 .4375 Mdot
.48625 .44875 Mdot
.585 .42625 Mdot
.52625 .41125 Mdot
.08375 .44125 Mdot
.5075 .47 Mdot
.30125 .49125 Mdot
.49375 .5025 Mdot
.4875 .50625 Mdot
.46 .50625 Mdot
.5225 .52375 Mdot
.58625 .53375 Mdot
.46375 .535 Mdot
.49 .54375 Mdot
.4425 .56875 Mdot
.6225 .54125 Mdot
.19375 .52125 Mdot
.62875 .50625 Mdot
.8275 .4825 Mdot
.23 .45125 Mdot
.61375 .46375 Mdot
.46125 .4875 Mdot
.5275 .5025 Mdot
.40875 .5 Mdot
.6375 .49 Mdot
.44625 .51625 Mdot
.355 .525 Mdot
.51375 .52875 Mdot
.60125 .56125 Mdot
.47 .54125 Mdot
.6025 .535 Mdot
.44 .51 Mdot
.45 .4925 Mdot
.51375 .50375 Mdot
.50125 .48 Mdot
.485 .46375 Mdot
.22 .45875 Mdot
.22625 .4425 Mdot
.4425 .49625 Mdot
.5025 .5175 Mdot
.415 .56 Mdot
.48375 .63125 Mdot
.46375 .61625 Mdot
.6825 .58125 Mdot
.48125 .54875 Mdot
.5 .47 Mdot
.48875 .38 Mdot
.4025 .39375 Mdot
.49625 .41625 Mdot
.3475 .44125 Mdot
.2175 .4775 Mdot
.4825 .4675 Mdot
.50625 .47375 Mdot
.445 .43875 Mdot
.3775 .43 Mdot
.75625 .42 Mdot
.50125 .4 Mdot
.4425 .35375 Mdot
.48125 .35 Mdot
.43625 .3675 Mdot
.55375 .37875 Mdot
.40375 .335 Mdot
.27625 .31125 Mdot
.20625 .24625 Mdot
.54125 .27 Mdot
.43875 .30875 Mdot
.4525 .34375 Mdot
.40125 .4025 Mdot
.81 .4425 Mdot
.3175 .41375 Mdot
.51625 .43625 Mdot
.52375 .425 Mdot
.54125 .3675 Mdot
.46125 .36125 Mdot
.35375 .35125 Mdot
.48 .34625 Mdot
.8325 .3675 Mdot
.31625 .44375 Mdot
.47875 .4375 Mdot
.50375 .44875 Mdot
.43125 .46125 Mdot
.52125 .44 Mdot
.76 .40875 Mdot
.30625 .40625 Mdot
.485 .4275 Mdot
.54 .46125 Mdot
.4275 .5125 Mdot
.5475 .49125 Mdot
.3275 .46875 Mdot
.745 .44125 Mdot
.56625 .395 Mdot
.36625 .3225 Mdot
.51375 .32 Mdot
.4775 .3575 Mdot
.35875 .3375 Mdot
.6375 .31875 Mdot
.545 .3425 Mdot
.52375 .3625 Mdot
.44 .32875 Mdot
.525 .31 Mdot
.5075 .30875 Mdot
.355 .285 Mdot
.44 .25875 Mdot
.96625 .24875 Mdot
.19875 .255 Mdot
.46875 .2375 Mdot
.4825 .24375 Mdot
.56375 .22875 Mdot
.365 .21125 Mdot
.7475 .1975 Mdot
.435 .195 Mdot
.4325 .185 Mdot
.5425 .18375 Mdot
.43625 .2375 Mdot
.515 .25 Mdot
.2 .24875 Mdot
.285 .255 Mdot
.3975 .20125 Mdot
.54625 .18625 Mdot
.4925 .165 Mdot
.30375 .13625 Mdot
.725 .11875 Mdot
.59625 .115 Mdot
.35625 .10125 Mdot
.46625 .095 Mdot
.55875 .14375 Mdot
.4925 .15 Mdot
.23 .13875 Mdot
.89875 .1475 Mdot
.49375 .16 Mdot
.34 .12625 Mdot
.53 .11625 Mdot
.49625 .08625 Mdot
.43625 .0475 Mdot
.44375 .0125 Mdot
.675 .0375 Mdot
.36125 .13125 Mdot
.56625 .18625 Mdot
.47375 .19125 Mdot
.51375 .17625 Mdot
.2975 .17125 Mdot
.88875 .225 Mdot
.35125 .27125 Mdot
.3325 .3725 Mdot
.49375 .47625 Mdot
.40375 .02625 Mdot
.5075 .02875 Mdot
.46125 .0275 Mdot
.45875 .00625 Mdot
.25 .11125 Mdot
.49625 .115 Mdot
.55 .1425 Mdot
.54 .21625 Mdot
.46125 .27625 Mdot
.37 .275 Mdot
.52 .295 Mdot
.69625 .26 Mdot
.395 .13625 Mdot
.48375 .0725 Mdot
.47625 .05 Mdot
.36125 .0675 Mdot
.54 .13875 Mdot
.94 .20625 Mdot
.19 .21875 Mdot
.48 .23 Mdot
.54 .19125 Mdot
.4325 .1975 Mdot
.535 .225 Mdot
.4 .25375 Mdot
.67625 .25875 Mdot
.51875 .2975 Mdot
.40625 .25875 Mdot
.51875 .165 Mdot
.51375 .06 Mdot
.24875 .0425 Mdot
.74 .02 Mdot
.5825 .015 Mdot
.4575 .07125 Mdot
.44625 .185 Mdot
.5025 .305 Mdot
.5225 .4975 Mdot
.41625 .53375 Mdot
.43 .5125 Mdot
.83375 .46375 Mdot
.2825 .34625 Mdot
.47875 .1925 Mdot
.48125 .1525 Mdot
.545 .17125 Mdot
.30625 .19875 Mdot
.96375 .2125 Mdot
.30625 .215 Mdot
.41625 .2325 Mdot
.53375 .26375 Mdot
.45125 .375 Mdot
.5325 .46625 Mdot
.26875 .505 Mdot
.91625 .54375 Mdot
.38625 .5275 Mdot
.405 .4375 Mdot
.5525 .33625 Mdot
.46875 .35125 Mdot
.1825 .41 Mdot
.89 .475 Mdot
.61 .53125 Mdot
.32625 .66375 Mdot
.43375 .73375 Mdot
.56 .80875 Mdot
.4925 .90625 Mdot
.325 .94125 Mdot
.7625 .94625 Mdot
.49625 .93625 Mdot
.3425 .89375 Mdot
.57125 .84625 Mdot
.5175 .85 Mdot
.42 .92125 Mdot
.39 .98375 Mdot
.24875 .46375 Mdot
.34375 .27875 Mdot
.49875 .0075 Mdot
.50375 .89375 Mdot
.4275 .85125 Mdot
.60625 .79625 Mdot
.50125 .75625 Mdot
.37125 .79375 Mdot
.58625 .80625 Mdot
.5275 .775 Mdot
.4125 .72 Mdot
.36125 .65125 Mdot
.22625 .50125 Mdot
.49125 .4025 Mdot
.48375 .32375 Mdot
.47625 .27125 Mdot
.45375 .2725 Mdot
.59375 .27625 Mdot
.49625 .29125 Mdot
.495 .34625 Mdot
.53375 .395 Mdot
.52125 .51625 Mdot
.47 .6075 Mdot
.5275 .0125 Mdot
.52875 .03 Mdot
.495 .00875 Mdot
.48625 .0275 Mdot
.39375 .03625 Mdot
.60875 .06625 Mdot
.52 .13 Mdot
.41125 .16625 Mdot
.38875 .22625 Mdot
.1775 .32125 Mdot
.49625 .31 Mdot
.4675 .315 Mdot
.48125 .30125 Mdot
.49125 .28 Mdot
.56 .25 Mdot
.485 .22375 Mdot
.505 .19875 Mdot
.53625 .2025 Mdot
.51 .22 Mdot
.44125 .21625 Mdot
.085 .09375 Mdot
.3325 .0225 Mdot
.51 .025 Mdot
.52125 .415 Mdot
.11625 .43375 Mdot
.005 .46625 Mdot
.43375 .445 Mdot
.56625 .435 Mdot
.5 .42375 Mdot
.53625 .43 Mdot
.44375 .43125 Mdot
.5225 .42875 Mdot
.51 .45125 Mdot
.55 .4725 Mdot
.47375 .45375 Mdot
.46 .46375 Mdot
.325 .48 Mdot
.32 .4775 Mdot
.14625 .58625 Mdot
.4325 .635 Mdot
.495 .66875 Mdot
.46125 .69 Mdot
.51375 .695 Mdot
.5175 .65875 Mdot
.4525 .61625 Mdot
.48125 .61125 Mdot
.495 .58 Mdot
.58 .5175 Mdot
.48 .48 Mdot
.02375 .47125 Mdot
.55 .43 Mdot
.2275 .4625 Mdot
.53 .51625 Mdot
.3825 .53 Mdot
.51125 .5325 Mdot
.55625 .53625 Mdot
.4875 .51125 Mdot
.49875 .475 Mdot
.5325 .47 Mdot
.58875 .4875 Mdot
.4675 .5075 Mdot
.40625 .54875 Mdot
.02 .6125 Mdot
.17625 .67625 Mdot
.4875 .64875 Mdot
.49375 .63 Mdot
.46625 .63 Mdot
.58625 .60625 Mdot
.42625 .5975 Mdot
.4875 .58625 Mdot
.5025 .56125 Mdot
.5225 .49125 Mdot
.515 .39625 Mdot
.4375 .37625 Mdot
.16125 .3975 Mdot
.765 .4275 Mdot
.46625 .525 Mdot
.49375 .505 Mdot
.48 .50875 Mdot
.4875 .50875 Mdot
.525 .53 Mdot
.46875 .6 Mdot
.62625 .64625 Mdot
.44625 .6375 Mdot
.495 .6125 Mdot
.5075 .575 Mdot
.14 .5175 Mdot
.8275 .48125 Mdot
.74125 .47125 Mdot
.31 .53625 Mdot
.5175 .59625 Mdot
.46625 .62875 Mdot
.49375 .6675 Mdot
.46125 .72625 Mdot
.4925 .735 Mdot
.51 .7275 Mdot
.5125 .68125 Mdot
.46875 .7 Mdot
.475 .65375 Mdot
.63625 .56875 Mdot
.06375 .52375 Mdot
.09375 .49875 Mdot
.465 .5 Mdot
.495 .51125 Mdot
.45125 .51 Mdot
.515 .50625 Mdot
.44875 .4875 Mdot
.545 .4725 Mdot
.55375 .48625 Mdot
.46375 .505 Mdot
.52875 .48375 Mdot
.51375 .48875 Mdot
.51375 .49375 Mdot
.30625 .5175 Mdot
.4825 .5325 Mdot
.52375 .5375 Mdot
.5025 .54625 Mdot
.4925 .53625 Mdot
.44375 .5775 Mdot
.5925 .61875 Mdot
.3925 .6425 Mdot
.56375 .65125 Mdot
.51375 .66125 Mdot
.445 .655 Mdot
.41 .64625 Mdot
.9175 .63125 Mdot
.26125 .6375 Mdot
.49875 .63625 Mdot
.44375 .60375 Mdot
.4975 .5875 Mdot
.46625 .58125 Mdot
.5275 .58875 Mdot
.6325 .6025 Mdot
.39625 .61875 Mdot
.5475 .6025 Mdot
.51125 .5775 Mdot
.44375 .525 Mdot
.07875 .4875 Mdot
.12375 .40125 Mdot
.49375 .375 Mdot
.3925 .4025 Mdot
.535 .51625 Mdot
.1725 .50625 Mdot
.12625 .47875 Mdot
.45625 .48375 Mdot
.55 .4675 Mdot
.48 .44 Mdot
.5275 .46375 Mdot
.4425 .46875 Mdot
.39 .455 Mdot
.735 .43375 Mdot
.52 .42375 Mdot
.40625 .395 Mdot
.50625 .405 Mdot
.37125 .41125 Mdot
.3125 .43875 Mdot
.245 .46625 Mdot
.455 .4525 Mdot
.51 .465 Mdot
.46875 .4575 Mdot
.50375 .4375 Mdot
.5075 .43125 Mdot
.32625 .4675 Mdot
.685 .46125 Mdot
.46125 .46125 Mdot
.53 .45625 Mdot
.465 .49625 Mdot
.20375 .465 Mdot
1 .43625 Mdot
.50875 .44375 Mdot
.31875 .47 Mdot
.50625 .40875 Mdot
.41875 .39375 Mdot
.5025 .42625 Mdot
.54375 .4225 Mdot
.4675 .4525 Mdot
.4325 .51125 Mdot
.725 .53625 Mdot
.48625 .53625 Mdot
.46125 .5325 Mdot
.42 .52375 Mdot
.15875 .505 Mdot
.275 .47 Mdot
.5075 .48125 Mdot
.485 .44875 Mdot
.4725 .41875 Mdot
.575 .43 Mdot
.4275 .41625 Mdot
.35625 .4075 Mdot
.735 .42875 Mdot
.4225 .465 Mdot
.52875 .6275 Mdot
.41875 .64 Mdot
.22 .63875 Mdot
.7925 .63375 Mdot
.9575 .63375 Mdot
.10625 .49125 Mdot
.45125 .50625 Mdot
.505 .525 Mdot
.4725 .5125 Mdot
.48625 .47625 Mdot
.495 .4525 Mdot
.4225 .4125 Mdot
.79375 .38125 Mdot
.37125 .37875 Mdot
.5 .4075 Mdot
.50125 .43375 Mdot
.2375 .47375 Mdot
.68 .505 Mdot
.7175 .535 Mdot
.37125 .53 Mdot
.54 .51375 Mdot
.42625 .47375 Mdot
.515 .455 Mdot
.44875 .41625 Mdot
.4025 .37 Mdot
.6575 .35625 Mdot
.5275 .3675 Mdot
.40875 .34125 Mdot
.52125 .37625 Mdot
.5625 .405 Mdot
.1825 .37875 Mdot
.17125 .425 Mdot
.50375 .41375 Mdot
.4775 .42625 Mdot
.42 .45875 Mdot
.56125 .47625 Mdot
.445 .4675 Mdot
.5025 .455 Mdot
.72125 .41 Mdot
.33 .3625 Mdot
.5225 .325 Mdot
.53625 .3 Mdot
.14 .26875 Mdot
.9275 .28125 Mdot
.485 .31625 Mdot
.3675 .31875 Mdot
.4925 .3075 Mdot
.56625 .33125 Mdot
.47625 .3475 Mdot
.485 .35 Mdot
.34375 .33125 Mdot
.8025 .32375 Mdot
.30625 .3075 Mdot
.5175 .285 Mdot
.5125 .26625 Mdot
.48625 .2175 Mdot
.48375 .165 Mdot
.7375 .1375 Mdot
.36 .125 Mdot
.5175 .09875 Mdot
.415 .13875 Mdot
.4975 .1575 Mdot
.43375 .17 Mdot
.48375 .16625 Mdot
.84125 .1675 Mdot
.2525 .1375 Mdot
.55375 .11 Mdot
.51125 .16875 Mdot
.46125 .20375 Mdot
.16375 .245 Mdot
.21875 .47 Mdot
.6025 .4475 Mdot
.325 .47625 Mdot
.49625 .02 Mdot
.38375 .06 Mdot
.38875 .07625 Mdot
.9675 .03375 Mdot
.46625 .04125 Mdot
.3925 .0075 Mdot
.5125 .02875 Mdot
.3275 .0875 Mdot
.58 .1025 Mdot
.6925 .0875 Mdot
.39625 .04625 Mdot
.4925 .05875 Mdot
.6025 .06875 Mdot
.24375 .10375 Mdot
.92 .0575 Mdot
.3 .01625 Mdot
.48 .00125 Mdot
.88375 .0575 Mdot
.2025 .09625 Mdot
.52 .27875 Mdot
.535 .335 Mdot
.27 .38625 Mdot
.775 .41375 Mdot
.4575 .42875 Mdot
.42375 .385 Mdot
.505 .41375 Mdot
.5575 .41125 Mdot
.47625 .3475 Mdot
.48 .36125 Mdot
.24375 .4175 Mdot
.2225 .57 Mdot
.48625 .7625 Mdot
.49125 .89875 Mdot
.51375 .935 Mdot
.5425 .97 Mdot
.6025 .98125 Mdot
.43125 .9575 Mdot
.54125 .98875 Mdot
.49375 .98875 Mdot
.90125 .8825 Mdot
.355 .57375 Mdot
.67 .31875 Mdot
.25875 .185 Mdot
.10875 .99125 Mdot
.41875 .7625 Mdot
.4975 .53 Mdot
.5425 .4775 Mdot
.55125 .43125 Mdot
.5175 .41625 Mdot
.495 .46125 Mdot
.60875 .46375 Mdot
.38 .4175 Mdot
.47625 .43375 Mdot
.33875 .42375 Mdot
.39 .4175 Mdot
.03 .44375 Mdot
.52875 .38625 Mdot
.50625 .265 Mdot
.51 .25625 Mdot
.35875 .27625 Mdot
.64375 .47125 Mdot
.4725 .72875 Mdot
.545 .1025 Mdot
.4775 .05 Mdot
.56875 .0375 Mdot
.46875 .02375 Mdot
.45875 .015 Mdot
.50875 .0675 Mdot
.435 .12625 Mdot
.0025 .16875 Mdot
.17625 .1975 Mdot
.38625 .0275 Mdot
.455 .05 Mdot
.47125 .1375 Mdot
.56375 .1025 Mdot
.495 .045 Mdot
.48375 .15 Mdot
.44625 .25125 Mdot
.1525 .285 Mdot
.42375 .05625 Mdot
.47375 .03125 Mdot
.48875 .04875 Mdot
.22125 .03375 Mdot
.395 .02 Mdot
.45 .095 Mdot
.595 .15875 Mdot
.3875 .0975 Mdot
.0425 .09125 Mdot
.37 .155 Mdot
.495 .2425 Mdot
.55375 .3075 Mdot
.55125 .3425 Mdot
.4775 .345 Mdot
.5175 .32125 Mdot
.6525 .3525 Mdot
.3875 .37125 Mdot
.46625 .39875 Mdot
.29625 .385 Mdot
.3725 .37 Mdot
.03375 .2875 Mdot
.505 .2525 Mdot
.49375 .30125 Mdot
.55125 .33375 Mdot
.41125 .38875 Mdot
.5 .4025 Mdot
.5225 .37625 Mdot
.72625 .29125 Mdot
.23 .19875 Mdot
.56125 .3475 Mdot
.4425 .36 Mdot
.5425 .36875 Mdot
.47625 .38125 Mdot
.49375 .41125 Mdot
.53875 .43125 Mdot
.48875 .405 Mdot
.5025 .39375 Mdot
.43625 .355 Mdot
.0025 .30625 Mdot
.1 .29375 Mdot
.395 .335 Mdot
.4825 .415 Mdot
.43 .445 Mdot
.53 .42125 Mdot
.5825 .42375 Mdot
.48375 .43125 Mdot
.4825 .38375 Mdot
.57625 .39625 Mdot
.4925 .4675 Mdot
.47625 .47375 Mdot
.4275 .41875 Mdot
.1 .32875 Mdot
.38875 .3175 Mdot
.6075 .35875 Mdot
.4525 .415 Mdot
.5 .4675 Mdot
.41375 .55125 Mdot
.56375 .56625 Mdot
.43375 .555 Mdot
.61625 .55125 Mdot
.48375 .5325 Mdot
.42875 .47875 Mdot
.44625 .49625 Mdot
.30375 .50625 Mdot
.1775 .47375 Mdot
.38375 .49625 Mdot
.5175 .48375 Mdot
.505 .49625 Mdot
.495 .54 Mdot
.48125 .5825 Mdot
.48875 .58375 Mdot
.49625 .58125 Mdot
.58125 .565 Mdot
.505 .5075 Mdot
.42875 .50625 Mdot
.0025 .4875 Mdot
.29375 .52 Mdot
.50125 .53 Mdot
.44375 .49375 Mdot
.44625 .53375 Mdot
.5475 .555 Mdot
.6025 .5725 Mdot
.45375 .60625 Mdot
.45625 .6375 Mdot
.49 .63375 Mdot
.54125 .58875 Mdot
.45875 .5425 Mdot
.495 .50125 Mdot
.245 .475 Mdot
.22375 .49625 Mdot
.5075 .5325 Mdot
.53 .5625 Mdot
.4875 .54125 Mdot
.4525 .52375 Mdot
.54875 .505 Mdot
.54125 .48125 Mdot
.48125 .45375 Mdot
.49125 .46625 Mdot
.465 .47 Mdot
.525 .4725 Mdot
.155 .475 Mdot
.955 .48625 Mdot
.53375 .5475 Mdot
.2925 .59875 Mdot
.51125 .67125 Mdot
.515 .7275 Mdot
.5 .75875 Mdot
.49 .73375 Mdot
.56875 .6725 Mdot
.5125 .60125 Mdot
.38 .5525 Mdot
.455 .53875 Mdot
.58125 .55 Mdot
.4375 .565 Mdot
.49125 .57625 Mdot
.02375 .56125 Mdot
.52375 .555 Mdot
.47125 .555 Mdot
.5625 .55875 Mdot
.42375 .555 Mdot
.50625 .5175 Mdot
.55 .48625 Mdot
.45125 .48 Mdot
.5825 .465 Mdot
.45375 .44125 Mdot
.4325 .46875 Mdot
.14875 .5175 Mdot
.0275 .52875 Mdot
.43125 .5575 Mdot
.4775 .53125 Mdot
.56 .47 Mdot
.5175 .45875 Mdot
.59625 .485 Mdot
.4325 .50125 Mdot
.66875 .50375 Mdot
.39875 .51625 Mdot
.4425 .5525 Mdot
.34 .575 Mdot
.37625 .59625 Mdot
.1275 .71625 Mdot
.52 .70125 Mdot
.47375 .70125 Mdot
.5325 .7225 Mdot
.3425 .695 Mdot
.7025 .6125 Mdot
.4425 .55625 Mdot
.6625 .485 Mdot
.28125 .3975 Mdot
.58 .48875 Mdot
.33625 .485 Mdot
.6675 .47125 Mdot
.5325 .4725 Mdot
.405 .45875 Mdot
.53125 .445 Mdot
.46625 .4775 Mdot
.54375 .53625 Mdot
.4475 .565 Mdot
.1425 .5825 Mdot
.12 .56875 Mdot
.44 .53375 Mdot
.47625 .5075 Mdot
.44125 .5075 Mdot
.38875 .53375 Mdot
.7475 .57875 Mdot
.5425 .57625 Mdot
.3875 .5875 Mdot
.5725 .585 Mdot
.49375 .55125 Mdot
.47875 .5275 Mdot
.4425 .5 Mdot
.115 .49625 Mdot
.10125 .53875 Mdot
.45 .56125 Mdot
.605 .58875 Mdot
.40625 .56 Mdot
.45875 .5475 Mdot
.5075 .51 Mdot
.56125 .485 Mdot
.49125 .4575 Mdot
.56 .46875 Mdot
.475 .455 Mdot
.435 .4875 Mdot
.45375 .47125 Mdot
.3875 .47625 Mdot
.25 .46375 Mdot
.405 .465 Mdot
.4925 .48 Mdot
.5625 .49625 Mdot
.3325 .50125 Mdot
.6675 .50875 Mdot
.49875 .5025 Mdot
.40375 .4925 Mdot
.59875 .4775 Mdot
.53125 .525 Mdot
.4225 .54625 Mdot
.1375 .5425 Mdot
.40625 .5225 Mdot
.49 .5275 Mdot
.4825 .52375 Mdot
.4325 .52625 Mdot
.51625 .5275 Mdot
.46 .535 Mdot
.73875 .465 Mdot
.3825 .42375 Mdot
.43375 .38125 Mdot
.57875 .37 Mdot
.40375 .39 Mdot
.55625 .39 Mdot
.28875 .40375 Mdot
.8825 .43875 Mdot
.255 .4475 Mdot
.55625 .43625 Mdot
.53125 .4575 Mdot
.5175 .4975 Mdot
.37375 .505 Mdot
.5625 .54875 Mdot
.67625 .56875 Mdot
.3275 .6025 Mdot
.58625 .55875 Mdot
.43125 .53125 Mdot
.53125 .4975 Mdot
.2375 .45375 Mdot
.80625 .37875 Mdot
.53 .35125 Mdot
.3475 .35 Mdot
.50875 .305 Mdot
.525 .32875 Mdot
.5025 .38 Mdot
.37 .39 Mdot
.7875 .40375 Mdot
.44875 .40125 Mdot
.355 .3625 Mdot
.485 .32375 Mdot
.53125 .3275 Mdot
.45 .30375 Mdot
.53 .30625 Mdot
.88 .30625 Mdot
.15875 .29375 Mdot
.5325 .27125 Mdot
.43625 .26375 Mdot
.55625 .2425 Mdot
.3375 .24125 Mdot
.665 .25 Mdot
.55125 .25875 Mdot
.4075 .26125 Mdot
.545 .27875 Mdot
.47375 .35875 Mdot
.445 .34375 Mdot
.245 .3 Mdot
.12625 .30125 Mdot
.445 .225 Mdot
.47 .27125 Mdot
.5475 .32375 Mdot
.3775 .32 Mdot
.83625 .2575 Mdot
.36 .21875 Mdot
.6125 .155 Mdot
.41875 .11875 Mdot
.44625 .1025 Mdot
.385 .05125 Mdot
.41875 .015 Mdot
.3725 .13625 Mdot
.56125 .27125 Mdot
.35125 .38875 Mdot
.49 .005 Mdot
.47 .05875 Mdot
.4775 .10375 Mdot
.26875 .15125 Mdot
.80125 .1125 Mdot
.615 .07875 Mdot
.3375 .03875 Mdot
.50125 0 Mdot
.4525 .01125 Mdot
.23625 .01875 Mdot
.43 .02875 Mdot
.99125 .08625 Mdot
.2825 .09625 Mdot
.40875 .12625 Mdot
.58125 .12625 Mdot
.38625 .1575 Mdot
.57125 .20125 Mdot
.375 .25375 Mdot
.715 .28 Mdot
.28375 .3 Mdot
.615 .26875 Mdot
.525 .2225 Mdot
.5625 .16625 Mdot
.305 .17 Mdot
.4975 .15875 Mdot
.84125 .1575 Mdot
.23875 .10875 Mdot
.5975 .08125 Mdot
.425 .06875 Mdot
.5275 .055 Mdot
.34375 .07375 Mdot
.66 .17 Mdot
.535 .22125 Mdot
.395 .17375 Mdot
.5225 .17 Mdot
.52625 .0725 Mdot
.3125 .13375 Mdot
.35875 .2925 Mdot
.515 .47625 Mdot
.50875 .565 Mdot
.47375 .57375 Mdot
.54 .5425 Mdot
.71125 .515 Mdot
.2925 .43 Mdot
.52 .3625 Mdot
.455 .3175 Mdot
.5375 .29125 Mdot
.23 .2825 Mdot
.82125 .29 Mdot
.55625 .31125 Mdot
.37 .36375 Mdot
.52 .45 Mdot
.48375 .57 Mdot
.44875 .6275 Mdot
.365 .64875 Mdot
.9625 .68125 Mdot
.26625 .67875 Mdot
.405 .66625 Mdot
.48875 .67375 Mdot
.53375 .7675 Mdot
.2575 .88875 Mdot
.29375 .5775 Mdot
.5025 .40625 Mdot
.41625 .18125 Mdot
.50375 .99625 Mdot
.19875 .835 Mdot
.2225 .5075 Mdot
.4975 .4 Mdot
.47875 .28 Mdot
.4475 .15625 Mdot
.5025 .115 Mdot
.4825 .12125 Mdot
.55125 .10625 Mdot
.49875 .14 Mdot
.50375 .21375 Mdot
.4725 .34 Mdot
.41625 .3675 Mdot
.24625 .4025 Mdot
.19375 .8325 Mdot
.485 .92375 Mdot
.52375 .5725 Mdot
.65375 .25 Mdot
.21375 .145 Mdot
.48875 .04125 Mdot
.455 .04125 Mdot
.48 .14125 Mdot
.52625 .31625 Mdot
.0025 .365 Mdot
.90625 .42 Mdot
.84625 .45375 Mdot
.17625 .29375 Mdot
.56 .14125 Mdot
.45375 .07375 Mdot
.525 .0625 Mdot
.15875 .11 Mdot
.81375 .08 Mdot
.51375 .03125 Mdot
.76625 .04375 Mdot
.505 .045 Mdot
.4975 .06 Mdot
.47625 .0775 Mdot
.1575 .0475 Mdot
.41375 .0325 Mdot
.01875 .0125 Mdot
.12 .01875 Mdot
.18625 .01 Mdot
.22375 .1975 Mdot
.46375 .21375 Mdot
.4625 .25 Mdot
.4825 .3175 Mdot
.52125 .345 Mdot
.495 .34375 Mdot
.49375 .34125 Mdot
.505 .315 Mdot
.50875 .29375 Mdot
.49375 .3 Mdot
.37 .2975 Mdot
.24125 .29375 Mdot
.21625 .405 Mdot
.50125 .44875 Mdot
.395 .53375 Mdot
.4775 .25875 Mdot
.72 .41625 Mdot
.14 .435 Mdot
.48 .4725 Mdot
.46 .48625 Mdot
.56875 .4825 Mdot
.52 .46 Mdot
.49875 .4475 Mdot
.5175 .4125 Mdot
.4075 .405 Mdot
.6025 .40625 Mdot
.47 .36 Mdot
.52875 .31125 Mdot
.95 .29625 Mdot
.89375 .3275 Mdot
.16 .40125 Mdot
.52375 .47375 Mdot
.48125 .555 Mdot
.4625 .57625 Mdot
.54875 .595 Mdot
.47625 .59625 Mdot
.57125 .61375 Mdot
.42875 .59875 Mdot
.50125 .55125 Mdot
.5275 .5325 Mdot
.5375 .50125 Mdot
.13875 .46625 Mdot
.82625 .4575 Mdot
.5375 .46875 Mdot
.6775 .44625 Mdot
.36125 .46625 Mdot
.37375 .49125 Mdot
.51625 .505 Mdot
.3725 .52625 Mdot
.73125 .53625 Mdot
.4475 .52875 Mdot
.53 .49 Mdot
.415 .465 Mdot
.37 .43875 Mdot
.76 .41625 Mdot
.5275 .45375 Mdot
.20875 .47125 Mdot
.55875 .5 Mdot
.53375 .5175 Mdot
.47875 .51375 Mdot
.525 .515 Mdot
.465 .50125 Mdot
.50125 .49375 Mdot
.46375 .46375 Mdot
.535 .45 Mdot
.53 .4575 Mdot
.4375 .45375 Mdot
.10625 .4325 Mdot
.10375 .43 Mdot
.4325 .41875 Mdot
.50875 .43875 Mdot
.435 .455 Mdot
.56625 .48 Mdot
.51 .5325 Mdot
.50125 .5775 Mdot
.30625 .59375 Mdot
.64125 .59 Mdot
.51875 .54375 Mdot
.5825 .4825 Mdot
.24 .47125 Mdot
.4175 .43375 Mdot
.04125 .51875 Mdot
.56 .56125 Mdot
.52375 .5475 Mdot
.50125 .58625 Mdot
.4725 .58375 Mdot
.46625 .545 Mdot
.525 .53625 Mdot
.405 .51125 Mdot
.605 .49875 Mdot
.5075 .49125 Mdot
.4675 .4625 Mdot
.1025 .4475 Mdot
.115 .4475 Mdot
.33375 .43875 Mdot
.575 .4625 Mdot
.51375 .45375 Mdot
.46375 .43625 Mdot
.51 .4225 Mdot
.525 .43375 Mdot
.4375 .4375 Mdot
.55375 .44 Mdot
.4825 .4425 Mdot
.49375 .46375 Mdot
.14 .46 Mdot
.355 .4225 Mdot
.3875 .4125 Mdot
.53625 .4325 Mdot
.525 .45375 Mdot
.5125 .43125 Mdot
.49875 .46125 Mdot
.42875 .47375 Mdot
.5775 .43375 Mdot
.51 .3975 Mdot
.48125 .445 Mdot
.43875 .4175 Mdot
.24375 .4375 Mdot
.215 .4875 Mdot
.51875 .48375 Mdot
.54125 .50625 Mdot
.4475 .49125 Mdot
.50875 .47625 Mdot
.51375 .47625 Mdot
.4725 .48375 Mdot
.40375 .49125 Mdot
.705 .48625 Mdot
.40125 .465 Mdot
.39875 .4825 Mdot
.3225 .4875 Mdot
.22125 .37875 Mdot
.685 .34 Mdot
.32125 .2975 Mdot
.55375 .505 Mdot
.04125 .51125 Mdot
.6825 .51 Mdot
.235 .5225 Mdot
.35875 .5475 Mdot
.58375 .5625 Mdot
.6125 .61 Mdot
.45875 .6375 Mdot
.4725 .62625 Mdot
.5375 .61375 Mdot
.4125 .585 Mdot
.48 .54375 Mdot
.625 .50875 Mdot
.585 .5025 Mdot
.81125 .48125 Mdot
.80875 .455 Mdot
.2125 .45 Mdot
.43375 .46125 Mdot
.65875 .465 Mdot
.45375 .5275 Mdot
.4975 .54125 Mdot
.47375 .55 Mdot
.54875 .56375 Mdot
.43 .5775 Mdot
.41375 .57125 Mdot
.76375 .56875 Mdot
.44125 .5425 Mdot
.19375 .54875 Mdot
.735 .5425 Mdot
.52625 .505 Mdot
.5275 .49875 Mdot
.46 .52125 Mdot
.56125 .49625 Mdot
.40125 .43125 Mdot
.3775 .41875 Mdot
.705 .4225 Mdot
.46125 .4075 Mdot
.4475 .4075 Mdot
.4625 .3875 Mdot
.4775 .4 Mdot
.685 .38375 Mdot
.0625 .41875 Mdot
.52 .5025 Mdot
.18875 .53 Mdot
.6175 .575 Mdot
.585 .5775 Mdot
.41125 .57875 Mdot
.55375 .58375 Mdot
.47 .5675 Mdot
.4875 .54125 Mdot
.39125 .515 Mdot
.58625 .48375 Mdot
.62125 .47 Mdot
.3925 .46625 Mdot
.20125 .50125 Mdot
.18375 .5225 Mdot
.435 .50125 Mdot
.63 .49375 Mdot
.4225 .455 Mdot
.4825 .4625 Mdot
.555 .46125 Mdot
.50625 .49 Mdot
.25375 .4975 Mdot
.57 .48625 Mdot
.76 .4225 Mdot
.45 .37125 Mdot
.28875 .3275 Mdot
.40375 .32 Mdot
.10375 .3275 Mdot
.45375 .35 Mdot
.77375 .355 Mdot
.3675 .335 Mdot
.475 .33625 Mdot
.46125 .3825 Mdot
.5225 .39375 Mdot
.2725 .40875 Mdot
.85 .4125 Mdot
.46375 .44 Mdot
.40375 .38875 Mdot
.22125 .355 Mdot
.14875 .2775 Mdot
.22125 .225 Mdot
.895 .215 Mdot
.395 .19375 Mdot
.42375 .21375 Mdot
.51125 .24 Mdot
.51625 .2625 Mdot
.3275 .29375 Mdot
.7575 .3175 Mdot
.44 .35875 Mdot
.45375 .3975 Mdot
.24125 .37125 Mdot
.91625 .34625 Mdot
.305 .37375 Mdot
.46875 .3675 Mdot
.62125 .305 Mdot
.47125 .27375 Mdot
.5 .3725 Mdot
.49375 .2875 Mdot
.4125 .2125 Mdot
.45625 .2 Mdot
.7975 .215 Mdot
.35 .12375 Mdot
.42625 .14375 Mdot
.36125 .12375 Mdot
.87625 .11 Mdot
.135 .09875 Mdot
.73375 .0625 Mdot
.5675 .05625 Mdot
.39 .075 Mdot
.49 .0825 Mdot
.50875 .065 Mdot
.45 .03125 Mdot
.265 .04375 Mdot
.4 .02125 Mdot
.44375 .01875 Mdot
.86125 .14875 Mdot
.24125 .255 Mdot
.85625 .26625 Mdot
.18 .395 Mdot
.7525 .2075 Mdot
.06375 .225 Mdot
.85375 .2325 Mdot
.67125 .2175 Mdot
.3 .13125 Mdot
.26125 .06375 Mdot
.7125 .025 Mdot
.46125 .07625 Mdot
.54375 .13875 Mdot
.4275 .19375 Mdot
.2925 .22875 Mdot
.86125 .28375 Mdot
.615 .33875 Mdot
.0125 .33125 Mdot
.71625 .35125 Mdot
.71875 .34875 Mdot
.3175 .2925 Mdot
.265 .16625 Mdot
.87875 .08 Mdot
.29375 .02625 Mdot
.3025 .055 Mdot
.61625 .05625 Mdot
.54875 .07875 Mdot
.3875 .03625 Mdot
.4775 .01375 Mdot
.34125 .0325 Mdot
.53125 .0825 Mdot
.59375 .17625 Mdot
.59125 .2675 Mdot
.22 .27125 Mdot
.81125 .2375 Mdot
.535 .17625 Mdot
.1825 .145 Mdot
.665 .095 Mdot
.66125 .11375 Mdot
.32875 .1375 Mdot
.55875 .14875 Mdot
.45125 .11 Mdot
.5 .11625 Mdot
.32 .17125 Mdot
.67 .23 Mdot
.665 .2375 Mdot
.36375 .1925 Mdot
.3025 .12125 Mdot
.885 .0575 Mdot
.295 .00625 Mdot
.38 .00875 Mdot
.7975 .0225 Mdot
.38 .03625 Mdot
.32375 .23625 Mdot
.32 .31 Mdot
.44625 .31 Mdot
.90875 .3125 Mdot
.11875 .225 Mdot
.4925 .04625 Mdot
.9075 .04375 Mdot
.255 .1 Mdot
.46 .16 Mdot
.47125 .11625 Mdot
.51375 .07125 Mdot
.165 .07125 Mdot
.40625 .11375 Mdot
.3575 .1825 Mdot
.3325 .22625 Mdot
.945 .20375 Mdot
.25625 .19875 Mdot
.08875 .165 Mdot
.24625 .29875 Mdot
.4 .36 Mdot
.52 .36125 Mdot
.51 .36375 Mdot
.2075 .34375 Mdot
.9775 .3775 Mdot
.3775 .51 Mdot
.42875 .6225 Mdot
.3425 .76 Mdot
.77 .88875 Mdot
.23375 .99125 Mdot
.10375 .97875 Mdot
.945 .99375 Mdot
.21 .9225 Mdot
.0225 .38375 Mdot
.6375 .9775 Mdot
.36125 .90375 Mdot
.18 .8775 Mdot
.87125 .8925 Mdot
.67875 .9125 Mdot
.53375 .95 Mdot
.43875 .88625 Mdot
.1375 .91625 Mdot
.6525 .9975 Mdot
.24875 .9925 Mdot
.77 .99375 Mdot
.445 .86875 Mdot
.6175 .69375 Mdot
.185 .56625 Mdot
.6275 .59875 Mdot
.84875 .62625 Mdot
.29625 .645 Mdot
.47375 .66125 Mdot
.4675 .7275 Mdot
.485 .69875 Mdot
.11 .665 Mdot
.05125 .60375 Mdot
.41875 .58375 Mdot
.51625 .65375 Mdot
.53625 .78 Mdot
.04625 .83125 Mdot
.51875 .84375 Mdot
.27 .77375 Mdot
.49375 .64375 Mdot
.50375 .63875 Mdot
.4175 .5375 Mdot
.4525 .07375 Mdot
.235 .26125 Mdot
.12375 .55 Mdot
.5175 .53375 Mdot
.585 .61375 Mdot
.435 .75375 Mdot
.09125 .82625 Mdot
.6975 .85125 Mdot
.20375 .75125 Mdot
.47625 .635 Mdot
.545 .67375 Mdot
.4625 .67 Mdot
.65875 .35 Mdot
.1725 .14 Mdot
.565 .05 Mdot
.48 .1075 Mdot
.4325 .17625 Mdot
.00125 .21625 Mdot
.35125 .175 Mdot
.3 .09375 Mdot
.4775 .04875 Mdot
.5375 .145 Mdot
.31625 .12 Mdot
.24375 .06625 Mdot
.16 .04125 Mdot
.6925 .08125 Mdot
.08875 .0775 Mdot
.5075 .03625 Mdot
.49625 .1975 Mdot
.12875 .29875 Mdot
.75125 .33625 Mdot
.73125 .3625 Mdot
.44875 .245 Mdot
.39875 .075 Mdot
.5725 .06 Mdot
.5725 .1225 Mdot
.1575 .1725 Mdot
.7725 .2675 Mdot
.79625 .35625 Mdot
.13 .3275 Mdot
.5325 .26875 Mdot
.4625 .28875 Mdot
.5075 .3225 Mdot
.195 .30875 Mdot
.85875 .27375 Mdot
.71625 .2 Mdot
.30125 .09375 Mdot
.42875 .00875 Mdot
.51875 .0575 Mdot
.5125 .0875 Mdot
.25125 .1275 Mdot
.175 .1075 Mdot
.34 .0075 Mdot
.57625 .0425 Mdot
.6 .18875 Mdot
.105 .18625 Mdot
.40625 .15875 Mdot
.03375 .07375 Mdot
.5175 .01 Mdot
.26125 .0475 Mdot
.38625 .04875 Mdot
.4975 .12 Mdot
.4675 .21125 Mdot
.235 .25375 Mdot
.695 .23 Mdot
.8625 .17 Mdot
.22625 .1 Mdot
.4825 .0475 Mdot
.47375 .095 Mdot
.475 .11125 Mdot
.06125 .13875 Mdot
.43 .105 Mdot
.505 .15125 Mdot
.485 .1725 Mdot
.0475 .17 Mdot
.52 .175 Mdot
.23875 .135 Mdot
.49 .1275 Mdot
.4975 .205 Mdot
.40375 .28875 Mdot
0 .3625 Mdot
.54 .6625 Mdot
.61625 .69875 Mdot
.4175 .71625 Mdot
.205 .7175 Mdot
.165 .21125 Mdot
.46125 .1325 Mdot
.4875 .1325 Mdot
.40875 .145 Mdot
.17125 .135 Mdot
.54125 .14875 Mdot
.20125 .15375 Mdot
.47 .14875 Mdot
.5375 .235 Mdot
.4075 .29 Mdot
.52375 .40875 Mdot
.25375 .38875 Mdot
.5225 .35875 Mdot
.4475 .3725 Mdot
.44375 .38 Mdot
.25625 .355 Mdot
.2725 .33625 Mdot
.49375 .36875 Mdot
.51625 .45 Mdot
.30875 .5 Mdot
.105 .55875 Mdot
.45 .595 Mdot
.4725 .56125 Mdot
.49 .48625 Mdot
.13875 .42375 Mdot
.57625 .37875 Mdot
.04375 .3125 Mdot
.43875 .31625 Mdot
.505 .33 Mdot
.49375 .32875 Mdot
.10125 .32625 Mdot
.7175 .3425 Mdot
.8825 .345 Mdot
.39 .33625 Mdot
.38625 .39 Mdot
.555 .4425 Mdot
.54875 .49125 Mdot
.17625 .54375 Mdot
.775 .58375 Mdot
.77 .565 Mdot
.0525 .5625 Mdot
.71875 .56125 Mdot
.39875 .55625 Mdot
.485 .555 Mdot
.2225 .5575 Mdot
.83375 .53375 Mdot
.61625 .50875 Mdot
.3425 .50125 Mdot
.6625 .49375 Mdot
.35 .5075 Mdot
.50125 .5375 Mdot
.235 .57375 Mdot
.10875 .64 Mdot
.365 .6375 Mdot
.7225 .61 Mdot
.48625 .5775 Mdot
.155 .5825 Mdot
.40125 .56875 Mdot
.3325 .5875 Mdot
.60875 .58625 Mdot
.49125 .53875 Mdot
.27875 .525 Mdot
.61 .52875 Mdot
.00875 .55125 Mdot
.54375 .6375 Mdot
.54 .65875 Mdot
.4075 .67375 Mdot
.3525 .555 Mdot
.19125 .53875 Mdot
.78625 .53625 Mdot
.40125 .54125 Mdot
.39 .51875 Mdot
.3775 .49875 Mdot
.6875 .50625 Mdot
.38 .52125 Mdot
.07 .5225 Mdot
.28375 .505 Mdot
.25125 .48875 Mdot
.66375 .485 Mdot
.4825 .47875 Mdot
.235 .45125 Mdot
.69125 .44375 Mdot
.7875 .45 Mdot
.21 .43375 Mdot
.54375 .395 Mdot
.525 .4075 Mdot
.42375 .42625 Mdot
.135 .43 Mdot
.04875 .48625 Mdot
.34625 .505 Mdot
.66875 .50125 Mdot
.45875 .4725 Mdot
.08625 .4525 Mdot
.445 .44125 Mdot
.25 .43875 Mdot
.53 .49 Mdot
.5875 .53375 Mdot
.34875 .57125 Mdot
.08875 .5875 Mdot
.43875 .56 Mdot
.825 .50375 Mdot
.34625 .45125 Mdot
.26375 .41625 Mdot
.9525 .51375 Mdot
.2275 .53375 Mdot
.44375 .5575 Mdot
.46 .57 Mdot
.34 .55 Mdot
.2825 .535 Mdot
.3375 .45625 Mdot
.25 .4275 Mdot
.48125 .4425 Mdot
.51 .44375 Mdot
.36125 .4525 Mdot
.0175 .43375 Mdot
.395 .35875 Mdot
.36 .34125 Mdot
.51625 .3175 Mdot
.46125 .34125 Mdot
.46875 .39125 Mdot
.1375 .48875 Mdot
.30875 .4925 Mdot
.495 .445 Mdot
.53875 .41625 Mdot
.28875 .39 Mdot
.0725 .36125 Mdot
.46625 .38 Mdot
.46875 .40625 Mdot
.47375 .49625 Mdot
.2375 .54 Mdot
.40625 .55875 Mdot
.1075 .57875 Mdot
.4275 .52125 Mdot
.47125 .51125 Mdot
.50875 .59375 Mdot
.17375 .6175 Mdot
.64625 .655 Mdot
.945 .66625 Mdot
.33125 .72 Mdot
.395 .65625 Mdot
.525 .66 Mdot
.56 .6525 Mdot
.28 .6425 Mdot
.69875 .5725 Mdot
.69 .54875 Mdot
.0025 .53125 Mdot
.9125 .50625 Mdot
.3325 .51 Mdot
.4775 .5075 Mdot
.29375 .49375 Mdot
.76125 .49625 Mdot
.46375 .47875 Mdot
.37875 .43375 Mdot
.89 .40125 Mdot
.275 .4025 Mdot
.47375 .40875 Mdot
.3 .4175 Mdot
.075 .4875 Mdot
.42125 .49875 Mdot
.88625 .47125 Mdot
.34375 .49375 Mdot
.26625 .47375 Mdot
.42375 .42625 Mdot
.36 .35875 Mdot
.735 .39 Mdot
.36875 .39875 Mdot
.40875 .4 Mdot
.65625 .40125 Mdot
.83125 .40375 Mdot
.08875 .35 Mdot
.65375 .33375 Mdot
.57625 .34875 Mdot
.31375 .32 Mdot
.12 .28 Mdot
.37375 .2825 Mdot
.14875 .285 Mdot
.98375 .3175 Mdot
.34375 .3775 Mdot
.37 .39 Mdot
.0475 .34625 Mdot
.04375 .20375 Mdot
.34625 .1225 Mdot
.8575 .15125 Mdot
.295 .1625 Mdot
.19125 .15875 Mdot
.34625 .1925 Mdot
.185 .15 Mdot
.81375 .10375 Mdot
.4825 .13875 Mdot
.2325 .16875 Mdot
.6775 .19125 Mdot
.68625 .22875 Mdot
.24375 .28375 Mdot
.57 .32125 Mdot
.57 .355 Mdot
.3925 .3025 Mdot
.275 .26125 Mdot
.18375 .115 Mdot
.26 .01 Mdot
.82125 .07125 Mdot
.435 .0875 Mdot
.19875 .07125 Mdot
.9775 .06 Mdot
.43375 .04625 Mdot
.28375 .045 Mdot
.32 .19 Mdot
.8075 .345 Mdot
.255 .46125 Mdot
.7175 .45375 Mdot
.31 .51125 Mdot
.44625 .35875 Mdot
.45 .3425 Mdot
.27 .4325 Mdot
.39625 .44375 Mdot
.1625 .61625 Mdot
.30375 .66875 Mdot
.49 .52 Mdot
.49875 .44 Mdot
.3325 .44875 Mdot
.13125 .45625 Mdot
.31 .52875 Mdot
.46 .58125 Mdot
.5275 .5475 Mdot
.4775 .56375 Mdot
.46125 .58375 Mdot
.08875 .615 Mdot
.34875 .575 Mdot
.49 .5725 Mdot
.5175 .52375 Mdot
.295 .4675 Mdot
.1625 .43875 Mdot
.46875 .41 Mdot
.455 .53875 Mdot
.46625 .45125 Mdot
.30625 .3675 Mdot
.28375 .29625 Mdot
.2125 .0225 Mdot
.38375 .0425 Mdot
.47375 .1675 Mdot
.50125 .1175 Mdot
.2725 .21375 Mdot
.56125 .31625 Mdot
.27375 .545 Mdot
.385 .74125 Mdot
.50375 .7925 Mdot
.58625 .81 Mdot
.3475 .7 Mdot
.62375 .53625 Mdot
.6075 .50375 Mdot
.29 .7025 Mdot
.44625 .97125 Mdot
.67875 .9775 Mdot
.41875 .99625 Mdot
.855 .6825 Mdot
.0475 .47375 Mdot
.46375 .25375 Mdot
.18125 .5375 Mdot
.36875 .68875 Mdot
.46125 .65625 Mdot
.99875 .5225 Mdot
.0125 .31875 Mdot
.40625 .0925 Mdot
.89625 .03 Mdot
.19375 .14 Mdot
.56 .27375 Mdot
.61625 .2875 Mdot
.68875 .30875 Mdot
.135 .39125 Mdot
.765 .37625 Mdot
.64625 .54875 Mdot
.18875 .765 Mdot
.25 .9675 Mdot
.95625 .9625 Mdot
.4 .92875 Mdot
.09 .80125 Mdot
.3 .72125 Mdot
.34625 .8175 Mdot
.20375 .95125 Mdot
.575 .96375 Mdot
.5725 .6825 Mdot
.545 .6225 Mdot
.38 .5825 Mdot
.4625 .76125 Mdot
.46 .75875 Mdot
.25125 .64 Mdot
.5025 .62875 Mdot
.12125 .42625 Mdot
.36125 .38875 Mdot
.52625 .545 Mdot
.48125 .61 Mdot
.33125 .57875 Mdot
.27 .58875 Mdot
.2525 .55875 Mdot
.5275 .535 Mdot
.5375 .62125 Mdot
.485 .5725 Mdot
.46625 .505 Mdot
.0675 .47 Mdot
.1275 .4 Mdot
.345 .44625 Mdot
.515 .475 Mdot
.5075 .5275 Mdot
.3325 .60375 Mdot
.2775 .65125 Mdot
.075 .76375 Mdot
.47 .7175 Mdot
.455 .5675 Mdot
.48 .58 Mdot
.4125 .64375 Mdot
.19375 .73125 Mdot
.47875 .85125 Mdot
.50375 .77375 Mdot
.3775 .63 Mdot
.49125 .5025 Mdot
.98 .33875 Mdot
.2775 .31125 Mdot
.3975 .19375 Mdot
.51375 .12875 Mdot
.5425 .085 Mdot
.42875 .155 Mdot
.56875 .32125 Mdot
.51125 .3625 Mdot
.0025 .38125 Mdot
.29125 .2225 Mdot
.5925 .03375 Mdot
.4525 .0075 Mdot
.515 .015 Mdot
.70125 .285 Mdot
.055 .485 Mdot
.46375 .72 Mdot
.055 .50375 Mdot
.4525 .36 Mdot
.5225 .4075 Mdot
.71125 .55 Mdot
.085 .76875 Mdot
.14375 .93875 Mdot
.63375 .7875 Mdot
.5575 .7375 Mdot
.60125 .7275 Mdot
.225 .67125 Mdot
.81 .67125 Mdot
.67125 .47375 Mdot
.11125 .28625 Mdot
.39875 .13125 Mdot
.6975 .20125 Mdot
.47375 .24125 Mdot
.0275 .38 Mdot
.3175 .34125 Mdot
.3025 .2325 Mdot
.3675 .14125 Mdot
.755 .2075 Mdot
.33625 .16625 Mdot
.18375 .26125 Mdot
.12375 .15875 Mdot
.3975 .04 Mdot
.67375 .16375 Mdot
.4075 .25375 Mdot
.06875 .3375 Mdot
.53125 .22375 Mdot
.2325 .0725 Mdot
.60125 .06875 Mdot
.51375 .14 Mdot
.315 .18375 Mdot
.61625 .20625 Mdot
.69125 .14125 Mdot
.305 .0475 Mdot
.62375 .1075 Mdot
.44125 .15125 Mdot
.06 .17625 Mdot
.34875 .025 Mdot
.175 .065 Mdot
.46875 .03125 Mdot
.26375 .22625 Mdot
.885 .43125 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00d?oooone
o`0000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool01Ol0003ooooooooooooooooo
003o00?ooooo0_l00?l2ooooo`;o003o00?oooooo`00ooooool08Oooool01?l00?ooooooo`00ool0
0?l3ooooo`03o`00oooooooooooo00;o003o0oooool2o`00o`03ooooool00?oooooo00Co003o00Oo
ooooo`00ool00?oo003oooooool00?oooooo00go003o0oooool00ol00?ooooooo`00o`05ooooo`03
o`00oooooooooooo01Sooooo00?o003oooooool00?l05_ooool01Ol00?oooooooooooooooooo003o
01;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`04
o`000?ooooooooooo`00oagooooo00Co003ooooooooooooo003o2_ooool01?l00?ooooooooooool0
0?l3ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00;ooooo2?l00?l4ooooo`?o003o00?oooooo`00ool00?l00_l00?l01?oooooo003o
o`00ool00?l7ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool08?ooool01?l00?oo
ooooooooool00?l?ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool000[o
oooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo01?ooooo00?o003ooooooooo
ool01?ooool00ol00?ooooooooooo`0;ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol0
0?ooooooooooo`0?ooooo`05o`00ooooooooooooo`00ooooool00_l00?l00ooooooo003oo`00o`04
o`00o`;ooooo0ol00?l00ooooooo003oo`00o`02o`00o`;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooo`00o`09ooooo`03o`00oooooooo003o037ooooo00?o003oooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo017ooooo0_l00?l01?oo
oooo003oooooool00?l2ooooo`06o`00oooooooo003oo`00oooooooo003o1?ooool2o`00o`;ooooo
00Co003oooooool00?oo003o1?ooool2o`00o`03ooooool00?oo003o00Kooooo00?o003ooooooooo
ool04Ol00?l2ooooo`;o003o0_ooool00ol00?ooooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01oooool00ol00?ooooooooooo`02ooooo`;o003o0_ooool01?l00?ooooooo`00ool00?l6
ooooo`04o`00ooooooooooooo`00o`gooooo00?o003oooooooooool04oooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool02?ooool0
1Ol00?oooooooooooooooooo003o00cooooo00?o003oooooooooool03oooool01?l00?oooooooooo
ooooool2o`00o`03ooooool00?oooooo00;ooooo00Wo003oooooooooooooooooo`00oooooooo003o
ooooool00?l00_ooool01?l00?ooooooo`00ooooool2o`00o`?ooooo00Ko003oooooool00?oooooo
o`00ooooool:o`00o`;ooooo0_l00?l2ooooo`03o`00oooooooo003o00Kooooo00Go003ooooooooo
ooooooooo`00o`0Kooooo`03o`00oooooooooooo01;ooooo0_l00?l=ooooo`05o`00oooooooooooo
ooooool000002oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo
00[ooooo00?o003oooooool00?l01_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo
oooo00Wooooo00Go003oooooooooooooooooo`00o`05ooooo`03o`00oooooooooooo00?ooooo0_l0
0?l01?oooooo003oooooool00?l5ooooo`;o003o00?oooooo`00ool00?l00_ooool00ol00?oooooo
ooooo`02oooooa7o003o00?oooooo`00ool00?l00_ooool00ol00?ooooooo`00o`03ooooo`03o`00
oooooooooooo00oooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o01?o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`04ooooo`03o`00
oooooooooooo01?ooooo00?o003oooooooooool05?ooool00ol00?ooooooooooo`02ooooo`07o`00
ooooooooooooooooool00?ooooooo`00o`02ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003o
ooooool00?l00_l00?l4ooooo`;o003o00Goooooo`00oooooooo003oooooo`03o`00o`;ooooo0_l0
0?l02?oooooo003oo`00ool00?ooooooo`00oooooooo003o2?ooool00ol00?ooooooooooo`08oooo
o`;o003o0oooool01ol00?oooooooooooooooooo003oooooool00?l04_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo013ooooo00?o003oo`000?ooool02_ooool000[ooooo00?o0000
0?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool00_l00?l5
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooool00?l00oooool01?l00?oooooooooooooo
ool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooool00?l00_l00?l5ooooo`05o`00oooo
ooooooooooooool00?l00_ooool4o`00o`;ooooo00Co003oooooool00?oooooo4?l00?l00ooooooo
003oo`00o`04o`00o`?ooooo00?o003oooooool00?l00oooool00ol00?ooooooo`00o`02ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`02o`00o`03
ooooool00?oooooo00[ooooo00Ko003ooooooooooooo003oooooool00?l2ooooo`03o`00oooooooo
oooo00;ooooo00?o003oooooooooool03_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l04?ooool3o`00o`;ooooo00Go003ooooo
ool00?oo003oooooo`03o`00o`03ooooool00?oo003o00Oo003o00?oooooo`00ooooool01?l00?l0
0ooooooo003oo`00o`04o`00o`?ooooo00?o003oooooool00?l01Oooool00ol00?ooooooo`00o`03
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0A
ooooo`03o`00oooooooooooo01?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?oo
O`3oogl0/@3ooglBooooo`03o`000?oooooooooo01oooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`08ooooo`05o`00oooooooo003oooooool00?l01?ooool01_l00?ooooooo`00ool0
0?ooooooo`00o`Cooooo00?o003oooooooooool00_l00?l2ooooo`?o003o0_ooool?o`00o`04oooo
ool00?oo003oo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooooooooooo003o
00?ooooo00?o003oooooooooool00_l00?l3ooooo`04o`00ooooooooooooo`00o`Wooooo00?o003o
ooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo0_l00?l5
ooooo`;o003o1oooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`08ooooo`03o`00oooooooooooo
00cooooo0_l00?l6ooooo`05o`00ooooooooooooooooool00?l01?ooool01Ol00?oooooooooooooo
oooo003o00Gooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`;o003o0ooo
ool2o`00o`03ooooool00?oo003o00;ooooo00?o003oooooooooool01Ol00?l00ooooooo003oo`00
o`03o`00o`04ooooool00?ooooooo`00o`Gooooo00?o003oooooooooool00_ooool01?l00?oooooo
ooooool00?lDooooo`03o`00oooooooooooo00Sooooo00Go003oooooooooooooooooo`00o`0@oooo
o`03o`00oooooooooooo00Wooooo00Go003oooooool00?ooooooo`00000;ooooo`002_ooool00ol0
0000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool00oooool00ol00?ooooooo`00o`06oooo
o`08o`00ooooooooooooo`00oooooooo003oooooool00?l8ooooo`07o`00ooooooooooooooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00?o003o1?ooool01?l00?ooooooo`00ool00?l8
ooooo`?o003o00Coooooo`00oooooooo003o0_ooool00ol00?ooooooooooo`02ooooo`?o003o00?o
ooooo`00ool00?l00_l00?l01Ooooooo003oo`00ool00?oooooo00Co003o00Coooooo`00ool00?oo
003o1Oooool01Ol00?ooooooooooool00?oooooo00?o003o2Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0>oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool00oooool2o`00o`Ko
oooo00?o003oooooooooool02Oooool02?l00?ooooooo`00oooooooo003oooooool00?oooooo0ol0
0?l5ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`;o003o0oooool00ol00?ooooooo`00o`03o`00o`03ooooool00?oooooo00Gooooo
0_l00?l00ooooooo003oo`00o`0:o`00o`Kooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`;o003o2Oooool2o`00o`Sooooo00Go003oooooooooooooooooo`00o`07ooooo`09
o`00oooooooo003oooooool00?ooooooo`00oooooooo003o01Oooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00gooooo00?o003o
ooooooooool03_ooool00ol00?ooooooooooo`09ooooo`05o`00ooooooooooooooooool00?l01_oo
ool01?l00?ooooooo`00ool00?l5ooooo`030?l00?oooooooooo00?o003o00?oooooo`00ool00?l0
0_l00?l00ooooooo003oooooo`02o`00o`03ooooool00?oo003o00Co003o00Goooooo`00ool00?oo
003oooooo`02o`00o`03ooooool00?oo003o00;o003o1Oooool00ol00?ooooooooooo`03ooooo`?o
003o0_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00_ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40
oomo4_ooool00ol0003oooooooooo`09ooooo`03o`00oooooooo003o00kooooo00?o003ooooooooo
ool01Oooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00o`07ooooo`04o`00oooo
ooooooooooooo`?o003o00?oooooo`00ool00?l00_ooool2o`00o`03ooooool00?oooooo00Co003o
0_ooool2o`00o`04ooooool00?oo003oo`00o`;ooooo2?l00?l00ooooooo003oooooo`07o`00o`;o
oooo00Go003oooooooooooooooooo`00o`02ooooo`05o`00ooooooooooooooooool00?l02Oooool2
o`00oa7ooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo
oooooooo017ooooo00?o003oo`000?ooool02_ooool000[ooooo00?o00000?ooO`3oogl0/@3ooglB
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool01?l00?oooooooooooooo
ool2o`00o`Gooooo00Co003oooooool00?oooooo0_l00?l01_oooooo003oooooool00?ooooooo`00
o`Gooooo00Co003ooooooooooooo003o0oooool01?l00?ooooooo`00ool00?l3ooooo`?o003o0_oo
ool8o`00o`;ooooo00Co003ooooooooooooo003o2Oooool00ol00?ooooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooool00?l00_ooool2o`00oa;ooooo00?o003oooooooooool0
1Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o
0000ooooooooool02oooool2o`00o`?ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooo003o00Sooooo00?o003oooooool00?l00ol00?l00ooooooo003ooooo
o`07ooooo`;o003o1Oooool2o`00o`03ooooool00?oo003o00;ooooo0ol00?l01?oooooo003oo`00
ooooool4o`00o`04ooooool00?oo003oooooo`Co003o00?oooooo`00ooooool00oooool00ol00?oo
ooooooooo`0<ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool02Oooool01Ol0
0?oooooooooooooooooo003o00;ooooo00?o003oooooooooool01Oooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00Go0000ooooooooooooooooo`00o`0C
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01oooool3o`00o`05ooooool00?oo
ooooooooool00?l00oooool2o`00o`Oooooo00?o003oooooool00?l00_ooool2o`00o`?ooooo00?o
003oooooooooool00_l00?l4ooooo`Co003o1?ooool00ol00?ooooooo`00o`07o`00o`;ooooo0_l0
0?l2ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooo`00
o`07ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool01?ooool00ol00?oooooooooo
o`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo01?ooooo00Go003oooooooooooooooooo`00
o`08ooooo`04o`00ooooooooooooo`00o`?ooooo0_l00?l00ooooooo003oooooo`03ooooo`04o`00
oooooooo003oooooo`;o003o00Goooooo`00ooooooooooooo`00o`02ooooo`07o`00oooooooooooo
o`00oooooooo003oooooo`0;o`00o`05ooooool00?ooooooo`00ooooool00_l00?l2ooooo`05o`00
ooooooooooooooooool00?l01?ooool02Ol00?oooooooooooooooooo003oooooool00?ooooooo`00
o`0Booooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0=ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0/@3ooglBooooo`03o`000?oooooo003o00kooooo00Wo003oooooool00?oooooo0?l0
0?oooooo003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00Go
oooo00?o003oooooool00?l03oooool01Ol00?ooooooo`00oooooooo003o00Gooooo00[o003ooooo
ool00?ooooooo`00oooooooo003oooooool00?oooooo0ol00?l00ooooooo003oo`00o`04o`00o`;o
oooo1Ol00?l00ooooooo003oo`00o`09ooooo`;o003o1oooool01?l00?ooooooooooooooool3o`00
o`Sooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool04Oooool00ol00?ooooooo`00000;ooooo`002_ooool00ol00000
oomo0?ooO`2a0?ooOa;ooooo00Go0000o`00ooooooooooooo`00o`0Aooooo`03o`00oooooooooooo
00Sooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooo`00ooooool00_l0
0?l2ooooo`03o`00oooooooo003o00?ooooo00Co003ooooooooooooo003o1?ooool00ol00?oooooo
ooooo`02ooooo`;o003o0_ooool01_l00?ooooooo`00oooooooo003oooooo`;o003o00?oooooo`00
ool00?l02_l00?l00ooooooo003oooooo`03o`00o`;ooooo0_l00?l00ooooooo003oooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00Co003ooooooooooooo003o3_ooool00ol00?ooooooooooo`0I
ooooo`04o`00ooooooooooooo`0000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool0
0ol0003oooooooooo`0Iooooo`03o`00oooooooooooo00?ooooo00Co003oooooool00?oo003o0ooo
ool01?l00?ooooooooooool00?l2ooooo`04o`00ooooooooooooooooo`;o003o00Ooooooo`00ool0
0?ooooooo`00oooooooo003o00;ooooo1?l00?l2ooooo`04o`00oooooooo003oooooo`?o003o00Co
ooooo`00ool00?oooooo2_l00?l00ooooooo003oo`00o`03o`00o`05ooooool00?oo003oooooool0
0?l00_ooool2o`00o`;ooooo0_l00?l5ooooo`05o`00ooooooooooooooooool00?l06Oooool00ol0
0?ooooooooooo`08ooooo`030?l00?oooooooooo00cooooo00?o003oooooooooool02?ooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000oooooooo
ool03_ooool00ol00?ooooooooooo`08ooooo`;o003o2oooool01_l00?oooooooooooooooooo003o
ooooo`?o003o1?ooool01?l00?ooooooooooooooool2o`00o`03ooooool00?oooooo00Kooooo1?l0
0?l00ooooooo003oooooo`02ooooo`Co003o00?oooooo`00ooooool01_l00?l01_oooooo003oo`00
ool00?ooooooo`00o`Gooooo00Co003ooooooooooooo003o1oooool00ol00?ooooooooooo`02oooo
o`;o003o2Oooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool0
0ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Sooooo00Go003oooooooooooooooooo`00
o`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00Co003ooooooooooooo003o0ooo
ool01_l00?ooooooooooool00?ooooooo`00o`;ooooo00?o003oooooooooool01_ooool00ol00?oo
ooooo`00o`02o`00o`;ooooo00?o003oooooooooool00oooool01?l00?ooooooo`00ool00?l2oooo
o`Oo003o00Coooooo`00ool00?oooooo1ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo
003o00Gooooo0_l00?l8ooooo`04o`00ooooooooooooo`00o`kooooo0_l00?l4ooooo`05o`00oooo
ooooooooooooool00?l00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003o003oooooo`08ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo003o00?ooooo
00?o003oooooooooool00oooool01ol00?oooooooooooooooooo003oooooool00?l01?ooool00ol0
0?ooooooo`00o`03ooooo`;o003o0_ooool00ol00?ooooooooooo`02o`00o`Oooooo1?l00?l4oooo
o`;o003o00?oooooo`00ool00?l02?l00?l2ooooo`;o003o0_ooool00ol00?ooooooo`00o`02o`00
o`Sooooo0_l00?l8ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`08
ooooo`03o`00oooooooooooo00?ooooo00Go003oooooooooooooooooo`00o`0:ooooo`030?l00?oo
oooooooo00;ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool01oooool2o`00o`[ooooo0_l00?l6
ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003oooooool00?oooooo0_l00?l00ooooooo003o
ooooo`05ooooo`03o`00oooooooooooo00;ooooo1?l00?l3ooooo`03o`00oooooooo003o00Gooooo
0_l00?l2ooooo`03o`00o`3o003ooooo00?o003o0_ooool00ol00?ooooooo`00o`06o`00o`04oooo
ool00?oo003oooooo`?o003o00Coooooo`00oooooooo003o0_ooool01?l00?ooooooooooool00?l7
ooooo`04o`00oooooooo003oooooo`;o003o0_ooool01?l00?ooooooooooool00?l7ooooo`05o`00
oooooooo003oooooool00?l03Oooool00ol00?ooooooooooo`06ooooo`;o003o3?ooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo
4_ooool00ol0003oooooooooo`06ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
2oooool00ol00?ooooooooooo`02o`00o`05ooooool00?ooooooooooool00?l00oooool00ol00?oo
ooooooooo`03ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003oooooool00?oo003o0oooool0
0ol00?ooooooooooo`02o`00o`;ooooo0_l00?l00ooooooo003oooooo`02o`00o`04ooooool00?oo
003oooooo`Go003o00?oooooo`00ool00?l02?l00?l2ooooo`04o`00oooooooo003oooooo`;o003o
0_ooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooo`00o`0<ooooo`;o003o2Oooool00ol00?ooooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003ooooo
ooooo`09ooooo`05o`00ooooooooooooooooool00?l02?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00;ooooo0_l00?l:ooooo`?o003o0_ooool4o`00o`?ooooo00Go003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00;o003o0_ooool01Ol00?ooooooooooool00?oo
oooo00Co003o00?oooooo`00ool00?l02Ol00?l00ooooooo003oo`00o`02ooooo`03o`00oooooooo
oooo00Oooooo0_l00?l<ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool02?ooool2
o`00o`;ooooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`02ooooo`;o003o00?ooooo
o`00ooooool01_ooool00ol00?ooooooooooo`0:ooooo`03o`00ool0003ooooo00[ooooo000:oooo
o`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooo`00o`05ooooo`03o`00oooooooooooo
00Kooooo00Ko003oooooool00?oo003oooooool00?l9ooooo`05o`00oooooooo003oooooool00?l0
2_ooool01Ol00?ooooooooooool00?oooooo00;o003o00?oooooo`00ool00?l00_l00?l2ooooo`03
o`00oooooooooooo00?o003o0oooool01?l00?ooooooooooool00?l3ooooo`;o003o0_ooool4o`00
o`03ooooool00?oo003o00So003o00Coooooo`00ool00?oo003o0_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00?ooooo0_l00?l6ooooo`03o`00oooooooooooo00Oooooo00Co003o
ooooool00?oo003o1oooool00ol00?ooooooo`00o`0Booooo`03o`00oooooooooooo00[ooooo00Go
003oooooooooooooooooo`00000;ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o
003oooooool00?l01?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Kooooo
00?o003oooooooooool00_ooool01?l00?ooooooooooool00?l:ooooo`03o`00oooooooooooo00Co
003o00Coooooo`00oooooooooooo0_l00?l2ooooo`05o`00ooooooooooooooooool00?l01_ooool0
1?l00?ooooooo`00ooooool4o`00o`Kooooo3ol00?l01Ooooooo003ooooooooooooo003o00?ooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0=ooooo`;o003o0_ooool00ol00?oooooo
o`00o`05ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02Oooool00ol00?oooooo
ooooo`0?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_oo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo017ooooo00Go003ooooooooooooooooo
o`00o`03ooooo`;o003o1?ooool01?l00?ooooooooooool00?l3ooooo`03o`00oooooooooooo00;o
oooo0ol00?l00ooooooo003oo`00o`03ooooo`04o`00ooooooooooooooooo`?o003o00?oooooo`00
ool00?l00_l00?l00ooooooo003oo`00o`06o`00o`03ooooool00?oo003o00?o003o00?oooooo`00
ooooool00_l00?l02_oooooo003oooooool00?ooooooo`00oooooooo003oooooool00?l2ooooo`03
o`00oooooooo003o00;ooooo00?o003oooooooooool00oooool2o`00oaCooooo00?o003ooooooooo
ool00_l00?l00ooooooo003oooooo`04ooooo`04o`00ooooooooooooo`00o`Kooooo00?o003ooooo
ooooool03oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;o
oooo00?o0000ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`04o`00ooooooooooooo`00
o`Oooooo0ol00?l=ooooo`;o003o1?ooool01?l00?ooooooo`00ool00?l2ooooo`;o003o00Gooooo
o`00oooooooo003oooooo`09o`00o`03ooooool00?oo003o00?o003o2_ooool2o`00o`03ooooool0
0?oooooo00Oooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool01Ol0003ooooooooooooo
ool0o`0000Oooooo00Go003oooooooooooooooooo`00o`02ooooo`03o`00oooooooooooo00[ooooo
0_l00?l01Ooooooo003oo`00oooooooo003o00Oooooo0_l00?l2ooooo`03o`00oooooooooooo00;o
003o0_ooool00ol00?ooooooo`00o`02o`00o`06ooooool00?oo003oooooool00?oooooo0_l00?l2
ooooo`03o`00oooooooooooo00;o003o00?oooooo`00ool00?l02?l00?l01_oooooo003oo`00oooo
oooo003oooooo`Go003o0_ooool3o`00o`Gooooo00Co003ooooooooooooo003o1Oooool02?l00?oo
ooooo`00ool00?ooooooo`00oooooooo003o2_ooool00ol00?ooooooo`00o`06ooooo`030?l00?oo
oooo003o00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglB
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool03Oooool01?l00?ooooooooooool0
0?l;ooooo`;o003o0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003oooooool00?l0
1?ooool00ol00?ooooooo`00o`07ooooo`04o`00oooooooo003oooooo`Ko003o0_ooool01Ol00?oo
ooooo`00ool00?oooooo00Ko003o0_ooool3o`00o`03ooooool00?oooooo00Oooooo00?o003ooooo
ool00?l01?ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00[ooooo00Co003ooooo
oooooooo00002oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo
00?ooooo00Co003oooooool00?oo003o0_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooo
003o00;ooooo00Go003oooooool00?oo003o0?l00003ooooo`03o`00oooooooo003o00Kooooo0_l0
0?l=ooooo`Go003o0_ooool4o`00o`Cooooo0_l00?l00ooooooo003oo`00o`09o`00o`09ooooool0
0?oo003oooooool00?ooooooo`00oooooooo003o00;ooooo00Ko003oooooool00?ooooooo`00oooo
ool2o`00o`?ooooo00Co003oooooool00?oo003o2?ooool00ol00?ooooooooooo`07ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0Eooooo`;o003o
1Oooool01?l00?ooooooooooool0000;ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo
00Co0000oooooooooooo003o4Oooool00ol00?ooooooo`00o`09ooooo`03o`00oooooooooooo00Go
oooo00?o003oooooooooool00_ooool00ol00?ooooooo`00o`04ooooo`03o`00oooooooo003o00Ko
oooo00?o003oooooooooool00oooool01Ol00?ooooooo`00oooooooo003o00Cooooo00Co003ooooo
ool00?oooooo1?l00?l00ooooooo003oooooo`04o`00o`08ooooool00?oo003oo`00oooooooo003o
ooooool00?l2ooooo`;o003o4?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00
o`Kooooo00?o003oooooool00?l01Oooool00`3o003oooooooooo`0Nooooo`04o`00oooooooo003o
o`0000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`03oooo
o`03o`00oooooooo003o01;ooooo00?o003oooooool00?l01oooool01ol00?ooooooo`00oooooooo
003oooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00;ooooo00?o003oooooool00?l0
0oooool2o`00o`05ooooool00?ooooooooooool00?l01_ooool00ol00?ooooooooooo`03ooooo`04
o`00oooooooo003oooooo`Oo003o00?oooooo`00ooooool00ol00?l00ooooooo003oo`00o`02o`00
o`Cooooo00?o003oooooooooool00_l00?l3ooooo`03o`00oooooooooooo00_ooooo00?o003ooooo
ooooool01?ooool00ol00?ooooooo`00o`0>ooooo`03o`00oooooooooooo00gooooo0_l00?l01_oo
oooo003oooooool00?ooooooo`00o`?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003o2ooo
ool00ol00?ooooooo`00o`05ooooo`03o`00oooooooo003o00Gooooo00?o003oooooooooool00ooo
ool01?l00?ooooooooooooooool3o`00o`Sooooo00Go003oooooooooooooooooo`00o`02ooooo`03
o`00oooooooo003o00Gooooo0ol00?l01ooooooo003oo`00ool00?ooooooo`00ooooool01Ol00?l0
1_oooooo003oo`00oooooooo003oooooo`?o003o0oooool01Ol00?ooooooo`00oooooooo003o00;o
oooo00Co003ooooooooooooo003o0_ooool00`3o003oooooooooo`0Cooooo`03o`00oooooooooooo
00oooooo0_l00?lBooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`00oooooooooooo00oooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`02ooooo`;o003o1_ooool0103o003oooooooooooooool2o`00
o`;ooooo0_l00?l01?oooooo003oooooooooool5o`00o`;ooooo0_l00?l00ooooooo003oo`00o`03
ooooo`Co003o00Goooooo`00oooooooo003oooooo`02o`00o`03ooooool00?oooooo00;o003o0_oo
ool5o`00o`;ooooo00Co003ooooooooooooooooo0_l00?l7ooooo`03o`00oooooooooooo00Cooooo
00?o003oooooool00?l00oooool00ol00?ooooooo`00o`08ooooo`030?l00?oooooooooo00?ooooo
0_l00?l3ooooo`03o`00oooooooo003o00Wooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`08ooooo`04o`00ooooooooooooo`0000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo
4_ooool01Ol0003oooooooooooooool0o`0000Kooooo00?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l8ooooo`03o`00oooooooooooo00Oooooo0_l00?l5ooooo`04o`00o`3o003ooooo
ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00;o003o00?ooooo
o`00ool00?l01Oooool00ol00?ooooooo`00o`06o`00o`03ooooool00?oooooo00co003o0_ooool4
o`00o`Gooooo00?o003oooooooooool04?ooool00ol00?ooooooooooo`03ooooo`030?l00?oooooo
oooo00Sooooo00?o003oooooool00?l01oooool00ooo003oooooooooo`02ooooo`03o`00oooooooo
oooo00Oooooo00Goo`00ooooooooooooooooo`00o`05ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0>ooooo`03o`00oooooooo
oooo013ooooo00?o003o0?l00?ooool00oooool01_l00?ooooooooooool00?ooooooo`00o`Gooooo
00Co003ooooooooooooo003o0oooool3o`00o`08ooooool00?oo003oo`00oooooooo003oooooool0
0?l2ooooo`030?l00?oooooooooo00;ooooo2Ol00?l01?oooooo003oo`00ooooool3o`00o`Kooooo
1?l00?l01Ooooooo003oooooo`3o003o003o00[ooooo00?o003oooooool00?l00_ooool2o`00o`[o
oooo00?o003oooooooooool01?ooool2o`00o`;ooooo00Oo003oooooooooooooooooo`00o`3o003o
003o00;ooooo00Co003ooooooooooooo003o1?ooool00ol00?ooooooooooo`0=ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`04
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04Oooool00ooo003oooooooooo`04
ooooo`03o`00oooooooo003o00;ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03
o`00o`03ooooool00?oooooo00Cooooo00Ko003oooooooooooooooooo`00ooooool3o`00o`;ooooo
0ol00?l01?oooooo003oo`00ooooool5o`00o`05ooooool00?oo003oo`00ooooool01?l00?l3oooo
o`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool03oooool2o`00o`Gooooo00?o003o
ooooool00?l02Oooool00ol00?ooooooooooo`02ooooo`;o003o2_ooool00ol00?ooooooooooo`08
ooooo`05o`00ooooooooooooooooool000002oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglB
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool05?ooool01?l00?ooooooo`00ool0
0?l3ooooo`;o003o00Koooooo`00oooooooo003oooooo`3o0006ooooo`03o`00oooooooo003o00Co
oooo00Co003oooooool00?oooooo0_l00?l00ooooooo003oooooo`03ooooo`050?l00?oooooooooo
ooooool00?l00_ooool4o`00o`030?l00?l00?oo003o00?o003o1?ooool01ol00?ooooooooooool0
0?ooooooo`00ooooool00_l00?l2ooooo`04o`00ooooooooooooool000;ooooo0_l00?l9ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool04Oooool2o`00o`;ooooo00?o003ooooooooo
ool06oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo
00?o0000ooooooooool01?ooool00ol00?ooooooooooo`0Aooooo`07o`00oooooooo003oooooool0
0?ooooooo`00o`03ooooo`03o`00oooooooooooo00oooooo00?o003oooooool00?l00_ooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooool00?l00_l00?l00ooo
oooo003oooooo`03o`00o`03ooooool00?oo003o00Go003o00Goooooo`00ool00?oo003oooooo`02
o`00o`;ooooo00Go003oooooooooooooooooo`00o`04ooooo`;o003o6Oooool01ol00?ooooooo`00
oooooooo003oooooool00?l00_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01[o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`00
0?oooooooooo00;ooooo00<0o`00ooooooooool07?ooool3o`00o`?ooooo00Co003ooooooooooooo
oooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0_ooool00ol0
0?ooooooooooo`03ooooo`03o`00oooooooo003o00;o003o0_ooool00`3o003o003oo`00o`0;o`00
o`03ooooool00?oo003o00Co003o00Soooooo`00ool00?oo003oooooool00?ooooooo`00o`Kooooo
00Co003oooooool00?oooooo0_l00?l01?oooooo003oooooool00?lDooooo`03o`00oooooooooooo
01Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0<ooooo`03
0?l00?oooooooooo00kooooo00?o003oooooooooool00_l00?l2ooooo`03o`00oooooooooooo00?o
003o0_ooool01ol00?oooooooooooooooooo003oooooool00?l00_ooool2o`00o`04ooooool00?oo
oooo0?l000;ooooo00Go003oooooooooooooooooo`00o`03ooooo`?o003o00Goooooo`00oooooooo
003oooooo`05o`00o`04ooooool00?oooooo0?l000Go003o1?ooool3o`00o`?ooooo00D0o`00o`00
oooooooooooo0?l00004ooooo`03o`00oooooooooooo00Kooooo00<0o`00ooooooooool02?ooool0
0ol00?ooooooooooo`04ooooo`;o003o2Oooool00ol00?ooooooooooo`04ooooo`030?l00?oooooo
oooo00gooooo00?o003oooooooooool00oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
0000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`00oooooooooooo00Cooooo00?o003oooooool00?l00_ooool2o`00o`Cooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooo`00o`02o`00o`?ooooo00Go003ooooooooooooo003oooooo`02
o`00o`;ooooo0_l00?l00ooooooo003oooooo`02o`00o`;ooooo00?o003oool00?l00?l00_ooool4
o`00o`03ooooool00?oo003o00oo003o0_ooool01Ol00?oooooo0?l00?oooooo003o00?ooooo00?o
003oooooool00?l00_ooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Kooooo
00?o003oooooooooool02_ooool01_l00?ooo`00ooooooooool0o`00o`00o`Wooooo00Co003ooooo
oooooooo003o3Oooool01?l00?ooooooo`00ool0000;ooooo`002_ooool00ol00000oomo0?ooO`2a
0?ooOa;ooooo00?o00000?l00?ooool05_ooool00ol00?l0o`00o`00o`08ooooo`05o`00oooooooo
003oooooool00?l00_ooool01?l00?ooooooo`00o`3o0004ooooo`;o003o00Coooooo`00oooooooo
003o0_ooool00ol00?ooooooo`00o`03ooooo`030?l00?oooooooooo00Cooooo0_l00?l2ooooo`?o
003o00Coooooo`00ool00?oooooo1_l00?l00ooooooo003oo`00o`06o`00o`05ooooool00?oooooo
ooooool00?l00oooool00ol00?ooooooooooo`02ooooo`;o003o00Coooooo`00ooooool0o`001Ooo
ool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00Kooooo00?oo`00ooooooooool00ooo
ool00ol00?ooooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0;40oomo4_ooool00ol0003ooooo0?l0000?ooooo`040?l00?ooooooooooo`00o`Sooooo0_l0
0?l00ooooooo003oooooo`05ooooo`Go003o0_ooool01_l00?ooooooo`00oooooooo003oooooo`?o
003o1Oooool3o`00o`?ooooo00?o003oooooool00?l00oooool01Ol00?ooooooo`00ool00?l0o`00
00;ooooo2Ol00?l2ooooo`03o`00oooooooo003o00Ko003o00Coooooo`00oooooooooooo0_l00?l3
ooooo`050?l00?l00?oo003oooooool00?l02Oooool00`3o003oooooooooo`03ooooo`08o`00oooo
ooooooooooooo`3o003oooooo`00ooooool3o`00o`;ooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`03ooooo`07o`00oooooooo003o0?l00?oooooo003o0?l00004ooooo`030?l00?oo
oooooooo00gooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglB
ooooo`04o`000?ooooooooooooooo`;o003o1Oooool00ooo003oooooooooo`06ooooo`03o`00oooo
oooo003o00?ooooo0_l00?l8ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l01Ooo
ool01_l00?ooooooooooo`3o003oooooo`00o`;ooooo00<0o`00ooooooooool01?l00?l2ooooo`04
o`00ooooooooooooo`00o`?ooooo00?o003oooooooooool01?l00?l00ooooooo003oo`00o`02o`00
o`03ooooool00?oo003o00Cooooo00?o003oooooool00?l00_l00?l3ooooo`03o`00oooooooo003o
00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooo`3o00000_ooool2o`00o`?ooooo00<0o`00ooooooooool00_ooool01@3o
003ooooooooooooooooo003o00Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`03
ooooo`030?l00?l00?oooooo00;ooooo00?o003oooooool00?l01Oooool00ol00?oo0000ooooo`0:
ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00Go0000ooooooooooooooooool00006
ooooo`0:0?l00?ooooooooooo`00oooooooo003oooooo`3o003oooooo`00o`Kooooo00?o003ooooo
ooooool02oooool2o`00o`08ooooool00?ooooooooooool00?oooooo0?l00?l00?l3ooooo`03o`00
oooooooo003o00;ooooo00Wo003oooooool00?oo003oooooool00?ooooooool00?l00?l01?ooool0
0ol00?ooooooooooo`03ooooo`Co003o00?oooooo`00ooooool01Ol00?l00ooooooo003oo`00o`03
o`00o`03ooooool00?l0o`0000?ooooo0_l00?l6ooooo`04ool00?l00?ooooooo`00o`?ooooo00@0
o`00oooooooooooo003o0_ooool01?l00?oooooo0?l00?l00?l3ooooo`07o`00o`3o003ooooooooo
ool00?ooooooo`00o`05ooooo`03o`00oooooooooooo00Cooooo00Oo003oooooooooooooooooo`00
oooooooo003o00Gooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00<0o`00oooo
ool00?l01?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;o
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool01?ooool0103o003o003oooooool00?l:ooooo`03o`00oooooooooooo
00Cooooo00Ko003oool00?oooooooooo0?l00?ooool3o`00o`Cooooo00Wo003oooooool00?oo003o
ooooool00?ooo`000?l00?l00?l00_ooool2o`00o`;ooooo1ol00?l01?oooooo003oo`00ooooool6
o`00o`04ooooool00?ooooooo`00o`;ooooo00?o003oooooooooool00_ooool01Ol00?oooooooooo
oooooooo003o00?ooooo00?o003oooooool00?l02Oooool00ol00?ooooooo`00o`04ooooo`030?l0
0?oo003ooooo00Cooooo00Co003o0?l00?oooooo003o1?ooool00ol00?ooooooooooo`05ooooo`03
o`00oooooooooooo00Kooooo0_l00?l2ooooo`;o003o1?ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool03oooool00ol00?oooooo
ooooo`07ooooo`05ool00?l00?ooooooooooool00?l01Oooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo00Co003ooooooooooooo003o0_ooool01Ol00?ooooooo`00oooo003o
003o00?ooooo00Co003ooooooooo003o003o0oooool2o`00o`;ooooo00Ko003oooooo`3o003ooooo
o`00ooooool2o`00o`Cooooo00?o003oooooooooool01Ol00?l02?ooool0o`00ooooool00?oooooo
o`00oooooooo003o1?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o
003oooooooooool01Oooool00ol00?l0o`00ooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooool00?l00oooool00`3o003oo`00ooooo`03ooooo`06o`00oooooooo003oooooo`3o003o
003o0_ooool2o`00o`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000000000000000
0P00002[0?ooO`@000004_ooool00ol00000o`00ooooo`0?ooooo`03o`00oooooooooooo00;ooooo
0ol00?l8ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooooooo0ol00?l2ooooo`03
0?l00?oooooo003o00?ooooo0_l00?l00ooooooo003oooooo`02ooooo`;o003o0oooool01?l00?oo
ooooooooooooool2o`00o`03ooooool00?oooooo00;o003o00?oooooo`00ool00?l02_l00?l00ooo
ool0o`00o`00o`07o`00o`03ooooool00?oo003o00?ooooo00L0o`00ooooooooool0o`00o`00oooo
ool0o`0000?ooooo00H0o`00ooooooooool0o`00ooooo`3o0004ooooo`03o`00o`3o003o003o00ko
oooo00<0o`00ooooo`3o00002Oooool01P3o003oooooooooool00?oooooo0?l000Oooooo00?o003o
ooooooooool00_ooool00`3o003oooooo`00o`02ooooo`03o`00ool0003ooooo00[ooooo000:oooo
o`03o`00001oool0Oooo0080Oooo1@00002P0?ooO`H00000101ooolBooooo`03o`00oooooooooooo
00[ooooo00?o003o0?l00?l00?l01?ooool00`3o003o003oooooo`0@ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01Oooool01?l00?ooooooooooool00?l2ooooo`03o`00ooooool0
o`000080o`001Oooool01_l00?oooooooooooooooooo003oooooo`?o003o00?oooooo`00ooooool0
0_l00?l01@3o003o003oo`00ool00?oooooo00Wo003o1?ooool2o`00o`070?l00?l00?oooooooooo
ool00?oooooo0?l00003ooooo`05o`00ooooooooooooooooo`3o00001Oooool00`3o003o003oo`00
o`04ooooo`030?l00?l00?oooooo00Sooooo00@0o`00oooooooooooooooo0_l00?l00oooooooo`00
ooooo`08ooooo`03o`00oooooooo003o00Kooooo00?o003oooooooooool02_ooool00ol00?oo0000
ooooo`0:ooooo`002_ooool00ol00000Oooo07ooo`0707ooo`@00000V@3oogl3000000X0Oooo4_oo
ool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00_oo
ool00`3o003oooooooooo`07ooooo`03o`00oooooooooooo00Cooooo00Go003o0?l00?oooooo003o
ool00003ooooo`80o`0000Ko003oooooooooool0o`00ooooool00?l4ooooo`;o003o00<0o`00o`00
ool00?l00_l00?l00ooooooo003oooooo`03ooooo`05o`00ooooooooooooooooool00?l00P3o0000
0ooooooo003oo`00o`03o`00o`03ooooool00?oo003o00Co003o00Ooooooo`00ool00?oo003ooooo
ool00?l0o`0000?o003o00P0o`00ooooool00?oooooo0?l00?oo003o003oooooo`?o003o0_ooool0
0`3o003o003oooooo`05ooooo`03o`00oooooooooooo00;ooooo0_l00?l2ooooo`030?l00?oooooo
oooo00Gooooo00Go003oooooooooooooooooo`00o`03ooooo`030?l00?oooooooooo00;ooooo00D0
o`00ooooooooooooooooo`00o`04ooooo`030?l00?oooooooooo00?ooooo00?o003oooooooooool0
2_ooool01?l00?ooooooooooool0000;ooooo`002_ooool00ol00000Oooo07ooo`0;07ooo`H00000
S@3oogl6000000d0Oooo4_ooool00ol0003oooooo`00o`04ooooo`04o`00ooooooooooooooooo`80
o`000oooool01Ol00?ooooooo`00ooooool0o`0000Cooooo00<0o`00ooooooooool03?ooool01@3o
003oooooooooooooool0o`0000;ooooo00X0o`00o`00oooo003o003ooooooooo003oooooo`00oooo
oooo003o0_ooool01`3o003oooooooooo`3o003o003oool00?ooool01ol00?l2ooooo`03o`00oooo
oooo003o00Go003o00?oooooo`00ooooool00_l00?l01Ooooooo003oo`00ool00?l0o`0000Co003o
0_ooool01?l00?ooooooo`00ool00?l6ooooo`04o`00o`3o003oooooo`00o`;ooooo00Co003ooooo
ooooool0o`000_ooool00ol00?l0o`00ooooo`08ooooo`05o`00oooooooooooo0?l00?l00?l00_oo
ool00`3o003ooooo0?l0000Aooooo`03o`00oooooooooooo00cooooo00@0o`00oooooooooooo003o
0_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0A07ooo`L00000O`3o
ogl7000001<0Oooo4_ooool00ol0003oooooooooo`04ooooo`030?l00?oooooooooo00Cooooo00Ko
003o0?l00?ooooooo`00ooooool00?l8ooooo`04o`00oooooooooooo0?l000;o003o0_ooool01?l0
0?ooooooo`00ool00?l2ooooo`;o003o00<0o`00oooooooo00000_ooool00ol00?ooooooooooo`02
ooooo`030?l00?l00?oo003o00;o003o0oooool00`3o003o003oooooo`02o`00o`03ooooool00?oo
oooo00Go003o00<0o`00o`00ool00?l01?l00?l01ooooooo003oo`00ool00?ooooooo`00o`3o0000
1_l00?l00ooooooo003oo`00o`06o`00o`Sooooo00@0o`00ooooool00?ooo`001_ooool00`3o003o
003oool00008ooooo`07o`00ooooool0o`000?l00?oooooo003oool00005ooooo`;o003o1Oooool0
0ol00?ooooooo`00o`04ooooo`050?l00?ooooooooooooooo`3o00001Oooool01_l00?l0o`00oooo
o`3o003oooooo`00o`Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0
601oool8000006l0oomo2000000J07oooa;ooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`03ooooo`;o003o00Coooooool00?oooooo003o1?ooool01ol00?ooooooooooo`3o003oo`00
oooooooo00001oooool02@3o003ooooooooooooooooo003o0?l00?oooooo003oooooo`02o`00o`;o
oooo00H0o`00oooooooooooooooo0?l00?l00?l7ooooo`060?l00?l00?l0o`000?l00?l00?oooooo
2_l00?l01Ooooooo003oo`00ool00?l0o`0000Go003o00T0o`00o`00ool00?oooooo0?l00?oooooo
003oooooool00?l00P3o0003ooooo`050?l00?ooooooooooo`00ooooool00`3o0002ooooo`050?l0
0?oooooo003oooooool00?l01?ooool20?l000?ooooo103o0002ooooo`;o003o00Cooooo0?l00?oo
oooo003o0oooool01_l00?ooooooooooo`3o003ooooo0?l000Cooooo00Goo`00oooooooooooooooo
o`00o`06ooooo`040?l00?oooooo003o0?l000Sooooo00?o0000ooooooooool02Oooool000[ooooo
00?o000007ooo`1oool0801oool700000600oomo2000000R07oooa;ooooo00?o0000o`00ool00?l0
0oooool0103o003oooooooooo`3o000:ooooo`030?l00?oooooooooo00;ooooo00<0o`00oooooooo
ool00_ooool01P3o003o003oooooool00?l0o`00o`00o`Cooooo00?o003oooooooooool00_l00?l2
ooooo`070?l00?oooooo003oo`00oooooooo003oooooo`020?l000Cooooo0ol00?l2ooooo`030?l0
0?l00?oooooo00Oo003o0_ooool6o`00o`;ooooo00<0o`00o`00ool00?l00ol00?l2ooooo`03ool0
0?oooooooooo00;o003o00T0o`00o`00ooooooooooooo`00ooooool0o`00ool0003o00000_ooool0
0ol00?ooo`00o`00o`06ooooo`04o`00oooooooooooo0?l000;ooooo00Co003oooooo`3o003oo`00
0_ooool01P3o003oooooooooooooool0o`00o`00o`Gooooo0_oo0005ooooo`030?l00?oooooooooo
00Cooooo00<0o`00ooooooooool01_ooool2o`00o`Gooooo00<0o`00ooooooooool01?ooool00ol0
0?ooooooo`00000;ooooo`002_ooool00ol00000Oooo07ooo`0W07ooo`P00000D@3oogl7000002X0
Oooo4_ooool00ol0003oooooooooo`09ooooo`08o`00ooooooooooooooooool00?ooooooo`00o`3o
0002ooooo`05o`00ooooooooooooooooool00?l00_ooool0103o003oooooool00?oo0008ooooo`03
o`00ooooool0o`0000?ooooo00?o003oooooool00?l01?ooool4o`00o`04oooooooo0000o`00o`00
o`?ooooo0ol00?l02?oooooo003oo`00oooooooo003oooooool00?oooooo0_l00?l01?oooooo003o
ooooo`3o0008o`00o`03ooooool00?oo003o00;o003o00P0o`00o`00oooooooo003o0?l00?oo003o
ooooo`00o`;ooooo00<0o`00ooooo`3o00000_ooool2o`00o`05ooooo`3o003o003o0?l00?ooool0
0P3o0002ooooo`?o003o0oooool00ol00?ooooooooooo`02ooooo`03o`00o`3o003oo`0000;ooooo
00@0o`00oooooooooooo003o0P3o0007ooooo`03o`00o`3o003ooooo00Kooooo00<0o`00oooooooo
ool01?ooool01Ol00?ooooooooooooooool0o`0000Cooooo00H0o`00ooooool00?ooooooo`00ool0
000;ooooo`002_ooool00ol00000Oooo07ooo`0_07ooo`P00000@@3oogl800000340Oooo4_ooool0
0ol0003oooooooooo`02ooooo`04ool00?ooooooooooo`00o`Gooooo00?o003oooooo`3o00000_oo
ool30?l000;ooooo00D0o`00ool0003o003oooooool00003ooooo`04o`00ooooooooooooooooo`;o
003o1oooool05_l00?oooooo0?l00?ooool0o`00ooooool00?oooooo0?l00?oooooo003oooooo`3o
003o003o0?l00?oooooo003ooooooooo003oooooo`00ooooool2o`00o`06ool00?oooooooooo0?l0
0?oo0000o`000_l00?l00`3o003o003oo`00o`02o`00o`03ooooool00?oo003o00Ko003o00?ooooo
o`00ool00?l00ol00?l03_oooooo003oo`00ool00?ooooooo`00oooo003oooooo`00o`3o003ooooo
o`00oooooooo003o1?ooool2o`00o`;ooooo00/0o`00o`00ooooool0o`00o`00ooooool0o`00ool0
003o003oooooo`00o`03ooooo`04ool00?ooooooooooool000Cooooo00Goo`00ooooooooooooo`00
o`00o`04ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`;o
003o0_ooool00ol00?ooooooooooo`04ooooo`060?l00?ooooooo`00o`00oooooooo00002oooool0
00[ooooo00?o000007ooo`1oool0=`1oool7000003<0oomo1`00000i07oooa;ooooo00Co0000oooo
ooooool0o`001oooool01ooo003oooooooooooooooooo`00o`00oooo00002Oooool0103o003ooooo
ooooool00?l2ooooo`80o`0000?ooooo0?l00?ooool00_l00?l01Ooooooo003oooooo`3o003ooooo
00?o003o0_ooool20?l00004o`00ooooool0o`000?l000;o003o00?oooooo`00ooooool00P3o0002
o`00o`0>ooooo`3o003ooooo0?l00?ooooooo`00o`00oooo003o003oooooo`3o003o003oooooool0
0?l20?l00003ooooool00?oo003o00Go003o00?oo`000?l00?l00?l01?l00?l01Ooooooo003oool0
0?ooool0o`0000;o003o00H0o`00o`00oooooooo003oooooo`3o0002ooooo`030?l00?oooooo003o
00;ooooo00Co003o0?l00?l00?oo003o0_ooool00`3o003oooooooooo`03ooooo`060?l00?l00?l0
o`000?l00?oooooo003o1?ooool00`3o003oooooooooo`04ooooo`030?l00?oooooooooo00Sooooo
00?o003oooooooooool00P3o0005ooooo`070?l00?ooooooo`00ooooo`3o003ooooo0?l00007oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo03h0Oooo4P00000=o`0001@0
0000@01ooolBooooo`03o`00003o0000o`0000Gooooo00?o003oooooooooool01?ooool00ol00?l0
o`00ooooo`02ool00005ooooo`3o003o003oooooool00?l00_oo0003o`00o`?ooooo00?oo`00oooo
ooooool00oooool2o`00o`;ooooo00Oo003ooooooooooooo003oooooool00?oooooo0080o`0000?o
oooo0?l0003o00000_ooool01ol00?ooo`00o`00oooooooo003oooooool00?l00_ooool01ol00?l0
o`000?l00?ooooooo`00o`00ooooool00_l00?l01?oo0000o`000?l0003o0003o`00o`03ooooool0
0?oo003o00Go003o00<0o`00o`00ool00?l00_l00?l01Ooooooo003oo`00ool00?oooooo0080o`00
0_l00?l02`3o003o003o0?l00?oooooo003oooooo`3o003ooooo0?l00?oooooo003o00?ooooo0_l0
0?l20?l00007o`00o`3o003o003o0?l00?ooool0o`00ool00003ooooo`050?l00?ooooooo`00oooo
o`3o00000_ooool01Ol00?l0o`000?l00?oooooo003o00Kooooo0P3o00002?ooool0o`00oooooooo
ooooo`00ooooool00?l0o`000_ooool00`3o003oooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01Oooool01?l00?oooooo0?l00?l0000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oo
oa;ooooo00Go003ooooooooooooooooo0?l00007ooooo`;o003o0_ooool00ol00?ooooooooooo`0;
ooooo`06o`00o`3o003oo`000?l00?oo003o003o1?ooool01?l00?ooooooooooool00?l3ooooo`06
ool0003o003o003o0?l00?oooooo003o1?ooool01?l00?ooooooo`00o`3o0003ooooo`;o003o00Co
ooooo`00ool00?l0o`000ol00?l00ooooooo003oo`00o`02o`00o`05ooooool00?oo003oo`00oooo
ool01Ol00?l00ooooooo003o0?l00004o`00o`?ooooo0_l00?l01P3o003ooooooooooooo003o003o
0?l000?ooooo00?o003o0?l0003o00000P3o00001Oooool0o`000?l00?oooooo003o00;ooooo00@0
o`00ooooooooool0o`000_ooool01P3o003oooooooooooooool0o`00o`00o`;ooooo00Goo`00oooo
o`3o003oooooo`00o`03ooooo`060?l00?ooooooooooo`00ooooooooo`000_ooool00`3o003ooooo
ooooo`06ooooo`050?l00?ooooooooooooooo`3o00003Oooool00ol00?l0o`00o`00000;ooooo`00
2_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o003o0?l00?ooool02Oooool00`3o003ooooo
ooooo`03ooooo`030?l00?oooooooooo00Kooooo00P0o`00ooooo`3o0000o`00o`00o`3o003ooooo
o`00o`<0o`0000Soooooool00?ooooooooooo`00o`3o003o003oooooo`;o003o1?ooool2o`00o`06
ooooool00?l0o`00o`00ooooool0o`000_ooool00`3o003o003oo`00o`020?l00003ool0003o003o
oooo00Oo003o00Ooooooo`00ool00?oo003oooooool00?oooooo00co003o00@0o`00o`00ool00?l0
o`000ol00?l00oooool0o`00ooooo`02ooooo`030?l00?ooooooo`000080o`0000?ooooo0?l00?oo
ool00P3o00001Oooool0o`00oooooooooooo003o00;ooooo0P3o00001?oo0000o`00o`00o`3o0003
ooooo`;o003o1?ooool30?l00004ooooool00?l0o`00o`00o`?ooooo00Co003oooooo`3o003o003o
1?ooool00ol00?oooooo0?l0000?ooooo`050?l00?ooool0o`00ooooool000002oooool000[ooooo
00?o000007ooo`1oool0/@1ooolBooooo`80o`000oooool00`3o003oooooooooo`03ooooo`070?l0
0?oooooo003o0?l00?l00?ooooooo`00o`03ooooo`04o`00o`3o003ooooo0?l000Cooooo00So003o
oooooooo0000o`00o`00ooooool0o`00ool00080o`000oooool0103o003o003oo`00ooooool20?l0
0003ooooo`3o003ooooo00;ooooo00H0o`00ool00?l00?oo003o0?l00?ooool2o`00o`03oooooooo
0000o`0000?ooooo00Oo003o0?l00?l00?oo003oooooool00?ooo`0000So003o00?oo`00o`00ool0
0?l00_l00?l00ooo003o003oo`00o`03o`00o`04ooooool00?oo003oooooo`;o003o00T0o`00o`00
ool00?ooo`000?l00?l00?oooooo0?l00?ooool00P3o00002_ooool0o`000?l00?l00?l0o`00oooo
ool00?ooo`000?l00?ooool20?l000;ooooo00D0o`00ooooooooooooo`000?l00002ooooo`030?l0
0?l00?oo003o00@0o`0000Oo003oool0003o003oooooool0003o003ooooo00<0o`0000Go003ooooo
oooooooo003o0?l00004ooooo`03ool00?oooooooooo00Cooooo00D0o`00ooooooooool0o`00o`00
o`0:ooooo`030?l00?l0003ooooo00[ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool2
0?l000;ooooo0_l00?l3ooooo`03o`00oooooooooooo00;ooooo00Ko003oooooo`3o0000o`00ool0
0?ooool2o`00o`<0o`001oooool02P3o003o003oooooooooooooo`00oooooooo0000o`00o`00o`3o
0002ooooo`040?l00?l00?ooooooooooo`80o`0000Kooooo0?l00?ooool0o`00ool00?l00?l3oooo
o`08ool0003o003o003oo`00ooooool0o`00o`00o`3o0002o`00o`08ool0003o003o003oooooool0
0?oooooo0?l00?ooool8o`00o`03ool00?l00?oo003o00Oo003o00D0o`00o`00oooooooooooo0?l0
0002o`00o`0;0?l00?oo003o003oooooool00?l0o`00o`00o`3o003o003oooooo`3o00000_ooool4
0?l00003ool0003o003o003o00?ooooo00Ooo`00ooooo`3o003ooooo0?l00?ooool0o`0000Kooooo
00?o003oooooo`3o00000_ooool00ooo003o003oo`00o`06ooooo`03ool00?oooooooooo00;ooooo
00?oo`00o`00ooooool00oooool00ooo0000o`00ooooo`04ooooo`<0o`000oooool01Ol00?oooooo
oooooooooooo000000_ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool02Ol00?oooooo
oooooooooooo003oooooo`3o003oooooo`00o`09ooooo`80o`000oooool00`3o003o003o0?l00002
ooooo`80o`000oooool20?l000Cooooo00<0o`00o`00ool00?l00_l00?l2ooooo`03ool00?oooooo
oooo00@0o`0000Go003ooooooooooooo003oooooo`020?l0000;ooooo`3o0000o`000?l00?oooooo
o`00o`00o`3o003oo`00ooooool00?l00P3o00000oooool0o`00ooooo`05o`00o`80o`002?l00?l0
0ooooooo003oo`00o`02o`00o`070?l00?l00?oo003o0?l00?oo003o003oooooo`020?l0000;oooo
ool00?ooo`00ooooo`3o003ooooo0?l00?l00?l0o`00o`00ooooool00P3o00002?l00?l0o`000?l0
0?ooooooo`00o`00oooo003ooooo0P3o0003ooooo`040?l00?l00?ooo`000?l000;ooooo0P3o0000
1Oooooooo`00oooooooooooo003o00?ooooo00L0o`00o`00oooo003ooooo0?l00?ooool0o`0000Co
oooo00@0o`00o`00o`3o003oo`001?ooool01?oo003oooooool0003o0002ooooo`06ool00?oooooo
oooo0?l00?oooooo003o0_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07oooa;ooooo00?oo`00ooooooooool00oooool01?oo003ooooo0?l00?l00?l3ooooo`0<ool0
003o003o003oooooo`3o003oo`00ooooool00?l0o`00ool00?oooooo003o1?ooool00`3o003ooooo
ooooo`02o`00o`;ooooo00?o003o0?l00?l00?l0103o00000ooo003ooooo0?l00004o`00o`80o`00
00?o003o0?l00?ooool01P3o00000ol00?ooooooo`00o`02o`00o`04ool00?l00?l0o`00ooooo`Go
003o00@0o`00o`00ool00?oo003o0_oo000:o`00o`030?l00?l00?oo003o00?o003o00Soo`000?l0
003o003o003o0?l00?oo003o003oooooo`;o003o0`3o00000ol00?l0o`00o`00o`02ooooo`06ool0
0?l00?oo003oo`00o`3o003ooooo103o0003ooooo`04o`00ooooooooooooooooo`;o003o00Cooooo
0?l0003o003ooooo0ooo00000`3o003oo`000?l00002o`00o`80o`0000Gooooo0?l0003o003ooooo
o`00o`04ooooo`03o`00ooooool0o`0000?ooooo00@0o`00ooooooooool0o`000_oo0004ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooool000002oooool000[ooooo00?o000007ooo`1oool0
/@1ooolBooooo`03o`000?l00?l0o`0000;oo`0000Kooooo0?l0003o003oo`000?l00?oo0002oooo
o`030?l00?oooooooooo00?ooooo00Coo`00ooooooooooooo`000_ooool2ool00003o`00ooooool0
o`0000;ooooo00Go003o0?l00?oooooooooo0?l00002ooooo`80o`0000Coo`000?l0003o0000o`00
0_l00?l01Oooool0o`00o`00o`3o003o003o0080o`0000_oooooo`00o`3o0000o`00ool0003o003o
003o0?l00?oo003o003oool000020?l000;ooooo00<0o`00o`00oooo00000_l00?l00ooooooo003o
o`00o`05o`00o`040?l00?l00?oo003oooooo`;o003o00<0o`00o`00ool00?l01?l00?l00`3o003o
003oool00002o`00o`;ooooo0ol00?l01_ooool0o`00o`00ool00?l0o`00ool00080o`000_oo0000
2`3o003oo`00ool00?oo003ooooo0?l00?oo0000o`00o`00oooo003ooooo0080o`0000Oo003o0?l0
0?l00?ooooooool00?ooool0o`0000;ooooo00<0o`00ool00?l00?l00_ooool01@3o003oo`00o`00
oooo0000o`0000?ooooo00@0o`00ooooooooool0o`000oooool02Ooo003ooooo0?l00?ooool0o`00
ooooool00?oooooo0?l0000>ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0
Oooo0;40Oooo4_ooool01?l0003oooooooooool00?l7ooooo`03ool00?l00?ooo`000080o`0000Go
oooo0?l00?oooooooooo0?l00003o`00o`;ooooo00H0o`00o`00oooo003o003oool0003o0002o`00
o`04ooooool00?ooooooooooo`?o003o00<0o`00o`00o`3o00000_l00?l20?l00004ooooool00?oo
003oo`00o`80o`000_ooool00ooo0000o`00ooooo`02o`00o`05oooooooo0000o`00ool00?ooool0
0_l00?l00`3o003oo`00o`00o`02o`00o`060?l00?l00?oo003o0?l00?l00?ooo`003_l00?l00`3o
003o003oo`00o`02o`00o`03ool00?l00?l0o`0000;o003o00@0o`00ool0003o003oo`000ol00?l0
1P3o003oooooool00?l00?oooooo0?l000;ooooo00Wo003oooooool00?l0o`00ool0003o003o003o
oooooooo00000_l00?l0103o003oo`000?l00?l00?l3ooooo`03ool00?oooooooooo00;ooooo00?o
o`00o`00ool00?l00_ooool00ol00?ooo`00o`00o`020?l00006o`00ooooooooooooool00?oooooo
003o0_oo00002`3o003o003ooooooooooooo003oooooo`3o003oooooool00?ooool0o`0000?ooooo
00<0o`00o`00o`3o00001?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07oo
o`2a07oooa;ooooo00Co0000ool00?ooool0o`001?ooool0103o003oooooo`00o`3o0002ooooo`03
o`00o`3o003o003o00;ooooo00?o003oooooooooool00_oo00000`3o003oooooo`00o`02ooooo`05
o`00ooooooooo`000?l00?ooool00_l00?l3ooooo`03o`00oooooooo003o00?ooooo00Koo`000?l0
0?oooooo003oooooo`3o0003o`00o`04ooooool00?l0o`00o`00o`;ooooo0_l00?l01P3o003o003o
o`00ool00?l0o`00o`00o`;ooooo0_oo00001P3o003o003oool00?l00?l0o`00ool000Wo003o00<0
o`00o`00ool00?l00ol00?l00ooo003o003oo`00o`02o`00o`030?l00?ooool0o`0000?o003o00Wo
ooooool00?oo0000o`00ooooool00?l0o`00ool00?ooool00P3o0002ool000090?l00?oo003oo`00
0?l00?ooooooo`00o`00oooo003ooooo00<0o`0000?oooooool00?oo0000103o00002?l00?oooooo
0?l00?ooool0o`00ooooool00?ooo`000P3o00002_oo0000o`00ool00?oooooo003ooooooooo003o
oooo0?l00?ooool20?l00004ooooo`3o0000o`000?l000;ooooo00Co003oooooool00?ooo`000ooo
ool01_oo003ooooo0?l0003o003ooooo0?l000;ooooo00?o003oo`000?ooool02_ooool000[ooooo
00?o000007ooo`1oool0/@1ooolBooooo`06o`000?oooooo003oool00?oooooo003o1oooool30?l0
0007ooooo`3o003o003oo`00o`3o003oooooool00002ooooo`04o`00oooooooo003o0?l000;ooooo
00Co003oooooool00?oo003o0P3o00001?ooool0o`00ooooooooool20?l000;ooooo00Co003ooooo
ool00?ooo`000_l00?l01@3o003ooooo0?l00?l00?l0o`0000;o003o00?oooooool0003o00001?oo
0000103o003oooooo`00o`3o0003o`00o`030?l00?l00?oo003o00So003o00?oooooo`00ool00?l0
4Ol00?l00`3o003o003oool00003o`00o`Coo`000_l00?l01Ooo003o003oool00?oo003ooooo0080
o`0000Ko003o0?l0003o0000o`00ool00?ooool20?l0000Bo`00oooooooooooo0?l00?ooool0o`00
ool00?l00?l0o`00ool00?l00?ooo`000?l00?ooooooo`000?l00?oooooo003o0P3o00000ol00?l0
o`00ooooo`02o`00o`05ooooo`3o003o003ooooooooo00000_l00?l01?ooool0o`00ool00?oo0002
0?l000;ooooo00/0o`00ooooo`3o003ooooo0?l00?ooooooo`00ooooo`3o003oooooo`00000;oooo
o`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000ooooo`3o00000_ooool0103o003o
ooooooooool00?l2ooooo`04o`00ooooooooooooo`00o`80o`0000Go003ooooooooooooo003ooooo
o`02o`00o`08ool00?ooooooooooo`00oooo0000o`00ooooool00?l2ooooo`090?l00?oo0000o`00
0?l00?l00?ooooooool00?l00?oooooo00;o003o00?oooooool00?l00?l00ol00?l0103o003o003o
ool00?l00?l20?l000;oo`0000?o003o0?l00?ooool00_ooool00ol00?l0o`000?l00002o`00o`03
ooooool00?ooo`000080o`001_l00?l00`3o003o003oooooo`08o`00o`03ooooool00?oo003o00Ko
003o00?oo`00o`00ool00?l00_l00?l01@3o003oo`000?l0003o003ooooo00;o003o00L0o`00o`00
ooooooooo`00oooooooo003ooooo00;oo`0000[ooooo0?l00?l00?oo003ooooooooo003o003ooooo
o`3o003o003o103o00001_ooool0o`00o`00ooooooooo`000?l000;ooooo00Ko003oooooo`3o003o
003oool00?ooool20?l00004ooooo`3o003ooooo0?l000;oo`0000Goooooool00?oooooooooo0?l0
0002ooooo`80o`0000Ooooooool00?oooooooooo0?l00?ooool0o`0000Gooooo00<0o`00ooooool0
00002oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`05o`000?ooool0o`000?l00?l0
0?l01Oooool01@3o003oo`00o`00o`3o003ooooo00;o003o0`3o00001?oo003ooooo0?l00?ooool2
o`00o`Cooooo00[oo`00o`00oooo003o003ooooooooo0000o`00o`00ooooool0o`000_l00?l00ooo
003ooooo0?l000020?l000;o003o00Coo`00o`00ool00?oo003o0_oo00001?l00?ooo`00o`00o`3o
0003o`00o`07ooooo`3o003o003oo`00oooo003o003o0?l00002o`00o`080?l00?ooooooooooool0
0?l00?l0o`00ool0003o000Ao`00o`030?l00?l00?oo003o00;o003o0_oo00001@3o003o003oo`00
ool00?oooooo00;o003o00T0o`00ool0003o003o003oool00?ooool0o`00o`00o`3o00001?oo0000
3Ol00?ooo`000?l0003o003o003oooooool00?ooo`00o`00oooo0000o`00ooooo`3o00000_l00?l0
303o003oo`00o`00ool00?ooo`000?l00?ooool0o`00ool00?ooool0o`00ool00080o`0000Cooooo
0?l0003o003o003o0P3o00002oooool0o`00ooooooooool0o`00o`00o`3o003oooooool00?oooooo
003o00;ooooo00Oo003o0?l00?l00?oo003o0?l00?oooooo003o00;ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`030?l00?oooooooooo00;o003o0ooo
ool02`3o003o003oooooooooooooo`000?l00?ooool0o`00oooooooo003ooooo00;o003o00Cooooo
o`00oooooooo003o0_ooool01`3o003ooooo0?l00?oo003o003oool00?l00?l00_ooool02_oo0000
o`000?l00?oo0000o`00o`00o`3o003o003oool00?l00?l3ool000050?l00?l00?l0o`000?l00?l0
0?l00_oo00002ol00?ooooooo`00ooooooooo`00o`00o`3o003oooooo`00ooooooooo`0000;o003o
00Koo`00o`00ooooooooo`00o`00oooo0003o`00o`030?l00?l00?oo003o017o003o00H0o`00o`00
o`3o003oo`00o`00oooo0004o`00o`03ool00?l00?l0o`0000?o003o0P3o00001?oo0000o`000?l0
003o0002ooooo`Coo`000`3o00001_oo003o003o0?l00?l00?oooooo0?l000;ooooo017oo`00o`00
ooooooooo`000?l00?oooooo003o0?l00?l00?ooooooo`00o`3o003oooooool00?ooool0o`00oooo
o`02ool000060?l00?ooool0o`00ool00?oooooo003o0P3o00002Ooo0000o`000?l0003o003ooooo
ool00?ooooooo`000?l00002ooooo`<0o`0000?oo`000?l00?l000002oooool000[ooooo00?o0000
07ooo`1oool0/@1ooolBooooo`07o`00003o003o003oo`00o`3o003ooooo0?l00002ooooo`070?l0
0?l00?l0o`00ool0003o003oooooo`00o`02ooooo`040?l00?l00?oo003oo`00o`80o`0000Kooooo
o`00o`3o003o003oool00?ooool2ool00008ooooool00?l0o`000?l00?ooool0o`00o`00ooooool2
0?l0000<ooooo`3o0000o`00ool00?l00?l0o`00ool00?l00?oooooo0?l00?oo003o003o0ooo0000
1@3o003oooooo`00ooooooooo`000080o`000ol00?l00ooooooo003oool0000Co`00o`030?l00?l0
0?oo003o00So003o00?oo`00o`00ool00?l00ol00?l20?l00005ool0003o003o003oo`00o`3o0000
0_l00?l00ooo0000o`00ool000040?l00005o`00ooooooooo`000?l00?ooool00P3o00001?oo003o
ooooool00?l00?l2ool000060?l00?l00?l0o`00ooooo`3o003oo`000_ooool00`3o003oo`00o`00
o`030?l000;ooooo00<0o`00ooooool00?l00_ooool00ol00?ooooooooooo`02o`00o`04ool00?oo
oooooooo0?l000;ooooo00@0o`00ooooooooooooo`000_ooool01@3o003oooooooooo`3o003ooooo
0080o`0000?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`06
o`000?l00?l0o`00ooooo`3o003o003o0`3o00002?oo0000o`000?l00?oooooo003oooooool00?oo
oooo0_l00?l00ooo003oooooool000020?l00003ool00?oooooooooo0080o`000_l00?l01_oo003o
003oo`00o`3o003oo`00ooooo`80o`0000Goo`000?l00?oo003oo`000?l00004o`00o`0>ooooo`3o
003oo`000?l00?oo0000o`00oooooooo003o003oooooool00?l0o`00o`00oooo0006o`00o`030?l0
0?l00?oo003o00Co003o00Coo`00o`00ool00?l0o`005?l00?l02_oooooo003oo`00ool00?l0o`00
ool00?l00?l0o`00o`00oooo0002o`00o`06ool0003o003oo`00o`00oooo0000o`000_oo00001?l0
0?l0o`00ool00?ooool2ool000;ooooo00`0o`00o`00oooo003ooooo0?l00?oo003oooooo`00oooo
ooooo`00o`00oooo0002ooooo`03o`00o`3o003oo`0000<0o`0000?oo`000?l0003o00000`3o0000
2_l00?ooo`00o`00o`3o003oooooool00?l00?l0o`00o`00ooooool2ool00003o`00ooooool0o`00
00;ooooo00H0o`00ooooooooooooo`000?l00?ooool2ool00003ooooo`3o003o000000_ooooo000:
ooooo`03o`00001oool0Oooo0;40Oooo4_ooool02?l0003oooooooooooooooooo`00o`00oooooooo
003o0P3o0002o`00o`04ooooo`3o003ooooo0?l000;o003o1_ooool2ool00003o`00o`3o003oo`00
00;o003o00Cooooo0?l0003o0000o`000_ooool00`3o003oo`00o`00o`02o`00o`05ool00?l00?oo
003oo`00o`3o00000ooo00002@3o003oo`00ool00?oo0000o`00ool00?oooooo003o0?l00008o`00
o`030?l00?l00?oo003o00?o003o00<0o`00o`00ool00?l00ol00?l00ooo003o003oo`00o`0Ao`00
o`05ool00?l00?oo003oool0003o00000_l00?l0103o003o003oo`00oooo0003o`00o`80o`0000?o
003o0?l0003o00000P3o00000ooo003o003oo`00o`03o`00o`0:ool00?ooool0o`000?l00?oooooo
o`00ooooo`3o003o003o0?l000;oo`0000Cooooo0?l00?oo0000o`000_ooool3o`00o`;oo`0000So
003oool00?ooool0o`00oooooooo0000o`00ool000;ooooo00D0o`00ooooooooooooo`00ooooo`02
0?l000;o003o00?ooooo0?l00?ooool00oooool00ooo0000o`00ooooo`02ooooo`030?l00?l0003o
oooo00[ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003ooooo0?l00002ool0
00030?l00?oo0000o`000080o`0000Ko003oool0003o0000o`00ooooool00?l20?l000Co003o00@0
o`00o`00o`3o003o003o0_ooool01?l00?ooo`00o`00ool00?l20?l00003oooooooo003o003o00;o
003o00@0o`00ool00?l00?oo003o0P3o0003o`00o`060?l00?l00?ooo`000?l00?oo0000o`000ol0
0?l01P3o003o003oo`00ool00?l0o`00o`00o`80o`0000Co003oool00?l00?ooo`001ol00?l00`3o
003o003oo`00o`0Fo`00o`03ool00?l00?oo003o00;o003o00<0o`00o`00oooo00000_l00?l03?oo
ooooo`00ool00?l00?ooo`00o`00oooo003o003oool00?l00?ooo`00o`00o`;oo`0000?oooooool0
0?oo00000_l00?l01_ooooooo`000?l00?oo003o003oooooo`?oo`0000l0o`00ool00?oo003o003o
ool0003o003o003o0?l00?oo003o003o0?l00?l00?oooooo0?l00?oo00001@3o00000oooool0o`00
0?l000020?l00003o`00o`3o0000o`000080o`0000co003o0?l00?ooooooo`00ooooool00?ooo`00
0?l00?ooool0o`00o`00ool0000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Ko
00000?l00?ooool0o`00ooooool00?l20?l000;ooooo00L0o`00ool0003o003o003oooooo`3o003o
oooo00Co003o00`0o`00o`00oooooooo003oool0003o003ooooo0?l00?l00?l0o`00o`00ooooool2
0?l00003ool00?l00?l0o`0000?oo`000P3o0002o`00o`04ool00?ooooooo`000?l000;o003o00<0
o`00ool00?ooool00_l00?l2ool000<0o`0000Ko003o0?l00?l00?l0o`00ooooo`3o0002o`00o`04
0?l00?l00?l0o`000?l001ko003o00D0o`00o`00o`3o003o003oool00002o`00o`?oo`0000/0o`00
ool0003o003o003o0?l00?oo0000o`00ool00?l00?ooo`000?l00004ool000030?l00?l00?ooo`00
0080o`000_oo00002?ooool0o`00ool0003o003oo`00oooooooo003ooooo0_oo00001P3o003o003o
o`00oooooooo003oool000?o003o00@0o`00ool0003o0000o`000_oo00001oooool0o`00o`00oooo
0000o`00ooooo`3o00000_ooool01?l00?l0o`00o`00oooo00030?l00005ool00?ooool0o`000?l0
0?l000002oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`04o`000?l00?ooo`00ool0
00;ooooo00H0o`00oooooooo003oo`000?l00?l00?l20?l0000Cooooo`3o003o003ooooooooo0000
o`00ool0003o003oo`000?l00?oo003o003o0?l00?ooool0o`00o`00oooooooo003oooooo`02o`00
o`80o`0000?oo`00o`00o`3o00000ol00?l01Ooo0000o`00o`00ool00?l0o`0000;oo`0000D0o`00
ool00?l00?oo003o0?l00002o`00o`030?l00?l00?ooo`0000;o003o00Koo`000?l00?l00?oo003o
0?l00?oo0003o`00o`04ooooool00?oo003oool001co003o00<0o`00o`00ool00?l00_oo00000ol0
0?ooo`00o`00o`02o`00o`030?l00?l00?l0o`000080o`0000Goo`000?l00?l00?l0o`00ool00002
o`00o`040?l00?l00?l0o`00o`00o`Koo`0001Ko003oooooo`3o003oo`000?l00?ooooooo`000?l0
0?oo0000o`00ool00?ooool0o`00oooooooo003o003oooooo`3o003oooooool00?l00?l0o`000_oo
ool2ool0000;oooooooo003o003oo`00oooo0000o`00ool00?ooool0o`00ooooool00?l00`3o0000
1_ooool0o`00o`00o`3o003oooooo`0000_ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_oo
ool2o`00o`;ooooo00Woo`000?l00?oo003ooooo0?l00?oooooo003o0?l00?oo00000P3o00001ooo
003o003oo`00o`3o003oooooool00?ooool00ooo00002?l00?oooooo0?l0003o003oo`00o`00o`3o
003oo`000ol00?l0103o003o003oo`00o`3o0002o`00o`06ool0003o003o003o0?l00?ooooooo`00
0_l00?l30?l00003o`00o`3o003o003o00;oo`0000<0o`00o`00oooo00000P3o0004o`00o`03ool0
0?l00?ooo`0000Wo003o00<0o`00o`00ool00?l03Ol00?l00ooo003o003oo`00o`06o`00o`070?l0
0?l00?ooo`00o`00oooo003o003oool000020?l000;o003o00L0o`00ool0003o003oo`00o`00oooo
003o003o00?oo`0000<0o`00ool00?oo00000_oo00020?l00004ooooool00?oo003oooooo`<0o`00
0_oo00001Oooool0o`00o`00ooooool0o`0000;ooooo00?o003o0?l00?ooool00_l00?l30?l000;o
o`000140o`00ool00?oooooooooo0?l00?oo003oooooo`00ooooooooo`00oooooooo003oooooo`00
oooo003oooooo`00o`04ooooo`03ool00?l0003ooooo00[ooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo4_ooool3ool000060?l00?l00?ooooooool00?oooooo003o0_oo00001?oooooo003o0?l0
003o0002o`00o`03ooooool00?l0o`0000;o003o00?oo`000?l00?oo00000_oo00000`3o003o003o
o`00o`03o`00o`05ool0003o0000o`00o`00ooooool00ol00?l00ooo003o003oo`00o`03o`00o`03
0?l00?l00?oo003o00?o003o00?oo`00o`00o`3o00000_l00?l00ooo003o003oool00002ool000;o
003o00Coo`00o`00oooo0000o`000ol00?l2ool001[o003o00<0o`00o`00ool00?l01?l00?l00`3o
003oo`00o`00o`04o`00o`;oo`0000?o003oool00?l00?l00ol00?l2ool00007o`00oooo003oo`00
ool00?l00?l0o`00o`00o`02ool00009ooooool00?oo003oooooool00?l0o`00ool0003o003o003o
00D0o`000ooo00030?l00003ooooo`3o0000o`0000;oo`0000L0o`00ool00?l00?l0o`00o`00oooo
003o003o00?ooooo00<0o`00ool00?l00?l00_l00?l02?ooool0o`00ool0003o003oo`00oooooooo
003o00002oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`07o`000?oooooooooo0?l0
0?l00?l0o`00ooooo`02ool00006oooooooo0000o`000?l00?l00?l0o`000_l00?l01?oooooo003o
ool00?ooool3o`00o`80o`0000Koo`00o`00o`3o003oo`00o`00oooo0002o`00o`;oo`0000T0o`00
ool00?l00?oo003oool00?l00?ooooooool00?l00?l00ooo00001_l00?oooooo0?l0003o003o003o
0?l000;oo`0000<0o`00o`00ool00?l00ol00?l01P3o003oo`00o`00ool00?l0o`00ool000Co003o
00Goo`000?l00?l00?oo003oool00006o`00o`030?l00?l00?oo003o017o003o00<0o`00o`00ool0
0?l00ol00?l0103o003oo`00ool00?oo0002o`00o`;oo`0000@0o`00o`00oooo003oo`000ol00?l2
ool000030?l00?oo003oo`000080o`000ooo00001`3o003oo`000?l00?ooool0o`00ooooo`3o0000
1Ooo00002P3o003oo`00ool0003o003oo`000?l00?oo0000o`00ool0003o0002ooooo`09o`00oooo
ool0o`00oooooooo0000o`00ooooo`3o003oo`0000;o003o00<0o`00ooooooooool01@3o0002oooo
o`030?l00?l0003ooooo00[ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool01_oo003o
ooooooooool00?oooooo0?l000;oo`0000Ooooooool00?l00?l0o`00oooooooo0000o`0000;ooooo
0_l00?l02@3o003oo`00ooooo`3o003o003ooooooooo0000o`00o`00o`02ooooo`030?l00?oo003o
003o00;oo`000_l00?l00ooo0000o`00o`00o`02o`00o`07ool00?l00?oo003o0?l00?oo0000o`00
o`00o`03ool00009o`00oooo003oo`00ool0003o003o003oooooool00?ooo`0000?o003o0ooo0000
0`3o003o003oooooo`09o`00o`03ool00?l00?oo003o01;o003o00?oooooo`00ool00?l02?l00?l2
ool000;o003o00@0o`00o`00o`3o0000o`000_l00?l2ool000030?l00?oo003ooooo0080o`000_l0
0?l2ool000050?l00?oo003oo`00ooooo`3o00000_oo00030?l0000:ool00?l00?ooooooool00?l0
0?ooo`00ooooool00?l0o`00ooooo`;o003o00D0o`00ool00?oo003oooooool00002ooooo`060?l0
0?ooooooo`000?l00?l00?ooo`000_l00?l01P3o003o003oooooo`3o003ooooo0?l000;ooooo0P3o
00000ooo003o0000ooooo`0:ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Co003o
0?l0003o003ooooo0_oo00001_l00?ooo`00ooooool00?ooo`00ooooo`Ko003o00Koo`00o`00o`3o
003o003o0?l00?oo0002o`00o`03ooooo`3o003o003o0080o`0000Goooooool00?l00?ooooooool0
0002o`00o`040?l00?l00?l0o`00ooooo`;oo`0000L0o`00o`00ool00?oo003oool00?l00?oooooo
00Ko003o00T0o`00o`00oooo003o003oool00?l00?ooo`00o`00oooo00000_l00?l2ool000Go003o
00?oo`00o`00ool00?l06?l00?l00ooo003o003oo`00o`02o`00o`030?l00?ooooooo`0000Co003o
00?oo`00o`00o`3o00000_l00?l00ooo003o003oool00002o`00o`?oo`0000?o003oool00?oo0000
0_oo00001P3o003oo`00ool00?oo003o003oool000<0o`0000Koo`000?l00?oo003o003ooooooooo
0002o`00o`;oo`0000@0o`00o`00oooo003oo`000`3o00000oooool0o`00o`00o`02ool00003oooo
o`3o003oo`0000?oo`0000Coooooool00?oo003o003o0P3o00000oooooooo`000?l00002ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0003ooooo
ool00003ooooo`090?l00?ooooooooooool00?ooool0o`00ool00?l00?oooooo00;o003o00Ooo`00
0?l00?l00?l0o`00o`00o`3o003ooooo00?oo`000_ooool01?l00?ooo`00o`00ooooool2ool00005
0?l00?l00?oo003oo`00o`3o00001?l00?l01@3o003oo`00o`00oooo003o003o00<0o`0000?ooooo
o`00ool00?l00_l00?l00ooo0000o`00o`00o`02ool000Co003o0_oo0002o`00o`030?l00?l00?oo
o`0000;o003o00?oo`00o`00ool00?l07_l00?l01?oo003o003oo`00oooo0002o`00o`03ool0003o
003oo`000080o`001?l00?l01ooooooo003oool0003o003oo`000?l00?l00?l00ooo00001?oooooo
003oooooo`3o0002o`00o`04ool00?l00?ooo`00ooooo`80o`0000?oo`00ooooool00?l00P3o0000
1?oo0000o`00ooooo`3o0002o`00o`;ooooo00<0o`00ooooooooool00P3o00001Oooooooo`00oooo
ool00?l0o`0000;oo`000P3o00001_oo0000o`000?l00?oooooo003oooooo`80o`0000?o0000oooo
ooooool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`04o`000?oo003oo`00o`00
o`80o`0000?oo`000?l0003o00000_oo00001_l00?l0o`000?l0003o003o003oooooo`;o003o00<0
o`00o`00ool00?l00ol00?l02_oooooo003oo`00o`3o003o003oool00?l00?ooooooo`00oooo0004
o`00o`050?l00?l00?oo003oo`00o`3o00000_oo0002o`00o`03ool00?l00?oo003o00;oo`0000<0
o`00o`00oooo00001ol00?l01?oo003o003o0?l00?oo000Qo`00o`03ool00?l00?oo003o00Go003o
00<0o`00o`00ool00?l00_oo00001?l00?l0o`00o`00o`3o0002o`00o`03ool00?l00?oooooo00?o
o`0000L0o`00o`00oooo003oo`000?l00?oo003o003o00?oo`0000`0o`00o`00oooo003oo`000?l0
0?l00?l0o`00o`00oooo003ooooo0?l00?l00?l3ool00006ooooo`3o003o003oo`00o`3o003o003o
0_oo00001Ooooooo003o0?l00?l00?ooo`0000<0o`0000Soo`00o`00oooooooo003o0?l00?oo0000
o`00ooooo`?oo`0000@0o`00o`00oooo003o00002oooool000[ooooo00?o000007ooo`1oool0/@1o
oolBooooo`040?l00?oo003oooooool000;ooooo00D0o`00ooooool00?ooooooo`00o`020?l00003
o`00oooooooo003o00;oo`000P3o00001?oo003o003oooooo`3o0003o`00o`040?l00?oo003o003o
ool000?o003o00P0o`00ool0003o003oooooool00?oooooo003oool000So003o00?oo`00o`00ool0
0?l01?l00?l3ool000Ko003o00?oo`00o`00ooooool00ol00?l00ooo003ooooo0?l00005o`00o`03
0?l00?l00?oo003o01Ko003o00?oo`00o`00oooo00000ol00?l20?l000;o003o1?oo00001P3o003o
003o0?l00?l00?l0o`00o`00o`Coo`0000Coooooool00?l00?ooo`000_l00?l2ool000@0o`0000Go
oooo0?l00?oo0000o`00ool00002ooooo`060?l00?l00?oooooo0?l00?oo0000o`001?oo00000`3o
003oo`000?l000020?l0000;ooooool00?oooooo0?l00?ooool0o`00ooooo`3o003oo`00ooooool0
0?l00_ooool20?l00003oooooooo003o000000_ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
4_ooool00ol00?l0o`000?l00002ool0000@oooooooo003o003oo`00oooo003oooooool0003o003o
o`00oooooooo0000o`00ool00?l00?l0o`00o`00o`80o`0000?oooooo`00oooo00000_ooool01P3o
003o003oo`00ool00?ooo`00o`00o`80o`0000?o003o0?l00?oo00000ooo0003o`00o`030?l00?l0
0?oo003o00;o003o00P0o`00o`00oooo0000o`00o`00oooo003o003oooooo`;oo`0000Ko003oool0
0?l00?oo003o0?l00?oo00020?l00005o`00oooo003o003oo`00oooo00001ol00?l00`3o003o003o
o`00o`0Bo`00o`0<ool00?l00?oo003oo`00o`3o003o003oool0003o003o003oool00?l00?ooo`00
0_l00?l01Ooo0000o`00o`00ool00?ooo`0000;o003o00Ooo`00o`00oooo003o003o0?l00?oo003o
003o00?oo`0000Go003oool00?l00?oooooo0?l00002ool000040?l00?oo0000o`00ool00080o`00
0_oo00000`3o003oo`00ool00002ool00080o`0000[ooooo0?l0003o0000o`00ooooo`3o003o003o
0?l00?l00?l0o`000oooool01_l00?ooooooooooool00?ooo`00o`00o`;oo`000_ooool01?l00?l0
o`00ool00?l0000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Soo`000?l00?oo
ooooo`00o`00ooooool0o`00o`00o`;ooooo00H0o`00ooooo`3o003o003oool00?ooool2o`00o`06
0?l00?l00?ooooooooooo`3o003ooooo0_l00?l01_oo003o003o0?l0003o003o003oooooo`;o003o
00Gooooo0?l00?oooooo003o0?l00002ool000;o003o00Ooo`00o`00ool00?l0o`00ool00?oooooo
003o00;oo`0000L0o`00ool0003o003o003o0?l00?l00?ooo`0000?o003o00D0o`00o`00ool00?oo
003oool00008o`00o`05ool0003o003o003oo`00oooo00004Ol00?l2ool00005o`00o`3o003o003o
0?l00?oo00001_l00?l01?oo003o003oo`00oooo0002o`00o`?oo`0000?o003o0?l0003o00001_oo
00000ol00?ooo`00ool000040?l00003ool0003o003ooooo0080o`0000Ooo`00o`00oooo003oo`00
oooooooo003o003o00;oo`0000?ooooo0?l00?ooool00`3o00001_ooool0o`000?l00?l00?l0o`00
ool00080o`000_oo0002ooooo`08ool00?ooooooo`000?l00?oooooo003o0?l00?ooool2o`00o`;o
oooo00?oo`00o`000?ooool02_ooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`030?l0
0?oooooooooo00;oo`000P3o0002ool00080o`0000Co003oooooool00?oooooo0_oo0002ooooo`;o
003o00Sooooo0?l00?oo003oo`000?l00?oo003o003oool000?o003o00Goo`00o`00ool00?oo003o
0?l00002ool00003ooooool00?ooo`0000;o003o00coooooool00?oo003oo`00ooooool00?l0o`00
oooooooo003o003oool00?l00?l20?l00007ool0003o003o003o0?l00?oo003o003oool00004o`00
o`03ool00?l00?l0o`0000Ko003o00<0o`00o`00ool00?l04?l00?l2ool00004o`00oooooooo003o
ool000;o003o00<0o`00o`00o`3o00000ol00?l00`3o003oo`00ool00003ool000030?l00?oo0000
o`000080o`0000Co003oooooool00?l0o`000ooo00001?l00?ooo`00o`00oooo0002ooooo`<0o`00
00Co003oool00?ooool0o`000_oo00000`3o003o003o0?l000030?l000?oo`0000Go003o0?l0003o
003ooooo0?l00002ool000?ooooo00So003oool00?oo003oo`00ooooool00?ooooooo`00o`<0o`00
00Coo`00ooooooooool0o`000_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo
07ooo`2a07oooa;ooooo00?oo`00o`00o`3o00000_ooool02Ol00?ooo`000?l00?ooooooo`00oooo
o`3o003oo`00ooooo`020?l00007o`00o`3o003oooooo`00oooo003o003oool00002ooooo`80o`00
0ol00?l0103o003o003oo`00o`3o0004o`00o`05ooooool00?l0o`00ool00?ooool00_oo00001?l0
0?ooo`00ool00?ooool4o`00o`?oo`000_l00?l00ooo0000o`00o`00o`04o`00o`03ool00?l00?oo
003o00?o003o00Koo`00o`00ool00?l0o`00ool0003o000Jo`00o`030?l00?l00?l0o`0000?oo`00
0_l00?l3ool00007o`00oooo003oo`00ool0003o003oo`000?l00002o`00o`04ool00?l00?l0o`00
0?l000?oo`0000P0o`00o`00ool00?l0o`00ool0003o003oo`000?l000Coo`0000L0o`00ool00?oo
oooo003o0?l00?oo0000o`0000?oo`0000Ooooooool0003o0000o`00ool00?ooool0o`0000;oo`00
00Coooooool00?oooooo003o1P3o0002ooooo`080?l00?oo0000o`00ooooo`3o003o003oool00?l0
000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Ko003oooooool00?ooo`000?l0
0?oo0004ooooo`040?l00?l00?ooooooool000<0o`0000Koooooool0003o003ooooo0?l00?l00?l2
ooooo`07o`00o`3o003oooooool00?l00?ooooooool000040?l00004ooooool00?ooo`00ool000;o
003o00<0o`00ool00?l00?l00_oo00001Oooooooo`00oooooooooooo003o0080o`0000?oo`000?l0
0?oo00001_l00?l00oooool0o`00o`00o`030?l00005ool00?l00?oo003oo`00ooooool00ol00?l0
0ooo003o003oo`00o`02o`00o`03ool00?l00?oo003o00_o003o00?oo`00o`00o`3o00000ooo0005
o`00o`03ool00?l00?oo003o00;o003o00Koo`00o`00oooo003ooooo0?l00?oo0004o`00o`;oo`00
0_l00?l3ool00004o`00o`3o003oo`00o`00o`Coo`0000Coooooool0003o003oo`000_ooool00ol0
0?ooo`00ool00002ool0000;0?l00?l00?oo003oooooo`3o003o003o0?l00?oo0000o`00oooooooo
00000oooool00`3o003o003oooooo`030?l000;oo`0000<0o`00ool0003o00000_ooool00ol00?oo
o`00ooooo`02ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo
4_ooool03Ol0003oooooooooo`3o003o003oooooo`3o003ooooo0?l00?oo003oooooool00?l00?l0
0oooool01ol00?l0o`00o`00ooooool0o`00ool00?l00?l00ooo00000`3o003oo`00o`00o`020?l0
00;ooooo0_l00?l2ool000050?l00?ooooooo`00o`00o`3o00000_l00?l01?oooooo003oool0003o
0002o`00o`80o`0000?oo`000?l00?oo00000_l00?l00`3o003o003oo`00o`030?l00003o`00o`3o
003oo`0000Oo003o00?oo`00o`00ool00?l00_l00?l00ooo0000o`00o`00o`0?o`00o`03ooooool0
0?oo003o00?o003o0_oo00001Ol00?ooo`00o`00o`3o003o003o00;oo`0000@0o`00o`00ool00?oo
o`000P3o0002o`00o`0<ooooo`3o003oo`00ool00?ooool0o`00ool00?l00?ooo`000?l00?l00?l0
o`000_l00?l00`3o003o003o0?l00002ool000030?l00?l00?oo003o00;o003o00?oo`000?l00?oo
00000`3o0002ooooo`05ool00?ooooooooooool00?ooool00P3o00001Ooooooo003oooooool00?oo
oooo00@0o`0000Ko003oooooo`3o003oooooo`00oooo0003ooooo`05ool0003o003oooooool00?l0
00002oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`0;o`000?ooooooo`00ool00?oo
ool0o`00o`00o`3o003o003o0?l00?ooool01@3o00001Ooo0000o`00ool00?oooooo003o00;ooooo
0P3o00001?l00?l0o`000?l0003o0002o`00o`03ooooool00?oooooo00?oo`0000Go003oool00?l0
0?l0o`00o`00o`02ool00003ooooo`3o0000o`000080o`0000Go003ooooooooo0000o`00ool00002
ooooo`060?l00?oo0000o`00ool0003o003oo`000_l00?l00`3o003o003oooooo`02o`00o`03ool0
0?l00?oo003o00?oo`001_l00?l01@3o003o003oo`00ool00?ooo`0000ko003o00H0o`00ool00?oo
003o003o0?l00?l00?l20?l00005ool00?l00?l0o`00o`00oooo00000P3o0004o`00o`80o`0000Oo
ooooool00?l00?ooo`000?l00?oo003o003o00@0o`0000Ko003oool00?oo0000o`00ool00?ooool3
0?l000;oo`0000Woooooool00?oo0000o`00ool00?l00?l0o`00ooooool00?l0103o00000oooool0
o`00ooooo`020?l000;ooooo00D0o`00ooooool00?ooo`000?l00003ooooo`80o`000oooool01@3o
003o003oooooool00?oo000000_ooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool00ol0
0000o`00o`00o`030?l00003ooooo`3o0000o`0000;ooooo00L0o`00ooooo`3o003oooooo`00o`3o
003ooooo00?o003o00Goooooo`00ooooooooo`000?l00002ooooo`03ool0003o003o003o00;ooooo
00[oo`00ooooool00?l0o`00oooooooo0000o`00ooooo`3o003oo`000ol00?l00`3o003oo`00ool0
0002o`00o`0:ool0003o003oo`00o`00oooo003o003o0?l00?l00?l0o`00ool000?o003o00Gooooo
o`00ool00?ooo`00o`00o`02ool000Co003o00Coooooo`00oooo003oo`000ol00?l00`3o003o003o
o`00o`06o`00o`030?l00?l00?oo003o00co003o00<0o`00o`00ool00?l00P3o0002o`00o`04ool0
0?l00?l0o`00o`00o`Koo`000_l00?l2ool000?o003o00Coo`000?l0003o003ooooo0P3o00000ol0
0?ooo`00ool00003ool000030?l00?l00?ooo`0000?oo`0000Co003oooooo`3o003o003o0`3o0000
2?oo003o003oooooo`3o003oooooool0003o003oo`000P3o00001?l00?l0o`000?l00?l00?l2oooo
o`070?l00?ooool0o`000?l00?oooooo003oool00002o`00o`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00001oool0Oooo0;40Oooo4_ooool02ol0003oooooooooo`3o003oo`000?l00?l00?oo
ooooool0003o003ooooo0080o`0000Kooooo0?l00?oo003ooooo0?l00?oo0002o`00o`03ool00?l0
0?ooo`0000;ooooo0`3o0002o`00o`06ool00?l00?oo003o0?l00?ooool0o`000_oo0002o`00o`80
o`0000coo`00o`00o`3o003oo`000?l00?oo003o003oool00?l00?l0o`00oooooooo00030?l00003
ooooool00?oo003o00Co003o00Goo`000?l00?l00?l0o`00ool00003o`00o`030?l00?oooooo003o
00?o003o00D0o`00o`00o`3o003o003o0?l00008o`00o`03ool00?l00?oo003o00;o003o0P3o0002
o`00o`030?l00?oo003o003o00;o003o0P3o0003ool000050?l00?l00?l0o`00ooooool00?l00`3o
00001ooo003oooooool0003o003oooooool00?l00?l00_oo00000ol00?l0o`000?l00002ool00005
ooooo`3o003oooooool00?ooool00`3o00001_ooool0o`00ool00?l00?l0o`00ool00080o`0000?o
oooo0?l00?ooool00P3o00000ooo003oooooool000020?l00005ool00?ooooooooooooooo`3o0000
1?ooool01`3o003o003o0?l00?oo0000o`00ooooool00?l01Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo103o00001_l00?l0o`00ooooooooool0o`00
o`00o`80o`000_ooool20?l00004ooooo`3o003oo`00o`00o`<0o`0000Koooooool00?l00?ooo`00
oooooooo00030?l00003ool00?ooooooo`000080o`0000Coo`00o`00o`3o003ooooo0_l00?l01_oo
003oooooo`00o`3o003oo`00o`00o`Coo`000`3o0002ool00080o`0000?oo`00ooooool00?l00`3o
00001?oo0000o`00ooooo`3o0002o`00o`04ool00?l00?oo003oo`00o`80o`000_l00?l00ooo003o
003oo`00o`0;o`00o`050?l00?l00?l0o`00o`00oooo00001?l00?l00`3o003oo`00o`00o`03o`00
o`;oo`0000Ooooooool0003o003o003o0?l00?ooool0o`0000;oo`000_l00?l0303o003oo`00o`00
ool00?l0o`00ool0003o003o003o0?l00?ooooooo`000?l000;oo`0000?ooooo0?l00?l00?l00ooo
00000ol00?l0o`00ooooo`02ool00080o`0000_oo`000?l0003o0000o`00ooooo`3o003oooooo`00
o`3o003oo`00ooooo`020?l0000:ooooo`3o003o003oool0003o003oooooool0003o003oooooo`00
o`Cooooo00D0o`00ooooooooooooo`00o`00000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oo
oa;ooooo00?o0000ool00?oo00001Oooool2ool00080o`001?ooool2ool000;ooooo00Go003ooooo
ool00?ooo`000?l00002ool000;ooooo00@0o`00o`00ool00?oooooo0_l00?l02P3o003ooooo0?l0
0?ooool0o`00ooooo`3o003ooooo0?l00?oo0003o`00o`;ooooo00?o003o0?l00?oo00000P3o0002
ooooo`H0o`0000Soo`00o`00o`3o003o003oool00?l00?ooo`000?l000;o003o0P3o00001?l00?oo
ooooo`00o`3o000@o`00o`030?l00?l00?oo003o00;oo`0000Goooooo`00ool00?oo003o0?l00005
o`00o`040?l00?oooooo003o0?l000;o003o00Coooooool00?l00?l0o`000_oo00001ol00?ooo`00
ool0003o003oo`000?l00?l00?l00P3o0002ooooo`050?l00?ooooooooooool0003o00000_l00?l0
1?oo0000o`00ool00?oo00050?l000;ooooo0_oo00000oooool0o`00ooooo`02ooooo`060?l00?oo
ooooo`00ooooo`3o003ooooo0P3o00002?ooool0o`00ool00?oo003ooooo0?l00?ooool0o`001_oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Woo`00
oooooooooooooooo0?l00?l00?ooo`000?l00?l00?l01?ooool00ol00?ooooooooooo`040?l00003
oooooooo0000o`000080o`0000goooooo`00ool00?ooo`00o`00oooo0000o`00ool00?ooool0o`00
ooooo`3o003oo`000080o`0000?o003o0?l00?l00?l00ooo00002@3o003oo`00ool00?l00?ooo`00
o`00o`3o003o003o0?l00002ool00006o`00ooooool0o`000?l00?l00?oooooo0ol00?l20?l000?o
003o00@0o`00o`00oooo003o003o0_oo00000ol00?l0o`00o`00o`04o`00o`03ool00?l00?oo003o
00;o003o00@0o`00o`00ool00?ooo`000_l00?l00ooo003o003o0?l000030?l000;o003o0_oo0002
o`00o`;oo`0000Go003oool0003o0000o`00ooooo`020?l00007oooooooo003oo`00ooooool00?oo
o`000?l00003ool00005o`00o`3o0000o`00o`00oooo00000P3o00000oooooooo`000?l000020?l0
0009ool0003o0000o`000?l00?ooool0o`00ooooo`3o003oo`0000;o003o00Coo`000?l00?oo0000
o`000oooool00`3o003oooooooooo`020?l000?ooooo00?oo`000?l00?ooool00_ooool0103o003o
003ooooooooo0002ooooo`030?l00?ooooooo`0000;ooooo00?o0000ooooooooool02Oooool000[o
oooo00?o000007ooo`1oool0/@1ooolBooooo`030?l00?ooooooo`0000;ooooo00<0o`00ooooo`3o
00000_ooool20?l000Cooooo00Coo`000?l0003o003o003o0oooool00ol00?ooooooooooo`020?l0
0003ool0003o003o003o0080o`0000Ko003o0?l00?ooool0o`00o`00o`3o0002ool00080o`000_oo
00001_l00?ooooooo`00ooooooooo`00ooooo`80o`0000Go003oool00?oo003o003o0?l00004o`00
o`03ool00?l00?l0o`0000;oo`0000Co003o0?l00?l00?oooooo0P3o0008o`00o`050?l00?l00?oo
003oool0003o00002Ol00?l00`3o003o003oo`00o`02o`00o`03ooooo`3o003o003o0080o`000_l0
0?l01`3o003o003oo`00oooo003o003ooooooooo00000P3o00001?oo0000o`00o`00ool00?l4ool0
00030?l00?l00?oooooo00;oo`0000<0o`00ool00?oo00000_ooool0203o003o003o0?l00?ooool0
o`00ool00?ooooooo`000P3o00001?oo0000o`00ool00?ooool20?l00003ooooool00?l0o`0000;o
oooo00<0o`00ooooooooool00_ooool01?oo003oooooool0003o0008ooooo`03ool00?oooooo003o
00;ooooo0P3o00000ooooooo0000ooooo`0:ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;o
oooo00Co0000ooooooooool0o`000oooool01?l00?l0o`000?l00?oo0002ooooo`04ool00?ooool0
o`00ooooo`80o`000oooool00`3o003oooooooooo`02o`00o`060?l00?l00?l0o`000?l00?l00?oo
oooo103o00001Ol00?ooo`00ool0003o003ooooo00<0o`0000Coo`00ooooo`3o003oo`000P3o0000
0ol00?ooooooool000030?l0000?ooooo`3o003oo`000?l00?ooooooo`00o`00oooo003ooooo0?l0
0?oo003o003oool0003o003o003o00;oo`000_l00?l00`3o003o003oool00003o`00o`03ool00?l0
0?oo003o00Ko003o00<0o`00o`00ool00?l00_oo00001@3o003oooooo`00oooo003o003o00;oo`00
00Wo003o0?l00?ooool0o`00ool00?oooooo003o0?l00?oo00000P3o00000ooooooo003o0?l00002
0?l00009ool0003o003ooooo0?l00?l00?l0o`00o`00oooo003ooooo0080o`000_oo00001@3o003o
o`000?l00?oo003o003o00;ooooo0_l00?l01oooool0o`00o`00ooooool0o`00oooooooo00000_oo
ool01@3o003ooooooooooooooooo003o0080o`000_ooool01@3o003ooooo0?l00?ooooooo`0000;o
oooo00Ko003o0?l00?oooooooooo0?l00?ooool40?l000;ooooo00?oo`00o`00ool000002oooool0
00[ooooo00?o000007ooo`1oool0/@1ooolBooooo`04o`000?oooooo003o0?l000;ooooo00<0o`00
ooooo`3o00000P3o00002?ooool0o`000?l00?ooool0o`00o`00ooooool0o`001Oooool2ool00004
o`00o`3o003oooooool000;ooooo00@0o`00oooooooooooo003o0_ooool01?l00?ooooooool00?oo
0003ooooo`;o003o00_ooooo0?l00?l00?ooo`00ooooo`3o003ooooo0?l00?l00?l0o`00o`00o`02
0?l00005o`00o`3o003o003o0?l00?ooool00`3o00000oooool0o`00o`00o`020?l00004ooooo`3o
003o003o0?l000?o003o0_oo00000oooool0o`00o`00o`0;o`00o`0<0?l00?l00?ooooooool0003o
003oooooo`00o`3o003oo`00ooooool00?oooooo0ol00?l2ooooo`040?l00?oo003o003oool000P0
o`0000Soo`000?l00?l00?l0o`00ool0003o003oo`000?l000;ooooo00coo`00ooooooooooooo`00
oooooooo003oooooool0003o003ooooo0?l00?oo0002ooooo`03o`00ooooool0o`0000<0o`0000Ko
oooo0?l0003o003oooooool00?ooool30?l00006o`00ooooooooooooooooo`3o003oo`000_ooool0
0`3o003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo
0;40Oooo4_ooool01?l0003ooooooooooooo0004ooooo`030?l00?oooooooooo00Cooooo103o0000
1Oooooooo`000?l00?ooool0o`0000Gooooo00<0o`00ooooo`3o00000_oo00000ooooooo003o0?l0
0002ool0000=0?l00?ooooooooooool0003o003oo`000?l00?oo003o003o0?l00?l00?l0o`00ool0
00020?l000;o003o00D0o`00ool00?ooool0o`00ool00002o`00o`04ool0003o0000o`000?l000;o
003o00H0o`00o`00o`3o003o003o0?l00?oo00020?l00004ooooool00?l0o`000?l000?o003o00?o
o`00o`00ool00?l00_l00?l00`3o003o003oo`00o`02o`00o`03ooooool00?ooo`0000?o003o103o
00001?l00?ooooooool0003o0002o`00o`040?l00?l00?l0o`00ooooo`<0o`0000Cooooo0?l0003o
0000o`000oooool01?oo0000o`000?l00?oo0002ooooo`030?l00?oooooooooo00?ooooo00Soo`00
ooooooooooooooooool00?l00?ooo`00o`00o`;ooooo00D0o`00ooooo`3o003ooooo0?l00002oooo
o`03ool00?l00?oooooo00Wooooo00Coo`00ooooo`3o003oo`000oooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo0;40Oooo4_ooool02?l0
003oooooooooooooool0o`00ool00?ooooooo`000oooool00ooo003oooooooooo`04ooooo`05ool0
0?oooooooooo0?l00?ooool00P3o00001?ooool0o`00ooooo`3o0002ooooo`030?l00?oooooooooo
0080o`0000Goo`00ooooooooooooooooool00002o`00o`04ool0003o0000o`000?l000;oo`000`3o
00000ooo003o003o0?l00002ool00004ooooo`3o003o003o0?l000;ooooo00T0o`00o`00ool00?oo
ooooool0003o003oooooool00?ooool00_l00?l00ooo003o003oo`00o`03o`00o`030?l00?l00?oo
003o00;o003o0`3o0006o`00o`?oo`000P3o00000ol00?ooooooo`00o`03o`00o`06ooooool00?oo
ooooo`00oooo003ooooo0P3o0002o`00o`06ooooool00?oo003oooooo`3o003oo`000P3o0002ool0
0080o`0000Goo`00o`00o`3o0000o`00ool000020?l0000>o`00ooooool0o`00oooooooo003ooooo
o`00oooo0000o`00ooooo`3o003oo`00ooooo`3o0002ooooo`03ool00?ooool0o`0000?ooooo00?o
003o0?l00?ooool00_ooool40?l00003ool00?oooooooooo00Oooooo00H0o`00ooooo`3o003ooooo
0?l00?l0000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00Go0000oooooooooooo
o`00o`00o`04ooooo`04o`00o`3o003oooooo`00o`Cooooo00T0o`00ool00?oo0000o`00ooooool0
0?ooo`00ooooo`3o00000oooool00`3o003ooooo0?l00002ooooo`03ool00?oooooooooo00?ooooo
00<0o`00ooooooooool00_l00?l00ooooooo003oooooo`02ooooo`0;0?l00?oo003oooooooooo`3o
003ooooo0?l00?oooooo003oooooool00?l00`3o0002ooooo`04o`00o`3o003oooooooooo`80o`00
0_ooool00`3o003oooooool00002o`00o`030?l00?l00?l0o`0000[o003o00P0o`00o`00o`3o003o
ooooool00?l00?oooooo0?l000;oo`000_ooool3o`00o`040?l00?oooooo003o0?l000;ooooo00?o
003oool00?ooool00P3o00000oooool0o`00ool000020?l000;oo`0000?ooooo0?l00?l00?l00ooo
ool01@3o003oo`000?l00?ooooooo`0000;ooooo00<0o`00ooooooooool00P3o00001Oooooooo`00
ool00?ooool0o`0000Cooooo00Ooo`00ooooooooooooooooo`00oooooooo003o00Oooooo00<0o`00
ooooooooool00_ooool01`3o003ooooo0?l0003o003oo`00ooooo`3o00000_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00So0000ool00?oooooooooo
o`00oooo003ooooo0?l000Cooooo00Goo`00ooooo`3o003ooooo0?l00002ooooo`04ool00?l00?oo
oooo0?l000;ooooo00<0o`00ooooooooool00oooool00`3o003ooooo0?l00002ool000?ooooo00Go
003oool0003o003o003oool00002ooooo`80o`00013oooooo`00o`3o003oooooool00?ooool0o`00
ool00?ooool0o`00ooooool00?oooooo0?l00?ooool0o`000_ooool20?l00003ool00?oooooooooo
00?o003o00Kooooo0?l0003o003o003oool00?l00?l20?l00009o`00o`3o003oo`00o`00oooooooo
003o0?l00?l00?oooooo00;o003o00Coooooo`00ool00?oooooo0ol00?l30?l000?o003o0P3o0000
1oooool0o`00o`00ool00?ooo`00ooooo`3o00000oooool70?l00008ool0003o003o003o0?l00?oo
oooo003o0?l00?ooool30?l00006ooooo`3o003ooooooooooooo003o003o0_oo00000`3o003ooooo
ooooo`02ooooo`03ool0003o003ooooo00?ooooo00?oo`00ooooooooool01oooool00`3o003ooooo
0?l00002ooooo`03ool00?ooooooo`0000;ooooo00<0o`00ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00D0o`00ooooo`3o003ooooo
ool00007ooooo`050?l00?ooooooooooooooool00?l00oooool00`3o003oooooooooo`02ooooo`07
ool00?ooool0o`00ooooool00?ooooooo`00o`06ooooo`03ool00?oooooooooo00Cooooo00Goo`00
ooooo`3o0000o`00ooooo`020?l00003ooooo`3o003o003o00;ooooo00?oo`000?l00?ooool00_oo
ool0403o003o003oool00?l00?l0o`00oooooooo003o003o0?l00?l00?l0o`00ooooo`3o003ooooo
0?l00?oo0002o`00o`03ool00?l00?oo003o00Go003o00@0o`00o`00o`3o003ooooo0_l00?l0103o
003ooooooooooooo0002ooooo`04ool00?ooool0o`00o`00o`<0o`0000Co003o0?l00?oo003ooooo
0ooo00001P3o003o003o0?l0003o003ooooo0?l000;ooooo00?o003oool00?ooool00_ooool00`3o
003ooooo0?l00002ooooo`030?l00?ooooooo`0000?ooooo00Goo`00oooooooo003ooooo0?l00002
ooooo`030?l00?oo003ooooo00;ooooo00H0o`00ooooooooool0o`00ooooo`3o0005ooooo`80o`00
00Co003ooooooooooooooooo0P3o0004ooooo`030?l00?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o000007ooo`1oool0/@1ooolBooooo`80o`001?ooool00`3o003ooooo
ooooo`02ooooo`030?l00?ooool0o`0000?ooooo00<0o`00ooooooooool00_ooool00`3o003ooooo
ooooo`03ooooo`80o`0000Goo`00oooooooo003oooooo`00o`03ooooo`80o`0000?oooooool00?oo
00000_ooool03@3o003oooooo`00ool00?ooo`000?l00?ooooooo`00ooooo`3o003oooooo`00o`3o
00001Oooool01@3o003ooooooooooooo003ooooo00;o003o00D0o`00ooooooooool0o`00o`00o`02
0?l00005o`00o`3o003o003oo`00o`3o00000_ooool02?l00?l0o`000?l00?l00?ooooooo`00oooo
ool0o`000_l00?l00ooooooo003oo`00o`02o`00o`;ooooo00Goo`000?l00?ooooooooooo`00o`03
ooooo`08o`00ooooool0o`00ool0003o003oooooo`00o`3o0002o`00o`030?l00?oooooooooo00Go
oooo00@0o`00ooooo`3o0000o`000oooool0103o003ooooooooooooo0002ooooo`040?l00?oooooo
oooo0?l000;ooooo00L0o`00oooooooo0000o`00ool00?ooool0o`0000Cooooo00<0o`00oooooooo
ool00_ooool01?l00?ooooooooooo`3o0004ooooo`03ool0003o0000o`0000?ooooo00Goo`00oooo
ooooooooooooo`00000;ooooo`002_ooool00ol00000Oooo07ooo`2a07oooa;ooooo00?o0000oooo
ooooool01?ooool01@3o003oooooool0003o003oo`0000Oooooo00<0o`00ooooooooool01Oooool0
1?oo0000o`000?l00?ooool20?l00004ool00?ooool0o`000?l000?ooooo00<0o`00oooooooo0000
0_ooool01@3o003oo`00o`00o`3o003ooooo0080o`0000Gooooo0?l00?ooooooooooo`00o`020?l0
00;o003o0_ooool03P3o003oooooooooooooool0o`00o`00o`3o003ooooo0?l00?l00?ooooooool0
0?l00?l0o`000_oo00020?l00003o`00o`3o003oo`0000Co003o00@0o`00o`00ool00?oo003o0`3o
00001ol00?oooooooooooooo0000o`00ooooool00?l00`3o00000ol00?ooo`000?l00006ooooo`03
o`00o`3o0000o`000080o`000_ooool01@3o003oooooooooooooool0o`0000;ooooo00@0o`00o`00
o`3o003ooooo0_oo00001_l00?l0o`00ooooo`3o003oo`000?l000;ooooo0P3o00001?ooool0o`00
oooooooo0002ooooo`050?l00?oo003oooooo`00o`3o00002?ooool00ooo003oooooooooo`05oooo
o`040?l00?oooooooooo0?l000;ooooo00Coo`00oooooooooooo00002oooool000[ooooo00?o0000
07ooo`1oool0/@1ooolBooooo`03o`000?ooool0o`0000?ooooo00<0o`00ooooooooool02Oooool0
103o003oooooool0003o0009ooooo`03ool0003o0000o`0000Gooooo00<0o`00ooooooooool00P3o
0003ooooo`<0o`0000Kooooo0?l00?ooooooo`000?l00?ooool20?l000Wooooo0_l00?l00oooool0
o`00o`00o`020?l00004ool00?ooooooo`00ooooo`Co003o00Coooooo`00ooooooooo`000ol00?l3
ooooo`@0o`0000Ooooooool0003o003o003oooooool00?l0o`0000?o003o00D0o`00ooooooooool0
o`00ool000040?l000Cooooo00H0o`00ool0003o003oooooool0003o0002ooooo`03ool00?l00?oo
003o00Cooooo00<0o`00ooooo`3o00001_ooool00ol00?ooooooool00002ooooo`050?l00?ooool0
o`00oooooooo00000P3o0006ooooo`080?l00?ooool0o`00ooooool00?ooo`00ooooool00?l3oooo
o`03o`00oooooooooooo00Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o000007ooo`1o
ool0BP1oool6000000co00002@00001<07oooa;ooooo00?o0000ooooooooool01?ooool00`3o003o
ooooooooo`02ooooo`03ool00?oooooo003o00;ooooo00@0o`00oooooooooooo003o1Oooool00ooo
003oooooooooo`02ooooo`030?l00?oooooooooo00;ooooo00Ooo`00ooooo`3o0000o`00o`00oooo
oooo003o00;ooooo00So003o0?l00?l00?oooooo0?l00?oo003oooooool000@0o`000oooool01_l0
0?l0o`00ooooool00?l0o`00ool000;o003o00?oooooo`00ool00?l00_ooool01P3o003oooooo`00
ool00?ooo`000?l000;o003o00Coooooo`00ool00?oooooo0_l00?l00`3o003oo`00o`00o`02o`00
o`0:0?l00?l00?l0o`00ool00?l00?l0o`00o`00ooooool0o`00o`00o`<0o`000_oo00001?ooool0
o`00ool0003o0002ooooo`<0o`0000?oooooo`00oooo00000P3o00001?ooooooo`00ool0003o0003
ooooo`03ool00?ooool0o`0000;ooooo00Go003ooooooooooooooooo0?l00002ooooo`030?l00?oo
ool0o`0000Sooooo00D0o`00oooooooooooooooo0?l00003ooooo`050?l00?ooooooooooooooo`3o
00000oooool02_l00?ooooooooooo`3o003oooooo`00ooooooooo`00ooooo`3o0003ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo03d0Oooo3@00000K0?ooO`d00000?`1o
oolBooooo`03o`000?oooooooooo00?ooooo00<0o`00ooooooooool01Oooool00ooo003oooooo`00
o`07ooooo`030?l00?oooooooooo00_ooooo0P3o0002ooooo`030?l00?oooooooooo00?ooooo0P3o
00001?l00?ooooooool00?l00?l5ooooo`050?l00?ooool0o`00ooooo`3o00000_ooool00`3o003o
ooooooooo`02ooooo`06o`00o`3o0000o`00o`00oooooooo003o0P3o00001Ol00?l0o`00ooooo`3o
003o003o00?ooooo00So003o0?l00?l00?ooooooo`00oooo0000o`00ooooo`;o003o00D0o`00oooo
o`3o003oo`00ooooo`030?l000?ooooo00Co003o0?l0003o003ooooo0_l00?l00oooooooo`00oooo
o`02ooooo`030?l00?ooool0o`0000;ooooo00<0o`00ooooooooool01_ooool01P3o003oooooo`00
ool00?ooooooo`00o`Gooooo00<0o`00ooooo`3o00000oooool01`3o003oooooooooooooool0o`00
ooooo`3o00000_ooool00`3o003oooooooooo`04ooooo`030?l00?oooooooooo00Cooooo00?oo`00
ooooooooool00oooool00ol00?oo0000ooooo`0:ooooo`002_ooool00ol00000Oooo07ooo`0^07oo
o`l00000=@3oogl@000002l0Oooo4_ooool00ol0003oooooooooo`07ooooo`030?l00?l00?oooooo
00Cooooo00<0o`00ooooooooool01oooool20?l000?ooooo00<0o`00ooooo`3o00001_ooool00`3o
003oooooooooo`020?l000Cooooo00Co003oool0003o0000o`001?ooool40?l00003ooooo`3o003o
oooo00;o003o0P3o00001_l00?l0o`00ooooo`3o003o003oool000;ooooo00H0o`00oooooooo0000
o`00ooooool00?l2ooooo`070?l00?l00?oo003oo`00o`3o003o003oooooo`04o`00o`050?l00?oo
ooooooooo`00ooooool00_l00?l20?l000;ooooo00So003o0?l0003o003o003oooooo`3o003ooooo
0?l000;ooooo0P3o0003ooooo`080?l00?ooooooooooooooool00?ooooooo`00ooooool30?l000Co
oooo00L0o`00ooooooooooooooooool00?ooool0o`0000Wooooo00L0o`00oooooooo003ooooo0?l0
0?ooool0o`0000Oooooo00?oo`00ooooooooool00_ooool00`3o003oooooool00005ooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo02H0Oooo2000001D0?ooO`L00000:01o
oolBooooo`03o`000?oooooooooo00Wooooo0P3o0005ooooo`040?l00?ooool0o`000?l000;ooooo
00D0o`00ooooooooooooooooo`00o`07ooooo`030?l00?oooooooooo00?ooooo00Ko003ooooooooo
ooooo`00ooooo`3o0003ooooo`0:ool00?oooooooooooooooooo0000o`00ooooo`3o003oo`000?l0
00?ooooo00<0o`00ooooo`3o00000oooool01Ol00?ooooooooooooooool0o`0000;ooooo0P3o0002
o`00o`08ooooool00?l0o`00ooooool00?l0o`00o`00o`3o0002o`00o`03ooooool00?oo003o00;o
003o0_ooool01?l00?oooooo0?l00?ooool20?l00004ooooo`3o003ooooo0?l000;ooooo00<0o`00
ooooo`3o00000_ooool01ol00?l0o`00oooooooooooo003o0?l00?oo00001?ooool00ooo0000o`00
0?l00004ooooo`040?l00?ooool0o`00ooooo`80o`001oooool20?l000;ooooo00<0o`00oooooooo
ool01_ooool00`3o003oooooooooo`02ooooo`80o`0000?o003oooooooooool01?ooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00001oool0Oooo01l0Oooo
1`00001S0?ooO`L000008@1ooolBooooo`03o`000?oooooooooo00Sooooo00@0o`00oooooooo003o
o`002?ooool00ol00?ooo`00ooooo`06ooooo`030?l00?oo003ooooo00Cooooo00Co003o0?l00?oo
ooooo`000_ooool00`3o003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l00P3o0000
1?ooool0o`00ooooo`3o0002ooooo`0:0?l00?oooooooooo0?l00?ooool0o`00ooooo`3o003ooooo
0?l000?ooooo00So003o0?l00?ooool0o`00ooooool00?l0o`00o`00o`?ooooo0_l00?l00`3o003o
ooooo`00o`02o`00o`07ooooool00?oooooo0?l00?oooooo003oool00003ooooo`030?l00?oo003o
o`0000?ooooo00Oo003o0?l00?oooooooooo0?l00?ooool0o`0000;ooooo0P3o0006ooooo`050?l0
0?ooooooooooooooo`3o00000_ooool00ooo003oooooooooo`06ooooo`040?l00?ooooooooooool0
00Gooooo00?oo`00ooooooooool04Oooool00`3o003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`00001oool0Oooo01T0Oooo1P00001a0?ooO`H000006`1ooolBooooo`03
o`000?oooooooooo00Sooooo00<0o`00ooooooooool01?ooool00`3o003oooooo`00o`02ooooo`04
ool00?l00?oooooo0?l000Cooooo00<0o`00o`00ooooool00oooool00`3o003o003o0?l00002oooo
o`050?l00?ooooooooooooooool00?l01_ooool0203o003o003oo`00ooooool0o`00ooooool00?l0
o`000oooool2o`00o`030?l00?l00?oooooo0080o`0000Kooooo0?l00?l00?ooooooo`00ooooool2
0?l000;ooooo00Co003oool00?oooooooooo0_l00?l2ooooo`07o`00oooooooo003oo`00ooooool0
o`00o`00o`02ool000;o003o0_ooool01ol00?ooooooooooooooool0o`00ool00?ooool00P3o0003
ooooo`03o`00ooooooooo`0000;ooooo00D0o`00ool00?oo003ooooo0?l00005ooooo`050?l00?oo
ool0o`00ooooo`3o00000oooool01@3o003oooooooooooooooooo`0000_ooooo00<0o`00oooooooo
ool02Oooool00`3o003oooooooooo`02ooooo`05o`00o`3o003ooooo0?l00?oo00001Oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000Oooo07ooo`0E07ooo`@00000O@3oogl4000001L0
Oooo4_ooool00ol0003ooooo0?l0000<ooooo`030?l00?oo003ooooo00Gooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`030?l00?oooooooooo00Cooooo0_l00?l5ooooo`03
0?l00?oooooooooo00Cooooo0P3o00001Ol00?ooooooooooooooool0o`0000Sooooo0P3o00001?oo
ool0o`00o`00o`3o0003ooooo`080?l00?oo003o003oo`00oooooooo003oooooool00?l20?l00005
o`00ooooool0o`00ooooool00?l00`3o0002ooooo`0:o`00ooooooooooooooooool00?ooooooool0
003o003ooooo0?l000Gooooo00D0o`00ooooo`3o003ooooo0?l00004ooooo`030?l00?ooool0o`00
00Gooooo00?oo`000?l00?ooool03Oooool01Ol00?l0o`000?l00?ooooooo`0000Gooooo00<0o`00
ool00?ooool00oooool20?l000cooooo00D0o`00ooooooooooooooooo`00000;ooooo`002_ooool0
0ol00000Oooo07ooo`0@07ooo`D00000Q@3oogl600000140Oooo4_ooool00ol0003oooooooooo`08
ooooo`03ool00?oooooooooo00;ooooo00@0o`00ooooooooool0o`001?ooool00ol00?oooooooooo
o`04ooooo`030?l00?l00?oooooo00Cooooo0P3o0006ooooo`030?l00?oo003o003o00Kooooo00@0
o`00ooooooooool0o`000_ooool01ol00?ooooooo`00oooooooo003oooooool00?l00oooool2o`00
o`;ooooo00?o003oooooo`3o00000_ooool01?l00?l0o`00o`00ooooool2o`00o`040?l00?oooooo
ooooool000?ooooo00?o003ooooooooo00000_l00?l30?l000?ooooo00<0o`00oooooooo00001?oo
ool01@3o003ooooooooooooo0000o`0000Kooooo00@0o`00o`00o`3o0000o`001?ooool01_l00?l0
o`00oooooooooooo003o0?l000;ooooo00<0o`00ooooooooool01?ooool0103o003oooooooooo`3o
0002ooooo`070?l00?ooooooooooooooool00?ooo`00o`00o`0<ooooo`030?l00?oooooooooo00;o
oooo00Ko003oooooooooooooooooo`00ool0000;ooooo`002_ooool00ol00000Oooo07ooo`0807oo
o`P00000T03oogl7000000X0Oooo4_ooool00ol0003oooooooooo`06ooooo`030?l00?oooooooooo
00_ooooo00D0o`00oooooooooooooooo0?l00006ooooo`;oo`000oooool0103o003oooooooooool0
0?l7ooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooo`3o00000oooool01P3o003ooooooooo
ooooool0o`00ool000Kooooo00Coo`00ooooool00?oo003o0_ooool01_l00?oooooo0?l00?l00?oo
oooo0?l000Kooooo0_l00?l7ooooo`03o`00oooooooooooo00;o003o1Oooool01`3o003oo`00oooo
o`3o003o003oooooo`3o00002?ooool01Ol00?oooooo0?l00?ooool0o`0000?ooooo00@0o`00oooo
o`3o003o003o1_ooool01@3o003oooooool00?ooool0o`0000Kooooo00?o003oooooooooool02ooo
ool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o000007ooo`1oool00P1oool6000009l0oomo1@00000507oooa;ooooo00?o0000
ooooooooool02oooool00ol00?oooooo0?l00004ooooo`03o`00oooooooooooo00Cooooo00?o003o
oooooooo00001?ooool00`3o003oooooooooo`05ooooo`04o`00ooooooooo`00ooooo`80o`0000?o
003oooooo`3o00000_ooool00ol00?ooooooooooo`03ooooo`03o`00oooo003oo`0000;ooooo00D0
o`00o`00o`3o003ooooo0?l00003ooooo`040?l00?oooooooooo0?l000;o003o00Coooooo`00oooo
oooooooo1Ol00?l00ooooooo003o0?l00002ooooo`;o003o00H0o`00ooooooooooooooooo`00o`3o
0002ooooo`040?l00?oooooo003o0?l000?ooooo00<0o`00ooooo`3o00000P3o00001?ooooooo`00
ooooo`3o000<ooooo`030?l00?oo0000o`0000?ooooo00@0o`00ool0003o0000o`000_ooool00ol0
0?ooooooool00004ooooo`80o`001Oooool00ol00?ooooooooooo`06ooooo`05o`00oooooooooooo
ooooo`3o00002Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000Oooo000000020000
0:X0oomo100000000`1oooooooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00<0o`00oooo
ooooool05?ooool0103o003oooooooooo`3o0004ooooo`05o`00ooooooooooooool0003o00000ooo
ool0203o003oooooooooo`3o003oo`000?l00?ooool0o`001?ooool01_l00?ooooooooooool00?oo
ooooo`00o`Kooooo00<0o`00ooooo`3o00000_ooool00ol00?ooooooooooo`02ooooo`04o`00oooo
oooo003oo`00o`;ooooo00<0o`00ooooool00?l00_ooool0103o003o003oooooool00?l3ooooo`03
o`00oooooooooooo00;ooooo00?oo`00ooooo`3o00000oooool30?l00003o`00oooooooooooo00;o
oooo00?oo`00ooooooooool01?ooool01Ol00?oooooooooooooooooo003o00Sooooo00<0o`00oooo
ooooool00_ooool00`3o003oooooooooo`020?l000Kooooo00<0o`00ooooooooool01?ooool00`3o
003oooooooooo`02ooooo`070?l00?ooooooooooooooo`3o003oooooo`00o`04ooooo`030?l00?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000000003oogl0/03oogl0
0`00003oooooooooo`0@ooooo`03o`000?l00?oooooo00Cooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`05ooooo`030?l00?oooooooooo00Cooooo00?oo`00ooooooooool01_ooool0
0`3o003o003oooooo`03ooooo`03o`00oooooooooooo00Gooooo00<0o`00ooooool00?l01_ooool0
2@3o003ooooooooooooooooo003oooooo`3o003ooooo0?l00002ooooo`060?l00?ooool0o`00oooo
o`3o003o003o0oooool00`3o003o003oooooo`02ooooo`;o003o00@0o`00o`00o`3o003ooooo0ol0
0?l01?oooooo003oo`00ool00?l5ooooo`80o`000oooool2o`00o`040?l00?oooooo003o0?l000So
oooo0P3o0007ooooo`03ool00?oooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003o
ooooooooo`02ooooo`030?l00?oooooooooo01Oooooo00@0o`00oooooooooooo00002oooool000[o
oooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00Gooooo00Co003o0?l00?oo
oooooooo0P3o000<ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool00_ooool01Ol0
0?oooooooooooooooooo003o00Sooooo00@0o`00o`00oooooooo003o1_ooool01Ol00?l0o`000?l0
0?oooooo003o00Cooooo0_l00?l2ooooo`03o`00oooooooo003o00Wooooo0_l00?l4ooooo`<0o`00
00Woooooo`00oooo003oooooo`00oooooooo003oooooool00?l01_ooool00`3o003oooooooooo`02
ooooo`060?l00?oooooooooo0?l00?oooooo003o1_ooool01?oo003oooooooooo`3o000;ooooo`03
o`00oooooooooooo00?ooooo00<0o`00ooooooooool01oooool00`3o003oooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0
/@3ooglBooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool00oooool2o`00o`03oooo
ool00?oooooo00Oooooo00?o003oooooooooool01Oooool00`3o003oooooooooo`03ooooo`030?l0
0?l00?oo003o00;ooooo00@0o`00oooooooooooooooo0P3o00000oooooooo`000?l00002ooooo`07
0?l00?ooooooooooo`00oooooooo003o0?l00002ooooo`06o`00ooooooooooooo`00ooooool0o`00
1_ooool0103o003oooooooooo`3o000Aooooo`03o`00oooooooooooo00Sooooo00<0o`00ooooool0
0?l09_ooool00ol00?ooooooo`00000;ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo
00Go0000ooooooooooooooooo`00o`0=ooooo`030?l00?oooooooooo00;ooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01oooool00`3o
003o003oooooo`04ooooo`030?l00?oooooooooo00Kooooo00Co003oooooooooool0o`001oooool0
0`3o003o003oooooo`02ooooo`060?l00?ooooooooooooooool00?oooooo0_l00?l0103o003o003o
0?l0003o0002ooooo`03o`00ooooool0o`0000;ooooo00?o003oooooooooool02_ooool00ooo0000
o`00ooooo`020?l000Gooooo00@0o`00oooooooooooo003o1?ooool0103o003oooooooooool00?l2
ooooo`050?l00?ooooooooooooooool00?l01_ooool0103o003oooooooooo`3o0005ooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool04Oooool00`3o003ooooooooo
o`03ooooo`030?l00?oooooooooo00[ooooo0P3o0004ooooo`05o`00ooooooooooooooooool00?l0
0_ooool00`3o003oooooo`00o`03ooooo`030?l00?oooooo003o00Oooooo00<0o`00ooooool00?l0
0oooool00ol00?l0o`00ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Ko003o0?l00?l00?oo
ooooo`00ooooool2o`00o`Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02oooo
o`03o`00oooooooo003o00Cooooo00<0o`00ooooooooool00oooool01_l00?ooooooooooo`3o003o
oooo0?l000kooooo00?o003oooooooooool03?ooool00ol00?ooooooo`00o`04ooooo`040?l00?oo
oooooooo0?l000cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3o
oglBooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool00oooool00ol00?oooooooooo
o`05ooooo`03o`00oooooooooooo00?ooooo00<0o`00ooooooooool01Oooool00ol00?oooooooooo
o`04ooooo`03o`00ooooooooo`0000;ooooo00?o003oooooo`3o00001Oooool00ol00?l0o`00oooo
o`02ooooo`80o`000_ooool7o`00o`?ooooo0_l00?l>ooooo`04o`00ooooooooooooo`00o`?ooooo
00So003ooooooooooooo003oooooool00?ooooooo`00o`?ooooo00<0o`00ooooooooool00_ooool0
0`3o003oooooooooo`06ooooo`050?l00?ooooooooooooooool00?l02oooool00ooo0000o`00oooo
o`0Eooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool0
0ol0003oooooooooo`0Hooooo`03o`00oooooooooooo00Gooooo00Ko003oooooooooooooooooo`00
o`3o000=ooooo`03ool00?oooooooooo00Kooooo00?o003oooooooooool02oooool01Ooo003o003o
o`00oooooooo003o00;ooooo00?o003oooooool00?l01Ol00?l4ooooo`03o`00oooooooooooo00So
oooo00<0o`00ooooooooool05Oooool00`3o003oooooooooo`0<ooooo`03ool00?oooooooooo00?o
oooo00?o003oooooooooool02_ooool00`3o003oooooo`00o`0<ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`03ooooo`050?l0
0?ooooooooooooooo`3o00003Oooool00ol00?ooooooooooo`0Iooooo`03o`00oooooooooooo00?o
oooo00Go003o0?l00?l00?ooo`00o`00o`06ooooo`03o`00oooooooooooo00;ooooo0_l00?l3oooo
o`050?l00?oooooo003oooooool00?l00_ooool5o`00o`03ooooool00?oo003o00?ooooo00Ko003o
0?l00?oooooo003oooooool00?l6ooooo`040?l00?oooooooooo0?l000Sooooo00@0o`00oooooooo
oooo003o8?ooool01@3o003ooooooooooooooooo003o00Cooooo00?o003oooooooooool02oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000oooo
ooooool0;_ooool00`3o003oooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00<0o`00oooo
ooooool00_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo0ol00?l01Ooo
oooo003ooooooooooooo003o00Sooooo00D0o`00oooooooooooooooo0?l0000>ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool03Oooool00`3o003oooooooooo`0Aooooo`03o`00oooo
oooo000000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`09
ooooo`03o`00oooooooooooo01Kooooo00?o003oooooool00?l00oooool00ol00?ooooooooooo`0C
ooooo`03o`00oooooooooooo00Oooooo00<0o`00ooooooooool00oooool3o`00o`Gooooo00Go003o
oooooooooooo003o0?l00003ooooo`03o`00oooooooooooo00;ooooo00<0o`00ooooooooool00ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00<0o`00ooooooooool01Ooo
ool01?l00?ooooooooooo`3o000Booooo`03o`00oooooooooooo01_ooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool03?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Sooooo00<0
o`00ooooooooool01Oooool00ol00?ooooooool0000:ooooo`04o`00ooooooooooooo`00o`?ooooo
0_l00?l2ooooo`?o003o0_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooo003o00?ooooo
00<0o`00ooooool00?l01?ooool2o`00o`Kooooo00<0o`00ooooooooool0>?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool07ooo
ool00ol00?ooooooooooo`06ooooo`06o`00ooooooooooooo`00ooooool0o`001oooool01ol00?oo
oooooooooooooooo003oooooool00?l01Oooool00ol00?ooooooooooo`03ooooo`;o003o1oooool0
2_l00?ooooooooooool00?ooooooo`00oooooooo003oooooool00?l6ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool05?ooool00`3o003oooooooooo`04ooooo`030?l00?oooooooooo
01;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03
0?l00?oooooooooo00;ooooo00@0o`00ooooooooool0o`001?ooool00ol00?ooooooo`00o`0=oooo
o`030?l00?ooool0o`0000;ooooo00?o003oooooooooool01oooool00`3o003oooooooooo`02oooo
o`03o`00oooooooooooo00Sooooo00?o003o0?l00?ooool01?ooool00`3o003ooooo0?l00002o`00
o`Gooooo00Go003oooooool00?ooooooo`00o`07ooooo`05o`00oooooooooooooooooooo00000_oo
ool00ol00?ooooooooooo`02o`00o`[ooooo00?o003oooooooooool04oooool2o`00ob_ooooo00?o
003oooooool000002oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooo
oooo02Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`05ooooo`030?l00?ooool0
o`0000Gooooo00?o003oooooooooool01_ooool0103o003oooooooooool00?l2ooooo`03o`00oooo
oooo003o00Cooooo00Oo003oooooool00?ooooooo`00oooooooo003o00?ooooo00<0o`00oooooooo
ool00_ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00Goo`00oooooooo
ooooooooo`00o`0Qooooo`03o`00oooooooooooo01Oooooo00?o0000ooooooooool02Oooool000[o
oooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo03Gooooo00?o003ooooooooo
ool03oooool00`3o003o003oooooo`03ooooo`03o`00oooooooooooo00Gooooo0_l00?l2ooooo`03
o`00oooooooo003o00?o003o00@0o`00o`00oooooooooooo0_l00?l5ooooo`03o`00oooooooooooo
00oooooo00<0o`00ooooooooool01oooool00ol00?ooooooooooo`0Nooooo`04o`00oooooooooooo
0?l000Kooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBoooo
o`03o`000?oooooooooo00;ooooo00<0o`00ooooooooool06_ooool00ol00?ooooooooooo`05oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0;oooo
o`?o003o00?oooooool00?ooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03
o`000?oooooooooo02Sooooo00D0o`00ooooooooooooooooo`00o`0:ooooo`03o`00oooooooo003o
00Gooooo00Co003ooooooooooooo003o0_ooool01@3o003oooooooooooooool0o`0000?ooooo00Go
003oooooooooooooooooo`00o`02ooooo`050?l00?l00?ooooooooooool00?l00_ooool00ol00?oo
ooooooooo`03ooooo`;o003o0oooool01?l00?ooooooooooool00?l2ooooo`04o`00oooooooooooo
o`00o`Oooooo00?o003oooooooooool00oooool00`3o003ooooo0?l0000Booooo`030?l00?oooooo
oooo00Oooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool01?l0003oooooooooo`3o000F
ooooo`03ool00?oooooooooo00Sooooo00@0o`00oooooooooooo003o3?ooool00ol00?ooooooo`00
o`0;ooooo`?o003o3?ooool01P3o003oooooo`00ool00?ooooooo`00o`;ooooo0_l00?l2ooooo`04
o`00ooooooooooooo`00o`Cooooo00?o003oooooooooool01?ooool01?l00?ooooooooooool00?l3
ooooo`030?l00?oooooooooo00Sooooo00<0o`00ooooooooool01_ooool00`3o003oooooooooo`0R
ooooo`030?l00?oooooooooo00Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?oo
O`3oogl0/@3ooglBooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0;?ooool00`3o
003o003oooooo`02ooooo`03o`00oooooooooooo00;ooooo00<0o`00ooooooooool01?ooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Co003o0oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0Foooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3o
ogl0/@3ooglBooooo`03o`000?oooooooooo02;ooooo00Go003oooooooooooooooooo`00o`08oooo
o`03ool00?oooooooooo01Gooooo0ol00?l00ooooooo003oooooo`02ooooo`03o`00oooooooo003o
00?ooooo0_l00?l3ooooo`04o`00oooooooo003oo`00o`Wooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`0:ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00ool0003ooooo00[ooooo000:ooooo`03o`00003oogl0oomo
0;40oomo4_ooool00ol0003oooooooooo`07ooooo`030?l00?oooooo003o02_ooooo00?o003ooooo
ool00?l04oooool01Ol00?ooooooooooool00?oooooo00;o003o0_ooool2o`00o`Sooooo00Go003o
ooooooooooooooooo`00o`04ooooo`03o`00oooooooooooo00Kooooo0P3o000oooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0D
ooooo`040?l00?oooooo003oo`00o`;ooooo00Go003ooooooooo003oooooo`00o`0<ooooo`03o`00
oooooooooooo00gooooo00?o003oooooooooool00oooool2o`00o`?ooooo0_l00?l00`3o003o003o
ooooo`06ooooo`04o`00ooooooooooooo`00o`?ooooo00?o003oooooool00?l00oooool00ol00?oo
ooooooooo`0Wooooo`05o`00ooooooooooooooooool00?l00_ooool00ol00?ooooooooooo`0Coooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3o
ogl0/@3ooglBooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool01oooool00`3o003o
ooooooooo`0Hooooo`03o`00oooooooo003o00[ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`07ooooo`07o`00o`3o003oooooooooool00?ooooooo`00o`07ooooo`;o003o00?ooooo
o`00ooooool00_ooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooo`3o0000
>Oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003o
ogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0<ooooo`030?l00?l00?oooooo00Gooooo00<0
o`00ooooooooool05Oooool00`3o003oooooo`00o`09ooooo`050?l00?ooooooooooooooool00?l0
1oooool01Ol00?ooooooooooool00?oooooo00;o003o0oooool0103o003oooooooooool00?l3oooo
o`060?l00?ooooooooooo`00oooooooo003o0_ooool01Ol00?oooooooooooooooooo003o00;ooooo
00?o003oooooool00?l00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01Gooooo
00?o003oooooooooool09_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?oo
O`2a0?ooOa;ooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01_ooool2o`00o`[ooooo00?o003oooooooooool01ooo
ool2o`00o`Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0;ooooo`;o003o0_oo
ool01?l00?ooooooooooooooool3o`00o`03ooooool00?oo003o01Gooooo00?o003oooooooooool0
7oooool00ol00?ooooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003o
ogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0Uooooo`03o`00oooooooo003o00_ooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool00oooool02?l00?oooooooooooooooooo003oooooool00?oooooo0ol00?l7oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;oooo
o`03o`00oooooooooooo02Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3o
ogl0/@3ooglBooooo`03o`000?oooooooooo00oooooo00D0o`00ooooooooooooooooo`00o`07oooo
o`03o`00oooooooooooo00kooooo00Ko003ooooooooooooo003oooooo`3o000:ooooo`03o`00oooo
oooooooo00Sooooo00?o003oooooooooool00_ooool2o`00o`;ooooo0_l00?l4ooooo`05o`00oooo
ooooooooooooool00?l02Oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool08oooool01?l00?ooooooooooool0000;ooooo`002_ooool00ol00000oomo
0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0Qooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool01_ooool01?l00?ooooooo`00ool00?l7ooooo`03
o`00oooooooooooo00;o003o0_ooool00ol00?ooooooo`00o`06ooooo`03o`00oooooooooooo00So
oooo00?o003oooooool00?l02Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00_o
oooo00?o003oooooooooool07oooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0Kooooo`03o`00
oooooooooooo027ooooo00?o003oooooooooool03_ooool01`3o003ooooooooooooooooo003ooooo
ool00?l00oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooooooo`?o003o5?ooool0
0ooo003oooooooooo`0Booooo`03o`00oooooooooooo01kooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00[ooooo00?o003ooooo
ooooool03oooool00ol00?ooooooooooo`08ooooo`05o`00ooooooooooooooooool00?l04oooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00;o003o2Oooool01?l00?oooooooooooooo
ool2o`00o`;ooooo00?o003oooooool00?l03?ooool00ol00?ooooooooooo`0Yooooo`03o`00oooo
oooooooo01Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglB
ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`03
ooooo`;o003o4_ooool2o`00o`?ooooo1?l00?l2ooooo`03o`00oooooooo003o00Gooooo0ol00?l4
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooool00?l02_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?oo
O`3oogl0/@3ooglBooooo`03o`000?oooooooooo01cooooo00Co003ooooooooooooo003o0_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooo003o00Wooooo00Go003oooooool00?ooooooo`00
o`02ooooo`08o`00ooooooooooooooooool00?ooooooo`00ooooool2o`00o`Wooooo00?o003ooooo
ooooool0:Oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo00Co
oooo00Co003ooooooooooooooooo0_l00?l2ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool04?ooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00?ooooo00?o003ooooo
ooooool01?l00?l2ooooo`;o003o00Koooooo`00ool00?oo003oooooool00?l6ooooo`03o`00oooo
oooooooo00;ooooo00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`0Gooooo`03o`00
oooooooooooo00_ooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000oomo0?ooO`2a0?ooOa;ooooo00Go0000ooooooooooooooooool0000Vooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool03Oooool01Ol00?oooooooooooooooooo003o00So
oooo00?o003oooooool00?l01_ooool00ol00?ooooooooooo`11ooooo`03o`00oooooooooooo00[o
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo
0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0=ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooool00?l03?ooool00ol00?ooooooo`00o`02ooooo`;o003o
0_ooool2o`00o`03ooooool00?oooooo00?ooooo00Go003oooooool00?ooooooo`00o`03ooooo`04
o`00ooooooooooooo`00o`?ooooo0_l00?l<ooooo`03o`00oooooooooooo00cooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00oooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;o
oooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`0Nooooo`03o`00oooooooooooo00Co
oooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`04ooooo`;o003o1Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo02cooooo00?o003oooooooooool05?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool0
8?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00_ooooo00?o003oooooooooool0
0_ooool01?l00?ooooooooooooooool2o`00o`Cooooo1ol00?l01ooooooo003oo`00oooooooo003o
ooooool00?l03Oooool00ol00?ooooooo`00o`0Yooooo`03o`00oooooooooooo00kooooo00<0o`00
ooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0Tooooo`;o003o00?oooooo`00
ooooool05Oooool00ol00?ooooooooooo`09ooooo`;o003o2Oooool4o`00o`?ooooo00?o003ooooo
ooooool01Oooool2o`00oa3ooooo00?o003oooooooooool07?ooool00ol00?ooooooooooo`0Goooo
o`03o`00oooooooo000000_ooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003o
ooooooooo`0_ooooo`03o`00oooooooooooo00oooooo00Co003ooooooooooooo003o1Oooool3o`00
o`04ooooool00?ooooooo`00o`;ooooo00Co003oooooool00?oooooo0_l00?l3ooooo`?o003o1?oo
ool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0<_oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000
ooooooooool05_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`06ooooo`;o003o1?ooool00ol00?ooooooo`00o`04
ooooo`03o`00oooooooooooo00cooooo00Go003ooooooooooooo003oooooo`02o`00o`Kooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a
0?ooOa;ooooo00?o0000ooooooooool02Oooool2o`00oaGooooo00Co003ooooooooooooo003o3ooo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool00_oo
ool00ol00?ooooooooooo`02o`00o`03ooooool00?oo003o00;o003o2oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0>?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool0:Oooool0
1Ol00?oooooooooooooooooo003o00?ooooo00?o003oooooooooool04Oooool3o`00o`Oooooo00Co
003oooooool00?oo003o0oooool01?l00?ooooooo`00ool00?l8ooooo`?o003o9?ooool00ol00?oo
ooooooooo`0Dooooo`03o`00oooooooooooo00kooooo00?o0000ooooooooool02Oooool000[ooooo
00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool0
2Oooool2o`00o`?ooooo0ol00?l2ooooo`?o003o1Oooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00;ooooo00?o003oooooooooool02Oooool2o`00o`?ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo00_ooooo00?o003oo`000?ooool0
2_ooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`000?oooooooooo01Oooooo00?o
003oooooooooool0<?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00Go
003ooooooooooooo003oooooo`02o`00oaSooooo00?o003oooooooooool01_ooool00ol00?oooooo
ooooo`06ooooo`030?l00?oooooooooo00gooooo00?o003oooooooooool04_ooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_oo
ool00ol0003oooooooooo`09ooooo`;o003o6oooool00ol00?ooooooooooo`0?ooooo`05o`00oooo
ooooooooooooool00?l02oooool00ol00?ooooooooooo`03o`00o`Kooooo00?o003oooooooooool0
0_ooool2o`00o`Kooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`05ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool08?ooool01?l00?ooooooo`00
ool00?l7ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool05?ooool00ol00?oooooo
ooooo`03ooooo`07o`00ooooooooooooooooool00?ooooooo`00o`02ooooo`;o003o1Oooool00ol0
0?ooooooooooo`05ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0=Oooool00ol0
003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000oooooooo
ool0<_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00Oo003oooooool0
0?oo003oooooool00?oooooo00;o003o1Oooool2o`00o`?ooooo1Ol00?l3ooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0booooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003oooooooooo`09oooo
o`03o`00oooooooooooo03Gooooo00?o003oooooooooool00oooool01Ol00?oooooooooooooooooo
003o00;ooooo00?o003oooooool00?l01?ooool00ol00?ooooooo`00o`0Qooooo`03o`00oooooooo
oooo01cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooo
oooo00Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBoooo
o`03o`000?oooooooooo02[ooooo00Oo003oooooooooooooooooo`00oooooooo003o00Gooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`05ooooo`04o`00ooooooooooooo`00o`;ooooo
00?o003oooooool00?l00oooool00ol00?ooooooo`00o`02ooooo`03o`00oooooooooooo00Gooooo
00Co003ooooooooooooo003o3Oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo033o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0/@3ooglBooooo`03o`00
0?oooooooooo017ooooo0_l00?l:ooooo`03o`00oooooooooooo01Oooooo00?o003oooooooooool0
4?ooool01Ol00?ooooooooooool00?oooooo00;o003o1Oooool01?l00?ooooooooooool00?l3oooo
o`03o`00oooooooo003o00_ooooo00?o003oooooooooool08Oooool00ol00?ooooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0;40oomo4_ooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool05Oooool00ol00?oo
ooooooooo`02o`00o`;ooooo00Ko003oooooooooooooooooo`00ooooool2o`00o`Gooooo00Go003o
ooooooooooooooooo`00o`04ooooo`04o`00ooooooooooooo`00o`Gooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
1?ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003o
ogl0oomo0;40oomo4_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo02Wooooo00?o
003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`06o`00ooooooooooooo`00oooooooo
003o1oooool3o`00o`;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo02Kooooo00?o003oooooooooool06oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool08oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool00?l00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00?ooooo00Ko003ooooooooooooo003oooooool00?l8oooo
o`05o`00ooooooooooooo`00ooooool00_l00?l7ooooo`;o003oDOooool00ol0003oooooooooo`09
ooooo`002_ooool00ol00000oomo0?ooO`2a0?ooOa;ooooo00?o0000ooooooooool04Oooool00ol0
0?ooooooooooo`08ooooo`03o`00oooooooooooo00Sooooo00Co003ooooooooooooo003o4Oooool0
0ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`;ooooo00Co003ooooooooooooo003o
1Oooool01?l00?ooooooooooooooool2o`00o`04ooooool00?ooooooo`00o`Cooooo00Co003ooooo
oooooooo003o2_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00Wooooo000:oooo
okCo00004_oooolQo`000003o`00ool0003o000002co000000?o003oo`000?l000001_l00002o`00
oaCo000000?o003oo`000?l000001?l000000ol00?oo0000o`000009o`000003o`00ool0003o0000
033o00002oooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-111.324, -105.216, 1.11046, 1.11046}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-111.324, -105.216, 1.11046, 1.11046}, {{208.5, 388.938}, {184.875, 4.5}} -> \
{-331.568, -105.169, 1.10997, 1.10997}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute expected error", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(errors = ExpectedError2D[p1, p2, x, y]\)], "Input"],

Cell[BoxData[
    \(7.862184492618784`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify training and test image", "Subsection"],

Cell[BoxData[{
    \(\(c1 = 
        ClassifyImage2D[Partition[brick3, size], p1, 
          p2];\)\), "\[IndentingNewLine]", 
    \(\(c2 = ClassifyImage2D[Partition[wood3, size], p1, p2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification results", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{brickIm, c1}, {woodIm, c2}}], \ 
        ImageSize \[Rule] 400];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
78668C7A9191A8888F6B458C5E8B6D57667A7A4D647256946997954C904D717172D7845F
4675ACCAA4B2A5A9A49B7D656B7CA6BF719B95A5CD8FB1BFAAC34C89638B837574A0A97A
7654ABC2ACA47851E1A07C756360A9B799518A938E8992C4774B423E7583575B777E7082
5C675F7B938D8E9A9BBC7B9CA66D465C5F8D8275
71547B77868EAF7A887653885B7964536C868C505A65518069948D488D58818678D08D68
4B77AAC0A6AEA0A5A0987B687176A2C277959FA9BF78B9B3A2C35582618F87726EB0B17A
8A6998BFB6A5755BDC9C6A76746EB8B9A3618A9D939094D47F4943386A745C585E61658F
6B695B829594A29C9CB191A4AF7A50665F74817A
7F6081708579875D74663D745D8860564D63985D565D487E739B8E4B955C77767ED18369
5371A1B39CA59AAD98998E7D8585B1CA71AB95A2BB7CBDAEA5CF5C805F7E7B686CA4A276
7E7187C6BEAC735FD1945D837977A2B9AD6A7FA18B8494D783444431648D65655D677076
53675E788E7F9696A5BDA2BEA96B4F7A6F6E7E72
6B567D707E75A469856143815E75515958727B5D49573D7A72998C4A8A5C787677C08B6B
4A7CA7ACABB89E9D91997D6E6A6F98BD71A08F9DB976B9A19ABF5D8267867D5F5CA2BB71
868581C3B5AE6976BC8C5E78766D95C8A963819368707FBD783B3E3058806D7079856B7E
5A5F4C6F7F77A8657E756A7F996E575A73827A7F
7767878194889D5F88764F8B62966475647C8367505F427E6B908B4B825F777177D09A68
477AB4BFBFB79C9D9798867C767098AC6C9995A8B47EC4ACA3C55A80637F7C6C6F9FBD93
88848DBCB2A76671BB8A5B85897AA0C6A1706C9461827DAE713634314E70736C89817997
6A755B786E79A27AA4A280A7B47B5C526B7B8976
80608A748F81B26B8D7955886591515D6484926E5D59547D6A9C9A4A8356716781CC7D5D
417CAEBCBCBA9A959AA2847C6F789AB8799E74BEB983B9ACA8C05682607D8C545D95C27E
807484C3BBC8797EC583578B867AA7C9B76F8A9A71968DB97D423C3C53797C6E8B8B8295
6969787B9795B287AC90889DAF7C505F64798368
866E8B6C7F7BAC5E706A43806A803E5E54778F6A6159477965949E4A885B8D7C7FD2845A
376494A69BAC9FA09DA6837571719AA66AA277B1C57FB7AB9FB54E755D74786F659DB27B
7F8599BDA9B37577BA92638C8175A2C79F53B6A96D8F92CA7F45373D4A737A7088907C97
69776B737F7A96729A89879FB18651676981667C
7F5C80677E8DC169936641855D8E4A5F686A837E5E5845676F9E99498360867580D48C64
4186C1CAAFB69A989F93777464749AB05E8E91A9C97FAEB09BB24B76607C7F5D6B92BF7C
838397C1B1C0777EB887608E6A759CC7A86380A063828BC27C443E42426E7C6F6C856F8D
656763797483BB86BF818BA5AE7E516970868E7D
8976986D827FB064736C4A8D6295505D788C936D544E5265739E9F50825F7C6F7CC67E5B
3E77B6C6B5B7A4989B8474747591AEC6779A99A8CA82B7BEA1B14E84678283636392BF86
7E7680AEC1B17A7BA9885D84717091BCB0738095667A8AC4814A3A3F3F697276868A708C
675C5F839891C57CBB7380928F6751526D959479
7B5E8053878CBA7782724F935F9C4D5A7B7E92755C4C47636F949C457F4D718183D6875F
426B97A8A3A28B9191808167698398A5789898AABF7AABB49EBF37716383856963A8C49A
79807FB0B6B590849B8B7A89787196CAAD647B975F5A77C57E4638393D5A4F5B5E7C6091
646965768069966DB773929D92774B4C657A8783
7D648F5F866F7A757265437F609A4C568E858E644B464A5F78999D4989596D736DBB7B54
3D6B9CACA3B09B9D978E8A6B707B99C2809B90A9C083A69C98BA39654E67655E6594AA8D
5C6F7EA7C2B4847D9A9E8D7B7B638DB6A4588F84755B70B5934C3A384F636C6A76726072
5D4E5C7C8886AB92CF6D878C7C67505D5F657070
82718F5276738E68716745785B8E49529682997060575D64718C9B3F854F67747ACB8B6B
467DB8BBADAA8B9796868562717A9BCB779987A6BB9BABB39EC341807189835D5BB7B589
5D6188ACD3AF87778C9BA370605A73B19D639BA0795876C3A9554939577B70796F746E70
7963776E7F9A9B90AB487895968166596A698B84
8472955F7D778A5266624774679048488B7A926855484B4F7D968C437B5162687DC6915D
3E72B8B6A4B39B90988D7B5466758BA6638789B4C1A0AAC0AEB03F725C64736D4E9BB8A8
745F8CB7C8B18C7291B19B6A6F6398C7A07894968D6773C6B05B463C4D776C7A5A685F67
8A6368738B98878CAC508EA0977E7C6C646B7B72
766A835884819261715B436B697D484890718A716349615E829A954C7F546B6387BB8758
3467A6A6A3ADA1969A8B6B536D7994BB648F88B3C7A69BB8B9C44F917B7479736C8BAF9F
7E588DAEDABC70659BBE996B7173A8C2AB79A8A69A6978B2B6523E4A4681736F67736562
796A5563727E8D9EA94A888D8477625A7567877A
647E8446887E9158705A4F73707A464D877881714F47474B7A8F915682506E5E8BCB9E4D
2D64A2A7AEB39592A1957970717B95AB559587BACAAD93B1B6BA468A8488828D6D8ECC8C
6F4D7F84DAAD735D9FC581696170A1A8A185A19E855B6AA3B2603E4C415F747F70695D77
5F67636E899088939D5299A4A18C7A5F5E686765
6A747746937D815D726D5C9072794541907978855949455C73949C557E48606193CBA55C
3B739DB5AEAE939BA6A47E5C7C7D97AD609480B7C8B296B2B5B749807B7B7E8B6D7AC58A
7A589596BAA07A658FC77A6E6D6F9DADA9858E8D7F7690A5AE5F3E5444606C76727A6677
726E5C75859E8C819B5486B29D8D8B6A757A6E68
7A8A894B7F7A7C547B716A877D7758465A6570794246525A658F92558F5D786089CDA765
4B7EAEB1BBB18F7F8C7F644F78849EB76EB07BB8D0B398AFD0C15E86877E78946D74D886
715494AECDB8898E97CA6471776795B5A28286A383618BA3A1654D454164736F6F787880
77605B626A9A867C904971909880745A7C78626A
7C8E87458185764C6C687276837E6D4D7371866A48413D616D927C427753735D88CBA16E
5185A0BAB4A68D989A7F70586F7C9AA561A080B6C4BD9BB1D5C15F8B8E797F997862D396
7A53819CBAB4807E95D86B847C74939ABE9488897B7391A697714F3C4F69616B6D7B7876
6F7A646A5C938492B25B8CA69F756C5A74687169
7FA386467F8B7456816B78797E7A644B88828E6F4B4E566D6E978D3F894B73538DCBA356
416AA6B0AEA1848593826A546C7291AC5C9885BFC9D0A1A5C3BB6584917874967D56E38B
77556C93C5AF948CA0D6666D736E809DC0908BA982607FA19B744A334B635B7D6686787D
6B71677778AD949DAE5E7EA0A2897057645C7266
7AA97D5077816E54735A6B6C776E57467B8594715B4B546B769682557D426E4986BE8060
3C74B6B7A7AE9983998D755F6F7AA0B564A087BBC7CC9697B9B97C7994757B95714FD08D
7A6A7F9BBCB58B8A89D95F757F7275A7BF8D759C755B699BA2724533395E64785B786C7F
64745E6D729B90A1AE5E97A8AC84746B626B7972
74A17643788C73618668787378694D457F8196736A5550606C9F956E90577E5187CD915B
3A67A6A897AB9B759589735969778BB9649E90BEC8C5888BBBB07771906F70926C5FD075
7E6F728CB5C4878A79D36C9C7B78759CC8956F877C5A63A6A765433836617D696A6B787F
6469597476939193A5559CAEAF8A705870686A5C
6B936C406C6C685471697A6B716A47437180976756564C5F6C9A8661935F825F7FC39B5D
4069959DB1C0A29BA088775A6C7A92C468A992B8C7CC898AB6AE7A798E767A975F60D27D
8872719EB0C5999276CA5897777374A6CA95699C775F78B1B5724A434167755B6368778E
786A52787398AE8FAC68829B99735E67696C806F
71A7774A7C856D58805C76737E63545E7376896D5C44475E74A08B558C567E668CC78A59
2B5EB8B7B2BA9B97A588795A747E9DC964AA96BFCDD48F8FC4B581938A7A7D9D666BCF82
8887719A9FB8927C69D969886A808FBBD6996AA87A6F7EA2B56D3E393F5D705A5B626E85
87594D6D7999A38EAF84829AAC7C654D59597356
6298643B6E78695D84597B6C7B604653758C8F7066584E6174998A59995481707ABF854A
5259A9B3BEB98A9E998B7558677C8FAF549484AEC7D99393C5AF868973726D92606ED790
8F946EB6A3C9AC8170DF6F927B787CA7D09E67A589767A97BC74414040608A5E4E5D6766
754F547E7995B695B08085A0AC85625A626B8471
62A9754C7A85765C887C97787064435F697F857358463C5D728F92809E5A7F8282D18763
7464B4B8C0B8A6889F8B7559708793C45E9785ABBBC98484BBBD82867C7B7D9B5768CBA8
899067B8ACC69A6C52D97F90879395BFDCA175B48D8A739ACA6C45433C5684535D686D5B
7F4455706E8AAA80B78D8898AE7D545C6A577A62
679D7244707B654D6B68796C735B3C5C7C877E6D5058567C6F988B7A944E706676B16C5D
5960A09B9B9696879189755A818097C761A085B7BFD38C91BEB784786F7B798C5C6EC39F
768F5EB5AABC996050D67387838690ACD3A26DB39C987894CF68403A384C7D546859695D
6E4F616A79A9AC9BC09791B1AF7E5F606954765A
6AA96C426D7565597F69808C8A5A395E63818D795E584979609FA483AA5D776E6EBE8D5B
5973BAC4B6AEB29CA48B745670839EC35EAC8DBAC0D69389B1B38D767077768C6373C099
6F8760BEACAEAF714BD67393757B719DCE8862BDA496798CC76C413737536F65686F6875
7951685C889BAB94B79F5B7C987B6B5E625B9160
6EA47146768373667F759284805B426D5B727A6D4C434D5E5082897D95566F7980D59064
5C70A8B5BBAFAA9B938777637A7581AF57A69AB8C2CA9185B6B3986F736E848A7475C5A3
627152BBAEC6B37A47E08190828C8BB4DD936BB8A993717DC4764839394062785F83777C
6A5E6A6380AAAB85B7BC748FA3845B6B6A678A77
5F967B4C7376735E7F768B65664E387169878B745A55407255928E7E9C6476757BCC8B60
516EA9B2B2A2A690917E6E596C7993BD5D8C8FB5BDC58C79ABA197786D7793847788B89F
577250C3BAB6A96A40D07A9E81776897C79073BEB7826E8ACA8F4F3E2E4471956880767D
765978607FAAA691BEB67096A69168765F748D79
678C7B467581745777697F787B434560537E816853504477609A8E879D7678767DCD9762
6272A3B9B8B3B09AA58C7E617E8390BC619587B6BCC28F92AFB89071727892817D91BCA6
627A59C2B3A9AC7C4BDB768F758482ADC67F679EB2746986CC955A4716378A8E5E7D7E8C
806264508EB3A29FA09F6486888A5B7B74819976
5D8B7A517785805E807C7971764F4D5955799061535A447B639EA7849570737673C47F5A
737395B8C1B69D798E807556727C9CB76D9481B2BDC3907DAFAF8E757081927E7B8EB794
59775AC6C29AAD8148DE88897B8389AED5977DACB8677C71B3995C4133246F69536C7385
7956684260949B8881B8738C9B895170697B9D84
65A3744A7D9E875E7C7D94827C5C4765677B704B5D4E426F5896A78C9E7673796ABD7956
605A7AA0A7A6957A8C7D7257787F9ABA73988BA2BAC59578B8BA9D7E647793848592BAA0
5C745EBEC7B7AB8444D7958C847B7EABD59084A1BE67745BC0994C433534686152587F73
725A67516A89969594AD69A098985759485D8A78
5E936B4876896F56817D94817B6258686889A5525055497A52979D94A373757C72CC845E
71697FA9ACB18A8192838153739699BF8E9E95A2C4C29C74A9AEAD797194A67E8886BDAB
636A78A2B0A4967642C986907E706E9DC58487ACAE6E825DA19C51434A51636C64475C56
73506C4C5F7BA18599AB648E7F9C59725D7D8E6F
649E6A446C9E8F759A8BA28E79535B67688F9D5F5D5A467D55A09587AC7776816FD39C64
796B9DC5C0C78F8C8E77785B86919FB29CA58E99D5B4A98EAEA38F7D7B94AA869891BFBB
79597CABC4AB9A6F3ECA858981706EA5C787819B8B744C569A894B33344B63616A4A685D
6C57664E59959C928B9A63A690A55B66677E8574
659172466C7E88859B808F826D5B4F694F758C595951436353968B83A3715F736DCA836A
865D88BDB7C1929B908181558081AB9A98938E81DAB5BA8FC2C29E7F737991819A8EB7B6
725694AABDBFA07943D68D8D7D6E6C9EB88C8B9E87936A5D9297543E3B5B5A59664C675C
84455D604578A08F859C6FA985AA555F74878D8D
69AE7C558AA593779C7E917F80513F5C5E7378545D4F417F629F8D90A36B65605DC58D66
7B5A73ADB5B1848E8A7E8B708F88B0A396909979DFA9AC85C1BE977773849681AE87AFBD
765891ACB9A37A6B3FCF978A89787EB8CD9596A485A4628DA29E4E37354F564A6B596253
8943505E4F768C998A887CB79992625C798A8473
549365447AA0A084958D7D7E6F57465C5E8084486559478276A28D95AD7A6F6A5DBC8575
7B618EB9C5BB899D908390787A77A799996C915ED8A5A696BBBD816C617B8575A06D99A0
72518CADBBA68F6B43D2967F806F72AEC39F9AB28FB574929E8C463533434C466E6A544F
83484A74567A928A8A8B88AA9D9E5E557C6A696B
66A079517FA39F806C7E66736D5F3A555E6D6A466B5944685A9393A0A37C6F6C5AB3897C
775A7BAEC6B5898D908291857B80B29699839B6CC6A59FA4ADC19179768780738661A1A9
6B5080ADB79A956A4FDD7E7B6D656DB5B89A80A792AA5C8F9E894D3929414A3E7D6C5B6C
75674F78797B99998E84919A9A9F585D6453746F
67917266819B9C897B956D7D77664D5A837A622F52464987548994A3A47B6E7065C08782
6F5B84B8D6AE6D80897894806D65A273AB99A75FD49E94A19AB692777E8D8E828C739EA7
766D779DA696936151DA9073796678C0B5A587A380AB63838F9060342B3F413459665A67
6A60516270789D95887B8BA5A689706A7B5C7365
749A7C5D7A909EA16B7F667673604E648F97833970725F7D558F8D9BA27A6B725AC28881
7F5D93BBDAAB534D806D8476666EB183AD96A159DFA29BB897C98D7C81938B9FA280A7BB
79817F9EA9AF8B5850D288636E5671CBBEA9839B8DB5637E9FA476433E5352427B4C4F6B
66564544507FA19789918E7F957E6E7286637177
658D764A83A09D80787A5674735B333B687F74335A6352765A9194ABB491746C4DBA8B80
845A8FB4D19E7A5C7D7185935F6CB18BA695AB5CCB9492A689BC8773667973889777A5A9
72817C90A0B9967162E1936487677FD5C0B57D9E81B7727D9DA7773B3A464E407A5D5057
505B635B506BA2899DA59298BC897D6C77517F71
678574468EA19B8F967D66857F61454F6B916B315F6A658A619799A6B08B6B6C57C3887C
8C4F90BCD69F7261847A878A5B6AA283A1939967DFA39CB39BCE8E847B8679A3875EA3B4
7D7E7789A0AC806E62DC986F7B6A77C5BBB9819F7FA97F83A2B17E4440606A5A8A746364
5A625E4741809BA28FA37E84B1809669775C7A7B
688D7E4D9499968A948077858262535F6E937735596E65755C8D95A6B19674705DCA8986
8F4999C3D3A16D668D85868855689B8C8F84A06ED9B297BE96BE777471816DA07F5BA4AD
7987757FA5AD7C7355E08C6C746986C3BAB76FA9809A857B98B976403C576E5F6E6D685E
576B62594663919E96B6778FAC80825D74728875
7A8D84529C9C8E8C8F706D686A5D4E5C6A906D3254595476569695A5A69370755CC69C7D
764694B5D49374689F927C9C666FB1ADB0A2AF76D8AAA0C0ABC77976736F4E7C7265A6B6
90867486A7BD6F8058DE9977826E8FCDC3B36DA1899A787D87BC67382E455C605B6A5A59
585F6E72567998A58DBF6F87AA7E6F544C5A5C5B
71887C528E9B74828E6C70795B594A557698853C6659537B589E9DACAB976E725BCFA98B
7B60788DC39A775E8D95779F5E66CBBAAB9CB17DE0B1AAACABBF7C856E7B4F987872B7C3
A4967E8BA9BA607D5CDD996F756573B9B3AF7E838096838C87C159372B475B59514E5455
4A766980646990AE9BD65F8CA5946C47516F5F54
7D9B8D4F929E808A9F797B7E5C5D395983926A31453B566D4D998FB2A38F595B56C99685
736F87AAD3908F709CA185A2635DB6A7988B9B7BD0B1949694AF8478757C519C7584B6C1
8D9A6B7F98D6648263E193697B6B6BB0BDA95E8C919A7C8B85BF4D3A2A485D6E4E5A5052
5A726C92546991A172C1569FA18E7E5A60857468
6D877F4787997B88937165735561665E667954214455556B608E88AAA69B6A625ABA977D
85587EA9D3839075A4A28A8D6052A8A69B90A189D7CB989998B28C886574527B6A8FA4CE
8380638294CF537B66DC8F6B715C6CB5BBB4689A9E98818E8FCA54412A4C75645B69665A
4C7B5877485277868DCB609B999D5E5764846A5B
7F91804B8A997D7B896168775A605B6770746132545B577C448C88ABA89B68655FC09A8A
6D438CA9CC8A966FA6A28B8B6D6AA7AB9A92A897C9CA8E9396AC958C6E745699788FA3C4
7580597B9DDC587F70E299717A5B67A5A9AE658E92958E9899CC57432C3B655757716659
596960882E5D858D6EA6698EA0A15B5D6D7C5462
7394864C91A38683947264705E5C6163849A7F3C6E705C894BA094ABA89E5E6462BB9787
67437CABCA90966CA1B08484656BAFBCA3A4AA96C7D9978FA6A8A78F73765E9B7C978FB1
6F875E6F91D24E675BB67D65746076C7CFBC71868891827C85C15440273A5A5357736369
5C5F51833A3A627E81B67D8398AB4F5C6A6B5363
6388774F929B84898D64686E565162607A8D713A6761537F5C8295B4A99D65696EC6B598
735B7D90C2A48E6B969F7B6D6864A9BEA5A2AF94C6D08E8FAEA1A5826B6E5899729289C9
6A7C5571BCBA58766FE2956A6B5F6EB4CCAE64999C8C857B74A94A3C2635494C48716861
5F6B6675416BAA9CA8C59D98AAC07E7B7B6F677E
5E897A518FA28D898D7069747B4D4E56707069416263648A9DA392B49F95746067C1AB89
5D607699B3928B709491715372749FAF9395B097BFC1838AA998AF7D867B609C719686CB
867E557998DD6C6E69E3937273637BC6CDAF747B928C928186BD5E3B332D4E5F59738C81
70695C68374CA18884B99E658A926A80A76A6378
5C927A487B8F7789805E4968665A5B6E91967D42616C5F96A7B399B9AC935E526CBDB191
6963778CAB998E6F9F867C54876F99A293A1BA869EBF9894B1B5C0808D81699E89AD81D4
87825878A3E1736464DF91776D6871BCCBAE768A917A736C82A16439323050594E6A8478
7A6E7060523F919F8CB0A061889A825D5D37546C
609973447C81757D7E7955706049546689887A41675B628A97AC99BAA598745474C0C196
686D8598CEAD9B81B9897D6192809AB1B0B5CB8EA6B69483ABACC2768884779483986EDC
7E6D63899FDA655168E098767A7D7ACCD7BB909CA58F9A829EC97B3A342F4C5957767579
67656E4B5B568B9788BBA5658798886A634C6B86
5D7D6F45869C8588907A557C7353466A8767583A5E6D61828AA182B2A19B73497ACDC48A
616C8299C3AC9A71B686876E9579A0B2C4B7C48EA9CCA593B4AAC5607D8587A68F906CD9
8464617AA1D45D5358C7926D787C76C3CBA27CA8A8919788A4C574393C3151545A756573
6758504B5E4C5F987995867479849870705D718A
6D907C4B8D8E85899B6A486B7A6244708A827341536B7186A49E87B09C926D4B77C6B982
62657F9EC5AD9E6CAC7B81729E728AA5BCA1A7819CBEB1ACB8BCCA5787968A8C828672DD
7B637387ACDC614864D7865D746F79BDC7A16C89A07E8D8798C2793B3D364A6165806C77
70755A616A5B669C7A987363718F926668706C8A
708D7D4991B29D9597684C72675D4A6C7A8571475D6F5E7490A991B7A18C6D577BCEBF85
61799CB0D8C0AB75B072837A9B6C7DA0B58B8F8686ABA3A4A8B0B7568E8B878479826BDB
7B5D7994ABDC80576DE69A68816E83C5D0BA7A8EA88D8E8CA3C38043473F55687E887983
718260647662537D91AA846F908091716D728188
72917F52849F8B9191774E7D7B52405D6F6D5F5163695D687F8E85A4936F5C4863B3A46D
566F94ADD7BEA574B1778A818E5F8DAAB783A19697BFA7B1A5BBB55F8E849B819E7B6DDB
8C5B7B929CDF8C566CE4A26C866A80C0C2A16F85A28C8E97AAC3855246464F618C857A77
6C8C66657C676E828A97837C96967F676C928CA6
78A67E5E81A6939682644A6D6F5D435D817173585D6962788DA293ADA482623E60BEBA72
5B72829CC2AC8E629B647B7A7A5A82A4BA8C9999A1B1AABE92BFB267A58AA27B9E886DDB
9B5F8EA68ED47F4F5ADB99657D6A7BBEC8AB6C8AA5898C98A4C38644414D4A527E8E706C
6A8A676B61519B9F9B91716C9B936D56587E83A1
6D907662819B8F8D7B6B557A7057536C93807250516A677984B19FA39178674B65ABA466
52638A93C9CA966CAD6E908571657EA2C183998B9DBAA7CE88ADB463996B7576946A65D6
AD5E928C8BDE955957E3AA66886E86C4CEAC6A87A184889194AB77453E4B44486E7B5A52
617E767364576C7B9C968C82A5A67E706F80807C
6A8573508A9D8C90756C4D827857505E71706D4257796A7788B8A6A39E745F576BB5B872
5D5C7687BDB88C539368818660627A9FB47B90889DA995AF73A197547463837989695FD1
9E538E7B87CC955150E1BC738C6578B3C1B372949E878191B1C8764142464957737B685E
65786B777463A392AAA08184A0A6615E72847E91
748184487A7C6F757F62426C7256437C876B62425275595C81AE998C8671605571B0B779
68758A8BD5D3973E997F8D8F5B6A7DA5A984A390A0AFA1C57AB2AE6C91758495A57A78D2
C159898BA1D998444FD5A86F8463729DB19E6381957B788AB7C57E4646424D5F828B7A61
627C7160616B9795B1A48291AAB2806C65675B76
7C85955EA3AA88919A8256888B553D6394755B5A505E616485C0A29DA778665C639E9462
6373858DCCC99140A88F9A8F586E79ABAE99ABA8A2B6A39C72BBBC758D7579899A7875CB
B65B778D8FD4AD3A54DE9277896982BCC5AA61868C897A84BCC987494E48505B8072795C
63876F70664D70829EA68687AAB6868C7D655E63
6F6F7F4CA9B0968E977253686C593E71988A6F594C52656176C3A089AF7D6D7171A1A887
6F7B8487C6C08947A590A28B54727EA9B39AA99AA1C0978666A2A759746E7E83897578CC
B77B8A90A5D1BF645DE1B37B866B88CAC2B56E909D9B8E91BD9DA4545252555D85876E63
5B88717D64406C777E8A8480909D87A167696A6F
7077954EA1A1938FA3676781644A32576E755E4E4F51775986C8A688AB7974718EABB585
7E8491AECEC39448AC969F944A7D90B2BDA5B98994C1AF9F79BFC07B9A718298AD6F7CBC
B69B74829BC4BA5A60DF9E8089647DC4BCBA76989CA58992B7949B5D52494B566674616B
4F7F755F744D6D7BAE98807DA2967BA568586758
7C8698519AA997929B6C5F807B5B44667F8273706E5A906886BB9D84B578787D8EB4C990
8D8089A1CCBC934499898F89497C8BB8CEA4BD9390CAAB9F72A8BD7C916D7D7D9C828AC1
AD9B6D7FA6BA9B415BC39882766179BEB6BC729B90A86A98A4A08A6959514B5174847B78
568A87697850868A8B959474757A8395525B665A
6E7385448A908087906C57727057497281856F7B6D55835A84B79888AE7B7B817BB2BC83
837D9099D4BB934093889282467B82A3B9A9B09589C9B5A176BFC47F866F78869B7889BB
A38A6979A4B8B9516AE28586756671B8ABB2768C74AB5F97AC9C91564E4E4955667A706A
568B91686652728A999AA77C757E928045646965
7680864A8E988A969879557C674A416C9188716F504F5D5468A28F82A4737F7B67ACA76E
7F72809EDAC5925DA9989D87487A8AABC3B7AD9180C4B3A286C2C489897C8088988377AE
B491777CBBB8B05263DD928A7D797EBBB4A56E7D7491598C936797574B41445B707C6E5A
577F85595D4F6D8060709C647D768D7741647273
7183864F899588949673538B74514166777B6D7249505F607DB8A783BA80878F70AAB076
9361719AD3B69A62A19A96874B7C91ADACAFA3888AC8AE9A8BC7CC8F88766F91A59289C2
B0918073B8B4AE3B65DC9995906F7CC0BFA577888382779BA66E924E523D46607987745C
69878E595C4A56758685A96F767D946341635564
627C7D4A859A9199947A517C6E604C708D8F7A7949576B6885B39D7FBF8B8F82709FA47E
86636CA2D5A9A1679AA780834E8195A5A6BCA2926CBAA78E83BFBF8178746A83928E88BD
A9827B66BAAEA9266DDE84A2826970ACA69A857F8C796C83A071995E6C404F6186947561
628CA1545D56687E7D83AF757A838975566E655E
5D817F53728C8E8E7E6A527D5F66577B889776805C5F76678AB1A18ABB828181709CB589
9C4E6198C8A9987097B182705272978FA4BAAA967DBC928F8DB7C78C747D6E929B9C86BE
AC82745FB7A3A82E6DD47B97816D73BEBFA7B9758E8A8180838B986C5E3D505A688B8667
5D877E5855475C6F798BAE7C7F797979485F5F6D
658C84527CA09D938879617C6A665A6B73834F805A4D6F638AAD9A86B083907F658FAC96
9F566DAFCDB7B57798C07F775084A39BB3C4B0AC82C99E8D92AABC886073697D91998FC2
A67D7A58BAA7B03E6DDC85A1777171BCB9A7B28B9E84677E7496946A4935485A56797E6A
5D8B8D6568706F7C9493B387838386694D61576B
708D7C5170929299927D5F786565505443826B7842386A5D73A69D7BAD8382816D94B18B
96515490A696956E7EA27879538BB695AFC5A49C87D8AD8F90B9D0A37B7F768C7A8F83A8
9673654DAAB6AE436FDA7997756C6BB3BFA493928A956F966FA6977A593B514F616D6C6F
648A84716D6284818C87B6808386946B42576054
708893597F9696978D7D5B6E706F768369806C69453672738CA78C70B4948888638FB391
985F63ACB5B3A58486B1807A50849F8DBEC5A29781D8AD989BBACFAA7677669381998EAE
A6906E56C6BAAF4C6BDE76AB896C68A9C6AB7C908D92729368A9A3734A374C4B7965686B
66827A696C72838DA3A8BA8C8578937E565A5B59
7793985A889EA19C8E75596B686269756C826673584A66788EAA897DA37B67775A87B897
946462BFB5C4A7937FA7857E558DA99AC3C9A49980E0AFA1A0BFD29A758565A5839B8DB0
A98E674EB7ABA5535AD06EA4806E61B2CDB2838A8C86799C629FA2734838474880527F78
68886E6E637598968B96C0938C8FA3946B6A6565
7287804D889A978F92775E6B706B63795C807D512D51647786B28C86AF957C6F4A6FA28E
825D50ADAEBA9BA2789B84745B80AC97BDC1A99B7DDDAB989EB7D09F6D6B569782998BB1
AD9C654BBEB7C1535CD46AA27C656399AF9E8782809579A460A99B6C4035484E765B7175
79967579626980717B799A747F79968D71777A79
6B917D4E839A9A9A917760746E52706D5D807545564F547B89AD8F72ACA0866D5795BA92
836746A7A0BDA5A37A968A79728BA1A5B4B8A9927CD4ABA3A6C8D59C78805C9287A188B7
A4935F50BDB7CF556FDD75B07C616FABC29D78859A9875A05DAA9F623C385953575B666D
5C8E6D51737D99958B88B6838586887E565E5D73
77A07D4F919CA0958D7F5F6B763D6B7B69A185777C5D518387B28F6CAEA289725486B59F
757549C1B9C6ACA47D9897767589A5ACBCCEB0937CD7B09F9DB8D6917280619987987CB2
9A8D5B55C5A7A63E60D774B97F7876B3D7A57391A4977A995CAF996E3A4467745B6A747A
749575787A709F85A69EB0747586787374784B71
66997B4B939C9EA18C7B5B7679847977629D7B6770574E7C86B38F7AA9A58B736CA5CCA7
7E7B4BBCAEC7A7948580736A7582929C9FBEA28B7EDAB4989EB0DA9477856692859C7FA4
A2A9645FC9B7C64670D776A67C8071AFD0A67CB0AF9F86AD5CB4A1833940636D4B6D6773
829873757D81A1A59E88AE6D70837F8C746D5E82
6DA27B4B95999EA48B79577F7C777066589578566B5B557A7AB28D87A8A58C645899CEA2
7A7946BCA4BEA67F7B7E8078888D8C92B6CCB59978DBB697A0B8D4A2768C679687A18BAF
A791595EABAEBB3A7AD479B577847EADDBA57A92A89984935ABE957E353D5C5B4C53505A
5D77566B626C899E9F88B4888787728F70736A7D
6A967C458A9496A6837459847775636D588C7E4A5C574C7571AB868FA2A083665789C79D
6A6242B49BB9A6867C7E735F807C9489B5BDB1947FD2B8AAA1BACCA1797E619590A091AB
A68A536197A9D13F91E47EAC7A837AADDAA49A8BAE8F979073C4A27F3D4063625F676875
6D7E60656B5C79968B8AB5847E9280857477778F
7E9C804D8E9699B1937E598B7B7F7887619270626E524A7986AE8A88A099735B578EB597
667547A79BC2AC89778586758F739B93B3C1B39B81E0B2A19DBACEA8758E68998CA191AA
AE975C77A6AECF2F8DDD7EB2887F76B4D59E9696B0939E8B7ABFA0744B436062546E7575
717671726C8597A3898AB196869E7988756B6B8A
769781559EA3A2B797775A93797272775C8F845A7769608F90B1989BB8AC846A5FA6D0B1
6E7853A093C4B1806B7888769B658B91A3A4A78E78D5B3A5ABBAD8AD7B86609686A48B9C
9974526F8FA6C0329CD87CA0837A73B9D19A7AB1ADA2A98F81BE8963513D615F4B617D6B
69736E6B737F8AA1969BB28E7E825E656C5A5C7F
7296825798969FAD756F59826B77797376A08253636D5C7178A68991ABA1766B5FABDDBB
687F509F9AC0BC826E81917E9A678B9BB5C2B39E73B8A59BAAA7CA80727C69A68EA78CAA
A38B597BA6B1C43BA7E082977D7262A2BC8B68AF9D8F8E8CA0C88A5B5A4368645971847B
74666C6B7F869EA87993B38F7F8B8B594C64666A
5A83794A979B9D969C7654797C66554753896D425A4C56737E9C8997ABA873715C94D199
637D579598C4B07A6D718B7398739099B5C3B49D77D5C0B2B9A9DA8E7F886A9B86A87EA6
8F825C7E9BAEC73FA3E08D9B7F7F6FB2CB9E625C87A18E8D8FAA8453473C525856687975
6A765D6A6C6B828C567B9B74708983626F727A9C
6C957E528E90978D8C6F4A6C73686A67538C72416547496A79A27E9BA194646C608EC096
5E80589CA7C6A977716D8271916E8794B4A2A39165D2BB92AFB0E0948982609D85A87DAC
A48C5E7F9A9ED246A3E3818E7E8573AFCFA5555D869989969CBB794044365C5A626C7970
696D685C6C77928B627C98837E766F636E6F6C78
67A67954919CA0A28277577A7558726470886D3E6A565478729B7F99ACA36566618BC390
557A537D93C8AF7D6F637F728870878CB5AB98956DDAC59C7A8CA67C77725B9082A67DB2
AD866485ADAECA40A5E48493838674B8D0A75F919092839B8BB86C4D4437575A62677C69
6D755162575B779A6A8B91615E67675260636E80
6DAD7D67879FA7B48E7C60898F5B77667D906F485740476570B48894A6985C64779BD09D
5C80588795CBB582795F7C7484647E8AAA98868F71D6BFB365C797667678639280A386AA
AE8B6287A7AFBD40A2E28F997D7F7BB0D0A664B092A48FA890A86B593A4B8265707B8273
846D707376779ABF7EAEB18C75857E745166727A
7ABE866584A0A6AE8E7F5C839366635B727A41447D5C586767AB8790B4A4626971A8CCA3
6A8D5C81A2CAB27C785F83728564788EB3A38CA375C4B7B58BBCB388827952807D9986A5
AD825E889AB1C142A1D8858E767F74AFD19F69B68C9780A882AF71503C5C846293707579
7E8372766D7E99B16193A9908E967F847D6F7A84
80B6886B8C9EB2AD8C836686927169486F893A567D676D7470AF938F9D9B685A6398C395
5E7F6488B2D2B28A83638E7D916F607EA197788577D1C3B8959DB28C867D5E8B7C9378A4
B1865A87A1AFCA4AA7DB7584808573B1CA946BBE8E9684AC80BA6E4F3C5E83688A667069
7D796B6F5E73829A5B949E79677C697C69637882
6EAA846381A8C0A48C896C839E8272547F9D605A8B7C707D78B5979DB2BB71616EA4D2A4
65817D95B4DDB58F87618E75846C76A6B4A7939782C8B9B69597AD837C785C9692986FA1
AD785D868EB3C84BA7E37396858F83B8D99A69B6978C81A766BB693E2C517B58916E6E68
64716B5157688BAB688F876A5D646D69665D8A8B
6E836E5D8099A6867D7A6A8E9878484D6C8169558E69677671B8909DB1B2675F71A4C8AB
5F826F88BCDCB181815D8C8284655F8CA29B848F7FC6B6BA99A69A847172559998987EA4
AA715B869EAEC449ADDF649478757FAEC38566AC9587848E5BC16E442D5379538A716969
74746D65708C9CA27995917861706A557151728C
82B0847E9AB2A58A7789735C7B7E6E85838758498A67597767A38095AEA05E597599D8B6
5B858B88C0D7B686895D8A817D7663A2A0B097948ECDC0C2A4B0A08A7276509D90A584A0
A66E627B98ADD74898E27CA0888881B2D5A4689E86908D8C53B1815E3E54895C8F756159
6D7E7E54648691A383938C776F896B585C516F6E
86B389929BABA9968D8C7C7B8787635E749F654F8367516F6FA594A2A89B614D719ECA95
5580878BBAD4A6828E638189868A6EC4A4B49E9687C1C5B99BB1A68D858058A0909D849F
A57263829D98D04689DA8F9784767BA7D1A399A8A29DA29D558F8F5538507850856F6C52
647E7469537C779D809F936E749D73615B56686F
7DA9829D94A6AB9385787C7783837B7B7793604D865B59676DAB97A4AA9E655C7FA6D2A3
608D967DA6CA886C866582806F775EC0A2A594917BC9C4BCA8BEA88B7E7E5D968BA98BA3
B77D6C8DB5AFD5469FD4AC99897087A4CC8C86A1A6879C9E62AA8C57395D7E5481666054
66846F5E537C81B880A591768AA076656A667484
87AC838B81A8A2998C82776B8590888184966F557971617C6DAD9CA1B0A3666989AFD69E
5D838784AAD7B3879D5A847B7D8570C2B0B198A088CAC3A399BE9E8E807E679296A189A8
AA6F677EA5B4CE44A4E3AF928C86A2BCD39781ADAC7F9A9F62AA944830608A5F78665951
6A86848B568095AD759A797C8CBC905C4E60717D
7AA585868AAFAE958D8D72637A84737E87A9775289796A867FB8998AAAA0666468A2D099
5E898D89B1D3A7777547737A7864587DA09B9A9E88C6BCB089BE98888B7977909EA18CAE
B070687497B1CB4399E3B595898BA8BED59C83B2AD87A29E5BAB94603872A1878472704E
647370814B7283AD8DAD8F7F94AD955E665B6976
8AA68B829DACAF9E828A73617D8B70857A9B7B567F61607B6DB49485B1A86C68619AD7A7
6984848FB6D5AF7D845F9279956579B1B7B2959E87D0C4AB88B58B7C81757E8BA3A182BC
A4806A679DB7CA4B9EE4B1867080A7B2CE9D7EB0A67F94946FC2914F2C739C7B72757868
6F72778A4E7B9FA49EB98C92A6B498595F5D5F80
839379769AA6B39F8293826C7C89738C709970547A584D7378A68676A19A6E69659FDDB3
718985A0C1D7BB8F866392858B677CBCB4B4979D8FD5C6A88FC8988D9173828CA69980C4
B192656C9EABD34697E0A7776577A6B0D19369A9998C89958CC3853F297989736A685861
7385879459739E9F8AB08A95A6B1936272616070
7891836FA4A3A29A8C9C7B7F7E8D7876599268556F4D577E78AD9079ABA068665F97CFA5
60816497A5CBAA8082618D80875E6E999F9F909575D9D2A284C3A08580698074948780D1
A39D6F68A7A2CB4B91DC8D79697BB5BACF975DAF8F936681A4BF78383184905173776071
5A7C7885567AA59783AD7C8DB5B08A5E756A6167
66807C937197A08B8D9373858180849E699D69637E54618179A38675A4977D6F5FA8D8AD
5E825AB0A7D5BA83826B957D8A68709F9E99889264C8B28D7FC4AE80896E897F95757BD4
9CA27363B2ADBF449ADEB26F6A7DB9C7D0BA61AC88886188B7927D4434757C3C7C7C7A74
628483935970A09985C78A91A7AA7B667C706674
84938CB78DA5B891899269838266848D65A3706F856C697B6CA29376A88E7875559BD49B
707A4CAAA6D4C4807D6F957C974D66959B98908F6BDABD9B7AC09C769275918099746ED4
97906C58B6A7CC469CDFBF806B75B3CDD0B76F9B8B62757CAF768C5B3A857C6267727580
6285758F5E8BAC9077C58597AFA9825C6C564E6C
7D8F80B082A9BA918395728582558BA262A16F73816A5B7A7BBC8B77A59B796F508AC9A3
707B48B9ABDAD38C8B7D917F9D6777AEB49D9E9375E0C4A07DBB946E9A7BA38CA57B6BD2
9E977658B8A9C0399BE2B8716B75ACC7BBAB798E9A618A839694656C3F8C708E726B748C
5D7A72987087A88C79CC92A1B29E8967685E6EA5
7F92819A79A1B7928B967B818D5B85A26FA46F69755A5A7F79B89382AD9D7C7C5992CFAA
797D48BC99D3C985746D8877946D6EA2B2A09D987AD9B99888AF97689D8B9F8CA67864D3
A0837F58C0ABC534A1E3BC6A6874A7BBC6967C899976788068BD66532C6A65888A726E7E
5D735D8373819F836DC5908FB09BA27162697DA3
848D798A86B6B292849B75758D5A869976886A62825B5B737FB0847CA3A3847E5EA0CCA8
7D8444B89DDAD29187648C7E967F76A9B3A2A08F79D4B18F7EA98760968DA68BA4755ECD
9A888658C2ABC628B0E4B06F75729EC3CDA1928FA67A8F807CA46D4932716671907A7973
6F6B6E77717AA27467C49687AD876C7A726B796E
8296839288B5A99586A77F6C89538591759D806B7352507A78B3877EA79E8486658AC7A9
828948B7A5DDD492835F8D6D8C8368A4A59DA18D81D3A4917DAC886694838B7D947661CD
98707D57CAAAC21AB7E2937E7975A3BEBC8BA28EAA7B9A6CA9916C472F7C6259986C675F
926F7168837F998365C19F7DA18D845E66598164
8B896C787CAFAD9880A6867A8C57877D6EA171606F4B4C7075AA8176A79C7B85699ACAA4
7A824AB8A5DBCA8D7B61876E906A629B6685978F7FD9AE8B6DA68E6F99999A90A07B62CC
996D7E51BBA2C33EA5E39085857B98CCC87AA789A67F946C9D96665240715C6092947C6F
9D6967508183938468BA9E748D977D5B59749486
7D8574948FB0B991809E7B80955D8D956D9C6E5F624B4A77669C7A81AAA5867B598EC4AB
787C4DAE8FD3CB8B7F6C8E6D8F676AAE8E979D8B77D4A38D85AE99798E9E918DA4825ED4
9E728C5BBBA1BE559FE28E7F8B8A9BC1BD83A98E9C8A9474A4966E554C7A64697587767B
916F58486779939064A3977C8B9A718258648E79
897B849287A8A8908D987A8B8E649098779D7E6F7249527A7CB1868BA69F8583599CCAAF
7B8355C3A8DED0908B748D7A9F6270BC8DAFA08B83D5A18D80B1A8798A9E8D95A08267DD
9D6C8F60C3A9B62FA5E48881767A99CFC6909E9F9E889477B98F6F43316C5E7C6379607B
837F647582868C9864BDA67F8B8F62834F4E736F
937A7F8E89B5B19894A37C7C8D708088638676696F4752767EAB8482B1A0878B578DC4A2
797F52BE9BD9C993896B7770946666AA83BAA69B7FE4AF9376A29C7181888889A28559D0
8C759C79BDA29C25E0E69085887B91C2BB8DAB9EAD949984A98267383F8D508358845F74
8E7D6F8B7E8B98A073C8BC72929D5F743F3F615E
8B727D877B9BAEA09798808F855B7790536B49495C55627B88B48D80AF9D81935E8DC6A7
7C824DBE91D6C39A817281789B716FA997C5A3A57CD7A69B87ABA57A7B8D8491BC9186A0
A672A080BFB3A92ADCE3857D7B7994CDBC7EA18F958B7C91C08B68483E804D8A64837970
8871776176857E8C72BAC0668FBD6385594E715F
8F788A9D8CADC0AC8F9B6987946286986B9B7C6C664D5A7E89AF8E80B09D857F4F8FBBA5
768B4BC69EE0BEA7846F8680A17E7B9AB2BB959F92D4A8B489A49F807C7F6A75A79A7ACE
97629681A2AF993AE1E5787B888CA8C5B972A89483768288B77677433E7B587962778085
976D7E666C7E8CA979B9C0618EC55B6C60676D6D
8E7889AD93ADC0AD989C7A8D8E62819685AC76747F5862867BB59C7CB4A3858F6490C0A6
7A8A4BC596D2BCAD826D887B95797D889BBB7E8BADC5A5BA85ACA18D8087687F889F81CD
96668882AEB2843BDDE1657874749DC4B86DA0887E766987AE676E463C735865858D7274
815D766C6984818C6FB1A36D8AA751566B566E72
8D7C94AB8DAFC0A3979C788694597C987EA66A627B4F647D92B39E7DBEA4888C6893C7AA
7D894AC799C9B9AB88818B7D9686949CB0BE8F9FABD3A1C681AEA37E7B8562958CA3A7DD
8D6E899297BB7F31D6DD62738482B1C5B86AA28F8B79726BB869644138786A6780876E8F
80746D63616B7F9576AD88738DAC5A4F59566760
917B95AC90A8BEA6869274869150839E8AA460647C5478808EC09780BEA086906E90BBAD
869651BA96D3B9AA85668D808E8C9F94A4B19293B6D09FB8798E8D758181518F7198A8D6
898283B39FCF774DE2DC6A81746BBDC1BB7F9D92956C8D5EA87161503D76695C787E6584
707777676C76869474C37D7F91A96257594D6B63
917C8E9B8FA8B8AC869B688E95607D9C87986B64714D767087B79875BD9B89956995C0AB
8E944AC2A4CEB4A28B668073797E97B0A8A89296999EA6B77FA89B838C82509C7F92B1D5
91876DABA1DA6A4ADEDE79697759C9A8B088968D947591687F935D4C3D7F60576D7B5C7A
73707A6D727F968D7DD572929AA26D636352746B
90838F998EAFA8B5868F5B918866928D889A6F5E705C6E7487B59288CAA090936691C0A8
89854ABBADCBB0997F6D8D6C73878B9599AA8E88B7ABAAB48FB68987927D568D8780AFD2
8A8F60ABA1DC624DD8D17B697751CEBAB894756C896A7F7A769754405085796260828587
6B656979838BB18479D774959E9559685D4E6B6C
887E888685B3A1BE8F8B5B948A6985958195765F705866758AC49386BF8E857D6290B197
8C804EBC9BBCB29F7D6E88756F8D8FB3AAA6A490AAC6A29F85BB7F8B8F8B719A8873B0C7
809E5EA097DF575DE1C199787D5BC2CBAB9B9C89A6778093939A784154807D7F708A6273
6B6A65818E8EBA7A89DC579C958983756A547279
988A87807EAFB3B483865A9F92606D98879288676E505E7A88AE927DC083818D6895B498
998057B6A2C8ADA978718779528091BCA4949D7FADD4A3A689C27B768592808E9D65A6BA
84A7589195DF5073E4BD977A776BABD79F819B8E9B7B89A0A89D7D405A9156A072786872
716E6D7D9791B36E94D2538A908B924E6C4E716A
8D8D867E7FB5C9C596895F997E5E749789898465674C527E80AC947ABF8B84856E88C1A0
A98459BEB1CFB1B57B7D8E895F8FA6ACA193A28BA6CCA4A48EB77673818E929AB86EA9B5
91A6688AAAE54F77E3AE9985707BBDDE9865A097807A6B91B98F7149638A49A2766A786B
7E6A6E758A91A06F8DD0567B8C8491695A5B7B79
8CA87F7980B8C8C299865FA0905D6A868A8E836F684B5A8281AC988AC38D8A8F6786C09D
A97B58AEA7CEABAC797B84885085AAC09A96A7A1A5CFAC9D94C27174818A9991B673A2A4
879F7286A6DD4C88E59C8F8F8685B2DB91629F9A8D9F7F87B27D875A617B429A78627973
90669969A098A0658AC0657A9F83787C5B5A8475
8BA67D737EAEC3A7937C5D9C8D63727F9886867469424E7E76B99C86B88D8A8B5D79B297
A0835BBAABCBA6A47A8385884D80A3B3A397A19AA0C8A3998DBE7672828F969CC07CA4A8
8E957F98AAE03C93E3967E82919CC6DA89579499848E84A3BF8E7F465E814B89767C8A85
8A77B4638D8BAE6D9BA77173AC8A7C6153537B6C
89A9806E7BAEBFA2A07D65958C67797EA5898A7A634A568061B9B194C9938F936E81CEA1
A97B55B2AAC6ACAC7F7B87864C7DA6B4B080A4A5B1DAA3A09CC4777B7B938EABAD8BA9B2
91869997B1DD3B9DE39B7B73869CCDC094549D8F798F8A94B18981305A764A757C7F798C
7382BC739196AC7DA9A987769C9B885F50509080
88B3877A89B8C59E9F826D867D67645CAB868A7D664555315AB1A196BF8D89877186C097
9D6F61C4B6C6ACB57D7E90924972A9A6B47CB1B6B8D99B969CC37B7F7B8D8D9E9C9EB0AB
9575A5A5B9D642ABE6A97965819CB694AB64B0998B9C8C8DA88D7D366E834768736A6E91
828CBD758B899C81939D86A6A8A9795B4D5C766C
899D8C6D8FB0C6A2A8907594786A655FA57E767B6350563E7BA9A092BD928F8A7893BA98
A07070C2BAC4B0A9837D8F954674A7B5B973ABB7C3DF999C9CBA858B738C7A9E92A3B4B0
8171A8B0C2D539AEEBB679578091BABAAC6AAA878A9A908CB58A893D7D7E50786C6B6B80
8089A46D7D879882928B828FA4B37A6A4E697864
7993875598A5BC9BAC82799583747178B1897C876F64586482B09B94AE8C8D868798C39D
9F6B73ACC3C2AA9A8178869E4D67A6ADAE77A6A4C9DB959D8FAB808A7A8C839985A2B3AF
7A64A0B2C7D332AFE6BD7C5D7E98B7BCAF739A818F818D7DC4807D2D685F5183647B7D8A
837989798396968DAA7F8F97A9A47780636B7D72
7D998B5BA099A796AA846D8685817669AC977E936E5D473E84B89EA0BD8E93897FA3C39B
9C747AA5D8D1B897867C7D9B6268A0B39B74A3A3D5D3A1A987AA8F8786857F967F93B4B3
83629EAAC2C22CB5EAC07262568CA1B8B187A990A079976CB7867F397F7162935F796F8D
777A7F83879E8F90A18A9B969A986C755C6D7D70
81988B639E98B89AAF899191756E6C589E84698F6F52684486B9968FA286788183B6C4A0
946C7BA3D0C2B18881898098747392AC9A7AA19DE1D2ADA089A3978594797490889CB1A3
6D6498A5C4C726BEE7BC7276609DA6BD9595AC9297669E71A2A5693D6E58629657717086
70806C8982B99796A7909B949A9274716669787B
879590559D9AB494B592A490777C6C72A68285A085506C4488BA8C98A474657273B2BF93
8F706DA1DDC7B2858F6E848E797491AC88739193E3C5B2A990AC8E82AE817FA88499B5AE
858394C7CAA934C4E7AA7B844C94A0D195A37FA49768888384B95338966473915B715B72
636F638B99B7A48FB1ACA3B69877806E5D6B806E
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FFFF8000FF80000000FFFF80000000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FFFF80000000FFFF8000FF80000000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
FF8000FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FFFF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FFFF80000000FFFF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FFFF80000000FFFF80000000FF0000FFFF8000FF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
6.93889e-18 0.00787402 -0.00787402 0.00787402 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
0 -0.00787 translate
1.00787 1.00787 scale
128 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
5A8393A1AF9E5037B3B9BCB8B67D2F7F757780858147ADB1AAA9AB951E788F94999E9326
556269696E733D7E929DA4AAA9B0B4579FB2B2B0B0713A9DABAFABB06E338380929CA96C
2546495568754F6EB9B2AFADAE539AB8B8BABCB664B4B8BCB9B85B84B2ADB4B48689B2AF
ADACA95388A5ACB1AD8683C3C7C0BEAD52ACB0AE
5E91A1B5B9B37239AEBCBCBCB97E38756D6E7884883AA8B0AEAAAD91268C9BA5A4A19522
647E836D68593180969FA3AAAEB3B555A1ABAFAEB0762C87A0A0AAAD6C369C979CA3A977
3D65434E67704973B3ABADB0AC5196B3AFB0BAAB6BB7B9BFB9B96A8FB3ABB3B5A6A1BDB6
B8B6B25C869EAAABB5938DBBBBBBBFC36FAAAAAA
5E97AAADA8A5662D9EB5B4B9B89D5571696A75859138839DA3A397623F8392A19E98842E
57796F6E60502C8AA3ABA1A7AEB0B05398ABADAFB0742AAA9F90A0AB703B9F9DA2A6AC78
4795535E6F734561B3A8A6AEB04E95B6B2B1B1B064B6BFB8BCB96B8EB4B5B3B6A498B7B8
B6B2B1579CB0AEB5B89286B0B0AEB3BC72ADA39E
3C40463D393829242F2F202826221E282328292D322D3D4E34291D151F3D3E3A35374932
383E3937342D2346494E4E575D66612E4E686C6E7145176D63575E755A216D6E6B7A7B52
3044372E2C363B629E98938590456A9EA4B1B5AA61B3BCB6BCAE4E65A0A3A2A88E8FBEBA
B5B8B75C8DAEACAEB0867FA5A698A5B7659EA6AA
A5A5ABA85F7F9088A0A4A8ACA3A6A49C948A6B66A49FA29E9A8D8C8F868F8C88824A6B79
6B70767877777878745E4732526665655E46564C4539392F2217212F34382F352B232A29
2A2B2D1F222F35373E3C3C3C2D1F171B2630231F10242C212A1803112724272E221C3643
45494D192E4B494D512D335161636D743B414A4C
AEAEB3B5589288809BADAFB2B5B1B3B0B1B16D6AAFABADACA8A5A8ABAEB1B7B3B55A7B86
858A8F9EA09C8E85858F9F4B7BACAAA9A68D969F7F7E656D6147887F72AAAAAD917085B4
B4B2B7677CADB3B2AEB2B1B0AEAAAAAB9357879B9FA09A999E9A8B878C8B7F668E8B877D
757A77696A6F726C60456B5D55515457686C6D66
AEA8ACB2529D8C90A1A4A5A0A6A7A6ACADB06F6AAAABACACAAA4A6A7A8ACAFB6B34CA49C
95A4A5A6A7A49A898298A24681A1AFB3AA9696987476788382568A8C8CACABAC94776FB1
B8B6BA6179ADADA8A6A7A7A7A9A5ABACA75F8AAAADADAEB5BAB0A6A8ADABAF67BAC5C4C1
B6C2A78568B2BEB98A8FB8B3AAB3B7BCBDB3BCBB
B1AEB3B353A89795A7A3A6A3AAA3A5A4ADB16767AAABACABA8A6A9A6A5A6A6AEAB43A8A1
989BA3A7A6A09D948EA09B4B81A1AFB1B0AC9E9B9F94A0A48C538C9194A9A8AF8F7785B2
B5B3B95C76A9A8A5A4A9A9A8A7AAADADA4578AA9ABA9AAB2B6B2A5B0B4B2B34AA5C4C5C7
B9BB805340A7BEBD8B8AB9B7ACB6BABCBCBDC1BE
A9ACA49652808487878C909198928D9A9FA1695A888B9A9E8C938D948D8E8F9B9446A8A7
99A09DA1A1989A928B979B4579A59F9DB1B3ADABA9ACAAAB8750889B9FAAABB39A7E81B6
B9BAB9617FAFACA3A29F9FA3A6A7ACA6A26A96A8A6A19FA5AEB09DA0ACADAB4098BFBEB2
AAA46137449DB2B0718BBAB5ADB6BABFBDBABCBD
9A97938F8D877D787968356668757E797A777C65797E71583F5473767375786F6F6E6F62
5754405E7F7C798181877D767B7C6257534E4D4C5151555B4D444C6060695E5846495568
787578504E78796967657A7C82886D7382497A8C8575848F989D9C8D979D9F3884A69B7E
8079554A6B798C96738DAFB2ACB3BBBBB9B8BDB4
BBB7BABAB7B5B2AFA9AC4E9CA19FA3A5ABA8ADB1B4B3ACA160A1AFAEADB5B4B4BBB9BCBF
C0BA65ADAFA9A6A6A5AAADADAEB1B3B36B8EB2B0A7A4B4B7B4B8B6B1AFA56789979C9A97
9695969EA8A99A835A7B83777471797E7E887869653F49656A6A5A5B62615F645F6C6A44
61686264655C5F5B574B393B3B3A3E4C474F4A4B
B7B0B3B0AFACA9ACABAC50A2A5A59D98909DA8AAAFAEA9A75CA4ABACA9ABA9A9A7A9B1B7
BBBF76A7ADA49B9DA2A1A9AEAEADB0AE7B8CAAA7A6A5ACAEB0B0B0ACAAAA88B6BBC2BCBB
BEC2BFC1C1C5BEB589B8BAB8B4AFB6B7B3B3B4B6B35F89BABCBCBAB8B2B4B8B4BAC0BC69
AFB7B1ACAFB4B4B7B4A8A9AD9664A0AEB3AFA4A0
B1AFAFAAA9A9A6ABADAF608E899A9CA19F9FACADACABAAAC72B3AAA8A7A8AAA8ABA9ADB4
BBBA78B3AE9D9A95A6A0A4A2A5ABAFAD73819B96979FA8A7AAA9AEABA79D8BB5B8BCBBB7
B5BFC6BDBFC7C3B57AB5B7B8B5B1BBB8B5B2ABACAD5A7DB8BCBAB9B9B4B4B4B8B9BBB964
9BB3ACA9AFB3B2B0AFAAADAE9064ABB4B2B3ABB1
B3B1B1B6B09FA1A3A9A9578698A8B1B1AEA8ACB1B3B9B6B270A2A8A8A7AAADAAB3B0B5B7
BCBB7CB9B5B0AEA9A296A0ABB0B6B5B3637A8E8B8F94A1999DA2A2A89E7C81B1B4B6B7B9
BABDBDB7B8BEBBB183B3B1B6B9B7B2B1ADACABA6A3578BB4B7B9B8B6B1B3B2B1B7B9B456
94AFA8A7ADB1B0AEADAAACAB8E77AAB7B4B3A9AF
665D483931363431413C3432403B3C39423D30363C3E3B3A263E4C4B4D3D3B34352A3A43
463A3B595E61566061605D616A75736B344E5B5C666263646B6C6E6E6765487B80817C6C
667081858A908F65618E7FA3A1A49EA09C97989B924E85B1B3B8B6B4AFAEAEB3B2B3AD4A
9EB0AEAEB0B1B2B2AB9FAAB08C77A2A4B1A9A9B1
B7B6AB7279AEAFB3B3B3B4BCB8B4ADACA99352B3B6B7B3B2AAA59D948C8D9187499EACAD
A4A4A7A7A6A09B9791834F7D8182807E776C68656969767036525F595E656E6C67625B5D
563D2F4A4A4F4A493E2F463F403B354C525155484953544441483B2C2E373A43474D372D
414E4B50545A5E62666C6A685235535D6A656276
B1B2A87689ADB1B5B5B9BABBC0BBAEA6ABAC5AADAFB5A7AEADA9A29D8C90979B51AEB0A9
A9AEAFB5B4AFAAA4A3A16AA9B8BBBDBEBCB9BAB9B5B9BCBC69B2B2AAA7B4B4B4B3B8B8B4
B29557B098B3BBBDBEBEBFBFBB6B64B4B6B8B7B3B3B7BBBBC1BFB86D7DA5A9A0B0BCBBBA
AFAB9A968C4E72857E807F726D747B7078818462
B0B0AD778AAEAEB2B8B3B4B2B3B4AD9EAC9E5BAEB3B3A4A8A8A5A79E9B9E9CA049ACAEAB
A4A0AEB7B5B1AEA99F9E67AFB6B7BBBBBBBBBCB9B7B9BBBE65B3ACA9A7ABB2B4B2B2B0AD
AD9C78B39AAABFBEBDBCC2C3BD6869B7B1B6B5B4B6B9B5BCBEBEB8828EAFACA8B3BABABF
B8BCB9B7B056A3BEBEC0BDBBB8BBBDC0C2C1BC94
AEAFA96983B0A9ADB5A8AAA5A9ACAC99A5A162B5B4B4AFACA7A8A9A59F9F9BA342A0B2A4
A6A9ACB5AEADACA9A69E5FAFB4B3B5B7B6B6BBBBB6B3B2A562B2AA98A1AEB7BCB7B3B1AE
AE9672AEA8ADB1B8B6BBBDBAB77565B3B2B6B3B3B4B7B8B8BEBDB9748BADAB9BAFB7BBB7
B2B3B4BAB147B0C3C5C3BBB7B2B7BBBEC3C0B98F
887E6B485F7B7981867E7678736E716A666449888488806265666B6D5B5F535723406572
777E92918976817D84803B909EABAB8C96A1B6A298B4B5A66FB2A6899FACB0B4B2B5B0B5
B28D5999ADB2B3B4B6B1B4B2AB7173B4B0ABADB0B0B3B5B7B9B6B46B8DA9A9A0ADB7B8B7
AEB1B4B8AF47ADBFBEBCB7B5A8B3B8BDBBBCA881
A4998D909088858484576470717378796E6F7D777B80795542656E6C727173716C6C7A75
655B3053555758565C5A6454585B573E24414842423C3F4D464838424F333D5045575745
4F502F3B4553564C4E4E4E57634336494952555B575A5E63626166323260697172787D7C
777D6F786E2F6B9497949B98949191A3A6AD7962
B9B7B8BCBCBCB9B7B56E92B2A8B7B8B9B8B4B9B8B7B8B87A6BADA7A7AFB1B8B7B8B4B3AD
AA933DA3B0A49A928C84949CA2A6ABAB529AA4A3A7A9A9A6B1B2B1ABACAF69A6A8A4A6AA
ABA7ACA7AAA9A78677A6A6A7ACABA2A3A199988F7D3D55706D696A7679777A706D656440
5F63676665636463626467533F3D60636668665D
B8B7BDBEBFBCB8B8B56D91AD9AA9AEACABADAFB7B7B1AA826BA4A5A2A1A6A8A9AFAEB1AF
B2A149ACAFA79897948E8A8C94A3AEA741939D9D9DA5A1A4AEB1ABADB5B379ABA7A7A7A7
A8A8A7AAAAA9AA8381B0B0AEB3B4B2B0B2B4AAABA95F80A0AAB2B0AEAAADA7A4A8ADA861
A6AEAFB0B1B4B3B1AEA9AA947D6595A1ACB6B6B4
B7B5B7B8B5B5B4B7B0698AA998A9A9AEA6A9ABAEAEAFAB7D659A929FA2A5A7A7A9A7AEAD
B1AE48A5A89B9194838482858598A8963F8E96979A9C9C9BADACAAAAB3B16FA79FA09FA5
9FA1A3A5A4A5A7828BACADADAAA8A6ACABB0ABADA74E769EACA9ABAAA7A3A39CA29FA95C
9EACA8AAA9ACAEB3AFA8A7A79B679595A7AAAFAE
87827D7B7D848D8A8C5A7C907292949C9C9BA0A1A9A8A6774F8C9298A0A1A0A49AACB2AE
ACB04CA7A08F8C9183827B807F84948E578B8E84878EA09FAEADADABAFAA669997939191
969E9FA89E9FA27A80A9A8A7A8A6A5A4A6A3A3A6A15C7997AAABA9A49D9E9E9394969D59
A0A6ABABA7A7ACAFAE9898A5986B8B7896A5A7A7
695F51304D504942394B4F464946474F39293F464B413D392B302A232F2623232A4C5A60
5D494169726A554F5B5D57626B55585737394440424D51524C585658524D4265676D6D6B
6667645C63656251577A8072757F81817F70797E7F4A636776787D7162594E5D5B596348
7A828A70758B928F8F8378896859736E8AA09D9C
BAB9B16FB9B5B0B4ADB2B3B7BABEBFBAA65A7C88B3BAB9BEB5B2AEA5ACACA74AAAB4B3B0
ADB0A2AFAFACA19B8D509EACA7A4A8A8A29D9D959F9B7C457F8A85878C8F848B8E8E9195
8C56707A797B76736D68645859572C375E5A55585E645C56615A483C5C656559555B6468
5F544E432638473E413F3F3C4542494D58533E44
B5B4AE71B3B4B7B2AEB1ADB7BBBAB7B1AE4E8E95ABAFB7B4B1ABA8A5A8A49E53AFAEB0AE
A7B0AEAEABA5ABABAC60ACB1B2B6B5B4B0AB9B9DACB2A4539FA59C9BA4A7A6A5A3A6ACAE
B276B9BDBDBDBFBFC0BFBCB6B3BB3F8CA7A8AAAAAFB4B8BBBBB86D6EA4A9B2B8BDBBBDBB
B8B1AF9E5194AEA9ACB4B3B0B9B7BEBDBDAC6AAE
B5B1A66EB3B8B9B4B1AEABB2B7B5B2ACAD5DA9A3ADA9A6A9A7A3A3A7AAA08A5FAEACAAA9
9EA6AAA4A6A7A6AAB071B1ADB4B1ADA5A29DA2A3AAACA64B9E9E8F97929E9C9EA4A2A9AD
B071B9BEBFC1C2BEAFB2B6B5B8B94DA4A7ABA9AAAFB2B5B4B7B66970A7AEB3B7BBBDBABA
B5B2AC8C4A9BAAAEAEAFB0B2BAB8BBBAB9AF74B1
AFAAA777B5B7B8ADA1A4A9B3B4B2ADA9A758ADAAACAEA4A2A59AA0A3A7AA8F5AAEA8A9A7
9299989599A8AAA7AF64AEAEACAEA4A5A6A5A6A3A1A5AF4D9D9B837F7C8A9194A3A0AAAA
AA72BDC1C0BDBDBBB9B3BBB7BCBA589A9A8E94A0A7B0B5B9B9AE4E6DABABACABADB7B5AE
AAA3A8944B99A1A6A6A697A5A0A1A9B1A8A37DB4
4D443027404338363320303B3E413D3E322C3A484C4848413B484E505546421D5C646667
6B67706C6A766E6B6F3D7277797B737373716C76787C793A7D77787166787E81818B8B87
8C568D8A9088879091859599A2B14B99A8988B979298A6ADB8B04E6D9D9C9EA2ABA8A9A4
A08B9A8E599F94949EA19691898B9AA4AEA376B0
6B4483908B88722C638A8B817E67305F828383777436696E62575E55283A444D66623928
5E776F6668672B3E60635749513758544A3C403A2A5C5858483029232B2F38362B273A45
49423A3633413D38342219262D312A2D3A45414445413D3942574B4C4C53534D494E5759
58525255362A3B414545555748474C4C5C4E3045
9E3DBCC8C9CABD2B81B4B7B7B89E288CB9B9B9AC974D919D8C8A8E804D565565838F8233
8DAE9D97A19C4375A9B1B0B3B855A18D645D565148B7B9B8B6B2695BA7B6B7BCAB4289B5
B4B4BAAE43BABFC4C58B83BAB2A8A48C52A1AAA5ABAAA456AFB4BCB9B34C6CA093909096
5F488891A3A1893B6E8D9998998F36618E99A29C
AF45BEC5C9CAB42485AFADB2B4A72692B7B3B4A5933A93B3B1B3A9A9553D3D4B6D7B7E42
88B2A597A3A03B83B7B7BABFBF63A6A690705F4B56B5B8B9BCB86874B0B4B9C0B84B94B4
AAAEB8BC68BDC1C2C8B36FA8A89DA3A760A7ABA5A29C8D52B7BBBBB7B86D74959C908790
5985AEB6B7B3AE419FB9B8B8B3AD3EA1A8ACB0B0
B255B8C1C0C6A82D8FA9A8ABA893218EB3B2AC97803F98B4ABACB0AE4F3717191E414533
849F7F7A939A497FA9AFB0BBBE639CABA983725F4EB3AEACB2B4657FAFB4B5B7AA3A96B1
ACB2B7B560BABDBDC6AF71A6A1A7A5976299A59D95848647B2B5B3AEB063648A827F7B75
4888B2B6B8B7B036A4B3B8B6B1A83798A5ADABA7
84337C857E82763D5C7F7A76877B2A5F6D715B535F4562788282868D463E2C3B3C415440
63644B55606947617C72708087489A977464436147938B7E7B885669808393A082378894
9FA0ABA45A9799B5B6A06CA8A7A4A79C5A969F9893857F4FAAAFAAA4A7544E89887C796D
4E92B8C4BCB9B32BA0B6BBBAB9B139A4A6A8B0AE
887B7872415B70797E6F6D70796A685855583E47686F685E5C4B555B5A595E503C49636A
6B625C5C5F5F625F585E463A5157555C5C5B5D62605F69624E555B5B564D464C46526262
66614D4A423B444C483E4B564A4F515B536664615A645B537C736D6A664C405F665C5D59
4C6A7885837678416F7B817577713F787C79837E
B4B0A79F4294ABABACA5B2B4B5B0AAA4959D6A7EB4ABA6A0ADADACACA8AAAEB0738BB1B1
B1ABAEA6A6A9A6ACA9AB7870B9BDBCB5B8B7B5B1B4B3B9B569AEB6B6B7B3A6AAB0BEB9B6
C2C45252A8A9B4B4B1AAA59E8B7B41A5AFA182938C969B9E9F99896256959A8E9AA2A081
98A197969552809C90846F51556E896A63614F4F
B4AEABA73897A7A5A29BA6ACA8A5A5A3A29C6881AFB1A789A5A2A4A79CA1ADB27D8EB6B4
B2B6B0A7A6A7A7ABA7A18C91B2B1B0AEB3B5B4B2B1B6B7B657A6B4B0B1B0A1A2A7BFC0C0
BDAE447AA9AFB6B8ADA8A6A3A38145B8B8BCB9B9B7B6AB94A9B3B59175B1B2ADB4BBBEBA
BCBBB7ACB46FA8B2A99C9FB5B8B3B4ADB1B87A6D
A8A3A69F379AA3A3A29E9FA5A8A9A39DA3A06E86B0B8B397A69DA0A9A3A5B4B48C84B9B6
B4B3AFA6A5AAAAAAA8AD766FAAAEB1ADB0ADB0AFB1B0B5B761A4ABAEAAADA5A5A6B4BBBF
BEA0397FAAADACAEAAA2A5A3948449B7BBC3BEC2BDBAA593AFBCBB9380B2B4B5B9B9B9B4
BCBBB8B0B267A6B3AA9094B6BAB9B7B5B9BB7C76
B1B3B0B257A2A2A3A2929A99A8ACA7A1A3A06280A9AFB09BADA1A6A9A29CA2AF7F7EAFB1
B6B4B3ACA5ADABACA89F595BA2AAAAA8A7A8A5A9AAAEB3B66EA3A3A6A7A8A9ADAAB4B9BA
BBAF4D76A8A7ADABADA9A58F88835DB1B6B8B6BCB7BCA8A8B8C1BD9783B2B3B8B9BAB9B3
B5B9B3ADB05DA3B3A98275A3AFB2ADB4B4B78A80
6557484831404B51524A3E294B635B4D473F3E4B556A605444383839313845403B4A595A
656757423C53514D413F362B5451523E4339354941524D4D37626761636D6D716A70666B
68532C4866615B665D584C5D656139606B73717B757C6F7780858369557A7C8380817D81
7A827E78794A7B7962535461717A7A828D886562
B18A799AA2A9AC9E928D8126A6A7A1A09B9A9A979E9E8B8F9254919CA1AEB1B3B4B4B6AF
AFA98959A6A1A7A8A1A39F959AA2A8AA633A8E989EA6A9A9A09094A3ADA778669DA6A4AF
B1AFAEA69AACB6B268709B9D97969D9E9D9998989B85436B787A7473767467585C523762
6A6969666C6F575E6C6B735F4A6C6B6967696864
B4A29093A4A8B1958BA29C2C9BA2938D8C86808B89856990973E848C8D9EA09DA6A7A8A7
A3A0936DA2A0A0A3A1A09B8B989FA4AA7451A5A1A5A9AAA6A398A0A5AEB06F79A8A9ABB5
B2AFB9B9B6B4B6B86F7BB7B7B1ACB9B9B3AEB7BCC0B23D7DA7B3AFA49C9A8CA1B0BB6895
B9B1B2B0B3A581A2ADAAB08582B9C0BEC1B8B9B8
ABA5948DA0A6A78E899F932C9E9F98888479848A868F7E939137829286919FA0A1A6A9A4
A0A07F6B919D979C9F9B9C9496A0A3A57156A4A6A4A5A5A7A39A9EA5A8A56A60A1A4ACB3
B4AEB5BBB7B5B6B66C83B8B4A8A9B6B7B3AAB7BCBCBA4893B7B3AC9B99A6ABACAFB86A97
B5B4B1B3B2ADA2AAABA7AF787CB6BBC4BDADB7B5
A5A1A39DA09E9C8F8F857D399EA0A6A49B84888189909B96983E8083839296908D91A1A3
A09E71576783918D9C999C8692A0A19F85669DA8A7A3A1A39B8F8C93939175618B95A0A7
A3A1AAB1B0B4B7B57295B7B29AA9B4B2AEA8B6B9B9B8419BBAB9AE9BA7AEAEAEAFB9689A
B1B1B1B4AFA6A8A5ABA8AE7D82B9BBC1BAABB0B4
7366675C4046423A392627294553525342483D494F5C4C43343E53494E5D66534A474F59
50614D49455045474B5E574F56565A554A46716B6E6A6866646D63606A64564F4E5B7073
75736965716F706E3B63807B7581847D837A7C777C76357285847D5C747E848C90925F75
878A857E78707E8088818265619AA2A09D7B9197
AFA4A5974C809299978B9295A1A3A8A7A9954D57A39980A0A29F9B989A9EA0A77968999A
8B8492868E94959098915D769CA8A594919093908B8BA0A45F7488877F838D868D8A8983
867946858081888C897464635F5C2B628A8F8C918E8C8C837F827F753A667B7B75737772
70696C66673740565A4F575A5A5D5D5E625D5F3B
B6B1ACAA4C88A9AFAFB1B2B6B4B4A6A3AC9957589C978999908A838B939BA1A6826EACA6
A0A39B9F9F9BA1A49A8C5A7FB8B9B8A1AFAFADA6A7A5A8AB74A7B0AFB0B0B4B8B6B9BABE
BEB45EBAAFAAB2B3B9B4B1A69AA0308AB0ACA9B0B5B5ADACB1B6BCA537A6B3B1B2B5B6AC
ADAEB2AEAA6479B6B7B7BAB4A8A4B0AEB2B1B162
B3AEACA93B87AEAFAAADAEB7B7B7A4A1A6A56854A5A197978C837B7C8F9EA09F8271A7A7
A79B899CA195A2A594834C7CB4B4B49DB5AFAAA9A7AEADAB7198ACB1AEB0B7B8B9BCC1C4
BFA862B7B0ABABADB6B2ABA39F913076ADACAEAFB3B2B4AFB5BBBB9E35A6A8ADA8ADA5A8
ACB0B0A8AB6F76B0AEB0B5AB999FABB2B1B4B16A
B0AAA8AA5175A6A8A2A1A6ABB0A7A2A09AA16752A29A9798877D7D7A7B848A947976A4A8
A69B97A4A9A0A0A397885184AEAEAC9FAFACACA2A1ABA6A56389AFAFABACA89FBCBDC3C2
C19C5DB5B3B2A39FAAABA9A4877C3D68A7AAACAFB4B2B6B6B3B0AFAC3FADADAAB2B3ADB0
AEB7BBB8B97C77ADB0B3B4AFABA7AAB4B7BAB267
75716963345C6E676A6A6B61696763544E4C30346D757070645A595B535A61683C4E7670
6F646166705F5E61544C32517375726F707A756A5F5F564F314755656E67675E79838A86
834A3F88828C7F878280877A676E44618F9997A19E908295909A938036819D909494979C
A0A4A8ABAC806495A4AAA6AAA59DA1A2A4AAA964
9798959095908484949CA058688F8D8182899093908983847F54395E60646B6960606C6A
6E6D6A465F666C666E737E767A766B7162466F6F696A676B74776C7678764B3965706B65
6B6F776C6E716F67546C6D6A72787874706C68625F3924313C3D4A475152574B4F473F3A
5F6162605E6463585F5C56503543615D625B605B
BEB9B5B6B8B2B1ADAEB0B4617BA9A49E969E9EA6A2A1A4A7A363518C8994979AAAAAADA9
AAA9B16286AEB7B8AEACADAEAEACB0ACA469AAA39893909FA5A4A5A9A6A67260AAB0B3B3
B1B8B7B9B6B9B3AB83A7B1B7B6B3B4AEAEB7B9B7B870667F80A0A291775A7A8485835F4D
A5ACAEB4B9B6AAB7B9BFBBB94392AAA9B2B7B5B1
BEBAB0B0B6AFAFACAFADB16D85ACA19B959B999DA0A3A5A69A60508D928F9995A2A3AAA8
A39FA56C83ACADB0A2A0ABADACA9A8A99D56A7A398868EA4A69BA3A8AAA76E69ABAFB4AF
AEB0B3B5BBBDB8A486A0AEB4B1AFAFA6ACAFB5B8B36794AA90A19699865696A7AAAC775C
ACA5A7ACB2AE8F9EB8BBB6B95C93ADB0B1B5B1AD
B3B0ACA8A9ACABACADAEAD7884A29472707F97A093A1A39F90554E7F818D91868A899DA0
9B9DA2657F91A4ACA29698A5A4A7A6A5985EA092938885A0A3A2A5A6ABAB7682A6A9ACA6
A8A2AFAFB5B5B1A58799B2AFAEAEA9A0A7A8ACB0A8608B9E8F9D8B8D8E59949DA7AA7A59
AA9DABA8AFA89BB1B9BAB8B96F9BA8AFAFAEAEAB
8677727570706D676B686A38607D827A4B5D5E6F756D7181783E5672727573675A4F6276
71716B466D778980715E546F797673777A4D6D6A746E656A5F5F6B6E6F645469676A7A7D
738A8A898F827F8472668C8D8F9394949C90909686598582807F6F796B4B7F9191A06B66
7B7C9D9C9C927CA8A4958771566598ABA5A3AAB1
7E6F634630717375798289898478707B77552E5D67655F58585657544F5050331E546D65
65616263645C64605D48325D625F6561605E5B605E565033283D4642445A5F5C5C5F6161
593A47636A665F72706D7573757A71344F5E5C4A5A57575355463A221D27263A46585D62
666D6C615037254A3F413E4048526873757F7663
A48773743EA8A9AFAAABA6ADA8AA9FA7A17F59ADABA8AAA7ABA4988F9EA3A16C3DAEABA9
A39FA3A0A2A6A2928D7E3C88A1ABAFB4B5B5B3B7B2A6AE6145737B797993988F81929288
8A5A95B0B3B5B4B0B6B6B9B5B0AEAE318FAFB3C1B6BEB7B8BEC1BAAB304386ABAFB4BBBC
BBB4B0B1A99D74B2B2A4A4B6B7B8BCC0C5D2D076
AE95687357B0AEACAAA5A6A4A9857D999A905CABAEAEAAAAABA2A1969CA19E783DAAADA8
A19E9C9DA2A1A2A2A07E3F9DA4A9ABADA9AFAEB0ACA7AD7157756E6E6A776E6963768984
845587B2B5B39F96AFB3B3AFB0AEA83694A9A8B1AFB7B8B5B8B8BAB54676ADA39099ABB1
B2B3AEADAAA972B7B4B1B0B6B2B4BBB7BBC2C071
AC9A735B67B5B5AAADB0B3B0AB6A7CAEAA8F61ACACACAAA8AC999999998F916C3FB0B0A4
A8A0A8A7ABA7A0A3A07E2F9D979CA5AAA7A9ACAFAAA9AE714365666A6B6A68584F5E7575
734883AFB1AEA39C9DB3B4ACAFB3AF3792AAACACB2B6BCB9C0BBC0B6527DABA599A5ACB4
B1B2B0AEACAA6DB1B1AFADB2B3B3B6B5B8B8B874
91886C4E4F8B8573778275777F5C678186654C8175777E868883856872616248408B9190
8B847D79728874716C5E2F7D7B71818388867D787271704D31302D3637443E40404C4554
4E487E918F9585877E8D8A8B8C938538588286897E7D81807F71717739609AA6A4A3A8AE
ADA9A3AC9E7B639196949093999B9DA4A9A59854
41425E666D665D36495950555951243757516062614640374753544F2B233846504D3121
38454C515744313E63696A5B5E261D4D52514E522C3E4E5A625C51293E585058623F2753
6768615F5F365C66575C5E5426496262655E4745626462535E39555D5946483729313A30
38362A2B374139413A242F3D424E4941334D4C48
7A5BA4A5AAB1B75E7B918898A1972A4D9499939CA94F63969A948D7C3B3B61735778923D
7BA3A0A3AE8D40698F9B9E9192396AACA388859E4A6EABA2A69DA2498EAFB1B5BDA72690
B1B4B6B8BE3AA3C1B9B1AE9F2F82889298907578AFAEACAFB75D96A0A5AAA974269AC5C1
BCAF5B3FA8A8A7A3984C688EAEAEB6A041B0B8B8
8B6EA0A5A8B5BB635AA38F9FA8B049538E95908D985A619B9A8E7D733A395D7E6477864C
78959995A8904C6F9BA8A09A9C4E72AFAAA09E9B4B6EAAA8A69B9D4996B8B6B9BEB6539E
B1ACB0BABB3DA9BFBCB5B299327D8D8F9181626AAEB3B7C1C055869FA2A5A07238B5B6B7
B5B76475AFA7A9ADA7477A99A2A6AFB24FB3B8B8
8F77AAA6B1BEBF5A73A88EA7B4AD44699C908D8EA152668F7F6F6D61343951595B61753E
7B9BA1A7A897477A9F97948793527AADA89C929D4A72A2A5A4A7973F98B8B7B7B8B24D99
A9A7AAB3B93BA8BDBAB8B9A43780887F7B866872B2B8B9C0BB589EA9A7A6A16B4BB5B2AF
B4B37076B0AAAAB1AD3C7C96A5A59B6649B2BAB7
8D629CA0A0A59C4F448698AEB1A1345CA192908D99472C888A757C7D4E597775655C804B
859AABB2A9A04360A79F9082885470999D92867743749D8782989B669BB2B2B5AB8D4299
A3AAB1B8B84CA3B5B0A8A490324B5E6C83835C568C979698A291ADB2B1ABA67264B6B4B4
B9BB7283B0ABACB0AE467BAEA8A0927D52B2B3B4
6958503F323435333B494F4E53504B55563F39484D514B50535A51463A323E242A4C443A
4B4E696B6F62535F582D535A4548476872785058574A38244C595E585B6667675A53494B
472F4B5A62596D716866645A595441374B574245565A50586E7F796E425765616683847E
7C7C585E5C5257625D4B5D625D5654423B4D5356
AAA79D6E378B9CA0A7A7A7ACAEAEAAACA87663908C9C83849A9D958D788B8D6162A1A6A7
A5A2A6ABAEB1B1B1B24C93A89F9F99ABAEACA6A2AAA0A43CA6AAAFA8A5A5ACABAEB0B1B2
B2429FA8B2AFB1B8B1B2ACA5A8AC9C85B4B8AAA5B1AEB6B3BCBAB1AE56ABB3B9B7BABBBA
B8B1A7A4AE70648D97A2ACB0AEAEB2B1B3B7AE61
ABA4AA6661A89E8A98A09D9EA1A49FA4A38868999AA28C898F9A8F8E8D97916884A4A9A5
A19E9C9D9FA3A6AAB26899A99E978DA6AAA7A999A6A1A45FA0A4A6A4909AA4A2A5A6AAAD
AD3FA4A8AEB2B1ADA49FAAADB2B1A086B8B8ADABBAB5BCB7C1BFB9B35EAEB4B6BEBDC0C0
BEB2A6A7B57678A8ABA8ABADA7A9A7A7AAABAD66
AFA9AC5D47A59F8D91A2A6A7A4A09EA7A48C65A1A2A59F9A8C8C998278878D6984A39BA1
9E9986899B9F9BA6AC6A9CA8A3A391A2A1A5ABA2A5A39D5DA29D9A9A949A978DA0A4A6A8
AD4EA4A2A4ADACAEA5A2AFB0ADADA084B8BCB2AEB6B6BEBBC2BDBCB76FB2B2BBC2BCBEBD
BBABA1A9B36871A0A6AAA9A69E9DA0A1A8A3A877
B8B8B672419DA3A0A39D9FA5A8AEACA7A1846393A1A6A4A19F9D9A89757B996584A29C9F
9DA18C847E888AA29545969884989BAAA8A7A69D9F9E9A4781857C7C798486939A9FA7A8
AA4E9F9FA6ACAAA59A95989EA19C7E78B0B2A4A1B4B9BBB7B9BDB9B571A0A3B3B7B8B8B3
B2A397A3AF5B64ABA5A5A6A39C9F9F999EA6A083
666964543F505E5B675E44414A4B4B2C2B2E2F33414B5A4F3D343A39595062445B69675B
4D40373C494F515135283C403E3D404D39313E3F40423C34303B30362F2E24323B53484F
492E484D55594C51324446595B5F6C6660645B463F34324D4A5250534A49525D585B5566
5F61586A6B4A334C4B4342414E574F5F534E4839
A8A3A3A1A0A3A59E9C955662B0ABA2AAA5A7A8A9B0B3B3B05255909495A0A6AFB0A29D9A
A69D5C48A8A3A0A8AAA4A4A1A4ACAFB17D2C808993959D9698939B95A4953D5F656C6D76
8593999289859B644CB2B5B3ABB3BBBDBDC2B6977C5A82CBC3BDB7B5B7B3B2B6B69870B6
BABAB1B0B5B8B3AEB0AF843CA59EA2B2B5B3AEAE
A69D9A908C8C9D968E8F5D6BADAEA2A3A1A2A2A7A9B3B4AF7F67977B799CA09F99998C8F
8A88613696A0999DA19D9E88A3AAAEAE8145A7A3A6A4A6A6A8A6A78BA2A95A657276837B
717C85847B817A613F9EAEAEA3ADB1B2B4B6B4B4B56D92BBB8B8B4B1B1ADB1B0A96F6FB7
B6B5B4B7B5B7B4AFADAE9D52A2A3A6B3B1AEADB2
A8A3A092928294958B846166ABACA29D9D9AA4A0A6AAB1AB80689381868A8DACA9AEABAC
A7986A2D9AA7A4AAA6A39F90A4ADB3AE8848A9B4B4AAA3A7A4A6A07EA0AB5D667F8B897F
7D7D7F878588796842827C696D9FAAAEABAFAFADAD5F92B3B1B2AAABAAA9A5A4A5597ECA
C4BDB4B6B4B6B8B3B3B3A85E9EA1A7ADAFA8ACAE
A5A3999B8F8D91888F936A5CAAA7A3A49D9A9FA0A9AAAEA56A718C8A7881839EA7ABADA9
A9A26A3298AEADB1ACACA5A1A9ACB0A79840A5A2A7A7A19299A2A08A8DA56A779F9F987A
6E767C8F9285867369A09E9E6C808AA1A39B9D938B3E809F999896A19CA09B99996072BC
BCBCB5AFA9A1A8B0A09E9A559C9EA5AAADA5A3A8
655847393B424848493F262C607178746947494D494F4A3E2C3C434B4343464C524E5361
5E3E242B49545C4F4F4246474348442F39374D504C3F41313033414242434040464C493F
3038343B37393F323B3F354047432D21383B413D3B39404B433F443C233336353C443D44
48494833321C2E3C3736444A5459635D4E4E465B
B2A8A35A7C92747D9794A4AA8FACAAA7A5396888A2ADAFAEACAAA2A1A2A0A9587AA6A8AB
A3A7A0A5AAA1A8AF9E4670818D9A9BA09CA1A1A19A9A97499FADAFB4C0B7B0ADB0AEB3B4
9569A4AEABAEB7BABBB7B6B4B0B34761B9BCBAAFB4BBBDBABDBCBAA73DBBB7BABABAB6B4
B1B1B2ADA568A2B4B0B4B1B0B0AAA4A6A4AA71A0
AAA7A56478945C7A897B9295659E9E9E9D2D657A809D9A96989791949297A86688AAAAA6
A5A49CA1A09EA6AAAB5A7999989FA3A5A09A908E8D8F8A3FA3B2B8B5BBB4B0AFACAEABB0
97699DA3ACB3AFB3B8B6B2ABACAE4D82BDC5BFB4B7C0BFC4C5C6BEAD45B4B1B4B3B4A7A6
A6AEAFAFA960ADB5ADB0B1B0B6ACA8B0B1B279AC
A19D9F5D738A5489917F9381669A98989F375E79799E9C97918188909292945273A1A3A1
A1A093969293A0A4A14A69999AA19D8E8A8985848E8C89419BADADAEB4B0A9A7A4A3A5A9
A3659296A0A8A1ACAEACA8A4A7AA4C8DBFC2BFBBBABEC3C9C5BDBBB24AB3B1B5B6B1A79F
99989FA9A356ADB2ADACAEAFB1ADADB4B6AF76A9
A19C9B65718F6F9F9B9AA4807DA1A09D93435E838C9CA39F9A91908E8D938234759E9E9D
97A0988D88939799994F6388959A998F837F7E80858877428A9EA49DA4A69F9794919D9A
975B9786899D99999E9996979E9A3980A7A4B0AEAFACA3B4A6A7AF99518C8D99AAA79286
87888494985BA3A3A4A4A99A9F96A3A4A09A5D95
594B4A393B4B3F44484F4E3B4A5047443A1B243C3C383842382D3A4C4F533C1F465E595F
55554E4A4746504D4821374B5253524D51454843423A37202C2F2E263D4238372F293033
29264E413C3B3A41463630312D231F1E24252A2C26283A4041494C4D423E3A2327281220
27261F26261619201B221A0D162731312F292222
938887817D797474797D8430486B7A757B80767E7E7C726E68247C8A868F9DA69A989B95
888D832F5D7D8983797774646A6E6B6C75336F7067747880848A8E969690746E988C949D
999C9797A8A9AB65839A938E8E939A999FA29FA17A68989EB0B5A8AE9D9BA09A89A4548A
5E7C97A29C737B7D8BA2A06081A1A4A5A7A79C86
AFA1A1A19DA5A6A3A29BA13C8A97A0A49D968D9FA4A3938D822D8A9B989D9CA4A4A3A499
8C8B894B9B939DA1A6A39A9383867680963489898A87979D92908FA1A29277538A8D9399
9B9FA0A0A9AAAA4D9BA69EA09EA8AAA5AAACABA3825AA3A2ABAB92A3828E968F869A5A84
47909A9F99706D687093A66C7B939EA0A4A7A3A6
B1A4A19E96919CA19483853A69838F9A908883909E928577772E818F908F7E797F8B9E7E
6D76703D8E9FA2A5A4A1968B72837D8F9D309A9C9E9195938388819AA1946F5F96919C9D
90948F9EA7ADAB64A0A5A7A7A7A6A9A5A7A9A6A48D609FA3AF96AC9D82949A99929C3F4C
51868688895B68537499A15B7C81979CA5A09FA3
ABA5A59F9A919B9D8D848941788C858B8A878883978A6A61712F86939988797A7987A48B
6965563081899497938C8979768093968C4093978E838987899A8F938F8F69526562686E
6F7471798D95784F7E9795A1A5A5A7A397A6999B85689696B0B5AA959C8B979A979E3950
6492898B63485A507983833E6997A299919EA1A0
70676B6862636466535861364656545452534D474C4E373A401E515B646164625D636460
4F45372C56595A5F5B4A445146484B4B431C625E645E58525966525F5D45382F44433A32
3542505353552A251E49565848494B3D4054483B21252D162530293521202625291F0C11
1E25251B1C18191D27272D24262A322424404144
6755433918315C404F534D5C655E5D5D5A56494E7B726A67686D6B6E786D736C40606961
5F595E606061625B645E426566634B4D616E5E56595E653B426C7B787B7872757163676B
6A294A6675717E8886848A797882722B7B8594888EA69EA2A0A29F9C3E7A858F97979AA2
A39F9F98936774928E8681616A8A948D8D958B64
AFB1B4AA3E5D9353557F858F888C85847E775585BCBCBBB5B6B6B4B0B3B0B2AF5C7D8679
7169676561646B6C777D5C9A9497A3A9A8AAA4A1A2A4A9746AA5A8ABAAA3A5A4A3A4A39F
A03773A0A3A6A7A6A4A2A58F939A7F5395A29B98A0A2A7A6A5A7A99A369CA0A8AFA8A2A5
A6A59C96985C809E9A88909899878A8C8DA08B75
B3B0AFA8415988495479777F7A7C80777C734F88B6B8B3ABADA9A0A3A59AA7A562768785
637368615B53566162685595A19DA1A5A6AEA69BA0A0A5666AA7A7ACA4A1A4A2A1A2A4A2
9C3C718FA3A4A499A0A3A07E94996D52989A9B9FA5A0A3909FAAA1702593A0AAB0ADAEAB
A19E9E988B5476959A9F8B889F8A7A8EA4AA8C71
ADA8A49240487E4557827A7B7E707A797A78467EB0AA9E9E9FA09A8C90839392686F8683
6B7278858C9192867573588F96939D9EA1A2988E898B965A6AA3A1A199989D9990A3A5A2
9F35547D99A297949CA39D677A706663A3A1A2A5A6A0977780907C713E929EABA9A6A8A4
9F9E979E843F758B8B95847C91777A9F9FA8836B
806A48553D556B4D625D667767596C6F6554375697949089817675736A6450443326554F
4A514F655A5A6756514F25505A56686C606670675A525E414D7871646862665751636D6C
662F3D575C6D726F7272664B513928405659555E5E5F5A5E5B67574D2146556058575F5E
5B54544A3E2A43504553575354484448484C3238
603028545B51443E1C2253534B49361C0A515C6D686A42213B484C515B44295B5B5E5E61
4826576A71737A3F255A5A5F635C283765718177722B2B45454F53202A656C5D625F4049
686864613F1E4663626B732A477885887B662B6A818789884A426B848E8B5A0733544438
625319647B888A7D4A366D6D707C7E3E64828E94
BC6954AA94878990384997A4B0B3A3502AB2B3B8BBBC7D1A96A59B9A9A7834868475817B
5344838D948C905735A29B96A0A25561A5A6A9A9913E7C8B888C7E7951A2A2A9AB886374
A09687989E429D9B95A09E5679A0A6A7A698398CA8AAA5A45773AEB4B3B485157BA6A2A5
AB921E8B8F919CA4583597A0ADB4B44690AAB2B8
BB624DA3A6A0937F3149A49F9EABA85629AEB9BCB7B9741FA2A5908D8F722D889098907B
4733779199919A542C9DA29C9C9F5368A5A9A8A09443787B90946D4C56929AA6AEAA5877
9583848C824DA1A08E86965A7EACAAA99A9044A0B0B3B1AE6879ADB6B8B6890F6FA1A7AA
ADA61D81959DA09B4C41A7A9ABACA5438BABADB4
B76755A4A5A39D823C4C9F9E9AA4A45828ADB8B2AFB475229EA29C98946D378D99858B90
5F3D8EA4AAA4A47746A1A2A2919D5E67A7AEAFA2933B8E9F9186623A41767F8A93885179
8C7F838A8D478F9F988B9A6071A8A8A79C933AADB8B4B3B25C8BB7B9B6AA864481A5ABB1
B09F228A95A0A3A75F5CABA4917D7C378BA6AAAB
8952599B8A9A9B8C4724478A8E8B85491C4376969B625C2187878781783B274A59667685
5347788C92939049296E7A7B798C52516F7C797B6D2E75856853444833686D6369662F4C
6166636B6216004053596C44223D6E6C695A30555855484425555B66655E32155A747777
6C61284B5D69696F401C67695D4B4A3362696460
5F5A4E201325223D3F3F2C232C313A424916081521232A2D3233313C3D4040220A424942
392B3D454C4D4F56573D172E3D3A404A564D40363B51522D2144424C4143484E4E526263
5E223C556675838684787283868D6A37655164686C6E67556B7E81622C507E8886737276
726479796A414D6A6E818580735949698C883A51
A49DA0544A706A9AA1A0826D818BABAFA6400C9AA8A7A8A2A59F90889B989C6316A8A59E
947F92AEAEB0ADAFB49B21989F938A8391928E7482A3AB804DAA9B98808693959D9EA7A7
A33F5D85839595939698939E9FA2A26D9E8789A2A0A3928F8FAEB4B047ABA8A2A7A6A4A7
A2A29C96A3688AA19A919FA1997B52849EA93C68
9D94985260907494909486697E8FA6A6AA4B36A2A6A7AAAAA69F90819393966318A0A39C
967D85A6A6ACAFAFB1A1289998998A7789908F85849AA47E47A6A5897B78828E989AA6A8
A54767808B8C878489878590948C9771ADA0929C969D9C9195A5AAAF4C94A0AAAAA79EA3
A49F9DA1A34F8A9E9283969B98835184A0A44673
A9A39E5A5C9F799C9D9B98749897A5ACA85731A3ADAFAEABA7A2937D8D8D8E75189C999C
A1867CA2ABAEAFB0ACA1379B9DA29F85969A9C87849D987D5096A58B7E7C8A9A9CA3A5A8
A44958788E98857C7875828889948D6EA8A48B9F9FA4978D9AA9ABAB419AA7ACAEAFADAA
ABA999959453919B9D9D9C9CA3835C89A1A35580
9E93862D5198768E90969466817C91909C4E148B928B8987807D76685B645A480E6D7178
75745F817D7D74736D582A60707D646174726E625560653A3D737778706B606768605861
613A3B4F5672725E665C4D4437254D1B565B4F635F66544A5E5D6369225F706D70586970
686954383D4C505A6163605E5B463A4150492C34
3D33312D34383E383C200F12131310182535322A2D35313311312E2925221B22231F2327
241D13292D2231312B313F3F342A301D1D352821252F36393E33242619111E2D2F3F473E
392D3A36493D2D234F4D4F505D66665D473B4A4924475B5D5E58615A605B585457264560
6D7077788880746A6B8055306474788394999E9B
9499A7A7ABAAAFABA55B10777D7D7B8A91898B939C9AA1992F9D9495867C7F8794878F95
94752B989AA5A7A487A2A6A9AA9EA57266A6A6A49CA3A2A7A4A3A4A99147729A9B9B939C
96889693A1AC9759ADAAA3A8ADACB1AFA7AEADA75298B0A7A5A3A7A2A38D7C83A95580AF
AFADA698A69DA1A086A7764D998A9AA5AFB3B5B2
A085909C9CA1A5A59D8B2283909D9686877F8490929C9A983C92A6A3A188808B9494958E
9D8B356C727C76898A9A97A4A0A2A37F4E81887E84838B94908E9091925B5F8B8F9C9390
87848F979AA89068ABADA7A8AAABA8ACADB5B0A85BAAAEA49BA2AAABAC9B99A3A96087AD
ADADA79DA4A29EA093A8735F958894959AA5AEB1
A0878A95939E99968B7C3586959E9E8C8E7C6D8E9CA49E874298A3AAAA9889A1A3A4A6A2
A68536999FA69D80919884898C9BA2834D838784797C7F868E858D807E4F6E929098A69F
8B8F9C9D98A38C58B1B3ADB0ADACAEB2B4B7B5AD489EB0AAADAFB5AEB5ACA1A9AC5985AE
ACACA7A2A8A8A8A7A1B68568887B888186A1A8A8
A2929A9E8A8D91897B762780989DA69C9D998D80949A8365479EA2A6AB9F979DA0A49E96
927B308A999DA2837B7F6D6C6D8981554572777B796969736C6E7C76804C5E798285888D
8D7B8B8585815A2986938E8F83818285878A867F2D68827F8E898A70767E736E69314970
716F6B6555555A56534423293C373C4456625F5B
2C251A1E1211130B0D090A161A181F201D1D19131519141E382F29262525211B1A272824
1E1E171C10151A200F1D241621242D30343324231F1A132B343339352E384045413D3A22
20263339464B474D4436342F311F283326372E3C46474D4A4D4F23375C625E61636A6D67
68676E623A6D737A7F7A74716B70747A7D27668D
9B958A53AFA78484919D9DA3ADA8B5B2763C90A1A6ACA4A29E9689868B9D395C969DA997
908F8888879C9F9A2A82938C909098A09FA0A29E9E6F3AA7A5A7A19597A1A2A5A6A5A14E
6B989894A2A7ACAEAEAAA37B9144A0BBBEBCBAB9B9BFC4C3C5C74F7AB3B8B2AFB0ACACA5
8E9298844D88888B928F898B889397A09D3BA0B4
ABA7A94CAAAA9F9899A1A5A5A7ADACAE913E8D99989A9191928F93848098496F9EA6A694
8887847E83979A9124717579818E9A8E9593A4A8A6653CA4A29E9EA19A9594958E94A15C
638E9298878D9E97918D898B7F43B0BDBAB7B3BAB3B4BBBABFC16382ACACA1A3A19C9A99
7470776D4980808782847F7D7F7B859398379CA9
A69FA94DA7A7A5A2989F9E9798A7AFAC8D3F8C9BA5A7A49DA1A79F868E954666A3A8A498
8F877B787284999132747C8D8B8AA1A19F989BA39B2340A7A8A2A39D9395939E9E9EA663
567E8A99999EA49DA0A4948A9949B0C0B8B7B4B4ADA8A8ADBDCA6584A9A39C9898949291
7C7571675195989288847882807F899699298A96
ACA6984BABA79FA09897849081979B8F7940869CA8A9ACAEA9A59B9A9C8B256DA193A193
7574756E707F9994397F828A9488969B9B918D9D945542A4A9AAAAA39586799698989A68
4D788BA1A5A6949D97908B7C98539C9AACBEB0A498A095918D9E4D727E767E7572777372
5D574938335C63655B494349534D5353461C5E6A
5D473826373C383A37332C1C2126242A22103F474146484B59463633391A060D13131B19
1C1D1E191E201D1F1D171B1F201A2023192723252020212B3E3F39342C2308172B323130
2C3A3840535137241F2629373E3B3A37444B4E4C351E3B3D42434D4644443D4749491C3B
605F616B6A6270817D7C66397F797B80848C7A6F
989496999A988D98A0A0932269898596938C7E7C80919AA19E3264858688A4A398A3A09C
9C987E36879C9A9BA09DA29FA0A2A3A535817E80776E7591969391838271327B8693989C
9A9594A1A0A7A4567CAAA5A4A6A4A5A3A89A73726F50B6AB9EA3B3B3AA9E8FA5AAA452A1
9B8B7C7484767C94999472359A9A989BA08A8479
B7B0AEAEB0AEA7A5A4AAAB368FA9A9A48A77869B868BA1A49F3992A093A6A6A2928D8497
A08E794188A19DA2999D99898C98A5A939667E7E796C71777D7D7D7C7B8043817F7A8586
83908A939AA0AC607FA8A28B8682848D9B967E786344ADA8A7A2A5ABA6A4A1A4A39B469D
8D85776E7A75728993A178318C8D898FA0867A83
B7AEB1ADB4AFAAA7AAB2992A8BA4A7A2827881817E8C98A4A0379B988F9D969D9690848C
978B7E3D91A1A19F959B95979092A3A53362737F8668677278808288867F487F766E7881
7C787F7C9293AB6C7BA6A29A91939093A28C83846855AAA8B0ACAFA9A8A7A0A29D8C249C
A5866F695E6966909B9E7D48A29FA6A6AFA6A0A3
B8B3B4AAA9AEA9AAA3A09F499FA0A197897C7D78919A9BA3973D9B9992A4A0A58C907687
85837545939C93919E9E99978F949E9D456A6D817B80667475716B7C76774B6160636B71
6A737B888F969A697F8676838C8891968B7D6A664B4B8F8C8F8A8C897D7F7A7A7B5E176A
74664E3C363E364C5C5C462E444D4F41475A6664
6157614C45383E403D34291551504F43474951493C4447453F1A40493F3A3336362A1F17
18160F122A3335343A34302C1D2F311C2A241D1E211B1B232F29222E2B2C2E3432322B28
24295458523E2E393C3B3C3A343319304950574E585D5D5D5E4E4F2E2A404049484D5352
4B4F484E2E66708A9896A29A938B979685418590
857B863D56998C8F7D848796A8A39EA9A9343C7F7C83838385868E868F97945353679BA1
A4A89CA5A8A9A48EAA3C6B9A837B878F91827E7682837B167EA39CA793A0A2A7879092AB
7F5BA786A3ADB2AEA7A59C95999B4091B6B4B1ACAFB5BCBEC5C2C57397B9B5B8BABBBDC2
C1C1BCB45496B2B3B1A8A6ABACABABAEA3579CA4
ABB2B04A6B9F9B9085858A97A29EA8A8B05F5B9781827F7B77737E8179869851626491A7
A6A1839A9DA4A48EAC43718E7B797A7D7E7E7C7E7E857F208BA0A1A3979DA6A4797A86AC
975E96969D9EA2A39A9F9B919A933FB2BDB8B8B8BCBEC1C1BBC0BE6986AAAFA6A198A2A8
B7AEAEA857A3A6A3A5A4A4A4A2A5A7AB984F8B9D
AAACAA4664989C968B888B878F8D989FA758477D8A8A847A7875868678788B58625A83A5
9F9B77969B9E9F7CA13E647E74746F6F7578787D7879762E8C8A9791969EA4A687838BA4
8F4C9B999FA29FA39F9F8E9392933EB0BEBDBDBDB9BAB9B7B3B1AC54799A917675899764
A792948F5694A19F9C99989898A2A2A484368B99
AEADA341579B9F9F9A99A29F957C8C95A54E2E717784827D8A8D8B8B86868F5A4D648C96
8E926B7582918B6A692C437B7A786D717B8081786D67623E868B868686929AA79B94898B
5317858F85838B8C8784838D7F7938879C928F938782918F8E8C79406D58493B45494145
48363F3731464C554B4D484B4E49413A22132337
666C6133326066615B5C5C5A605B645A62353143433B4437352C3730372D2B2322282F31
22151612152E271E1711152B2B31493E4346483232433B121B23303F3C2C32403B322C19
1E2F372A1425353B4142162132312D33371B2F494E4E4E364B50657B8A665171706F6B64
236E746A6863292B6069767E761C73737A8F874A
76507C7A767E823536737B7A8C8B28519C9BA8AC943E6F999C9C91772895AAADA8AE5C2B
8D948F8A8A4622435A5D73833D356A6571706F302E6A79776F642F6D82758194580C7A95
928C9E7535AAAFADA49E2776ADAFB3BDB62EA5BBB9BBB7569DB8B9B6B28471A9B5B6B4A8
35A9AFA8A7A7416CA9B1B1B4A11F8077616B6C40
9354ABB0ABB0B15D70B5B7B8BCBD3662AEB3B9B7B74783B5B3AFB0832099A1A7A6A86542
A4ABA9AEAC59365A676B6E6C35357575776963282E5E6A6E686522667A72718C5C0D7A9C
9C9A946256AFB1A4958D2675A9A8B3BBB12DB0BCB9BBB95499B7BABBB98571B0B1ACA8A2
3CA8AFAAA4A44283B4B0B0B39C22877A677C864D
9456A4ABAAA49F4F79B9BCB9BABA4B68A4B4B8B9B73F86AFB0ACAF9837ABB1B1B0AB6136
99AAADAFAE5531595E5B4B673F468C87807267282F575861636125748B847E925F0D93B5
AEA4A16763B1B2B1B1AD337FA9AFB4BAB534B7B7BFBFBA549BBDBAB6B58973A09D9C927F
36A6ACABA8A33F80AEAEB0ACA637AB8B8791874A
945AA4ABA7A7A25277AFB0B0B2B85364818C9FA09A3188ADAAA6AB863BA5A7ADAD9B5A58
A3ABABB0B05E706573546073596FA499877D6F2C2E434A4A3E411C8B99908D95551C96AA
ABA3976F539FA9A9A5A338687473A8B3B23685828881753276837F7F6D41516D69665C56
285A62625B46234351524943321E3F323531301B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00744048 0.0238095 0.00744048 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02381 translate
.95238 .95238 scale
384 string
128 128 8 [128 0 0 128 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF80000000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FFFF8000
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF80000000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FFFF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000
0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF
0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF80000000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FFFF80000000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF8000FF8000FF8000FF80000000FFFF8000FF80000000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000
FF80000000FFFF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF80000000FF0000FFFF8000
FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF
FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000
0000FF0000FFFF80000000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF0000FF
0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000
0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
0000FF0000FFFF8000FF8000FF8000FF80000000FF0000FF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FF0000FFFF80000000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
FF8000FF8000FF80000000FFFF80000000FFFF80000000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FFFF8000FF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF80000000FFFF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FF0000FF
0000FF0000FF0000FFFF80000000FF0000FF0000FF0000FFFF80000000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF80000000FF0000FFFF8000FF8000FF8000FF80000000FF
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000
FF8000FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF80000000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF
0000FF0000FF0000FF0000FFFF8000FF80000000FF0000FFFF8000FF8000FF8000FF8000
FF8000FF8000FF80000000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF80000000FFFF80000000FF0000FF0000FF0000FF0000FFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF80000000FFFF8000FF8000FF8000FF80000000FF
0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
0000FF0000FFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF80000000FF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`002@3oool0
101hN7P0IVIV06IVIP2<S8`207YjNP<0TI6A00D0Z:RX08R8R02?Shl0Shn?06][J`0204E5A@0508b<
S01NGUh0Rh^;08^;R`1]KFd00P1GEeL01@1VIVH0NWYj07YjNP1jNWX0CDe=0080I6AT00@0LW9b05IF
EP1FEUH0U9BD0P1YJFT01@2GUiL0UIFE04a<C01<C4`0T92@0080CDe=0`1aLG401@1bLW80emOG08B4
Q024Q8@0GemO0080ATI600D0MGEe0:b/[03:b/X0b/[:0:BTY0020;:b/P050:FUY@2YZJT0ZJVY0:BT
Y02KVi/00P1mOGd0101UIFD0Jf][06][J`1lO7`20:JVYP050;no_`1aLG40Vi^K09^KV`2EUID00P2U
YJD01@3=cLd0Shn?0;6a/@2a/K40_kno0080ZZZZ00D0`l?304a<C01<C4`0RHV906=SH`0208^;R`04
08>3P`1eMGD0MGEe07AdM080X:2P00D0ZJVY07YjNP1fMWH0MWIf05ADE0020:^[Z`050<;2`P2/[:`0
Y:BT0:BTY01hN7P00P1ADE401@3QhN40X:2P0:2PX01lO7`0MGEe0080Hf=S00@0H61P0:VYZ@2YZJT0
]kNg0P2IVIT01@1ADE40RXZ:09>CT`2CTi<0SXj>0080RHV900D0TY:B0<C4a034a<@0MgMg04];B`02
0492@P0503hn?P1eMGD0MGEe08>3P`1GEeL00P1KFe/0101gMgL0OWin07inOP1`L70208:2PP0505aL
G01WIfL0GemO05mOG`1kNg/00P2CTi<01@2=SHd0SXj>08j>SP2JVYX0Vi^K0080_;bl00D0Ng]k09bL
W02LW9`0YZJV06e]K@0204I6AP0405aLG01OGel0GemO08f=S@80PX:200<0MGEe0?ooo`3oool0c`3o
ool000T0oooo00@0LG5a05ADE01DE5@0Ng]k0P1gMgL01@26QXH0SXj>08j>SP2_[jl0NWYj0080R8R8
00D0MWIf05=CD`1CDe<0R8R805]KF`0207UiN@0406ATI01CDe<0De=C06a/K080QXJ600D0S8b<051@
D01JFUX0FUYJ06EUI@02055AD@050820P01YJFT0JFUY09BDU02=SHd00P18B4P0102=SHd0F5QH05QH
F021PH4208J6QP0507QhN03@d=00SHf=08f=S@1XJ6P00P1;Bd/01@1gMgL0ZZZZ0<30`030`<00YZJV
0080[Zj^00D0X:2P0:FUY@2UYJD0X:2P09RHV00207]kN`0406QXJ01aLG40LG5a07IfMP80XZ:R00D0
`/;207MgM`2EUID0UIFE09nOW`020:VYZ@050;no_`1hN7P0^KVi0;Vi^@2c/k<00P2RXZ801@33`l<0
EEEE05EEE@22PX80HF5Q0080Shn?00@0QhN7079bLP1bLW80KVi^0P2`/;001@2a/K40NWYj08Z:RP2:
RXX0JFUY0080V9RH00D0_kno0;Jf]P2UYJD0YJFU07EeM@0205]KF`050=cLg02LW9`0W9bL06YZJP1f
MWH00P1dM7@0101^KVh0^;Rh0;Rh^02i^KT20:>SX`05065QH@2:RXX0WIfM09fMW@2CTi<00P2@T900
1@2DU9@0e=CD0=CDe01oOgl0BDU90080@d=300D0>3Ph06YZJP1ZJVX0M7Ad05aLG00205QHF00405iN
GP1QHF40HF5Q06EUI@80Shn?00D0Jf][06UYJ@1KFe/0Fe]K08:2PP0209FEU@0309BDU02RXZ80XZ:R
0080W9bL0P2a/K401@2ATI40Y:BT0:BTY02_[jl0NWYj0080D51@00@0IVIV05mOG`1OGel0M7Ad0P21
PH400`1jNWX0oooo0?ooo`3?0?ooo`002@3oool0101aLG40E5AD05ADE01kNg/207MgM`0508J6QP2>
SXh0SXj>0:n_[`1jNWX00P28R8P01@1fMWH0De=C05=CD`28R8P0Fe]K0080NGUi00@0I6AT05=CD`1C
De<0K6a/0P26QXH01@2<S8`0D51@05YJFP1JFUX0IFEU0080DE5A00D0P82006UYJ@1YJFT0U9BD08f=
S@0204Q8B00408f=S@1HF5P0F5QH0861P@80QXJ600D0N7Qh0=3@d02=SHd0SHf=06QXJ00204];B`05
07MgM`2ZZZX0`<300<30`02VYZH00P2^[Zh01@2PX:00YJFU0:FUY@2PX:00V9RH0080Ng]k00@0J6QX
075aL@1aLG40MWIf0P2RXZ801@32`/80MgMg09FEU@2EUID0WinO0080ZJVY00D0_kno07QhN02i^KT0
^KVi0;>c/`020::RXP050<?3``1EEED0EEEE08:2PP1QHF400P2?Shl01027QhL0LW9b079bLP1^KVh2
0;2`/0050;6a/@1jNWX0RXZ:08Z:RP1YJFT00P2HV9P01@2o_kl0][Jf0:FUY@2UYJD0MGEe0080Fe]K
00D0g=cL09bLW02LW9`0JVYZ07IfMP0207AdM00406i^KP2h^;P0^;Rh0;Vi^@80Xj>S00D0HF5Q08Z:
RP2MWId0WIfM09>CT`02092@T00509BDU03De=@0e=CD07moO`19BDT00P13@d<01@0h>3P0JVYZ06YZ
JP1dM7@0G5aL0080F5QH00@0GUiN065QH@1QHF40IFEU0P2?Shl01@1[Jf/0JFUY05]KF`1KFe/0PX:2
0080UIFE00<0U9BD0::RXP2RXZ800P2LW9`20;6a/@05096AT@2TY:@0Y:BT0:n_[`1jNWX00P1@D500
101VIVH0GemO05mOG`1dM7@20861P@0307YjNP3oool0oooo0<l0oooo00090?ooo`0407moO`1PH600
H61P0861P@80L71`00D0QHF507UiN@1iNGT0QhN705eMG@0207AdM00506IVIP0m?Cd0?Cdm07AdM01M
GEd00P28R8P0101PH600EUIF05IFEP1=CDd206=SH`0509RHV01MGEd0EUIF05IFEP1MGEd00P18B4P0
1@1nOWh0Lg=c07=cL`2KVi/0SXj>0080Bd];00@0UIFE05aLG01LG5`0MgMg0P1fMWH01@1nOWh0dM7A
08>3P`23Ph<0JFUY0080De=C00D0LG5a0:6QX@2c/k<0/k>c09bLW0020:FUY@0509ZJVP2][Jd0[Jf]
09RHV02IVIT00P2>SXh0101mOGd0QHF508F5Q@25QHD20;6a/@050<[:bP1aLG40Zj^[0:^[Z`2EUID0
0P2RXZ801@2k^k/0O7al0;fm_@2m_Kd0[Zj^0080YJFU00D0clo?05aLG01LG5`0P82005mOG`0207in
OP0407]kN`1XJ6P0J6QX06a/K080Y:BT00D0XZ:R07IfMP1nOWh0OWin075aL@0208N7Q`050<K6aP2n
_[h0[:b/0:b/[01cLg<00P1OGel01@3AdM40U9BD09BDU01MGEd0Ph>30080NGUi00@0MgMg0::RXP2R
XZ80^KVi0P2][Jd01@1ZJVX0Ogmo0:6QX@2QXJ40Rh^;0080Q8B400@0U9BD0=OGe`3GemL0Ph>30`14
A4@0100a<C40I6AT06ATI02=SHd306EUI@0405eMG@1WIfL0IfMW071`L080MWIf00D0De=C06MWI`1N
GUh0GUiN07QhN00208j>SP0507moO`2FUYH0UYJF09JFUP2UYJD00P2m_Kd01@2RXZ80_[jn0;jn_P2Y
ZJT0Jf][0080Cdm?00@0NWYj06m_K`1_Kfl0KVi^0P1nOWh00`1bLW80oooo0?ooo`3?0?ooo`002@3o
ool0101[Jf/0EUIF05IFEP1mOGd2071`L00507inOP1eMGD0MGEe0:BTY01YJFT00P25QHD01@1QHF40
@d=304=3@`21PH40GUiN0080MGEe00@0DE5A05UIF@1IFET0F5QH0P1bLW801@1kNg/0GEeM04U9B@19
BDT0EeMG0080?Cdm00D0NWYj079bLP1bLW80VIVI08b<S00204Y:BP0408Z:RP1LG5`0G5aL07QhN080
MWIf00D0MgMg0<30`02;Rh/0Rh^;06][J`0204Y:BP0507alO02WYjL0[:b/0:b/[02[Zj/00P2h^;P0
1@2NWYh0WIfM09fMW@2ATI40VIVI0080OGem00@0KVi^06YZJP1ZJVX0Kfm_0P2HV9P01@2m_Kd0LG5a
0:2PX02PX:00Shn?0080WIfM00D0^KVi07IfMP2i^KT0^KVi0:6QX@0209ZJVP050;no_`1MGEd0GEeM
08:2PP1WIfL00P26QXH0101mOGd0GemO05mOG`1LG5`20::RXP050;^k^`1aLG40QXJ608J6QP25QHD0
0P21PH401@33`l<0]KFe0:j^[P2^[Zh0JFUY0080MWIf00D0_;bl08b<S02<S8`0GUiN07QhN00207If
MP0406e]K@2EUID0UIFE0<S8b080ZJVY00D0Hf=S0861P@2CTi<0Ti>C06QXJ002071`L00507moO`2m
_Kd0_Kfm07QhN00k>c/00P0n?Sh01@0`<300F5QH05QHF020P800KFe]0080L71`00@0NGUi08F5Q@25
QHD0Jf][0P1nOWh01@1JFUX0GemO04a<C01<C4`0Kfm_0080Ogmo00D0MgMg0:RXZ02XZ:P0IFEU07in
OP0207EeM@0506YZJP1oOgl0Ogmo09VIV@1^KVh00P1GEeL0101JFUX0Lg=c07=cL`22PX8207YjNP03
07moO`3oool0oooo0<l0oooo00090?ooo`0406][J`1FEUH0EUIF07emO@80L71`00D0OWin07EeM@1e
MGD0Y:BT06UYJ@0208F5Q@05065QH@13@d<0@d=30861P@1NGUh00P1eMGD0101ADE40FEUI05UIF@1H
F5P2079bLP0507]kN`1MGEd0BDU904U9B@1GEeL00P0m?Cd01@1jNWX0LW9b079bLP2IVIT0S8b<0080
BTY:00@0RXZ:05aLG01LG5`0N7Qh0P1fMWH01@1gMgL0`<3008^;R`2;Rh/0Jf][0080BTY:00D0O7al
0:NWY`2/[:`0[:b/0:^[Z`020;Rh^00509jNWP2MWId0WIfM096AT@2IVIT00P1mOGd0101^KVh0JVYZ
06YZJP1_Kfl209RHV0050;fm_@1aLG40X:2P0:2PX02?Shl00P2MWId01@2i^KT0MWIf0;Vi^@2i^KT0
XJ6Q0080VYZJ00D0_kno05eMG@1MGEd0PX:206MWI`0208J6QP0407emO@1OGel0GemO05aLG080XZ:R
00D0^k^k075aL@26QXH0QXJ608F5Q@020861P@050<?3``2e]KD0[Zj^0:j^[P1YJFT00P1fMWH01@2l
_;`0S8b<08b<S01NGUh0N7Qh0080MWIf00@0KFe]09FEU@2EUID0b<S80P2YZJT01@1SHf<0PH6109>C
T`2CTi<0J6QX0080L71`00D0Ogmo0;fm_@2m_Kd0N7Qh03/k>`0203hn?P05030`<01HF5P0F5QH0820
P01]KFd00P1`L700101iNGT0QHF508F5Q@1[Jf/207inOP0505YJFP1OGel0C4a<04a<C01_Kfl00P1o
Ogl01@1gMgL0Z:RX0:RXZ01UIFD0OWin0080MGEe00D0JVYZ07moO`1oOgl0VIVI06i^KP0205MGE`04
05YJFP1cLg<0Lg=c08:2PP80NWYj00<0Ogmo0?ooo`3oool04`3ooon90000o`030?n000000?l0003o
0240003o3`3oool000T0oooo00@0MgMg06MWI`1WIfL0QhN70P21PH401@2DU9@0R8R808R8R02MWId0
GemO0080R8R800D0MWIf04m?C`1?Cdl0Rh^;069RHP0209JFUP0406ATI01eMGD0MGEe06ATI080O7al
00D0Ph>306MWI`1@D500D51@05mOG`020492@P0507inOP1[Jf/0Jf][092@T02;Rh/00P1;Bd/01022
PX80GemO05mOG`1gMgL2075aL@0507MgM`3@d=00VYZJ09ZJVP1XJ6P00P17AdL00`1jNWX0];Bd0;no
_`020;no_`80]kNg00D0W9bL09fMW@2MWId0UiNG09RHV00208J6QP0407alO01fMWH0MWIf071`L080
V9RH00D0[:b/06a/K02IVIT0VIVI09FEU@020:RXZ0050;Bd]01nOWh0a<C40<C4a02/[:`00P2SXj<0
1@35aLD0FUYJ05YJFP20P800Hf=S0080Ogmo00@0O7al06a/K01/K6`0Kfm_0P2OWil01@2m_Kd0Ti>C
08R8R028R8P0Q8B40080SHf=00D0_;bl0;:b/P2WYjL0YjNW06IVIP02075aL@050;^k^`2:RXX0RXZ:
05]KF`25QHD00P29RHT0101jNWX0X:2P0:2PX036a/H20:6QX@05071`L01/K6`0U9BD09BDU01QHF40
0P22PX801@1mOGd0[Zj^0:j^[P1aLG40=SHf0080=3@d00D0<C4a04i>CP1>CTh0L71`07=cL`0206a/
K00408V9R@21PH40PH6107UiN@80UiNG00D0JVYZ07EeM@1KFe/0Fe]K07QhN00206i^KP0507UiN@2R
XZ80XZ:R07YjNP2TY:@00P2RXZ801@20P800YjNW0:NWY`2d];@0Ng]k0080G5aL00@0DU9B06][J`1[
Jf/0Ng]k0P29RHT00`1fMWH0oooo0?ooo`0C0?ooo`@0003o1`3oP00`0000o`T0oh00EP000?l70?n0
00`0003o3`3oool000T0oooo00@0P820061PH01PH600RXZ:0P1dM7@01@2?Shl0PH610861P@2b/[80
Jf][0080SHf=00D0NGUi05EEE@1EEED0R8R806EUI@02096AT@04055AD@1MGEd0GEeM06ATI080Q8B4
00D0TY:B06i^KP1MGEd0GEeM05UIF@0205ADE00507emO@1ZJVX0JVYZ09bLW02JVYX00P1:BTX01023
Ph<0EUIF05IFEP1aLG4206MWI`050861P@3<c<`0OGem07emO@1MGEd00P11@D400`1lO7`0[Zj^0;bl
_0020;bl_080^[Zj00D0VYZJ09FEU@2EUID0VYZJ0::RXP0208B4Q00407alO01_Kfl0Kfm_07QhN080
VYZJ00D0^;Rh07UiN@2NWYh0WYjN07AdM0020;jn_P050;Vi^@23Ph<0^KVi0;Vi^@2/[:`00P2XZ:P0
1@30`<00EUIF05IFEP22PX80H61P0080OGem00@0S8b<05ADE01DE5@0GEeM0P2EUID01@32`/80OWin
0820P020P800M7Ad0080Q8B400D0`l?30;^k^`38b<P0b<S807UiN@0207inOP050<G5a@23Ph<0Ph>3
05MGE`2;Rh/00P26QXH0101jNWX0YjNW0:NWY`39bLT20;Ng]`0506m_K`2:RXX0VYZJ09ZJVP1aLG40
0P2FUYH01@2=SHd0^KVi0;Vi^@1mOGd0@T9200<0?3`l0P1CDe<0101iNGT0O7al06i^KP1^KVh308^;
R`0308:2PP2EUID0UIFE0080JFUY0P1hN7P0101kNg/0UiNG09NGU`2EUID20;:b/P0508N7Q`2/[:`0
T92@092@T028R8P00P2MWId01@2_[jl0O7al051@D01@D500GemO0080I6AT00@0NGUi08>3P`23Ph<0
J6QX5@3oool40000o`L0oh00<0000?l90?n005H0003o1`3oP00<0000o`l0oooo00090?ooo`040820
P01PH600H61P08Z:RP80M7Ad00D0Shn?0861P@21PH40/[:b06][J`0208f=S@0507UiN@1EEED0EEEE
08R8R01UIFD00P2ATI40101ADE40GEeM05eMG@1TI6@208B4Q00509:BTP1^KVh0GEeM05eMG@1IFET0
0P1DE5@01@1mOGd0JVYZ06YZJP2LW9`0VYZJ0080BTY:00@0Ph>305IFEP1FEUH0LG5a0P1WIfL01@21
PH40c<c<07emO@1mOGd0GEeM0080@D5100<0O7al0:j^[P2l_;`00P2l_;`20;Zj^P0509ZJVP2EUID0
UIFE09ZJVP2RXZ800P24Q8@0101lO7`0Kfm_06m_K`1hN7P209ZJVP050;Rh^01iNGT0WYjN09jNWP1d
M7@00P2n_[h01@2i^KT0Ph>30;Vi^@2i^KT0[:b/0080Z:RX00D0`<3005IFEP1FEUH0PX:2061PH002
07emO@0408b<S01DE5@0E5AD05eMG@80UIFE00D0`/;207inOP20P800P82007AdM00208B4Q0050<?3
``2k^k/0b<S80<S8b01iNGT00P1nOWh01@35aLD0Ph>308>3P`1GEeL0Rh^;0080QXJ600@0NWYj0:NW
Y`2WYjL0bLW90P2g]kL01@1_Kfl0RXZ:09ZJVP2JVYX0LG5a0080UYJF00D0SHf=0;Vi^@2i^KT0OGem
0492@P0303`l?080De=C00@0NGUi07alO01^KVh0KVi^0`2;Rh/00`22PX80UIFE09FEU@0206UYJ@80
N7Qh00@0Ng]k09NGU`2GUiL0UIFE0P2b/[801@27QhL0[:b/092@T02@T900R8R80080WIfM00D0[jn_
07alO01@D500D51@05mOG`0206ATI00407UiN@23Ph<0Ph>306QXJ1D0oooo?@000?l30?n005L0003o
2`3oP00;0000o`l0oooo00090?ooo`0408J6QP1^KVh0KVi^08^;R`80K6a/00D0Ogmo07]kN`1kNg/0
[:b/05iNGP02071`L00506YZJP13@d<0@d=30820P01ZJVX00P20P800100n?Sh0GUiN05iNGP1DE5@2
07MgM`0508n?S`1ZJVX0HF5Q065QH@1IFET00P17AdL01@1iNGT0IFEU06EUI@2DU9@0WYjN0080BTY:
00@0R8R805]KF`1KFe/0SHf=0P1lO7`01@1oOgl0d];B08B4Q024Q8@0FUYJ0080=cLg00D0I6AT09BD
U02VYZH0YZJV09^KV`020:b/[00509nOW`2PX:00X:2P09fMW@2VYZH00P23Ph<0101eMGD0LG5a075a
L@1aLG4209ZJVP050:JVYP1ZJVX0XZ:R0::RXP1gMgL00P2a/K401@35aLD0Ogmo0;Ng]`2g]kL0Zj^[
0080WinO00D0]KFe04i>CP1>CTh0MGEe05eMG@0207AdM00407QhN01_Kfl0Kfm_06EUI@80WIfM00D0
/[:b07]kN`1oOgl0Ogmo08F5Q@0209VIV@050;fm_@2YZJT0/k>c0;>c/`1eMGD00P1gMgL01@2j^[X0
TY:B09:BTP1SHf<0S8b<0080PH6100@0MGEe0::RXP2RXZ80alO70P2OWil01@1CDe<0][Jf0:VYZ@2Y
ZJT0KFe]0080Shn?00D0TY:B0<[:bP3:b/X0Ogmo04E5A@0203Lg=`0503dm?@1:BTX0BTY:07=cL`1j
NWX00P1`L7001028R8P0T92@092@T01lO7`209NGU`0506UYJ@1gMgL0Jf][06][J`1cLg<00P1oOgl0
1@1jNWX0UYJF09JFUP1bLW80VYZJ0080RHV900D0QhN709nOW`2OWil0/K6a08J6QP02055AD@0406MW
I`1YJFT0JFUY0861P@80IVIV00<0O7al0?ooo`3oool04`3ooonE0000o`030?n000000?l0003o00<0
003o1P3oP00<0000o`l0oooo00090?ooo`0407moO`1LG5`0G5aL0820P080IfMW00D0OWin08f=S@2=
SHd0`L7106UYJ@0209>CT`0506IVIP11@D40@D5108F5Q@1MGEd00P2>SXh0101:BTX0GemO05mOG`1X
J6P206YZJP0508>3P`1nOWh0GUiN05iNGP1HF5P00P15ADD01@1WIfL0Kfm_06m_K`2NWYh0VIVI0080
BDU900@0Ph>3061PH01PH600QXJ60P1eMGD01@20P800e=CD08b<S02<S8`0I6AT0080@D5100D0QXJ6
0<71`@3:b/X0b/[:0:n_[`020;Jf]P0509ZJVP2HV9P0V9RH09nOW`2CTi<00P1gMgL0101dM7@0I6AT
06ATI01dM7@209ZJVP050;2`/01NGUh0SXj>08j>SP2ATI400P2YZJT01@39bLT0Ogmo0:j^[P2^[Zh0
/;2`0080Vi^K00D0/[:b04];B`1;Bd/0MWIf061PH00207alO00407moO`1MGEd0GEeM06][J`80TY:B
00<0_kno07alO023Ph<00P23Ph<209NGU`050<71`@2a/K40`<300<30`01gMgL00P1nOWh01@2h^;P0
QhN708N7Q`1PH600SXj>0080JVYZ00@0MGEe09bLW02LW9`0alO70P2XZ:P01@1SHf<0P8200:2PX02P
X:00Hf=S0080PX:200D0Rh^;0<;2`P32`/80O7al04A4A00203hn?P<0@T9200D0KVi^07alO01_Kfl0
Kfm_06a/K00208F5Q@0506m_K`2=SHd0SHf=06EUI@1WIfL00P1SHf<0101iNGT0M7Ad07AdM023Ph<2
0;^k^`0508J6QP2o_kl0PH610861P@2;Rh/00P2UYJD01@2^[Zh0OWin055AD@1ADE40JFUY0080L71`
00@0QXJ608j>SP2>SXh0OGem5@3ooomU0000o`80oh00;0000?l60?n001@0003o3`3oool000T0oooo
00@0RHV907IfMP1fMWH0V9RH0P1]KFd01@22PX80Ogmo07moO`2`/;00I6AT0080Lg=c00D0K6a/04Y:
BP1:BTX0SHf=069RHP0209FEU@04051@D01MGEd0GEeM07QhN080S8b<00D0Ti>C06e]K@1DE5@0E5AD
04i>CP02059BDP0506EUI@1cLg<0Lg=c09jNWP2OWil00P1@D5001022PX80GemO05mOG`1lO7`206m_
K`0507alO036a/H0OWin07inOP1KFe/00P0n?Sh01@1gMgL0][Jf0<K6aP36a/H0]KFe0080]kNg00D0
Y:BT09RHV02HV9P0Vi^K08B4Q00307AdM080MGEe00D0TI6A0:j^[P2^[Zh0a/K607MgM`0209ZJVP05
09VIV@2XZ:P0Z:RX0<[:bP22PX800P2g]kL0102n_[h0XJ6Q0:6QX@2a/K4204i>CP0508B4Q01WIfL0
PX:208:2PP23Ph<00`1SHf<209:BTP050;no_`26QXH0OWin07inOP1fMWH00P20P8001@2^[Zh0`L71
0;6a/@2a/K40NWYj0080Ng]k00D0ZJVY08R8R028R8P0GEeM08B4Q002075aL@04071`L02ATI40TI6A
0;bl_080/;2`00D0Lg=c0820P02EUID0UIFE06IVIP0207YjNP0508Z:RP34a<@0a<C40861P@1:BTX0
0P0j>SX303lo?`0506UYJ@1bLW80MWIf07IfMP26QXH00P2:RXX01@1`L700S8b<08b<S01WIfL0G5aL
0080GemO00@0Ph>309RHV02HV9P0TI6A0P35aLD01@1lO7`0^k^k07=cL`1cLg<0P8200080TY:B00D0
Shn?06MWI`1ADE40DE5A059BDP0206e]K@0409FEU@2DU9@0U9BD07UiNAD0ooooI@000?l20?n002`0
003o1P3oP00D0000o`l0oooo00090?ooo`0408V9R@1fMWH0MWIf09RHV080KFe]00D0PX:207moO`1o
Ogl0/;2`06ATI00207=cL`0506a/K01:BTX0BTY:08f=S@1RHV800P2EUID0101@D500GEeM05eMG@1h
N7P208b<S00509>CT`1]KFd0E5AD05ADE01>CTh00P1BDU801@1UIFD0Lg=c07=cL`2NWYh0WinO0080
D51@00@0PX:205mOG`1OGel0O7al0P1_Kfl01@1lO7`0a/K607inOP1nOWh0Fe]K0080?Shn00D0MgMg
0;Jf]P36a/H0a/K60;Fe]@020;Ng]`050:BTY02HV9P0V9RH09^KV`24Q8@00`1dM7@207EeM@05096A
T@2^[Zh0[Zj^0<K6aP1gMgL00P2JVYX01@2IVIT0Z:RX0:RXZ03:b/X0PX:20080]kNg00@0_[jn0:6Q
X@2QXJ40/K6a0P1>CTh01@24Q8@0IfMW08:2PP22PX80Ph>300<0Hf=S0P2BTY801@2o_kl0QXJ607in
OP1nOWh0MWIf0080P82000D0[Zj^0<71`@2a/K40/K6a07YjNP0207]kN`050:VYZ@28R8P0R8R805eM
G@24Q8@00P1aLG40101`L700TI6A096AT@2l_;`20;2`/00507=cL`20P800UIFE09FEU@1VIVH00P1j
NWX01@2:RXX0a<C40<C4a021PH40BTY:0080>SXj0`0o?cl01@1YJFT0LW9b07IfMP1fMWH0QXJ60080
RXZ:00D0L71`08b<S02<S8`0IfMW05aLG00205mOG`0408>3P`2HV9P0V9RH096AT@80aLG500D0O7al
0;^k^`1cLg<0Lg=c0820P00209:BTP0508n?S`1WIfL0DE5A055AD@1BDU800P1]KFd0102EUID0U9BD
09BDU01iNGTE0?ooo`D0003o0P3oP00W0000o`L0oh00H0000?l50?n001<0003o3`3oool000T0oooo
00@0Ng]k05iNGP1NGUh0P8200P1CDe<01@27QhL0S8b<08b<S02j^[X0MgMg0080PX:200D0LW9b04m?
C`1?Cdl0Ti>C05mOG`0209bLW00404e=C@1JFUX0FUYJ07]kN`80OWin00D0TY:B07EeM@1LG5`0G5aL
04a<C00204M7A`0506=SH`1_Kfl0Kfm_09BDU02LW9`00P15ADD0101oOgl0CDe=04e=C@1aLG420861
P@0508>3P`3Fe]H0QhN708N7Q`1OGel00P12@T801@1[Jf/0UiNG0:RXZ02XZ:P0Xj>S0080XZ:R00D0
Rh^;096AT@2ATI40TI6A0820P0020861P@0406MWI`1YJFT0JFUY08>3P`80V9RH00<0YJFU07QhN02H
V9P00P2HV9P20:ZZZP050;no_`1jNWX0Zj^[0:^[Z`2d];@00P2NWYh01@2o_kl0=cLg03Lg=`1aLG40
Hf=S0080Ph>300@0QHF506UYJ@1YJFT0Hf=S0P2XZ:P01@34a<@0VYZJ07UiN@1iNGT0P8200080Ogmo
00D0/;2`0;Jf]P2e]KD0]KFe092@T00208B4Q00509^KV`2;Rh/0Rh^;07YjNP29RHT00P1hN7P0101a
LG40UYJF09JFUP3:b/X20:f][@0506ATI01kNg/0UiNG09NGU`1OGel00P1JFUX01@1gMgL0aLG50<G5
a@1nOWh0ATI60080>3Ph00D0>CTi03dm?@0m?Cd0FUYJ04m?C`0205]KF`0405iNGP1lO7`0O7al061P
H080TI6A00D0I6AT06UYJ@1UIFD0IFEU07IfMP020820P00506UYJ@2FUYH0UYJF06e]K@2g]kL00P1c
Lg<01@2BTY80WIfM09fMW@2BTY80MgMg0080Bd];00@0C4a<06EUI@1UIFD0NWYj0P27QhL00`23Ph<0
oooo0?ooo`0C0?ooo`D0003o0P3oP00W0000o`D0oh003P000?l30?n006T0003o3`3oool000T0oooo
00@0OGem06ATI01TI6@0Shn?0P1OGel01@26QXH0Kfm_06m_K`1jNWX0MGEe0080LW9b00D0IFEU04=3
@`13@d<0Ogmo061PH00209ZJVP0404a<C01FEUH0EUIF08j>SP80QHF500D0SXj>06ATI01;Bd/0Bd];
04I6AP0204Y:BP0505mOG`1hN7P0N7Qh09VIV@2MWId00P19BDT01029RHT0FEUI05UIF@1]KFd207=c
L`0506e]K@2k^k/0Ng]k07]kN`1DE5@00P0m?Cd01@1[Jf/0W9bL0:b/[02/[:`0Xj>S0080/;2`00D0
Vi^K09fMW@2MWId0UiNG08j>SP0208Z:RP0406][J`1`L700L71`07]kN`80VIVI00D0`/;20820P02K
Vi/0Vi^K092@T0020:VYZ@050<30`023Ph<0YZJV0:JVYP2LW9`00P2HV9P01@2j^[X0>CTi03Ti>@1U
IFD0CTi>0080IfMW00@0IFEU05iNGP1NGUh0IFEU0P2DU9@01@2ZZZX0SHf=05aLG01LG5`0Kfm_0080
OWin00D0YjNW0<;2`P2d];@0];Bd08B4Q00207emO@0409ZJVP2NWYh0WYjN08f=S@<0Ng]k00@0Hf=S
08f=S@2=SHd0][Jf0P2TY:@01@1HF5P0Shn?08B4Q024Q8@0MGEe0080Fe]K00D0L71`0;Fe]@2e]KD0
Ti>C04a<C00203Xj>P0503Ph>01?Cdl0Cdm?06=SH`1/K6`00P1ZJVX0101fMWH0LW9b079bLP1PH602
079bLP0505eMG@1>CTh0G5aL05aLG01lO7`00P28R8P01@26QXH0Zj^[0:^[Z`2BTY80clo?0080KFe]
00D0QhN708b<S02<S8`0O7al06MWI`02051@D00405eMG@1OGel0GemO06EUI@<0L71`5@3oool00`3o
P000003o0000o`020000o`80oh00;0000?l20?n000/0003o103oP0130000o`H0oh0020000?l40?n0
00D0003o0`3oP0080000o`@0oh003`3oool000T0oooo00@0OGem06ATI01TI6@0Shn?0P1OGel01@26
QXH0Kfm_06m_K`1jNWX0MGEe0080LW9b00D0IFEU04=3@`13@d<0Ogmo061PH00209ZJVP0404a<C01F
EUH0EUIF08j>SP80QHF500D0SXj>06ATI01;Bd/0Bd];04I6AP0204Y:BP0505mOG`1hN7P0N7Qh09VI
V@2MWId00P19BDT01029RHT0FEUI05UIF@1]KFd207=cL`0506e]K@2k^k/0Ng]k07]kN`1DE5@00P0m
?Cd01@1[Jf/0W9bL0:b/[02/[:`0Xj>S0080/;2`00D0Vi^K09fMW@2MWId0UiNG08j>SP0208Z:RP04
06][J`1`L700L71`07]kN`80VIVI00D0`/;20820P02KVi/0Vi^K092@T0020:VYZ@050<30`023Ph<0
YZJV0:JVYP2LW9`00P2HV9P01@2j^[X0>CTi03Ti>@1UIFD0CTi>0080IfMW00@0IFEU05iNGP1NGUh0
IFEU0P2DU9@01@2ZZZX0SHf=05aLG01LG5`0Kfm_0080OWin00D0YjNW0<;2`P2d];@0];Bd08B4Q002
07emO@0409ZJVP2NWYh0WYjN08f=S@<0Ng]k00@0Hf=S08f=S@2=SHd0][Jf0P2TY:@01@1HF5P0Shn?
08B4Q024Q8@0MGEe0080Fe]K00D0L71`0;Fe]@2e]KD0Ti>C04a<C00203Xj>P0503Ph>01?Cdl0Cdm?
06=SH`1/K6`00P1ZJVX0101fMWH0LW9b079bLP1PH602079bLP0505eMG@1>CTh0G5aL05aLG01lO7`0
0P28R8P01@26QXH0Zj^[0:^[Z`2BTY80clo?0080KFe]00D0QhN708b<S02<S8`0O7al06MWI`02051@
D00405eMG@1OGel0GemO06EUI@<0L71`5@3oool00`3oP000003o0000o`020000o`80oh00;0000?l2
0?n000/0003o103oP0130000o`H0oh0020000?l40?n000D0003o0`3oP0080000o`@0oh003`3oool0
00T0oooo00@0PX:2075aL@1aLG40Shn?0P1BDU801@1fMWH0Lg=c07=cL`2>SXh0J6QX0080LG5a00D0
IfMW04E5A@15ADD0N7Qh05]KF`0208j>SP0404U9B@1BDU80DU9B09JFUP80PX:200D0VIVI071`L01P
H600H61P05MGE`0205eMG@0506ATI01aLG40LG5a08b<S02KVi/00P0o?cl01025QHD0Cdm?04m?C`1W
IfL207AdM00507YjNP3;bl/0Rh^;08^;R`1[Jf/00P16ATH01@1mOGd0^;Rh0;^k^`2k^k/0[Jf]0080
ZZZZ00D0Rh^;09NGU`2GUiL0UYJF08J6QP0208F5Q@04069RHP1aLG40LG5a07YjNP80Vi^K00D0bl_;
07MgM`2IVIT0VIVI08N7Q`020:JVYP050;^k^`2KVi/0Zj^[0:^[Z`2c/k<00P2NWYh01@33`l<0@D51
0451@@20P800LG5a0080RHV900@0Ph>305eMG@1MGEd0Fe]K0P2g]kL01@2e]KD0RHV905eMG@1MGEd0
HF5Q0080R8R800D0[:b/0=?Cd`2_[jl0[jn_08N7Q`0207MgM`0508b<S02KVi/0Vi^K0:>SX`1`L700
0P1PH600101JFUX0Lg=c07=cL`2a/K4209fMW@0506=SH`2KVi/0X:2P0:2PX01iNGT00P1HF5P01@1f
MWH0`l?30<?3``2YZJT0EEEE0080BDU900D0>CTi05MGE`1GEeL0Ng]k071`L00207UiN@0406m_K`1d
M7@0M7Ad06i^KP80L71`00D0NGUi06=SH`1gMgL0MgMg06i^KP0207moO`0509ZJVP2KVi/0Vi^K092@
T02[Zj/00P18B4P01@1hN7P0UIFE09FEU@2FUYH0PH610080IVIV00@0FEUI06YZJP1ZJVX0JFUY0P2;
Rh/00`24Q8@0oooo0?ooo`0C0?ooo`D0003o103oP00P0000o`030?n000000?l0003o00H0003o1`3o
P0070000o`80oh005P000?l30?n000030000o`3oP000oh000080oh0090000?l70?n000X0003o1@3o
P0040000o`030?n000000?l0003o00`0003o3`3oool000T0oooo00@0Q8B4079bLP1bLW80UIFE0P1O
Gel01@1mOGd0MgMg07MgM`2:RXX0DU9B0080IVIV00D0HV9R04M7A`17AdL0M7Ad06MWI`02092@T0<0
B4Q800D0Rh^;07YjNP1jNWX0TY:B06QXJ00205EEE@0404Q8B01;Bd/0Bd];04m?C`80OGem00D0UYJF
08b<S013@d<0@d=307]kN`02055AD@05069RHP1XJ6P0J6QX07emO@36a/H00P2ATI401@1MGEd0?Shn
03hn?P1bLW80^;Rh0080][Jf00@0Y:BT0;>c/`2c/k<0Vi^K0P2@T9001@2HV9P0SHf=07]kN`1kNg/0
E5AD0080IVIV00D0MGEe08^;R`2;Rh/0YZJV06=SH`0208N7Q`0508V9R@2d];@0];Bd0<71`@2PX:00
0P2ZZZX01030`<00[Zj^0:j^[P2`/;0203lo?`05079bLP1LG5`0I6AT06ATI01cLg<00P1]KFd01@1>
CTh0Vi^K09^KV`2h^;P0Z:RX0080M7Ad00D0GemO08b<S02<S8`0]kNg0<S8b0020;6a/@0408b<S01b
LW80LW9b096AT@80/K6a00D0Vi^K06YZJP1_Kfl0Kfm_06=SH`0209RHV0050<O7a`2PX:00X:2P07Qh
N02DU9@00P2FUYH0102=SHd0IfMW06MWI`1cLg<20<K6aP050;2`/01KFe/0ATI604I6AP0l?3`00P1=
CDd01@1gMgL0K6a/07YjNP1jNWX0FUYJ0080J6QX00D0GemO06MWI`1WIfL0RXZ:06=SH`0206QXJ004
07=cL`2;Rh/0Rh^;09RHV080QhN700D0S8b<0:b/[01@D500D51@08j>SP020:2PX00509NGU`1nOWh0
O7al07alO01/K6`00P1TI6@0101[Jf/0Ng]k07]kN`1bLW8E0?oooaP0003o0`3oP00>0000o`80oh00
0P000?l20?n002D0003o1`3oP00c0000o`@0oh0010000?l50?n000@0003o0P3oP0070000o`80oh00
0`000?l?0?ooo`002@3oool0101fMWH0JVYZ06YZJP23Ph<205QHF00508B4Q021PH40PH6109:BTP1Q
HF400P1aLG401@1KFe/0@d=304=3@`1[Jf/0JFUY0080OGem0`18B4P01@2@T900LG5a075aL@2:RXX0
LG5a0080Hf=S00@0BDU9065QH@1QHF40GUiN0P22PX801@2JVYX0UIFE04a<C01<C4`0Ogmo0080E5AD
00D0Jf][06=SH`1SHf<0QhN70;^k^`0208N7Q`0405QHF00d=3@0=3@d06MWI`<0YZJV00@0Xj>S0:f]
[@2][Jd0XJ6Q0P2FUYH01@2JVYX0Rh^;06][J`1[Jf/0De=C0080KFe]00D0NGUi09BDU02DU9@0^k^k
06ATI00208n?S`0508R8R02c/k<0/k>c0<O7a`2VYZH00P2KVi/0102h^;P0^KVi0;Vi^@34a<@204m?
C`05096AT@1kNg/0M7Ad07AdM01iNGT00P1cLg<01@1/K6`0Rh^;08^;R`2_[jl0WinO0080OWin00D0
F5QH08f=S@2=SHd0[Zj^0=[JfP020;bl_004071`L01UIFD0IFEU09^KV`80_[jn00D0VIVI06][J`1a
LG40LG5a07=cL`020:RXZ0050<;2`P2[Zj/0Zj^[07UiN@2XZ:P00P2VYZH0102JVYX0JFUY06UYJ@1h
N7P20;:b/P050;Jf]P1BDU80?Shn03hn?P1:BTX00P16ATH01@21PH40Lg=c06m_K`1_Kfl0IfMW0080
Lg=c00D0IFEU069RHP1RHV80NGUi06YZJP0205EEE@0406=SH`1bLW80LW9b07inOP80SHf=00D0WYjN
0:VYZ@1:BTX0BTY:08R8R00208f=S@0508B4Q01gMgL0HV9R069RHP1JFUX00P1eMGD0101WIfL0QhN7
08N7Q`1jNWXE0?oooaP0003o0`3oP00>0000o`80oh000P000?l20?n002D0003o1`3oP00c0000o`@0
oh0010000?l50?n000@0003o0P3oP0070000o`80oh000`000?l?0?ooo`002@3oool0101fMWH0JVYZ
06YZJP23Ph<205QHF00508B4Q021PH40PH6109:BTP1QHF400P1aLG401@1KFe/0@d=304=3@`1[Jf/0
JFUY0080OGem0`18B4P01@2@T900LG5a075aL@2:RXX0LG5a0080Hf=S00@0BDU9065QH@1QHF40GUiN
0P22PX801@2JVYX0UIFE04a<C01<C4`0Ogmo0080E5AD00D0Jf][06=SH`1SHf<0QhN70;^k^`0208N7
Q`0405QHF00d=3@0=3@d06MWI`<0YZJV00@0Xj>S0:f][@2][Jd0XJ6Q0P2FUYH01@2JVYX0Rh^;06][
J`1[Jf/0De=C0080KFe]00D0NGUi09BDU02DU9@0^k^k06ATI00208n?S`0508R8R02c/k<0/k>c0<O7
a`2VYZH00P2KVi/0102h^;P0^KVi0;Vi^@34a<@204m?C`05096AT@1kNg/0M7Ad07AdM01iNGT00P1c
Lg<01@1/K6`0Rh^;08^;R`2_[jl0WinO0080OWin00D0F5QH08f=S@2=SHd0[Zj^0=[JfP020;bl_004
071`L01UIFD0IFEU09^KV`80_[jn00D0VIVI06][J`1aLG40LG5a07=cL`020:RXZ0050<;2`P2[Zj/0
Zj^[07UiN@2XZ:P00P2VYZH0102JVYX0JFUY06UYJ@1hN7P20;:b/P050;Jf]P1BDU80?Shn03hn?P1:
BTX00P16ATH01@21PH40Lg=c06m_K`1_Kfl0IfMW0080Lg=c00D0IFEU069RHP1RHV80NGUi06YZJP02
05EEE@0406=SH`1bLW80LW9b07inOP80SHf=00D0WYjN0:VYZ@1:BTX0BTY:08R8R00208f=S@0508B4
Q01gMgL0HV9R069RHP1JFUX00P1eMGD0101WIfL0QhN708N7Q`1jNWXE0?oooaP0003o0`3oP00B0000
o`80oh009@000?l50?n001L0003o103oP00i0000o`l0oooo00090?ooo`0406ATI01nOWh0OWin08B4
Q080ATI600D0R8R807inOP1nOWh0TI6A05QHF002071`L00505YJFP1?Cdl0Cdm?07=cL`1`L7000P1j
NWX01016ATH0CDe=04e=C@27QhL207QhN0040861P@1aLG40Cdm?04m?C`<0AdM700D0Bd];07YjNP1j
NWX0Shn?096AT@0205IFEP0408:2PP1@D500D51@06i^KP80GUiN00D0Rh^;0<_;b`2NWYh0WYjN04e=
C@0202d];@0506ATI02RXZ80YjNW0:NWY`2^[Zh00P2c/k<01@2EUID0TY:B09:BTP2QXJ40UIFE0080
NGUi00@0L71`075aL@1aLG40Ng]k0P2EUID01@2[Zj/0EEEE09FEU@2EUID0QhN70080^[Zj00D0b/[:
0:f][@2CTi<0Ti>C0;6a/@020;Jf]P050;Zj^P16ATH0ATI608Z:RP24Q8@00P28R8P01022PX80SHf=
08f=S@1]KFd208j>SP050<c<c02<S8`0Kfm_06m_K`1=CDd00P1oOgl01@24Q8@0f][J0:f][@2][Jd0
Lg=c0080GEeM00D0WinO0<G5a@35aLD0PH6106UYJ@02065QH@04071`L02QXJ40XJ6Q0:RXZ080XJ6Q
00D0QHF50:6QX@2NWYh0WYjN08F5Q@0205]KF`0506YZJP2SXj<0Xj>S0;:b/P1PH6000P0n?Sh01@1<
C4`0@D510451@@1OGel0M7Ad0080Ogmo00@0L71`06UYJ@1YJFT0GEeM0P1gMgL01@1OGel0IfMW06=S
H`1SHf<0KVi^0080RHV900D0T92@08R8R028R8P0Ti>C09fMW@02059BDP0509VIV@2TY:@0Y:BT0:6Q
X@2<S8`00P1jNWX0101OGel0GUiN05iNGP1XJ6P206MWI`0306EUI@3oool0oooo01<0oooo6P000?l0
0`3oP000003o0000o`0S0000o`@0oh0040000?l50?n004H0003o0`3oP00;0000o`l0oooo00090?oo
o`0406YZJP1dM7@0M7Ad07MgM`80ATI600D0Ti>C07emO@1mOGd0PH6105eMG@02079bLP0506e]K@1L
G5`0G5aL092@T01bLW800P1iNGT01015ADD0@D510451@@2@T90207UiN@0507QhN025QHD0FEUI05UI
F@19BDT00P15ADD01@1LG5`0Lg=c07=cL`2DU9@0W9bL0080EEEE00@0OWin04Q8B018B4P0H61P0P1Q
HF401@2CTi<0bl_;0:FUY@2UYJD0G5aL0080>c/k00@0Lg=c09fMW@2e]KD0]KFe0`2^[Zh01@2CTi<0
Vi^K09^KV`2VYZH0Y:BT0080OWin00@0G5aL07alO01lO7`0OGem0P2GUiL01@2][Jd0H61P09BDU02D
U9@0P8200080]kNg00D0b<S80;:b/P2FUYH0UYJF0;:b/P020;Fe]@040;Ng]`19BDT0BDU90820P0<0
Ng]k00@0OWin08^;R`2;Rh/0KFe]0P1jNWX01@35aLD0RXZ:07YjNP1jNWX0F5QH0080UIFE00D0UYJF
0;Zj^P2PX:00X:2P07YjNP0206EUI@0508n?S`37alL0alO707YjNP1^KVh00P1]KFd0101_Kfl0WIfM
09fMW@2][Jd20:VYZ@0508F5Q@2>SXh0SHf=08f=S@1oOgl00P1fMWH01@2@T900YJFU0:FUY@2^[Zh0
GemO0080?Shn00D0E5AD04A4A014A4@0H61P06a/K00207IfMP04079bLP1jNWX0NWYj06IVIP80MgMg
00D0LW9b06i^KP1LG5`0G5aL07EeM@0208F5Q@0509jNWP2<S8`0S8b<0861P@2KVi/00P1DE5@01@26
QXH0/[:b0;:b/P2MWId0SHf=0080Rh^;00@0JVYZ07EeM@1eMGD0NWYj0P1^KVh00`1XJ6P0oooo0?oo
o`0C0?oooaX0003o1@3oP01K0000o`030?n000000?l0003o01H0003o0`3oP0080000o`@0oh002`00
0?l?0?ooo`002@3oool0101ZJVX0M7Ad07AdM01gMgL204I6AP0509>CT`1mOGd0OGem0861P@1MGEd0
0P1bLW801@1]KFd0G5aL05aLG02@T900LW9b0080NGUi00@0ADE50451@@11@D40T92@0P1iNGT01@1h
N7P0QHF505UIF@1IFET0BDU90080ADE500D0G5aL07=cL`1cLg<0U9BD09bLW00205EEE@0407inOP18
B4P0B4Q8061PH080HF5Q00D0Ti>C0<_;b`2UYJD0YJFU05aLG00203/k>`0407=cL`2MWId0]KFe0;Fe
]@<0[Zj^00D0Ti>C09^KV`2KVi/0YZJV0:BTY00207inOP0405aLG01lO7`0O7al07emO@80UiNG00D0
[Jf]061PH02DU9@0U9BD0820P0020;Ng]`050<S8b02b/[80UYJF09JFUP2b/[800P2e]KD0102g]kL0
BDU904U9B@20P80307]kN`0407inOP2;Rh/0Rh^;06e]K@80NWYj00D0aLG508Z:RP1jNWX0NWYj05QH
F00209FEU@0509JFUP2j^[X0X:2P0:2PX01jNWX00P1UIFD01@2?Shl0alO70<O7a`1jNWX0KVi^0080
KFe]00@0Kfm_09fMW@2MWId0[Jf]0P2YZJT01@25QHD0SXj>08f=S@2=SHd0Ogmo0080MWIf00D0T92@
0:FUY@2UYJD0[Zj^05mOG`0203hn?P0505ADE014A4@0A4A4061PH01/K6`00P1fMWH0101bLW80NWYj
07YjNP1VIVH207MgM`05079bLP1^KVh0G5aL05aLG01eMGD00P25QHD01@2NWYh0S8b<08b<S021PH40
Vi^K0080E5AD00D0QXJ60;:b/P2b/[80WIfM08f=S@0208^;R`0406YZJP1eMGD0MGEe07YjNP80KVi^
00<0J6QX0?ooo`3oool04`3ooolJ0000o`D0oh00F`000?l00`3oP000003o0000o`0F0000o`<0oh00
20000?l40?n000/0003o3`3oool000T0oooo00@0NWYj08Z:RP2:RXX0RHV90P1;Bd/01@1oOgl0NWYj
07YjNP1lO7`0E5AD0080Ng]k00D0LG5a06YZJP1ZJVX0QhN707emO@0207MgM`0405QHF016ATH0ATI6
05YJFP80IFEU00D0L71`07UiN@12@T80@T9204I6AP02059BDP0505YJFP1UIFD0IFEU08n?S`2BTY80
0P1EEED0102?Shl0GEeM05eMG@1hN7P2061PH00508V9R@3=cLd0YjNW0:NWY`1UIFD00P1;Bd/01@1n
OWh0[Zj^0;6a/@2a/K40^k^k0080/K6a00D0Shn?07moO`1oOgl0S8b<07moO`0206ATI00404m?C`1h
N7P0N7Qh08B4Q080WYjN00D0]kNg06i^KP2`/;00/;2`07]kN`020;Rh^0050=3@d02c/k<0V9RH09RH
V02_[jl00P3@d=001@31`L40GUiN05iNGP26QXH0QhN70080OWin00@0N7Qh09BDU02DU9@0KFe]0P1d
M7@01@3Hf=P0QXJ6075aL@1aLG40E5AD0080U9BD00D0[Zj^0<g=c@2h^;P0^;Rh08V9R@0208j>SP05
09NGU`3:b/X0b/[:06ATI01aLG400P1gMgL0101WIfL0UIFE09FEU@2e]KD20::RXP0508:2PP26QXH0
Xj>S0:>SX`23Ph<00P1QHF401@2;Rh/0Xj>S0:>SX`2QXJ40IFEU0080CDe=00D0ADE50451@@11@D40
I6AT07=cL`0306m_K`<0N7Qh0P20P8001@1gMgL0H61P05]KF`1KFe/0HV9R0080JVYZ00D0VYZJ08J6
QP26QXH0O7al092@T00204U9B@05075aL@2@T900T92@09RHV020P8000P1dM7@0101JFUX0O7al07al
O01hN7P2069RHP0306YZJP3oool0oooo01<0ooooH0000?l00`3oP000003o0000o`0H0000o`030?n0
00000?l0003o02P0003o0`3oP0040000o`l0oooo00090?ooo`0407alO02>SXh0SXj>08N7Q`80ADE5
00D0PH6108F5Q@25QHD0MWIf04a<C00206a/K00506QXJ01bLW80LW9b07IfMP23Ph<00P1nOWh0101]
KFd0CDe=04e=C@1cLg<2075aL@0508J6QP1ZJVX0B4Q804Q8B011@D400P0m?Cd01@1QHF40KFe]06e]
K@2BTY80O7al0080@T9200@0MgMg05=CD`1CDe<0Lg=c0P1MGEd01@28R8P0bl_;0:6QX@2QXJ40KVi^
0080DE5A00D0QHF50:2PX02j^[X0^[Zj0;Bd]0020:JVYP0508f=S@2HV9P0V9RH09ZJVP1oOgl00P1`
L700101HF5P0Kfm_06m_K`1lO7`209ZJVP050:FUY@1QHF40X:2P0:2PX020P8000P2f][H01@34a<@0
_Kfm09^KV`2KVi/0/K6a0080eMGE00D0`L7105mOG`1OGel0Rh^;08j>SP0207UiN@0407moO`2IVIT0
VIVI07QhN080HV9R00D0dm?C09JFUP1jNWX0NWYj05=CD`020861P@0509bLW02j^[X0];Bd0;Bd]020
P8000P1nOWh01@2EUID0f=SH0=SHf01[Jf/0Q8B40080O7al00@0M7Ad09>CT`2CTi<0VYZJ0P2n_[h0
1@2DU9@0R8R808V9R@29RHT0Ng]k0080Lg=c00D0TI6A0:JVYP2VYZH0UiNG075aL@0204m?C`0503`l
?01?Cdl0Cdm?06UYJ@1QHF400P1[Jf/0101]KFd0Ng]k07]kN`1hN7P207IfMP0506m_K`1jNWX0I6AT
06ATI01ZJVX00P1LG5`01@2CTi<0Q8B408B4Q02BTY80/[:b0080Fe]K00D0S8b<0:JVYP2VYZH0WinO
07EeM@0206a/K00405YJFP1dM7@0M7Ad06QXJ080LG5a00<0JFUY0?ooo`3oool04`3ooolF0000o`03
0?n000000?l0003o0200003o103oP00Z0000o`030?n000000?l0003o03L0003o00@0oh000000o`00
0?l0oh0020000?l?0?ooo`002@3oool0101lO7`0SXj>08j>SP27QhL204E5A@050861P@25QHD0QHF5
07IfMP1<C4`00P1/K6`01@1XJ6P0LW9b079bLP1fMWH0Ph>30080OWin00@0KFe]04e=C@1=CDd0Lg=c
0P1aLG401@26QXH0JVYZ04Q8B018B4P0@D510080?Cdm00D0HF5Q06e]K@1]KFd0TY:B07alO0020492
@P0407MgM`1CDe<0De=C07=cL`80GEeM00D0R8R80<_;b`2QXJ40XJ6Q06i^KP02055AD@0508F5Q@2P
X:00^[Zj0;Zj^P2d];@00P2VYZH01@2=SHd0V9RH09RHV02JVYX0Ogmo0080L71`00@0F5QH06m_K`1_
Kfl0O7al0P2JVYX01@2UYJD0HF5Q0:2PX02PX:00P8200080][Jf00D0a<C40;fm_@2KVi/0Vi^K0;6a
/@020=GEe@050<71`@1OGel0GemO08^;R`2>SXh00P1iNGT0101oOgl0VIVI09VIV@1hN7P2069RHP05
0=?Cd`2FUYH0NWYj07YjNP1CDe<00P21PH401@2LW9`0^[Zj0;Bd]02d];@0P8200080OWin00D0UIFE
0=SHf03Hf=P0Jf][08B4Q00207alO00407AdM02CTi<0Ti>C09ZJVP80_[jn00D0U9BD08R8R029RHT0
RHV907]kN`0207=cL`05096AT@2VYZH0YZJV09NGU`1aLG400P1?Cdl01@0l?3`0Cdm?04m?C`1YJFT0
HF5Q0080Jf][00@0KFe]07]kN`1kNg/0N7Qh0P1fMWH01@1_Kfl0NWYj06ATI01TI6@0JVYZ0080G5aL
00D0Ti>C08B4Q024Q8@0TY:B0;:b/P0205]KF`0508b<S02VYZH0YZJV09nOW`1eMGD00P1/K6`0101J
FUX0M7Ad07AdM01XJ6P2075aL@0306UYJ@3oool0oooo01<0oooo4P000?l00`3oP000003o0?n00002
0?n00200003o1P3oP0050000o`80oh007`000?l50?n00380003o0`3oP00010000?l0oh000?n0003o
P00<0000o`l0oooo00090?ooo`0407moO`2SXj<0Xj>S08J6QP80ATI600D0Ogmo08^;R`2;Rh/0M7Ad
05IFEP020861P@0506][J`1hN7P0N7Qh07UiN@1nOWh00P1jNWX0101TI6@0Bd];04];B`28R8P208:2
PP0508j>SP1_Kfl0Bd];04];B`1>CTh00P1FEUH01@1]KFd0KVi^06i^KP2GUiL0SHf=0080?clo00@0
RHV904];B`1;Bd/0Lg=c0P1CDe<01@2=SHd0bl_;0:>SX`2SXj<0EUIF0080@D5100D0JVYZ0:JVYP2`
/;00/;2`0:j^[P020:6QX@0508B4Q025QHD0QHF509>CT`22PX800P1ZJVX0101DE5@0K6a/06a/K01b
LW82096AT@050:b/[01LG5`0V9RH09RHV025QHD00P2o_kl01@39bLT0d=3@0:6QX@2QXJ40YJFU0080
`l?300D0^k^k06EUI@1UIFD0Q8B4096AT@0207QhN00407AdM02FUYH0UYJF07emO@80EUIF00D0hn?S
08^;R`1gMgL0MgMg05EEE@0206a/K00509>CT`35aLD0[jn_0:n_[`2DU9@00P2<S8`01@2PX:00e]KF
0=KFeP1VIVH0KFe]0080Lg=c00@0KVi^0820P020P800WIfM0P30`<001@2@T900Rh^;0:VYZ@2YZJT0
PX:20080H61P00D0Ogmo0:6QX@2QXJ40Vi^K07AdM00204Y:BP0503<c<`1;Bd/0Bd];06=SH`1KFe/0
0P1mOGd0101VIVH0QXJ608J6QP1hN7P207emO@0506][J`1aLG40IfMW06MWI`1gMgL00P1hN7P01@2]
[Jd0U9BD09BDU02MWId0[Zj^0080GUiN00D0OWin0:2PX02PX:00XZ:R08V9R@02071`L00405MGE`1T
I6@0I6AT05aLG080LW9b00<0IVIV0?ooo`3oool04`3ooolB0000o`030?n000000?l0oh000080oh00
80000?l60?n000D0003o0P3oP00O0000o`D0oh00<P000?l30?n000040000o`3oP000oh000?n000`0
003o3`3oool000T0oooo00@0NWYj0:VYZ@2YZJT0OGem0P1@D5001@1gMgL0PH610861P@1^KVh0E5AD
0080Lg=c00D0FUYJ06][J`1[Jf/0K6a/07MgM`0206i^KP0405MGE`16ATH0ATI607]kN`80QHF500D0
U9BD075aL@1KFe/0Fe]K04];B`0205ADE00506][J`1fMWH0MWIf09JFUP22PX800P1EEED0101mOGd0
@T920492@P1^KVh204U9B@0508J6QP2n_[h0P8200820P01PH6000P0l?3`01@1dM7@0][Jf0;Ng]`2g
]kL0YjNW0080[Zj^00D0VIVI08>3P`23Ph<0VIVI08f=S@0207EeM@0405mOG`1_Kfl0Kfm_07YjNP80
X:2P00D0]KFe06ATI02PX:00X:2P08N7Q`020;^k^`050<O7a`3<c<`0UYJF09JFUP2GUiL00`2i^KT2
07alO00507UiN@2DU9@0MGEe07EeM@1kNg/00P2EUID01@1aLG40Cdm?04m?C`3@d=00SHf=0080NWYj
00D0JVYZ07moO`1oOgl0Vi^K0;bl_0020;Fe]@0408^;R`2:RXX0RXZ:08V9R@80fMWI00D0GemO07Ee
M@1oOgl0Ogmo079bLP0207EeM@050:NWY`2o_kl0_kno08f=S@1eMGD00P2LW9`0101eMGD0Fe]K05]K
F`1YJFT209^KV`050::RXP1bLW80ADE504E5A@0c<c<00P0i>CT01@1NGUh0I6AT07QhN01hN7P0Fe]K
0080N7Qh00D0K6a/07moO`1oOgl0I6AT07AdM00205iNGP0406e]K@1bLW80LW9b09^KV`80T92@00D0
XJ6Q0:j^[P1NGUh0GUiN09NGU`020:RXZ0050:b/[024Q8@0M7Ad07AdM01[Jf/00P1RHV80101[Jf/0
NGUi07UiN@1bLW8E0?ooojd0003o3`3oool000T0oooo00@0M7Ad0:6QX@2QXJ40MWIf0P13@d<01@1h
N7P0S8b<08b<S01cLg<0HF5Q0080QXJ600D0J6QX07QhN01hN7P0Lg=c07QhN00206UYJ@0404e=C@15
ADD0ADE507moO`80PH6100D0UYJF07=cL`1ZJVX0JVYZ05EEE@02051@D005061PH01/K6`0K6a/09nO
W`2EUID00P1^KVh0102@T900EeMG05MGE`1nOWh2055AD@0508N7Q`3=cLd0TI6A096AT@1KFe/00P0j
>SX01@1WIfL0YZJV0:RXZ02XZ:P0UiNG0080Zj^[00D0Vi^K07EeM@1eMGD0UIFE08V9R@0207=cL`04
05UIF@1YJFT0JFUY07MgM`80Rh^;00D0^KVi06ATI02NWYh0WYjN092@T0020;jn_P050<S8b035aLD0
R8R808R8R02;Rh/00P2k^k/01@2`/;00MgMg07MgM`1aLG40T92@0080Kfm_00@0L71`09:BTP2BTY80
K6a/0P1OGel01@3@d=00MGEe07inOP1nOWh0Kfm_0080LW9b00D0S8b<0;Fe]@34a<@0a<C408N7Q`02
08Z:RP0507UiN@3Cdm<0dm?C06a/K02LW9`00P1kNg/0101hN7P0MGEe07EeM@2LW9`20<S8b00509FE
U@1_Kfl0QhN708N7Q`1lO7`00P1JFUX01@1SHf<0YZJV0:JVYP2WYjL0IFEU0080@d=300D0>3Ph03Hf
=P0f=SH0HF5Q07emO@0206UYJ@0406YZJP1[Jf/0Jf][07QhN080Ogmo00D0I6AT06UYJ@1IFET0FEUI
07AdM00207IfMP0509>CT`2ATI40TI6A09>CT`2UYJD00P1EEED01@2LW9`0[Zj^0:j^[P2_[jl0RXZ:
0080L71`00@0F5QH071`L01`L700J6QX0P1ZJVX00`1LG5`0oooo0?ooo`0C0?oooiD0003o00<0oh00
0000o`000?l05@000?l?0?ooo`002@3oool0101dM7@0XJ6Q0:6QX@1fMWH204=3@`0507QhN02<S8`0
S8b<07=cL`1QHF400P26QXH01@1XJ6P0N7Qh07QhN01cLg<0N7Qh0080JFUY00@0CDe=04E5A@15ADD0
Ogmo0P21PH401@2FUYH0Lg=c06YZJP1ZJVX0EEEE0080D51@00D0H61P06a/K01/K6`0WinO09FEU@02
06i^KP04092@T01GEeL0EeMG07inOP80DE5A00D0QhN70<g=c@2ATI40TI6A05]KF`0203Xj>P0506MW
I`2VYZH0Z:RX0:RXZ02GUiL00P2[Zj/01@2KVi/0MGEe07EeM@2EUID0RHV90080Lg=c00@0FEUI06UY
J@1YJFT0MgMg0P2;Rh/01@2i^KT0I6AT09jNWP2NWYh0T92@0080_[jn00D0b<S80<G5a@28R8P0R8R8
08^;R`020;^k^`050;2`/01gMgL0MgMg075aL@2@T9000P1_Kfl0101`L700TY:B09:BTP1/K6`205mO
G`050=3@d01eMGD0OWin07inOP1_Kfl00P1bLW801@2<S8`0]KFe0<C4a034a<@0QhN70080RXZ:00D0
NGUi0=?Cd`3Cdm<0K6a/09bLW00207]kN`0407QhN01eMGD0MGEe09bLW080b<S800D0UIFE06m_K`27
QhL0QhN707alO00205YJFP0506=SH`2VYZH0YZJV0:NWY`1UIFD00P13@d<01@0h>3P0=SHf03Hf=P1Q
HF40OGem0080JFUY00@0JVYZ06][J`1[Jf/0N7Qh0P1oOgl01@1TI6@0JFUY05UIF@1IFET0M7Ad0080
MWIf00D0Ti>C096AT@2ATI40Ti>C0:FUY@0205EEE@0509bLW02^[Zh0[Zj^0:n_[`2:RXX00P1`L700
101HF5P0L71`071`L01XJ6P206YZJP0305aLG03oool0oooo01<0oooo[@000?l?0?ooo`002@3oool0
101[Jf/0Ti>C09>CT`1/K6`20410@0<0K6a/00D0J6QX05ADE01aLG40LG5a06UYJ@0207YjNP0506][
J`1aLG40JVYZ06YZJP17AdL00P13@d<01@1aLG40P8200820P02GUiL0IfMW00<0EUIF0P1<C4`01@1O
Gel0K6a/06a/K02JVYX0QXJ60080HF5Q00@0Ti>C05mOG`1OGel0PX:20P1OGel01@1oOgl0`l?309^K
V`2KVi/0GEeM0080@41000D0JFUY09FEU@2MWId0WIfM0;6a/@020<30`0050::RXP2KVi/0Vi^K0:2P
X028R8P00P1gMgL0101JFUX0K6a/06a/K01jNWX209:BTP050<C4a01XJ6P0ZJVY0:VYZ@2BTY800P2h
^;P01@37alL0c<c<08V9R@29RHT0RXZ:0080][Jf00D0[Zj^07YjNP1jNWX0NGUi08j>SP0207IfMP04
07YjNP2GUiL0UiNG05mOG`80H61P00D0d];B07emO@28R8P0R8R8079bLP02075aL@0509jNWP2`/;00
aLG50<G5a@2IVIT00P2BTY801@1fMWH0b/[:0<[:bP1HF5P0UiNG0080MgMg00@0Lg=c07AdM01dM7@0
YZJV0P3:b/X01@2EUID0JFUY09bLW02LW9`0MgMg0080GemO00D0N7Qh0;6a/@2a/K40]KFe079bLP02
04Y:BP0504=3@`11@D40@D5106MWI`1eMGD00P1KFe/0101SHf<0J6QX06QXJ01gMgL208j>SP0507Qh
N01ZJVX0DU9B059BDP1hN7P00P1cLg<01@2HV9P0[Zj^0:j^[P2?Shl0[:b/0080J6QX00D0PX:209^K
V`2KVi/0VIVI07=cL`0205iNGP0406MWI`1YJFT0JFUY06a/K080P82000<0Kfm_0?ooo`3oool04`3o
oon]0000o`l0oooo00090?ooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25QHD0KFe]
05QHF0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1cLg<207If
MP0508V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080EEEE00@0
S8b<05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN0;Rh^02g
]kL0]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad07AdM01n
OWh209fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?S`80a<C4
00D0]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0clo?08:2
PP28R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0fMWI0=WI
f@1YJFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02XZ:P0NWYj
0080Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`L7000P1J
FUX0101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT01@2IVIT0
Xj>S0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=C@1IFET0
FEUI05UIF@80Lg=c00<0EUIF0?ooo`3oool04`3oool50000o`<0oh00;@000?l20?n006P0003o0P3o
P00<0000o`l0oooo00090?ooo`04075aL@2WYjL0YjNW07MgM`80BTY:00D0O7al08F5Q@25QHD0KFe]
05QHF0020820P00505aLG01fMWH0MWIf07=cL`1nOWh00P1SHf<0101DE5@0GUiN05iNGP1cLg<207If
MP0508V9R@1]KFd0G5aL05aLG014A4@00P17AdL01@1NGUh0M7Ad07AdM02PX:00Rh^;0080EEEE00@0
S8b<05IFEP1FEUH0OWin0P1VIVH01@2<S8`0alO708Z:RP2:RXX0FEUI0080:b/[00D0GUiN0;Rh^02g
]kL0]kNg0;:b/P020;Zj^P0509^KV`2GUiL0UiNG0:FUY@28R8P00P1iNGT0101JFUX0M7Ad07AdM01n
OWh209fMW@050<W9b@1TI6@0ZZZZ0:ZZZP2FUYH00P2o_kl00`3=cLd0e=CD08n?S`0208n?S`80a<C4
00D0]KFe0861P@21PH40Ti>C08Z:RP0207YjNP0407emO@2MWId0WIfM06IVIP80Jf][00D0clo?08:2
PP28R8P0R8R808N7Q`02075aL@0509ZJVP2OWil0^;Rh0;Rh^02BTY800P1lO7`01@1YJFT0fMWI0=WI
f@1YJFT0R8R80080JVYZ00@0P82008n?S`2?Shl0^k^k0P3Fe]H01@2IVIT0JVYZ0:RXZ02XZ:P0NWYj
0080Kfm_00D0OWin0::RXP2RXZ80]KFe06e]K@0203hn?P0503Ti>@0o?cl0?clo05eMG@1`L7000P1J
FUX0101KFe/0HV9R069RHP1^KVh208F5Q@0508N7Q`1IFET0CDe=04e=C@1]KFd00P1iNGT01@2IVIT0
Xj>S0:>SX`2>SXh0[jn_0080Q8B400D0PX:209ZJVP2JVYX0[:b/07alO00206EUI@0404e=C@1IFET0
FEUI05UIF@80Lg=c00<0EUIF0?ooo`3oool04`3oool010000?l0oh000?n000000?l30?n009L0003o
0`3oP0050000o`80oh001@000?l?0?ooo`002@3oool0101RHV80V9RH09RHV01TI6@203/k>`0506i^
KP1hN7P0N7Qh06UYJ@1MGEd00P24Q8@01@1IFET0Ng]k07]kN`1/K6`0Ng]k0080H61P00@0ATI605=C
D`1CDe<0MGEe0P2<S8`01@2?Shl0L71`06IVIP1VIVH0F5QH0080CTi>00D0HF5Q07AdM01dM7@0VIVI
08Z:RP0205UIF@0409VIV@1DE5@0E5AD0861P@80L71`00D0NWYj0;no_`25QHD0QHF504Y:BP02059B
DP0505UIF@2YZJT0/k>c0;>c/`2n_[h00P2i^KT01@2:RXX0WYjN09jNWP2IVIT0Rh^;0080MGEe00@0
F5QH06MWI`1WIfL0O7al0P2?Shl01@2_[jl0E5AD09BDU02DU9@0Q8B40080[Zj^00<0alO70=WIf@2C
Ti<00P2CTi<20<G5a@050:n_[`26QXH0QXJ608V9R@1cLg<00P1bLW80101]KFd0TY:B09:BTP1PH602
06i^KP050=OGe`2@T900Shn?08n?S`2DU9@00P1^KVh01@2f][H0Xj>S0<W9b@39bLT0[:b/0080PH61
00D0L71`0=oOg`3Ogml0Kfm_09:BTP0207]kN`0407QhN01lO7`0O7al0:NWY`80d=3@00D0WYjN06MW
I`2UYJD0YJFU08V9R@0207IfMP0507YjNP2GUiL0UiNG0;bl_01dM7@00P11@D430410@005061PH02:
RXX0GUiN05iNGP1>CTh00P1MGEd01@1WIfL0IVIV06IVIP1eMGD0Cdm?0080E5AD00@0OWin07UiN@1i
NGT0UIFE0P2f][H01@2EUID0/;2`0820P020P800QHF50080X:2P00D0[:b/08F5Q@1RHV80HV9R05YJ
FP02069RHP0406][J`24Q8@0Q8B4075aLAD0oooo00<0003o0?n0003oP000HP000?l20?n000`0003o
00<0oh000000o`000?l0;`000?l40?n000@0003o3`3oool000T0oooo00@0HV9R0:VYZ@2YZJT0MGEe
0P1<C4`01@1jNWX0QHF508F5Q@1fMWH0G5aL0080R8R800D0O7al09NGU`2GUiL0N7Qh071`L00206AT
I00404=3@`1OGel0GemO06UYJ@80Ogmo00D0QHF507=cL`1HF5P0F5QH04I6AP0203`l?00505eMG@1b
LW80LW9b08n?S`2BTY800P20P800102NWYh0FUYJ05YJFP1oOgl308:2PP040=7Ad@27QhL0QhN706=S
H`80M7Ad00D0I6AT0;Bd]02h^;P0^;Rh0<30`0020;Rh^0050:JVYP28R8P0R8R809nOW`2;Rh/00P1e
MGD0101IFET0L71`071`L027QhL209>CT`050<C4a01NGUh0UiNG09NGU`25QHD00P2[Zj/00`2k^k/0
bLW908B4Q00208B4Q080^k^k00D0_Kfm08:2PP22PX80QXJ607alO00207]kN`0407emO@2KVi/0Vi^K
05MGE`80J6QX00D0bl_;0:RXZ029RHT0RHV9092@T00206MWI`050;Rh^02/[:`0a/K60<K6aP2JVYX0
0P1/K6`01@1BDU80fMWI0=WIf@1oOgl0T92@0080QhN700@0Ti>C09FEU@2EUID0_kno0P3Lg=`01@2Q
XJ40MGEe0;Bd]02d];@0SHf=0080RXZ:00D0Lg=c09ZJVP2JVYX0b/[:06a/K00204E5A@0504=3@`0l
?3`0?3`l05IFEP24Q8@00P1CDe<0101MGEd0J6QX06QXJ01]KFd205]KF`0507moO`14A4@0EEEE05EE
E@1`L7000P1^KVh01@2:RXX0ZZZZ0:ZZZP20P800]kNg0080SHf=00D0R8R809RHV02HV9P0[Zj^07em
O@0205ADE00405aLG01ZJVX0JVYZ05MGE`80NWYj00<0HV9R0?ooo`3oool04`3oool00`000?l0oh00
0?n0001R0000o`80oh0030000?l00`3oP000003o0000o`0_0000o`@0oh0010000?l?0?ooo`002@3o
ool0101RHV80ZJVY0:VYZ@1eMGD204a<C00507YjNP25QHD0QHF507IfMP1LG5`00P28R8P01@1lO7`0
UiNG09NGU`1hN7P0L71`0080I6AT00@0@d=305mOG`1OGel0JFUY0P1oOgl01@25QHD0Lg=c05QHF01H
F5P0ATI60080?3`l00D0GEeM079bLP1bLW80Shn?09:BTP020820P00409jNWP1JFUX0FUYJ07moO`<0
PX:200@0dM7A08N7Q`27QhL0Hf=S0P1dM7@01@1TI6@0];Bd0;Rh^02h^;P0`<300080^;Rh00D0YZJV
08R8R028R8P0WinO08^;R`0207EeM@0405UIF@1`L700L71`08N7Q`80Ti>C00D0a<C405iNGP2GUiL0
UiNG08F5Q@020:^[Z`030;^k^`39bLT0Q8B40080Q8B40P2k^k/01@2m_Kd0PX:208:2PP26QXH0O7al
0080Ng]k00@0OGem09^KV`2KVi/0EeMG0P1XJ6P01@3;bl/0Z:RX08V9R@29RHT0T92@0080IfMW00D0
^;Rh0:b/[036a/H0a/K609ZJVP0206a/K005059BDP3IfMT0fMWI07moO`2@T9000P27QhL0102CTi<0
UIFE09FEU@2o_kl20=cLg0050:6QX@1eMGD0];Bd0;Bd]02=SHd00P2:RXX01@1cLg<0VYZJ09ZJVP3:
b/X0K6a/0080ADE500D0@d=303`l?00l?3`0EUIF08B4Q00205=CD`0405eMG@1XJ6P0J6QX06e]K@80
Fe]K00D0Ogmo04A4A01EEED0EEEE071`L00206i^KP0508Z:RP2ZZZX0ZZZZ0820P02g]kL00P2=SHd0
1@28R8P0V9RH09RHV02^[Zh0OGem0080E5AD00@0G5aL06YZJP1ZJVX0EeMG0P1jNWX00`1RHV80oooo
0?ooo`0C0?ooo`030000o`3oP000oh0003h0003o0`3oP00T0000o`030?n000000?l0003o00L0003o
103oP00`0000o`80oh001@000?l?0?ooo`002@3oool0101WIfL0WIfM09fMW@1bLW8204A4A005071`
L01kNg/0Ng]k06EUI@1=CDd00P1[Jf/01@1XJ6P0NGUi07UiN@1/K6`0Lg=c0080Fe]K00@0?3`l05aL
G01LG5`0O7al0P27QhL01@1nOWh0KFe]051@D01@D500F5QH0080EUIF00D0O7al06m_K`1_Kfl0V9RH
08^;R`0207YjNP0409BDU01>CTh0CTi>071`L080IVIV00D0MWIf0;6a/@1/K6`0K6a/05eMG@0205UI
F@03061PH02PX:00Vi^K0080Vi^K0`2FUYH208N7Q`05096AT@29RHT0MGEe07EeM@1JFUX00P21PH40
1@20P800UiNG09NGU`37alL0HF5Q0080X:2P00D0QHF50;Ng]`2g]kL0_kno0=?Cd`0208b<S004096A
T@2n_[h0_[jn0;Ng]`80Q8B400D0N7Qh06m_K`1kNg/0Ng]k07UiN@0208b<S00505aLG01^KVh0KVi^
0<?3``2OWil00P1fMWH01@2?Shl0GUiN05iNGP2e]KD0ZZZZ0080_;bl00@0VIVI061PH01PH600D51@
0P3Fe]H01@1cLg<0QhN708>3P`23Ph<0QXJ60080T92@00D0[:b/0=?Cd`3Cdm<0XZ:R06e]K@020;>c
/`0409bLW02HV9P0V9RH07QhN080U9BD00D0clo?06QXJ010@400@41003Xj>P0203Ph>00504a<C01m
OGd0E5AD05ADE01XJ6P00P1IFET01@1YJFT0GEeM05eMG@1^KVh0Cdm?0080HF5Q00@0JVYZ07UiN@1i
NGT0ZJVY0P2/[:`01@2KVi/0`<3009NGU`2GUiL0TI6A0080/K6a00D0[jn_07inOP1OGel0GemO061P
H00206UYJ@0405ADE01fMWH0MWIf05YJFQD0oooo00<0003o0?n0003oP0000P000?l90?n000d0003o
0`3oP0090000o`@0oh000P000?l:0?n003T0003o1P3oP00P0000o`<0oh0050000?l?0?ooo`002@3o
ool0101ZJVX0ZJVY0:VYZ@1/K6`20492@P0506e]K@1eMGD0MGEe06EUI@1IFET00P1oOgl01@1YJFT0
P8200820P02<S8`0RXZ:0080FUYJ00@0>CTi05iNGP1NGUh0Hf=S0P21PH401@2=SHd0NGUi05iNGP1N
GUh0F5QH0080BDU900D0NGUi061PH01PH600WinO0:BTY00208>3P`040:ZZZP1MGEd0GEeM07MgM`<0
KVi^00@0_[jn08f=S@2=SHd0Fe]K0P1IFET01@1cLg<0^[Zj0<C4a034a<@0][Jf0080[Zj^00D0/[:b
09bLW02LW9`0Y:BT08^;R`0207AdM00405IFEP1`L700L71`08>3P`80WYjN00D0`l?305iNGP2/[:`0
[:b/08f=S@020;Zj^P050<30`03Fe]H0Ti>C09>CT`29RHT00P2a/K401@2c/k<0SHf=08f=S@1fMWH0
L71`0080MgMg00@0MWIf08b<S02<S8`0Hf=S0P1cLg<01@30`<00VIVI06m_K`1_Kfl0QhN70080H61P
00D0_[jn0:b/[02^[Zh0[Zj^0:n_[`02075aL@0504];B`3Fe]H0e]KF07=cL`2CTi<00P1eMGD0101k
Ng/0LG5a075aL@2MWId20<k>cP0508R8R01RHV80_Kfm0;fm_@2TY:@00P2FUYH01@1iNGT0S8b<08b<
S037alL0K6a/0080@D510`0g=cL01@1CDe<0Kfm_06EUI@1UIFD0J6QX0080Kfm_00D0J6QX07EeM@1e
MGD0NGUi055AD@0206QXJ00405aLG028R8P0R8R809^KV`80Zj^[00D0U9BD0;Ng]`2OWil0WinO05]K
F`0207alO00509RHV01kNg/0Jf][06][J`1NGUh00P1RHV80101KFe/0TI6A096AT@1PH60E0?ooo`L0
003o1`3oP00I0000o`<0oh000`000?l<0?n00680003o1P3oP00<0000o`l0oooo00090?ooo`0406i^
KP2TY:@0Y:BT075aL@80ATI600D0MWIf08>3P`23Ph<0Lg=c06IVIP0207moO`0507EeM@2BTY80TY:B
08B4Q020P8000P1KFe/01012@T80KFe]06e]K@1KFe/2079bLP0507YjNP1]KFd0C4a<04a<C013@d<0
0P1=CDd01@1NGUh0D51@051@D022PX80RHV90080OGem00@0UIFE05IFEP1FEUH0Kfm_0P1iNGT01@20
P800eMGE092@T02@T900I6AT0080G5aL00D0L71`0:RXZ02e]KD0]KFe0;^k^`020:n_[`050:ZZZP2K
Vi/0Vi^K09>CT`27QhL00P1gMgL0101SHf<0NWYj07YjNP1eMGD20861P@050:n_[`1GEeL0YZJV0:JV
YP2JVYX00P2h^;P01@32`/80b/[:096AT@2ATI40QHF50080][Jf00D0/k>c09RHV02HV9P0Kfm_07=c
L`0206i^KP0408B4Q02:RXX0RXZ:07AdM080MGEe00D0aLG50:>SX`1RHV80HV9R075aL@02059BDP05
0;^k^`2^[Zh0a/K60<K6aP2c/k<00P1jNWX01@17AdL0h>3P0>3Ph021PH40T92@0080PX:200@0S8b<
08^;R`2;Rh/0];Bd0P3MgMd01@2CTi<0Jf][0;Rh^02h^;P0ZJVY0080Ti>C00D0LG5a07emO@1mOGd0
a<C407IfMP0204Q8B0<0>CTi00D0@410069RHP1hN7P0N7Qh05mOG`0208>3P`0507MgM`1lO7`0O7al
06YZJP1NGUh00P1ZJVX0101SHf<0P8200820P02ZZZX20:^[Z`0508F5Q@2g]kL0_;bl0;bl_01dM7@0
0P2?Shl01@2SXj<0Q8B405]KF`1KFe/0Jf][0080JVYZ00@0IfMW08Z:RP2:RXX0MgMg5@3oool70000
o`L0oh006@000?l30?n000<0003o303oP01R0000o`H0oh0030000?l?0?ooo`002@3oool0101^KVh0
Y:BT0:BTY01aLG4204I6AP0507IfMP23Ph<0Ph>307=cL`1VIVH00P1oOgl01@1eMGD0TY:B09:BTP24
Q8@0P8200080Fe]K00@0@T9206e]K@1]KFd0Fe]K0P1bLW801@1jNWX0KFe]04a<C01<C4`0@d=30080
CDe=00D0GUiN051@D01@D500PX:208V9R@0207emO@0409FEU@1FEUH0EUIF06m_K`80NGUi00D0P820
0=GEe@2@T900T92@06ATI00205aLG005071`L02XZ:P0]KFe0;Fe]@2k^k/00P2_[jl01@2ZZZX0Vi^K
09^KV`2CTi<0QhN70080MgMg00@0Hf=S07YjNP1jNWX0MGEe0P21PH401@2_[jl0EeMG0:JVYP2VYZH0
VYZJ0080^;Rh00D0`/;20<[:bP2ATI40TI6A08F5Q@020;Jf]P050;>c/`2HV9P0V9RH06m_K`1cLg<0
0P1^KVh01024Q8@0RXZ:08Z:RP1dM7@207EeM@050<G5a@2SXj<0HV9R069RHP1aLG400P1BDU801@2k
^k/0[Zj^0<K6aP36a/H0/k>c0080NWYj00D0AdM70>3Ph03Ph>00PH61092@T00208:2PP0408b<S02;
Rh/0Rh^;0;Bd]080gMgM00D0Ti>C06][J`2h^;P0^;Rh0:VYZ@0209>CT`05075aL@1mOGd0OGem0<C4
a01fMWH00P18B4P303Ti>@050410@01RHV80N7Qh07QhN01OGel00P23Ph<01@1gMgL0O7al07alO01Z
JVX0GUiN0080JVYZ00@0Hf=S0820P020P800ZZZZ0P2[Zj/01@25QHD0]kNg0;bl_02l_;`0M7Ad0080
Shn?00D0Xj>S08B4Q01KFe/0Fe]K06][J`0206YZJP0406MWI`2:RXX0RXZ:07MgMaD0oooo5`000?l0
0`3oP000003o0000o`060000o`@0oh003@000?l80?n003L0003o1P3oP00U0000o`H0oh0030000?l?
0?ooo`002@3oool0101OGel0UYJF09JFUP1kNg/204a<C00507=cL`1fMWH0MWIf07=cL`1NGUh00P1o
Ogl01@1fMWH0Rh^;08^;R`1UIFD0IVIV0080CTi>00@0>3Ph075aL@1aLG40JFUY0P27QhL01@2;Rh/0
M7Ad05YJFP1JFUX0EEEE0080@41000D0LW9b05EEE@1EEED0TY:B08j>SP0207inOP0409bLW01TI6@0
I6AT07IfMP80MGEe00D0Ng]k0<c<c02;Rh/0Rh^;061PH002055AD@0306i^KP2YZJT0/[:b0080/[:b
0P2RXZ801@2VYZH0T92@092@T02ATI40OWin0080KVi^00@0FEUI06a/K01/K6`0NGUi0P2CTi<01@2m
_Kd0GEeM08b<S02<S8`0Shn?0080]KFe00D0_Kfm0<G5a@2<S8`0S8b<07UiN@020:^[Z`050:6QX@2G
UiL0UiNG07QhN01]KFd00P1gMgL0102CTi<0Q8B408B4Q01gMgL208R8R0050;Rh^02OWil0EeMG05MG
E`1bLW800P1@D5001@33`l<0^[Zj0;Jf]P2f][H0ZJVY0080JVYZ00D0@4100=3@d03@d=00NWYj09jN
WP020861P@0407MgM`1XJ6P0J6QX09NGU`80alO700D0T92@07=cL`2n_[h0_[jn0;Ng]`0208:2PP05
06i^KP2:RXX0RXZ:0<[:bP2?Shl00P1?Cdl01@0n?Sh0;Rh^02h^;P14A4@0LG5a0080UIFE00@0J6QX
0820P020P800MWIf0P1mOGd01@1fMWH0FEUI07QhN01hN7P0H61P0080Ogmo00D0ZZZZ0:JVYP2VYZH0
TI6A0;jn_P020;Jf]P05071`L02FUYH0UYJF0:JVYP2ATI400P1XJ6P0101fMWH0GemO05mOG`1dM7@2
08f=S@0307UiN@3oool0oooo01<0oooo5P000?l20?n00080003o0P3oP0060000o`030?n000000?l0
003o04/0003o1P3oP00g0000o`l0oooo00090?ooo`0406MWI`2<S8`0S8b<07]kN`80ATI600D0MGEe
0861P@21PH40M7Ad05MGE`0207MgM`0506UYJ@1oOgl0Ogmo07QhN01kNg/00P13@d<01015ADD0H61P
061PH01CDe<207inOP050861P@1XJ6P0De=C05=CD`1@D5000P14A4@01@1gMgL0H61P061PH02JVYX0
SXj>0080QhN700@0WIfM07IfMP1fMWH0N7Qh0P1fMWH0101mOGd0cLg=09NGU`2GUiL3069RHP05079b
LP2SXj<0^KVi0;Vi^@2h^;P00P2c/k<01@2`/;00VYZJ09ZJVP2UYJD0S8b<0080OWin00@0HF5Q07in
OP1nOWh0Ph>30P2@T9001@2l_;`0HF5Q09FEU@2EUID0QhN70080][Jf00D0_;bl0<;2`P2?Shl0Shn?
09:BTP020:n_[`050;Rh^02@T900T92@075aL@1bLW800P1hN7P0102BTY80PH610861P@1mOGd2096A
T@050;bl_02VYZH0HV9R069RHP1jNWX00P1IFET01@32`/80/k>c0:VYZ@2YZJT0[:b/0080O7al00D0
Bd];0=_Kf`3Kfm/0MWIf08n?S`0207EeM@0408B4Q022PX80PX:20:f][@80a/K600D0Ogmo06MWI`2N
WYh0WYjN0;:b/P0207AdM00506UYJ@26QXH0QXJ60<c<c02EUID00P1JFUX01@17AdL05QHF01HF5P0g
=cL0RXZ:0080SXj>00@0GUiN07emO@1mOGd0OWin0P2<S8`01@20P800HV9R06ATI01TI6@0D51@0080
SXj>00D0/k>c0::RXP2RXZ80WinO0:2PX00209nOW`0506ATI026QXH0QXJ608R8R02:RXX00P1KFe/0
101kNg/0M7Ad07AdM021PH4209VIV@0307IfMP3oool0oooo01<0oooo3P000?l00`3oP000003o0000
o`030000o`<0oh0090000?l20?n003D0003o0P3oP00i0000o`l0oooo00090?ooo`0406MWI`2<S8`0
S8b<07]kN`80ATI600D0MGEe0861P@21PH40M7Ad05MGE`0207MgM`0506UYJ@1oOgl0Ogmo07QhN01k
Ng/00P13@d<01015ADD0H61P061PH01CDe<207inOP050861P@1XJ6P0De=C05=CD`1@D5000P14A4@0
1@1gMgL0H61P061PH02JVYX0SXj>0080QhN700@0WIfM07IfMP1fMWH0N7Qh0P1fMWH0101mOGd0cLg=
09NGU`2GUiL3069RHP05079bLP2SXj<0^KVi0;Vi^@2h^;P00P2c/k<01@2`/;00VYZJ09ZJVP2UYJD0
S8b<0080OWin00@0HF5Q07inOP1nOWh0Ph>30P2@T9001@2l_;`0HF5Q09FEU@2EUID0QhN70080][Jf
00D0_;bl0<;2`P2?Shl0Shn?09:BTP020:n_[`050;Rh^02@T900T92@075aL@1bLW800P1hN7P0102B
TY80PH610861P@1mOGd2096AT@050;bl_02VYZH0HV9R069RHP1jNWX00P1IFET01@32`/80/k>c0:VY
Z@2YZJT0[:b/0080O7al00D0Bd];0=_Kf`3Kfm/0MWIf08n?S`0207EeM@0408B4Q022PX80PX:20:f]
[@80a/K600D0Ogmo06MWI`2NWYh0WYjN0;:b/P0207AdM00506UYJ@26QXH0QXJ60<c<c02EUID00P1J
FUX01@17AdL05QHF01HF5P0g=cL0RXZ:0080SXj>00@0GUiN07emO@1mOGd0OWin0P2<S8`01@20P800
HV9R06ATI01TI6@0D51@0080SXj>00D0/k>c0::RXP2RXZ80WinO0:2PX00209nOW`0506ATI026QXH0
QXJ608R8R02:RXX00P1KFe/0101kNg/0M7Ad07AdM021PH4209VIV@0307IfMP3oool0oooo01<0oooo
3P000?l00`3oP000003o0000o`030000o`<0oh0090000?l20?n003D0003o0P3oP00i0000o`l0oooo
00090?ooo`0405eMG@2;Rh/0Rh^;07YjNP80DE5A00D0MgMg08F5Q@25QHD0P82005iNGP020820P005
07alO01iNGT0NGUi075aL@1fMWH00P1?Cdl0101=CDd0FEUI05UIF@1EEED207UiN@05092@T01QHF40
De=C05=CD`1JFUX00P14A4@01@1kNg/0Hf=S06=SH`2NWYh0YjNW0080Q8B400@0UIFE071`L01`L700
Lg=c0P1fMWH01@1cLg<0a<C407moO`1oOgl0FUYJ00<0Lg=c00@0UIFE0;Rh^02h^;P0`L710P2f][H0
1@2MWId0NGUi07UiN@2>SXh0P8200080MGEe00@0EUIF079bLP1bLW80O7al0P2LW9`01@2g]kL0KFe]
09BDU02DU9@0PH610080/[:b00D0_Kfm0<?3``2@T900T92@07emO@030:n_[`80SXj>00D0MGEe071`
L021PH40PH6109:BTP0207inOP0507]kN`2>SXh0SXj>0;Ng]`2DU9@00P1IFET01@1gMgL0FUYJ05YJ
FP36a/H0`/;20080VYZJ00@0[Jf]0861P@21PH40B4Q80P3Ng]h01@28R8P0RHV907]kN`1kNg/0Ph>3
0080RHV900D0[Zj^0=GEe@3EeMD0UiNG07emO@020:b/[0040;Rh^01WIfL0IfMW07alO080LG5a00D0
/k>c09VIV@1LG5`0G5aL0451@@0203<c<`0502@T901_Kfl0JFUY06UYJ@1CDe<00P1/K6`01@1cLg<0
QHF508F5Q@1iNGT0EUIF0080J6QX00@0@T92061PH01PH600U9BD0P2KVi/01@28R8P0PH610;Rh^02h
^;P0Lg=c0080S8b<00D0Vi^K08V9R@1ADE40DE5A071`L00206UYJ@0407]kN`2MWId0WIfM08B4Q1D0
oooo=P000?l80?n003T0003o00<0oh000000o`000?l070000?l30?n001@0003o3`3oool000T0oooo
00@0IFEU0:>SX`2SXj<0M7Ad0P1:BTX01@1mOGd0WYjN09jNWP27QhL0GUiN0080O7al00D0OGem09BD
U02DU9@0PX:207alO00205aLG00404M7A`1UIFD0IFEU06MWI`80Ng]k00D0L71`04];B`1MGEd0GEeM
04i>CP020492@P0506m_K`1HF5P0F5QH09JFUP2WYjL00P2<S8`0102NWYh0MWIf07IfMP1cLg<207Ui
N@0506YZJP2m_Kd0NGUi07UiN@1FEUH00P1PH6001@1JFUX0NWYj0:2PX02PX:00YjNW0080YZJV00D0
UIFE07YjNP1jNWX0S8b<07emO@02079bLP0405MGE`1hN7P0N7Qh07moO`80VYZJ00D0^[Zj07=cL`2H
V9P0V9RH08^;R`020::RXP050;Zj^P35aLD0UIFE09FEU@1hN7P00P2h^;P01@2j^[X0WIfM09fMW@1n
OWh0I6AT0080MgMg00@0Ti>C08B4Q024Q8@0QHF50P2BTY801@2j^[X0X:2P05aLG01LG5`0M7Ad0080
GUiN00D0_[jn0<O7a`2g]kL0]kNg0:^[Z`0208B4Q00504A4A03GemL0emOG09FEU@2<S8`00P24Q8@0
101kNg/0OWin07inOP2[Zj/20=GEe@05092@T024Q8@0XJ6Q0:6QX@2n_[h00P1WIfL01@1dM7@0Fe]K
05]KF`30`<00VIVI0080C4a<00D0@d=303De=@0e=CD0=3@d06QXJ002065QH@04059BDP1HF5P0F5QH
07moO`80Lg=c00D0LW9b05YJFP1WIfL0IfMW055AD@0206YZJP0508V9R@2FUYH0UYJF09FEU@2DU9@0
0P2][Jd00`1YJFT0X:2P0:2PX00209RHV080EeMG00@0FEUI04Q8B018B4P0GEeM0P2:RXX00`1hN7P0
oooo0?ooo`0C0?oooc40003o0P3oP01S0000o`<0oh0050000?l?0?ooo`002@3oool0101NGUh0Ti>C
09>CT`1[Jf/204Q8B00507IfMP29RHT0RHV906m_K`1FEUH00P21PH401@1mOGd0U9BD09BDU021PH40
Ng]k0080HV9R00@0F5QH06QXJ01XJ6P0J6QX0P29RHT01@2UYJD0DU9B051@D01@D500EEEE0080BDU9
00D0NWYj059BDP1BDU80UiNG09fMW@0209BDU0040:>SX`1cLg<0Lg=c07EeM@80O7al00D0LW9b0<c<
c024Q8@0Q8B405iNGP02075aL@0506UYJ@1oOgl0ZJVY0:VYZ@2/[:`00P2a/K401@2:RXX0PH610861
P@2BTY80Ph>30080PH6100@0De=C07=cL`1cLg<0UYJF0P2IVIT01@2o_kl0SXj>09jNWP2NWYh0UIFE
0080XZ:R00D0a<C40<;2`P2LW9`0W9bL07AdM0020:VYZ@050:j^[P2][Jd0[Jf]07UiN@1aLG400P2D
U9@0102VYZH0OWin07inOP28R8P208J6QP050;fm_@2[Zj/0Hf=S06=SH`1ZJVX00P1hN7P01@2RXZ80
/;2`0:BTY02TY:@0UYJF0080MWIf00D0@T920<W9b@39bLT0QXJ6092@T00207inOP04071`L01^KVh0
KVi^09fMW@80aLG500D0Q8B408N7Q`2/[:`0[:b/0:j^[P0206i^KP0508:2PP1MGEd0GEeM0:6QX@2L
W9`00P1ADE401@13@d<0BTY:04Y:BP1ADE40Hf=S0080K6a/00@0I6AT04M7A`17AdL0G5aL0P1FEUH0
1@1cLg<0D51@06a/K01/K6`0C4a<0080GemO00D0Ng]k0:6QX@2QXJ40QHF509VIV@020:^[Z`0506AT
I02>SXh0SXj>07moO`2LW9`00P1IFET0101bLW80GEeM05eMG@1mOGd208j>SP0306m_K`3oool0oooo
01<0oooo<@000?l20?n006<0003o0`3oP00D0000o`l0oooo00090?ooo`0405iNGP2CTi<0Ti>C06][
J`80B4Q800D0MWIf08V9R@29RHT0Kfm_05IFEP020861P@0507emO@2DU9@0U9BD0861P@1kNg/00P1R
HV80101HF5P0J6QX06QXJ01XJ6P208V9R@050:FUY@1BDU80D51@051@D01EEED00P19BDT01@1jNWX0
DU9B059BDP2GUiL0WIfM0080U9BD00@0Xj>S07=cL`1cLg<0MGEe0P1lO7`01@1bLW80c<c<08B4Q024
Q8@0GUiN0080LG5a00D0JFUY07moO`2YZJT0ZJVY0:b/[0020;6a/@0508Z:RP21PH40PH6109:BTP23
Ph<00P21PH40101CDe<0Lg=c07=cL`2FUYH209VIV@050;no_`2>SXh0WYjN09jNWP2EUID00P2RXZ80
1@34a<@0`/;209bLW02LW9`0M7Ad0080ZJVY00D0[Zj^0:f][@2][Jd0NGUi075aL@0209BDU0040:JV
YP1nOWh0OWin08R8R080QXJ600D0_Kfm0:^[Z`1SHf<0Hf=S06YZJP0207QhN0050::RXP2`/;00Y:BT
0:BTY02FUYH00P1fMWH01@12@T80bLW90<W9b@26QXH0T92@0080OWin00@0L71`06i^KP1^KVh0WIfM
0P35aLD01@24Q8@0QhN70:b/[02/[:`0[Zj^0080KVi^00D0PX:205eMG@1MGEd0XJ6Q09bLW002055A
D@0504=3@`1:BTX0BTY:055AD@1SHf<00P1/K6`0101TI6@0AdM704M7A`1LG5`205IFEP0507=cL`1@
D500K6a/06a/K01<C4`00P1OGel01@1kNg/0XJ6Q0:6QX@25QHD0VIVI0080Zj^[00D0I6AT08j>SP2>
SXh0Ogmo09bLW00205UIF@04079bLP1MGEd0GEeM07emO@80SXj>00<0Kfm_0?ooo`3oool04`3oool]
0000o`030?n000000?l0oh0000<0oh00<P000?l20?n003h0003o103oP0040000o`l0oooo00090?oo
o`0406ATI02NWYh0WYjN06YZJP80A4A400D0K6a/09jNWP2NWYh0Shn?07EeM@0209ZJVP0508^;R`2R
XZ80XZ:R08j>SP1iNGT00P1CDe<0101KFe/0IfMW06MWI`1XJ6P208n?S`0509fMW@1OGel0GEeM05eM
G@1JFUX00P16ATH01@1mOGd0EEEE05EEE@2PX:00UIFE0080QhN700@0[:b/07MgM`1gMgL0MWIf0P21
PH401@1_Kfl0dm?C09bLW02LW9`0I6AT0080NGUi00D0Jf][09fMW@35aLD0aLG50<30`0020<O7a`05
08n?S`2<S8`0S8b<08j>SP1gMgL00P1hN7P0101KFe/0QXJ608J6QP2ATI4209nOW`050;:b/P2LW9`0
YJFU0:FUY@2>SXh00P2IVIT01@3EeMD0];Bd0:VYZ@2YZJT0SXj>0080[Zj^00D0Xj>S08n?S`2?Shl0
OGem07]kN`0209BDU0040:ZZZP26QXH0QXJ609RHV080TI6A00D0_kno0;^k^`1iNGT0NGUi05UIF@02
07alO0050:^[Z`34a<@0Zj^[0:^[Z`2JVYX00P1_Kfl01@0n?Sh0b/[:0<[:bP25QHD0RHV90080PH61
00@0L71`06i^KP1^KVh0YJFU0P37alL01@27QhL0PH6109^KV`2KVi/0Rh^;0080M7Ad00D0C4a<05IF
EP1FEUH0VYZJ08V9R@0204];B`0503<c<`0d=3@0=3@d04];B`1SHf<00P1QHF40101ZJVX0BTY:04Y:
BP1XJ6P205eMG@0506a/K01GEeL0IVIV06IVIP1>CTh00P1IFET01@2EUID0W9bL09bLW02BTY80Rh^;
0080VYZJ00D0Hf=S0:JVYP2VYZH0T92@0:FUY@0205]KF`0406IVIP1WIfL0IfMW07inOP80QHF500<0
M7Ad0?ooo`3oool04`3oool40000o`D0oh00G0000?l20?n001<0003o0P3oP00a0000o`l0oooo0009
0?ooo`0406EUI@2ATI40TI6A079bLP80ATI600D0K6a/07inOP1nOWh0R8R808F5Q@0209^KV`050820
P02?Shl0Shn?08:2PP1]KFd00P1KFe/0101?Cdl0JFUY06UYJ@1?Cdl207EeM@0508b<S01IFET0FEUI
05UIF@1ADE400P13@d<01@1SHf<0De=C05=CD`2FUYH0Rh^;0080Ph>300@0Xj>S075aL@1aLG40GemO
0P1cLg<01@1]KFd0b/[:08>3P`23Ph<0JVYZ0080QXJ600D0GEeM08R8R02m_Kd0_Kfm0;Ng]`020<71
`@0409:BTP2KVi/0Vi^K092@T0<0PH6100@0EEEE0820P020P800PH610P2[Zj/01@2JVYX0V9RH09>C
T`2CTi<0SXj>0080PH6100D0f][J0;Fe]@2j^[X0^[Zj08n?S`030<;2`P80WYjN00D0Ogmo07=cL`1i
NGT0NGUi096AT@020861P@0509ZJVP2>SXh0SXj>0;Ng]`2f][H00P1bLW801@1FEUH0U9BD09BDU02Z
ZZX0_Kfm0080_kno00@0X:2P07UiN@1iNGT0@d=30P3Fe]H208f=S@80OGem00@0KVi^06a/K01/K6`0
WYjN0P2h^;P01@2<S8`0Rh^;09jNWP2NWYh0QhN70080Ti>C00D0JVYZ05eMG@1MGEd0TY:B09NGU`02
05ADE00503hn?P0k>c/0>c/k05]KF`1JFUX00P1IFET0101VIVH0C4a<04a<C01WIfL205aLG00508B4
Q015ADD0GEeM05eMG@1PH6000P15ADD01@1hN7P0X:2P0:2PX02?Shl0QHF50080W9bL00D0Kfm_0:VY
Z@2YZJT0QHF50:ZZZP0205EEE@0405mOG`1dM7@0M7Ad08N7Q`<0SHf=5@3oool70000o`80oh00:@00
0?l30?n004D0003o1P3oP00]0000o`l0oooo00090?ooo`0406EUI@2ATI40TI6A079bLP80ATI600D0
K6a/07inOP1nOWh0R8R808F5Q@0209^KV`050820P02?Shl0Shn?08:2PP1]KFd00P1KFe/0101?Cdl0
JFUY06UYJ@1?Cdl207EeM@0508b<S01IFET0FEUI05UIF@1ADE400P13@d<01@1SHf<0De=C05=CD`2F
UYH0Rh^;0080Ph>300@0Xj>S075aL@1aLG40GemO0P1cLg<01@1]KFd0b/[:08>3P`23Ph<0JVYZ0080
QXJ600D0GEeM08R8R02m_Kd0_Kfm0;Ng]`020<71`@0409:BTP2KVi/0Vi^K092@T0<0PH6100@0EEEE
0820P020P800PH610P2[Zj/01@2JVYX0V9RH09>CT`2CTi<0SXj>0080PH6100D0f][J0;Fe]@2j^[X0
^[Zj08n?S`030<;2`P80WYjN00D0Ogmo07=cL`1iNGT0NGUi096AT@020861P@0509ZJVP2>SXh0SXj>
0;Ng]`2f][H00P1bLW801@1FEUH0U9BD09BDU02ZZZX0_Kfm0080_kno00@0X:2P07UiN@1iNGT0@d=3
0P3Fe]H208f=S@80OGem00@0KVi^06a/K01/K6`0WYjN0P2h^;P01@2<S8`0Rh^;09jNWP2NWYh0QhN7
0080Ti>C00D0JVYZ05eMG@1MGEd0TY:B09NGU`0205ADE00503hn?P0k>c/0>c/k05]KF`1JFUX00P1I
FET0101VIVH0C4a<04a<C01WIfL205aLG00508B4Q015ADD0GEeM05eMG@1PH6000P15ADD01@1hN7P0
X:2P0:2PX02?Shl0QHF50080W9bL00D0Kfm_0:VYZ@2YZJT0QHF50:ZZZP0205EEE@0405mOG`1dM7@0
M7Ad08N7Q`<0SHf=5@3oool70000o`80oh00:@000?l30?n004D0003o1P3oP00]0000o`l0oooo0009
0?ooo`0406UYJ@2^[Zh0[Zj^07alO080EEEE00D0RXZ:0:FUY@2UYJD0Ti>C07MgM`0209bLW00507in
OP2ATI40TI6A07moO`20P8000P1ADE40100o?cl0G5aL05aLG01NGUh207=cL`0507QhN01DE5@0GEeM
05eMG@1?Cdl00P11@D401@1oOgl0HV9R069RHP2OWil0SHf=0080T92@00@0Xj>S06][J`1[Jf/0IFEU
0P1PH6001@1MGEd0aLG508f=S@2=SHd0IVIV0080Ng]k00D0FUYJ07=cL`2][Jd0[Jf]0;Fe]@020;6a
/@0508B4Q02>SXh0SXj>08Z:RP1nOWh00P2;Rh/0101`L700Shn?08n?S`28R8P20;2`/0050:>SX`2F
UYH0T92@092@T02IVIT00P1iNGT01@3Ogml0ZJVY0:b/[02/[:`0QHF50080`L7100D0_[jn09NGU`2G
UiL0MgMg07=cL`0208B4Q00409JFUP21PH40PH610:j^[P80QhN700D0[jn_0;fm_@1fMWH0MWIf05QH
F002096AT@050:b/[02i^KT0Xj>S0:>SX`1jNWX00P1[Jf/01@0o?cl0clo?0<o?c`2GUiL0RXZ:0080
RHV900@0N7Qh07inOP1nOWh0^;Rh0P3=cLd01@2EUID0UYJF0:BTY02TY:@0QHF50080Y:BT00D0HV9R
08f=S@2=SHd0XZ:R09jNWP0204i>CP0503Lg=`0e=CD0=CDe04m?C`1FEUH00P1:BTX0101[Jf/0FEUI
05UIF@1RHV8205=CD`0508V9R@13@d<0D51@051@D01NGUh00P1?Cdl01@1fMWH0S8b<08b<S02IVIT0
RXZ:0080R8R800D0O7al0;Ng]`2g]kL0VIVI09:BTP02069RHP0405aLG01iNGT0NGUi08Z:RP80Q8B4
00<0Lg=c0?ooo`3oool04`3oool00`000?l0oh000?n0001T0000o`80oh002@000?l00`3oP000003o
0000o`0h0000o`l0oooo00090?ooo`0405ADE02CTi<0Ti>C06EUI@80A4A400D0NWYj0:2PX02PX:00
X:2P08B4Q00209FEU@0508f=S@1mOGd0OGem07inOP1_Kfl00P1GEeL01016ATH0G5aL05aLG01NGUh2
0820P00508B4Q018B4P0IFEU06EUI@1IFET00P17AdL01@22PX80MWIf07IfMP2RXZ80SHf=0080UIFE
00@0[Jf]07YjNP1jNWX0Kfm_0P1ZJVX01@1MGEd0_;bl08F5Q@25QHD0MGEe0080Ng]k00D0HF5Q08j>
SP2i^KT0^KVi0<G5a@020;^k^`0508V9R@2MWId0WIfM092@T023Ph<00P2@T900101hN7P0NWYj07Yj
NP1gMgL20:NWY`80VIVI0P1/K6`01@2ATI40GUiN05iNGP3Hf=P0YJFU0080YZJV00@0UYJF0;^k^`2k
^k/0_Kfm0P21PH401@1/K6`0HF5Q07]kN`1kNg/0QHF50080MGEe00D0X:2P06e]K@1]KFd0VIVI0:2P
X002079bLP05055AD@2<S8`0S8b<0:f][@2k^k/00P2VYZH0102?Shl0Jf][06][J`13@d<20=;BdP05
09JFUP1oOgl0P8200820P01_Kfl00P1bLW801@2^[Zh0`l?30<?3``2OWil0VYZJ0080/[:b00@0Shn?
0;Fe]@2e]KD0M7Ad0P2BTY801@2NWYh0S8b<04I6AP16ATH0=CDe0080<c<c00D0@d=304a<C016ATH0
ATI606i^KP0206YZJP0505ADE01?Cdl0Cdm?08>3P`18B4P00P1:BTX0101dM7@0EUIF05IFEP1jNWX2
09:BTP80RXZ:0P2;Rh/01@28R8P0ZZZZ0:ZZZP2MWId0WYjN0080GUiN00@0EEEE07alO01lO7`0JVYZ
0P1YJFT00`1[Jf/0oooo0?ooo`0C0?ooo`<0oh00;`000?l40?n00340003o0P3oP0070000o`<0oh00
=P000?l30?n000030000o`3oool0oooo00d0oooo00090?ooo`0405ADE02CTi<0Ti>C06EUI@80A4A4
00D0NWYj0:2PX02PX:00X:2P08B4Q00209FEU@0508f=S@1mOGd0OGem07inOP1_Kfl00P1GEeL01016
ATH0G5aL05aLG01NGUh20820P00508B4Q018B4P0IFEU06EUI@1IFET00P17AdL01@22PX80MWIf07If
MP2RXZ80SHf=0080UIFE00@0[Jf]07YjNP1jNWX0Kfm_0P1ZJVX01@1MGEd0_;bl08F5Q@25QHD0MGEe
0080Ng]k00D0HF5Q08j>SP2i^KT0^KVi0<G5a@020;^k^`0508V9R@2MWId0WIfM092@T023Ph<00P2@
T900101hN7P0NWYj07YjNP1gMgL20:NWY`80VIVI0P1/K6`01@2ATI40GUiN05iNGP3Hf=P0YJFU0080
YZJV00@0UYJF0;^k^`2k^k/0_Kfm0P21PH401@1/K6`0HF5Q07]kN`1kNg/0QHF50080MGEe00D0X:2P
06e]K@1]KFd0VIVI0:2PX002079bLP05055AD@2<S8`0S8b<0:f][@2k^k/00P2VYZH0102?Shl0Jf][
06][J`13@d<20=;BdP0509JFUP1oOgl0P8200820P01_Kfl00P1bLW801@2^[Zh0`l?30<?3``2OWil0
VYZJ0080/[:b00@0Shn?0;Fe]@2e]KD0M7Ad0P2BTY801@2NWYh0S8b<04I6AP16ATH0=CDe0080<c<c
00D0@d=304a<C016ATH0ATI606i^KP0206YZJP0505ADE01?Cdl0Cdm?08>3P`18B4P00P1:BTX0101d
M7@0EUIF05IFEP1jNWX209:BTP80RXZ:0P2;Rh/01@28R8P0ZZZZ0:ZZZP2MWId0WYjN0080GUiN00@0
EEEE07alO01lO7`0JVYZ0P1YJFT00`1[Jf/0oooo0?ooo`0C0?ooo`030000o`3oP000oh0002l0003o
00<0oh000000o`000?l07@000?l30?n005@0003o103oP00?0?ooo`002@3oool0101VIVH0X:2P0:2P
X01iNGT2055AD@0507moO`2SXj<0Xj>S09nOW`20P8000P1/K6`01@1nOWh0IVIV06IVIP1cLg<0KFe]
0080GemO00@0>SXj05EEE@1EEED0GUiN0P1]KFd01@1ZJVX0ATI606][J`1[Jf/0FEUI0080A4A400<0
J6QX05YJFP1JFUX00P2CTi<20:2PX0040:>SX`1lO7`0O7al06m_K`80K6a/00D0FUYJ0;>c/`29RHT0
RHV907alO00207MgM`0505YJFP1kNg/0[Zj^0:j^[P36a/H00P2e]KD01@29RHT0SHf=08f=S@2@T900
PX:20080TI6A00@0QHF507]kN`1kNg/0P8200P2b/[801@2FUYH0VIVI08>3P`23Ph<0Vi^K0080K6a/
00D0a/K60:FUY@2OWil0WinO0:BTY0020:f][@050<71`@2ATI40TI6A07UiN@1fMWH00P27QhL01020
P800Lg=c07=cL`26QXH2065QH@050:6QX@2YZJT0Jf][06][J`1@D5000P20P8001@2][Jd0]kNg09ZJ
VP2JVYX0UIFE0080JVYZ00D0Cdm?0=gMg@3MgMd0OWin07]kN`0206e]K@0406EUI@1]KFd0KFe]0;Fe
]@80^;Rh00D0VYZJ0820P02WYjL0YjNW09:BTP020:ZZZP0505aLG02?Shl0Shn?09jNWP29RHT00P1=
CDd01@0i>CT0:BTY02TY:@11@D40BTY:0080?Shn00@0OGem06a/K01/K6`0Fe]K0P1/K6`01@1eMGD0
IfMW04m?C`1?Cdl0N7Qh0080NGUi00D0Ng]k09VIV@2IVIT0VIVI08j>SP0208B4Q005096AT@2JVYX0
VYZJ09ZJVP2OWil00P1HF5P0101MGEd0I6AT06ATI01CDe<207AdM00306m_K`3oool0oooo01<0oooo
00<0003o0?n0003oP000;`000?l00`3oP000003o0000o`0M0000o`<0oh00E0000?l40?n000l0oooo
00090?ooo`0406MWI`2ATI40TI6A079bLP80IVIV00D0PH6109^KV`2KVi/0W9bL08V9R@0207]kN`05
09FEU@1]KFd0KFe]07emO@1gMgL00P1VIVH0101=CDd0FUYJ05YJFP23Ph<207YjNP05069RHP0_;bl0
DU9B059BDP16ATH00P19BDT01@27QhL0E5AD05ADE029RHT0U9BD0080Xj>S00@0Y:BT07]kN`1kNg/0
KVi^0P1`L7001@1UIFD0`<3008N7Q`27QhL0PX:20080Kfm_00D0Fe]K08B4Q02h^;P0^;Rh0=KFeP02
0:j^[P0506e]K@20P800P82008V9R@1hN7P00P2DU9@01020P800KFe]06e]K@1UIFD20::RXP0507=c
L`2[Zj/0VIVI09VIV@2WYjL00P1OGel01@3De=@0WYjN09BDU02DU9@0XJ6Q0080VYZJ00D0][Jf09:B
TP2BTY80MgMg07inOP0208f=S@0408j>SP22PX80PX:208b<S080Lg=c00D0WYjN0:NWY`1fMWH0MWIf
06e]K@0207MgM`0509fMW@2VYZH0UYJF09JFUP2CTi<00P1QHF401@1ADE40f][J0=[JfP2@T900Lg=c
0080NGUi00@0IVIV07QhN01hN7P0`<300P2e]KD01@2UYJD0QhN70:>SX`2SXj<0P8200080Zj^[00D0
Hf=S08>3P`23Ph<0Shn?092@T002061PH00503@d=00[:b/0:b/[03lo?`11@D400P0d=3@0101IFET0
IVIV06IVIP1JFUX206MWI`0506YZJP1PH600DE5A055AD@1RHV800P1`L7001@1hN7P0WIfM09fMW@2E
UID0R8R80080Ng]k00D0Rh^;0:FUY@2UYJD0YZJV08V9R@02071`L00406YZJP1kNg/0Ng]k05aLG080
Lg=c00<0IFEU0?ooo`3oool04`3oool80000o`@0oh001`000?l00`3oP000003o0000o`0Z0000o`03
0?n000000?l0003o06X0003o3`3oool000T0oooo00@0M7Ad09ZJVP2JVYX0O7al0P1MGEd01@1jNWX0
T92@092@T02NWYh0XJ6Q0080Jf][00D0Ogmo06IVIP1VIVH0MWIf07=cL`02061PH00404i>CP1TI6@0
I6AT08n?S`80UiNG00D0Ph>303Ti>@1`L700L71`079bLP0205mOG`0507emO@1EEED0EEEE08n?S`2=
SHd00P2KVi/0102RXZ80NWYj07YjNP1[Jf/2079bLP0505YJFP32`/80R8R808R8R021PH400P1oOgl0
1@1MGEd0Ti>C0;^k^`2k^k/0f][J0080Zj^[00D0De=C04e=C@1=CDd0P82006e]K@0208B4Q00407If
MP1VIVH0IVIV06i^KP80/K6a00D0Ph>30:f][@2FUYH0UYJF0:6QX@0205UIF@050=oOg`2RXZ80Vi^K
09^KV`2h^;P00P2GUiL01@39bLT0SHf=08f=S@1lO7`0PH610080Ti>C00@0Rh^;09nOW`2OWil0XZ:R
0P20P8001@2WYjL0^k^k07UiN@1iNGT0PH610080Ogmo00D0WYjN0:VYZ@2_[jl0[jn_08^;R`0205QH
F005051@D03Bd]80d];B08R8R01SHf<00P1^KVh0101FEUH0LG5a075aL@3;bl/20;jn_P050:VYZ@23
Ph<0Vi^K09^KV`2=SHd00P2e]KD01@1SHf<0OWin07inOP2OWil0Y:BT0080MWIf00D0@d=303hn?P0n
?Sh0De=C059BDP020492@P0407]kN`1<C4`0C4a<04m?C`80Jf][00D0IVIV05IFEP15ADD0ADE504A4
A002051@D00507moO`2QXJ40XJ6Q09NGU`29RHT00P2ATI401@2>SXh0Ogmo07moO`2EUID0OWin0080
KVi^00@0LW9b08J6QP26QXH0Hf=S0P1aLG400`1gMgL0oooo0?ooo`0C0?oooaL0003o0`3oP01]0000
o`<0oh008`000?l?0?ooo`002@3oool0101dM7@0VYZJ09ZJVP1lO7`205eMG@0507YjNP2@T900T92@
09jNWP2QXJ400P1[Jf/01@1oOgl0IVIV06IVIP1fMWH0Lg=c0080H61P00@0CTi>06ATI01TI6@0Shn?
0P2GUiL01@23Ph<0>CTi071`L01`L700LW9b0080GemO00D0OGem05EEE@1EEED0Shn?08f=S@0209^K
V`040::RXP1jNWX0NWYj06][J`80LW9b00D0FUYJ0<;2`P28R8P0R8R80861P@0207moO`0505eMG@2C
Ti<0^k^k0;^k^`3Jf]X00P2[Zj/01@1CDe<0CDe=04e=C@20P800KFe]0080Q8B400@0MWIf06IVIP1V
IVH0KVi^0P2a/K401@23Ph<0[Jf]09JFUP2FUYH0XJ6Q0080FEUI00D0gmoO0::RXP2KVi/0Vi^K0;Rh
^00209NGU`050<W9b@2=SHd0SHf=07alO021PH400P2CTi<0102;Rh/0WinO09nOW`2RXZ820820P005
0:NWY`2k^k/0NGUi07UiN@21PH400P1oOgl01@2NWYh0ZJVY0:n_[`2_[jl0Rh^;0080F5QH00D0D51@
0=;BdP3Bd]80R8R806=SH`0206i^KP0405IFEP1aLG40LG5a0<_;b`80_[jn00D0ZJVY08>3P`2KVi/0
Vi^K08f=S@020;Fe]@0506=SH`1nOWh0OWin09nOW`2TY:@00P1fMWH01@13@d<0?Shn03hn?P1CDe<0
DU9B0080@T9200@0Ng]k04a<C01<C4`0Cdm?0P1[Jf/01@1VIVH0EUIF04E5A@15ADD0A4A40080D51@
00D0Ogmo0:6QX@2QXJ40UiNG08V9R@02096AT@0508j>SP1oOgl0Ogmo09FEU@1nOWh00P1^KVh0101b
LW80QXJ608J6QP1SHf<2075aL@0307MgM`3oool0oooo01<0oooo40000?l<0?n001X0003o1@3oP00J
0000o`L0oh004@000?l20?n001@0003o00@0oh000000o`000?l0003o0P3oP0090000o`<0oh002000
0?l40?n000`0003o3`3oool000T0oooo00@0IFEU08f=S@2=SHd0MWIf0P1:BTX01@23Ph<0X:2P0:2P
X02MWId0P8200080N7Qh00D0NWYj05IFEP1FEUH0M7Ad07=cL`0205]KF`0403<c<`0k>c/0>c/k06QX
J080Ogmo00D0M7Ad03<c<`1JFUX0FUYJ06=SH`02059BDP0507IfMP1JFUX0FUYJ096AT@2DU9@00P2[
Zj/0102d];@0TI6A096AT@1dM7@206a/K00504e=C@2j^[X0Rh^;08^;R`20P8000P24Q8@01@1JFUX0
Shn?0;Bd]02d];@0dM7A0080WYjN00D0NWYj05aLG01LG5`0OGem075aL@0208F5Q@0409>CT`1OGel0
GemO06a/K080/K6a00D0Rh^;0:JVYP2EUID0UIFE0:^[Z`0205aLG0050<_;b`2DU9@0TY:B09:BTP2V
YZH00P29RHT01@2l_;`0QhN708N7Q`1cLg<0IVIV0080NGUi00@0Lg=c08R8R028R8P0UiNG0P1gMgL0
1@2UYJD0ZJVY079bLP1bLW80PH610080O7al00D0T92@0:2PX02i^KT0^KVi09JFUP02075aL@05069R
HP3QhN40hN7Q09>CT`1TI6@00P27QhL0101WIfL0Ogmo07moO`3EeMD20<30`0050;Fe]@1mOGd0WYjN
09jNWP21PH400P2g]kL01@1bLW80OGem07emO@2MWId0YjNW0080MgMg00D0>c/k03Xj>P0j>SX0ATI6
04i>CP020410@00407YjNP1MGEd0GEeM051@D080EeMG00D0D51@05]KF`1SHf<0Hf=S05]KF`02051@
D00506][J`2RXZ80XZ:R08V9R@2MWId00P2UYJD01@2BTY80V9RH09RHV02l_;`0RHV90080OGem00@0
K6a/07MgM`1gMgL0DE5A0P1oOgl00`1aLG40oooo0?ooo`0C0?oooa00003o303oP00J0000o`D0oh00
6P000?l70?n00140003o0P3oP00D0000o`040?n000000?l0003o0000o`80oh002@000?l30?n000P0
003o103oP00<0000o`l0oooo00090?ooo`0406MWI`25QHD0QHF507AdM080ATI600D0SXj>0:6QX@2Q
XJ40Vi^K08n?S`0209JFUP0507emO@1VIVH0IVIV08F5Q@1oOgl00P1QHF401015ADD0Cdm?04m?C`1[
Jf/2096AT@0506][J`0a<C40GemO05mOG`1ZJVX00P1UIFD01@2:RXX0HF5Q065QH@2GUiL0VIVI0080
YZJV00@0/;2`08^;R`2;Rh/0Jf][0P1/K6`01@1GEeL0`l?308R8R028R8P0O7al0080S8b<00D0Cdm?
092@T02l_;`0_;bl0=KFeP0209nOW`05079bLP1QHF40HF5Q08B4Q01jNWX00P27QhL0102:RXX0Fe]K
05]KF`1ZJVX20::RXP0508>3P`2QXJ40Ti>C09>CT`2IVIT00P1WIfL01@3Ogml0Xj>S09bLW02LW9`0
/k>c0080Vi^K00D0c/k>08j>SP2>SXh0Q8B407]kN`0208J6QP0407UiN@2SXj<0Xj>S08N7Q`80GUiN
00D0Xj>S0;Bd]01mOGd0OGem07inOP0207MgM`0508V9R@2PX:00[:b/0:b/[020P8000P1^KVh01@1R
HV80g=cL0=cLg02HV9P0Kfm_0080Ng]k00@0JVYZ07MgM`1gMgL0aLG50P2k^k/01@2i^KT0PH6109nO
W`2OWil0Ogmo0080ZJVY00D0Ogmo08>3P`23Ph<0XZ:R0;6a/@0207inOP0504A4A010@400@410061P
H01ZJVX00P1JFUX0102:RXX0M7Ad07AdM01SHf<206ATI00505YJFP1RHV80GUiN05iNGP17AdL00P11
@D401@20P800Vi^K09^KV`2RXZ80Shn?0080Xj>S00D0OWin08B4Q024Q8@0/K6a0820P00209JFUP04
06UYJ@1gMgL0MgMg05aLG080NWYj00<0Ng]k0?ooo`3oool04`3oool90000o`80oh000`000?l80?n0
03H0003o0P3oP0040000o`H0oh0040000?l00`3oP000003o0000o`0K0000o`@0oh004`000?l40?n0
00`0003o3`3oool000T0oooo00@0IfMW08F5Q@25QHD0M7Ad0P16ATH01@2>SXh0XJ6Q0:6QX@2KVi/0
Shn?0080UYJF00D0OGem06IVIP1VIVH0QHF507moO`02065QH@0404E5A@1?Cdl0Cdm?06][J`80TI6A
00D0Jf][034a<@1OGel0GemO06YZJP0206EUI@0508Z:RP1QHF40HF5Q09NGU`2IVIT00P2VYZH0102`
/;00Rh^;08^;R`1[Jf/206a/K00505MGE`33`l<0R8R808R8R01lO7`00P2<S8`01@1?Cdl0T92@0;bl
_02l_;`0e]KF0080WinO00D0LW9b065QH@1QHF40Q8B407YjNP0208N7Q`0408Z:RP1KFe/0Fe]K06YZ
JP80XZ:R00D0Ph>30:6QX@2CTi<0Ti>C09VIV@0206MWI`050=oOg`2SXj<0W9bL09bLW02c/k<00P2K
Vi/01@3>c/h0SXj>08j>SP24Q8@0Ng]k0080QXJ600@0NGUi0:>SX`2SXj<0QhN70P1NGUh01@2SXj<0
];Bd07emO@1mOGd0OWin0080MgMg00D0RHV90:2PX02/[:`0[:b/0820P00206i^KP05069RHP3Lg=`0
g=cL09RHV01_Kfl00P1kNg/0101ZJVX0MgMg07MgM`35aLD20;^k^`050;Vi^@21PH40WinO09nOW`1o
Ogl00P2YZJT01@1oOgl0Ph>308>3P`2RXZ80/K6a0080OWin00D0A4A40410@010@400H61P06YZJP02
05YJFP0408Z:RP1dM7@0M7Ad06=SH`80I6AT00D0FUYJ069RHP1NGUh0GUiN04M7A`020451@@050820
P02KVi/0Vi^K0::RXP2?Shl00P2SXj<01@1nOWh0Q8B408B4Q02a/K40P8200080UYJF00@0JFUY07Mg
M`1gMgL0G5aL0P1jNWX00`1kNg/0oooo0?ooo`0C0?oooe80003o1@3oP00`0000o`L0oh007`000?l?
0?ooo`002@3oool0101XJ6P0SHf=08f=S@1nOWh204e=C@0509BDU02IVIT0VIVI09JFUP2:RXX00P2D
U9@01@20P800MgMg07MgM`25QHD0PX:20080HV9R00@0De=C05mOG`1OGel0KVi^0P2CTi<01@1gMgL0
=CDe05UIF@1IFET0KVi^0080IFEU00D0MGEe05aLG01LG5`0SHf=09FEU@020:JVYP040;6a/@2FUYH0
UYJF07AdM080L71`00D0GEeM0<[:bP29RHT0RHV908J6QP0208n?S`0504U9B@2IVIT0`l?30<?3``3C
dm<00P2QXJ401@1]KFd0IVIV06IVIP2=SHd0QHF50080QXJ600@0R8R805EEE@1EEED0J6QX0P2KVi/0
1@2<S8`0Shn?08B4Q024Q8@0X:2P0080KVi^00D0fMWI0;:b/P2GUiL0UiNG0;jn_P0209JFUP050;jn
_P1gMgL0MgMg07AdM01aLG400P21PH40101]KFd0X:2P0:2PX01oOgl205]KF`050:BTY02][Jd0NGUi
07UiN@27QhL00P1eMGD01@1oOgl0YJFU0:f][@2][Jd0O7al0080Lg=c00D0EEEE0>3Ph03Ph>00S8b<
06a/K00207AdM00406UYJ@26QXH0QXJ60<?3``80^[Zj00D0]kNg06m_K`2YZJT0ZJVY0820P00209ZJ
VP0508F5Q@1kNg/0Ng]k09RHV02i^KT00P1fMWH01@10@400?3`l03`l?01GEeL0KVi^0080GemO00@0
KVi^06e]K@1]KFd0J6QX0P1NGUh01@1GEeL0Jf][069RHP1RHV80FEUI0080ATI600D0Hf=S096AT@2A
TI40WYjN09JFUP020;Jf]P0507MgM`2?Shl0Shn?0:b/[020P8000P22PX80101MGEd0M7Ad07AdM01b
LW8208R8R00307EeM@3oool0oooo01<0ooooA0000?l20?n005l0003o1@3oP0030000o`l0oooo0009
0?ooo`0407YjNP2=SHd0SHf=08B4Q080DU9B0`2LW9`01@2>SXh0S8b<08n?S`2?Shl0L71`0080KFe]
00D0J6QX06YZJP1MGEd0GEeM04i>CP0205aLG00506YZJP2@T900T92@06e]K@0b<S800P1DE5@0101I
FET0E5AD05ADE01fMWH205IFEP0509JFUP2EUID0YJFU0:FUY@2VYZH00P2CTi<01@1`L700MGEe07Ee
M@1LG5`0a/K60080W9bL00D0OGem07IfMP1fMWH0ATI609BDU0020;Fe]@040=CDe02CTi<0Ti>C07Ad
M080J6QX00D0WinO09:BTP1lO7`0O7al09bLW00206IVIP0506m_K`2a/K40/K6a0:f][@2`/;000P2R
XZ801@2_[jl0MWIf07IfMP3Hf=P0ZZZZ0080X:2P00@0`<300:^[Z`2[Zj/0alO70P1iNGT01@1fMWH0
Lg=c06m_K`1_Kfl0CTi>0080O7al00D0LW9b06EUI@1UIFD0YZJV0;Jf]P02092@T00508J6QP1dM7@0
M7Ad08J6QP2WYjL00P2m_Kd0101_Kfl0P8200820P01HF5P20=kNgP0509VIV@1gMgL0PX:208:2PP1^
KVh00P2?Shl01@3=cLd0`l?30<?3``2c/k<0KFe]0080XJ6Q00@0RHV909ZJVP2JVYX0N7Qh0P1mOGd0
1@27QhL0_;bl06MWI`1WIfL0>3Ph0080;Rh^00D0ADE505aLG01PH600H61P05]KF`0206YZJP0505YJ
FP1IFET0FEUI05QHF01OGel00P1^KVh0101bLW80EUIF05IFEP1iNGT209RHV0050:FUY@2=SHd0_kno
0;no_`1_Kfl00P27QhL01@2ZZZX0OWin06m_K`1_Kfl0E5AD0080C4a<00@0FUYJ05aLG01LG5`0Fe]K
5@3ooom40000o`80oh00G`000?l50?n000<0003o3`3oool000T0oooo00@0NWYj08f=S@2=SHd0Q8B4
0P1BDU8309bLW00508j>SP2<S8`0Shn?08n?S`1`L7000P1]KFd01@1XJ6P0JVYZ05eMG@1MGEd0CTi>
0080G5aL00D0JVYZ092@T02@T900KFe]038b<P0205ADE00405UIF@1DE5@0E5AD07IfMP80EUIF00D0
UYJF09FEU@2UYJD0YJFU0:JVYP0209>CT`05071`L01eMGD0MGEe05aLG036a/H00P2LW9`01@1mOGd0
MWIf07IfMP16ATH0U9BD0080]KFe00@0e=CD09>CT`2CTi<0M7Ad0P1XJ6P01@2OWil0TY:B07alO01l
O7`0W9bL0080IVIV00D0Kfm_0;6a/@2a/K40[Jf]0;2`/0020::RXP050:n_[`1fMWH0MWIf0=SHf02Z
ZZX00P2PX:001030`<00Zj^[0:^[Z`37alL207UiN@0507IfMP1cLg<0Kfm_06m_K`1>CTh00P1lO7`0
1@1bLW80IFEU06EUI@2VYZH0][Jf0080T92@00D0QXJ607AdM01dM7@0QXJ60:NWY`020;fm_@0406m_
K`20P800P82005QHF080g]kN00D0VIVI07MgM`22PX80PX:206i^KP0208n?S`050<g=c@33`l<0`l?3
0;>c/`1]KFd00P2QXJ401029RHT0VYZJ09ZJVP1hN7P207emO@0508N7Q`2l_;`0IfMW06MWI`0h>3P0
0P0^;Rh01@15ADD0G5aL061PH01PH600Fe]K0080JVYZ00D0FUYJ05UIF@1IFET0F5QH05mOG`0206i^
KP04079bLP1FEUH0EUIF07UiN@80V9RH00D0YJFU08f=S@2o_kl0_kno06m_K`0208N7Q`050:ZZZP1n
OWh0Kfm_06m_K`1DE5@00P1<C4`0101JFUX0G5aL05aLG01KFe/E0?oooeD0003o0`3oP00H0000o`<0
oh00<@000?l50?n000@0003o3`3oool000T0oooo00@0LG5a08R8R028R8P0O7al0P1BDU801@2>SXh0
Vi^K09^KV`1dM7@0PX:20080SXj>00D0K6a/071`L01`L700NGUi05]KF`0205UIF@0404Y:BP1EEED0
EEEE07IfMP80V9RH00D0QHF503`l?01VIVH0IVIV05UIF@0205=CD`0507]kN`1HF5P0F5QH09jNWP2M
WId00P2/[:`0102[Zj/0UiNG09NGU`1^KVh2079bLP0505]KF`3?cll0ZJVY0:VYZ@2;Rh/00P1kNg/0
1@1PH600N7Qh08f=S@2=SHd0`l?30080VYZJ00D0MgMg05iNGP1NGUh0SHf=09FEU@0207MgM`0409nO
W`1NGUh0GUiN06IVIP80bl_;00D0^[Zj0:^[Z`2LW9`0W9bL0;6a/@0207emO@050>3Ph02a/K40ZZZZ
0:ZZZP2/[:`00P2[Zj/01@2o_kl0O7al07alO025QHD0KVi^0080Ng]k00@0Cdm?09RHV02HV9P0N7Qh
0P1bLW801@2g]kL0`l?30:BTY02TY:@0UYJF0080OWin00D0Rh^;0:VYZ@2j^[X0^[Zj061PH00207em
O@0505aLG03MgMd0gMgM09VIV@1_Kfl00P1eMGD0101UIFD0Lg=c07=cL`2i^KT20;>c/`050:n_[`1n
OWh0Ph>308>3P`20P8000P2FUYH01@23Ph<0S8b<08b<S027QhL0`L710080FEUI00D0=cLg02/[:`0[
:b/0AdM705]KF`0205UIF@04055AD@1>CTh0CTi>05ADE080EEEE00D0BTY:07IfMP1YJFT0JFUY0820
P00206ATI00506UYJ@2@T900T92@0:j^[P2KVi/00P3Fe]H01@1OGel0S8b<08b<S02UYJD0U9BD0080
K6a/00@0AdM7055AD@1ADE40Kfm_0P1OGel00`1DE5@0oooo0?ooo`0C0?oooaH0003o0P3oP00J0000
o`<0oh003`000?l00`3oP000003o0000o`1V0000o`l0oooo00090?ooo`0407emO@2KVi/0Vi^K08f=
S@80Cdm?00D0TY:B09jNWP2NWYh0P82008Z:RP0209nOW`0507UiN@1kNg/0Ng]k07inOP1LG5`00P1M
GEd0100i>CT0FEUI05UIF@23Ph<209:BTP0506YZJP0a<C40ADE504E5A@0k>c/00P1FEUH01@1]KFd0
CDe=04e=C@2IVIT0Shn?0080/[:b00@0Xj>S08n?S`2?Shl0FEUI0P1KFe/01@1FEUH0bLW909JFUP2F
UYH0QHF50080Lg=c00D0Kfm_08N7Q`2ZZZX0ZZZZ0=?Cd`02092@T00508n?S`1`L700L71`09bLW02Q
XJ400P25QHD0102RXZ80Hf=S06=SH`1MGEd20;Jf]P050:NWY`2HV9P0Rh^;08^;R`2KVi/00P1kNg/0
1@3@d=00/K6a09BDU02DU9@0UYJF0080U9BD00D0[jn_08B4Q024Q8@0N7Qh07EeM@0207alO004055A
D@2LW9`0W9bL07EeM@80Q8B400D0][Jf0<71`@2=SHd0SHf=09ZJVP0206][J`0507moO`2HV9P0e]KF
0=KFeP1TI6@00P22PX801@1SHf<0hN7Q0>7Qh@2CTi<0JFUY0080Ng]k0`1[Jf/01@2`/;00_Kfm0;fm
_@2YZJT0GUiN0080S8b<00@0TI6A09ZJVP2JVYX0O7al0P2;Rh/01@25QHD0_kno04e=C@1=CDd0>SXj
0080:RXZ00D0B4Q805eMG@1^KVh0KVi^04i>CP0205YJFP05051@D01BDU80DU9B05YJFP1bLW800P1/
K6`0102BTY80E5AD05ADE01YJFT2096AT@050:6QX@1bLW80`L710<71`@1FEUH00P2OWil01@2QXJ40
SXj>07inOP1nOWh0FUYJ0080H61P00@0QHF507AdM01dM7@0J6QX5@3ooolK0000o`030?n000000?l0
003o02h0003o00<0oh000000o`000?l0EP000?l30?n000030000o`3oP000oh000080oh003`3oool0
00T0oooo00@0KFe]08N7Q`27QhL0Ogmo0P17AdL01@27QhL0VIVI09VIV@1kNg/0R8R80080Ti>C00D0
LG5a06EUI@1UIFD0Lg=c05EEE@02065QH@0406IVIP1NGUh0GUiN06IVIP80NGUi00@0E5AD024Q8@14
A4@0A4A40`1EEED01@1[Jf/0H61P061PH02>SXh0R8R80080ZZZZ00@0YZJV09^KV`2KVi/0JVYZ0P1R
HV801@1JFUX0^[Zj09NGU`2GUiL0OGem0080QHF500D0F5QH07inOP2YZJT0ZJVY0=?Cd`0208>3P`05
092@T01eMGD0MGEe0:BTY02RXZ800P2:RXX0102=SHd0H61P061PH01BDU820:RXZ0050:JVYP2KVi/0
T92@092@T02QXJ400P29RHT01@3GemL0bl_;09RHV02HV9P0VIVI0080V9RH00D0/[:b08b<S02<S8`0
R8R806EUI@0207AdM004059BDP1kNg/0Ng]k06YZJP80Shn?00D0Y:BT0<k>cP23Ph<0Ph>30820P002
06=SH`0508:2PP2DU9@0clo?0<o?c`1CDe<00P1kNg/01@1VIVH0g=cL0=cLg02?Shl0Jf][0080LG5a
00@0G5aL06a/K01/K6`0]KFe0P2k^k/01@2d];@0J6QX09ZJVP2JVYX0WYjN0080V9RH00D0PH6108j>
SP2>SXh0Shn?0<[:bP0205ADE0050451@@0Z:RX0:RXZ04a<C01eMGD00P1TI6@0101KFe/0JFUY06UY
J@1VIVH205YJFP0504a<C01kNg/0F5QH05QHF01gMgL00P18B4P01@1BDU80MgMg07MgM`26QXH0SHf=
0080bl_;00D0H61P09^KV`2KVi/0VIVI09fMW@0205iNGP0405MGE`1TI6@0I6AT08B4Q080JVYZ00<0
Fe]K0?ooo`3oool04`3ooolK0000o`030?n000000?l0003o02h0003o00<0oh000000o`000?l0EP00
0?l30?n000030000o`3oP000oh000080oh003`3oool000T0oooo00@0KFe]08N7Q`27QhL0Ogmo0P17
AdL01@27QhL0VIVI09VIV@1kNg/0R8R80080Ti>C00D0LG5a06EUI@1UIFD0Lg=c05EEE@02065QH@04
06IVIP1NGUh0GUiN06IVIP80NGUi00@0E5AD024Q8@14A4@0A4A40`1EEED01@1[Jf/0H61P061PH02>
SXh0R8R80080ZZZZ00@0YZJV09^KV`2KVi/0JVYZ0P1RHV801@1JFUX0^[Zj09NGU`2GUiL0OGem0080
QHF500D0F5QH07inOP2YZJT0ZJVY0=?Cd`0208>3P`05092@T01eMGD0MGEe0:BTY02RXZ800P2:RXX0
102=SHd0H61P061PH01BDU820:RXZ0050:JVYP2KVi/0T92@092@T02QXJ400P29RHT01@3GemL0bl_;
09RHV02HV9P0VIVI0080V9RH00D0/[:b08b<S02<S8`0R8R806EUI@0207AdM004059BDP1kNg/0Ng]k
06YZJP80Shn?00D0Y:BT0<k>cP23Ph<0Ph>30820P00206=SH`0508:2PP2DU9@0clo?0<o?c`1CDe<0
0P1kNg/01@1VIVH0g=cL0=cLg02?Shl0Jf][0080LG5a00@0G5aL06a/K01/K6`0]KFe0P2k^k/01@2d
];@0J6QX09ZJVP2JVYX0WYjN0080V9RH00D0PH6108j>SP2>SXh0Shn?0<[:bP0205ADE0050451@@0Z
:RX0:RXZ04a<C01eMGD00P1TI6@0101KFe/0JFUY06UYJ@1VIVH205YJFP0504a<C01kNg/0F5QH05QH
F01gMgL00P18B4P01@1BDU80MgMg07MgM`26QXH0SHf=0080bl_;00D0H61P09^KV`2KVi/0VIVI09fM
W@0205iNGP0405MGE`1TI6@0I6AT08B4Q080JVYZ00<0Fe]K0?ooo`3oool04`3ooolD0000o`<0oh00
UP000?l?0?ooo`002@3oool0101oOgl0TI6A096AT@20P80204];B`0508Z:RP2IVIT0VIVI07emO@1k
Ng/00P29RHT01@1QHF40J6QX06QXJ01gMgL0FUYJ0080H61P00@0Fe]K06MWI`1WIfL0L71`0P1dM7@0
1@1QHF40<S8b05ADE01DE5@0Fe]K0080EeMG00D0O7al04A4A014A4@0S8b<08R8R0020:^[Z`040:RX
Z02KVi/0Vi^K06QXJ080IFEU00D0GemO0<30`02JVYX0VYZJ08Z:RP0206e]K@0504=3@`2<S8`0ZJVY
0:VYZ@3<c<`00P2:RXX01@2FUYH0Kfm_06m_K`2VYZH0XZ:R00<0Rh^;0P1]KFd01@1ZJVX0YjNW0:NW
Y`2[Zj/0VYZJ0080TY:B00D0Z:RX09NGU`2GUiL0bLW90<[:bP0208j>SP0409>CT`2FUYH0UYJF0:b/
[080UIFE00D0S8b<06i^KP1dM7@0M7Ad05IFEP0209VIV@0507QhN02?Shl0Shn?0:>SX`34a<@00P1e
MGD01@20P800FEUI05UIF@1kNg/0WIfM0080g=cL00@0F5QH07moO`1oOgl0L71`0P3Rh^801@2IVIT0
LG5a07YjNP1jNWX0Fe]K0080IfMW00D0YJFU0:VYZ@2YZJT0[Zj^06EUI@0208j>SP0409:BTP2EUID0
UIFE08j>SP80V9RH00D0VIVI0<c<c01GEeL0EeMG04=3@`0202`/;00303/k>`1UIFD0EeMG0080EeMG
0P1aLG401@1VIVH0FEUI05UIF@1IFET0JFUY0080H61P00@0R8R802h^;P0^;Rh0GEeM0P25QHD01@2=
SHd0KVi^0:JVYP2VYZH0JFUY0080SXj>00D0X:2P0:6QX@1KFe/0Fe]K05eMG@0206e]K@0407alO01D
E5@0E5AD069RHQD0ooooJ@000?l20?n000P0003o103oP00f0000o`l0oooo00090?ooo`0407=cL`2D
U9@0U9BD08J6QP80C4a<00D0TI6A0:>SX`2SXj<0QXJ608>3P`0209BDU005079bLP1TI6@0I6AT071`
L01NGUh00P1LG5`0101QHF40Hf=S06=SH`24Q8@209ZJVP0507moO`0l?3`0KVi^06i^KP1`L7000P1L
G5`01@29RHT0Bd];04];B`2PX:00U9BD0080Zj^[00@0Z:RX09jNWP2NWYh0GUiN0P1TI6@01@1RHV80
^k^k09NGU`2GUiL0QhN70080IfMW00D0@d=307alO02[Zj/0Zj^[0<[:bP02092@T00509JFUP1/K6`0
K6a/0:6QX@2`/;000`24Q8@206EUI@0506][J`2_[jl0[jn_0;bl_02SXj<00P2TY:@01@2ZZZX0UYJF
09JFUP37alL0fMWI0080UiNG00@0Shn?0:JVYP2VYZH0Z:RX0P2WYjL01@2?Shl0Lg=c07IfMP1fMWH0
GUiN0080Vi^K00D0O7al09NGU`2GUiL0Shn?0;6a/@0206m_K`0508N7Q`1NGUh0GUiN06m_K`2ATI40
0P3Bd]80101>CTh0IfMW06MWI`1KFe/20;Jf]P0507emO@1UIFD0M7Ad07AdM01PH6000P1fMWH01@37
alL0clo?0<o?c`2l_;`0LG5a0080QXJ600@0R8R8096AT@2ATI40PX:20P1lO7`01@25QHD0`L7105AD
E01DE5@0@41000809bLW00D0>SXj05YJFP1CDe<0De=C05MGE`0207=cL`0506=SH`1YJFT0JFUY05aL
G01OGel00P1ADE401023Ph<0>SXj03Xj>P0j>SX2069RHP0507inOP21PH40][Jf0;Jf]P1mOGd00P23
Ph<01@2HV9P0Zj^[04m?C`1?Cdl0G5aL0080JVYZ00@0Jf][05=CD`1CDe<0Hf=S5@3ooomY0000o`80
oh0020000?l40?n003H0003o3`3oool000T0oooo00@0Lg=c09BDU02DU9@0QXJ60P1<C4`01@2ATI40
Xj>S0:>SX`26QXH0Ph>30080U9BD00D0LW9b06ATI01TI6@0L71`05iNGP0205aLG004065QH@1SHf<0
Hf=S08B4Q080VYZJ00D0Ogmo03`l?01^KVh0KVi^071`L00205aLG00508V9R@1;Bd/0Bd];0:2PX02D
U9@00P2[Zj/0102XZ:P0WYjN09jNWP1NGUh206ATI005069RHP2k^k/0UiNG09NGU`27QhL00P1WIfL0
1@13@d<0O7al0:^[Z`2[Zj/0b/[:0080T92@00D0UYJF06a/K01/K6`0XJ6Q0;2`/00308B4Q080IFEU
00D0Jf][0:n_[`2_[jl0_;bl0:>SX`020:BTY0050:ZZZP2FUYH0UYJF0<O7a`3IfMT00P2GUiL0102?
Shl0YZJV0:JVYP2XZ:P20:NWY`0508n?S`1cLg<0MWIf07IfMP1NGUh00P2KVi/01@1lO7`0UiNG09NG
U`2?Shl0/K6a0080Kfm_00D0QhN705iNGP1NGUh0Kfm_096AT@020=;BdP0404i>CP1WIfL0IfMW05]K
F`80][Jf00D0OGem06EUI@1dM7@0M7Ad061PH00207IfMP050<O7a`3?cll0clo?0;bl_01aLG400P26
QXH01028R8P0TI6A096AT@22PX8207alO00508F5Q@31`L40E5AD05ADE010@4000P0W9bL01@0j>SX0
FUYJ05=CD`1CDe<0EeMG0080Lg=c00D0Hf=S06UYJ@1YJFT0G5aL05mOG`02055AD@0408>3P`0j>SX0
>SXj03Xj>P80HV9R00D0OWin0861P@2f][H0][Jf07emO@0208>3P`0509RHV02[Zj/0Cdm?04m?C`1L
G5`00P1ZJVX0101[Jf/0De=C05=CD`1SHf<E0?oooa<0003o1@3oP01=0000o`80oh000P000?l30?n0
00030000o`3oP000oh0000<0003o103oP00M0000o`P0oh0010000?l30?n00080003o0P3oP0070000
o`l0oooo00090?ooo`0406=SH`28R8P0R8R807MgM`80Cdm?00D0TY:B09^KV`2KVi/0Q8B408V9R@02
08f=S@0506ATI01XJ6P0J6QX06i^KP1FEUH00P1ADE40101RHV80H61P061PH01jNWX208f=S@05075a
L@0j>SX0IfMW06MWI`1QHF400P1CDe<01@1oOgl0G5aL05aLG022PX80UIFE0080];Bd00@0ZJVY09fM
W@2MWId0IFEU0P1YJFT01@1^KVh0a/K60;Fe]@2e]KD0V9RH0080Lg=c00D0Fe]K07emO@2@T900T92@
0<;2`P020:BTY00508j>SP1[Jf/0Jf][09JFUP2OWil00P1kNg/0101]KFd0J6QX06QXJ01TI6@20:VY
Z@050;jn_P2UYJD0XZ:R0::RXP2_[jl00P2DU9@01@36a/H0d=3@08j>SP2>SXh0Shn?0080[Zj^00D0
XJ6Q0:FUY@2UYJD0PX:206][J`0206i^KP0405QHF02IVIT0VIVI079bLP80TY:B00D0RHV90<W9b@1Z
JVX0JVYZ07alO00205EEE@05075aL@2l_;`0^[Zj0;Zj^P1HF5P00P1fMWH01@1_Kfl0h^;R0>;RhP2E
UID0JVYZ0080Jf][00@0GemO06i^KP1^KVh0];Bd0P3<c<`01@2^[Zh0I6AT09VIV@2IVIT0W9bL0080
S8b<00D0QHF507]kN`1kNg/0M7Ad0:VYZ@0204Y:BP0503`l?00V9RH09RHV03De=@19BDT00P1<C4`0
1018B4P0LG5a075aL@1XJ6P2065QH@0505mOG`1[Jf/0IVIV06IVIP1eMGD00P11@D401@1[Jf/0ZZZZ
0:ZZZP2LW9`0Z:RX0080aLG500D0WIfM09RHV02HV9P0ZZZZ0<30`00207inOP<0Ng]k00@0Kfm_06MW
I`1WIfL0OWin5@3ooolK0000o`@0oh003P000?l20?n00500003o00<0oh000000o`000?l020000?l4
0?n000D0003o4P3oP0080000o`l0oooo00090?ooo`0405iNGP29RHT0RHV907YjNP80DE5A00D0Shn?
0::RXP2RXZ80SHf=08V9R@0208f=S@05071`L01YJFT0JFUY07AdM01kNg/00P1=CDd00`1>CTh0EUIF
05IFEP03071`L00506UYJ@11@D40HV9R069RHP1SHf<00P1TI6@01@2:RXX0WIfM09fMW@2SXj<0TY:B
0080];Bd00@0WinO09FEU@2EUID0M7Ad0P1PH6001@1WIfL0`L710:^[Z`2[Zj/0RHV90080GEeM00D0
H61P07IfMP2IVIT0VIVI0;>c/`0209:BTP0508^;R`1`L700L71`09BDU02ATI400P1aLG40101CDe<0
LW9b079bLP1dM7@209nOW`050:n_[`2CTi<0UIFE09FEU@2`/;000P2GUiL01@2o_kl0`L7108>3P`23
Ph<0RXZ:0080ZJVY00D0V9RH0:n_[`2_[jl0OGem08J6QP0207]kN`04061PH02LW9`0W9bL075aL@80
UYJF00D0QXJ60<_;b`26QXH0QXJ607inOP0205EEE@0507UiN@2HV9P0gMgM0=gMg@1/K6`00P1^KVh0
1@1YJFT0hn?S0>?Sh`2CTi<0LW9b0080Lg=c00@0Hf=S07]kN`1kNg/0a/K60P3=cLd01@2_[jl0M7Ad
07]kN`1kNg/0TY:B0080S8b<00D0TY:B0861P@21PH40QXJ60;fm_@0205iNGP0503/k>`0c<c<0<c<c
02d];@1>CTh00P1OGel0101IFET0Lg=c07=cL`2<S8`20861P@05071`L01YJFT0G5aL05aLG01XJ6P0
0P0g=cL01@1<C4`0XJ6Q0:6QX@28R8P0Q8B40080^KVi00D0WYjN06EUI@1UIFD0RXZ:09:BTP0206YZ
JP040820P02WYjL0YjNW06YZJP80Hf=S00<0N7Qh0?ooo`3oool04`3oool;0000o`030?n000000?l0
003o00@0003o1@3oP01W0000o`80oh002`000?l30?n000d0003o0P3oP0000`000?l0oh000?n00002
0?n000<0003o103oP0040000o`l0oooo00090?ooo`0405iNGP29RHT0RHV907YjNP80DE5A00D0Shn?
0::RXP2RXZ80SHf=08V9R@0208f=S@05071`L01YJFT0JFUY07AdM01kNg/00P1=CDd00`1>CTh0EUIF
05IFEP03071`L00506UYJ@11@D40HV9R069RHP1SHf<00P1TI6@01@2:RXX0WIfM09fMW@2SXj<0TY:B
0080];Bd00@0WinO09FEU@2EUID0M7Ad0P1PH6001@1WIfL0`L710:^[Z`2[Zj/0RHV90080GEeM00D0
H61P07IfMP2IVIT0VIVI0;>c/`0209:BTP0508^;R`1`L700L71`09BDU02ATI400P1aLG40101CDe<0
LW9b079bLP1dM7@209nOW`050:n_[`2CTi<0UIFE09FEU@2`/;000P2GUiL01@2o_kl0`L7108>3P`23
Ph<0RXZ:0080ZJVY00D0V9RH0:n_[`2_[jl0OGem08J6QP0207]kN`04061PH02LW9`0W9bL075aL@80
UYJF00D0QXJ60<_;b`26QXH0QXJ607inOP0205EEE@0507UiN@2HV9P0gMgM0=gMg@1/K6`00P1^KVh0
1@1YJFT0hn?S0>?Sh`2CTi<0LW9b0080Lg=c00@0Hf=S07]kN`1kNg/0a/K60P3=cLd01@2_[jl0M7Ad
07]kN`1kNg/0TY:B0080S8b<00D0TY:B0861P@21PH40QXJ60;fm_@0205iNGP0503/k>`0c<c<0<c<c
02d];@1>CTh00P1OGel0101IFET0Lg=c07=cL`2<S8`20861P@05071`L01YJFT0G5aL05aLG01XJ6P0
0P0g=cL01@1<C4`0XJ6Q0:6QX@28R8P0Q8B40080^KVi00D0WYjN06EUI@1UIFD0RXZ:09:BTP0206YZ
JP040820P02WYjL0YjNW06YZJP80Hf=S00<0N7Qh0?ooo`3oool04`3oool;0000o`030?n000000?l0
003o00@0003o1@3oP01W0000o`80oh002`000?l30?n000d0003o0P3oP0000`000?l0oh000?n00002
0?n000<0003o103oP0040000o`l0oooo00090?ooo`0405aLG02BTY80TY:B07YjNP80B4Q800D0Ng]k
08n?S`2?Shl0MgMg08V9R@020820P00505iNGP19BDT0BDU906QXJ01VIVH00P1JFUX0101KFe/0KVi^
06i^KP2ATI4209JFUP0507emO@12@T80HF5Q065QH@1/K6`00P1OGel01@2FUYH0YjNW0:NWY`2c/k<0
VIVI0080^KVi00@0[:b/09>CT`2CTi<0GUiN0P1BDU801@1/K6`0_Kfm0;6a/@2a/K40TI6A0080JFUY
00D0Hf=S07MgM`2<S8`0S8b<0:^[Z`0209VIV@0508j>SP1_Kfl0Kfm_09nOW`26QXH00P1lO7`0101D
E5@0QhN708N7Q`1_Kfl209VIV@050::RXP2CTi<0XJ6Q0:6QX@2j^[X00P26QXH01@2NWYh0_kno09RH
V02HV9P0U9BD0080/K6a00D0]KFe0<30`030`<00P82008f=S@020861P@0406UYJ@2NWYh0WYjN08V9
R@80[Jf]00D0PH610=CDe027QhL0QhN708:2PP0205QHF00507QhN02SXj<0hN7Q0>7Qh@1cLg<00`1T
I6@20=oOg`05096AT@1gMgL0KFe]06e]K@1XJ6P00P1aLG401@2l_;`0bl_;0<_;b`2^[Zh0MWIf0080
RXZ:00@0TI6A07YjNP1jNWX0Lg=c0P1/K6`01@22PX80XJ6Q06ATI01TI6@0>CTi0080<S8b00D0<30`
051@D01IFET0FEUI04i>CP0206YZJP0508B4Q01hN7P0N7Qh07YjNP1^KVh00P1`L700101PH600DU9B
059BDP0o?cl2096AT@0509nOW`2<S8`0/;2`0;2`/02PX:000P1QHF401028R8P0VYZJ08:2PP22PX83
05eMG@0403Lg=`1DE5@0E5AD06a/K1D0oooo2`000?l00`3oP000003o0000o`040000o`@0oh00I000
0?l80?n00280003o1P3oP0030000o`l0oooo00090?ooo`04061PH02IVIT0VIVI07=cL`80A4A400D0
O7al0861P@21PH40MGEe07emO@0207inOP0507UiN@1EEED0EEEE071`L01PH6000P19BDT0101DE5@0
IVIV06IVIP29RHT208R8R00507YjNP11@D40IfMW06MWI`1KFe/00P1RHV801@2:RXX0UiNG09NGU`2/
[:`0VIVI0080^[Zj00@0YJFU09RHV02HV9P0M7Ad0P1DE5@01@1dM7@0`<300<71`@31`L40UYJF0080
J6QX00D0KFe]08F5Q@2HV9P0V9RH0<k>cP020:f][@0509^KV`21PH40PH610;Vi^@29RHT00P1mOGd0
101QHF40TY:B09:BTP20P80209ZJVP050;6a/@2`/;00]KFe0;Fe]@3;bl/00P2>SXh01@2VYZH0][Jf
09BDU02DU9@0Ph>30080Zj^[00D0[:b/0<;2`P32`/80MWIf08R8R00208B4Q00407MgM`2DU9@0U9BD
08>3P`80V9RH00D0KVi^0=cLg01nOWh0OWin06e]K@0206=SH`0508V9R@2OWil0f][J0=[JfP1UIFD0
0P1ADE401@1XJ6P0h>3P0>3Ph02HV9P0MWIf0080NWYj00@0OGem07YjNP1jNWX0c<c<0P3GemL01@2k
^k/0T92@09bLW02LW9`0YJFU0080Shn?00D0VYZJ08:2PP22PX80WYjN0<W9b@0207]kN`0503Xj>P0d
=3@0=3@d02l_;`1<C4`00P1IFET0101GEeL0MWIf07IfMP1eMGD207UiN@0506MWI`1UIFD0KVi^06i^
KP1;Bd/00P1KFe/01@1FEUH0Rh^;08^;R`2GUiL0R8R80080^k^k00D0YJFU06EUI@1UIFD0QhN709RH
V00208R8R00406YZJP1SHf<0Hf=S04a<C080Jf][00<0QXJ60?ooo`3oool04`3ooolf0000o`030?n0
00000?l0003o03/0003o103oP0020000o`040?n000000?l0003o0000o`80oh006@000?l00`3oP000
003o0000o`0A0000o`l0oooo00090?ooo`0405eMG@1mOGd0OGem06m_K`80ADE500D0QXJ609bLW02L
W9`0QHF508R8R002092@T00507YjNP1EEED0EEEE07alO01cLg<00P1CDe<01016ATH0JVYZ06YZJP27
QhL206MWI`0505QHF00j>SX0GUiN05iNGP1]KFd00P1QHF401@22PX80RXZ:08Z:RP2QXJ40PX:20080
/[:b00@0XJ6Q09^KV`2KVi/0Lg=c0P19BDT01@1jNWX0cLg=0<C4a034a<@0RXZ:0080HF5Q00D0K6a/
08:2PP2IVIT0VIVI0<?3``020:b/[00509ZJVP1aLG40LG5a0;Jf]P26QXH00P27QhL0101^KVh0UIFE
09FEU@1iNGT20:2PX0050;:b/P34a<@0]kNg0;Ng]`34a<@00P2>SXh01@2YZJT0c<c<0:FUY@2UYJD0
Ti>C0080];Bd00D0ZZZZ0<G5a@35aLD0H61P07emO@0208F5Q@0408N7Q`2VYZH0YZJV08n?S`80T92@
00D0K6a/0=WIf@24Q8@0Q8B406ATI002065QH@0507YjNP2QXJ40e=CD0=CDe01MGEd00P1CDe<01@1H
F5P0alO70<O7a`2BTY80KFe]0080N7Qh00@0O7al07IfMP1fMWH0`l?30P3;bl/00`2RXZ80O7al0:RX
Z0020:RXZ080TI6A00D0UiNG08R8R028R8P0Y:BT0<G5a@0207AdM00503Ti>@0l?3`0?3`l034a<@1A
DE400P1DE5@0101JFUX0MGEe07EeM@1UIFD207=cL`0506MWI`1HF5P0D51@051@D01;Bd/00P1NGUh0
1@1<C4`0GemO05mOG`2HV9P0NGUi0080UIFE00D0QXJ607AdM01dM7@0NGUi08B4Q00209RHV0<0L71`
00@0GEeM075aL@1aLG40RXZ:5@3ooolC0000o`@0oh00;@000?l00`3oP000003o0000o`180000o`L0
oh000`000?l00`3oP000003o0000o`0A0000o`l0oooo00090?ooo`0405eMG@1mOGd0OGem06m_K`80
ADE500D0QXJ609bLW02LW9`0QHF508R8R002092@T00507YjNP1EEED0EEEE07alO01cLg<00P1CDe<0
1016ATH0JVYZ06YZJP27QhL206MWI`0505QHF00j>SX0GUiN05iNGP1]KFd00P1QHF401@22PX80RXZ:
08Z:RP2QXJ40PX:20080/[:b00@0XJ6Q09^KV`2KVi/0Lg=c0P19BDT01@1jNWX0cLg=0<C4a034a<@0
RXZ:0080HF5Q00D0K6a/08:2PP2IVIT0VIVI0<?3``020:b/[00509ZJVP1aLG40LG5a0;Jf]P26QXH0
0P27QhL0101^KVh0UIFE09FEU@1iNGT20:2PX0050;:b/P34a<@0]kNg0;Ng]`34a<@00P2>SXh01@2Y
ZJT0c<c<0:FUY@2UYJD0Ti>C0080];Bd00D0ZZZZ0<G5a@35aLD0H61P07emO@0208F5Q@0408N7Q`2V
YZH0YZJV08n?S`80T92@00D0K6a/0=WIf@24Q8@0Q8B406ATI002065QH@0507YjNP2QXJ40e=CD0=CD
e01MGEd00P1CDe<01@1HF5P0alO70<O7a`2BTY80KFe]0080N7Qh00@0O7al07IfMP1fMWH0`l?30P3;
bl/00`2RXZ80O7al0:RXZ0020:RXZ080TI6A00D0UiNG08R8R028R8P0Y:BT0<G5a@0207AdM00503Ti
>@0l?3`0?3`l034a<@1ADE400P1DE5@0101JFUX0MGEe07EeM@1UIFD207=cL`0506MWI`1HF5P0D51@
051@D01;Bd/00P1NGUh01@1<C4`0GemO05mOG`2HV9P0NGUi0080UIFE00D0QXJ607AdM01dM7@0NGUi
08B4Q00209RHV0<0L71`00@0GEeM075aL@1aLG40RXZ:5@3ooolC0000o`@0oh00;@000?l00`3oP000
003o0000o`180000o`L0oh000`000?l00`3oP000003o0000o`0A0000o`l0oooo00090?ooo`0406e]
K@2@T900T92@07alO080Bd];00D0SHf=08j>SP2>SXh0QHF508V9R@0209^KV`0506YZJP18B4P0B4Q8
06][J`1jNWX00P1RHV801014A4@0L71`071`L02:RXX208:2PP0507=cL`11@D40De=C05=CD`1[Jf/0
0P1aLG401@26QXH0Y:BT0:BTY02NWYh0QhN70080/;2`00@0W9bL09:BTP2BTY80KFe]0P1;Bd/01@1g
MgL0a/K60;Vi^@2i^KT0PX:20080HV9R00D0IFEU07moO`2NWYh0WYjN0<G5a@020:f][@0509jNWP1/
K6`0K6a/0:b/[01kNg/00P21PH40101bLW80WYjN09jNWP1bLW8208Z:RP050:FUY@2l_;`0XJ6Q0:6Q
X@2WYjL00P21PH401@2LW9`0_[jn0;6a/@2a/K40[:b/0080^;Rh00D0_;bl0<[:bP3:b/X0EeMG08N7
Q`0209JFUP0408Z:RP2<S8`0S8b<08:2PP80QXJ600D0LW9b0=gMg@1kNg/0Ng]k06=SH`0207=cL`05
08N7Q`2/[:`0g=cL0=cLg01QHF400P18B4P01@1TI6@0emOG0=OGe`26QXH0GEeM0080M7Ad00@0Kfm_
07UiN@1iNGT0_Kfm0P37alL01@2QXJ40K6a/08V9R@29RHT0X:2P0080OWin00D0SHf=08N7Q`27QhL0
V9RH0<;2`P0207UiN@0503/k>`0m?Cd0?Cdm03Hf=P1:BTX00P1QHF40101UIFD0P8200820P01/K6`2
07MgM`05071`L01eMGD0FUYJ05YJFP1QHF400P1ZJVX01@1KFe/0IVIV06IVIP2LW9`0NWYj0080V9RH
00D0Lg=c06=SH`1SHf<0LG5a08n?S`0209:BTP0406IVIP1XJ6P0J6QX071`L080K6a/00<0RXZ:0?oo
o`3oool04`3ooom>0000o`80oh009`000?l0103oP000003o0000o`3oP00R0000o`030?n000000?l0
003o00d0003o3`3oool000T0oooo00@0L71`08f=S@2=SHd0OGem0P19BDT01@2ATI40/[:b0;:b/P2M
WId0UIFE0080UiNG00D0J6QX04a<C01<C4`0LW9b06MWI`0205eMG@0404Y:BP1/K6`0K6a/07YjNP80
QHF500D0LG5a04M7A`1MGEd0GEeM06m_K`0205iNGP0507AdM02@T900T92@0:VYZ@2ATI400P2g]kL0
102QXJ40S8b<08b<S01]KFd205MGE`0507]kN`3>c/h0_kno0;no_`25QHD00P1QHF401@1iNGT0W9bL
0;2`/02`/;00f=SH0080`<3000D0Zj^[07EeM@1eMGD0/;2`079bLP0208>3P`0407YjNP2KVi/0Vi^K
06a/K080OGem00D0X:2P0;Fe]@2;Rh/0Rh^;08n?S`0308J6QP040:^[Z`2SXj<0Xj>S0:BTY080Z:RX
00D0/;2`0;Ng]`2g]kL0EUIF08j>SP0208^;R`0408N7Q`24Q8@0Q8B407UiN@80PX:200D0Jf][0=_K
f`1kNg/0Ng]k05eMG@0207UiN@0509BDU02[Zj/0g=cL0=cLg020P8000P1GEeL01@1]KFd0i^KV0>KV
iP2JVYX0J6QX0080PH6100@0KVi^08>3P`23Ph<0aLG50P3@d=001@2j^[X0NWYj08j>SP2>SXh0Z:RX
0080SHf=00D0SXj>08b<S02<S8`0Xj>S0<?3``020820P00504=3@`17AdL0AdM703lo?`1EEED00P1X
J6P0101nOWh0R8R808R8R01iNGT208>3P`05075aL@22PX80H61P061PH01TI6@00P1fMWH01@1RHV80
De=C05=CD`1mOGd0TI6A0080ZZZZ00D0Q8B406m_K`1_Kfl0T92@0820P002096AT@04075aL@1]KFd0
KFe]079bLP80PH6100<0R8R80?ooo`3oool04`3oool40000o`<0oh007`000?l30?n000040000o`3o
P000003o0000o`80oh000P000?l40?n001<0003o1@3oP00Z0000o`030?n000000?l0003o03<0003o
3`3oool000T0oooo00@0L71`08f=S@2=SHd0OGem0P19BDT01@2ATI40/[:b0;:b/P2MWId0UIFE0080
UiNG00D0J6QX04a<C01<C4`0LW9b06MWI`0205eMG@0404Y:BP1/K6`0K6a/07YjNP80QHF500D0LG5a
04M7A`1MGEd0GEeM06m_K`0205iNGP0507AdM02@T900T92@0:VYZ@2ATI400P2g]kL0102QXJ40S8b<
08b<S01]KFd205MGE`0507]kN`3>c/h0_kno0;no_`25QHD00P1QHF401@1iNGT0W9bL0;2`/02`/;00
f=SH0080`<3000D0Zj^[07EeM@1eMGD0/;2`079bLP0208>3P`0407YjNP2KVi/0Vi^K06a/K080OGem
00D0X:2P0;Fe]@2;Rh/0Rh^;08n?S`0308J6QP040:^[Z`2SXj<0Xj>S0:BTY080Z:RX00D0/;2`0;Ng
]`2g]kL0EUIF08j>SP0208^;R`0408N7Q`24Q8@0Q8B407UiN@80PX:200D0Jf][0=_Kf`1kNg/0Ng]k
05eMG@0207UiN@0509BDU02[Zj/0g=cL0=cLg020P8000P1GEeL01@1]KFd0i^KV0>KViP2JVYX0J6QX
0080PH6100@0KVi^08>3P`23Ph<0aLG50P3@d=001@2j^[X0NWYj08j>SP2>SXh0Z:RX0080SHf=00D0
SXj>08b<S02<S8`0Xj>S0<?3``020820P00504=3@`17AdL0AdM703lo?`1EEED00P1XJ6P0101nOWh0
R8R808R8R01iNGT208>3P`05075aL@22PX80H61P061PH01TI6@00P1fMWH01@1RHV80De=C05=CD`1m
OGd0TI6A0080ZZZZ00D0Q8B406m_K`1_Kfl0T92@0820P002096AT@04075aL@1]KFd0KFe]079bLP80
PH6100<0R8R80?ooo`3oool04`3ooolC0000o`030?n000000?l0003o00P0003o3@3oP0020000o`03
0?n000000?l0003o07H0003o0`3oP0040000o`l0oooo00090?ooo`04079bLP2ATI40TI6A07moO`80
DU9B00@0Q8B409nOW`2OWil0Rh^;0`2ATI401@1gMgL0CTi>04i>CP1mOGd0Ng]k0080DU9B00@0@410
05eMG@1MGEd0Kfm_0P1]KFd01@1OGel0DE5A06=SH`1SHf<0JFUY0080GEeM00D0J6QX07moO`1oOgl0
SXj>08F5Q@020:BTY00409>CT`1_Kfl0Kfm_05aLG080B4Q800D0Hf=S0;>c/`2TY:@0Y:BT06e]K@02
05IFEP0506m_K`2DU9@0[Jf]0:f][@3GemL00P2n_[h01@2UYJD0M7Ad07AdM02a/K40MgMg0080RXZ:
00@0PH6108j>SP2>SXh0GemO0P2=SHd01@2ZZZX0]kNg08>3P`23Ph<0XJ6Q0080UYJF00D0UiNG0;no
_`2WYjL0YjNW0;6a/@020:FUY@050;^k^`2e]KD0]KFe05mOG`2>SXh00P24Q8@0102KVi/0PH610861
P@2NWYh207]kN`0506e]K@3Kfm/0S8b<08b<S01KFe/00P1kNg/01@2BTY80W9bL0=oOg`3Ogml0S8b<
0080EUIF00D0K6a/0>CTi03Ti>@0XZ:R06a/K00208J6QP0406YZJP20P800P8200<30`080`/;200D0
XJ6Q06m_K`25QHD0QHF50::RXP0208b<S00508j>SP2GUiL0UiNG0:ZZZP33`l<00P25QHD01@1BDU80
ATI604I6AP16ATH0Cdm?0080HF5Q00@0S8b<08F5Q@25QHD0NWYj0P1gMgL01@1/K6`0S8b<06IVIP1V
IVH0IFEU0080O7al00D0IfMW06i^KP1^KVh0PX:208Z:RP0209NGU`0308>3P`1lO7`0O7al0080UYJF
0P1oOgl0101WIfL0K6a/06a/K02BTY8208b<S0030:JVYP3oool0oooo01<0oooo4`000?l00`3oP000
003o0000o`080000o`d0oh000P000?l00`3oP000003o0000o`1f0000o`<0oh0010000?l?0?ooo`00
2@3oool0101hN7P0YZJV0:JVYP1nOWh205iNGP050861P@2VYZH0YZJV09>CT`2FUYH00P22PX801@1T
I6@0BTY:04Y:BP1]KFd0Kfm_0080GEeM00@0@d=305eMG@1MGEd0PH610P1aLG401@1cLg<0F5QH05eM
G@1MGEd0JFUY0080HV9R00D0N7Qh08f=S@2=SHd0XZ:R09>CT`020:f][@040:BTY022PX80PX:2069R
HP80?Shn00D0H61P0;jn_P2j^[X0^[Zj079bLP0205]KF`05079bLP22PX80W9bL09bLW032`/800P2/
[:`01@2>SXh0HV9R069RHP2KVi/0I6AT0080Ng]k0`1jNWX01@1JFUX0PX:208:2PP2TY:@0^[Zj0080
S8b<0`2IVIT01@2QXJ40/K6a0:ZZZP2ZZZX0_[jn0080TY:B00D0_kno0;:b/P2b/[80IfMW0:FUY@02
08Z:RP040::RXP1kNg/0Ng]k09jNWP80R8R800D0KFe]0=_Kf`2KVi/0Vi^K05mOG`0208j>SP050:JV
YP2>SXh0e=CD0=CDe01oOgl00P1?Cdl01@1JFUX0fm_K0=_Kf`2IVIT0IFEU0080OGem00@0JVYZ07]k
N`1kNg/0_[jn0P38b<P01@2[Zj/0K6a/08Z:RP2:RXX0YJFU0080RHV900D0S8b<09RHV02HV9P0Y:BT
0<?3``0208J6QP0504A4A011@D40@D5104e=C@1:BTX00P1BDU80101nOWh0SXj>08j>SP1`L70206a/
K00506YZJP2:RXX0IfMW06MWI`1[Jf/00P1QHF401@1ADE40Vi^K09^KV`2OWil0Vi^K0080TI6A00D0
LG5a06a/K01/K6`0Vi^K09>CT`0206e]K@0405IFEP1HF5P0F5QH07inOP80Ph>300<0XJ6Q0?ooo`3o
ool04`3ooolc0000o`80oh0000@0003o0?n0003oP000oh007P000?l20?n00400003o0P3oP0030000
o`P0oh001`000?l?0?ooo`002@3oool0101]KFd0T92@092@T01fMWH2069RHP050861P@2KVi/0Vi^K
08n?S`2=SHd00P1kNg/01@1[Jf/0EEEE05EEE@1jNWX0L71`0080EeMG00@0De=C06a/K01/K6`0Ti>C
0P20P8001@1bLW80D51@055AD@1ADE40JVYZ0080IfMW00D0NGUi08B4Q024Q8@0/K6a09nOW`020:>S
X`04096AT@1hN7P0N7Qh06MWI`80Bd];00D0IFEU0:^[Z`2TY:@0Y:BT06IVIP02059BDP0506=SH`2:
RXX0Ti>C09>CT`39bLT00P3:b/X01@2FUYH0K6a/06a/K02][Jd0KVi^0080T92@00@0QHF5075aL@1a
LG40IFEU0P1nOWh01@2RXZ80`L7108>3P`23Ph<0VIVI0080Rh^;00D0WIfM0;Zj^P2WYjL0YjNW0<k>
cP0208R8R0050:f][@2d];@0];Bd06=SH`2IVIT00P1[Jf/0101eMGD0MWIf07IfMP2DU9@206YZJP05
06EUI@3Fe]H0[Jf]0:f][@1NGUh00P2BTY801@2<S8`0Rh^;0=kNgP3Ng]h0UIFE0080FEUI00D0EeMG
0>?Sh`3Shn<0ZZZZ06IVIP0208R8R00406i^KP26QXH0QXJ60<C4a080c/k>00D0[:b/06YZJP27QhL0
QhN70:6QX@0208B4Q00508R8R02ATI40TI6A09BDU02[Zj/00P1gMgL01@15ADD0?Shn03hn?P1;Bd/0
A4A40080B4Q800@0KVi^07]kN`1kNg/0FUYJ0P1BDU801@1QHF40OWin07IfMP1fMWH0Lg=c0080I6AT
00D0EeMG06a/K01/K6`0Ng]k09bLW00209JFUP0508b<S022PX80PX:20:FUY@2VYZH00P1nOWh00`1`
L700Kfm_06m_K`030820P00307alO03oool0oooo01<0oooo4`000?l00`3oP000003o0000o`0P0000
o`<0oh007`000?l00`3oP000003o0000o`0T0000o`<0oh002@000?l30?n000P0003o1@3oP0040000
o`H0oh0020000?l?0?ooo`002@3oool0101]KFd0T92@092@T01fMWH2069RHP050861P@2KVi/0Vi^K
08n?S`2=SHd00P1kNg/01@1[Jf/0EEEE05EEE@1jNWX0L71`0080EeMG00@0De=C06a/K01/K6`0Ti>C
0P20P8001@1bLW80D51@055AD@1ADE40JVYZ0080IfMW00D0NGUi08B4Q024Q8@0/K6a09nOW`020:>S
X`04096AT@1hN7P0N7Qh06MWI`80Bd];00D0IFEU0:^[Z`2TY:@0Y:BT06IVIP02059BDP0506=SH`2:
RXX0Ti>C09>CT`39bLT00P3:b/X01@2FUYH0K6a/06a/K02][Jd0KVi^0080T92@00@0QHF5075aL@1a
LG40IFEU0P1nOWh01@2RXZ80`L7108>3P`23Ph<0VIVI0080Rh^;00D0WIfM0;Zj^P2WYjL0YjNW0<k>
cP0208R8R0050:f][@2d];@0];Bd06=SH`2IVIT00P1[Jf/0101eMGD0MWIf07IfMP2DU9@206YZJP05
06EUI@3Fe]H0[Jf]0:f][@1NGUh00P2BTY801@2<S8`0Rh^;0=kNgP3Ng]h0UIFE0080FEUI00D0EeMG
0>?Sh`3Shn<0ZZZZ06IVIP0208R8R00406i^KP26QXH0QXJ60<C4a080c/k>00D0[:b/06YZJP27QhL0
QhN70:6QX@0208B4Q00508R8R02ATI40TI6A09BDU02[Zj/00P1gMgL01@15ADD0?Shn03hn?P1;Bd/0
A4A40080B4Q800@0KVi^07]kN`1kNg/0FUYJ0P1BDU801@1QHF40OWin07IfMP1fMWH0Lg=c0080I6AT
00D0EeMG06a/K01/K6`0Ng]k09bLW00209JFUP0508b<S022PX80PX:20:FUY@2VYZH00P1nOWh00`1`
L700Kfm_06m_K`030820P00307alO03oool0oooo01<0oooo<@000?l40?n000040000o`3oP000oh00
0?n00140003o2P3oP00010000?l0oh000?n0003oP0040000o`030?n000000?l0003o03H0003o0P3o
P00:0000o`030?n000000?l0003o00@0003o00<0oh000000o`000?l00P000?l?0?ooo`002@3oool0
101ZJVX0QHF508F5Q@1cLg<2051@D00508Z:RP2MWId0WIfM08b<S02@T9000P1eMGD01@1/K6`0CDe=
04e=C@22PX80N7Qh0080EeMG00@0D51@05iNGP1NGUh0LG5a0P1`L7001@1]KFd0@T9205MGE`1GEeL0
NGUi0080JVYZ00D0MgMg08R8R028R8P0^;Rh0:JVYP020:>SX`0409jNWP1dM7@0M7Ad05mOG`80EeMG
00D0Jf][0;Fe]@2h^;P0^;Rh079bLP0205eMG@0505aLG01fMWH0QhN708N7Q`2m_Kd00P2h^;P01@2<
S8`0De=C05=CD`2CTi<0J6QX0080PH6100@0QXJ6061PH01PH600HV9R0P1jNWX01@2OWil0];Bd07]k
N`1kNg/0T92@0080R8R800D0WIfM0:VYZ@2EUID0UIFE0:n_[`0207=cL`050:6QX@2GUiL0UiNG05AD
E01dM7@00P1SHf<01023Ph<0NGUi07UiN@29RHT206UYJ@0505mOG`3AdM40WYjN09jNWP1CDe<00P2>
SXh01@1kNg/0QhN70<c<c03<c<`0UIFE0080DE5A00D0D51@0>7Qh@3QhN40_;bl07=cL`0208b<S004
06EUI@1hN7P0N7Qh0;>c/`80`L7100D0/k>c079bLP2DU9@0U9BD09jNWP0208N7Q`050861P@2ATI40
TI6A0;6a/@38b<P00P1fMWH01@11@D40@T920492@P16ATH0BDU90080EeMG00@0Lg=c07]kN`1kNg/0
J6QX0P1NGUh01@1UIFD0N7Qh06][J`1[Jf/0MgMg0080M7Ad00D0Hf=S0:>SX`2SXj<0TY:B0:ZZZP02
0:2PX0050861P@24Q8@0Q8B40:2PX02VYZH00P1QHF40101NGUh0LW9b079bLP24Q8@207inOP03096A
T@3oool0oooo01<0oooo<@000?l40?n000040000o`3oP000oh000?n00140003o2P3oP00010000?l0
oh000?n0003oP0040000o`030?n000000?l0003o03H0003o0P3oP00:0000o`030?n000000?l0003o
00@0003o00<0oh000000o`000?l00P000?l?0?ooo`002@3oool0101dM7@0PH610861P@24Q8@204Q8
B00507YjNP1lO7`0O7al06m_K`1eMGD00P1oOgl01@1RHV80@T920492@P1/K6`0LW9b0080EUIF00@0
@d=307alO01lO7`0QhN70P1[Jf/01@1RHV80@T92059BDP1BDU80MGEe0080FEUI00D0G5aL0861P@21
PH40[Zj^09VIV@0208b<S00408J6QP1aLG40LG5a061PH080EEEE00D0LG5a0;2`/02g]kL0]kNg07Ui
N@0206QXJ00507EeM@2:RXX0Rh^;08^;R`3EeMD00P3Cdm<01@2GUiL0?Shn03hn?P2IVIT0Ogmo0080
SHf=00@0Shn?05]KF`1KFe/0JVYZ0P1mOGd01@2UYJD0ZJVY08B4Q024Q8@0Xj>S0080T92@00D0X:2P
0:n_[`2QXJ40XJ6Q0<G5a@0207YjNP050;:b/P2^[Zh0[Zj^06a/K02ATI400P1eMGD01024Q8@0UIFE
09FEU@2UYJD207YjNP0507QhN03Bd]80`L710<71`@1IFET00P29RHT01@2;Rh/0XJ6Q0=WIf@3IfMT0
V9RH0080A4A400D0Cdm?0=GEe@3EeMD0Z:RX06m_K`0208B4Q00406=SH`1bLW80LW9b09fMW@80/K6a
00D0WYjN06=SH`21PH40PH6109FEU@0207]kN`0507QhN02:RXX0RXZ:0;Ng]`35aLD00P1nOWh304I6
AP050492@P1=CDd0GemO05mOG`22PX800P2;Rh/01@1jNWX0HF5Q065QH@1RHV80O7al0080LG5a00@0
H61P065QH@1QHF40Jf][0P2GUiL01@2EUID0/K6a0:BTY02TY:@0PX:20080TI6A00D0ZZZZ0;:b/P20
P800P82006a/K00206EUI@0406MWI`1KFe/0Fe]K07IfMQD0oooo00<0003o0?n0003oP0002`3oP00A
0000o`030?n000000?l0003o0080oh002P000?l01@3oP000003o0000o`000?l0oh0002@0003o103o
P0000`000?l0oh000000o`0E0000o`@0oh00;`000?l20?n000D0003o3`3oool000T0oooo00@0M7Ad
0861P@21PH40Q8B40P18B4P01@1jNWX0O7al07alO01_Kfl0MGEe0080Ogmo00D0HV9R0492@P12@T80
K6a/079bLP0205IFEP0404=3@`1lO7`0O7al08N7Q`80Jf][00D0HV9R0492@P1BDU80DU9B07EeM@02
05UIF@0505aLG021PH40PH610:j^[P2IVIT00P2<S8`01026QXH0LG5a075aL@1PH60205EEE@05075a
L@2`/;00]kNg0;Ng]`1iNGT00P1XJ6P01@1eMGD0RXZ:08^;R`2;Rh/0eMGE0080dm?C00D0UiNG03hn
?P0n?Sh0VIVI07moO`0208f=S@0408n?S`1KFe/0Fe]K06YZJP80OGem00D0YJFU0:VYZ@24Q8@0Q8B4
0:>SX`02092@T0050:2PX02_[jl0XJ6Q0:6QX@35aLD00P1jNWX01@2b/[80[Zj^0:j^[P1/K6`0TI6A
0080MGEe00@0Q8B409FEU@2EUID0YJFU0P1jNWX01@1hN7P0d];B0<71`@31`L40FEUI0080RHV900D0
Rh^;0:6QX@3IfMT0fMWI09RHV00204A4A00504m?C`3EeMD0eMGE0:RXZ01_Kfl00P24Q8@0101SHf<0
LW9b079bLP2MWId20;6a/@0509jNWP1SHf<0PH610861P@2EUID00P1kNg/01@1hN7P0RXZ:08Z:RP2g
]kL0aLG50080OWin0`16ATH01@12@T80CDe=05mOG`1OGel0PX:20080Rh^;00D0NWYj065QH@1QHF40
HV9R07alO002075aL@04061PH01QHF40HF5Q06][J`80UiNG00D0UIFE0;6a/@2TY:@0Y:BT08:2PP02
096AT@050:ZZZP2b/[80P8200820P01/K6`00P1UIFD0101WIfL0Fe]K05]KF`1fMWHE0?ooo`<0oh00
00<0003o0?n0003oP0002@3oP00J0000o`H0oh00OP000?l?0?ooo`002@3oool0101lO7`0QHF508F5
Q@2EUID205iNGP050:>SX`2ZZZX0ZZZZ08R8R02ATI400P2JVYX01@22PX80EUIF05IFEP28R8P0Rh^;
0080EEEE00@0?Cdm06=SH`1SHf<0U9BD0P1eMGD01@1KFe/0FUYJ051@D01@D500GUiN0080HF5Q00D0
I6AT08F5Q@25QHD0`<300::RXP0209fMW@040:NWY`1hN7P0N7Qh06IVIP80G5aL00D0Hf=S09jNWP2D
U9@0U9BD069RHP0206=SH`0507=cL`25QHD0SHf=08f=S@3<c<`00P39bLT01@2ATI40@4100410@02X
Z:P0Shn?0080VYZJ00@0Shn?05QHF01HF5P0KVi^0P1iNGT01@2[Zj/0[Zj^09VIV@2IVIT0Zj^[0080
Z:RX00D0XZ:R0;Jf]P2SXj<0Xj>S09bLW002079bLP050;^k^`2l_;`0_;bl07EeM@2=SHd00P1eMGD0
101iNGT0RHV908V9R@2JVYX207QhN00507EeM@3;bl/0][Jf0;Jf]P1KFe/00P1gMgL01@2=SHd0Shn?
0=CDe03De=@0[Jf]0080>SXj00D0E5AD0=kNgP3Ng]h0TY:B07MgM`0208V9R@0406UYJ@22PX80PX:2
0;bl_080aLG500D0ZZZZ065QH@26QXH0QXJ608b<S00208V9R@0507YjNP24Q8@0Q8B40;bl_039bLT0
0P27QhL01@19BDT0CTi>04i>CP18B4P0D51@0080Fe]K00@0P820079bLP1bLW80NGUi0P1LG5`01@1S
Hf<0QhN706m_K`1_Kfl0L71`0080IVIV00D0CDe=071`L01`L700PX:209jNWP020:JVYP0508J6QP27
QhL0QhN70:ZZZP2f][H00P26QXH0102<S8`0OGem07emO@1UIFD205iNGP0306=SH`3oool0oooo01<0
oooo2`000?l00`3oP000003o0000o`040000o`D0oh00=P000?l;0?n000`0003o0`3oP00R0000o`03
0?n000000?l0003o00d0003o1@3oP00?0000o`l0oooo00090?ooo`<0Kfm_00@0Ogmo04a<C01<C4`0
ZJVY0P2`/;001@2FUYH0SXj>09NGU`2GUiL0LW9b0080De=C00D0J6QX06a/K01IFET0FEUI03hn?P02
075aL@0509RHV02:RXX0RXZ:06m_K`1IFET00P1<C4`0101BDU80IFEU06EUI@1QHF4207IfMP050<?3
``2PX:00RHV908V9R@2_[jl00P1mOGd01@1]KFd0LG5a075aL@1aLG40XJ6Q0080Z:RX00D0QhN706m_
K`1_Kfl0Ng]k08B4Q00208N7Q`040<K6aP30`<00`<3008V9R@80AdM700D0YJFU092@T02RXZ80XZ:R
08^;R`0205ADE005079bLP1nOWh0OWin0:VYZ@2c/k<00P2JVYX01@2YZJT0VYZJ09ZJVP2QXJ40`<30
0080UiNG00@0QXJ606IVIP1VIVH0XZ:R0P2WYjL01@1IFET0M7Ad06i^KP1^KVh0OWin0080Ph>300D0
RHV907EeM@1eMGD0N7Qh0<c<c0020;Ng]`0507]kN`2:RXX0RXZ:092@T02UYJD00P3AdM40102o_kl0
I6AT06ATI01MGEd20>7Qh@050;>c/`1kNg/0QXJ608J6QP1[Jf/00P28R8P01@3:b/X0`/;20<;2`P2e
]KD0KVi^0080T92@00@0WIfM09^KV`2KVi/0SXj>0P2ATI401@2m_Kd0WIfM0:BTY02TY:@0E5AD00<0
DU9B00@0EEEE05eMG@1MGEd0QHF50P27QhL01@1^KVh0Hf=S06=SH`1KFe/0R8R80080LG5a00@0OGem
06ATI01TI6@0@4100P1/K6`01@1gMgL0OWin08Z:RP2:RXX0Q8B40080P82000D0T92@09fMW@27QhL0
QhN70:6QX@0206MWI`0406UYJ@1ZJVX0JVYZ06m_KaD0oooo2`000?l00`3oP000003o0000o`040000
o`D0oh00=P000?l;0?n000`0003o0`3oP00R0000o`030?n000000?l0003o00d0003o1@3oP00?0000
o`l0oooo00090?ooo`<0Kfm_00@0Ogmo04a<C01<C4`0ZJVY0P2`/;001@2FUYH0SXj>09NGU`2GUiL0
LW9b0080De=C00D0J6QX06a/K01IFET0FEUI03hn?P02075aL@0509RHV02:RXX0RXZ:06m_K`1IFET0
0P1<C4`0101BDU80IFEU06EUI@1QHF4207IfMP050<?3``2PX:00RHV908V9R@2_[jl00P1mOGd01@1]
KFd0LG5a075aL@1aLG40XJ6Q0080Z:RX00D0QhN706m_K`1_Kfl0Ng]k08B4Q00208N7Q`040<K6aP30
`<00`<3008V9R@80AdM700D0YJFU092@T02RXZ80XZ:R08^;R`0205ADE005079bLP1nOWh0OWin0:VY
Z@2c/k<00P2JVYX01@2YZJT0VYZJ09ZJVP2QXJ40`<300080UiNG00@0QXJ606IVIP1VIVH0XZ:R0P2W
YjL01@1IFET0M7Ad06i^KP1^KVh0OWin0080Ph>300D0RHV907EeM@1eMGD0N7Qh0<c<c0020;Ng]`05
07]kN`2:RXX0RXZ:092@T02UYJD00P3AdM40102o_kl0I6AT06ATI01MGEd20>7Qh@050;>c/`1kNg/0
QXJ608J6QP1[Jf/00P28R8P01@3:b/X0`/;20<;2`P2e]KD0KVi^0080T92@00@0WIfM09^KV`2KVi/0
SXj>0P2ATI401@2m_Kd0WIfM0:BTY02TY:@0E5AD00<0DU9B00@0EEEE05eMG@1MGEd0QHF50P27QhL0
1@1^KVh0Hf=S06=SH`1KFe/0R8R80080LG5a00@0OGem06ATI01TI6@0@4100P1/K6`01@1gMgL0OWin
08Z:RP2:RXX0Q8B40080P82000D0T92@09fMW@27QhL0QhN70:6QX@0206MWI`0406UYJ@1ZJVX0JVYZ
06m_KaD0oooo40000?l;0?n00380003o0`3oP0001@000?l0oh000?n0003oP000003o00<0oh00<P00
0?l50?n000h0003o00<0oh000000o`000?l03@000?l?0?ooo`002@3oool0101`L700MgMg07MgM`2E
UID204i>CP<0XJ6Q00@0Ti>C08n?S`2SXj<0Xj>S0`1WIfL01@21PH40I6AT04Y:BP1:BTX0<S8b0080
EeMG00D0KVi^07EeM@1eMGD0GUiN04i>CP0204m?C`04055AD@1gMgL0MgMg05UIF@80QXJ600D0b<S8
0:JVYP28R8P0R8R80:^[Z`0207UiN@0507AdM01aLG40LG5a08j>SP2[Zj/00P2e]KD01@25QHD0OWin
07inOP24Q8@0TI6A0080[Zj^00@0c/k>0<?3``33`l<0U9BD0P18B4P01@2/[:`0UYJF09nOW`2OWil0
U9BD0080BTY:00D0OGem092@T02@T900/[:b0;fm_@020:FUY@050;Vi^@29RHT0RHV909BDU031`L40
0P2_[jl0102OWil0NGUi07UiN@2o_kl20<30`00507]kN`2JVYX0LG5a075aL@22PX800P2HV9P01@2]
[Jd0Kfm_06m_K`1lO7`0_;bl0080][Jf00D0Vi^K07AdM01dM7@0PX:209^KV`020<C4a0040;Zj^P1J
FUX0FUYJ061PH080gmoO00D0WYjN0820P029RHT0RHV906ATI00207emO@050<C4a02l_;`0_;bl0;Zj
^P1fMWH00P2HV9P0102LW9`0YJFU0:FUY@29RHT209:BTP050;Ng]`2DU9@0Vi^K09^KV`1MGEd00P1B
DU801@19BDT0Bd];05IFEP1FEUH0IVIV0080M7Ad00D0HF5Q06][J`1[Jf/0Cdm?07moO`0207EeM@04
05mOG`1dM7@0M7Ad04e=C@80KFe]00D0Ng]k0:j^[P2HV9P0V9RH0820P00207emO@050::RXP2FUYH0
Ng]k07]kN`2UYJD00P1XJ6P0101HF5P0IfMW06MWI`1HF5PE0?oooaP0003o0`3oP01=0000o`030?n0
00000?l0003o0280003o00<0oh000000o`000?l03@000?l00`3oP000003o0000o`0=0000o`l0oooo
00090?ooo`0407alO026QXH0QXJ609RHV080DE5A00D0VYZJ0:VYZ@2YZJT0UiNG09:BTP0209^KV`05
06a/K01OGel0GemO0820P01kNg/00P1KFe/01014A4@0IVIV06IVIP1oOgl208:2PP0507=cL`1`L700
KVi^06i^KP1JFUX00P2@T9001@1XJ6P0QXJ608J6QP2k^k/0WIfM0080Q8B400@0]KFe07QhN01hN7P0
N7Qh0P1mOGd01@2>SXh0];Bd0<W9b@39bLT0T92@0080SHf=00D0P82008V9R@2QXJ40XJ6Q0<c<c002
0;bl_00509>CT`14A4@0A4A409VIV@29RHT00P2?Shl01029RHT0BDU904U9B@1lO7`208^;R`050;Rh
^03>c/h0Y:BT0:BTY02m_Kd00P2CTi<01@2@T900b/[:0:^[Z`2[Zj/0WinO0080LW9b00D0Z:RX0;fm
_@2m_Kd0O7al096AT@0206e]K@<0OGem00D0W9bL08:2PP22PX80RXZ:0<71`@020:f][@0509^KV`1]
KFd0KFe]07moO`2VYZH00P2j^[X0102KVi/0@D510451@@1KFe/20<?3``0509RHV022PX80MWIf07If
MP1QHF400P1iNGT01@2n_[h0][Jf0;Jf]P2l_;`0LW9b0080Vi^K00@0T92@0:RXZ02XZ:P0JVYZ0P2H
V9P01@2TY:@0X:2P08Z:RP2:RXX0JFUY0080FEUI00D0DE5A04];B`1ADE40DE5A07AdM00208B4Q005
07]kN`1hN7P0N7Qh05IFEP2:RXX00P27QhL0101YJFT0N7Qh07QhN01@D50208J6QP0508Z:RP2;Rh/0
UIFE09FEU@2DU9@00P1dM7@01@1eMGD0NWYj08>3P`23Ph<0UIFE0080DU9B00@0Fe]K06IVIP1VIVH0
FUYJ5@3oool00`3oP000003o0000o`020000o`<0oh00T@000?l50?n000l0003o3`3oool000T0oooo
00@0KVi^07=cL`1cLg<0QHF50P14A4@01@2:RXX0T92@092@T020P800QhN70080T92@00D0K6a/05MG
E`1GEeL0LW9b071`L00205MGE`0404U9B@1bLW80LW9b0861P@80QHF500D0Kfm_07]kN`1]KFd0KFe]
05EEE@0208>3P`0505YJFP24Q8@0Q8B40;Ng]`2HV9P00P28R8P0102^[Zh0Ng]k07]kN`1kNg/20861
P@0407]kN`2b/[80_;bl0;bl_0<0Ph>300D0OGem092@T02IVIT0VIVI0=CDe0020;^k^`0509>CT`10
@400@41009>CT`28R8P00P2BTY801022PX80ATI604I6AP1kNg/208:2PP050:>SX`2i^KT0ZJVY0:VY
Z@2`/;000P2EUID01@29RHT0bLW90;Fe]@2e]KD0XJ6Q0080MWIf00D0_kno0<C4a034a<@0Ogmo08J6
QP0206m_K`0407QhN026QXH0QXJ609^KV`80N7Qh00D0RHV90;^k^`2SXj<0Xj>S08Z:RP0206UYJ@05
07UiN@2TY:@0^;Rh0;Rh^02i^KT00P1ADE401@1ZJVX0h^;R0>;RhP25QHD0QXJ60080MGEe00@0IVIV
075aL@1aLG40^;Rh0P2[Zj/01@2b/[80MWIf08b<S02<S8`0M7Ad0080Zj^[00D0GemO09NGU`2GUiL0
[:b/09bLW002096AT@0505IFEP1>CTh0CTi>04i>CP19BDT00P1EEED0101VIVH0NWYj07YjNP1`L702
06YZJP0505IFEP2;Rh/0TI6A096AT@1XJ6P00P1VIVH01@1BDU80LW9b079bLP2:RXX0VIVI0080VYZJ
00D0YjNW07alO01lO7`0MGEe07inOP0209:BTP040820P015ADD0ADE506ATI080JFUY00<0IFEU0?oo
o`3oool04`3oool00`3oP000003o0000o`020000o`<0oh00T@000?l50?n000l0003o3`3oool000T0
oooo00@0KVi^07=cL`1cLg<0QHF50P14A4@01@2:RXX0T92@092@T020P800QhN70080T92@00D0K6a/
05MGE`1GEeL0LW9b071`L00205MGE`0404U9B@1bLW80LW9b0861P@80QHF500D0Kfm_07]kN`1]KFd0
KFe]05EEE@0208>3P`0505YJFP24Q8@0Q8B40;Ng]`2HV9P00P28R8P0102^[Zh0Ng]k07]kN`1kNg/2
0861P@0407]kN`2b/[80_;bl0;bl_0<0Ph>300D0OGem092@T02IVIT0VIVI0=CDe0020;^k^`0509>C
T`10@400@41009>CT`28R8P00P2BTY801022PX80ATI604I6AP1kNg/208:2PP050:>SX`2i^KT0ZJVY
0:VYZ@2`/;000P2EUID01@29RHT0bLW90;Fe]@2e]KD0XJ6Q0080MWIf00D0_kno0<C4a034a<@0Ogmo
08J6QP0206m_K`0407QhN026QXH0QXJ609^KV`80N7Qh00D0RHV90;^k^`2SXj<0Xj>S08Z:RP0206UY
J@0507UiN@2TY:@0^;Rh0;Rh^02i^KT00P1ADE401@1ZJVX0h^;R0>;RhP25QHD0QXJ60080MGEe00@0
IVIV075aL@1aLG40^;Rh0P2[Zj/01@2b/[80MWIf08b<S02<S8`0M7Ad0080Zj^[00D0GemO09NGU`2G
UiL0[:b/09bLW002096AT@0505IFEP1>CTh0CTi>04i>CP19BDT00P1EEED0101VIVH0NWYj07YjNP1`
L70206YZJP0505IFEP2;Rh/0TI6A096AT@1XJ6P00P1VIVH01@1BDU80LW9b079bLP2:RXX0VIVI0080
VYZJ00D0YjNW07alO01lO7`0MGEe07inOP0209:BTP040820P015ADD0ADE506ATI080JFUY00<0IFEU
0?ooo`3oool04`3ooolK0000o`P0oh00F@000?l40?n001T0003o1@3oP00?0000o`l0oooo00090?oo
o`0407IfMP20P800P82008J6QP80BTY:00D0SXj>09RHV02HV9P0RXZ:09JFUP0209RHV00507UiN@1E
EED0EEEE07alO01WIfL00P1:BTX01011@D40K6a/06a/K02ATI4208R8R005075aL@1_Kfl0D51@051@
D01?Cdl00P1MGEd01@1DE5@0J6QX06QXJ02RXZ80Shn?0080PX:200@0Y:BT07=cL`1cLg<0Ogmo0P1k
Ng/01@1WIfL0[:b/0:NWY`2WYjL0KVi^0080Ogmo00D0LW9b0820P02NWYh0WYjN0=[JfP020<G5a@05
09:BTP1MGEd0GEeM0:VYZ@2HV9P00P2MWId01027QhL0B4Q804Q8B01jNWX208Z:RP050:^[Z`33`l<0
]kNg0;Ng]`2][Jd00P2ATI401@20P800a<C40;>c/`2c/k<0XZ:R0080QXJ600<0`/;20<C4a034a<@0
0P29RHT207alO0040820P028R8P0R8R809RHV080Ph>300D0MgMg0:j^[P2d];@0];Bd096AT@0207Mg
M`0507alO02k^k/0^;Rh0;Rh^02`/;000P1BDU801@1SHf<0gMgM0=gMg@2BTY80RXZ:0080OGem00@0
NGUi07inOP1nOWh0^k^k0P2d];@01@2UYJD0KVi^07emO@1mOGd0M7Ad0080TI6A00D0FEUI08b<S02<
S8`0Ti>C06MWI`0209NGU`0505MGE`1;Bd/0Bd];0451@@14A4@00P1KFe/0101`L700O7al07alO01^
KVh205YJFP0505MGE`1oOgl0QHF508F5Q@1IFET00P1MGEd01@1?Cdl0KFe]06e]K@20P800H61P0080
L71`00D0W9bL06ATI01TI6@0OGem07IfMP0208f=S@0407MgM`11@D40@D5106ATI080LW9b00<0Lg=c
0?ooo`3oool04`3ooolC0000o`<0oh00A@000?l00`3oP000003o0000o`1?0000o`l0oooo00090?oo
o`04075aL@23Ph<0Ph>308J6QP80Cdm?00D0RHV909FEU@2EUID0R8R809BDU00209JFUP0507=cL`1C
De<0De=C08^;R`1dM7@00P1ADE401011@D40IVIV06IVIP1gMgL207]kN`0506e]K@1bLW80BDU904U9
B@1@D5000P1OGel01@1PH600OGem07emO@2h^;P0YjNW0080Ph>300@0^[Zj0820P020P800QhN70P2?
Shl01@1`L700ZZZZ0;2`/02`/;00MWIf0080Ti>C00D0HF5Q075aL@2JVYX0VYZJ0=?Cd`020;Jf]P05
09ZJVP1RHV80HV9R0:6QX@2JVYX00P2FUYH01027QhL0Bd];04];B`1lO7`2096AT@050:f][@2/[:`0
[jn_0:n_[`2SXj<00P28R8P01@2:RXX0b<S80:j^[P2^[Zh0VYZJ0080Rh^;00D0alO70<c<c03<c<`0
Shn?08R8R00207IfMP0406m_K`2ATI40TI6A0:FUY@80TY:B00D0RHV90<;2`P2`/;00/;2`096AT@02
0820P00507=cL`2h^;P0];Bd0;Bd]02^[Zh00P0k>c/01@1UIFD0g=cL0=cLg02IVIT0UIFE0080T92@
00@0Kfm_07alO01lO7`0`<300P2o_kl01@2UYJD0MgMg08R8R028R8P0Ph>30080PX:200D0MgMg09^K
V`2KVi/0YZJV06i^KP0209:BTP0504i>CP1BDU80DU9B03dm?@16ATH00P1PH600101iNGT0QhN708N7
Q`1dM7@205aLG00506UYJ@27QhL0SXj>08j>SP1IFET00P1LG5`01@1:BTX0EUIF05IFEP1eMGD0QXJ6
0080QHF500D0ZJVY06m_K`1_Kfl0MWIf07emO@0209BDU00406=SH`11@D40@D5106=SH`80EEEE00<0
I6AT0?ooo`3oool04`3ooolC0000o`<0oh00A@000?l00`3oP000003o0000o`1?0000o`l0oooo0009
0?ooo`04075aL@23Ph<0Ph>308J6QP80Cdm?00D0RHV909FEU@2EUID0R8R809BDU00209JFUP0507=c
L`1CDe<0De=C08^;R`1dM7@00P1ADE401011@D40IVIV06IVIP1gMgL207]kN`0506e]K@1bLW80BDU9
04U9B@1@D5000P1OGel01@1PH600OGem07emO@2h^;P0YjNW0080Ph>300@0^[Zj0820P020P800QhN7
0P2?Shl01@1`L700ZZZZ0;2`/02`/;00MWIf0080Ti>C00D0HF5Q075aL@2JVYX0VYZJ0=?Cd`020;Jf
]P0509ZJVP1RHV80HV9R0:6QX@2JVYX00P2FUYH01027QhL0Bd];04];B`1lO7`2096AT@050:f][@2/
[:`0[jn_0:n_[`2SXj<00P28R8P01@2:RXX0b<S80:j^[P2^[Zh0VYZJ0080Rh^;00D0alO70<c<c03<
c<`0Shn?08R8R00207IfMP0406m_K`2ATI40TI6A0:FUY@80TY:B00D0RHV90<;2`P2`/;00/;2`096A
T@020820P00507=cL`2h^;P0];Bd0;Bd]02^[Zh00P0k>c/01@1UIFD0g=cL0=cLg02IVIT0UIFE0080
T92@00@0Kfm_07alO01lO7`0`<300P2o_kl01@2UYJD0MgMg08R8R028R8P0Ph>30080PX:200D0MgMg
09^KV`2KVi/0YZJV06i^KP0209:BTP0504i>CP1BDU80DU9B03dm?@16ATH00P1PH600101iNGT0QhN7
08N7Q`1dM7@205aLG00506UYJ@27QhL0SXj>08j>SP1IFET00P1LG5`01@1:BTX0EUIF05IFEP1eMGD0
QXJ60080QHF500D0ZJVY06m_K`1_Kfl0MWIf07emO@0209BDU00406=SH`11@D40@D5106=SH`80EEEE
00<0I6AT0?ooo`3oool04`3ooomb0000o`030?n000000?l0oh000080oh00=P000?l?0?ooo`002@3o
ool0101RHV80O7al07alO01mOGd204Y:BP0508F5Q@2JVYX0VYZJ096AT@2IVIT00P2DU9@01@1jNWX0
DE5A055AD@1lO7`0KVi^0080H61P00@0C4a<071`L01`L700SHf=0P2?Shl01@1jNWX0NGUi04U9B@19
BDT0EeMG0080Jf][00D0J6QX08F5Q@25QHD0/k>c09fMW@0207moO`040;no_`2;Rh/0Rh^;08n?S`80
PX:200D0L71`09nOW`2TY:@0Y:BT07inOP0208J6QP0506=SH`1/K6`0XZ:R0::RXP3EeMD00P2YZJT0
1@2QXJ40IfMW06MWI`2JVYX0YjNW0080P82000@0Ph>304i>CP1>CTh0PH610P2EUID01@2UYJD0YZJV
0;bl_02l_;`0XZ:R0080TY:B00D0K6a/0;Zj^P2WYjL0YjNW08j>SP0208>3P`<0_kno00D0PH6107Qh
N01dM7@0M7Ad06YZJP0208>3P`0509:BTP2>SXh0SXj>08R8R02m_Kd00P2YZJT01@22PX80Ng]k07]k
N`1VIVH0^[Zj0080[Zj^00@0ZJVY02HV9P0V9RH0KFe]0P3Ng]h01@24Q8@0XZ:R08:2PP22PX80JFUY
0080L71`00D0[:b/0:JVYP2VYZH0VYZJ08F5Q@0207moO`0408b<S01iNGT0NGUi06a/K080Ph>300D0
X:2P075aL@2IVIT0VIVI05iNGP0206a/K0050410@01?Cdl0HF5Q065QH@26QXH00P2DU9@01@1eMGD0
HF5Q065QH@1RHV80S8b<0080XJ6Q00@0E5AD05eMG@1MGEd0EUIF0P1XJ6P01@1nOWh0OGem08>3P`23
Ph<0[jn_0080MGEe00D0NWYj08>3P`29RHT0RHV907EeM@0205IFEP0406i^KP1UIFD0IFEU05iNGQD0
oooo1@000?l30?n002/0003o0P3oP01N0000o`L0oh004`000?l?0?ooo`002@3oool0101MGEd0PH61
0861P@1oOgl205=CD`03079bLP2<S8`0S8b<0080SXj>0P1nOWh01@1ZJVX0DU9B059BDP1mOGd0GemO
0080IVIV00@0EeMG07]kN`1kNg/0R8R80P2GUiL01@1fMWH0P82005aLG01LG5`0GemO0080MWIf00D0
IfMW08Z:RP2:RXX0/K6a0:6QX@0208Z:RP030;^k^`22PX80PX:200<0PH6100D0L71`09bLW02e]KD0
]KFe08V9R@0209bLW00504i>CP1QHF40V9RH09RHV038b<P00P2YZJT01@2HV9P0L71`071`L02GUiL0
/K6a0080PX:200@0L71`059BDP1BDU80LW9b0P2GUiL01@2?Shl0Y:BT0;Zj^P2j^[X0ZZZZ0080UYJF
00D0OGem0;bl_02BTY80TY:B08n?S`0208f=S@050;Ng]`37alL0alO708b<S01dM7@00P1mOGd0101^
KVh0TY:B09:BTP2KVi/209bLW00508J6QP2n_[h0[:b/0:b/[022PX800P1dM7@01@1OGel0]kNg0:>S
X`2SXj<0Z:RX0080;Rh^00D0KFe]0=CDe03De=@0Ng]k09NGU`020861P@0406e]K@1cLg<0Lg=c0;jn
_P80_kno00D0YjNW0;Vi^@1eMGD0MGEe08j>SP0208Z:RP050861P@20P800P82008>3P`2;Rh/00P2H
V9P01@1/K6`0GUiN05iNGP0m?Cd0D51@0080FUYJ00@0J6QX08^;R`2;Rh/0QXJ60P1WIfL01@1MGEd0
QhN707inOP1nOWh0F5QH0080EEEE00D0AdM705aLG01LG5`0Kfm_07UiN@0208^;R`040:j^[P1lO7`0
O7al07moO`@0NGUi0P18B4P305mOG`0306e]K@3oool0oooo01<0oooo<@000?l90?n001L0003o1P3o
P0120000o`030?n000000?l0003o0140003o3`3oool000T0oooo00@0GEeM0861P@21PH40Ogmo0P1C
De<00`1bLW80S8b<08b<S00208j>SP80OWin00D0JVYZ059BDP1BDU80OGem05mOG`0206IVIP0405MG
E`1kNg/0Ng]k08R8R080UiNG00D0MWIf0820P01LG5`0G5aL05mOG`0207IfMP0506MWI`2:RXX0RXZ:
0;6a/@2QXJ400P2:RXX00`2k^k/0PX:208:2PP030861P@05071`L02LW9`0]KFe0;Fe]@29RHT00P2L
W9`01@1>CTh0HF5Q09RHV02HV9P0b<S80080ZJVY00D0V9RH071`L01`L700UiNG0;6a/@0208:2PP04
071`L01BDU80DU9B079bLP80UiNG00D0Shn?0:BTY02j^[X0^[Zj0:ZZZP0209JFUP0507emO@2l_;`0
TY:B09:BTP2?Shl00P2=SHd01@2g]kL0alO70<O7a`2<S8`0M7Ad0080OGem00@0KVi^09:BTP2BTY80
Vi^K0P2LW9`01@26QXH0_[jn0:b/[02/[:`0PX:20080M7Ad00D0GemO0;Ng]`2SXj<0Xj>S0:RXZ002
02h^;P0506e]K@3De=@0e=CD07]kN`2GUiL00P21PH40101]KFd0Lg=c07=cL`2n_[h20;no_`050:NW
Y`2i^KT0MGEe07EeM@2>SXh00P2:RXX01@21PH40P8200820P023Ph<0Rh^;0080V9RH00D0K6a/05iN
GP1NGUh0?Cdm051@D00205YJFP0406QXJ02;Rh/0Rh^;08J6QP80IfMW00D0GEeM08N7Q`1nOWh0OWin
05QHF00205EEE@0504M7A`1LG5`0G5aL06m_K`1iNGT00P2;Rh/0102^[Zh0O7al07alO01oOgl407Ui
N@80B4Q80`1OGel00`1]KFd0oooo0?ooo`0C0?oooc40003o2@3oP00G0000o`H0oh00@P000?l00`3o
P000003o0000o`0A0000o`l0oooo00090?ooo`0406EUI@2<S8`0S8b<08B4Q080DU9B00D0O7al0:2P
X02PX:00WIfM09>CT`0208R8R00507UiN@1QHF40HF5Q07alO01ZJVX00P1VIVH0101JFUX0Jf][06][
J`1cLg<208>3P`0504m?C`20P800FUYJ05YJFP1=CDd00P1_Kfl01@1SHf<0RXZ:08Z:RP2][Jd0VYZJ
0080QXJ600@0/;2`08>3P`23Ph<0T92@0P1oOgl01@1UIFD0Shn?0:b/[02/[:`0UYJF0080WinO00D0
EUIF06e]K@2_[jl0[jn_0<g=c@020;Ng]`050;Fe]@1gMgL0MgMg09RHV030`<000P1oOgl0101gMgL0
D51@051@D024Q8@20:>SX`0509^KV`2c/k<0a<C40<C4a02`/;000P2/[:`01@22PX80bLW909jNWP2N
WYh0SHf=0080TY:B00D0ZZZZ0;bl_02l_;`0R8R8061PH00207=cL`0406UYJ@1mOGd0OGem096AT@80
VIVI00D0Shn?0<;2`P2VYZH0YZJV07emO@0207YjNP0505QHF02j^[X0YjNW0:NWY`2`/;000P0n?Sh0
1@1]KFd0g=cL0=cLg025QHD0XJ6Q0080MgMg0`1aLG401@2l_;`0^KVi0;Vi^@2WYjL0/[:b0080Rh^;
00@0WYjN08B4Q024Q8@0IfMW0P1nOWh01@1dM7@0UYJF09BDU02DU9@0JVYZ0080BDU900D0=CDe04Q8
B01JFUX0FUYJ05IFEP0207UiN@0507inOP1ZJVX0JVYZ05eMG@2;Rh/00P2=SHd0101UIFD0J6QX06QX
J01`L70206m_K`0507alO02DU9@0Ti>C09>CT`2c/k<00P27QhL208>3P`80QXJ600@0JFUY04e=C@1=
CDd0HF5Q0P1GEeL00`1[Jf/0oooo0?ooo`0C0?ooo`l0003o1@3oP0070000o`030?n000000?l0003o
0140003o2`3oP00J0000o`030?n000000?l0003o00D0003o203oP0190000o`l0oooo00090?ooo`04
071`L02=SHd0SHf=07alO080DE5A00D0L71`09:BTP2BTY80TY:B09VIV@0209:BTP0407emO@1OGel0
GemO07QhN0<0IFEU00@0D51@05ADE01DE5@0@d=30P22PX801@1[Jf/0N7Qh0492@P12@T80>3Ph0080
JVYZ00D0GEeM07=cL`1cLg<0YZJV09fMW@0207]kN`040:f][@23Ph<0Ph>308:2PP80PH6100D0KFe]
09BDU02a/K40/K6a08^;R`0209JFUP05055AD@1DE5@0T92@092@T02VYZH00P2FUYH01@2EUID0KVi^
06i^KP1nOWh0XZ:R0080N7Qh00@0NGUi05=CD`1CDe<0Rh^;0P2f][H01@2EUID0[jn_0<G5a@35aLD0
Y:BT0080W9bL00D0QhN70=SHf02][Jd0[Jf]08n?S`02092@T0050;Vi^@3@d=00d=3@0:>SX`1kNg/0
0P1oOgl0101fMWH0S8b<08b<S01jNWX208n?S`0508>3P`2XZ:P0UYJF09JFUP1cLg<00P1UIFD01@1=
CDd0ZZZZ0;Jf]P2f][H0[Zj^0080@d=300D0Kfm_0=[JfP3Jf]X0NGUi09NGU`0207EeM@0406a/K01[
Jf/0Jf][0;>c/`80_kno00D0Y:BT09>CT`2BTY80TY:B08Z:RP0209FEU@0506m_K`2FUYH0UYJF06m_
K`2VYZH00P2GUiL01@1jNWX0FEUI05UIF@0k>c/0DE5A0080Cdm?00@0HF5Q06e]K@1]KFd0K6a/0P1_
Kfl01@1TI6@0RXZ:08B4Q024Q8@0LG5a0080KFe]00D0HV9R08B4Q024Q8@0PH6108b<S00208N7Q`05
0;Jf]P20P800P82008>3P`26QXH00P2DU9@0101[Jf/0@T920492@P1GEeL2061PH00305ADE03oool0
oooo01<0oooo3`000?l50?n00180003o00<0oh000000o`000?l0>0000?l30?n004T0003o3`3oool0
00T0oooo00@0L71`08R8R028R8P0Ti>C0P1IFET01@1oOgl0UYJF09JFUP2FUYH0UiNG0080SHf=00D0
OGem05]KF`1KFe/0KVi^071`L00206m_K`0407IfMP23Ph<0Ph>306UYJ@80P82000D0K6a/06UYJ@15
ADD0ADE503Hf=P02079bLP0507=cL`2<S8`0S8b<0:NWY`2<S8`00P1`L7000`2d];@0U9BD09BDU003
08R8R00506=SH`2?Shl0/k>c0;>c/`2ATI400P2HV9P01@1OGel0Hf=S0:b/[02/[:`0]KFe0080/k>c
00D0YJFU08B4Q024Q8@0QXJ60;6a/@020820P00407YjNP1@D500D51@08B4Q080WinO00D0SHf=0;jn
_P35aLD0aLG50::RXP0209NGU`050861P@3Hf=P0[Jf]0:f][@2HV9P00P2KVi/01@2j^[X0clo?0<o?
c`2ZZZX0MWIf0080MgMg00@0IVIV09>CT`2CTi<0PH610P2IVIT01@2>SXh0[Zj^0:JVYP2VYZH0T92@
0080KVi^00D0EUIF0<K6aP2j^[X0^[Zj0:n_[`0204a<C00506][J`3Ng]h0g]kN07IfMP2[Zj/00P29
RHT0101/K6`0J6QX06QXJ02YZJT20<K6aP050:^[Z`1lO7`0T92@092@T02=SHd00P2BTY801@1bLW80
Ti>C09>CT`1XJ6P0ZJVY0080Xj>S00D0Lg=c04Y:BP1:BTX0=cLg04a<C00204];B`0407UiN@1UIFD0
IFEU06QXJ080Jf][00D0IVIV08:2PP1jNWX0NWYj06UYJ@0206a/K005079bLP23Ph<0Ph>308f=S@2S
Xj<00P2XZ:P01@2j^[X0S8b<08b<S025QHD0N7Qh0080Ti>C00@0OWin05IFEP1FEUH0FUYJ0P1KFe/0
0`1IFET0oooo0?ooo`0C0?oooaX0003o00<0oh000000o`000?l02@000?l00`3oP000003o0000o`1a
0000o`<0oh000P000?l60?n000P0003o3`3oool000T0oooo00@0L71`08R8R028R8P0Ti>C0P1IFET0
1@1oOgl0UYJF09JFUP2FUYH0UiNG0080SHf=00D0OGem05]KF`1KFe/0KVi^071`L00206m_K`0407If
MP23Ph<0Ph>306UYJ@80P82000D0K6a/06UYJ@15ADD0ADE503Hf=P02079bLP0507=cL`2<S8`0S8b<
0:NWY`2<S8`00P1`L7000`2d];@0U9BD09BDU00308R8R00506=SH`2?Shl0/k>c0;>c/`2ATI400P2H
V9P01@1OGel0Hf=S0:b/[02/[:`0]KFe0080/k>c00D0YJFU08B4Q024Q8@0QXJ60;6a/@020820P004
07YjNP1@D500D51@08B4Q080WinO00D0SHf=0;jn_P35aLD0aLG50::RXP0209NGU`050861P@3Hf=P0
[Jf]0:f][@2HV9P00P2KVi/01@2j^[X0clo?0<o?c`2ZZZX0MWIf0080MgMg00@0IVIV09>CT`2CTi<0
PH610P2IVIT01@2>SXh0[Zj^0:JVYP2VYZH0T92@0080KVi^00D0EUIF0<K6aP2j^[X0^[Zj0:n_[`02
04a<C00506][J`3Ng]h0g]kN07IfMP2[Zj/00P29RHT0101/K6`0J6QX06QXJ02YZJT20<K6aP050:^[
Z`1lO7`0T92@092@T02=SHd00P2BTY801@1bLW80Ti>C09>CT`1XJ6P0ZJVY0080Xj>S00D0Lg=c04Y:
BP1:BTX0=cLg04a<C00204];B`0407UiN@1UIFD0IFEU06QXJ080Jf][00D0IVIV08:2PP1jNWX0NWYj
06UYJ@0206a/K005079bLP23Ph<0Ph>308f=S@2SXj<00P2XZ:P01@2j^[X0S8b<08b<S025QHD0N7Qh
0080Ti>C00@0OWin05IFEP1FEUH0FUYJ0P1KFe/00`1IFET0oooo0?ooo`0C0?oooaX0003o00<0oh00
0000o`000?l02@000?l00`3oP000003o0000o`1a0000o`<0oh000P000?l60?n000P0003o3`3oool0
00T0oooo00@0MgMg09>CT`2CTi<0V9RH0P1JFUX01@28R8P0WYjN09jNWP2QXJ40W9bL0080SXj>00D0
MGEe05UIF@1IFET0Jf][06QXJ002069RHP0406UYJ@1eMGD0MGEe06a/K080PX:200D0IVIV07=cL`1H
F5P0F5QH04Y:BP0206IVIP0507QhN02>SXh0SXj>0:ZZZP29RHT00P1mOGd0102SXj<0Ng]k07]kN`1W
IfL207MgM`0505YJFP27QhL0^;Rh0;Rh^02GUiL00P2DU9@01@1TI6@0HV9R0;no_`2o_kl0]KFe0080
a<C400D0YjNW09>CT`2CTi<0Ogmo0:NWY`0208F5Q@0407inOP1EEED0EEEE08f=S@80ZJVY00D0VYZJ
0<?3``39bLT0bLW90:BTY00209VIV@050820P03Ph>00[jn_0:n_[`2QXJ400P2PX:001@2o_kl0d];B
0=;BdP2JVYX0MGEe0080QHF500@0IFEU0:FUY@2UYJD0Ph>30P2KVi/01@2=SHd0/;2`0:VYZ@2YZJT0
SXj>0080IfMW00D0CTi>0;Ng]`2[Zj/0Zj^[0:FUY@0205=CD`0505YJFP3@d=00d=3@06i^KP2TY:@0
0P20P800101^KVh0HF5Q065QH@2b/[820<g=c@050;:b/P23Ph<0RXZ:08Z:RP2<S8`00P26QXH01@1i
NGT0W9bL09bLW01RHV80WinO0080XZ:R00D0Lg=c04Q8B018B4P0>3Ph04M7A`0204Q8B0040820P01B
DU80DU9B07moO`80N7Qh00<0J6QX08R8R01^KVh00P1^KVh206=SH`0507EeM@2HV9P0V9RH09JFUP2;
Rh/00P2FUYH01@30`<00Ti>C09>CT`2<S8`0Shn?0080Xj>S00@0U9BD06][J`1[Jf/0JVYZ0`1UIFDE
0?ooobT0003o1@3oP01S0000o`030?n000000?l0003o0080003o2`3oP0040000o`@0oh0010000?l?
0?ooo`002@3oool0101bLW80QhN708N7Q`20P80204e=C@0508R8R02JVYX0VYZJ09NGU`2?Shl00P2B
TY801@1gMgL0GUiN05iNGP1[Jf/0L71`0080Jf][00@0Hf=S07UiN@1iNGT0G5aL0P20P8001@1mOGd0
DE5A02d];@0];Bd0DE5A0080I6AT00D0MgMg08J6QP26QXH0/[:b08b<S00208J6QP040:n_[`2EUID0
UIFE07alO080Kfm_00D0BTY:06m_K`2RXZ80XZ:R08j>SP0208:2PP0505eMG@1@D500[Jf]0:f][@2^
[Zh00P2j^[X01@2KVi/0XZ:R0::RXP1hN7P0Vi^K0080Q8B400@0M7Ad05]KF`1KFe/0P8200P2/[:`0
1@2GUiL0_Kfm0<71`@31`L40ZJVY0080Vi^K00D0OGem0=gMg@2[Zj/0Zj^[09RHV00209jNWP050;Ng
]`3@d=00d=3@09nOW`1]KFd00P1[Jf/0101FEUH0UiNG09NGU`22PX8209VIV@0508^;R`2a/K40[Jf]
0:f][@2LW9`00P1UIFD01@1;Bd/0_[jn0;Ng]`2g]kL0`L710080De=C00D0G5aL0=CDe03De=@0JVYZ
0::RXP0207alO00406EUI@1SHf<0Hf=S09VIV@80[jn_00D0WYjN08N7Q`22PX80PX:20820P00209FE
U@0507UiN@2TY:@0Y:BT061PH02YZJT00P2KVi/01@1/K6`0@4100410@00e=CD0B4Q80080CTi>00@0
MWIf05]KF`1KFe/0LG5a0P1eMGD01@1iNGT0UYJF07EeM@1eMGD0NGUi0080HV9R00D0JFUY0820P020
P800LG5a07]kN`0207UiN@0509ZJVP1dM7@0M7Ad07moO`1iNGT00P2FUYH0102=SHd0LG5a075aL@1g
MgL207YjNP0307UiN@3oool0oooo01<0oooo50000?l20?n000030000o`3oP000003o04h0003o00<0
oh000000o`000?l08@000?l80?n00180003o103oP0040000o`l0oooo00090?ooo`04079bLP27QhL0
QhN70820P080CDe=00D0R8R809ZJVP2JVYX0UiNG08n?S`0209:BTP0507MgM`1NGUh0GUiN06][J`1`
L7000P1[Jf/0101SHf<0NGUi07UiN@1LG5`20820P00507emO@1ADE40;Bd]02d];@1ADE400P1TI6@0
1@1gMgL0QXJ608J6QP2b/[80S8b<0080QXJ600@0[jn_09FEU@2EUID0O7al0P1_Kfl01@1:BTX0Kfm_
0::RXP2RXZ80SXj>0080PX:200D0GEeM051@D02][Jd0[Jf]0:j^[P020;Zj^P0509^KV`2RXZ80XZ:R
07QhN02KVi/00P24Q8@0101dM7@0Fe]K05]KF`20P8020:b/[00509NGU`2m_Kd0`L710<71`@2YZJT0
0P2KVi/01@1mOGd0gMgM0:^[Z`2[Zj/0V9RH0080WYjN00D0]kNg0=3@d03@d=00WinO06e]K@0206][
J`0405IFEP2GUiL0UiNG08:2PP80VIVI00D0Rh^;0;6a/@2][Jd0[Jf]09bLW00206EUI@0504];B`2n
_[h0]kNg0;Ng]`31`L400P1CDe<01@1LG5`0e=CD0=CDe01ZJVX0XZ:R0080O7al00@0IFEU06=SH`1S
Hf<0VIVI0P2_[jl01@2NWYh0QhN708:2PP22PX80P8200080UIFE00D0NGUi0:BTY02TY:@0H61P0:VY
Z@0209^KV`0506a/K010@400@41003De=@18B4P00P1>CTh0101fMWH0Fe]K05]KF`1aLG4207EeM@05
07UiN@2FUYH0MGEe07EeM@1iNGT00P1RHV801@1YJFT0P8200820P01aLG40Ng]k0080NGUi00D0VYZJ
07AdM01dM7@0Ogmo07UiN@0209JFUP0408f=S@1aLG40LG5a07MgM`80NWYj00<0NGUi0?ooo`3oool0
4`3oool>0000o`030?n000000?l0003o00<0003o1`3oP00@0000o`80oh005@000?l40?n00240003o
00<0oh000000o`000?l080000?l00`3oP000003o0000o`0P0000o`l0oooo00090?ooo`0406][J`2A
TI40TI6A07emO@80CTi>00<0Ph>309ZJVP2JVYX00P2JVYX2096AT@0507MgM`1PH600H61P07AdM01^
KVh00P1BDU80101`L700KFe]06e]K@1MGEd20820P00507EeM@15ADD0EUIF05IFEP1?Cdl00P1DE5@0
1@1kNg/0RHV908V9R@2][Jd0Shn?0080LW9b00@0[:b/0:2PX02PX:00QXJ60P1]KFd01@1GEeL0UIFE
0;Zj^P2j^[X0TY:B0080Ph>300D0IfMW04I6AP2WYjL0YjNW0:2PX0020;fm_@050:FUY@2SXj<0Xj>S
07YjNP2FUYH00P2:RXX0101iNGT0LW9b079bLP2;Rh/20:6QX@050:FUY@2d];@0^;Rh0;Rh^02YZJT0
0P2BTY801@1lO7`0e=CD0:^[Z`2[Zj/0Xj>S0080YZJV00D0b<S80=GEe@3EeMD0W9bL07QhN0020820
P00405aLG02BTY80TY:B08N7Q`80XJ6Q00D0R8R80;Ng]`2TY:@0Y:BT09>CT`0205mOG`05051@D02m
_Kd0]kNg0;Ng]`3?cll00P1EEED01@1_Kfl0gMgM0=gMg@1eMGD0/;2`0080O7al00@0HF5Q06m_K`1_
Kfl0Zj^[0P32`/801@2MWId0N7Qh08F5Q@25QHD0VYZJ0080V9RH00D0MGEe0:2PX02PX:00GEeM0:ZZ
ZP0209nOW`05069RHP0l?3`0?3`l03Ph>01IFET00P1CDe<0101GEeL0Fe]K05]KF`1VIVH206e]K@05
05aLG02>SXh0KFe]06e]K@1ADE400P1cLg<01@1mOGd0VIVI09VIV@2EUID0Rh^;0080R8R800D0][Jf
08>3P`23Ph<0QHF508J6QP0208R8R00407inOP1FEUH0EUIF05iNGP80GEeM00<0Lg=c0?ooo`3oool0
4`3oool>0000o`030?n000000?l0003o00<0003o1`3oP00@0000o`80oh005@000?l40?n00240003o
00<0oh000000o`000?l080000?l00`3oP000003o0000o`0P0000o`l0oooo00090?ooo`0407MgM`2P
X:00X:2P07emO@80Cdm?00D0TI6A09bLW02LW9`0X:2P09FEU@0208f=S@0507moO`1OGel0GemO06][
J`1fMWH00P0m?Cd0101[Jf/0Ng]k07]kN`1YJFT20:6QX@0508F5Q@1gMgL0O7al07alO01MGEd00P1A
DE401@23Ph<0QhN708N7Q`2b/[80Shn?0080K6a/00@0[Zj^0::RXP2RXZ80RHV90P1bLW801@1DE5@0
QXJ60;Fe]@2e]KD0WinO00<0MGEe00@0BDU90<71`@31`L40^KVi0P36a/H01@2/[:`0Y:BT0:BTY01m
OGd0V9RH0080UiNG00@0MWIf07EeM@1eMGD0RHV90P2UYJD01@2/[:`0_;bl0<k>cP3>c/h0/;2`0080
Ti>C00D0O7al0=OGe`2`/;00/;2`09nOW`0209fMW@050;Rh^03Fe]H0e]KF096AT@1bLW800P20P800
101QHF40VIVI09VIV@27QhL209RHV00507alO02b/[80VYZJ09ZJVP2=SHd00P1KFe/01@1EEED0aLG5
0:NWY`2WYjL0YZJV0080?Shn00D0H61P0=OGe`3GemL0M7Ad0;Vi^@0207moO`0407QhN01fMWH0MWIf
0;>c/`80emOG00D0YJFU07=cL`2ATI40TI6A0:BTY00209NGU`0507YjNP2IVIT0VIVI05aLG02_[jl0
0P2IVIT01@1^KVh0>SXj03Xj>P14A4@0IfMW0080M7Ad00@0Fe]K06YZJP1ZJVX0M7Ad0P1jNWX01@1d
M7@0UIFE07EeM@1eMGD0N7Qh0080NWYj00D0L71`09nOW`2OWil0QHF50:JVYP0209jNWP050;2`/01d
M7@0M7Ad07EeM@26QXH00P1hN7P0101cLg<0M7Ad07AdM01hN7P204];B`03075aL@3oool0oooo01<0
oooo3`000?l40?n001H0003o00@0oh000000o`3oP000oh0040000?l30?n00080003o1P3oP00O0000
o`030?n000000?l0003o0100003o0P3oP00B0000o`/0oh0050000?l?0?ooo`002@3oool0101VIVH0
VIVI09VIV@1kNg/204];B`0509>CT`2LW9`0W9bL09jNWP2QXJ400P2<S8`01@1kNg/0Fe]K05]KF`1f
MWH0NGUi0080Q8B400@0NGUi07MgM`1gMgL0HV9R0P2MWId01@1kNg/0IfMW071`L01`L700EeMG0080
CTi>00D0O7al08J6QP26QXH0/k>c08n?S`0207YjNP040:VYZ@2UYJD0YJFU08^;R`80Lg=c00D0K6a/
0:FUY@3<c<`0c<c<0:NWY`0207inOP0507]kN`1;Bd/0_;bl0;bl_02^[Zh00P37alL01@2WYjL0U9BD
09BDU025QHD0P8200080Lg=c00@0JVYZ07EeM@1eMGD0PX:20P2BTY801@2LW9`0WinO0;jn_P2n_[h0
XZ:R0080Rh^;00D0OWin0=[JfP2d];@0];Bd09RHV00209jNWP050;2`/03Jf]X0f][J09BDU01gMgL0
0P25QHD0101VIVH0TY:B09:BTP25QHD209bLW00507moO`2TY:@0XZ:R0::RXP2YZJT00P1TI6@01@1O
Gel0bLW90;Ng]`2g]kL0a/K60080ATI600D0L71`0=OGe`3GemL0MWIf0:JVYP0207alO0040820P01a
LG40LG5a0:n_[`80d=3@00D0YZJV07alO02`/;00/;2`0:n_[`0209nOW`0508J6QP2][Jd0[Jf]05aL
G02d];@00P2QXJ401@23Ph<0>CTi03Ti>@10@400Hf=S0080KFe]00@0Bd];06e]K@1]KFd0IfMW0P1c
Lg<01@22PX80V9RH07=cL`1cLg<0MGEe0080OGem00D0PH610:6QX@2QXJ40YJFU09jNWP0208R8R005
0:j^[P1]KFd0KFe]071`L023Ph<00P1oOgl0102<S8`0M7Ad07AdM01]KFd205iNGP0308:2PP3oool0
oooo01<0oooo?@000?l00`3oP000003o0000o`1:0000o`/0oh0060000?l?0?ooo`002@3oool0101V
IVH0VIVI09VIV@1kNg/204];B`0509>CT`2LW9`0W9bL09jNWP2QXJ400P2<S8`01@1kNg/0Fe]K05]K
F`1fMWH0NGUi0080Q8B400@0NGUi07MgM`1gMgL0HV9R0P2MWId01@1kNg/0IfMW071`L01`L700EeMG
0080CTi>00D0O7al08J6QP26QXH0/k>c08n?S`0207YjNP040:VYZ@2UYJD0YJFU08^;R`80Lg=c00D0
K6a/0:FUY@3<c<`0c<c<0:NWY`0207inOP0507]kN`1;Bd/0_;bl0;bl_02^[Zh00P37alL01@2WYjL0
U9BD09BDU025QHD0P8200080Lg=c00@0JVYZ07EeM@1eMGD0PX:20P2BTY801@2LW9`0WinO0;jn_P2n
_[h0XZ:R0080Rh^;00D0OWin0=[JfP2d];@0];Bd09RHV00209jNWP050;2`/03Jf]X0f][J09BDU01g
MgL00P25QHD0101VIVH0TY:B09:BTP25QHD209bLW00507moO`2TY:@0XZ:R0::RXP2YZJT00P1TI6@0
1@1OGel0bLW90;Ng]`2g]kL0a/K60080ATI600D0L71`0=OGe`3GemL0MWIf0:JVYP0207alO0040820
P01aLG40LG5a0:n_[`80d=3@00D0YZJV07alO02`/;00/;2`0:n_[`0209nOW`0508J6QP2][Jd0[Jf]
05aLG02d];@00P2QXJ401@23Ph<0>CTi03Ti>@10@400Hf=S0080KFe]00@0Bd];06e]K@1]KFd0IfMW
0P1cLg<01@22PX80V9RH07=cL`1cLg<0MGEe0080OGem00D0PH610:6QX@2QXJ40YJFU09jNWP0208R8
R0050:j^[P1]KFd0KFe]071`L023Ph<00P1oOgl0102<S8`0M7Ad07AdM01]KFd205iNGP0308:2PP3o
ool0oooo01<0oooo?@000?l00`3oP000003o0000o`1E0000o`D0oh004`000?l?0?ooo`002@3oool0
101]KFd0XZ:R0::RXP1kNg/204];B`0509FEU@2IVIT0VIVI09jNWP2TY:@00P2;Rh/01@1iNGT0EeMG
05MGE`1oOgl0O7al0080MgMg00@0L71`06IVIP1VIVH0F5QH0P2EUID01@1hN7P0EUIF06][J`1[Jf/0
Fe]K0080EEEE0`1jNWX01@2b/[80SHf=08N7Q`27QhL0Z:RX0080YJFU00D0S8b<06ATI01TI6@0F5QH
09VIV@020<k>cP050::RXP1jNWX0NWYj07UiN@16ATH00P2l_;`0102TY:@0_[jn0;jn_P2VYZH207mo
O`0507]kN`1nOWh0P8200820P01hN7P00P28R8P01@2=SHd0S8b<08b<S02BTY80][Jf0080c<c<00D0
]KFe09VIV@2IVIT0N7Qh0=_Kf`020;Jf]P0409NGU`2PX:00X:2P0;Rh^080e=CD00D0XZ:R07IfMP2<
S8`0S8b<06MWI`0209JFUP0508N7Q`2QXJ40XJ6Q08^;R`2_[jl00P2WYjL01@2ATI40FEUI05UIF@1N
GUh0Zj^[0080[Zj^00@0^k^k03Xj>P0j>SX0NWYj0P3De=@01@1iNGT0]KFe07MgM`1gMgL0Q8B40080
OWin00D0[Jf]0=_Kf`3Kfm/0YJFU07YjNP0209:BTP040:RXZ02IVIT0VIVI08B4Q080Ti>C00D0FUYJ
0;jn_P2EUID0UIFE07inOP0203De=@0503dm?@1LG5`0Fe]K05]KF`1<C4`00P1CDe<01@1@D500FUYJ
05YJFP1MGEd0MgMg0080EUIF00@0Jf][069RHP1RHV80K6a/0P29RHT01@2NWYh0WinO08R8R028R8P0
];Bd0080R8R80P27QhL2079bLP0408n?S`1`L700L71`07=cL`80JVYZ00<0OGem0?ooo`3oool04`3o
oolm0000o`030?n000000?l0003o05D0003o1@3oP00C0000o`l0oooo00090?ooo`0406YZJP2FUYH0
UYJF07alO080ADE500D0RXZ:09BDU02DU9@0UYJF0:JVYP0208>3P`0507AdM01IFET0FEUI08B4Q01g
MgL00P1eMGD0101SHf<0KFe]06e]K@1HF5P208b<S00507inOP1:BTX0G5aL05aLG01GEeL00P1<C4`0
1@1eMGD0LG5a075aL@2[Zj/0QXJ60080Shn?00@0XZ:R0:2PX02PX:00Ph>30P1VIVH01@1GEeL0RHV9
0<O7a`37alL0WIfM0080JVYZ00D0HV9R0492@P2d];@0];Bd09^KV`020;Vi^@050:JVYP26QXH0QXJ6
07alO01nOWh00P1cLg<0101OGel0P8200820P01lO7`209BDU00508V9R@2e]KD0_Kfm0;fm_@2a/K40
0P2DU9@01@1oOgl0d];B0;Rh^02h^;P0ZZZZ0080XJ6Q00D0^[Zj0<c<c03<c<`0XJ6Q07UiN@0207in
OP04065QH@2EUID0UIFE092@T080X:2P00D0TI6A0:^[Z`2VYZH0YZJV08Z:RP0205=CD`05065QH@2G
UiL0ZJVY0:VYZ@3AdM400P0o?cl01@2ATI40i>CT0>CTi01nOWh0[:b/0080NWYj00@0Ph>307YjNP1j
NWX0[Jf]0P3Jf]X01@2TY:@0VYZJ08^;R`2;Rh/0[Zj^0080Shn?00D0UiNG092@T02@T900Lg=c0<C4
a0020::RXP0507moO`0m?Cd0?Cdm0410@01SHf<00P1RHV80101OGel0IfMW06MWI`1XJ6P207EeM@05
06e]K@1nOWh0H61P061PH01UIFD00P1[Jf/01@1LG5`0NGUi07UiN@2FUYH0Rh^;0080RXZ:00D0]KFe
08B4Q024Q8@0OWin09:BTP020820P00308F5Q@1dM7@0M7Ad00<0MgMg00<0Shn?0?ooo`3oool04`3o
oolB0000o`030?n000000?l0003o00h0003o0`3oP0030000o`040?n000000?l0oh000?n003<0003o
0`3oP00b0000o`80oh002P000?l00`3oP000003o0000o`090000o`l0oooo00090?ooo`0406YZJP2F
UYH0UYJF07alO080ADE500D0RXZ:09BDU02DU9@0UYJF0:JVYP0208>3P`0507AdM01IFET0FEUI08B4
Q01gMgL00P1eMGD0101SHf<0KFe]06e]K@1HF5P208b<S00507inOP1:BTX0G5aL05aLG01GEeL00P1<
C4`01@1eMGD0LG5a075aL@2[Zj/0QXJ60080Shn?00@0XZ:R0:2PX02PX:00Ph>30P1VIVH01@1GEeL0
RHV90<O7a`37alL0WIfM0080JVYZ00D0HV9R0492@P2d];@0];Bd09^KV`020;Vi^@050:JVYP26QXH0
QXJ607alO01nOWh00P1cLg<0101OGel0P8200820P01lO7`209BDU00508V9R@2e]KD0_Kfm0;fm_@2a
/K400P2DU9@01@1oOgl0d];B0;Rh^02h^;P0ZZZZ0080XJ6Q00D0^[Zj0<c<c03<c<`0XJ6Q07UiN@02
07inOP04065QH@2EUID0UIFE092@T080X:2P00D0TI6A0:^[Z`2VYZH0YZJV08Z:RP0205=CD`05065Q
H@2GUiL0ZJVY0:VYZ@3AdM400P0o?cl01@2ATI40i>CT0>CTi01nOWh0[:b/0080NWYj00@0Ph>307Yj
NP1jNWX0[Jf]0P3Jf]X01@2TY:@0VYZJ08^;R`2;Rh/0[Zj^0080Shn?00D0UiNG092@T02@T900Lg=c
0<C4a0020::RXP0507moO`0m?Cd0?Cdm0410@01SHf<00P1RHV80101OGel0IfMW06MWI`1XJ6P207Ee
M@0506e]K@1nOWh0H61P061PH01UIFD00P1[Jf/01@1LG5`0NGUi07UiN@2FUYH0Rh^;0080RXZ:00D0
]KFe08B4Q024Q8@0OWin09:BTP020820P00308F5Q@1dM7@0M7Ad00<0MgMg00<0Shn?0?ooo`3oool0
4`3oool50000o`80oh0050000?l50?n00080003o103oP00L0000o`H0oh0020000?l20?n000d0003o
1P3oP00F0000o`030?n000000?l0003o0240003o0`3oP0020000o`80oh001`000?l?0?ooo`002@3o
ool0101nOWh0W9bL09bLW020P80204e=C@0508j>SP2FUYH0UYJF09VIV@2a/K400P2CTi<01@1nOWh0
FEUI05UIF@2;Rh/0Ng]k0080Ogmo00@0N7Qh08N7Q`27QhL0HF5Q0P2BTY801@1`L700HV9R06i^KP1^
KVh0DU9B0080BTY:00D0NGUi08J6QP26QXH0[Zj^08Z:RP0208R8R0040:2PX02IVIT0VIVI07=cL`80
Fe]K00D0EeMG08j>SP2e]KD0]KFe09NGU`0206IVIP0507EeM@17AdL0YjNW0:NWY`2KVi/00P32`/80
1@2/[:`0RHV908V9R@1gMgL0QHF50080QXJ600@0MGEe08n?S`2?Shl0Lg=c0P2KVi/01@2CTi<0/k>c
0<71`@31`L40/k>c0080Vi^K00D0PH610>3Ph02b/[80/[:b0:6QX@0209fMW@050;Zj^P3>c/h0c/k>
0:RXZ01eMGD00P2>SXh0101XJ6P0VIVI09VIV@2<S8`20:6QX@05096AT@2ZZZX0[Zj^0:j^[P2GUiL0
0P1LG5`01@1gMgL0YZJV0:j^[P2^[Zh0clo?0080;bl_00D0SHf=0=gMg@3MgMd0OWin0;:b/P0208R8
R00407moO`1fMWH0MWIf0;Bd]080eMGE00D0WYjN09JFUP2FUYH0UYJF0;2`/00209>CT`0509jNWP2;
Rh/0Rh^;07YjNP2o_kl00P2PX:001@1dM7@0Bd];04];B`13@d<0H61P0080HV9R00<0E5AD06i^KP1^
KVh00`1eMGD01@1aLG40MWIf075aL@1aLG40LW9b0080K6a/00D0QHF509NGU`2GUiL0Xj>S08V9R@02
08Z:RP050;6a/@2FUYH0UYJF08J6QP2NWYh00P1iNGT00`28R8P0MGEe07EeM@0306][J`0308Z:RP3o
ool0oooo01<0oooo2`000?l00`3oP000003o0000o`020000o`H0oh00=`000?l50?n00200003o00@0
oh000000o`3oP000oh007`000?l50?n000D0003o0P3oP0050000o`<0oh0010000?l?0?ooo`002@3o
ool0101fMWH0UiNG09NGU`21PH4205EEE@0509jNWP2SXj<0Xj>S0::RXP2g]kL00P2GUiL01@1gMgL0
FUYJ05YJFP2CTi<0NGUi00<0LW9b0P1gMgL01@1LG5`0Shn?08n?S`24Q8@0FUYJ0080MgMg00@0JFUY
061PH01PH600Shn?0P2@T9001@2a/K40V9RH09^KV`2KVi/0^;Rh0080[:b/00D0Q8B406YZJP1ZJVX0
GemO0:JVYP020=3@d0050;6a/@1^KVh0KVi^07QhN01CDe<00P2PX:00102CTi<0a<C40<C4a02a/K42
0820P00506][J`1hN7P0R8R808R8R01fMWH00P2KVi/01@1UIFD0Rh^;08^;R`2ATI40Xj>S0080Y:BT
00D0YjNW08j>SP2>SXh0N7Qh0=GEe@020;>c/`040:FUY@2[Zj/0Zj^[0;Zj^P80f=SH00D0[Jf]07]k
N`26QXH0QXJ6061PH00209JFUP0508J6QP2TY:@0Y:BT08^;R`2LW9`00P2IVIT01@1dM7@0DU9B059B
DP1_Kfl0Shn?0080YZJV00@0`<30038b<P0b<S80W9bL0P3Hf=P01@1lO7`0X:2P08>3P`23Ph<0NWYj
0080Lg=c00D0^KVi0=7Ad@3AdM40VYZJ07YjNP020;6a/@040:f][@2RXZ80XZ:R0:VYZ@80Shn?00D0
PH610;jn_P29RHT0RHV906=SH`02055AD@0503dm?@1QHF40GemO05mOG`1;Bd/00P1QHF401@1mOGd0
Jf][06][J`1YJFT0Lg=c0080KVi^00@0Jf][07=cL`1cLg<0Ogmo0P2:RXX01@2QXJ40UYJF09^KV`2K
Vi/0/[:b0080SXj>00D0OWin08:2PP1NGUh0GUiN06EUI@0206a/K00405YJFP1LG5`0G5aL07moOaD0
oooo2`000?l00`3oP000003o0000o`020000o`H0oh00=`000?l50?n00200003o00@0oh000000o`3o
P000oh007`000?l50?n000D0003o0P3oP0050000o`<0oh0010000?l?0?ooo`002@3oool0101fMWH0
UiNG09NGU`21PH4205EEE@0509jNWP2SXj<0Xj>S0::RXP2g]kL00P2GUiL01@1gMgL0FUYJ05YJFP2C
Ti<0NGUi00<0LW9b0P1gMgL01@1LG5`0Shn?08n?S`24Q8@0FUYJ0080MgMg00@0JFUY061PH01PH600
Shn?0P2@T9001@2a/K40V9RH09^KV`2KVi/0^;Rh0080[:b/00D0Q8B406YZJP1ZJVX0GemO0:JVYP02
0=3@d0050;6a/@1^KVh0KVi^07QhN01CDe<00P2PX:00102CTi<0a<C40<C4a02a/K420820P00506][
J`1hN7P0R8R808R8R01fMWH00P2KVi/01@1UIFD0Rh^;08^;R`2ATI40Xj>S0080Y:BT00D0YjNW08j>
SP2>SXh0N7Qh0=GEe@020;>c/`040:FUY@2[Zj/0Zj^[0;Zj^P80f=SH00D0[Jf]07]kN`26QXH0QXJ6
061PH00209JFUP0508J6QP2TY:@0Y:BT08^;R`2LW9`00P2IVIT01@1dM7@0DU9B059BDP1_Kfl0Shn?
0080YZJV00@0`<30038b<P0b<S80W9bL0P3Hf=P01@1lO7`0X:2P08>3P`23Ph<0NWYj0080Lg=c00D0
^KVi0=7Ad@3AdM40VYZJ07YjNP020;6a/@040:f][@2RXZ80XZ:R0:VYZ@80Shn?00D0PH610;jn_P29
RHT0RHV906=SH`02055AD@0503dm?@1QHF40GemO05mOG`1;Bd/00P1QHF401@1mOGd0Jf][06][J`1Y
JFT0Lg=c0080KVi^00@0Jf][07=cL`1cLg<0Ogmo0P2:RXX01@2QXJ40UYJF09^KV`2KVi/0/[:b0080
SXj>00D0OWin08:2PP1NGUh0GUiN06EUI@0206a/K00405YJFP1LG5`0G5aL07moOaD0oooo3`000?l7
0?n000030000o`3oP000003o02l0003o00<0oh000000o`000?l00P000?l30?n004D0003o1P3oP002
0000o`030?n000000?l0003o00H0003o0`3oP0040000o`l0oooo00090?ooo`04079bLP2FUYH0UYJF
08:2PP80EeMG00D0V9RH09JFUP2FUYH0WinO0:f][@0207EeM@0506m_K`1IFET0FEUI08:2PP1[Jf/0
0P1gMgL0101iNGT0Lg=c07=cL`1fMWH20:2PX00508:2PP1CDe<0Hf=S06=SH`1]KFd00P1LG5`01@1a
LG40N7Qh07QhN02VYZH0RHV90080TI6A00@0Zj^[0:6QX@2QXJ40MWIf0P1[Jf/01@1OGel0Zj^[0=gM
g@3MgMd0^k^k0080J6QX00D0Ogmo051@D02OWil0WinO09ZJVP020<30`0050;bl_022PX80PX:206i^
KP21PH400P2ATI40101nOWh0VYZJ09ZJVP1WIfL208^;R`0509^KV`2e]KD0`/;20<;2`P2c/k<00P2N
WYh01@1cLg<0^;Rh0:FUY@2UYJD0Vi^K0080ZZZZ00D0YjNW0<[:bP3:b/X0P820079bLP0207alO004
06UYJ@2VYZH0YZJV08j>SP80YjNW00D0S8b<0:ZZZP2SXj<0Xj>S08^;R`0205UIF@0507]kN`2VYZH0
/K6a0;6a/@34a<@00P0k>c/01@2WYjL0h>3P0>3Ph022PX80UiNG0080OGem00@0LW9b069RHP1RHV80
XZ:R0P2l_;`01@2;Rh/0J6QX0:n_[`2_[jl0WIfM0080Shn?00D0SXj>08b<S02<S8`0X:2P0<S8b002
08Z:RP0505]KF`1JFUX0FUYJ04=3@`1XJ6P00P1TI6@0101IFET0LG5a075aL@24Q8@207]kN`0507Ad
M01VIVH0K6a/06a/K01[Jf/00P1oOgl01@26QXH0WYjN09jNWP2XZ:P0NGUi0080Ti>C00@0/k>c08n?
S`2?Shl0Ogmo0`2;Rh/0101IFET0C4a<04a<C01TI6@206IVIP0306YZJP3oool0oooo01<0ooooD000
0?l40?n00440003o00<0oh000000o`000?l05@000?l?0?ooo`002@3oool0101JFUX0Ph>308>3P`1i
NGT204Y:BP0509NGU`2KVi/0Vi^K09fMW@2FUYH00P2LW9`01@1fMWH0E5AD05ADE01iNGT0O7al0080
IVIV00@0EEEE04M7A`17AdL0De=C0P29RHT01@1]KFd0@T9205YJFP1JFUX0C4a<0080EUIF00D0Lg=c
07inOP1nOWh0W9bL08V9R@0209NGU`040:^[Z`2XZ:P0Z:RX07=cL`80LG5a00D0G5aL09BDU03AdM40
dM7A09VIV@0206=SH`0507emO@1GEeL0UIFE09FEU@2HV9P00P34a<@01@2`/;00NWYj07YjNP1]KFd0
LG5a0080Rh^;00@0Lg=c09RHV02HV9P0Lg=c0P2@T9001@2IVIT0]KFe0<?3``33`l<0];Bd0080WIfM
00D0MgMg0=GEe@30`<00`<300;:b/P020;Vi^@050:VYZ@3Jf]X0f][J08j>SP1oOgl00P28R8P0101Z
JVX0Vi^K09^KV`26QXH20:RXZ00507inOP2VYZH0Shn?08n?S`22PX800P1LG5`01@1nOWh0Vi^K0:j^
[P2^[Zh0alO70080?clo00D0Xj>S0>3Ph03Ph>00SHf=09^KV`0307moO`80Kfm_00D0/[:b0<_;b`3;
bl/0WYjN069RHP0205aLG00408N7Q`2QXJ40XJ6Q08j>SP80SHf=00D0Shn?0:ZZZP24Q8@0Q8B405=C
D`0204M7A`0503`l?01BDU80F5QH05QHF01FEUH00P1XJ6P01@1iNGT0MGEe07EeM@1ZJVX0MWIf0080
GEeM00@0JVYZ06a/K01/K6`0Jf][0P22PX801@2<S8`0EUIF07]kN`1kNg/0Vi^K0080M7Ad00D0L71`
08V9R@23Ph<0Ph>3069RHP0206m_K`04079bLP1jNWX0NWYj09bLW1D0ooooD0000?l40?n00440003o
00<0oh000000o`000?l05@000?l?0?ooo`002@3oool0101/K6`0UIFE09FEU@1nOWh2059BDP0508j>
SP2@T900T92@09NGU`2=SHd00P2<S8`01@1_Kfl0BTY:04Y:BP1/K6`0Lg=c0080J6QX00@0JVYZ06MW
I`1WIfL0De=C0P2<S8`01@1bLW80@D5106EUI@1UIFD0AdM70080BDU900D0JVYZ07UiN@1iNGT0XZ:R
07inOP0209^KV`040:6QX@2DU9@0U9BD06ATI080K6a/00D0H61P08j>SP30`<00`<3009JFUP0205iN
GP050820P01HF5P0W9bL09bLW02WYjL00P36a/H01@2YZJT0MgMg07MgM`1aLG40KFe]0080PX:200@0
LG5a096AT@2ATI40KVi^0P27QhL01@2DU9@0];Bd0::RXP2RXZ80Xj>S0080TI6A00D0IFEU0=;BdP2k
^k/0^k^k09:BTP020:n_[`050;2`/03Ph>00h>3P09BDU029RHT00P22PX80101PH600WIfM09fMW@25
QHD20:RXZ00507emO@2/[:`0Y:BT0:BTY02<S8`00P1NGUh01@1oOgl0VYZJ09jNWP2NWYh0d];B0080
ATI600D0Xj>S0>?Sh`3Shn<0PH6108j>SP0207inOP0408F5Q@1cLg<0Lg=c0:n_[`80clo?00D0YJFU
05EEE@1MGEd0GEeM08J6QP0209VIV@0508V9R@2FUYH0UYJF09bLW02k^k/00P1iNGT01@10@400A4A4
04A4A00f=SH0G5aL0080FUYJ00@0HV9R06a/K01/K6`0NGUi0P1`L7001@1YJFT0KFe]06QXJ01XJ6P0
G5aL0080K6a/00D0MgMg09:BTP2BTY80Rh^;069RHP0207alO00509RHV023Ph<0Ph>307inOP1fMWH0
0P1_Kfl0101SHf<0KVi^06i^KP1_Kfl206a/K00307QhN03oool0oooo01<0ooooCP000?l60?n003h0
003o203oP0030000o`P0oh0020000?l?0?ooo`002@3oool0101/K6`0UIFE09FEU@1nOWh2059BDP05
08j>SP2@T900T92@09NGU`2=SHd00P2<S8`01@1_Kfl0BTY:04Y:BP1/K6`0Lg=c0080J6QX00@0JVYZ
06MWI`1WIfL0De=C0P2<S8`01@1bLW80@D5106EUI@1UIFD0AdM70080BDU900D0JVYZ07UiN@1iNGT0
XZ:R07inOP0209^KV`040:6QX@2DU9@0U9BD06ATI080K6a/00D0H61P08j>SP30`<00`<3009JFUP02
05iNGP050820P01HF5P0W9bL09bLW02WYjL00P36a/H01@2YZJT0MgMg07MgM`1aLG40KFe]0080PX:2
00@0LG5a096AT@2ATI40KVi^0P27QhL01@2DU9@0];Bd0::RXP2RXZ80Xj>S0080TI6A00D0IFEU0=;B
dP2k^k/0^k^k09:BTP020:n_[`050;2`/03Ph>00h>3P09BDU029RHT00P22PX80101PH600WIfM09fM
W@25QHD20:RXZ00507emO@2/[:`0Y:BT0:BTY02<S8`00P1NGUh01@1oOgl0VYZJ09jNWP2NWYh0d];B
0080ATI600D0Xj>S0>?Sh`3Shn<0PH6108j>SP0207inOP0408F5Q@1cLg<0Lg=c0:n_[`80clo?00D0
YJFU05EEE@1MGEd0GEeM08J6QP0209VIV@0508V9R@2FUYH0UYJF09bLW02k^k/00P1iNGT01@10@400
A4A404A4A00f=SH0G5aL0080FUYJ00@0HV9R06a/K01/K6`0NGUi0P1`L7001@1YJFT0KFe]06QXJ01X
J6P0G5aL0080K6a/00D0MgMg09:BTP2BTY80Rh^;069RHP0207alO00509RHV023Ph<0Ph>307inOP1f
MWH00P1_Kfl0101SHf<0KVi^06i^KP1_Kfl206a/K00307QhN03oool0oooo01<0oooo4`000?l30?n0
00D0003o00<0oh000000o`000?l0M`000?l:0?n000h0003o3`3oool000T0oooo00@0IfMW0:JVYP2V
YZH0NGUi0P1DE5@01@2ATI40W9bL09bLW02PX:00XZ:R0080PX:200D0MgMg05MGE`1GEeL0NWYj07Ee
M@0205QHF004079bLP1TI6@0I6AT071`L080R8R800D0KFe]03hn?P1ZJVX0JVYZ05IFEP0205ADE005
07QhN01bLW80LW9b09^KV`1oOgl00P2IVIT0102/[:`0Xj>S0:>SX`1UIFD206IVIP05065QH@2;Rh/0
`l?30<?3``2@T9000P1EEED01@1jNWX0De=C07emO@1mOGd0Ti>C0080b<S800D0[jn_07emO@1mOGd0
Kfm_06=SH`0207moO`04079bLP28R8P0R8R8071`L080QhN700D0S8b<0;Fe]@2[Zj/0Zj^[09RHV002
09FEU@0506e]K@3Jf]X0aLG50<G5a@2LW9`00P1jNWX01@2<S8`0YZJV0:JVYP1lO7`0MgMg0080LW9b
00@0Fe]K092@T02@T900PX:20P2VYZH01@1mOGd0/[:b0:f][@2][Jd0QXJ60080I6AT00D0QHF50:f]
[@2^[Zh0[Zj^0<[:bP020410@0050:FUY@3Ti>@0i>CT08B4Q02CTi<00P23Ph<01026QXH0M7Ad07Ad
M02h^;P20=3@d0050:NWY`1OGel0TI6A096AT@2@T9000P2BTY801@23Ph<0Vi^K09^KV`2;Rh/0^;Rh
0080K6a/00D0CDe=04A4A014A4@0=cLg05MGE`0205YJFP04069RHP1WIfL0IfMW07alO080JFUY00D0
KFe]07EeM@1ADE40DE5A069RHP0205MGE`0505]KF`1gMgL0MgMg09ZJVP1ZJVX00P2;Rh/0102ATI40
HF5Q065QH@1NGUh306MWI`04059BDP1PH600H61P06=SH`80KVi^00<0P8200?ooo`3oool04`3ooom4
0000o`@0oh00E`000?l90?n000D0003o3`3oool000T0oooo00@0KFe]0:f][@2][Jd0OGem0P1WIfL0
1@27QhL0WinO09nOW`2WYjL0];Bd0080SXj>00D0O7al061PH01PH600RHV908n?S`0205]KF`0407Mg
M`1VIVH0IVIV07emO@80T92@00D0Kfm_04Q8B01GEeL0EeMG0410@00204M7A`0506EUI@1`L700L71`
0;Bd]028R8P00P2DU9@0102VYZH0V9RH09RHV01LG5`206ATI00507MgM`2KVi/0d=3@0=3@d02MWId0
0P1LG5`01@20P800F5QH08N7Q`27QhL0UIFE0080bl_;00D0]KFe08:2PP22PX80NGUi05mOG`0207al
O00407AdM024Q8@0Q8B406ATI080OWin00D0RXZ:0:ZZZP2HV9P0V9RH08J6QP0208n?S`05075aL@3F
e]H0_kno0;no_`2c/k<00P1UIFD01@37alL0UiNG09NGU`1VIVH0MWIf0080N7Qh00@0Hf=S09:BTP2B
TY80P8200P2SXj<01@26QXH0ZZZZ0:j^[P2^[Zh0Rh^;0080HV9R00D0QhN70:NWY`2_[jl0[jn_0;fm
_@020410@0050::RXP3Rh^80h^;R08n?S`2IVIT00P1mOGd0101oOgl0Ng]k07]kN`2`/;020=3@d005
0:JVYP1TI6@0/;2`0;2`/02BTY800P2TY:@01@2?Shl0Z:RX0:RXZ02@T900Z:RX0080Jf][00D0FEUI
03Xj>P0j>SX0Bd];08:2PP0206EUI@04071`L01kNg/0Ng]k08:2PP80Lg=c00D0Q8B406e]K@1`L700
L71`07=cL`0207IfMP0507MgM`2JVYX0VYZJ0;no_`1nOWh00P2^[Zh01@2a/K40S8b<08b<S01eMGD0
QHF50080OWin00@0M7Ad055AD@1ADE40IVIV0P1bLW800`1jNWX0oooo0?ooo`0C0?oood@0003o103o
P01G0000o`T0oh001@000?l?0?ooo`002@3oool0101]KFd0[Jf]0:f][@1mOGd206MWI`0508N7Q`2O
Wil0WinO0:NWY`2d];@00P2>SXh01@1lO7`0H61P061PH029RHT0Shn?0080Fe]K00@0MgMg06IVIP1V
IVH0OGem0P2@T9001@1_Kfl0B4Q805MGE`1GEeL0@4100080AdM700D0IFEU071`L01`L700];Bd08R8
R00209BDU0040:JVYP2HV9P0V9RH05aLG080I6AT00D0MgMg09^KV`3@d=00d=3@09fMW@0205aLG005
0820P01HF5P0QhN708N7Q`2EUID00P3;bl/01@2e]KD0PX:208:2PP1iNGT0GemO0080O7al00@0M7Ad
08B4Q024Q8@0I6AT0P1nOWh01@2:RXX0ZZZZ09RHV02HV9P0QXJ60080Shn?00D0LG5a0=KFeP2o_kl0
_kno0;>c/`0206EUI@050<O7a`2GUiL0UiNG06IVIP1fMWH00P1hN7P0101SHf<0TY:B09:BTP20P802
0:>SX`0508J6QP2ZZZX0[Zj^0:j^[P2;Rh/00P1RHV801@27QhL0YjNW0:n_[`2_[jl0_Kfm0080@410
00D0XZ:R0>;RhP3Rh^80Shn?09VIV@0207emO@0407moO`1kNg/0Ng]k0;2`/080d=3@00D0YZJV06AT
I02`/;00/;2`09:BTP020:BTY00508n?S`2XZ:P0Z:RX092@T02XZ:P00P1[Jf/01@1IFET0>SXj03Xj
>P1;Bd/0PX:20080IFEU00@0L71`07]kN`1kNg/0PX:20P1cLg<01@24Q8@0KFe]071`L01`L700Lg=c
0080MWIf00D0MgMg09ZJVP2JVYX0_kno07inOP020:j^[P050;6a/@2<S8`0S8b<07EeM@25QHD00P1n
OWh0101dM7@0DE5A055AD@1VIVH2079bLP0307YjNP3oool0oooo01<0oooo90000?l20?n000@0003o
0`3oP00E0000o`H0oh00I@000?l?0?ooo`002@3oool0101jNWX0_[jn0;jn_P26QXH206EUI@0508B4
Q02PX:00X:2P0:JVYP2^[Zh00P2>SXh01@1oOgl0G5aL05aLG023Ph<0Ti>C0080IVIV00@0Hf=S05]K
F`1KFe/0LW9b0P1jNWX01@11@D40A4A407emO@1mOGd0G5aL0080F5QH0`1WIfL01@2[Zj/0QhN7092@
T02@T900];Bd0080Y:BT00D0HV9R06UYJ@1YJFT0LG5a0:RXZ0020<c<c0050:>SX`1ZJVX0JVYZ08f=
S@1LG5`00P21PH40102RXZ80b/[:0<[:bP2b/[8207alO00507QhN01OGel0Ph>308>3P`1bLW800P25
QHD01@1TI6@0N7Qh07QhN02>SXh0/k>c0080Xj>S00D0S8b<0:>SX`2SXj<0MGEe0<C4a0020;Ng]`04
0;Fe]@2;Rh/0Rh^;0;bl_080/k>c00D0R8R808:2PP1iNGT0NGUi059BDP020820P00507emO@2IVIT0
VIVI08J6QP2UYJD00P2][Jd01@22PX80GUiN05iNGP28R8P0VYZJ0080/K6a00@0`L710492@P12@T80
XJ6Q0P3Hf=P01@25QHD0SXj>07IfMP1fMWH0Ogmo0080M7Ad00D0[jn_0=7Ad@3AdM40WinO06UYJ@02
0;Jf]P0408b<S02GUiL0UiNG0820P080Z:RX00D0PX:20:n_[`1aLG40LG5a051@D00203`l?00505aL
G024Q8@0HV9R069RHP2CTi<00P1`L7001@1eMGD0NGUi07UiN@1nOWh0Ph>30080LW9b00@0MWIf06e]
K@1]KFd0OWin0P2IVIT01@2a/K40HF5Q09>CT`2CTi<0ZJVY0080T92@00D0SXj>09JFUP1oOgl0Ogmo
08B4Q00207emO@0406m_K`1jNWX0NWYj08B4Q1D0oooo1`000?l00`3oP000003o0000o`060000o`H0
oh0000<0003o0?n000000?l0:0000?l70?n002X0003o00<0oh000000o`000?l07@000?l40?n000P0
003o00<0oh000000o`000?l030000?l?0?ooo`002@3oool01020P800][Jf0;Jf]P28R8P206][J`05
08b<S02NWYh0WYjN0;:b/P2][Jd00P2<S8`01@23Ph<0IVIV06IVIP26QXH0TY:B0080LG5a00@0JFUY
04Q8B018B4P0Kfm_0P29RHT01@0j>SX0EUIF07emO@1mOGd0IfMW0080KFe]00D0M7Ad071`L01`L700
[jn_09>CT`0208n?S`0409fMW@2KVi/0Vi^K06QXJ080FUYJ00D0Hf=S09RHV033`l<0`l?309FEU@02
05iNGP0507moO`1TI6@0R8R808R8R02b/[800P3Bd]801@2b/[80RXZ:08Z:RP23Ph<0Hf=S0080SXj>
00@0OGem096AT@2ATI40Kfm_0P1PH6001@1nOWh0XJ6Q09NGU`2GUiL0N7Qh0080QHF500D0MgMg0=7A
d@33`l<0`l?30;Rh^00209FEU@0509fMW@2b/[80/[:b08b<S026QXH00P1mOGd0101NGUh0Rh^;08^;
R`1lO7`209>CT`0507QhN02TY:@0/K6a0;6a/@26QXH00P1JFUX01@27QhL0XJ6Q0:n_[`2_[jl0b/[:
0080BTY:00D0YjNW0=_Kf`3Kfm/0MGEe08B4Q0020820P00408F5Q@1cLg<0Lg=c0;6a/@80b/[:00D0
U9BD06][J`2n_[h0_[jn08j>SP0209JFUP0508B4Q02/[:`0[:b/0820P02j^[X00P1^KVh01@1?Cdl0
?3`l03`l?01NGUh0Ph>30080J6QX00@0RXZ:06IVIP1VIVH0L71`0P1YJFT01@1mOGd0NGUi06][J`1[
Jf/0Kfm_0080GUiN00D0Lg=c08:2PP22PX80VYZJ05]KF`0209BDU00509jNWP1iNGT0NGUi06MWI`1l
O7`00P1YJFT0101lO7`0JFUY06UYJ@1SHf<207QhN00308:2PP3oool0oooo01<0oooo203oP0080000
o`@0oh00<0000?l20?n002T0003o00<0oh000000o`000?l0103oP00O0000o`80oh004`000?l30?n0
00l0oooo00090?ooo`040820P02f][H0][Jf08R8R080Jf][00D0S8b<09jNWP2NWYh0/[:b0:f][@02
08b<S00508>3P`1VIVH0IVIV08J6QP2BTY800P1aLG40101YJFT0B4Q804Q8B01_Kfl208V9R@0503Xj
>P1FEUH0OGem07emO@1WIfL00P1]KFd01@1dM7@0L71`071`L02_[jl0Ti>C0080Shn?00@0WIfM09^K
V`2KVi/0J6QX0P1JFUX01@1SHf<0V9RH0<?3``33`l<0UIFE0080GUiN00D0Ogmo06ATI028R8P0R8R8
0;:b/P020=;BdP050;:b/P2:RXX0RXZ:08>3P`1SHf<00P2>SXh0101mOGd0TI6A096AT@1_Kfl2061P
H00507inOP2QXJ40UiNG09NGU`1hN7P00P25QHD01@1gMgL0dM7A0<?3``33`l<0^;Rh0080UIFE00D0
WIfM0;:b/P2b/[80S8b<08J6QP0207emO@0405iNGP2;Rh/0Rh^;07alO080Ti>C00D0N7Qh0:BTY02a
/K40/K6a08J6QP0205YJFP0508N7Q`2QXJ40[jn_0:n_[`3:b/X00P1:BTX01@2WYjL0fm_K0=_Kf`1e
MGD0Q8B40080P82000@0QHF507=cL`1cLg<0/K6a0P3:b/X01@2DU9@0Jf][0;jn_P2n_[h0SXj>0080
UYJF00D0Q8B40:b/[02/[:`0P8200;Zj^P0206i^KP0504m?C`0l?3`0?3`l05iNGP23Ph<00P1XJ6P0
102:RXX0IVIV06IVIP1`L70206UYJ@0507emO@1iNGT0Jf][06][J`1_Kfl00P1NGUh01@1cLg<0PX:2
08:2PP2JVYX0Fe]K0080U9BD00D0WYjN07UiN@1iNGT0IfMW07alO00206UYJ@0407alO01YJFT0JFUY
06=SH`80N7Qh00<0PX:20?ooo`3oool04`3oool80?n000P0003o103oP00`0000o`80oh00:@000?l0
0`3oP000003o0000o`040?n001l0003o0P3oP00C0000o`<0oh003`3oool000T0oooo00@0KVi^0:ZZ
ZP2ZZZX0Q8B40P1SHf<01@21PH40Z:RX0:RXZ030`<00Y:BT0080S8b<00D0RHV906a/K01/K6`0Ph>3
09jNWP0208:2PP04079bLP1DE5@0E5AD07moO`80WIfM00D0H61P05YJFP2;Rh/0Rh^;07alO002071`
L00507emO@1hN7P0N7Qh0;Fe]@2GUiL00P2MWId0102b/[80^k^k0;^k^`1aLG42065QH@0506i^KP2T
Y:@0d];B0=;BdP2TY:@00P1UIFD01@21PH40OGem09FEU@2EUID0];Bd0080gMgM00D0]KFe08n?S`2?
Shl0QhN7065QH@0208j>SP0407EeM@24Q8@0Q8B406a/K080MWIf00D0YZJV0;Bd]02WYjL0YjNW09>C
T`0209NGU`0508:2PP38b<P0^KVi0;Vi^@2f][H00P2EUID01@2GUiL0[Jf]0:f][@23Ph<0O7al0080
N7Qh00@0G5aL09JFUP2FUYH0TY:B0P2HV9P01@1_Kfl0XJ6Q0:f][@2][Jd0N7Qh0080GEeM00D0QXJ6
08j>SP2c/k<0/k>c0<S8b00204];B`050:NWY`3Shn<0hn?S07=cL`2FUYH00P25QHD0102?Shl0Ph>3
08>3P`2h^;P20=WIf@0509ZJVP1YJFT0][Jf0;Jf]P2GUiL00P2<S8`01@21PH40YjNW0:NWY`1VIVH0
^k^k0080JFUY00D0?Shn02`/;00/;2`0DE5A07]kN`0205QHF004096AT@1^KVh0KVi^06i^KP80J6QX
00D0I6AT075aL@1[Jf/0Jf][055AD@0205MGE`0506QXJ02;Rh/0Rh^;0:^[Z`1XJ6P00P2?Shl01@27
QhL0JVYZ06YZJP1MGEd0I6AT0080KFe]00@0JFUY06IVIP1VIVH0GEeM0P2:RXX00`2;Rh/0oooo0?oo
o`0C0?ooo`030000o`3oP000oh0000P0003o00<0oh000000o`000?l00P000?l40?n009T0003o3`3o
ool000T0oooo00@0KVi^08>3P`23Ph<0KVi^0P1MGEd01@20P800VIVI09VIV@2VYZH0QXJ60080OGem
00D0NWYj06YZJP1ZJVX0SXj>09RHV00207QhN00404Q8B01=CDd0CDe=06a/K080PH6100D0JFUY05EE
E@2>SXh0SXj>06UYJ@0206MWI`0507IfMP1aLG40LG5a0;Rh^02@T9000P2MWId0102a/K40/[:b0;:b
/P1WIfL205mOG`05075aL@2TY:@0b<S80<S8b02[Zj/00P1OGel01@22PX80Kfm_08R8R028R8P0_;bl
0080g=cL00D0/K6a0861P@21PH40PH6105eMG@0208b<S00408:2PP24Q8@0Q8B406EUI@80GemO00D0
S8b<0::RXP2KVi/0Vi^K08B4Q00208n?S`0507moO`36a/H0][Jf0;Jf]P2j^[X00P2IVIT01@2VYZH0
VYZJ09ZJVP24Q8@0LG5a0080LW9b00<0EEEE09VIV@2IVIT00`2HV9P01@1nOWh0Y:BT0:ZZZP2ZZZX0
LG5a0080Fe]K00D0QXJ609jNWP2^[Zh0[Zj^0<C4a00204U9B@050:f][@3Ogml0gmoO06ATI02DU9@0
0P1hN7P0101eMGD0Ogmo07moO`2^[Zh20<?3``0508F5Q@1VIVH0[:b/0:b/[02EUID00P27QhL01@24
Q8@0SXj>08j>SP1KFe/0`L710080KVi^00D0A4A402d];@0];Bd0De=C07UiN@0205=CD`0308Z:RP1a
LG40LG5a00<0JFUY0P1dM7@206e]K@0406EUI@1`L700L71`08b<S080W9bL00D0XZ:R07UiN@2EUID0
UIFE096AT@0207QhN005065QH@1`L700JVYZ06YZJP1EEED00P1aLG40101ADE40LW9b079bLP2<S8`E
0?ooobX0003o00D0oh000000o`000?l0003o0?n0000A0000o`80oh00=@000?l50?n00340003o3`3o
ool000T0oooo00@0PX:20;2`/02`/;00Q8B40P1nOWh01@2JVYX0/[:b0;:b/P2UYJD0RXZ:0080MgMg
00D0RHV907=cL`1cLg<0G5aL07]kN`0207inOP0406i^KP25QHD0QHF508>3P`80QhN700D0F5QH04U9
B@2:RXX0RXZ:06MWI`0205UIF@0507MgM`1WIfL0IfMW0:>SX`20P8000P2EUID0102^[Zh0X:2P0:2P
X01NGUh205UIF@0507EeM@2IVIT0f=SH0=SHf02f][H00P1KFe/01@25QHD0Rh^;08R8R028R8P0`<30
0080emOG00D0][Jf08J6QP26QXH0RHV905eMG@0208Z:RP040861P@1mOGd0OGem07IfMP80Hf=S00D0
XZ:R0:2PX02`/;00/;2`09NGU`0209BDU00508j>SP3=cLd0`<300<30`032`/800P2TY:@01@2`/;00
X:2P0:2PX02:RXX0LW9b0080MWIf00@0D51@09fMW@2MWId0T92@0P2UYJD01@24Q8@0X:2P0:JVYP2V
YZH0KVi^0080HV9R00D0Ng]k09RHV02][Jd0[Jf]0=OGe`0204Q8B00509RHV03Rh^80h^;R07alO02P
X:000`28R8P20861P@050;:b/P3EeMD0eMGE0:BTY01XJ6P00P2NWYh01026QXH0T92@092@T02=SHd2
08b<S00505=CD`2a/K40PH610861P@1NGUh00P0n?Sh01@1DE5@0RHV905aLG01LG5`0Shn?0080MGEe
00@0HF5Q05UIF@1IFET0KFe]0`1nOWh0101DE5@0I6AT06ATI026QXH2096AT@050:>SX`23Ph<0Ti>C
09>CT`2<S8`00P1gMgL01@1_Kfl0RHV906][J`1[Jf/0F5QH0080G5aL00@0DE5A06m_K`1_Kfl0KVi^
5@3ooole0000o`D0oh001P000?l20?n001l0003o0`3oP00?0000o`030?n000000?l0003o0300003o
0P3oP0050000o`l0oooo00090?ooo`0408:2PP2`/;00/;2`08B4Q080OWin00D0VYZJ0;:b/P2b/[80
YJFU08Z:RP0207MgM`0508V9R@1cLg<0Lg=c05aLG01kNg/00P1nOWh0101^KVh0QHF508F5Q@23Ph<2
08N7Q`0505QHF019BDT0RXZ:08Z:RP1WIfL00P1IFET01@1gMgL0IfMW06MWI`2SXj<0P8200080UIFE
00@0[Zj^0:2PX02PX:00GUiN0P1IFET01@1eMGD0VIVI0=SHf03Hf=P0][Jf0080Fe]K00D0QHF508^;
R`28R8P0R8R80<30`0020=OGe`050;Jf]P26QXH0QXJ608V9R@1MGEd00P2:RXX01021PH40OGem07em
O@1fMWH206=SH`050::RXP2PX:00/;2`0;2`/02GUiL00P2DU9@01@2>SXh0cLg=0<30`030`<00`/;2
0080Y:BT00D0/;2`0:2PX02PX:00RXZ:079bLP0207IfMP04051@D02MWId0WIfM092@T080YJFU00D0
Q8B40:2PX02VYZH0YZJV06i^KP02069RHP0507]kN`2HV9P0[Jf]0:f][@3GemL00P18B4P01@2HV9P0
h^;R0>;RhP1lO7`0X:2P00<0R8R80P21PH401@2b/[80eMGE0=GEe@2TY:@0J6QX0080WYjN00@0QXJ6
092@T02@T900SHf=0P2<S8`01@1CDe<0/K6a0861P@21PH40GUiN0080?Shn00D0E5AD08V9R@1LG5`0
G5aL08n?S`0207EeM@04065QH@1IFET0FEUI06e]K@<0OWin00@0E5AD06ATI01TI6@0QXJ60P2ATI40
1@2SXj<0Ph>309>CT`2CTi<0S8b<0080MgMg00D0Kfm_08V9R@1[Jf/0Jf][05QHF00205aLG004055A
D@1_Kfl0Kfm_06i^KQD0oooo=@000?l50?n000H0003o0P3oP00O0000o`<0oh003`000?l00`3oP000
003o0000o`0`0000o`80oh001@000?l?0?ooo`002@3oool01026QXH0/k>c0;>c/`29RHT209:BTP05
09^KV`2[Zj/0Zj^[0:VYZ@2FUYH00P2=SHd0102<S8`0O7al07alO01kNg/308N7Q`0406=SH`1NGUh0
GUiN07AdM080WinO00D0IFEU04m?C`23Ph<0Ph>306MWI`02055AD@<0Kfm_00D0YJFU09BDU02RXZ80
XZ:R0:RXZ00209^KV`05065QH@1=CDd0CDe=075aL@2NWYh00P3:b/X01@2EUID0EEEE05EEE@20P800
QhN70080Rh^;00@0^[Zj0=CDe03De=@0YZJV0P22PX801@2>SXh0Hf=S0861P@21PH40RHV90080QXJ6
00D0RXZ:06i^KP1^KVh0a<C40:BTY0020;Bd]00509jNWP2FUYH0UYJF08N7Q`31`L400P35aLD0102i
^KT0Vi^K09^KV`2a/K420:JVYP0508f=S@25QHD0P8200820P01HF5P00P2PX:001@2@T900WIfM09fM
W@24Q8@0WinO0080YJFU00D0LW9b06=SH`1SHf<0PX:209fMW@0209RHV0040=3@d016ATH0ATI608V9
R@80f][J00D0Shn?09NGU`24Q8@0Q8B407IfMP0207]kN`050:NWY`3AdM40dM7A0:>SX`2IVIT00P2X
Z:P0102RXZ80WIfM09fMW@2RXZ8209fMW@0505EEE@2?Shl0Shn?08n?S`1EEED00P0h>3P01@1@D500
N7Qh051@D01@D500QHF50080Kfm_00D0K6a/059BDP1BDU80I6AT07inOP0207AdM00406UYJ@1CDe<0
De=C07alO080MgMg00D0WIfM0820P02OWil0WinO09>CT`0206i^KP0507AdM02MWId0Lg=c07=cL`1Q
HF400P1KFe/0101FEUH0J6QX06QXJ01_KflE0?ooocD0003o1@3oP0040000o`P0oh00B`000?l50?n0
01L0003o3`3oool000T0oooo00@0OGem0:VYZ@2YZJT0PX:20P2MWId01@2DU9@0YZJV0:JVYP2[Zj/0
Ti>C0080QHF500@0N7Qh07alO01lO7`0MgMg0`23Ph<307]kN`0507MgM`2CTi<0Ti>C061PH01=CDd0
0P26QXH0101KFe/0FEUI05UIF@1WIfL206e]K@050:^[Z`2GUiL0Y:BT0:BTY02ZZZX00P2NWYh01@1U
IFD0G5aL05aLG01oOgl0YZJV0080d];B00D0Xj>S061PH01PH600SHf=09JFUP0207emO@040:JVYP3:
b/X0b/[:08R8R080K6a/00D0QXJ606EUI@22PX80PX:20820P00206m_K`0507MgM`1NGUh0GUiN0<30
`02RXZ800P2UYJD01@2DU9@0TI6A096AT@1kNg/0bLW90080a<C400@0_;bl0:RXZ02XZ:P0_[jn0P2X
Z:P01@2;Rh/0OWin07inOP1nOWh0GEeM0080UYJF00D0Rh^;0:VYZ@2YZJT0Rh^;0:>SX`020;Ng]`05
07emO@1/K6`0K6a/08f=S@2e]KD00P2_[jl0103EeMD0ATI604I6AP2OWil20=CDe0050:b/[02IVIT0
RHV908V9R@1`L7000P27QhL01@2TY:@0c<c<0<c<c02<S8`0QXJ60080XJ6Q00@0YZJV08N7Q`27QhL0
W9bL0P2NWYh01@1RHV80ZZZZ08b<S02<S8`0EeMG0080>CTi00D0GEeM07inOP1DE5@0E5AD0861P@02
06IVIP05061PH01DE5@0E5AD06IVIP24Q8@00P1_Kfl0101NGUh0De=C05=CD`1lO7`20861P@050;Rh
^020P800YJFU0:FUY@2ATI400P1fMWH01@2:RXX0X:2P07IfMP1fMWH0IFEU0080JVYZ00@0IVIV07Ad
M01dM7@0Q8B45@3ooolK0000o`030?n000000?l0003o01T0003o3`3oP0110000o`80oh0000<0003o
0?n000000?l08@000?l?0?ooo`002@3oool0101mOGd0ZJVY0:VYZ@22PX8209fMW@0509BDU02VYZH0
YZJV0:^[Z`2CTi<00P25QHD0101hN7P0O7al07alO01gMgL308>3P`<0Ng]k00D0MgMg09>CT`2CTi<0
H61P04e=C@0208J6QP0405]KF`1IFET0FEUI06MWI`80KFe]00D0Zj^[09NGU`2TY:@0Y:BT0:ZZZP02
09jNWP0506EUI@1LG5`0G5aL07moO`2VYZH00P3Bd]801@2SXj<0H61P061PH02=SHd0UYJF0080OGem
00@0YZJV0<[:bP3:b/X0R8R80P1/K6`01@26QXH0IFEU08:2PP22PX80P8200080Kfm_00D0MgMg05iN
GP1NGUh0`<300::RXP020:FUY@0509BDU02ATI40TI6A07]kN`39bLT00P34a<@0102l_;`0Z:RX0:RX
Z02n_[h20:RXZ00508^;R`1nOWh0OWin07inOP1MGEd00P2FUYH01@2;Rh/0ZJVY0:VYZ@2;Rh/0Xj>S
0080]kNg00D0OGem06a/K01/K6`0SHf=0;Fe]@020:n_[`040=GEe@16ATH0ATI609nOW`80e=CD00D0
[:b/09VIV@29RHT0RHV9071`L00208N7Q`050:BTY03<c<`0c<c<08b<S026QXH00P2QXJ40102VYZH0
QhN708N7Q`2LW9`209jNWP05069RHP2ZZZX0S8b<08b<S01GEeL00P0i>CT01@1MGEd0OWin05ADE01D
E5@0PH610080IVIV00D0H61P05ADE01DE5@0IVIV08B4Q00206m_K`0405iNGP1CDe<0De=C07alO080
PH6100D0^;Rh0820P02UYJD0YJFU096AT@0207IfMP0508Z:RP2PX:00MWIf07IfMP1UIFD00P1ZJVX0
101VIVH0M7Ad07AdM024Q8@E0?oood40003o00<0oh000000o`000?l0J@000?l?0?ooo`002@3oool0
1027QhL0[:b/0:b/[023Ph<208^;R`050861P@2XZ:P0Z:RX0::RXP2IVIT00P2<S8`01@22PX80MgMg
07MgM`1[Jf/0QHF50080T92@00@0R8R80861P@21PH40Q8B40P2FUYH01@1_Kfl0EEEE07UiN@1iNGT0
LG5a0080HF5Q00D0O7al06e]K@1]KFd0[Jf]09bLW0020:6QX@040;2`/02SXj<0Xj>S06IVIP80JFUY
00D0RHV90:n_[`3Fe]H0e]KF09jNWP0205eMG@0508>3P`27QhL0Q8B408B4Q02ZZZX00P3GemL01@2c
/k<0QhN708N7Q`2MWId0FUYJ0080Q8B400@0Ng]k07emO@1mOGd0QHF50P1`L7001@32`/80/;2`0;6a
/@2a/K40V9RH0080X:2P00D0R8R80<[:bP33`l<0`l?30:>SX`0209VIV@050;jn_P2NWYh0WYjN08j>
SP20P8000P1nOWh0101WIfL0TY:B09:BTP2FUYH20:6QX@0508V9R@2XZ:P0ZZZZ0:ZZZP1_Kfl00P1W
IfL01@1nOWh0YJFU0;Bd]02d];@0c/k>0080A4A400D0Y:BT0>?Sh`3Shn<0[jn_09:BTP0208b<S004
08J6QP2RXZ80XZ:R0;bl_080dm?C00D0UiNG0861P@2][Jd0[Jf]0:b/[00207moO`0509ZJVP2OWil0
WinO069RHP2ZZZX00P2DU9@01@18B4P0<30`030`<01PH600RXZ:0080GemO00@0N7Qh06IVIP1VIVH0
FEUI0P1ADE401@1ZJVX0QXJ608B4Q024Q8@0Rh^;0080EUIF00D0P82009FEU@2EUID0[Jf]07EeM@02
09ZJVP0507UiN@1lO7`0O7al08b<S02l_;`00P2@T900101LG5`0CTi>04i>CP1PH602075aL@0307em
O@3oool0oooo01<0oooo@@000?l00`3oP000003o0000o`1Y0000o`l0oooo00090?ooo`0407YjNP2U
YJD0YJFU08F5Q@80QXJ600D0RXZ:0:n_[`2_[jl0[Zj^09FEU@0308f=S@80LW9b00D0Hf=S07YjNP24
Q8@0Q8B407=cL`0207inOP0508N7Q`2YZJT0ZJVY07MgM`1BDU800P29RHT0101iNGT0JVYZ06YZJP26
QXH207moO`050;Rh^02IVIT0RXZ:08Z:RP2ZZZX00P2PX:001@1VIVH0I6AT06ATI01XJ6P0XZ:R0080
d=3@00D0VIVI05iNGP1NGUh0RHV908f=S@0208V9R@040;6a/@3Cdm<0dm?C0:NWY`80MgMg00D0MGEe
04M7A`1cLg<0Lg=c07YjNP0207QhN00506ATI01HF5P0F5QH07emO@2PX:000P2KVi/01@2JVYX0WYjN
09jNWP28R8P0a/K60080_;bl00@0/;2`08V9R@29RHT0_[jn0P2HV9P01@28R8P0Rh^;07UiN@1iNGT0
MgMg0080T92@00D0WYjN0:6QX@2QXJ40S8b<0:j^[P020;2`/005071`L01XJ6P0J6QX07AdM02GUiL0
0P2a/K40103;bl/0@d=304=3@`2IVIT20>?Sh`050;Fe]@2EUID0RHV908V9R@2;Rh/00P2XZ:P01@2n
_[h0eMGE0=GEe@2LW9`0Ph>30080/[:b00@0[Jf]08N7Q`27QhL0XZ:R0P2NWYh01@1KFe/0Zj^[09BD
U02DU9@0H61P0080>3Ph00D0LW9b0:6QX@27QhL0QhN708B4Q002079bLP05071`L01>CTh0CTi>06AT
I01cLg<00P1`L7001021PH40Bd];04];B`1bLW8208>3P`050:f][@2=SHd0[Jf]0:f][@2?Shl00P1o
Ogl01@2DU9@0[Jf]09FEU@2EUID0GUiN0080IVIV00@0Fe]K06UYJ@1YJFT0MWIf5@3oool^0000o`05
0?n000000?l0003o0?n000000?l00`3oP01L0000o`030?n000000?l0003o01P0003o3`3oool000T0
oooo00@0RXZ:0:JVYP2VYZH0Rh^;0P22PX801@2MWId0[:b/0:b/[02_[jl0WYjN0080PX:200D0RXZ:
07=cL`1cLg<0HF5Q07emO@0208^;R`04071`L025QHD0QHF507YjNP80Vi^K00D0Ng]k05IFEP1oOgl0
Ogmo065QH@02061PH00507]kN`1]KFd0KFe]0;Bd]02DU9@00P25QHD0102a/K40Z:RX0:RXZ01/K6`2
06QXJ005065QH@2JVYX0emOG0=OGe`2WYjL00P1YJFT208B4Q080Shn?00@0][Jf0=GEe@3EeMD0[jn_
0P1mOGd01@24Q8@0GemO09:BTP2BTY80NGUi0080UIFE00D0IFEU07UiN@1iNGT0/K6a0;Ng]`020;:b
/P0509FEU@2NWYh0WYjN08N7Q`3@d=000P34a<@0102[Zj/0R8R808R8R02e]KD208^;R`0507alO021
PH40MGEe07EeM@1nOWh00P2;Rh/01@2SXj<0XJ6Q0:6QX@22PX80_;bl0080Y:BT00D0P82006YZJP1Z
JVX0IfMW09fMW@020;Ng]`040<[:bP1;Bd/0Bd];09jNWP80i>CT00D0/K6a08J6QP1`L700L71`0820
P0020:NWY`050;:b/P3>c/h0c/k>09fMW@1nOWh00P2`/;000`2VYZH0Ogmo07moO`0309BDU00506m_
K`32`/80TI6A096AT@1?Cdl00P0/;2`01@1cLg<0W9bL07]kN`1kNg/0LW9b0080MGEe00D0N7Qh06QX
J01XJ6P0Kfm_079bLP0207MgM`0408Z:RP1>CTh0CTi>07]kN`80WinO00D0Y:BT09jNWP2i^KT0^KVi
08b<S00209:BTP050:JVYP2d];@0V9RH09RHV01IFET00P1OGel0101MGEd0GemO05mOG`20P80E0?oo
ocD0003o00<0oh000000o`000?l0M@000?l?0?ooo`002@3oool0102:RXX0YZJV0:JVYP2;Rh/208:2
PP0509fMW@2/[:`0[:b/0:n_[`2NWYh00P22PX801@2:RXX0Lg=c07=cL`1QHF40OGem0080Rh^;00@0
L71`08F5Q@25QHD0NWYj0P2KVi/01@1kNg/0EUIF07moO`1oOgl0HF5Q0080H61P00D0Ng]k06e]K@1]
KFd0];Bd09BDU00208F5Q@040;6a/@2XZ:P0Z:RX06a/K080J6QX00D0HF5Q09ZJVP3GemL0emOG0:NW
Y`0206UYJ@80Q8B40P2?Shl0102f][H0eMGE0=GEe@2_[jl207emO@0508B4Q01OGel0TY:B09:BTP1i
NGT00P2EUID01@1UIFD0NGUi07UiN@2a/K40]kNg0080/[:b00D0UIFE09jNWP2NWYh0QhN70=3@d002
0<C4a0040:^[Z`28R8P0R8R80;Fe]@80Rh^;00D0O7al0861P@1eMGD0MGEe07inOP0208^;R`050:>S
X`2QXJ40XJ6Q08:2PP2l_;`00P2TY:@01@20P800JVYZ06YZJP1WIfL0WIfM0080]kNg00@0b/[:04];
B`1;Bd/0WYjN0P3Ti>@01@2a/K40QXJ6071`L01`L700P8200080YjNW00D0/[:b0<k>cP3>c/h0WIfM
07inOP020;2`/0030:JVYP1oOgl0Ogmo00<0U9BD00D0Kfm_0<;2`P2ATI40TI6A04m?C`0202`/;005
07=cL`2LW9`0Ng]k07]kN`1bLW800P1eMGD01@1hN7P0J6QX06QXJ01_Kfl0LW9b0080MgMg00@0RXZ:
04i>CP1>CTh0Ng]k0P2OWil01@2TY:@0WYjN0;Vi^@2i^KT0S8b<0080TY:B00D0YZJV0;Bd]02HV9P0
V9RH05UIF@0205mOG`0405eMG@1OGel0GemO0820P1D0oooo1`3oP02O0000o`80oh001@000?l?0?oo
o`002@3oool01023Ph<0Ti>C09>CT`1iNGT207IfMP0509ZJVP2VYZH0YZJV0;>c/`2OWil00P22PX80
1@2CTi<0PX:208:2PP1/K6`0O7al0080RHV900@0Lg=c08b<S02<S8`0L71`0P2IVIT01@1`L700E5AD
07YjNP1jNWX0F5QH0080CDe=00D0Lg=c07QhN01hN7P0YZJV08J6QP0207IfMP040:6QX@2JVYX0VYZJ
06i^KP80JFUY00D0IFEU09nOW`3MgMd0gMgM0;>c/`02075aL@0508V9R@25QHD0X:2P0:2PX031`L40
0P3GemL01@2k^k/0Shn?08n?S`26QXH0Hf=S0080TY:B00@0QHF508^;R`2;Rh/0IfMW0P1lO7`01@2l
_;`0];Bd0;Bd]02d];@0UiNG0080WIfM00D0Shn?0=GEe@36a/H0a/K60:RXZ00208n?S`050<S8b02H
V9P0V9RH08f=S@2ATI400P1cLg<01022PX80S8b<08b<S02VYZH209VIV@050820P034a<@0/K6a0;6a
/@2BTY800P1UIFD01@1/K6`0WYjN0:^[Z`2[Zj/0dm?C0080ATI600D0UiNG0>3Ph03Ph>00YjNW07Mg
M`0206EUI@0407MgM`2VYZH0YZJV0;2`/080dM7A00D0Ti>C06UYJ@2YZJT0ZJVY09VIV@0208b<S005
08V9R@2EUID0UIFE08b<S033`l<00P25QHD01@0o?cl0:BTY02TY:@1iNGT0RHV90080Lg=c00@0JVYZ
06QXJ01XJ6P0F5QH0P1QHF401@1cLg<0QHF508N7Q`27QhL0U9BD0080FEUI00D0Lg=c09jNWP2NWYh0
WinO08Z:RP020;2`/00508Z:RP2EUID0UIFE0:JVYP2a/K400P2CTi<0101RHV80LW9b079bLP1QHF42
061PH003071`L03oool0oooo01<0oooo1`3oP02O0000o`80oh001@000?l?0?ooo`002@3oool0101h
N7P0TI6A096AT@23Ph<206m_K`050:BTY02SXj<0Xj>S0::RXP2JVYX00P2<S8`01@2LW9`0Ng]k07]k
N`1oOgl0OWin0080SHf=00@0N7Qh07IfMP1fMWH0FEUI0P2BTY801@1XJ6P0EEEE06m_K`1_Kfl0CDe=
0080EeMG00D0OWin07QhN01hN7P0[Jf]092@T00207UiN@040:^[Z`2PX:00X:2P06QXJ080IVIV00D0
GemO09NGU`3?cll0clo?0:FUY@02061PH0050861P@1TI6@0UiNG09NGU`2UYJD00P3;bl/01@2ZZZX0
P8200820P022PX80HF5Q0080SHf=00@0P82008N7Q`27QhL0GUiN0P1^KVh01@2IVIT0WinO09nOW`2O
Wil0T92@0080UIFE00D0MGEe0=WIf@3Bd]80d];B0::RXP0208B4Q0050<?3``2PX:00X:2P08F5Q@20
P8000P1YJFT01020P800M7Ad07AdM02DU9@208N7Q`050820P03AdM40Xj>S0:>SX`2MWId00P1_Kfl0
1@1XJ6P0YjNW0::RXP2RXZ80bl_;0080Bd];00D0TI6A0=cLg03Lg=`0SHf=07UiN@0206UYJ@0407]k
N`2e]KD0]KFe0;Zj^P80clo?00D0UiNG05eMG@2_[jl0[jn_08n?S`0209>CT`0506IVIP21PH40PH61
0:BTY02o_kl00P1hN7P01@0h>3P0<C4a034a<@24Q8@0T92@0080DE5A00@0Lg=c07MgM`1gMgL0H61P
0P1aLG401@1JFUX0O7al07QhN01hN7P0QHF50080EUIF00D0NWYj0:FUY@2UYJD0UiNG08>3P`020:f]
[@0507alO02=SHd0SHf=0;Fe]@2`/;000P2:RXX0101NGUh0MGEe07EeM@1ZJVX2065QH@0306MWI`3o
ool0oooo01<0oooo0`3oP00n0000o`<0oh00H@000?l40?n000@0003o3`3oool000T0oooo00@0N7Qh
096AT@2ATI40Ph>30P1_Kfl01@2TY:@0Xj>S0:>SX`2RXZ80VYZJ0080S8b<00D0W9bL07]kN`1kNg/0
Ogmo07inOP0208f=S@0407QhN01fMWH0MWIf05UIF@80TY:B00D0J6QX05EEE@1_Kfl0Kfm_04e=C@02
05MGE`0507inOP1hN7P0N7Qh0:f][@2@T9000P1iNGT0102[Zj/0X:2P0:2PX01XJ6P206IVIP0505mO
G`2GUiL0clo?0<o?c`2UYJD00P1PH6001@21PH40I6AT09NGU`2GUiL0YJFU0080bl_;00D0ZZZZ0820
P020P800PX:2065QH@0208f=S@040820P027QhL0QhN705iNGP80KVi^00D0VIVI09nOW`2OWil0WinO
092@T00209FEU@0507EeM@3IfMT0d];B0=;BdP2RXZ800P24Q8@01@33`l<0X:2P0:2PX025QHD0P820
0080JFUY00@0P82007AdM01dM7@0U9BD0P27QhL01@20P800dM7A0:>SX`2SXj<0WIfM0080Kfm_00D0
J6QX0:NWY`2RXZ80XZ:R0<_;b`0204];B`05096AT@3Lg=`0g=cL08f=S@1iNGT00P1YJFT0101kNg/0
]KFe0;Fe]@2j^[X20<o?c`0509NGU`1MGEd0[jn_0:n_[`2?Shl00P2CTi<01@1VIVH0PH610861P@2T
Y:@0_kno0080N7Qh00D0>3Ph034a<@0a<C40Q8B4092@T002055AD@0407=cL`1gMgL0MgMg061PH080
LG5a00D0FUYJ07alO01hN7P0N7Qh08F5Q@0205IFEP0507YjNP2UYJD0YJFU09NGU`23Ph<00P2][Jd0
1@1lO7`0SHf=08f=S@2e]KD0/;2`0080RXZ:00@0GUiN07EeM@1eMGD0JVYZ0P1QHF400`1WIfL0oooo
0?ooo`0C0?ooojd0003o3`3oool000T0oooo00@0IVIV0820P020P800O7al0P2CTi<01@1aLG40UiNG
09NGU`2PX:00Rh^;0080SHf=00D0Ti>C07=cL`1cLg<0QHF50861P@020820P00408B4Q02NWYh0WYjN
06UYJ@80WIfM00D0JFUY06=SH`1nOWh0OWin05ADE002065QH@050861P@1iNGT0NGUi0:>SX`26QXH0
0P1eMGD0102TY:@0UiNG09NGU`1mOGd206m_K`0505mOG`2XZ:P0f=SH0=SHf02][Jd00P1NGUh01@22
PX80FUYJ0;2`/02`/;00YjNW0080eMGE00D0^[Zj08>3P`23Ph<0PX:206][J`0209FEU@0407emO@2:
RXX0RXZ:06QXJ080L71`00D0WinO09jNWP2IVIT0VIVI08R8R00209:BTP0506ATI038b<P0/[:b0;:b
/P2=SHd00P1oOgl01@34a<@0[Zj^0:j^[P20P800RHV90080KVi^00@0RHV907moO`1oOgl0UIFE0P1e
MGD01@1kNg/0e=CD09bLW02LW9`0XZ:R0080Lg=c00D0Hf=S0;:b/P2][Jd0[Jf]0;no_`0204A4A005
09ZJVP3Ng]h0g]kN0;:b/P1_Kfl00P1ZJVX0101mOGd0^KVi0;Vi^@37alL20=3@d0040;Zj^P1QHF40
[:b/0:b/[0<0R8R800D0HF5Q08R8R028R8P0]kNg09:BTP0207emO@0504A4A00d=3@0=3@d07EeM@1l
O7`00P0l?3`307alO00507YjNP1dM7@0M7Ad069RHP24Q8@00P23Ph<0102CTi<0FEUI05UIF@1`L702
0:2PX00509VIV@25QHD0alO70<O7a`2:RXX00P2ATI401@2WYjL0ZZZZ07]kN`1kNg/0IVIV0080O7al
00@0L71`06IVIP1VIVH0M7Ad5@3ooon]0000o`l0oooo00090?ooo`0408B4Q02CTi<0Ti>C08b<S080
]kNg00D0SHf=0:FUY@2UYJD0^;Rh096AT@0208V9R@0509:BTP1YJFT0JFUY08>3P`22PX800P1VIVH0
1024Q8@0SHf=08f=S@1UIFD20:>SX`05071`L01_Kfl0QHF508F5Q@1/K6`00P1YJFT01@1kNg/0K6a/
06a/K02RXZ80Ti>C0080MWIf00@0Z:RX08j>SP2>SXh0N7Qh0P1eMGD01@1EEED0Vi^K0=CDe03De=@0
Vi^K0080L71`00D0NWYj04a<C02ZZZX0ZZZZ0:JVYP020=CDe0050<C4a020P800P82007emO@1_Kfl0
0P2EUID0101lO7`0UiNG09NGU`1=CDd206IVIP0509FEU@2KVi/0V9RH09RHV02@T9000P2?Shl01@1[
Jf/0f][J0;fm_@2m_Kd0Vi^K0080NWYj00D0`<3009bLW02LW9`0MWIf09:BTP0207EeM@04096AT@20
P800P82009VIV@80M7Ad00D0KVi^0=CDe02GUiL0UiNG092@T00206a/K00505QHF02f][H0YjNW0:NW
Y`3<c<`00P16ATH01@2LW9`0gmoO0=oOg`2o_kl0P8200080Jf][00@0MGEe0;>c/`2c/k<0cLg=0P3@
d=001@2g]kL0Kfm_09^KV`2KVi/0Rh^;0080HV9R00D0MGEe07alO01lO7`0[jn_07IfMP0208b<S005
05]KF`0j>SX0>SXj08F5Q@1lO7`00P1RHV80101WIfL0LW9b079bLP1eMGD20820P005069RHP25QHD0
MGEe07EeM@2?Shl00P1NGUh01@2;Rh/0[:b/0:b/[02@T900MgMg0080aLG500D0QHF509NGU`2GUiL0
[jn_0:VYZ@0208:2PP0405aLG01/K6`0K6a/05IFEP80CTi>00<0K6a/0?ooo`3oool04`3ooon]0000
o`l0oooo00090?ooo`0408B4Q02CTi<0Ti>C08b<S080]kNg00D0SHf=0:FUY@2UYJD0^;Rh096AT@02
08V9R@0509:BTP1YJFT0JFUY08>3P`22PX800P1VIVH01024Q8@0SHf=08f=S@1UIFD20:>SX`05071`
L01_Kfl0QHF508F5Q@1/K6`00P1YJFT01@1kNg/0K6a/06a/K02RXZ80Ti>C0080MWIf00@0Z:RX08j>
SP2>SXh0N7Qh0P1eMGD01@1EEED0Vi^K0=CDe03De=@0Vi^K0080L71`00D0NWYj04a<C02ZZZX0ZZZZ
0:JVYP020=CDe0050<C4a020P800P82007emO@1_Kfl00P2EUID0101lO7`0UiNG09NGU`1=CDd206IV
IP0509FEU@2KVi/0V9RH09RHV02@T9000P2?Shl01@1[Jf/0f][J0;fm_@2m_Kd0Vi^K0080NWYj00D0
`<3009bLW02LW9`0MWIf09:BTP0207EeM@04096AT@20P800P82009VIV@80M7Ad00D0KVi^0=CDe02G
UiL0UiNG092@T00206a/K00505QHF02f][H0YjNW0:NWY`3<c<`00P16ATH01@2LW9`0gmoO0=oOg`2o
_kl0P8200080Jf][00@0MGEe0;>c/`2c/k<0cLg=0P3@d=001@2g]kL0Kfm_09^KV`2KVi/0Rh^;0080
HV9R00D0MGEe07alO01lO7`0[jn_07IfMP0208b<S00505]KF`0j>SX0>SXj08F5Q@1lO7`00P1RHV80
101WIfL0LW9b079bLP1eMGD20820P005069RHP25QHD0MGEe07EeM@2?Shl00P1NGUh01@2;Rh/0[:b/
0:b/[02@T900MgMg0080aLG500D0QHF509NGU`2GUiL0[jn_0:VYZ@0208:2PP0405aLG01/K6`0K6a/
05IFEP80CTi>00<0K6a/0?ooo`3oool04`3ooon]0000o`l0oooo00090?ooo`0407emO@2?Shl0Shn?
0820P080/;2`00D0PX:20:VYZ@2YZJT0^[Zj096AT@0208>3P`0509FEU@1bLW80LW9b08F5Q@22PX80
0P1EEED0102;Rh/0XZ:R0::RXP1RHV820:6QX@0506m_K`1cLg<0PH610861P@1ZJVX00P1KFe/01@1j
NWX0Ng]k07]kN`2l_;`0Rh^;0080MgMg00@0YJFU09^KV`2KVi/0NGUi0P1_Kfl01@1@D500RXZ:0<W9
b@39bLT0Xj>S0080L71`00D0Ng]k04Q8B02i^KT0^KVi0:^[Z`020=[JfP050=?Cd`2<S8`0S8b<08^;
R`1mOGd00P2ATI40101oOgl0WIfM09fMW@1WIfL207MgM`050:j^[P2d];@0WIfM09fMW@2NWYh00P2C
Ti<01@1eMGD0h>3P0<C4a034a<@0X:2P0080OGem00D0^k^k09BDU02DU9@0KVi^09ZJVP0207]kN`04
0:>SX`2<S8`0S8b<0:FUY@80Ng]k00D0Jf][0=;BdP2NWYh0WYjN09NGU`0207IfMP0505QHF02h^;P0
ZJVY0:VYZ@30`<000P0i>CT01@2KVi/0h^;R0>;RhP2h^;P0LG5a0080Jf][00@0MGEe0:b/[02/[:`0
alO70P2k^k/01@2[Zj/0NGUi08j>SP2>SXh0VYZJ0080HF5Q00D0RXZ:08>3P`23Ph<0UYJF09BDU002
06EUI@0506a/K00o?cl0?clo08b<S01`L7000P2>SXh0101bLW80Jf][06][J`1dM7@208b<S00505eM
G@1jNWX0LW9b079bLP2HV9P00P1`L7001@27QhL0Z:RX0:RXZ02<S8`0NGUi0080c<c<00D0TY:B0:6Q
X@2QXJ40/[:b09jNWP0208V9R@0406MWI`1XJ6P0J6QX05iNGP80KVi^00<0YJFU0?ooo`3oool04`3o
oomG0000o`80oh00<P000?l20?n001T0003o0P3oP0050000o`l0oooo00090?ooo`0407moO`2BTY80
TY:B0861P@80VYZJ00D0NGUi0:6QX@2QXJ40]kNg09:BTP0208^;R`0509JFUP1kNg/0Ng]k0861P@2=
SHd00P1KFe/01025QHD0XZ:R0::RXP1_Kfl20:BTY00406m_K`1YJFT0MGEe07EeM@<0FUYJ00D0Ogmo
07UiN@1iNGT0^;Rh09>CT`0208:2PP030:f][@2MWId0WIfM00<0O7al00D0FEUI09:BTP3?cll0clo?
0:ZZZP0207UiN@0507emO@18B4P0_;bl0;bl_02IVIT00P3Cdm<01@39bLT0QHF508F5Q@1dM7@0KFe]
0080R8R800@0MgMg09BDU02DU9@0KFe]0P1^KVh01@2RXZ80/[:b0:2PX02PX:00WIfM0080V9RH00D0
NWYj0=WIf@2i^KT0^KVi09RHV00208R8R0050:n_[`2GUiL0UiNG06QXJ02MWId00P2;Rh/0102OWil0
S8b<08b<S02VYZH207QhN00506ATI03Cdm<0X:2P0:2PX023Ph<00P1oOgl01@1HF5P0`<300:^[Z`2[
Zj/0aLG50080=3@d00D0XJ6Q0>?Sh`3Shn<0_;bl06YZJP0206QXJ00407AdM02WYjL0YjNW0;^k^`80
a/K600D0UYJF07alO029RHT0RHV909VIV@0207IfMP0507QhN020P800P82006QXJ02m_Kd00P1VIVH0
1@1CDe<0;2`/02`/;01ZJVX0IFEU0080R8R800@0RXZ:079bLP1bLW80KVi^0P1nOWh01@1MGEd0Lg=c
05eMG@1MGEd0Ph>30080Lg=c00D0PH6109nOW`2OWil0Ph>306e]K@020<G5a@05092@T02?Shl0Shn?
0;2`/02KVi/00P2RXZ80101aLG40HV9R069RHP1YJFT207emO@030:>SX`3oool0oooo01<0ooooE`00
0?l20?n00380003o0P3oP00I0000o`80oh001@000?l?0?ooo`002@3oool01024Q8@0SHf=08f=S@1i
NGT208Z:RP0508J6QP2f][H0][Jf0;:b/P2BTY800P24Q8@01@2KVi/0MGEe07EeM@1eMGD0SHf=0080
FUYJ00@0QXJ609VIV@2IVIT0MWIf0P28R8P0101ZJVX0HV9R08:2PP22PX8305]KF`0507=cL`1oOgl0
Ogmo0;2`/024Q8@00P1lO7`30:>SX`0508B4Q01nOWh0OWin05iNGP2PX:000P3<c<`01@2XZ:P0OGem
07emO@24Q8@0A4A40080^;Rh00@0WIfM0=[JfP3Jf]X0d];B0P2ATI401@27QhL0I6AT08b<S02<S8`0
OWin0080UYJF00D0Ogmo07IfMP1fMWH0ZJVY0;>c/`020::RXP050:2PX02?Shl0Shn?07UiN@3De=@0
0P2a/K40102?Shl0OWin07inOP2YZJT208N7Q`05061PH02FUYH0SHf=08f=S@2VYZH00P2;Rh/01@2T
Y:@0MGEe07EeM@1NGUh0cLg=0080VYZJ00D0R8R808J6QP26QXH0F5QH0<;2`P020:^[Z`040<K6aP0X
:2P0:2PX0;2`/080i>CT00D0/;2`06m_K`1eMGD0MGEe079bLP0209jNWP050<?3``3=cLd0cLg=0:6Q
X@2BTY800P2?Shl0102VYZH0NWYj07YjNP2?Shl20820P00507alO02TY:@0KFe]06e]K@19BDT00P0b
<S801@1aLG40IVIV075aL@1aLG40T92@0080NWYj00D0NGUi07=cL`1cLg<0Kfm_06][J`0206i^KP04
07MgM`1aLG40LG5a07YjNP80XZ:R00D0M7Ad06MWI`34a<@0a<C409JFUP0208N7Q`050:f][@27QhL0
K6a/06a/K01jNWX00P1bLW80101[Jf/0NGUi07UiN@1^KVhE0?ooo`040000o`3oP000oh000?n003d0
003o1`3oP0150000o`030?n000000?l0003o01P0003o00<0oh000000o`000?l00P000?l?0?ooo`00
2@3oool01024Q8@0SHf=08f=S@1iNGT208Z:RP0508J6QP2f][H0][Jf0;:b/P2BTY800P24Q8@01@2K
Vi/0MGEe07EeM@1eMGD0SHf=0080FUYJ00@0QXJ609VIV@2IVIT0MWIf0P28R8P0101ZJVX0HV9R08:2
PP22PX8305]KF`0507=cL`1oOgl0Ogmo0;2`/024Q8@00P1lO7`30:>SX`0508B4Q01nOWh0OWin05iN
GP2PX:000P3<c<`01@2XZ:P0OGem07emO@24Q8@0A4A40080^;Rh00@0WIfM0=[JfP3Jf]X0d];B0P2A
TI401@27QhL0I6AT08b<S02<S8`0OWin0080UYJF00D0Ogmo07IfMP1fMWH0ZJVY0;>c/`020::RXP05
0:2PX02?Shl0Shn?07UiN@3De=@00P2a/K40102?Shl0OWin07inOP2YZJT208N7Q`05061PH02FUYH0
SHf=08f=S@2VYZH00P2;Rh/01@2TY:@0MGEe07EeM@1NGUh0cLg=0080VYZJ00D0R8R808J6QP26QXH0
F5QH0<;2`P020:^[Z`040<K6aP0X:2P0:2PX0;2`/080i>CT00D0/;2`06m_K`1eMGD0MGEe079bLP02
09jNWP050<?3``3=cLd0cLg=0:6QX@2BTY800P2?Shl0102VYZH0NWYj07YjNP2?Shl20820P00507al
O02TY:@0KFe]06e]K@19BDT00P0b<S801@1aLG40IVIV075aL@1aLG40T92@0080NWYj00D0NGUi07=c
L`1cLg<0Kfm_06][J`0206i^KP0407MgM`1aLG40LG5a07YjNP80XZ:R00D0M7Ad06MWI`34a<@0a<C4
09JFUP0208N7Q`050:f][@27QhL0K6a/06a/K01jNWX00P1bLW80101[Jf/0NGUi07UiN@1^KVhE0?oo
oi80003o1@3oP00F0000o`l0oooo00090?ooo`0408:2PP2FUYH0UYJF08>3P`80TY:B00D0R8R80;Fe
]@2e]KD0ZJVY09FEU@0208J6QP050:NWY`1oOgl0Ogmo06a/K029RHT00P1CDe<01025QHD0TI6A096A
T@1eMGD209fMW@050820P01[Jf/0Lg=c07=cL`1BDU800P1@D5001@1jNWX0N7Qh07QhN02c/k<0QhN7
0080OWin00@0YjNW09jNWP2NWYh0Q8B40P26QXH01@1UIFD0RXZ:0<O7a`37alL0ZJVY0080PX:200D0
RHV904Q8B02g]kL0]kNg0:FUY@020=gMg@050=CDe02BTY80TY:B08>3P`1OGel00P2=SHd0101]KFd0
S8b<08b<S023Ph<206QXJ0050:BTY02UYJD0WIfM09fMW@2QXJ400P2=SHd01@21PH40dm?C0:BTY02T
Y:@0TI6A0080OGem00D0[:b/08R8R028R8P0IVIV09BDU00208>3P`0408^;R`1mOGd0OGem09BDU080
MWIf00D0HF5Q0<g=c@2HV9P0V9RH071`L00207emO@0505MGE`3:b/X0ZZZZ0:ZZZP32`/800P0J6QX0
1@2g]kL0h^;R0>;RhP2CTi<0OWin0080NGUi00@0MGEe0:>SX`2SXj<0_[jn0P2l_;`01@2;Rh/0XZ:R
08j>SP2>SXh0ZZZZ0080Ng]k00D0VYZJ06a/K01/K6`0ZJVY096AT@0206a/K00504M7A`0_;bl0;bl_
07alO01RHV800P1IFET0102HV9P0K6a/06a/K01WIfL205mOG`0509:BTP1_Kfl0LG5a075aL@1XJ6P0
0P23Ph<01@1oOgl0VIVI09VIV@23Ph<0IFEU0080`L7100D0WinO07emO@1mOGd0XJ6Q08f=S@0208B4
Q00405iNGP1VIVH0IVIV05UIF@80PH6100<0I6AT0?ooo`3oool04`3ooon]0000o`l0oooo00090?oo
o`0408^;R`29RHT0RHV906a/K080N7Qh00D0O7al0:n_[`2_[jl0[Jf]09RHV0020820P0050:JVYP26
QXH0QXJ607YjNP2<S8`00P1GEeL01027QhL0OGem07emO@1^KVh20:6QX@05075aL@1PH600Kfm_06m_
K`1;Bd/00P1<C4`01@1`L700MGEe07EeM@2ZZZX0PH610080MWIf00@0YjNW09bLW02LW9`0Ng]k0P25
QHD01@1YJFT0VYZJ0<[:bP3:b/X0Y:BT0080NWYj00D0PX:204Y:BP2h^;P0^;Rh0:FUY@020=_Kf`05
0<[:bP2=SHd0SHf=07]kN`1QHF400P27QhL0101^KVh0T92@092@T01ZJVX2069RHP0509^KV`1VIVH0
QHF508F5Q@2GUiL00P2?Shl01@1oOgl0fMWI0:j^[P2^[Zh0Rh^;0080KFe]00@0YZJV08j>SP2>SXh0
Kfm_0`2IVIT0102JVYX0T92@092@T02PX:0207]kN`05069RHP3<c<`0VIVI09VIV@1]KFd00P1nOWh0
1@1ADE40^k^k0::RXP2RXZ80`l?30080?Shn00@0YJFU0>?Sh`3Shn<0T92@0`25QHD0101kNg/0V9RH
09RHV03<c<`20<S8b00507YjNP2WYjL0RHV908V9R@2VYZH00P1oOgl01@2DU9@0K6a/06a/K02MWId0
UYJF0080IVIV00D0DU9B0410@010@400LG5a05aLG002061PH00409:BTP2DU9@0U9BD07alO080Kfm_
00D0WIfM06UYJ@1WIfL0IfMW051@D0020861P@0508>3P`2CTi<0Ti>C08B4Q01XJ6P00P2j^[X01@2N
WYh0M7Ad07AdM02=SHd0UiNG0080OGem00@0Fe]K05UIF@1IFET0M7Ad0P2DU9@00`26QXH0oooo0?oo
o`0C0?ooojd0003o3`3oool000T0oooo00@0Rh^;08V9R@29RHT0K6a/0P1hN7P01@1lO7`0[jn_0:n_
[`2][Jd0V9RH0080P82000D0YZJV08J6QP26QXH0NWYj08b<S00205MGE`0408N7Q`1mOGd0OGem06i^
KP80XJ6Q00D0LG5a061PH01_Kfl0Kfm_04];B`0204a<C005071`L01eMGD0MGEe0:ZZZP21PH400P1f
MWH0102WYjL0W9bL09bLW01kNg/208F5Q@0506UYJ@2JVYX0b/[:0<[:bP2TY:@00P1jNWX01@22PX80
BTY:0;Rh^02h^;P0YJFU0080fm_K00D0b/[:08f=S@2=SHd0Ng]k065QH@0208N7Q`0406i^KP2@T900
T92@06YZJP80HV9R00D0Vi^K06IVIP25QHD0QHF509NGU`0208n?S`0507moO`3IfMT0[Zj^0:j^[P2;
Rh/00P1]KFd0102VYZH0SXj>08j>SP1_Kfl309VIV@0409ZJVP2@T900T92@0:2PX080Ng]k00D0HV9R
0<c<c02IVIT0VIVI06e]K@0207inOP05055AD@2k^k/0XZ:R0::RXP33`l<00P0n?Sh0102UYJD0hn?S
0>?Sh`2@T90308F5Q@0407]kN`2HV9P0V9RH0<c<c080b<S800D0NWYj0:NWY`29RHT0RHV90:JVYP02
07moO`0509BDU01/K6`0K6a/09fMW@2FUYH00P1VIVH01@1BDU80@4100410@01aLG40G5aL0080H61P
00@0TY:B09BDU02DU9@0O7al0P1_Kfl01@2MWId0JFUY06MWI`1WIfL0D51@0080PH6100D0Ph>309>C
T`2CTi<0Q8B406QXJ0020;Zj^P0509jNWP1dM7@0M7Ad08f=S@2GUiL00P1mOGd0101KFe/0FEUI05UI
F@1dM7@209BDU00308J6QP3oool0oooo01<0ooooNP000?l00`3oP000003o0000o`0H0000o`80oh00
0P000?l00`3oP000003o0000o`090000o`<0oh001@000?l?0?ooo`002@3oool0101mOGd0QHF508F5
Q@1dM7@209BDU00508n?S`2`/;00/;2`0;Vi^@2ATI400P20P8001@2NWYh0Ng]k07]kN`20P800UIFE
0080GEeM00@0SHf=09FEU@2EUID0KFe]0P2LW9`01@1^KVh0GemO069RHP1RHV80Bd];0080BTY:00D0
MgMg06IVIP1VIVH0W9bL07YjNP020861P@040:ZZZP2UYJD0YJFU08J6QP80Ng]k00D0FEUI08j>SP34
a<@0a<C40:^[Z`0207QhN00507alO01=CDd0[Zj^0:j^[P2?Shl00P3Cdm<01@3;bl/0Rh^;08^;R`1o
Ogl0K6a/0080SXj>00@0KFe]08n?S`2?Shl0IfMW0P1ZJVX01@2^[Zh0SXj>09NGU`2GUiL0WIfM0080
Rh^;00D0MgMg0=CDe02SXj<0Xj>S08f=S@0208F5Q@050:j^[P2IVIT0VIVI07UiN@2>SXh00P2NWYh0
102ATI40SHf=08f=S@2TY:@208:2PP0505iNGP3De=@0WYjN09jNWP1bLW800P2<S8`01@1KFe/0^k^k
0:6QX@2QXJ40_[jn0080EEEE00D0WinO0>;RhP3Rh^80SXj>07moO`0208^;R`0408Z:RP2KVi/0Vi^K
0<71`@80_Kfm00D0Ph>30:VYZ@2>SXh0SXj>09bLW00208Z:RP0509BDU01dM7@0M7Ad0:BTY02FUYH0
0P1^KVh01@1EEED0C4a<04a<C01jNWX0I6AT0080JFUY00@0MGEe08N7Q`27QhL0MWIf0P1kNg/01@2A
TI40Kfm_05QHF01HF5P0B4Q80080IfMW00D0NGUi09>CT`2CTi<0T92@06ATI0020:>SX`0509NGU`1l
O7`0O7al08^;R`2JVYX00P1aLG401022PX80F5QH05QHF01TI6@208j>SP0307UiN@3oool0oooo01<0
oooo00@0003o0?n0003oP000oh003P000?l80?n003h0003o0`3oP00k0000o`030?n000000?l0003o
01@0003o3`3oool000T0oooo00@0RHV907]kN`1kNg/0Q8B40P2BTY801@27QhL0Z:RX0:RXZ02XZ:P0
T92@0080SHf=00D0V9RH07YjNP1jNWX0Rh^;08j>SP0206ATI004092@T02HV9P0V9RH07MgM`80WIfM
00D0OWin06m_K`1bLW80LW9b04U9B@02059BDP0507YjNP1lO7`0O7al0;6a/@26QXH00P2;Rh/0102V
YZH0WinO09nOW`25QHD208>3P`0505UIF@2LW9`0b/[:0<[:bP2_[jl00P1kNg/01@23Ph<0EEEE0<?3
``33`l<0Z:RX0080g]kN00D0d=3@092@T02@T900Rh^;07AdM00208f=S@0407YjNP2OWil0WinO069R
HP80L71`00D0_;bl08f=S@2_[jl0[jn_0:2PX00208^;R`0508>3P`3EeMD0XJ6Q0:6QX@2=SHd00P20
P8001@2a/K40Z:RX0:RXZ01iNGT0RXZ:0080WYjN00@0SHf=09FEU@2EUID0X:2P0P22PX801@1WIfL0
gMgM09fMW@2MWId0K6a/0080Shn?00D0H61P0<?3``2YZJT0ZJVY0;Jf]P0202l_;`050:FUY@3Ti>@0
i>CT08R8R021PH400P1fMWH0101jNWX0VIVI09VIV@3?cll20<K6aP05092@T02NWYh0WinO09nOW`2N
WYh00P28R8P01@2DU9@0MgMg07MgM`2i^KT0Shn?0080Kfm_00D0@d=3034a<@0a<C40K6a/05iNGP02
07alO00406=SH`1iNGT0NGUi061PH080Ng]k00D0Ph>307moO`1TI6@0I6AT07EeM@0208:2PP0508J6
QP2<S8`0S8b<09RHV01TI6@00P2m_Kd01@2VYZH0Ogmo07moO`2;Rh/0Shn?0080HV9R00@0Ph>304m?
C`1?Cdl0CTi>0P1cLg<00`1_Kfl0oooo0?ooo`0C0?ooofl0003o00<0oh000000o`000?l07@000?l2
0?n000T0003o00<0oh000000o`000?l040000?l?0?ooo`002@3oool01029RHT0Ng]k07]kN`24Q8@2
09:BTP0508N7Q`2XZ:P0Z:RX0:RXZ02@T9000P2=SHd01@2HV9P0NWYj07YjNP2;Rh/0SXj>0080I6AT
00@0T92@09RHV02HV9P0MgMg0P2MWId01@1nOWh0Kfm_079bLP1bLW80BDU90080DU9B00D0NWYj07al
O01lO7`0/K6a08J6QP0208^;R`040:JVYP2OWil0WinO08F5Q@80Ph>300D0FEUI09bLW03:b/X0b/[:
0:n_[`0207]kN`0508>3P`1EEED0`l?30<?3``2XZ:P00P3Ng]h01@3@d=00T92@092@T02;Rh/0M7Ad
0080SHf=00@0NWYj09nOW`2OWil0HV9R0P1`L7001@2l_;`0SHf=0:n_[`2_[jl0X:2P0080Rh^;00D0
Ph>30=GEe@2QXJ40XJ6Q08f=S@020820P0050;6a/@2XZ:P0Z:RX07UiN@2:RXX00P2NWYh0102=SHd0
UIFE09FEU@2PX:0208:2PP0506MWI`3MgMd0WIfM09fMW@1/K6`00P2?Shl01@1PH600`l?30:VYZ@2Y
ZJT0][Jf0080;bl_00D0YJFU0>CTi03Ti>@0R8R80861P@0207IfMP0407YjNP2IVIT0VIVI0<o?c`80
a/K600D0T92@09jNWP2OWil0WinO09jNWP0208R8R00509BDU01gMgL0MgMg0;Vi^@2?Shl00P1_Kfl0
1@13@d<0<C4a034a<@1/K6`0GUiN0080O7al00@0Hf=S07UiN@1iNGT0H61P0P1kNg/01@23Ph<0Ogmo
06ATI01TI6@0MGEe0080PX:200D0QXJ608b<S02<S8`0V9RH06ATI0020;fm_@050:JVYP1oOgl0Ogmo
08^;R`2?Shl00P1RHV801023Ph<0Cdm?04m?C`1>CTh207=cL`0306m_K`3oool0oooo01<0ooooK`00
0?l00`3oP000003o0000o`0M0000o`80oh002@000?l00`3oP000003o0000o`0@0000o`l0oooo0009
0?ooo`0409>CT`1jNWX0NWYj07moO`80SXj>00D0RHV90;Fe]@2e]KD0/K6a09RHV00209BDU0050:>S
X`1lO7`0O7al07alO02=SHd00P1`L7001020P800R8R808R8R01SHf<208J6QP0507IfMP1YJFT0Kfm_
06m_K`17AdL00P1BDU801@1fMWH0OWin07inOP2[Zj/0Q8B40080PX:200@0/K6a0:2PX02PX:00QhN7
0P2;Rh/01@1GEeL0SHf=0<C4a034a<@0XZ:R0080NGUi00D0Ogmo059BDP2n_[h0_[jn09^KV`020=WI
f@050<W9b@2CTi<0Ti>C08V9R@1[Jf/00P1gMgL00`1`L700U9BD09BDU00306IVIP050:ZZZP23Ph<0
^[Zj0;Zj^P2VYZH00P2KVi/01@1oOgl0i>CT0:n_[`2_[jl0Ti>C0080MWIf00D0XZ:R09bLW02LW9`0
LG5a0861P@0308R8R080RHV900D0XZ:R08F5Q@25QHD0FEUI0=3@d00208b<S00507EeM@2LW9`0W9bL
07UiN@2m_Kd00P2RXZ80102LW9`09BDU02DU9@3Ph>020>KViP05092@T025QHD0R8R808R8R01kNg/0
0P2ATI401@32`/80^k^k0;^k^`2=SHd0Zj^[0080WYjN00@0[Jf]09BDU02DU9@0VIVI0P24Q8@01@2Y
ZJT0PX:206MWI`1WIfL0>3Ph0080?clo00D0SHf=051@D023Ph<0Ph>305QHF00208B4Q00505mOG`1d
M7@0M7Ad08j>SP1mOGd00P1_Kfl0102;Rh/0OWin07inOP2;Rh/209RHV0050:2PX01cLg<0b<S80<S8
b02l_;`00P1bLW801@2BTY80WIfM05mOG`1OGel0M7Ad00<0?clo0P1QHF400`1NGUh0oooo0?ooo`0C
0?oood40003o1@3oP00Y0000o`030?n000000?l0003o03/0003o3`3oool000T0oooo00@0Rh^;079b
LP1bLW80OGem0P27QhL01@1kNg/0Vi^K09^KV`2^[Zh0X:2P0080UiNG00D0V9RH0820P020P800Shn?
08F5Q@0205]KF`0407MgM`2@T900T92@05=CD`80Jf][0P19BDT205aLG00405EEE@1RHV80HV9R07]k
N`80R8R800D0];Bd08f=S@20P800P8200:n_[`0209fMW@050861P@2CTi<0Ti>C05iNGP2=SHd00P36
a/H01@2WYjL0O7al07alO022PX80CDe=0080_[jn00@0TI6A0=KFeP3Fe]H0`l?30P2JVYX01@21PH40
LW9b0861P@21PH40N7Qh0080Vi^K00D0LG5a06m_K`1_Kfl0ZJVY09NGU`020<G5a@050:>SX`2UYJD0
YJFU07alO03GemL00P2VYZH0102KVi/0QhN708N7Q`2[Zj/20:FUY@0507YjNP1kNg/0SHf=08f=S@24
Q8@00P2ATI401@2l_;`0TI6A096AT@26QXH0X:2P0080YZJV00D0LW9b0:2PX02PX:00P8200;no_`02
0;>c/`040:VYZ@0Z:RX0:RXZ0=cLg080hn?S00D0QHF507emO@1kNg/0Ng]k07UiN@0209BDU0050<g=
c@2l_;`0_;bl07inOP2QXJ400P2?Shl0102EUID0Rh^;08^;R`1lO7`2096AT@050<30`02;Rh/0J6QX
06QXJ018B4P00P0n?Sh01@20P800CDe=08Z:RP2:RXX0I6AT0080Ph>300D0NGUi071`L01`L700R8R8
075aL@0207MgM`04065QH@1fMWH0MWIf08F5Q@80OWin00D0S8b<079bLP2j^[X0^[Zj0<30`00206IV
IP0508n?S`2m_Kd0Hf=S06=SH`25QHD00P1IFET0101>CTh0LG5a075aL@1OGelE0?ooodD0003o00<0
oh000000o`000?l04`000?l00`3oP000003o0000o`1?0000o`l0oooo00090?ooo`0408n?S`1hN7P0
N7Qh08Z:RP80WIfM00D0S8b<0:f][@2][Jd0`<300:b/[00208n?S`0509^KV`1YJFT0JFUY08N7Q`2D
U9@00P1RHV801026QXH0V9RH09RHV01[Jf/209^KV`0507alO01/K6`0IVIV06IVIP1=CDd00P1JFUX0
1@1nOWh0RHV908V9R@2_[jl0SXj>0080P82000@0/;2`09fMW@2MWId0QHF50P1oOgl01@1?Cdl0Shn?
0;^k^`2k^k/0YJFU0080MWIf00D0Rh^;04];B`36a/H0a/K609jNWP020>3Ph0050;jn_P2WYjL0YjNW
08B4Q01_Kfl00P26QXH01020P800XJ6Q0:6QX@1nOWh207]kN`0509ZJVP2b/[80^k^k0;^k^`2EUID0
0P2OWil01@2BTY80e=CD0:RXZ02XZ:P0];Bd0080RHV900D0Y:BT09nOW`2OWil0P82007alO00207mo
O`0406YZJP1eMGD0MGEe0:NWY`80VYZJ00D0NWYj0<k>cP2GUiL0UiNG069RHP0209JFUP050861P@2R
XZ80[jn_0:n_[`2IVIT00P0j>SX01@3QhN40iNGU0>GUi@1hN7P0Ng]k0080R8R800@0S8b<0:RXZ02X
Z:P0aLG50P2i^KT01@1bLW80Z:RX09BDU02DU9@0Ph>30080MWIf00D0PX:208R8R028R8P0]kNg07If
MP0207MgM`0504=3@`0n?Sh0?Shn07]kN`1HF5P00P1iNGT0101RHV80MgMg07MgM`20P80208F5Q@05
09NGU`1]KFd0OWin07inOP1VIVH00P1/K6`01@1nOWh0S8b<08b<S02YZJT0NGUi0080^KVi00D0`<30
065QH@1QHF40SXj>0<G5a@0205]KF`0406a/K01PH600H61P06MWI`<0KFe]5@3ooomB0000o`80oh00
F@000?l?0?ooo`002@3oool0102?Shl0N7Qh07QhN02:RXX209fMW@0508b<S02][Jd0[Jf]0<30`02/
[:`00P2?Shl01@2KVi/0JFUY06UYJ@27QhL0U9BD0080HV9R00@0QXJ609RHV02HV9P0Jf][0P2KVi/0
1@1lO7`0K6a/06IVIP1VIVH0CDe=0080FUYJ00D0OWin08V9R@29RHT0[jn_08j>SP020820P0040;2`
/02MWId0WIfM08F5Q@80Ogmo00D0Cdm?08n?S`2k^k/0^k^k0:FUY@0207IfMP0508^;R`1;Bd/0a/K6
0<K6aP2NWYh00P3Ph>001@2n_[h0YjNW0:NWY`24Q8@0Kfm_0080QXJ600@0P8200:6QX@2QXJ40OWin
0P1kNg/01@2JVYX0/[:b0;^k^`2k^k/0UIFE0080WinO00D0TY:B0=CDe02XZ:P0Z:RX0;Bd]00208V9
R@050:BTY02OWil0WinO0820P01lO7`00P1oOgl0101ZJVX0MGEe07EeM@2WYjL209ZJVP0507YjNP3>
c/h0UiNG09NGU`1RHV800P2FUYH01@21PH40XZ:R0:n_[`2_[jl0VIVI0080>SXj00D0hN7Q0>GUi@3U
iND0N7Qh07]kN`0208R8R00408b<S02XZ:P0Z:RX0<G5a@80^KVi00D0LW9b0:RXZ02DU9@0U9BD08>3
P`0207IfMP0508:2PP28R8P0R8R80;Ng]`1fMWH00P1gMgL01@13@d<0?Shn03hn?P1kNg/0F5QH0080
NGUi00@0HV9R07MgM`1gMgL0P8200P25QHD01@2GUiL0KFe]07inOP1nOWh0IVIV0080K6a/00D0OWin
08b<S02<S8`0ZJVY07UiN@020;Vi^@050<30`01QHF40HF5Q08j>SP35aLD00P1KFe/0101/K6`0H61P
061PH01WIfL306e]KAD0ooooDP000?l20?n005T0003o3`3oool000T0oooo00@0SXj>07QhN01hN7P0
RHV90P2][Jd01@2CTi<0[Jf]0:f][@30`<00[Jf]0080V9RH00D0W9bL07YjNP1jNWX0SHf=08j>SP02
069RHP040861P@2FUYH0UYJF08F5Q@80[:b/00D0MWIf07AdM01oOgl0Ogmo05QHF002069RHP0508J6
QP1kNg/0Ng]k0;Fe]@2LW9`00P1lO7`0102d];@0Xj>S0:>SX`25QHD208n?S`0506ATI02@T900`<30
0<30`02VYZH00P1jNWX01@2:RXX0Bd];0<G5a@35aLD0UYJF0080d];B00D0_;bl0:f][@2][Jd0PX:2
06e]K@0208R8R00407]kN`2EUID0UIFE07UiN@80OGem00D0R8R809^KV`2k^k/0^k^k07inOP0208^;
R`050:f][@35aLD0YJFU0:FUY@2j^[X00P25QHD01@2/[:`0XJ6Q0:6QX@2=SHd0P8200080QhN700@0
J6QX07moO`1oOgl0R8R80P2OWil01@21PH40cLg=09JFUP2FUYH0IVIV0080R8R800D0PX:20:j^[P2b
/[80/[:b08B4Q00203/k>`050=gMg@3QhN40hN7Q06EUI@1hN7P00`1dM7@209fMW@050<C4a02h^;P0
^;Rh06e]K@2PX:000P28R8P0101nOWh0MWIf07IfMP1YJFT208N7Q`050:j^[P1WIfL0KVi^06i^KP16
ATH00P0l?3`01@1cLg<0F5QH06EUI@1UIFD0QHF50080SHf=00D0LW9b07AdM01dM7@0PH6105eMG@02
07IfMP0406a/K01YJFT0JFUY08B4Q080PH6100D0S8b<06m_K`2a/K40/K6a0:>SX`0206e]K@0508Z:
RP2WYjL0DE5A055AD@1FEUH00P1[Jf/0101FEUH0KVi^06i^KP1bLW8E0?ooojd0003o3`3oool000T0
oooo00@0SHf=07alO01lO7`0U9BD0P2[Zj/01@2=SHd0[jn_0:n_[`30`<00Xj>S0080UiNG00D0W9bL
07QhN01hN7P0QXJ609BDU00205UIF@0407alO02HV9P0V9RH07inOP80YZJV00D0JVYZ069RHP1kNg/0
Ng]k04m?C`0206ATI00507emO@2BTY80TY:B0;>c/`2NWYh00P1mOGd0102n_[h0Y:BT0:BTY028R8P2
08b<S00506QXJ02CTi<0alO70<O7a`2ZZZX00P1mOGd01@29RHT0BTY:0<O7a`37alL0VIVI0080bLW9
00D0^KVi0:^[Z`2[Zj/0R8R80861P@0208^;R`0407emO@2FUYH0UYJF08J6QP80U9BD00D0W9bL0;2`
/02n_[h0_[jn08n?S`0209nOW`050:^[Z`3Cdm<0XJ6Q0:6QX@36a/H00P21PH401@2^[Zh0Xj>S0:>S
X`1nOWh0Ng]k0080QHF500@0HV9R09FEU@2EUID0S8b<0P2SXj<01@2WYjL0gMgM08f=S@2=SHd0KVi^
0080RHV900D0TY:B09NGU`2k^k/0^k^k07moO`02034a<@050=KFeP3MgMd0gMgM069RHP1cLg<00P24
Q8@01022PX80/K6a0;6a/@35aLD20;Rh^00506YZJP2RXZ80Shn?08n?S`2;Rh/00P1iNGT01@1bLW80
Jf][06][J`2h^;P0JFUY0080I6AT00D0@D5103Ph>00h>3P0N7Qh06YZJP0206MWI`040820P027QhL0
QhN706i^KP80Shn?00D0P82007AdM01]KFd0KFe]06=SH`02065QH@0506][J`1oOgl0Ogmo09FEU@1f
MWH00P2][Jd01@28R8P0Lg=c07=cL`2=SHd0[:b/0080FUYJ00@0Cdm?05UIF@1IFET0EUIF0P1WIfL0
0`1PH600oooo0?ooo`0C0?oood@0003o0P3oP00a0000o`L0oh00;`000?l?0?ooo`002@3oool0102=
SHd0O7al07alO02DU9@20:^[Z`0508f=S@2_[jl0[jn_0<30`02SXj<00P2GUiL01@2LW9`0N7Qh07Qh
N026QXH0U9BD0080FEUI00@0O7al09RHV02HV9P0OWin0P2VYZH01@1ZJVX0HV9R07]kN`1kNg/0Cdm?
0080I6AT00D0OGem09:BTP2BTY80/k>c09jNWP0207emO@040;jn_P2TY:@0Y:BT08R8R080S8b<00D0
J6QX09>CT`37alL0alO70:ZZZP0207emO@0508V9R@1:BTX0alO70<O7a`2IVIT00P39bLT01@2i^KT0
Zj^[0:^[Z`28R8P0PH610080Rh^;00@0OGem09JFUP2FUYH0QXJ60P2DU9@01@2LW9`0/;2`0;jn_P2n
_[h0Shn?0080WinO00D0Zj^[0=?Cd`2QXJ40XJ6Q0<K6aP020861P@050:j^[P2SXj<0Xj>S07inOP1k
Ng/00P25QHD0101RHV80UIFE09FEU@2<S8`20:>SX`050:NWY`3MgMd0SHf=08f=S@1^KVh00P29RHT0
1@2BTY80UiNG0;^k^`2k^k/0Ogmo0080<C4a00D0e]KF0=gMg@3MgMd0HV9R07=cL`0208B4Q00408:2
PP2a/K40/K6a0<G5a@80^;Rh00D0JVYZ0::RXP2?Shl0Shn?08^;R`0207UiN@05079bLP1[Jf/0Jf][
0;Rh^01YJFT00P1TI6@01@11@D40>3Ph03Ph>01hN7P0JVYZ0080IfMW00@0P82008N7Q`27QhL0KVi^
0P2?Shl01@20P800M7Ad06e]K@1]KFd0Hf=S0080HF5Q00D0Jf][07moO`1oOgl0UIFE07IfMP020:f]
[@0508R8R01cLg<0Lg=c08f=S@2/[:`00P1JFUX0101?Cdl0FEUI05UIF@1FEUH206MWI`03061PH03o
ool0oooo01<0ooooN0000?l20?n003<0003o3`3oool000T0oooo00@0TI6A07]kN`1kNg/0UIFE0P2/
[:`01@2@T900Z:RX0:RXZ02n_[h0YZJV0080QXJ600D0TY:B07AdM01dM7@0QXJ6096AT@02051@D004
08>3P`2NWYh0WYjN08Z:RP80Y:BT00D0H61P06ATI01lO7`0O7al05ADE00207QhN0050820P02>SXh0
SXj>0<30`02GUiL00P20P800102n_[h0X:2P0:2PX026QXH2092@T00506i^KP2@T900^k^k0;^k^`2]
[Jd00P26QXH01@2FUYH0DE5A0;Zj^P2j^[X0UYJF0080dm?C00D0^KVi0:ZZZP2ZZZX0QHF506IVIP02
08f=S@040820P02>SXh0SXj>08b<S080WinO00D0U9BD0:BTY02a/K40/K6a09:BTP0209>CT`050;Jf
]P3@d=00WinO09nOW`2h^;P00P1iNGT0102>SXh0SHf=08f=S@1eMGD30861P@04055AD@2?Shl0Shn?
075aL@80V9RH00D0Z:RX0=KFeP29RHT0RHV908:2PP0208>3P`050;>c/`2OWil0clo?0<o?c`1gMgL0
0P1=CDd01@3Rh^80g=cL0=cLg01ZJVX0PH610080M7Ad00@0Jf][0;fm_@2m_Kd0`L710P2k^k/01@1o
Ogl0WIfM09:BTP2BTY80UIFE0080K6a/00D0SHf=05iNGP1NGUh0Z:RX075aL@02065QH@05051@D00m
?Cd0?Cdm07IfMP1YJFT00P1LG5`0101hN7P0OWin07inOP1UIFD208B4Q005071`L01gMgL0MgMg07Mg
M`1WIfL00P1/K6`01@1fMWH0QXJ608J6QP2DU9@0M7Ad0080`l?300D0OGem07moO`1oOgl0TI6A0:VY
Z@02069RHP0405MGE`1IFET0FEUI04e=C@80Jf][00<0Hf=S0?ooo`3oool04`3ooomh0000o`80oh00
<`000?l?0?ooo`002@3oool0102ATI40O7al07alO02>SXh209^KV`0508n?S`2XZ:P0Z:RX0;Rh^02/
[:`00P26QXH01@2KVi/0J6QX06QXJ02>SXh0UIFE0080H61P00@0OGem09bLW02LW9`0QhN70P2HV9P0
1@1[Jf/0I6AT075aL@1aLG40CDe=0080MWIf00D0L71`08N7Q`27QhL0]kNg09RHV00207EeM@040;fm
_@2KVi/0Vi^K08V9R@80UIFE00D0JFUY09FEU@30`<00`<300:^[Z`0208j>SP0509BDU01:BTX0`/;2
0<;2`P2TY:@00P3>c/h01@2d];@0XZ:R0::RXP2;Rh/0IVIV0080P82000@0Lg=c07UiN@1iNGT0OWin
0P2GUiL01@2`/;00Z:RX0:RXZ02XZ:P0TY:B0080UYJF00D0VIVI09jNWP2VYZH0YZJV0;Ng]`0207mo
O`050:RXZ02KVi/0Vi^K08>3P`2<S8`00P22PX80101@D500W9bL09bLW01oOgl209:BTP050;6a/@3E
eMD0TI6A096AT@27QhL00P1]KFd01@2[Zj/0XJ6Q0=[JfP3Jf]X0JVYZ0080BTY:0`3Ng]h01@1iNGT0
JFUY07MgM`1gMgL0FEUI0080bLW900D0Z:RX0;2`/02`/;00R8R809JFUP0208f=S@0409BDU01eMGD0
MGEe096AT@80J6QX00D0Ogmo09>CT`1MGEd0GEeM04a<C00203dm?@0507moO`1PH600EeMG05MGE`1]
KFd00P1kNg/01@1LG5`0NWYj07YjNP1cLg<0L71`0080NWYj00@0KFe]079bLP1bLW80Ogmo0P2FUYH0
1@2=SHd0OGem0=GEe@3EeMD0LW9b0080TY:B00@0VYZJ0::RXP1]KFd0KFe]0`1SHf<0101BDU80M7Ad
07AdM01[Jf/E0?ooojd0003o3`3oool000T0oooo00@0TI6A07alO01lO7`0SXj>0P2KVi/01@2?Shl0
Z:RX0:RXZ02h^;P0[:b/0080QXJ600D0Vi^K06QXJ01XJ6P0SXj>09FEU@02061PH00407emO@2LW9`0
W9bL08N7Q`80V9RH00D0Jf][06ATI01aLG40LG5a04e=C@0207IfMP05071`L027QhL0QhN70;Ng]`2H
V9P00P1eMGD0102m_Kd0Vi^K09^KV`29RHT209FEU@0506UYJ@2EUID0`<300<30`02[Zj/00P2>SXh0
1@2DU9@0BTY:0<;2`P32`/80Y:BT0080c/k>00D0];Bd0::RXP2RXZ80Rh^;06IVIP020820P00407=c
L`1iNGT0NGUi07inOP80UiNG00D0/;2`0:RXZ02XZ:P0Z:RX09:BTP0209JFUP0509VIV@2NWYh0YZJV
0:JVYP2g]kL00P1oOgl01@2XZ:P0Vi^K09^KV`23Ph<0S8b<0080PX:200@0D51@09bLW02LW9`0Ogmo
0P2BTY801@2a/K40eMGE096AT@2ATI40QhN70080KFe]00D0Zj^[0:6QX@3Jf]X0f][J06YZJP0204Y:
BP<0g]kN00D0NGUi06UYJ@1gMgL0MgMg05UIF@020<W9b@050:RXZ02`/;00/;2`08R8R02FUYH00P2=
SHd0102DU9@0MGEe07EeM@2ATI4206QXJ00507moO`2CTi<0GEeM05eMG@1<C4`00P0m?Cd01@1oOgl0
H61P05MGE`1GEeL0KFe]0080Ng]k00D0G5aL07YjNP1jNWX0Lg=c071`L00207YjNP0406e]K@1bLW80
LW9b07moO`80UYJF00D0SHf=07emO@3EeMD0eMGE079bLP0209:BTP0409ZJVP2RXZ80KFe]06e]K@<0
Hf=S00@0DU9B07AdM01dM7@0Jf][5@3ooomj0000o`80oh00<@000?l?0?ooo`002@3oool0102@T900
Ph>308>3P`2?Shl209VIV@0508j>SP2_[jl0[jn_0:RXZ02e]KD00P26QXH01@2?Shl0Fe]K05]KF`2A
TI40R8R80080IVIV00@0TY:B08f=S@2=SHd0R8R80P2JVYX01@1_Kfl0GUiN071`L01`L700G5aL0080
KVi^00D0M7Ad08N7Q`27QhL0]KFe09:BTP0208R8R0040<[:bP2PX:00X:2P092@T080Ti>C00D0IVIV
096AT@30`<00`<300:RXZ00208V9R@0508F5Q@1:BTX0^k^k0;^k^`2][Jd00P3;bl/01@2`/;00VIVI
09VIV@1oOgl0KFe]0080SHf=00@0K6a/07=cL`1cLg<0QhN70P2;Rh/01@2EUID0VIVI0:ZZZP2ZZZX0
SXj>0080R8R800D0]kNg0:^[Z`2ZZZX0ZZZZ0;Bd]00208n?S`050;Jf]P29RHT0RHV908N7Q`2BTY80
0P1mOGd0101FEUH0SHf=08f=S@27QhL20820P0050:n_[`3Bd]80RXZ:08Z:RP2?Shl00P1PH6001@2[
Zj/0XJ6Q0=cLg03Lg=`0HV9R0080CDe=00D0f=SH0=7Ad@3AdM40Ng]k06UYJ@0207MgM`04055AD@3>
c/h0c/k>0;Zj^P80^;Rh00D0U9BD07EeM@1/K6`0K6a/08V9R@0206YZJP0507moO`1jNWX0NWYj07If
MP2GUiL00P1DE5@01@10@400D51@051@D025QHD0NGUi0080HV9R00@0H61P08:2PP22PX80QHF50P27
QhL01@1[Jf/0IFEU06UYJ@1YJFT0NGUi0080Ph>300D0Rh^;0;6a/@2a/K40Q8B407UiN@020=OGe`05
07AdM02EUID0UIFE09jNWP2EUID00P1IFET0101XJ6P0GEeM05eMG@1>CTh206][J`0306a/K03oool0
oooo01<0oooo[@000?l?0?ooo`002@3oool01028R8P0OWin07inOP28R8P208J6QP0508F5Q@2c/k<0
/k>c0:6QX@2n_[h00P2?Shl01@2;Rh/0Fe]K05]KF`2DU9@0RXZ:0080JFUY00@0QHF509FEU@2EUID0
PH610P2EUID01@1fMWH0GemO071`L01`L700F5QH0080IVIV00D0MGEe08Z:RP2:RXX0a<C409>CT`02
08J6QP040;no_`2>SXh0SXj>08F5Q@80OGem00D0HV9R092@T02a/K40/K6a09NGU`0208b<S0050820
P01>CTh0_;bl0;bl_02KVi/00P2l_;`01@2b/[80WinO09nOW`1mOGd0KVi^0080R8R800@0MGEe06m_
K`1_Kfl0SHf=0P2?Shl01@2c/k<0ZZZZ0:JVYP2VYZH0Y:BT0080T92@00D0ZZZZ0<K6aP2RXZ80XZ:R
09nOW`0208F5Q@050;^k^`1oOgl0Ogmo08^;R`2?Shl00P2;Rh/0101aLG40VYZJ09ZJVP28R8P207=c
L`050;2`/037alL0P8200820P02NWYh00P1NGUh01@2PX:00UiNG0=oOg`3Ogml0EeMG0080GEeM00D0
hN7Q0<71`@31`L40VIVI07QhN00207emO@0405]KF`32`/80`/;20<_;b`80Zj^[00D0Vi^K09bLW029
RHT0RHV90:JVYP0207MgM`050820P02CTi<0Ti>C09>CT`2JVYX00P1hN7P01@11@D40E5AD05ADE020
P800OGem0080Ogmo00@0L71`08Z:RP2:RXX0HV9R0P1cLg<01@1[Jf/0JVYZ06EUI@1UIFD0PH6100<0
SXj>0P2j^[X01@1jNWX0RHV90=cLg03Lg=`0EeMG0080W9bL00D0UIFE08V9R@23Ph<0Ph>307EeM@02
06YZJP0405ADE01bLW80LW9b07UiNAD0oooo[@000?l?0?ooo`002@3oool0102HV9P0RXZ:08Z:RP27
QhL20820P00507inOP2_[jl0[jn_0;>c/`2d];@00P23Ph<01@26QXH0FUYJ05YJFP2OWil0TY:B0080
H61P00@0KFe]09RHV02HV9P0QhN70P2BTY801@28R8P0IfMW06i^KP1^KVh0D51@0080GUiN00D0NWYj
08R8R028R8P0[Zj^09:BTP0207emO@040<30`023Ph<0Ph>30861P@80SHf=00D0J6QX09FEU@2d];@0
];Bd09RHV00209VIV@050820P01GEeL0][Jf0;Jf]P2RXZ800P38b<P01@2][Jd0ZJVY0:VYZ@1hN7P0
LG5a0080QhN700@0NGUi059BDP1BDU80P8200P2ATI401@2l_;`0Y:BT09BDU02DU9@0WIfM0080Ogmo
00D0[Jf]0=CDe02SXj<0Xj>S0:JVYP0208V9R@050<;2`P1kNg/0Ng]k07IfMP25QHD00P2BTY801020
P800SXj>08j>SP2MWId206EUI@050:JVYP2j^[X0Q8B408B4Q02WYjL00P1HF5P01@2ATI40UIFE0=oO
g`3Ogml0D51@0080Lg=c00D0i>CT0;fm_@2m_Kd0UiNG07YjNP0207MgM`0406][J`2[Zj/0Zj^[0=OG
e`80WinO00D0PH6109^KV`2>SXh0SXj>09^KV`0207]kN`0508V9R@2PX:00X:2P0:RXZ02MWId00P1m
OGd01@10@400FUYJ05YJFP2ATI40EUIF0080X:2P00@0LW9b07QhN01hN7P0J6QX0P1bLW801@1aLG40
KVi^06e]K@1]KFd0OGem0080UiNG00D0TI6A0;>c/`2c/k<0KVi^09BDU0020=;BdP0505=CD`2:RXX0
RXZ:092@T02;Rh/00P2BTY80101>CTh0K6a/06a/K01>CTh2075aL@0306YZJP3oool0oooo01<0oooo
:`000?l20?n00800003o3`3oool000T0oooo00@0V9RH08Z:RP2:RXX0QhN70P20P8001@1nOWh0[jn_
0:n_[`2c/k<0];Bd0080Ph>300D0QXJ605YJFP1JFUX0WinO09:BTP02061PH00406e]K@2HV9P0V9RH
08N7Q`80TY:B00D0R8R806MWI`1^KVh0KVi^051@D00205iNGP0507YjNP28R8P0R8R80:j^[P2BTY80
0P1mOGd01030`<00Ph>308>3P`21PH4208f=S@0506QXJ02EUID0];Bd0;Bd]02HV9P00P2IVIT01@20
P800EeMG0;Jf]P2f][H0XZ:R0080b<S800D0[Jf]0:VYZ@2YZJT0N7Qh075aL@0208N7Q`0407UiN@1B
DU80DU9B0820P080TI6A00D0_;bl0:BTY02DU9@0U9BD09fMW@0207moO`050:f][@3De=@0Xj>S0:>S
X`2VYZH00P29RHT01@32`/80Ng]k07]kN`1fMWH0QHF50080TY:B00@0P82008j>SP2>SXh0WIfM0P1U
IFD01@2VYZH0^[Zj08B4Q024Q8@0YjNW0080F5QH00D0TI6A09FEU@3Ogml0gmoO051@D00207=cL`05
0>CTi02m_Kd0_Kfm09NGU`1jNWX00P1gMgL0101[Jf/0Zj^[0:^[Z`3GemL209nOW`050861P@2KVi/0
SXj>08j>SP2KVi/00P1kNg/01@29RHT0X:2P0:2PX02XZ:P0WIfM0080OGem00D0@41005YJFP1JFUX0
TI6A05IFEP020:2PX004079bLP1hN7P0N7Qh06QXJ080LW9b00D0LG5a06i^KP1]KFd0KFe]07emO@02
09NGU`05096AT@2c/k<0/k>c06i^KP2DU9@00P3Bd]801@1CDe<0RXZ:08Z:RP2@T900Rh^;0080TY:B
00@0CTi>06a/K01/K6`0CTi>0P1aLG400`1ZJVX0oooo0?ooo`0C0?oooah0003o00<0oh000000o`00
0?l0S0000?l?0?ooo`002@3oool308f=S@0408J6QP1nOWh0OWin07moO`80]KFe00D0bLW90<G5a@2F
UYH0UYJF08V9R@0205mOG`0509VIV@1nOWh0GUiN05iNGP1dM7@00P2GUiL308V9R@0508B4Q01UIFD0
IfMW06MWI`1<C4`00P1BDU801@1nOWh0P8200820P02/[:`0U9BD0080NWYj00@0_kno08^;R`2;Rh/0
Q8B40P25QHD01@1^KVh0R8R80<71`@31`L40X:2P0080ZJVY00D0Q8B405UIF@2n_[h0_[jn0;6a/@02
0<o?c`050;6a/@2e]KD0]KFe07]kN`1mOGd00P2>SXh01029RHT0GemO05mOG`2?Shl20:JVYP050:b/
[02QXJ40Ti>C09>CT`2RXZ800P2;Rh/00`2VYZH0c<c<0:BTY0020:BTY080SXj>00D0]kNg07IfMP1f
MWH0Lg=c0861P@0208j>SP0409:BTP2JVYX0VYZJ0;Rh^080KVi^00D0ZJVY0;Fe]@2ATI40TI6A0:JV
YP0206QXJ00508Z:RP2ZZZX0iNGU0>GUi@1?Cdl00P1gMgL01@3Shn<0[Zj^0:j^[P2IVIT0QHF50080
L71`00@0Ng]k0;fm_@2m_Kd0g]kN0P2HV9P01@1UIFD0X:2P09NGU`2GUiL0P8200080NWYj00D0Jf][
096AT@2ATI40^KVi08n?S`02075aL@0504U9B@1SHf<0Hf=S08Z:RP19BDT00P2RXZ80101fMWH0JVYZ
06YZJP1hN7P206][J`0507inOP1ZJVX0KVi^06i^KP1eMGD00P2:RXX01@2ATI40X:2P0:2PX01_Kfl0
SHf=0080d=3@00D0EUIF07]kN`1kNg/0S8b<08B4Q002096AT@0406UYJ@1JFUX0FUYJ05]KF`80Ng]k
00<0NGUi0?ooo`3oool04`3ooolN0000o`030?n000000?l0003o08`0003o3`3oool000T0oooo00@0
S8b<0:RXZ02XZ:P0Ogmo0P1iNGT01@20P800^;Rh0;Rh^038b<P0`/;20080VIVI00D0QXJ605mOG`1O
Gel0X:2P092@T00205eMG@0406YZJP26QXH0QXJ608Z:RP80SXj>00D0Ph>306m_K`1XJ6P0J6QX04];
B`0205YJFP0508:2PP21PH40PH610:b/[02HV9P00P2:RXX01033`l<0SHf=08f=S@2:RXX208n?S`05
06MWI`26QXH0`<300<30`02MWId00P2YZJT01@1kNg/0F5QH0:j^[P2^[Zh0YjNW0080c/k>00D0Zj^[
0:b/[02/[:`0NGUi07]kN`0208B4Q00408R8R01@D500D51@08F5Q@80ZZZZ00D0`<3009ZJVP2FUYH0
UYJF0:NWY`020:6QX@050:FUY@3?cll0[:b/0:b/[02MWId00P2DU9@01@32`/80LG5a075aL@1dM7@0
PH610080RXZ:00@0VIVI096AT@2ATI40][Jf0P1cLg<01@2RXZ80Y:BT08N7Q`27QhL0WinO0080LW9b
00D0QXJ60:JVYP3MgMd0gMgM04a<C00208R8R0030>GUi@2LW9`0W9bL0080Shn?0P26QXH01025QHD0
/[:b0;:b/P3Kfm/2096AT@05069RHP2OWil0VYZJ09ZJVP2=SHd00P2OWil01@1oOgl0QhN708N7Q`2b
/[80OGem0080QhN700D0FUYJ065QH@1QHF40Ng]k0492@P0209ZJVP0407QhN01RHV80HV9R07UiN@80
Lg=c00D0T92@06IVIP2IVIT0VIVI06UYJ@020:2PX00509RHV02PX:00X:2P06EUI@2:RXX00P30`<00
1@1UIFD0NWYj07YjNP2OWil0Ph>30080N7Qh00@0O7al05]KF`1KFe/0FUYJ0P24Q8@00`1eMGD0oooo
0?ooo`0C0?oooa/0003o1@3oP02=0000o`l0oooo00090?ooo`0408b<S02XZ:P0Z:RX07moO`80NGUi
00D0P8200;Rh^02h^;P0b<S80<;2`P0209VIV@0508J6QP1OGel0GemO0:2PX02@T9000P1MGEd0101Z
JVX0QXJ608J6QP2:RXX208j>SP0508>3P`1_Kfl0J6QX06QXJ01;Bd/00P1JFUX01@22PX80PH610861
P@2/[:`0V9RH0080RXZ:00@0`l?308f=S@2=SHd0RXZ:0P2?Shl01@1WIfL0QXJ60<30`030`<00WIfM
0080ZJVY00D0Ng]k05QHF02^[Zh0[Zj^0:NWY`020<k>cP050:^[Z`2/[:`0[:b/07UiN@1kNg/00P24
Q8@01028R8P0D51@051@D025QHD20:ZZZP050<30`02JVYX0UYJF09JFUP2WYjL00P2QXJ401@2UYJD0
clo?0:b/[02/[:`0WIfM0080U9BD00D0`/;2075aL@1aLG40M7Ad0861P@0208Z:RP0409VIV@2ATI40
TI6A0;Jf]P80Lg=c00D0XZ:R0:BTY027QhL0QhN709nOW`02079bLP0508J6QP2VYZH0gMgM0=gMg@1<
C4`00P28R8P00`3UiND0W9bL09bLW00208n?S`80QXJ600@0QHF50;:b/P2b/[80fm_K0P2ATI401@1R
HV80WinO09ZJVP2JVYX0SHf=0080WinO00D0Ogmo08N7Q`27QhL0/[:b07emO@0208N7Q`0505YJFP1Q
HF40HF5Q07]kN`12@T800P2JVYX0101hN7P0HV9R069RHP1iNGT207=cL`05092@T01VIVH0VIVI09VI
V@1YJFT00P2PX:001@2HV9P0X:2P0:2PX01UIFD0RXZ:0080`<3000D0IFEU07YjNP1jNWX0WinO08>3
P`0207QhN00407alO01KFe/0Fe]K05YJFP80Q8B400<0MGEe0?ooo`3oool04`3ooon]0000o`l0oooo
00090?ooo`0408^;R`2VYZH0YZJV07emO@80Lg=c00D0OWin0:j^[P2^[Zh0`l?30:NWY`0209>CT`05
07alO01MGEd0GEeM09bLW02=SHd00P1SHf<0101bLW80Ogmo07moO`2HV9P308J6QP0407AdM01YJFT0
JFUY0492@P80CTi>00D0OWin07IfMP1fMWH0^KVi09bLW00208J6QP040;Rh^02=SHd0SHf=08Z:RP80
Rh^;00D0GEeM07UiN@2b/[80/[:b09NGU`020:2PX00508>3P`1KFe/0^[Zj0;Zj^P2[Zj/00P3;bl/0
1@2VYZH0Y:BT0:BTY01jNWX0Ph>30080QHF500@0R8R804e=C@1=CDd0P8200P2SXj<01@2c/k<0Xj>S
09NGU`2GUiL0XJ6Q0080VYZJ00D0X:2P0<S8b02SXj<0Xj>S09VIV@0208f=S@050;jn_P1fMWH0MWIf
079bLP22PX800P2?Shl0102FUYH0W9bL09bLW030`<0207alO0050:BTY02XZ:P0SXj>08j>SP2EUID0
0P1oOgl01@2HV9P0ZZZZ0>3Ph03Ph>00?3`l0080Ti>C00D0hn?S09JFUP2FUYH0OWin08:2PP02096A
T@0409bLW036a/H0a/K60=[JfP80RHV900D0EeMG09BDU02IVIT0VIVI08B4Q00208j>SP0508B4Q02S
Xj<0Xj>S0;no_`2>SXh00P1oOgl01@16ATH0GUiN05iNGP21PH40Bd];0080RHV900@0MWIf07alO01l
O7`0RXZ:0P25QHD01@2:RXX0MgMg0;Bd]02d];@0Hf=S0080SHf=00D0Rh^;0:j^[P2^[Zh0KFe]09^K
V`020:NWY`05075aL@1cLg<0Lg=c0:b/[02:RXX00P1lO7`0101QHF40De=C05=CD`1CDe<207]kN`03
06a/K03oool0oooo01<0oooo6P000?l40?n006D0003o00@0oh000000o`000?l0003o0P3oP00T0000
o`l0oooo00090?ooo`0408V9R@2YZJT0ZJVY0820P080KVi^00D0Ng]k0:j^[P2^[Zh0_kno0::RXP02
0:2PX00507emO@1UIFD0IFEU09FEU@2<S8`00P1WIfL0101iNGT0OWin07inOP2UYJD208V9R@0508Z:
RP1jNWX0Hf=S06=SH`1:BTX00P1FEUH01@20P800HF5Q065QH@2i^KT0/K6a0080U9BD00@0bLW909>C
T`2CTi<0Shn?0P2CTi<01@1^KVh0PH610<k>cP3>c/h0XJ6Q0080ZJVY00D0Ng]k05EEE@2b/[80/[:b
0:ZZZP020<K6aP<0[:b/00D0Ogmo07]kN`27QhL0QhN708J6QP0204a<C00507emO@2VYZH0YZJV0;Bd
]02`/;000P20P8001@2TY:@0YJFU0:FUY@2a/K40f][J0080Xj>S00@0X:2P09bLW02LW9`0a<C40P1g
MgL207]kN`80Ti>C00@0SXj>0:^[Z`2[Zj/0[Jf]0P2;Rh/01@2YZJT0/[:b096AT@2ATI40QXJ60080
VIVI00D0UiNG0;6a/@3MgMd0gMgM03/k>`0209fMW@050>?Sh`2KVi/0Vi^K07]kN`1cLg<00P26QXH0
102LW9`0cLg=0<g=c@30`<0209BDU00505ADE02MWId0Shn?08n?S`1iNGT00P2?Shl01@2:RXX0U9BD
09BDU02a/K40RHV90080PH6100D0<30`05YJFP1JFUX0MWIf04Y:BP0207EeM@0407alO01oOgl0Ogmo
07UiN@80S8b<00D0Lg=c08:2PP2l_;`0_;bl07=cL`02096AT@0409JFUP2/[:`0[:b/07emO@<0ZJVY
00D0QhN707IfMP1fMWH0W9bL09^KV`0208R8R00405mOG`1@D500D51@051@D080T92@00<0P8200?oo
o`3oool04`3ooolJ0000o`@0oh00I@000?l0103oP000003o0000o`000?l20?n002@0003o3`3oool0
00T0oooo00@0R8R80;>c/`2c/k<0QhN70P1jNWX01@29RHT0^;Rh0;Rh^035aLD0WYjN0080WinO00D0
PX:206e]K@1]KFd0QXJ607emO@0206MWI`0406ATI01LG5`0G5aL0:^[Z`80QXJ600D0RXZ:07emO@1V
IVH0IVIV04E5A@0205EEE@05034a<@1JFUX0FUYJ0;6a/@2QXJ400P2FUYH0102o_kl0SHf=08f=S@29
RHT208N7Q`05075aL@26QXH0`<300<30`02GUiL00P2MWId01@1_Kfl0HF5Q0<C4a034a<@0][Jf0080
a/K600D0[:b/0;Fe]@2e]KD0OGem07inOP02092@T00409:BTP19BDT0BDU9079bLP80ZJVY00D0YZJV
0;Bd]01lO7`0O7al0;6a/@020;Jf]P050;Rh^03IfMT0Vi^K09^KV`2FUYH00P2LW9`01@33`l<0Ng]k
07]kN`1oOgl0Ng]k00<0SHf=0P2NWYh01@2LW9`0WYjN09jNWP2`/;00Zj^[0080UIFE00D0MGEe0:FU
Y@2UYJD0YJFU0;Vi^@020=KFeP040492@P2[Zj/0Zj^[0>KViP80ZJVY00D0NGUi06EUI@21PH40PH61
09bLW0020;Jf]P0509BDU02[Zj/0Zj^[06ATI02`/;000P2IVIT0102;Rh/0W9bL09bLW02<S8`208f=
S@050:RXZ02=SHd0OGem07emO@0f=SH00P1^KVh01@23Ph<0AdM706QXJ01XJ6P0Lg=c0080JVYZ00D0
KVi^096AT@2ATI40PX:208b<S0020;fm_@0407EeM@2;Rh/0Rh^;08V9R@80W9bL00D0PH6109>CT`2M
WId0WIfM08J6QP020:JVYP050:RXZ02YZJT0NGUi07UiN@1KFe/00P1=CDd0101LG5`0MWIf07IfMP1/
K6`E0?ooofl0003o00<0oh000000o`000?l05@000?l20?n002@0003o3`3oool000T0oooo00@0R8R8
0;>c/`2c/k<0QhN70P1jNWX01@29RHT0^;Rh0;Rh^035aLD0WYjN0080WinO00D0PX:206e]K@1]KFd0
QXJ607emO@0206MWI`0406ATI01LG5`0G5aL0:^[Z`80QXJ600D0RXZ:07emO@1VIVH0IVIV04E5A@02
05EEE@05034a<@1JFUX0FUYJ0;6a/@2QXJ400P2FUYH0102o_kl0SHf=08f=S@29RHT208N7Q`05075a
L@26QXH0`<300<30`02GUiL00P2MWId01@1_Kfl0HF5Q0<C4a034a<@0][Jf0080a/K600D0[:b/0;Fe
]@2e]KD0OGem07inOP02092@T00409:BTP19BDT0BDU9079bLP80ZJVY00D0YZJV0;Bd]01lO7`0O7al
0;6a/@020;Jf]P050;Rh^03IfMT0Vi^K09^KV`2FUYH00P2LW9`01@33`l<0Ng]k07]kN`1oOgl0Ng]k
00<0SHf=0P2NWYh01@2LW9`0WYjN09jNWP2`/;00Zj^[0080UIFE00D0MGEe0:FUY@2UYJD0YJFU0;Vi
^@020=KFeP040492@P2[Zj/0Zj^[0>KViP80ZJVY00D0NGUi06EUI@21PH40PH6109bLW0020;Jf]P05
09BDU02[Zj/0Zj^[06ATI02`/;000P2IVIT0102;Rh/0W9bL09bLW02<S8`208f=S@050:RXZ02=SHd0
OGem07emO@0f=SH00P1^KVh01@23Ph<0AdM706QXJ01XJ6P0Lg=c0080JVYZ00D0KVi^096AT@2ATI40
PX:208b<S0020;fm_@0407EeM@2;Rh/0Rh^;08V9R@80W9bL00D0PH6109>CT`2MWId0WIfM08J6QP02
0:JVYP050:RXZ02YZJT0NGUi07UiN@1KFe/00P1=CDd0101LG5`0MWIf07IfMP1/K6`E0?oooa00003o
203oP0180000o`030?n000000?l0003o02@0003o0P3oP00T0000o`l0oooo00090?ooo`0408V9R@2M
WId0WIfM08b<S080KFe]00D0Shn?0;2`/02`/;00a/K60::RXP020:RXZ005092@T01eMGD0MGEe09BD
U01hN7P00P1ZJVX0101UIFD0GemO05mOG`2UYJD207inOP0507IfMP1kNg/0Hf=S06=SH`1@D5000P1F
EUH01@0n?Sh0Ng]k07]kN`2YZJT0X:2P0080TY:B00@0_Kfm09:BTP2BTY80Shn?0P2:RXX01@1hN7P0
Ti>C0;Zj^P2j^[X0V9RH0080X:2P0P1`L7020<;2`P040;Zj^P34a<@0a<C40;2`/080ZJVY00D0Ph>3
07emO@2?Shl0Shn?09FEU@0204I6AP0507AdM02WYjL0YjNW0;Fe]@2i^KT00P1cLg<01@2[Zj/0]kNg
0;Ng]`33`l<0gmoO0080VIVI0`2LW9`01@2j^[X0QHF508F5Q@2;Rh/0Lg=c0080S8b<00@0NWYj09jN
WP2NWYh0TY:B0P2SXj<01@2d];@0/;2`0861P@21PH40LG5a0080Z:RX00D0/;2`0<;2`P3EeMD0eMGE
03Ti>@020:j^[P050>_[j`2f][H0][Jf07UiN@1GEeL00P20P800102ATI40^[Zj0;Zj^P2j^[X20:b/
[00506YZJP2ZZZX0QhN708N7Q`2:RXX00P2JVYX01@2@T900S8b<08b<S02e]KD0RXZ:0080RHV900D0
?Cdm07emO@1mOGd0OWin051@D00207QhN00406a/K01[Jf/0Jf][06][J`<0P82000@0RHV90:BTY02T
Y:@0KFe]0P1mOGd01@27QhL0V9RH09RHV022PX80TY:B0080Rh^;00D0PX:208n?S`2?Shl0Y:BT0;>c
/`0207YjNP0406YZJP1>CTh0CTi>06UYJ@80N7Qh00<0I6AT0?ooo`3oool04`3oool80000o`H0oh00
0P000?l:0?n000H0003o0`3oP00:0000o`030?n000000?l0003o02@0003o103oP0030000o`030?n0
00000?l0oh0000D0oh000P000?l20?n000`0003o00@0oh000000o`000?l0oh002`000?l20?n000<0
003o0P3oP0040000o`030?n000000?l0003o00D0003o00@0oh000000o`3oP000oh000P000?l30?n0
00030000o`3oP000oh0000`0003o3`3oool000T0oooo00@0NGUi09>CT`2CTi<0QhN70P1EEED01@2H
V9P0YJFU0:FUY@2l_;`0Vi^K0080[:b/00D0PX:207UiN@1iNGT0UIFE08>3P`0207AdM004075aL@1h
N7P0N7Qh0;6a/@80RHV900D0O7al08N7Q`1_Kfl0Kfm_06ATI00205QHF00506ATI022PX80PX:20;2`
/02KVi/00P2DU9@0102^[Zh0S8b<08b<S02=SHd208J6QP0508N7Q`2HV9P0`l?30<?3``2MWId00P2O
Wil01@1[Jf/0Lg=c0:b/[02/[:`0`l?30080`/;200D0ZZZZ09ZJVP2JVYX0PH6107QhN00208J6QP04
09jNWP1=CDd0CDe=06MWI`80YZJV00D0[Jf]0:j^[P1gMgL0MgMg0:JVYP020:BTY0050<W9b@3Kfm/0
UIFE09FEU@2MWId00P2?Shl01@2[Zj/0P8200820P02:RXX0NWYj0080S8b<00@0Ph>309VIV@2IVIT0
QHF50P2RXZ801@2c/k<0[jn_07YjNP1jNWX0I6AT0080X:2P00D0/[:b0<O7a`3Cdm<0dm?C038b<P02
0:n_[`050>KViP2m_Kd0_Kfm07alO01MGEd00P1nOWh0102HV9P0]kNg0;Ng]`2l_;`20:n_[`0507=c
L`2JVYX0PH610861P@2?Shl00P21PH401@2=SHd0OGem07emO@34a<@0P8200080OGem00D0;Bd]06QX
J01XJ6P0GemO055AD@0208>3P`0406ATI01kNg/0Ng]k07emO@80RXZ:00D0Ph>307UiN@29RHT0RHV9
07UiN@0208>3P`<0UYJF00D0SHf=0:ZZZP1oOgl0Ogmo08n?S`0209NGU`050:VYZ@2TY:@0MgMg07Mg
M`20P8000P1SHf<0101[Jf/0OGem07emO@1bLW8E0?ooo`P0003o1P3oP0020000o`X0oh001P000?l3
0?n000X0003o00<0oh000000o`000?l090000?l40?n000<0003o00<0oh000000o`3oP0001@3oP002
0000o`80oh0030000?l0103oP000003o0000o`3oP00;0000o`80oh000`000?l20?n000@0003o00<0
oh000000o`000?l01@000?l0103oP000003o0?n0003oP0020000o`<0oh0000<0003o0?n0003oP000
30000?l?0?ooo`002@3oool0101iNGT0Ti>C09>CT`27QhL205EEE@0509RHV02UYJD0YJFU0;bl_02K
Vi/00P2/[:`01@22PX80NGUi07UiN@2EUID0Ph>30080M7Ad00@0LG5a07QhN01hN7P0/K6a0P29RHT0
1@1lO7`0QhN706m_K`1_Kfl0I6AT0080F5QH00D0I6AT08:2PP22PX80/;2`09^KV`0209BDU0040:j^
[P2<S8`0S8b<08f=S@80QXJ600D0QhN709RHV033`l<0`l?309fMW@0209nOW`0506][J`1cLg<0[:b/
0:b/[033`l<00P32`/801@2ZZZX0VYZJ09ZJVP21PH40N7Qh0080QXJ600@0WYjN04e=C@1=CDd0IfMW
0P2VYZH01@2][Jd0[Zj^07MgM`1gMgL0YZJV0080Y:BT00D0bLW90=_Kf`2EUID0UIFE09fMW@0208n?
S`050:^[Z`20P800P82008Z:RP1jNWX00P2<S8`01023Ph<0VIVI09VIV@25QHD20::RXP050;>c/`2_
[jl0NWYj07YjNP1TI6@00P2PX:001@2b/[80alO70=?Cd`3Cdm<0<S8b0080[jn_00D0i^KV0;fm_@2m
_Kd0O7al05eMG@0207inOP0409RHV02g]kL0]kNg0;bl_080[jn_00D0Lg=c09ZJVP21PH40PH6108n?
S`020861P@0508f=S@1mOGd0OGem0<C4a020P8000P1mOGd01@0];Bd0J6QX06QXJ01OGel0DE5A0080
Ph>300@0I6AT07]kN`1kNg/0OGem0P2:RXX01@23Ph<0NGUi08V9R@29RHT0NGUi0080Ph>30`2FUYH0
1@2=SHd0ZZZZ07moO`1oOgl0Shn?0080UiNG00D0ZJVY0:BTY01gMgL0MgMg0820P00206=SH`0406][
J`1mOGd0OGem079bLQD0oooo20000?l40?n000L0003o103oP00;0000o`030?n000000?l0003o00P0
003o0P3oP00X0000o`030?n000000?l0003o0080003o103oP00C0000o`040?n000000?l0003o0?n0
00/0003o00<0oh000000o`000?l040000?l00`3oP000003o0000o`070000o`<0oh002`000?l?0?oo
o`002@3oool0101mOGd0VIVI09VIV@2;Rh/205]KF`050:2PX02IVIT0VIVI0:NWY`2FUYH00P2ZZZX0
1@24Q8@0KFe]06e]K@26QXH0QHF50080PH6100@0MWIf06UYJ@1YJFT0[:b/0P2GUiL01@1nOWh0Ti>C
06i^KP1^KVh0GEeM0080AdM700D0?Shn08B4Q024Q8@0^;Rh09jNWP020:2PX0040;fm_@2>SXh0SXj>
09>CT`80RHV900D0Ogmo0:>SX`33`l<0`l?309^KV`0209bLW00507AdM01jNWX0YJFU0:FUY@3Hf=P0
0P3AdM401@2h^;P0UiNG09NGU`26QXH0O7al0080OGem00@0Vi^K069RHP1RHV80J6QX0P2PX:00102c
/k<0Vi^K07AdM01dM7@30:>SX`050=GEe@3Cdm<0XJ6Q0:6QX@2YZJT00P27QhL01@2ZZZX0Shn?08n?
S`27QhL0QXJ60080QHF500@0Ogmo09JFUP2FUYH0Ogmo0P2CTi<01@2d];@0/k>c08>3P`23Ph<0HV9R
0080WYjN00D0ZZZZ0<;2`P32`/80`/;202`/;0020;Fe]@050>[ZjP30`<00`<30079bLP1RHV800P1F
EUH0102<S8`0XJ6Q0:6QX@2h^;P20;6a/@0508N7Q`2YZJT0T92@092@T02PX:000P1iNGT01@2GUiL0
K6a/06a/K02g]kL0QXJ60080Ogmo00D0>CTi07moO`1oOgl0LG5a069RHP0209>CT`0405mOG`1iNGT0
NGUi06m_K`80SHf=00D0MgMg07YjNP1oOgl0Ogmo08>3P`0208N7Q`0509jNWP2?Shl0Shn?092@T02Q
XJ400P2:RXX01@2KVi/0UYJF09JFUP2JVYX0V9RH0080K6a/00@0MGEe05aLG01LG5`0KFe]0P1mOGd0
0`1`L700oooo0?ooo`3?0?ooo`002@3oool01021PH40V9RH09RHV02;Rh/206=SH`0509jNWP2HV9P0
V9RH0;Rh^02JVYX00P2_[jl01@29RHT0TI6A096AT@2ATI40MGEe0080KVi^00@0K6a/05QHF01HF5P0
WYjN0P24Q8@01@1YJFT0Shn?06m_K`1_Kfl0DU9B0080J6QX00D0A4A408J6QP26QXH0^KVi09JFUP02
08n?S`040::RXP26QXH0QXJ607QhN080PH6100D0Ph>30;Jf]P34a<@0a<C40:2PX00209BDU00506a/
K01kNg/0Xj>S0:>SX`3@d=000P32`/801@2a/K40R8R808R8R021PH40RHV90080P82000@0V9RH07Ad
M01dM7@0Lg=c0P2BTY801@2/[:`0VYZJ07YjNP1jNWX0XJ6Q0080WIfM00D0hN7Q0=;BdP2][Jd0[Jf]
0:2PX00208V9R@050:>SX`2GUiL0UiNG08F5Q@2DU9@00P1iNGT0101dM7@0T92@092@T028R8P209bL
W0050;6a/@2SXj<0KFe]06e]K@1TI6@00P2HV9P01@2UYJD0a<C40<O7a`37alL09RHV0080_[jn00D0
inOW0;bl_02l_;`0LW9b07IfMP02061PH00409fMW@2VYZH0YZJV0;fm_@<0UIFE00@0[:b/09:BTP2B
TY80UiNG0P1VIVH01@2NWYh0LG5a075aL@2RXZ80YJFU0080JFUY00D0?Cdm06i^KP1^KVh0F5QH069R
HP0209JFUP0405MGE`1aLG40LG5a071`L080QXJ600D0L71`0820P01/K6`0K6a/08V9R@0208:2PP05
0;Vi^@2GUiL0UiNG09JFUP2WYjL00P2@T9001@2KVi/0U9BD09BDU02JVYX0TY:B0080M7Ad00@0LG5a
06IVIP1VIVH0JFUY0P1hN7P00`1kNg/0oooo0?ooo`3?0?ooo`002@3oool01021PH40V9RH09RHV02;
Rh/206=SH`0509jNWP2HV9P0V9RH0;Rh^02JVYX00P2_[jl01@29RHT0TI6A096AT@2ATI40MGEe0080
KVi^00@0K6a/05QHF01HF5P0WYjN0P24Q8@01@1YJFT0Shn?06m_K`1_Kfl0DU9B0080J6QX00D0A4A4
08J6QP26QXH0^KVi09JFUP0208n?S`040::RXP26QXH0QXJ607QhN080PH6100D0Ph>30;Jf]P34a<@0
a<C40:2PX00209BDU00506a/K01kNg/0Xj>S0:>SX`3@d=000P32`/801@2a/K40R8R808R8R021PH40
RHV90080P82000@0V9RH07AdM01dM7@0Lg=c0P2BTY801@2/[:`0VYZJ07YjNP1jNWX0XJ6Q0080WIfM
00D0hN7Q0=;BdP2][Jd0[Jf]0:2PX00208V9R@050:>SX`2GUiL0UiNG08F5Q@2DU9@00P1iNGT0101d
M7@0T92@092@T028R8P209bLW0050;6a/@2SXj<0KFe]06e]K@1TI6@00P2HV9P01@2UYJD0a<C40<O7
a`37alL09RHV0080_[jn00D0inOW0;bl_02l_;`0LW9b07IfMP02061PH00409fMW@2VYZH0YZJV0;fm
_@<0UIFE00@0[:b/09:BTP2BTY80UiNG0P1VIVH01@2NWYh0LG5a075aL@2RXZ80YJFU0080JFUY00D0
?Cdm06i^KP1^KVh0F5QH069RHP0209JFUP0405MGE`1aLG40LG5a071`L080QXJ600D0L71`0820P01/
K6`0K6a/08V9R@0208:2PP050;Vi^@2GUiL0UiNG09JFUP2WYjL00P2@T9001@2KVi/0U9BD09BDU02J
VYX0TY:B0080M7Ad00@0LG5a06IVIP1VIVH0JFUY0P1hN7P00`1kNg/0oooo0?ooo`3?0?ooo`002@3o
ool01027QhL0UIFE09FEU@2@T90205EEE@0509fMW@2JVYX0VYZJ0;Bd]02DU9@00P2e]KD01@2BTY80
Y:BT0:BTY02@T900MgMg0080O7al00@0K6a/079bLP1bLW80YZJV0P22PX801@25QHD0X:2P08F5Q@25
QHD0D51@0080K6a/00D0A4A408R8R028R8P0^[Zj08b<S00209RHV0040:BTY01dM7@0M7Ad06EUI@80
LW9b00D0Lg=c0;:b/P2o_kl0_kno09>CT`0208n?S`05071`L01]KFd0XJ6Q0:6QX@3MgMd00P37alL0
1@2b/[80QHF508F5Q@2?Shl0KVi^0080Q8B400@0SXj>07UiN@1iNGT0M7Ad0P2ATI401@2/[:`0R8R8
07=cL`1cLg<0TI6A0080Ti>C00D0hn?S0<G5a@2b/[80/[:b0:VYZ@02092@T0050:b/[02>SXh0SXj>
08:2PP2^[Zh00P21PH40101oOgl0Z:RX0:RXZ024Q8@209VIV@050;Fe]@2^[Zh0QHF508F5Q@23Ph<0
0P2DU9@01@37alL0b/[:0:VYZ@2YZJT0=3@d0080a<C400D0inOW0:ZZZP2ZZZX0Ng]k08B4Q00204a<
C00409BDU02PX:00X:2P0=7Ad@80UIFE00D0Xj>S07moO`2TY:@0Y:BT09NGU`0206QXJ00508R8R023
Ph<0Ph>308B4Q02i^KT00P1CDe<01@0h>3P0UYJF09JFUP1TI6@0Lg=c0080TI6A00@0Fe]K075aL@1a
LG40Fe]K0P1bLW801@1SHf<0Kfm_06=SH`1SHf<0Rh^;0080VIVI00D0]kNg0:BTY02TY:@0Shn?0;6a
/@020:b/[0050:>SX`2f][H0][Jf09RHV01gMgL00P20P800101^KVh0GEeM05eMG@1[Jf/20820P003
06i^KP3oool0oooo0<l0oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo00090?ooo`0405YJFP23Ph<0
Ph>309>CT`80XJ6Q00D0[jn_09jNWP2NWYh0D51@03Lg=`020;>c/`050;Vi^@2l_;`0_;bl0;Rh^02f
][H00P1mOGd0100_;bl0Ogmo07moO`1eMGD207MgM`050820P025QHD0PH610861P@17AdL00P2][Jd0
1@2a/K40ZZZZ0:ZZZP2YZJT0Zj^[0080UIFE00@07QhN07QhN01hN7P0Shn?0P2DU9@01@2IVIT0WYjN
09>CT`2CTi<09RHV0080EEEE00D0HV9R06UYJ@1YJFT0JFUY06i^KP0207=cL`0503dm?@1nOWh0OWin
09:BTP2MWId00P2TY:@0102ZZZX0ZJVY0:VYZ@2`/;020;Bd]00305MGE`2OWil0/[:b0080/[:b0`2`
/;00101aLG40>SXj03Xj>P2MWId20:^[Z`050:n_[`2[Zj/0Zj^[0;2`/01^KVh00P0c<c<01023Ph<0
P8200820P02BTY8209bLW0050:VYZ@1/K6`09BDU02DU9@16ATH00P19BDT01@1EEED0J6QX07EeM@1e
MGD0Cdm?0080KVi^00D0^KVi0;:b/P2b/[80[jn_0:f][@020:j^[P0305=CD`2JVYX0VYZJ00<0^;Rh
00D0^[Zj0;bl_02f][H0][Jf06ATI0020;Bd]0050;Rh^02l_;`0_;bl0;Vi^@2h^;P00P1KFe/01024
Q8@0/[:b0;:b/P2][Jd30;Bd]00408J6QP29RHT0RHV90;:b/P80[jn_00D0[Jf]0:b/[02YZJT0ZJVY
05=CD`0208R8R0050:FUY@2/[:`0[:b/0;6a/@2][Jd00P26QXH01@23Ph<0`l?30<?3``37alL0`<30
0080_[jn00@0[Jf]059BDP1BDU80[:b/0P2`/;000`2^[Zh0oooo0?ooo`3?0?ooo`002@3oool0101N
GUh0TI6A096AT@2QXJ420;Fe]@050;Vi^@2c/k<0/k>c079bLP0i>CT00P2^[Zh40;bl_0040;Vi^@1n
OWh0OWin03Ph>080MGEe00D0KFe]06i^KP1^KVh0N7Qh08B4Q00208R8R00403Xj>P2XZ:P0Z:RX0;2`
/080[Zj^00D0ZZZZ0:f][@2ATI40TI6A02HV9P0208b<S00509^KV`2UYJD0YJFU0:BTY02QXJ400P2E
UID01@0R8R80I6AT06ATI01nOWh0Ph>30080KFe]00@0J6QX05UIF@1IFET0<C4a0P20P8001@2FUYH0
WinO0:>SX`2SXj<0ZZZZ0080[Zj^00D0/k>c0;Fe]@2e]KD0EEEE0:6QX@020:^[Z`050:n_[`2^[Zh0
[Zj^0;2`/01fMWH00P0/;2`01027QhL0X:2P0:2PX02PX:020:ZZZP050:f][@1/K6`0=SHf03Hf=P2L
W9`00P2GUiL01@2LW9`0Xj>S0:>SX`2YZJT0MgMg0080?Cdm00D0IFEU04=3@`13@d<0CTi>06MWI`02
071`L00404U9B@1cLg<0Lg=c0;>c/`80Zj^[00D0[Jf]0;2`/02/[:`0[:b/055AD@0209JFUP050;>c
/`2_[jl0[jn_0;2`/02j^[X00P2[Zj/0101[Jf/0]kNg0;Ng]`2i^KT20;no_`80^KVi0P1ZJVX01@2?
Shl0/k>c0;>c/`2[Zj/0/k>c0080]KFe00@0YZJV0:6QX@2QXJ40_Kfm0P2f][H01@2h^;P0][Jf0;:b
/P2b/[80G5aL0080QXJ600D0WYjN0:ZZZP2ZZZX0Zj^[0;Fe]@0209>CT`0308f=S@2k^k/0^k^k0080
^k^k0P2o_kl00`33`l<0Kfm_06m_K`040:ZZZ]40oooo00090?ooo`0405iNGP2ATI40TI6A0:6QX@80
]KFe00D0^KVi0;>c/`2c/k<0LW9b03Ti>@020:j^[P@0_;bl00@0^KVi07inOP1nOWh0>3Ph0P1eMGD0
1@1]KFd0KVi^06i^KP1hN7P0Q8B40080R8R800@0>SXj0:RXZ02XZ:P0/;2`0P2^[Zh01@2ZZZX0[Jf]
096AT@2ATI409RHV0080S8b<00D0Vi^K0:FUY@2UYJD0Y:BT0:6QX@0209FEU@05028R8P1TI6@0I6AT
07inOP23Ph<00P1]KFd0101XJ6P0FEUI05UIF@0a<C420820P00509JFUP2OWil0Xj>S0:>SX`2ZZZX0
0P2^[Zh01@2c/k<0]KFe0;Fe]@1EEED0XJ6Q0080Zj^[00D0[jn_0:j^[P2^[Zh0/;2`07IfMP0202`/
;00408N7Q`2PX:00X:2P0:2PX080ZZZZ00D0[Jf]06a/K00f=SH0=SHf09bLW00209NGU`0509bLW02S
Xj<0Xj>S0:VYZ@1gMgL00P0m?Cd01@1UIFD0@d=304=3@`1>CTh0IfMW0080L71`00@0BDU907=cL`1c
Lg<0/k>c0P2[Zj/01@2][Jd0/;2`0:b/[02/[:`0DE5A0080UYJF00D0/k>c0:n_[`2_[jl0/;2`0;Zj
^P020:^[Z`0406][J`2g]kL0]kNg0;Vi^@80_kno0P2i^KT206YZJP0508n?S`2c/k<0/k>c0:^[Z`2c
/k<00P2e]KD0102VYZH0XJ6Q0:6QX@2m_Kd20;Jf]P050;Rh^02f][H0/[:b0;:b/P1LG5`00P26QXH0
1@2NWYh0ZZZZ0:ZZZP2[Zj/0]KFe0080Ti>C00<0SHf=0;^k^`2k^k/00P2k^k/20;no_`030<?3``1_
Kfl0Kfm_00@0ZZZZd@3oool000T0oooo00@0GUiN09NGU`2GUiL0ZZZZ0P2][Jd01@2XZ:P0YJFU0:FU
Y@1VIVH0;Bd]0080WYjN00D0]KFe0;Bd]02d];@0^KVi0;Rh^00209fMW@0405EEE@1aLG40LG5a06UY
J@80JVYZ00D0MGEe08F5Q@2ATI40TI6A03Ph>00208>3P`0509fMW@2SXj<0Xj>S0:>SX`2GUiL00P1R
HV80100o?cl0Ph>308>3P`2BTY820:6QX@0509jNWP2HV9P0Q8B408B4Q00^;Rh00P1GEeL01@1iNGT0
Kfm_06i^KP1^KVh0H61P0080D51@00D0;2`/08Z:RP2:RXX0Xj>S0:^[Z`020:6QX@030:NWY`2^[Zh0
[Zj^00<0/;2`00D0De=C09RHV02[Zj/0Zj^[0:f][@020:n_[`050;2`/01dM7@0:RXZ02XZ:P2ZZZX0
0P2OWil01@2@T900X:2P0:2PX02[Zj/0L71`0080>c/k00@0WinO09fMW@2MWId0XZ:R0P2VYZH01@2/
[:`0N7Qh04M7A`17AdL0UIFE0080De=C00D0GUiN06m_K`1cLg<0Lg=c04E5A@02065QH@050;>c/`2X
Z:P0Z:RX0:JVYP2^[Zh00P2`/;00101>CTh0UIFE09FEU@2f][H20;:b/P80/K6a0P2`/;00101TI6@0
][Jf0;Jf]P2o_kl20;Rh^0050;bl_02i^KT0Jf][06][J`2>SXh00P2d];@01@2e]KD0/k>c0;Jf]P2f
][H0Y:BT0080V9RH00D0]kNg0;Rh^02h^;P0][Jf0;:b/P020;6a/@0405MGE`2LW9`0W9bL0;2`/080
[Zj^00D0]KFe0;Rh^02BTY80TY:B08J6QP030;2`/0040:j^[P2c/k<0/k>c0;bl_080LW9b00@0[Jf]
0:>SX`2SXj<0WYjNd@3oool000T0oooo00@0?3`l0410@010@400ATI60P0m?Cd01@0i>CT0>3Ph03Ph
>00Y:BT092@T00<0;bl_0P0P82001@0X:2P09RHV028R8P0R8R807QhN0080:2PX00D08b<S02PX:00X
:2P0:BTY02d];@02038b<P0402d];@0m?Cd0?Cdm04i>CP80=3@d00D0:BTY01dM7@0E5AD05ADE01lO
7`0203dm?@0503hn?P0j>SX0>SXj03De=@0g=cL00P19BDT01@0b<S80>3Ph03Ph>00n?Sh0>CTi0080
=cLg00@0=3@d02d];@0];Bd08b<S0P16ATH01@19BDT0CTi>04i>CP1>CTh0EeMG0080GEeM00D0IVIV
065QH@1QHF40;Rh^04i>CP0206QXJ00506a/K01^KVh0KVi^075aL@15ADD00P0G5aL0101]KFd0Hf=S
06=SH`1GEeL205iNGP0507EeM@1JFUX08B4Q024Q8@1]KFd00P1^KVh01@1[Jf/0NWYj07YjNP1kNg/0
DU9B0080<30`00D0A4A403Lg=`0g=cL0;Rh^02`/;00203Hf=P0403/k>`1RHV80HV9R09jNWP80V9RH
00D0Ti>C08F5Q@2@T900T92@04E5A@0206YZJP0509jNWP2TY:@0Y:BT0;6a/@2e]KD00P2ZZZX0101Q
HF40/k>c0;>c/`2l_;`20;Jf]P050;bl_02^[Zh0CTi>04i>CP1UIFD00P2PX:001@2SXj<0XZ:R0:RX
Z02XZ:P0SXj>0080Shn?00D0_[jn0;Zj^P2j^[X0]KFe0;Rh^0020;Ng]`0405aLG02=SHd0SHf=0:j^
[P80[:b/00D0[Zj^0;2`/026QXH0QXJ607moO`020:FUY@050:JVYP2HV9P0YJFU0:FUY@2g]kL00P1U
IFD0102NWYh0YZJV0:JVYP2ZZZ[A0?ooo`002@3oool0100l?3`0@4100410@016ATH203dm?@0503Ti
>@0h>3P0>3Ph02TY:@0T92@00`0_;bl2020P800502PX:00V9RH08R8R028R8P0N7Qh00P0X:2P01@0S
8b<0:2PX02PX:00Y:BT0;Bd]0080<S8b00@0;Bd]03dm?@0m?Cd0CTi>0P0d=3@01@0Y:BT07AdM01DE
5@0E5AD07alO0080?Cdm00D0?Shn03Xj>P0j>SX0=CDe03Lg=`0204U9B@05038b<P0h>3P0>3Ph03hn
?P0i>CT00P0g=cL0100d=3@0;Bd]02d];@0S8b<204I6AP0504U9B@1>CTh0CTi>04i>CP1GEeL00P1M
GEd01@1VIVH0HF5Q065QH@0^;Rh0CTi>0080J6QX00D0K6a/06i^KP1^KVh0LG5a04E5A@0201LG5`04
06e]K@1SHf<0Hf=S05MGE`80GUiN00D0MGEe05YJFP0Q8B408B4Q06e]K@0206i^KP0506][J`1jNWX0
NWYj07]kN`1BDU800P0`<3001@14A4@0=cLg03Lg=`0^;Rh0;2`/0080=SHf00@0>c/k069RHP1RHV80
WYjN0P2HV9P01@2CTi<0QHF5092@T02@T900ADE50080JVYZ00D0WYjN0:BTY02TY:@0/K6a0;Fe]@02
0:ZZZP04065QH@2c/k<0/k>c0;bl_080][Jf00D0_;bl0:j^[P1>CTh0CTi>06EUI@020:2PX0050:>S
X`2RXZ80Z:RX0:RXZ02>SXh00P2?Shl01@2n_[h0^[Zj0;Zj^P2e]KD0^;Rh0080]kNg00@0G5aL08f=
S@2=SHd0[Zj^0P2/[:`01@2^[Zh0/;2`08J6QP26QXH0Ogmo0080YJFU00D0YZJV09RHV02UYJD0YJFU
0;Ng]`0206EUI@0409jNWP2VYZH0YZJV0:ZZZQD0oooo0`000?l50?n00:D0003o3`3oool000T0oooo
0`2UYJD0102[Zj/0Z:RX0:RXZ01OGel207moO`05092@T028R8P0X:2P0:2PX02TY:@00P2XZ:P01@2/
[:`0Xj>S0:JVYP2VYZH0Y:BT0080W9bL00D0U9BD08Z:RP2:RXX0Jf][06IVIP020:BTY00409nOW`2R
XZ80XZ:R09jNWP80VYZJ00D0SHf=08b<S02?Shl0Shn?08J6QP0208n?S`0508b<S028R8P0R8R808:2
PP1:BTX00P1[Jf/01@1iNGT0Jf][06][J`1`L700MWIf0080N7Qh0`1gMgL307QhN00507AdM01NGUh0
AdM704M7A`0b<S800P1BDU801@1VIVH0IFEU06EUI@1UIFD0GUiN0080ATI600@0EUIF04a<C01<C4`0
ADE50`0i>CT0100_;bl08R8R028R8P0G5aL2024Q8@0502l_;`0d=3@0>3Ph03Ph>00_;bl00P0e=CD0
1@0[:b/08b<S02<S8`0Z:RX0:BTY0080:RXZ00D0:b/[02d];@0];Bd07alO028R8P0202l_;`0403De
=@0g=cL0=cLg03hn?P@0?3`l0P0];Bd0100O7al05aLG01LG5`0K6a/202HV9P05030`<00S8b<07alO
01lO7`0@41000P0T92@01@0/;2`08B4Q024Q8@0Z:RX061PH00800`<300D04A4A02LW9`0W9bL092@T
02LW9`0202h^;P04028R8P0L71`071`L03Hf=P80@d=300D0ADE504U9B@1=CDd0CDe=01TI6@0202h^
;P0504];B`19BDT0BDU904e=C@1ADE400P0];Bd01@0c<c<0DE5A055AD@1QHF40Hf=S0080KFe]00@0
M7Ad03/k>`0k>c/0@D510P1:BTX00`1<C4`0oooo0?ooo`0C0?ooofP0oh0010000?l00`3oP000003o
0000o`030?n00180003o0P3oP00T0000o`<0oh003`3oool000T0oooo0`2^[Zh0102c/k<0]KFe0;Fe
]@1HF5P209:BTP0508R8R020P800Vi^K09^KV`2][Jd00P2_[jl01@2b/[80]KFe0;6a/@2a/K40/k>c
0080/;2`0`2a/K401@1]KFd0JVYZ0:n_[`2_[jl0Zj^[0080[Jf]00D0[:b/0:RXZ02XZ:P0YJFU0:RX
Z0020:^[Z`040:j^[P2a/K40/K6a0;Ng]`80/k>c00D0]KFe05YJFP1kNg/0Ng]k08J6QP0208F5Q@05
08Z:RP2?Shl0WYjN09jNWP2PX:000P2LW9`01@2>SXh0QHF508F5Q@25QHD0Shn?0080WinO00@0Bd];
07]kN`1kNg/0[:b/0P2ZZZX01@2YZJT0YZJV08f=S@2=SHd0UYJF0080WinO00D0Ogmo07inOP1UIFD0
IFEU06e]K@02065QH@0504M7A`28R8P0R8R807moO`1bLW800`2ZZZX20:f][@04096AT@1`L700L71`
08F5Q@<0];Bd00D0/[:b0;Ng]`2g]kL0IfMW07alO0020:f][@040;>c/`2b/[80/[:b0:j^[P80/[:b
00@0/K6a0;2`/02^[Zh0[Zj^0`2ZZZX01@2[Zj/0Ti>C09>CT`1GEeL0QhN70080Vi^K00@0WinO0:2P
X02PX:00VYZJ0P2IVIT01@2NWYh0VYZJ08^;R`2;Rh/0QhN70080S8b<00D0Rh^;07moO`1VIVH0IVIV
08j>SP0208^;R`0508N7Q`1mOGd0OGem07EeM@1jNWX00P1gMgL0101YJFT0JVYZ06YZJP1_Kfl2079b
LP0506a/K01PH600ADE504E5A@1[Jf/00P1MGEd01@1EEED0DE5A05ADE01DE5@0EeMG0080J6QX00@0
K6a/06e]K@1]KFd0IVIV5@3ooomX0?n000@0003o00<0oh000000o`000?l00`3oP00B0000o`80oh00
90000?l30?n000l0oooo00090?ooo`<0[Zj^00@0/k>c0;Fe]@2e]KD0F5QH0P2BTY801@28R8P0P820
09^KV`2KVi/0[Jf]0080[jn_00D0/[:b0;Fe]@2a/K40/K6a0;>c/`020;2`/0<0/K6a00D0KFe]06YZ
JP2_[jl0[jn_0:^[Z`020:f][@050:b/[02XZ:P0Z:RX0:FUY@2XZ:P00P2[Zj/0102^[Zh0/K6a0;6a
/@2g]kL20;>c/`050;Fe]@1JFUX0Ng]k07]kN`26QXH00P25QHD01@2:RXX0Shn?09jNWP2NWYh0X:2P
0080W9bL00D0SXj>08F5Q@25QHD0QHF508n?S`0209nOW`0404];B`1kNg/0Ng]k0:b/[080ZZZZ00D0
ZJVY0:JVYP2=SHd0SHf=09JFUP0209nOW`0507moO`1nOWh0IFEU06EUI@1]KFd00P1QHF401@17AdL0
R8R808R8R01oOgl0LW9b00<0ZZZZ0P2][Jd0102ATI40L71`071`L025QHD30;Bd]0050;:b/P2g]kL0
]kNg06MWI`1lO7`00P2][Jd0102c/k<0/[:b0;:b/P2^[Zh20;:b/P040;6a/@2`/;00[Zj^0:j^[P<0
ZZZZ00D0Zj^[09>CT`2CTi<0EeMG08N7Q`0209^KV`0409nOW`2PX:00X:2P09ZJVP80VIVI00D0WYjN
09ZJVP2;Rh/0Rh^;08N7Q`0208b<S00508^;R`1oOgl0IVIV06IVIP2>SXh00P2;Rh/01@27QhL0OGem
07emO@1eMGD0NWYj0080MgMg00@0JFUY06YZJP1ZJVX0Kfm_0P1bLW801@1/K6`0H61P04E5A@15ADD0
Jf][0080GEeM00D0EEEE055AD@1DE5@0E5AD05MGE`0206QXJ00406a/K01]KFd0KFe]06IVIQD0oooo
C03oP00E0000o`@0oh000`000?m10?n000040000o`3oP000oh000?n000l0oooo00090?ooo`040:j^
[P2XZ:P0Z:RX0:b/[080/[:b00D0DU9B09fMW@2MWId0S8b<092@T0020:6QX@050:BTY02UYJD0YJFU
0:2PX02VYZH00P2WYjL0102VYZH0[:b/0:b/[02][Jd20;2`/00506m_K`1ZJVX0ZZZZ0:ZZZP2[Zj/0
0`2/[:`20:ZZZP050:BTY02VYZH0YjNW0:NWY`2XZ:P00P2/[:`01@2_[jl0][Jf0;Jf]P2c/k<0C4a<
0080Y:BT00D0W9bL09FEU@2EUID0Y:BT0:FUY@020:JVYP040:NWY`2TY:@0Y:BT09ZJVP80RHV900D0
PX:209RHV02RXZ80XZ:R04I6AP020861P@050:6QX@2_[jl0[jn_0;>c/`2ZZZX00`2FUYH209RHV005
07AdM01fMWH0N7Qh07QhN023Ph<00P22PX800`1FEUH0RXZ:08Z:RP0208b<S080[:b/00@0Zj^[0:b/
[02/[:`0U9BD0P1gMgL01@1_Kfl0/K6a0;Rh^02h^;P0][Jf0080^[Zj00<0HF5Q07UiN@2][Jd00P2]
[Jd20:RXZ0030:JVYP2WYjL0YjNW0080YjNW0P2YZJT0102UYJD0Zj^[0:^[Z`2/[:`20:NWY`0405mO
G`2:RXX0ZZZZ0:ZZZP<0[Jf]00D0[Zj^0;Fe]@2e]KD0^[Zj0;2`/0020:JVYP050:RXZ02][Jd0[Jf]
0:^[Z`2_[jl00P1WIfL0102j^[X0aLG50<G5a@34a<@20<71`@050;Jf]P32`/80YjNW0:NWY`25QHD0
0P1XJ6P01@2b/[80_[jn0;jn_P2i^KT0RXZ:0080Shn?00D0^;Rh0;>c/`2c/k<0ZZZZ0;>c/`020;Ng
]`040;bl_02m_Kd0_Kfm0;>c/`80_;bl00<0^k^k0?ooo`3oool04`3ooolZ0?n000@0003o2`3oP000
0`000?l0oh000?n0001^0?n00080003o00<0oh000?ooo`3oool03@3oool000T0oooo00<0/K6a0:j^
[P2^[Zh00`2c/k<01@1CDe<0Z:RX0:RXZ02GUiL0UIFE0080YjNW00D0Xj>S0:JVYP2VYZH0Xj>S0:ZZ
ZP020:>SX`040:FUY@2TY:@0Y:BT0:f][@80/K6a0P1WIfL20:ZZZP040:^[Z`2/[:`0[:b/0:^[Z`80
Z:RX00D0YZJV0:VYZ@2VYZH0YZJV0:FUY@030:JVYP80[Zj^00D0Zj^[04=3@`2XZ:P0Z:RX0:6QX@02
09RHV00509^KV`2SXj<0YjNW0:NWY`2VYZH00P2PX:001@2MWId0U9BD09BDU02>SXh0X:2P0080Vi^K
00@0Bd];0861P@21PH40XJ6Q0P2_[jl01@2a/K40/;2`0:b/[02/[:`0WYjN0080Vi^K00D0WinO09BD
U02PX:00X:2P0:BTY00208b<S00505=CD`2<S8`0S8b<096AT@2DU9@00P2YZJT0102XZ:P0[jn_0:n_
[`2?Shl207MgM`0508F5Q@2b/[80]KFe0;Fe]@2c/k<00P2i^KT01@1LG5`0MWIf0:VYZ@2YZJT0Z:RX
0080YJFU00D0Y:BT0:VYZ@2YZJT0ZJVY0:RXZ0020:NWY`040:ZZZP2][Jd0[Jf]0:f][@80Y:BT00D0
EeMG08Z:RP2YZJT0ZJVY0:^[Z`020:VYZ@050:ZZZP2b/[80/[:b0;Jf]P2b/[800P2UYJD01@2`/;00
];Bd0;Bd]02b/[80/k>c0080BTY:00@0YJFU0<C4a034a<@0aLG50P37alL01@2i^KT0^k^k0820P020
P800De=C0080@41000D0YjNW0;jn_P2n_[h0_Kfm08^;R`0208Z:RP050;Vi^@2g]kL0]kNg0:b/[02f
][H00P2j^[X30;bl_0040;fm_@31`L40`L710;jn_QD0oooo30000?l80?n000/0003o2`3oP00?0000
oe@0oh0030000?l@0?n000@0003o3`3oool000T0oooo00@0ZJVY0:b/[02/[:`0Y:BT0P2FUYH0101B
DU80P8200820P024Q8@308N7Q`0508b<S02@T900T92@096AT@2HV9P00P2BTY80102=SHd0VYZJ09ZJ
VP2OWil20:6QX@0506UYJ@1JFUX0R8R808R8R02;Rh/00P2JVYX01@2NWYh0S8b<08b<S02CTi<0SHf=
0080U9BD00@0SHf=08j>SP2>SXh0Shn?0P2KVi/01@2DU9@0ATI60:RXZ02XZ:P0YjNW0080VIVI00<0
X:2P09fMW@2QXJ400P2QXJ4209RHV00509ZJVP2BTY80TY:B08^;R`2GUiL00P2KVi/01015ADD0NGUi
07UiN@2UYJD209nOW`0509fMW@2a/K40/k>c0;>c/`2][Jd00P2[Zj/01@2YZJT0[:b/0:ZZZP2ZZZX0
Zj^[0080QhN700D0D51@08R8R028R8P0Vi^K09nOW`020:ZZZP040:^[Z`2c/k<0/k>c09ZJVP80OWin
00D0PH610;Jf]P2i^KT0^KVi0;Zj^P020;Vi^@05065QH@1oOgl0[jn_0:n_[`2/[:`00P2SXj<01@2R
XZ80WinO09nOW`2OWil0Xj>S0080YZJV00@0YjNW0:b/[02/[:`0YZJV0P2RXZ801@1ZJVX0UYJF0:RX
Z02XZ:P0YZJV0080XJ6Q00D0WinO0:FUY@2UYJD0[Zj^0;2`/00209fMW@050:2PX02/[:`0[:b/0:f]
[@2[Zj/00P10@400102HV9P0_kno0;no_`2n_[h20;:b/P050:ZZZP2TY:@0HF5Q065QH@0g=cL00P14
A4@01@2MWId0/[:b0;:b/P2`/;00LG5a0080Rh^;00D0^[Zj0;Fe]@2e]KD0[Jf]0;Jf]P020;Zj^P04
0;no_`2m_Kd0_Kfm0;Zj^P80_;bl00<0_Kfm0?ooo`3oool04`3oool<0000o`P0oh002`000?l;0?n0
00l0003oE03oP00<0000oa00oh0010000?l?0?ooo`002@3oool0102YZJT0[:b/0:b/[02TY:@209JF
UP04059BDP20P800P82008B4Q0<0QhN700D0S8b<092@T02@T900TI6A09RHV00209:BTP0408f=S@2J
VYX0VYZJ09nOW`80XJ6Q00D0JFUY05YJFP28R8P0R8R808^;R`0209ZJVP0509jNWP2<S8`0S8b<09>C
T`2=SHd00P2DU9@0102=SHd0SXj>08j>SP2?Shl209^KV`0509BDU016ATH0Z:RX0:RXZ02WYjL00P2I
VIT00`2PX:00WIfM0:6QX@020:6QX@80V9RH00D0VYZJ09:BTP2BTY80Rh^;09NGU`0209^KV`0404E5
A@1iNGT0NGUi0:FUY@80WinO00D0WIfM0;6a/@2c/k<0/k>c0:f][@020:^[Z`050:VYZ@2/[:`0ZZZZ
0:ZZZP2[Zj/00P27QhL01@1@D500R8R808R8R02KVi/0WinO0080ZZZZ00@0Zj^[0;>c/`2c/k<0VYZJ
0P1nOWh01@21PH40][Jf0;Vi^@2i^KT0^[Zj0080^KVi00D0HF5Q07moO`2_[jl0[jn_0:b/[0020:>S
X`050::RXP2OWil0WinO09nOW`2SXj<00P2VYZH0102WYjL0[:b/0:b/[02VYZH20::RXP0506YZJP2F
UYH0Z:RX0:RXZ02VYZH00P2QXJ401@2OWil0YJFU0:FUY@2^[Zh0/;2`0080WIfM00D0X:2P0:b/[02/
[:`0[Jf]0:^[Z`020410@00409RHV02o_kl0_kno0;jn_P80/[:b00D0ZZZZ0:BTY01QHF40HF5Q03Lg
=`0204A4A00509fMW@2b/[80/[:b0;2`/01aLG400P2;Rh/01@2j^[X0]KFe0;Fe]@2][Jd0][Jf0080
^[Zj00@0_kno0;fm_@2m_Kd0^[Zj0P2l_;`00`2m_Kd0oooo0?ooo`0C0?ooobh0003o00<0oh000000
o`000?l05`000?l40?n00300003o<03oP0000`000?l0oooo0?ooo`0=0?ooo`002@3oool0102JVYX0
UiNG09NGU`2CTi<208n?S`0508f=S@27QhL0QhN707emO@1hN7P00P1iNGT01@1XJ6P0=CDe03De=@1V
IVH0J6QX0080MGEe00@0OWin07UiN@1iNGT0NWYj0P1gMgL01@1lO7`0IFEU07UiN@1iNGT0OWin0080
LG5a00D0F5QH03lo?`0o?cl0E5AD07=cL`0207IfMP0407=cL`1eMGD0MGEe07QhN0<0Kfm_00@0KVi^
06m_K`1_Kfl0HV9R0P1GEeL01@1DE5@0@41005iNGP1NGUh0Ogmo0080O7al00D0NGUi0861P@21PH40
PH6108N7Q`0207emO@0407IfMP1kNg/0Ng]k07alO080HV9R00D0EeMG05=CD`1>CTh0CTi>04e=C@02
04a<C080DE5A0P1EEED0101KFe/0CDe=04e=C@14A4@204a<C080H61P0P1YJFT0101NGUh0F5QH05QH
F016ATH204U9B@0505EEE@1XJ6P0N7Qh07QhN01eMGD00P1hN7P01@1@D500CTi>07QhN01hN7P0NGUi
0080JFUY00D0IfMW06EUI@1UIFD0NWYj07alO00208:2PP0408R8R01]KFd0KFe]07=cL`80PX:200D0
BDU907YjNP2<S8`0S8b<08F5Q@0207EeM@0508B4Q02?Shl0Shn?09RHV02MWId00P2LW9`01@2=SHd0
UiNG09NGU`2MWId0WinO0080>3Ph00@0Q8B40:JVYP2VYZH0Vi^K0P1nOWh01@20P800NGUi05EEE@1E
EED0BTY:0080Jf][00D0NGUi08b<S02<S8`0UYJF07=cL`0208f=S@050:n_[`2b/[80/[:b0:b/[02c
/k<00`2k^k/20;Vi^@040;Rh^02m_Kd0_Kfm0;Bd]1D0oooo00D0003o0?n0003oP000oh000000o`07
0?n000l0003o00<0oh000000o`000?l00P000?l20?n008/0003o3`3oool000T0oooo00<0^k^k0;Ng
]`2g]kL00`2j^[X01@2g]kL0]KFe0;Fe]@2b/[80[jn_0080ZJVY00D0[:b/04i>CP1>CTh0W9bL0:6Q
X@0209nOW`040:>SX`2UYJD0YJFU0:^[Z`80Z:RX00D0[Jf]0;6a/@2d];@0];Bd0;>c/`020:b/[005
0:6QX@1PH600H61P0:6QX@2_[jl00P2^[Zh00`2][Jd0]KFe0;Fe]@030;Bd]0050;^k^`2i^KT0_;bl
0;bl_02o_kl00P30`<001@2j^[X0IFEU0:f][@2][Jd0[jn_0080ZJVY0`2VYZH00`2UYJD0ZZZZ0:f]
[@020:f][@80[Zj^00D0/K6a0;>c/`2c/k<0/k>c06][J`0208j>SP050;:b/P2`/;00/;2`0:NWY`2T
Y:@00P2d];@0102g]kL0];Bd0;Bd]02h^;P20;Jf]P050;6a/@2_[jl0YJFU0:FUY@1WIfL00P29RHT0
1@2GUiL0W9bL09bLW02JVYX0UiNG0080UYJF00D0UIFE09JFUP2FUYH0WYjN0:RXZ0020:VYZ@0409ZJ
VP23Ph<0Ph>305YJFP80Ng]k00D0Ph>307MgM`1dM7@0M7Ad075aL@0207UiN@<0OWin00D0R8R807Qh
N01YJFT0JFUY06EUI@0203lo?`0304U9B@1UIFD0IFEU0080JVYZ0P1JFUX01@1KFe/0HV9R069RHP1Q
HF40GemO0080I6AT00@0GemO06a/K01/K6`0JVYZ0P14A4@01@1QHF40J6QX069RHP1RHV80I6AT0080
IFEU00D0G5aL05mOG`1OGel0Fe]K05MGE`0204];B`0503Ti>@0k>c/0>c/k03/k>`0j>SX00P0n?Sh0
101<C4`0AdM704M7A`1?Cdl204Y:BP0304];B`3oool0oooo01<0oooo0`000?l40?n000L0003o00<0
oh000000o`000?l02`000?l40?n000X0003o303oP00;0000ocX0oh004`000?l00`3oP000003o0000
o`0L0000o`l0oooo00090?ooo`030;^k^`2g]kL0]kNg00<0^[Zj00D0]kNg0;Fe]@2e]KD0/[:b0:n_
[`020:VYZ@050:b/[01>CTh0CTi>09bLW02QXJ400P2OWil0102SXj<0YJFU0:FUY@2[Zj/20:RXZ005
0:f][@2a/K40];Bd0;Bd]02c/k<00P2/[:`01@2QXJ40H61P061PH02QXJ40[jn_0080[Zj^00<0[Jf]
0;Fe]@2e]KD00`2d];@01@2k^k/0^KVi0;bl_02l_;`0_kno0080`<3000D0^[Zj06EUI@2][Jd0[Jf]
0:n_[`020:VYZ@<0YZJV00<0YJFU0:ZZZP2][Jd00P2][Jd20:j^[P050;6a/@2c/k<0/k>c0;>c/`1[
Jf/00P2>SXh01@2b/[80/;2`0;2`/02WYjL0Y:BT0080];Bd00@0]kNg0;Bd]02d];@0^;Rh0P2f][H0
1@2a/K40[jn_0:FUY@2UYJD0IfMW0080RHV900D0UiNG09bLW02LW9`0VYZJ09NGU`0209JFUP0509FE
U@2FUYH0UYJF09jNWP2XZ:P00P2YZJT0102JVYX0Ph>308>3P`1JFUX207]kN`0508>3P`1gMgL0M7Ad
07AdM01aLG400P1iNGT307inOP0508R8R01hN7P0JFUY06UYJ@1UIFD00P0o?cl00`19BDT0IFEU06EU
I@0206YZJP80FUYJ00D0Fe]K069RHP1RHV80HF5Q05mOG`0206ATI00405mOG`1/K6`0K6a/06YZJP80
A4A400D0HF5Q06QXJ01RHV80HV9R06ATI00206EUI@0505aLG01OGel0GemO05]KF`1GEeL00P1;Bd/0
1@0i>CT0>c/k03/k>`0k>c/0>SXj0080?Shn00@0C4a<04M7A`17AdL0Cdm?0P1:BTX00`1;Bd/0oooo
0?ooo`0C0?ooo`<0003o103oP0070000o`030?n000000?l0003o00/0003o103oP00:0000o``0oh00
2`000?lj0?n001<0003o00<0oh000000o`000?l070000?l?0?ooo`002@3oool0102g]kL0/;2`0;2`
/02c/k<20;2`/0050:n_[`2/[:`0[:b/0:VYZ@2/[:`00P2[Zj/0102/[:`0D51@051@D02RXZ830:FU
Y@0409fMW@2HV9P0V9RH092@T080WIfM00D0Z:RX0:ZZZP2_[jl0[jn_0:j^[P020:VYZ@050:NWY`1L
G5`0G5aL0:BTY02[Zj/00P2/[:`00`2YZJT0Zj^[0:^[Z`030:VYZ@050:NWY`2YZJT0/K6a0;6a/@2g
]kL00P2k^k/01@2o_kl0MWIf0:NWY`2WYjL0[Jf]0080Y:BT00D0Vi^K09fMW@2MWId0XZ:R0:6QX@02
0:VYZ@<0[Zj^00D0[Jf]0;2`/02`/;00[Zj^07]kN`0208b<S0050:ZZZP2WYjL0YjNW0:JVYP2UYJD0
0P2/[:`00`2^[Zh0/;2`0;2`/0030;2`/0050:b/[02ZZZX0ZZZZ0:ZZZP28R8P00P2f][H01@2k^k/0
`/;20<;2`P2l_;`0^k^k0080_[jn00<0`/;20;no_`2o_kl00P31`L420<G5a@040;jn_P2e]KD0]KFe
08V9R@80^;Rh00D0^[Zj0;Rh^02d];@0];Bd0:n_[`020;Jf]P050;Ng]`2c/k<0/k>c0;>c/`2d];@0
0P2f][H0102c/k<0GemO05mOG`29RHT20;Zj^P80_;bl0P2j^[X01@2h^;P0/[:b0;:b/P2d];@0^;Rh
0080];Bd00@0^[Zj0<30`030`<00_;bl0P1YJFT01@2_[jl0]kNg0;6a/@2a/K40[:b/0080[jn_0`2d
];@01@2g]kL0];Bd0:RXZ02XZ:P0ZJVY0080[Jf]00D0UYJF06ATI02PX:00X:2P0:j^[P020;>c/`04
0:n_[`2TY:@0Y:BT0:2PX1D0ooooN03oP0060000o`P0oh004`000?lA0?n000<0003o3`3oool000T0
oooo00@0/K6a0:n_[`2_[jl0[jn_0P2ZZZX30:VYZ@050:JVYP2[Zj/0[Jf]0:f][@2_[jl00P1PH600
1@2>SXh0RHV909ZJVP2JVYX0W9bL0080XJ6Q0`2OWil01@2/[:`0[Jf]0:b/[02/[:`0Zj^[0080ZZZZ
00D0[:b/079bLP1bLW80/k>c0:ZZZP020:RXZ0040:NWY`2XZ:P0Z:RX0:ZZZP80Z:RX00D0Zj^[0:VY
Z@2][Jd0[Jf]0;Bd]0020;^k^`050;Zj^P1hN7P0/k>c0;>c/`2^[Zh00P2MWId01@2JVYX0UIFE09FE
U@2VYZH0X:2P0080Y:BT00@0XZ:R0:FUY@2UYJD0Zj^[0P2_[jl01@2][Jd0Lg=c0861P@21PH40Vi^K
0080UYJF00D0UiNG09nOW`2XZ:P0Z:RX0:NWY`020:ZZZP050:VYZ@2^[Zh0[Zj^0:^[Z`2WYjL00P2M
WId0102;Rh/0]KFe0;Fe]@2h^;P20;bl_0050;^k^`2g]kL0]KFe0;Fe]@2o_kl00P36a/H01@2m_Kd0
_kno0<O7a`37alL0`l?30080]KFe00D0NWYj0;Fe]@2e]KD0]kNg0;Rh^0020;Fe]@040;6a/@2k^k/0
^k^k0;Rh^080]KFe00D0/[:b0:^[Z`2/[:`0[:b/0:f][@0205YJFP0507emO@2h^;P0^;Rh0;bl_02j
^[X00`2i^KT40;Bd]080^;Rh00@0^KVi0;^k^`2k^k/0^KVi0P1TI6@01@2KVi/0/k>c0:b/[02/[:`0
ZJVY0080[jn_00D0/k>c0;:b/P2b/[80/;2`0:n_[`020:ZZZP050:f][@2^[Zh0[Zj^092@T01TI6@0
0P2[Zj/0102d];@0/[:b0;:b/P2c/k<20:^[Z`030;6a/@3oool0oooo01<0oooo303oP0020000odX0
oh000`000?l20?n000L0003o00<0oh000000o`000?l00P000?m30?n000030000o`3oool0oooo00d0
oooo00090?ooo`040;>c/`2a/K40/K6a0;6a/@80][Jf00D0/;2`09nOW`2OWil0XJ6Q0:>SX`030:VY
Z@80EeMG00@0QXJ609RHV02XZ:P0Z:RX0`2a/K401@2^[Zh0Z:RX0:RXZ02/[:`0/K6a0080/k>c00@0
^KVi0;Jf]P2f][H0/[:b0P1`L7001@2RXZ80Z:RX0:RXZ02XZ:P0YjNW0080ZZZZ00D0[Jf]0:ZZZP2Z
ZZX0/k>c0;2`/0020;Fe]@050;Ng]`2l_;`0_;bl0;^k^`1lO7`00P2i^KT0102e]KD0/;2`0;2`/02^
[Zh20:VYZ@050::RXP2FUYH0X:2P0:2PX02[Zj/00P2`/;001@2f][H0]KFe0;Fe]@2c/k<0Hf=S0080
NWYj00D0SXj>08^;R`2;Rh/0Shn?09BDU0020:6QX@0309VIV@2MWId0WIfM00<0XZ:R00D0Z:RX09jN
WP1lO7`0O7al0861P@020;6a/@050;Bd]02f][H0][Jf0;Ng]`2i^KT00P2j^[X30;fm_@050;Ng]`2h
^;P0_[jn0;jn_P2k^k/00P2a/K401@23Ph<0/k>c0;>c/`2a/K40][Jf0080^KVi00@0]kNg0;:b/P2b
/[80/K6a0P2][Jd01@2/[:`0Zj^[0:JVYP2VYZH0Xj>S0080EeMG00D0Rh^;0;Bd]02d];@0]kNg0;Vi
^@020;Rh^0050;Jf]P2a/K40/K6a0;>c/`2b/[800P2a/K40102g]kL0^KVi0;Vi^@2d];@205IFEP05
09BDU02_[jl0Z:RX0:RXZ02WYjL00P2][Jd01@2a/K40/;2`0;2`/02^[Zh0[Jf]0080ZZZZ00D0[:b/
0:^[Z`2[Zj/0SXj>07MgM`020:ZZZP040;Ng]`2d];@0];Bd0;>c/`80ZJVY00<0[jn_0?ooo`3oool0
4`3oool<0?n00080003oBP3oP0030000o`80oh001`000?l00`3oP000003o0000o`020000od<0oh00
00<0003o0?ooo`3oool03@3oool000T0oooo00@0/k>c0;6a/@2a/K40/K6a0P2f][H01@2`/;00WinO
09nOW`2QXJ40Xj>S00<0ZJVY0P1GEeL01026QXH0V9RH0:RXZ02XZ:P30;6a/@050:j^[P2XZ:P0Z:RX
0:b/[02a/K400P2c/k<0102i^KT0][Jf0;Jf]P2b/[82071`L0050::RXP2XZ:P0Z:RX0:RXZ02WYjL0
0P2ZZZX01@2][Jd0ZZZZ0:ZZZP2c/k<0/;2`0080]KFe00D0]kNg0;bl_02l_;`0^k^k07alO0020;Vi
^@040;Fe]@2`/;00/;2`0:j^[P80ZJVY00D0XZ:R09JFUP2PX:00X:2P0:^[Z`020;2`/0050;Jf]P2e
]KD0]KFe0;>c/`1SHf<00P1jNWX01@2>SXh0Rh^;08^;R`2?Shl0U9BD0080XJ6Q00<0VIVI09fMW@2M
WId00`2RXZ801@2XZ:P0WYjN07alO01lO7`0PH610080/K6a00D0];Bd0;Jf]P2f][H0]kNg0;Vi^@02
0;Zj^P<0_Kfm00D0]kNg0;Rh^02n_[h0_[jn0;^k^`020;6a/@0508>3P`2c/k<0/k>c0;6a/@2f][H0
0P2i^KT0102g]kL0/[:b0;:b/P2a/K420:f][@050:b/[02[Zj/0YZJV0:JVYP2SXj<00P1GEeL01@2;
Rh/0];Bd0;Bd]02g]kL0^KVi0080^;Rh00D0][Jf0;6a/@2a/K40/k>c0;:b/P020;6a/@040;Ng]`2i
^KT0^KVi0;Bd]080EUIF00D0U9BD0:n_[`2XZ:P0Z:RX0:NWY`020:f][@050;6a/@2`/;00/;2`0:j^
[P2][Jd00P2ZZZX01@2/[:`0Zj^[0:^[Z`2>SXh0MgMg0080ZZZZ00@0]kNg0;Bd]02d];@0/k>c0P2Y
ZJT00`2_[jl0oooo0?ooo`0C0?oooeL0003oE@3oP0000`000?l0oooo0?ooo`0=0?ooo`002@3oool0
101VIVH0GEeM05eMG@18B4P203Ti>@05034a<@0f=SH0=SHf03@d=00a<C400P11@D401@0l?3`0=3@d
03@d=00b<S80@4100080>c/k00@0?3`l03Ti>@0i>CT0@T920P0m?Cd01@0`<300=SHf03`l?00l?3`0
?Shn0080>c/k00D0>SXj02HV9P0V9RH0?Shn04a<C00204];B`0404e=C@0m?Cd0?Cdm03/k>`80=3@d
00D0=CDe02XZ:P0j>SX0>SXj04=3@`0204I6AP0503Xj>P0k>c/0FEUI05UIF@1NGUh00P1QHF401@1F
EUH0H61P061PH01QHF40H61P0080GEeM00@0HF5Q06YZJP1ZJVX0MGEe0P1cLg<01@1[Jf/0=3@d04i>
CP1>CTh0Fe]K0080G5aL00D0IVIV069RHP1SHf<0Hf=S06ATI00206][J`0506a/K01^KVh0KVi^06i^
KP1WIfL00P1UIFD01018B4P0Ng]k07]kN`20P8020861P@0507alO01/K6`0IVIV06IVIP1`L7000P21
PH401@25QHD0RXZ:092@T02@T900Shn?0080IFEU00D0HF5Q08j>SP2>SXh0Ogmo0:>SX`020:6QX@04
0:BTY02NWYh0WYjN0:2PX080W9bL00D0UiNG09RHV02KVi/0Vi^K09:BTP0204i>CP0508F5Q@2a/K40
/K6a0;>c/`2h^;P00P2f][H00`2d];@0[jn_0:n_[`020:j^[P80/k>c00@0/[:b0;>c/`2c/k<0[Jf]
0P1:BTX00`2NWYh0/;2`0:j^[P020:j^[P80/;2`00D0/K6a0;:b/P2b/[80/[:b0:^[Z`0209nOW`05
0:ZZZP2`/;00/;2`08b<S01gMgL00P2RXZ800`2TY:@0/K6a0;6a/@030:VYZ@030;6a/@3oool0oooo
01<0oooo[@000?l?0?ooo`002@3oool0102g]kL0][Jf0;Jf]P2[Zj/2079bLP0407UiN@2^[Zh0[Zj^
0:n_[`@0/k>c0P2d];@01@2l_;`0^;Rh0;Bd]02d];@0[Jf]0080[:b/00D0ZJVY09>CT`2CTi<0DU9B
0;>c/`020;Jf]P040;Ng]`2c/k<0/k>c0;:b/P80ZZZZ00D0YJFU09fMW@2DU9@0U9BD08b<S00208f=
S@05096AT@27QhL0QhN704U9B@2NWYh00P2/[:`0102][Jd0Y:BT0:BTY02TY:@30:NWY`040:JVYP2P
X:00X:2P09^KV`80UiNG00D0TI6A08>3P`1?Cdl0Cdm?07emO@020861P@0508:2PP20P800P82007in
OP1gMgL00P1/K6`00`1XJ6P0IFEU06EUI@0206UYJ@80MWIf00@0L71`03Hf=P0f=SH0DU9B0P1OGel0
1@1IFET0GUiN06EUI@1UIFD0KVi^0080K6a/00D0IfMW069RHP1RHV80Fe]K05eMG@0205IFEP0303dm
?@0_;bl0;bl_0080BTY:0P1?Cdl0101:BTX0BDU904U9B@0n?Sh202l_;`0504I6AP0o?cl0@4100410
@00k>c/00P0e=CD01@1<C4`0DU9B059BDP1ADE40EEEE0080B4Q800@0BDU905=CD`1CDe<0E5AD0P14
A4@01@11@D40B4Q803/k>`0k>c/0;2`/0080;Rh^00D0=cLg03Xj>P13@d<0@d=304M7A`0204e=C@05
03Lg=`0];Bd0;Bd]0451@@1>CTh00P1;Bd/0101@D500E5AD05ADE01JFUX205iNGP05069RHP1VIVH0
K6a/06a/K01ZJVX00P1XJ6P01@1BDU80=CDe05=CD`1CDe<0GEeM0080JVYZ00@0IFEU069RHP1RHV80
MWIf5@3ooom`0?n003T0003o103oP00?0?ooo`002@3oool0102g]kL0][Jf0;Jf]P2[Zj/2079bLP04
07UiN@2^[Zh0[Zj^0:n_[`@0/k>c0P2d];@01@2l_;`0^;Rh0;Bd]02d];@0[Jf]0080[:b/00D0ZJVY
09>CT`2CTi<0DU9B0;>c/`020;Jf]P040;Ng]`2c/k<0/k>c0;:b/P80ZZZZ00D0YJFU09fMW@2DU9@0
U9BD08b<S00208f=S@05096AT@27QhL0QhN704U9B@2NWYh00P2/[:`0102][Jd0Y:BT0:BTY02TY:@3
0:NWY`040:JVYP2PX:00X:2P09^KV`80UiNG00D0TI6A08>3P`1?Cdl0Cdm?07emO@020861P@0508:2
PP20P800P82007inOP1gMgL00P1/K6`00`1XJ6P0IFEU06EUI@0206UYJ@80MWIf00@0L71`03Hf=P0f
=SH0DU9B0P1OGel01@1IFET0GUiN06EUI@1UIFD0KVi^0080K6a/00D0IfMW069RHP1RHV80Fe]K05eM
G@0205IFEP0303dm?@0_;bl0;bl_0080BTY:0P1?Cdl0101:BTX0BDU904U9B@0n?Sh202l_;`0504I6
AP0o?cl0@4100410@00k>c/00P0e=CD01@1<C4`0DU9B059BDP1ADE40EEEE0080B4Q800@0BDU905=C
D`1CDe<0E5AD0P14A4@01@11@D40B4Q803/k>`0k>c/0;2`/0080;Rh^00D0=cLg03Xj>P13@d<0@d=3
04M7A`0204e=C@0503Lg=`0];Bd0;Bd]0451@@1>CTh00P1;Bd/0101@D500E5AD05ADE01JFUX205iN
GP05069RHP1VIVH0K6a/06a/K01ZJVX00P1XJ6P01@1BDU80=CDe05=CD`1CDe<0GEeM0080JVYZ00@0
IFEU069RHP1RHV80MWIf5@3ooom`0?n003T0003o103oP00?0?ooo`002@3oool0102a/K40/[:b0;:b
/P2XZ:P207IfMP0408V9R@2][Jd0[Jf]0;6a/@<0]KFe00D0^KVi0;Zj^P2j^[X0^k^k0<30`0020;^k
^`040:j^[P2VYZH0YZJV0:^[Z`80[:b/00D0FUYJ0:f][@2_[jl0[jn_0;Fe]@020:NWY`050:j^[P2]
[Jd0[Jf]0:VYZ@2RXZ800P2MWId0102<S8`0T92@092@T02GUiL209^KV`04055AD@2^[Zh0/;2`0;2`
/0<0ZJVY00D0[Zj^0:n_[`2e]KD0]KFe0;Bd]0020:n_[`050:ZZZP2TY:@0Y:BT0:>SX`2QXJ400P1Z
JVX0102YZJT0^;Rh0;Rh^02k^k/20;fm_@050;jn_P2l_;`0^KVi0;Vi^@2j^[X00P2i^KT00`2e]KD0
^KVi0;bl_0020;bl_080JFUY0`2b/[800`2ZZZX0YjNW0;Bd]0040;Bd]0050;>c/`2h^;P0^;Rh0;Rh
^02d];@00P2b/[801@2EUID0EeMG05MGE`2`/;00V9RH0080/k>c00<0^k^k0;fm_@2m_Kd00`2n_[h2
0;no_`80^k^k00@0Jf][06ATI01TI6@0];Bd0P2f][H00`2h^;P0]kNg0;>c/`020;>c/`80]kNg0`2k
^k/01@31`L40_kno0;Rh^02h^;P0KFe]0080OGem00D0YJFU0:VYZ@2PX:00X:2P0;2`/0020;bl_005
0;^k^`2j^[X0^[Zj0:n_[`2[Zj/00P2JVYX0102FUYH0S8b<08b<S01>CTh2079bLP0508F5Q@1nOWh0
P8200820P01oOgl00P1bLW801@1]KFd0M7Ad07]kN`1kNg/0L71`0080N7Qh00@0PH6108B4Q024Q8@0
HV9R5@3ooomQ0?n000/0003o?03oP0000`000?l0oh000?n000020?n000l0oooo00090?ooo`<0/;2`
00@0[Jf]07MgM`1gMgL0RXZ:0`2^[Zh0102b/[80^;Rh0;Rh^02c/k<20;Bd]0050;:b/P2c/k<0];Bd
0;Bd]02][Jd00P2NWYh01@2/[:`0WYjN09jNWP1KFe/0[Zj^00<0/k>c0P2TY:@30:RXZ0050:FUY@2W
YjL0WYjN09jNWP2KVi/00P2NWYh01@2LW9`0X:2P0:2PX019BDT0[:b/0080[Zj^00D0Zj^[0:BTY02T
Y:@0X:2P0:j^[P020;Ng]`040;Fe]@2a/K40/K6a0:j^[P80ZJVY00D0WinO09jNWP1WIfL0IfMW0:n_
[`020;Jf]P030;Ng]`2k^k/0^k^k00@0^k^k00D0_;bl0;Vi^@2i^KT0]kNg0;Vi^@020;^k^`040;jn
_P1UIFD0IFEU0;>c/`80[:b/00D0ZJVY0:NWY`2[Zj/0Zj^[0;:b/P020;Bd]0<0/[:b00D0/;2`0:f]
[@2][Jd0[Jf]09bLW00207QhN0050;>c/`2JVYX0ZZZZ0:ZZZP2o_kl00P2n_[h01@2m_Kd0_;bl0;bl
_032`/80`l?30080_Kfm00@0J6QX06UYJ@1YJFT0]kNg0P2a/K401@2f][H0]KFe0;Bd]02d];@0][Jf
0080^KVi00<0]KFe0;bl_02l_;`00P2n_[h20;Rh^00508:2PP2>SXh0SXj>0:n_[`2/[:`00P2XZ:P0
102c/k<0^[Zj0;Zj^P2j^[X20;no_`050;Rh^02l_;`0^KVi0;Vi^@2g]kL00P2`/;000`1FEUH0Xj>S
0:>SX`020;jn_P80`<3000D0_Kfm0;^k^`2k^k/0^;Rh0;^k^`020;fm_@040<30`032`/80`/;20<71
`@80_;bl00<0U9BD0?ooo`3oool04`3oooli0?n000D0003oJ`3oP00010000?l0oh000?n0003oP00?
0?ooo`002@3oool30;2`/0040:f][@1gMgL0MgMg08Z:RP<0[Zj^00@0/[:b0;Rh^02h^;P0/k>c0P2d
];@01@2b/[80/k>c0;Bd]02d];@0[Jf]0080WYjN00D0[:b/09jNWP2NWYh0Fe]K0:j^[P030;>c/`80
Y:BT0`2XZ:P01@2UYJD0YjNW09jNWP2NWYh0Vi^K0080WYjN00D0W9bL0:2PX02PX:00BDU90:b/[002
0:j^[P050:^[Z`2TY:@0Y:BT0:2PX02^[Zh00P2g]kL0102e]KD0/K6a0;6a/@2^[Zh20:VYZ@0509nO
W`2NWYh0IfMW06MWI`2_[jl00P2f][H00`2g]kL0^k^k0;^k^`040;^k^`050;bl_02i^KT0^KVi0;Ng
]`2i^KT00P2k^k/0102n_[h0IFEU06EUI@2c/k<20:b/[0050:VYZ@2WYjL0Zj^[0:^[Z`2b/[800P2d
];@30;:b/P050;2`/02][Jd0[Jf]0:f][@2LW9`00P1hN7P01@2c/k<0VYZJ0:ZZZP2ZZZX0_kno0080
_[jn00D0_Kfm0;bl_02l_;`0`/;20<?3``020;fm_@0406QXJ01YJFT0JFUY0;Ng]`80/K6a00D0][Jf
0;Fe]@2d];@0];Bd0;Jf]P020;Vi^@030;Fe]@2l_;`0_;bl0080_[jn0P2h^;P01@22PX80SXj>08j>
SP2_[jl0[:b/0080Z:RX00@0/k>c0;Zj^P2j^[X0^[Zj0P2o_kl01@2h^;P0_;bl0;Vi^@2i^KT0]kNg
0080/;2`00<0EUIF0:>SX`2SXj<00P2n_[h20<30`0050;fm_@2k^k/0^k^k0;Rh^02k^k/00P2m_Kd0
1030`<00`/;20<;2`P31`L420;bl_00309BDU03oool0oooo01<0oooo>P000?mK0?n000@0003o4@3o
P0030000o`l0oooo00090?ooo`040:j^[P2_[jl0[jn_0:VYZ@80JFUY00D0Ph>30;2`/02`/;00ZJVY
0:f][@020;Fe]@050:RXZ02ZZZX0ZZZZ0:FUY@2YZJT00`2/[:`209VIV@050:FUY@2QXJ40XJ6Q069R
HP2e]KD00`2d];@20:n_[`050:b/[02WYjL0YjNW0:RXZ02YZJT00P2UYJD309nOW`0509^KV`2SXj<0
Xj>S0492@P2PX:000P2b/[801@2TY:@0YZJV0:JVYP2YZJT0[:b/0080]KFe00@0[Zj^0:f][@2][Jd0
[:b/0P2YZJT01@2VYZH0WYjN05mOG`1OGel0[jn_0080];Bd00@0/k>c0;Fe]@2e]KD0]kNg0`2f][H3
0;^k^`050;Jf]P2c/k<0/[:b0;:b/P2UYJD00P1RHV801@2b/[80ZZZZ0:ZZZP2HV9P0XJ6Q0080[Zj^
00@0]kNg0;bl_02l_;`0]kNg0P2c/k<01@2a/K40[Zj^0:j^[P2^[Zh0UYJF0080LW9b00D0[Zj^0:RX
Z02][Jd0[Jf]0;6a/@020;Rh^0050;Jf]P2k^k/0^k^k0;fm_@2j^[X00P2g]kL0101eMGD0IFEU06EU
I@2c/k<20;:b/P050;Jf]P2c/k<0/k>c0;>c/`2d];@00P2g]kL30;Rh^0050;jn_P2m_Kd0^KVi0;Vi
^@1dM7@00P2;Rh/01@2][Jd0Zj^[09^KV`2KVi/0[jn_0080]kNg00D0^k^k0;Ng]`2g]kL0/[:b0;>c
/`020;Bd]0040;Zj^P2a/K40/K6a04M7A`80/;2`00D0`l?30<G5a@33`l<0`l?30;^k^`020;Ng]`05
0;:b/P2g]kL0^k^k0;^k^`2n_[h00P33`l<01030`<00^KVi0;Vi^@2?ShlE0?ooocX0003oF`3oP004
0000oa40oh000`000?l?0?ooo`002@3oool01028R8P0OWin07inOP1[Jf/204Q8B00505mOG`1kNg/0
Ng]k07UiN@21PH400P26QXH01@1nOWh0MWIf07IfMP1hN7P0Lg=c0080KVi^00@0LG5a06YZJP1ZJVX0
IVIV0P1TI6@01@19BDT0R8R808B4Q024Q8@0R8R80080P82000D0HV9R06EUI@1UIFD0IVIV06][J`02
06e]K@0405]KF`1OGel0GemO05=CD`80EeMG00D08b<S0410@01UIFD0IFEU079bLP0207MgM`0507in
OP2BTY80TI6A096AT@29RHT00P1fMWH01@21PH40OGem07emO@24Q8@0P8200080>c/k00<0T92@09jN
WP2NWYh00`2[Zj/01@2<S8`0UYJF0:6QX@2QXJ40][Jf0080XZ:R00D0V9RH0;Bd]02e]KD0]KFe0:JV
YP0206m_K`050;:b/P2VYZH0YZJV08V9R@2OWil00P2/[:`0102`/;00];Bd0;Bd]02b/[820;Fe]@05
0;2`/02e]KD0/[:b0;:b/P2=SHd00P1IFET01@2IVIT0[Jf]0;:b/P2b/[80/k>c0080];Bd00D0][Jf
0;6a/@2a/K40];Bd0;:b/P020:^[Z`04075aL@1cLg<0Lg=c0;Bd]080/;2`00<0Zj^[0:f][@2`/;00
0P2`/;020;>c/`050;Fe]@2g]kL0]kNg0;Vi^@2f][H00P2d];@00`1[Jf/0SHf=08f=S@020:VYZ@80
X:2P00@0[Jf]0;Ng]`2g]kL0^;Rh0P2g]kL01@2^[Zh0/K6a0;Bd]02d];@0^;Rh0080[jn_00D0AdM7
0:f][@2][Jd0_kno0;jn_P020;bl_0050;Ng]`2e]KD0]KFe0:RXZ02c/k<00P2h^;P0102m_Kd0^k^k
0;^k^`2l_;`20:RXZ0030861P@3oool0oooo01<0ooooT@000?l60?n00080003o4@3oP0030000o`l0
oooo00090?ooo`040:BTY02IVIT0VIVI08f=S@<0T92@0P28R8P01@25QHD0Q8B408B4Q024Q8@0EeMG
0080I6AT00D0L71`075aL@1cLg<0Lg=c07QhN00207UiN@0506i^KP1_Kfl0Kfm_07emO@1gMgL00P1k
Ng/01020P800NGUi07UiN@1EEED20492@P0506EUI@1^KVh0K6a/06a/K01bLW800P1aLG400`1cLg<0
LG5a075aL@0206a/K080NWYj00D0MGEe06EUI@1UIFD0Fe]K030`<00205=CD`0405EEE@1GEeL0EeMG
05QHF080EUIF00D0G5aL05YJFP1TI6@0I6AT05ADE00205QHF00505]KF`1GEeL0EeMG03hn?P0T92@0
0P11@D401@18B4P0@T920492@P12@T80?3`l0080?clo00@0CDe=04I6AP16ATH0B4Q80P0h>3P01@12
@T80Cdm?03<c<`0c<c<0?Cdm0080D51@00D0ADE505MGE`1GEeL0EeMG04E5A@0204m?C`05051@D00_
;bl0;bl_03/k>`15ADD00P1CDe<00`1FEUH0C4a<04a<C00404i>CP0405MGE`1SHf<0Hf=S04=3@`80
=SHf0`19BDT01@1BDU80EEEE05]KF`1KFe/0EeMG0080FUYJ00D0GUiN06=SH`1SHf<0HV9R065QH@02
06IVIP<0<S8b00D0H61P06UYJ@1aLG40LG5a079bLP0207QhN00507emO@1lO7`0O7al07MgM`1mOGd0
0P1_Kfl0101hN7P0KVi^06i^KP0_;bl206][J`0509BDU02GUiL0U9BD09BDU02KVi/00P2HV9P01@2D
U9@0TI6A096AT@2ATI40Xj>S0080YZJV00@0[Jf]07UiN@1iNGT0HV9R5@3ooolm0?n006d0003o0`3o
P00?0?ooo`002@3oool0102TY:@0VIVI09VIV@2=SHd3092@T080R8R800D0QHF508B4Q024Q8@0Q8B4
05MGE`0206ATI005071`L01aLG40Lg=c07=cL`1hN7P00P1iNGT01@1^KVh0Kfm_06m_K`1mOGd0MgMg
0080Ng]k00@0P82007UiN@1iNGT0EEEE0P12@T801@1UIFD0KVi^06a/K01/K6`0LW9b0080LG5a00<0
Lg=c075aL@1aLG400P1/K6`207YjNP0507EeM@1UIFD0IFEU05]KF`0`<3000P1CDe<0101EEED0EeMG
05MGE`1HF5P205IFEP0505aLG01JFUX0I6AT06ATI01DE5@00P1HF5P01@1KFe/0EeMG05MGE`0n?Sh0
92@T0080@D5100D0B4Q80492@P12@T80@T9203`l?00203lo?`0404e=C@16ATH0ATI604Q8B080>3Ph
00D0@T9204m?C`0c<c<0<c<c03dm?@02051@D00504E5A@1GEeL0EeMG05MGE`15ADD00P1?Cdl01@1@
D500;bl_02l_;`0k>c/0ADE50080De=C00<0EUIF04a<C01<C4`0101>CTh0101GEeL0Hf=S06=SH`13
@d<203Hf=P<0BDU900D0DU9B05EEE@1KFe/0Fe]K05MGE`0205YJFP0505iNGP1SHf<0Hf=S069RHP1Q
HF400P1VIVH3038b<P05061PH01YJFT0LG5a075aL@1bLW800P1hN7P01@1mOGd0O7al07alO01gMgL0
OGem0080Kfm_00@0N7Qh06i^KP1^KVh0;bl_0P1[Jf/01@2DU9@0UiNG09BDU02DU9@0Vi^K0080V9RH
00D0U9BD096AT@2ATI40TI6A0:>SX`020:JVYP040:f][@1iNGT0NGUi069RHQD0oooo;`3oP00?0000
of@0oh000P000?l20?n000@0003o0`3oP00?0?ooo`002@3oool0102i^KT0]kNg0;Ng]`2h^;P50;bl
_0050;Vi^@2g]kL0]KFe0;Fe]@1^KVh00P2BTY801@2b/[80Z:RX0;Ng]`2g]kL0^;Rh0080^KVi00D0
^;Rh0;Bd]02d];@0^KVi0;Rh^0020;Ng]`<0^;Rh00@0NWYj06][J`1[Jf/0[Jf]0`2WYjL0102_[jl0
/K6a0;6a/@2h^;P20;Ng]`050;Rh^02d];@0/k>c0;>c/`2][Jd00P2ZZZX01@2CTi<0?Cdm0:>SX`2S
Xj<0/;2`0080Y:BT00D0VYZJ09:BTP2BTY80S8b<08B4Q00209BDU00409bLW02RXZ80XZ:R0:JVYP<0
Zj^[00@0DU9B09ZJVP2JVYX0Y:BT0P2SXj<01@2WYjL0ZJVY0:VYZ@2YZJT0YZJV0080/K6a00D0/[:b
0;6a/@2a/K40Zj^[0:b/[0020:n_[`0406UYJ@2VYZH0YZJV0:RXZ080Y:BT00D0YZJV0:ZZZP2[Zj/0
Zj^[0:NWY`020:b/[0050:NWY`2ZZZX0ZJVY0:VYZ@2WYjL00P26QXH01@1gMgL0YZJV0:JVYP2VYZH0
YjNW0080[:b/00@0Zj^[0::RXP2RXZ80Xj>S0P2QXJ401@2IVIT0V9RH08n?S`2?Shl0OGem0080?Cdm
00D0EEEE071`L01`L700KFe]06UYJ@0206YZJP0507IfMP1iNGT0NGUi07MgM`1jNWX00P1`L700101]
KFd0IFEU06EUI@1TI6@20410@00505mOG`1SHf<0IfMW06MWI`1VIVH00P1UIFD01@1SHf<0I6AT06AT
I01SHf<0HV9R0080I6AT00D0IfMW05=CD`1CDe<0?clo03dm?@02061PH00406=SH`1VIVH0IVIV06QX
J080IVIV00<0GEeM0?ooo`3oool04`3oool_0?n000l0003oI03oP0020000o`80oh0010000?l30?n0
00l0oooo00090?ooo`040;Rh^02g]kL0]kNg0;fm_@80_[jn00<0_kno0;bl_02l_;`00P2h^;P20;Fe
]@0506e]K@2ATI40TI6A0:f][@2JVYX00P2YZJT0102^[Zh0[:b/0:b/[02[Zj/20:f][@050:n_[`2g
]kL0]kNg0;Ng]`2a/K400P2ZZZX01@22PX80Jf][06][J`2TY:@0YJFU0080XZ:R00@0XJ6Q0:JVYP2V
YZH0Z:RX0P2YZJT01@2_[jl0[Zj^0;6a/@2a/K40[jn_0080/[:b00D0XJ6Q04U9B@2/[:`0[:b/0:n_
[`020:NWY`0509RHV02GUiL0UiNG09BDU02>SXh00P2:RXX0102<S8`0U9BD09BDU02SXj<20:j^[P04
0:NWY`11@D40Ti>C09>CT`@0WIfM00@0YJFU0:6QX@2QXJ40Y:BT0P2^[Zh01@2a/K40Zj^[0:^[Z`2]
[Jd0]KFe0080/k>c00<0NGUi0:^[Z`2[Zj/01@2WYjL30:RXZ080YjNW0P2ZZZX20:VYZ@040:ZZZP23
Ph<0Ph>30861P@<0/;2`00@0[Zj^0;>c/`2c/k<0];Bd0P2b/[801@2`/;00/[:b0;:b/P2d];@0ZZZZ
0080Zj^[00@0ZJVY05mOG`1OGel0P8200P2PX:001@2ZZZX0/[:b0;2`/02`/;00[Zj^0080ZZZZ00D0
[Jf]0:NWY`2TY:@0Y:BT0:RXZ0020:f][@050:RXZ01QHF40HF5Q0:JVYP2^[Zh00P2_[jl0102`/;00
/K6a0;6a/@2d];@20;>c/`050;6a/@2^[Zh0ZJVY0:VYZ@2ZZZX00P2DU9@01@1mOGd0IFEU09FEU@2E
UID0XJ6Q0080[:b/0`2f][H00`2d];@0oooo0?ooo`0C0?ooo`D0003oU03oP0040000o`T0oh001`00
0?l?0?ooo`002@3oool0102h^;P0]kNg0;Ng]`2m_Kd20;jn_P030;no_`2l_;`0_;bl0080^;Rh0P2e
]KD01@1]KFd0TI6A096AT@2][Jd0VYZJ0080ZJVY00@0[Zj^0:b/[02/[:`0Zj^[0P2][Jd01@2_[jl0
]kNg0;Ng]`2g]kL0/K6a0080ZZZZ00D0PX:206][J`1[Jf/0Y:BT0:FUY@020::RXP040:6QX@2VYZH0
YZJV0:RXZ080ZJVY00D0[jn_0:j^[P2a/K40/K6a0:n_[`020;:b/P050:6QX@19BDT0[:b/0:b/[02_
[jl00P2WYjL01@2HV9P0UiNG09NGU`2DU9@0SXj>0080RXZ:00@0S8b<09BDU02DU9@0Xj>S0P2^[Zh0
102WYjL0@D5109>CT`2CTi<409fMW@040:FUY@2QXJ40XJ6Q0:BTY080[Zj^00D0/K6a0:^[Z`2[Zj/0
[Jf]0;Fe]@020;>c/`0307UiN@2[Zj/0Zj^[00D0YjNW0`2XZ:P20:NWY`80ZZZZ0P2YZJT0102ZZZX0
Ph>308>3P`21PH430;2`/0040:j^[P2c/k<0/k>c0;Bd]080/[:b00D0/;2`0;:b/P2b/[80];Bd0:ZZ
ZP020:^[Z`040:VYZ@1OGel0GemO0820P080X:2P00D0ZZZZ0;:b/P2`/;00/;2`0:j^[P020:ZZZP05
0:f][@2WYjL0Y:BT0:BTY02XZ:P00P2][Jd01@2XZ:P0HF5Q065QH@2VYZH0[Zj^0080[jn_00@0/;2`
0;6a/@2a/K40];Bd0P2c/k<01@2a/K40[Zj^0:VYZ@2YZJT0ZZZZ0080U9BD00D0OGem06EUI@2EUID0
UIFE0:6QX@020:b/[0<0][Jf00<0];Bd0?ooo`3oool04`3ooomh0?n000@0003o203oP0030000ob<0
oh000`000?l?0?ooo`002@3oool0102g]kL0]KFe0;Fe]@2g]kL20;Rh^0<0]KFe00D0];Bd0;Ng]`2`
/;00/;2`06UYJ@0208Z:RP030:VYZ@2HV9P0ZJVY0080ZJVY0P2^[Zh0102VYZH0ZJVY0:VYZ@2[Zj/3
0:j^[P040:n_[`2[Zj/0Zj^[07emO@80IFEU00D0VYZJ09:BTP2OWil0WinO0::RXP020:FUY@<0YjNW
00D0ZJVY0:NWY`2^[Zh0[Zj^0:f][@020;6a/@050:j^[P18B4P0YJFU0:FUY@2XZ:P00P2KVi/01@2A
TI40U9BD09BDU023Ph<0Q8B40080PX:20`25QHD01@2HV9P0Z:RX0:RXZ02FUYH0?clo0080SXj>00@0
UYJF09NGU`2GUiL0VYZJ0`2LW9`0102KVi/0[Jf]0:f][@2/[:`30:ZZZP040;>c/`2a/K40/K6a06m_
K`80YjNW00D0WinO0:2PX02PX:00WinO0:FUY@0209nOW`050:6QX@2SXj<0Xj>S0:FUY@2TY:@00P2U
YJD0102WYjL0PX:208:2PP2;Rh/20:b/[080[Jf]0P2ZZZX0102XZ:P0YZJV0:JVYP2/[:`20:^[Z`05
0;2`/02[Zj/0[Jf]0:f][@2WYjL00P1>CTh01@1fMWH0WYjN09jNWP2/[:`0ZJVY0080Zj^[00<0ZZZZ
0:NWY`2WYjL00P2SXj<209bLW0040::RXP2OWil0WinO0:VYZ@80G5aL00D0WYjN0:b/[02XZ:P0Z:RX
0:ZZZP020:VYZ@050:b/[02^[Zh0[Zj^0;>c/`2_[jl00P2XZ:P30:NWY`0309^KV`1WIfL0UIFE0080
UIFE0P2WYjL0102ZZZX0[jn_0:n_[`2^[ZhE0?ooog<0003o>P3oP00?0?ooo`002@3oool01027QhL0
PX:208:2PP1mOGd207]kN`0507emO@24Q8@0Q8B408f=S@2:RXX00P2<S8`01@1JFUX0O7al07alO02@
T900LW9b0080TY:B00@0U9BD09bLW02LW9`0W9bL0P2KVi/01@2PX:00XJ6Q0:VYZ@2YZJT0Z:RX0080
YZJV00D0MgMg04m?C`1?Cdl0S8b<09:BTP0209RHV0040:2PX02QXJ40XJ6Q0:2PX080Y:BT00D0VYZJ
0:b/[02b/[80/[:b0:j^[P020:b/[0050;2`/01<C4`0YjNW0:NWY`2PX:000P2?Shl01@2<S8`0TI6A
096AT@23Ph<0PX:20080Ng]k00@0P82007moO`1oOgl0Q8B40P2DU9@01@2>SXh0EeMG08^;R`2;Rh/0
SXj>0080Q8B400D0QhN708j>SP2PX:00X:2P09nOW`020:j^[P<0[Jf]00D0Zj^[0:n_[`2ZZZX0ZZZZ
06IVIP0209VIV@0309NGU`2CTi<0Ti>C0080TI6A0P2FUYH01@2NWYh0WinO09nOW`2XZ:P0WYjN0080
WinO00@0XZ:R07YjNP1jNWX0P8200P2YZJT01@2XZ:P0YjNW0:RXZ02XZ:P0YZJV0080YJFU00<0Y:BT
0:JVYP2VYZH00P2SXj<20:JVYP040:6QX@1LG5`0G5aL07UiN@80UiNG00D0ZZZZ0:^[Z`2YZJT0ZJVY
0:BTY00209fMW@80WYjN0P2CTi<0102DU9@0UYJF09JFUP2MWId205UIF@030:2PX02VYZH0Zj^[0080
Zj^[0`2WYjL20:b/[0030:n_[`2^[Zh0V9RH0080V9RH0P2UYJD01@2HV9P0Jf][08^;R`2;Rh/0N7Qh
0080UYJF00@0YJFU0:NWY`2WYjL0YjNW5@3ooomc0000ocX0oh003`3oool000T0oooo00@0QhN708:2
PP22PX80OGem0P1kNg/01@1mOGd0Q8B408B4Q02=SHd0RXZ:0080S8b<00D0FUYJ07alO01lO7`0T92@
079bLP0209:BTP0409BDU02LW9`0W9bL09bLW080Vi^K00D0X:2P0:6QX@2YZJT0ZJVY0:RXZ0020:JV
YP0507MgM`1?Cdl0Cdm?08b<S02BTY800P2HV9P0102PX:00XJ6Q0:6QX@2PX:020:BTY00509ZJVP2/
[:`0/[:b0;:b/P2^[Zh00P2/[:`01@2`/;00C4a<0:NWY`2WYjL0X:2P0080Shn?00D0S8b<096AT@2A
TI40Ph>308:2PP0207]kN`040820P01oOgl0Ogmo08B4Q080U9BD00D0SXj>05MGE`2;Rh/0Rh^;08j>
SP0208B4Q00508N7Q`2>SXh0X:2P0:2PX02OWil00P2^[Zh30:f][@050:^[Z`2_[jl0ZZZZ0:ZZZP1V
IVH00P2IVIT00`2GUiL0Ti>C09>CT`02096AT@80UYJF00D0WYjN09nOW`2OWil0Z:RX09jNWP0209nO
W`040::RXP1jNWX0NWYj0820P080ZJVY00D0Z:RX0:NWY`2XZ:P0Z:RX0:JVYP020:FUY@030:BTY02V
YZH0YZJV0080Xj>S0P2VYZH0102QXJ40G5aL05aLG01iNGT209NGU`050:ZZZP2[Zj/0ZJVY0:VYZ@2T
Y:@00P2MWId209jNWP80Ti>C00@0U9BD09JFUP2FUYH0WIfM0P1IFET00`2PX:00YZJV0:^[Z`020:^[
Z`<0YjNW0P2/[:`00`2_[jl0[Zj^09RHV00209RHV080YJFU00D0V9RH06][J`2;Rh/0Rh^;07QhN002
09JFUP040:FUY@2WYjL0YjNW0:NWYaD0oooo2@3oP02Q0000o`<0oh003`3oool000T0oooo00@0JFUY
05mOG`1OGel0DE5A0P0`<3001@1=CDd0D51@051@D019BDT0@T920080>CTi00D0Bd];04m?C`1?Cdl0
ATI604U9B@0204I6AP0404M7A`1?Cdl0Cdm?03Ti>@80:BTY00D0?clo04I6AP1;Bd/0Bd];0451@@02
03dm?@0503Ti>@0[:b/0:b/[030`<00Z:RX00P0S8b<00`0_;bl09RHV02HV9P0302<S8`0502XZ:P1<
C4`0FUYJ05YJFP1PH6000P1MGEd01@19BDT0@D5106UYJ@1YJFT0LW9b0080JVYZ00D0EEEE04m?C`1?
Cdl0Fe]K05eMG@0205MGE`04069RHP1[Jf/0Jf][05EEE@80F5QH00D0EeMG03Lg=`0i>CT0>CTi04A4
A0020410@0050492@P1=CDd0DE5A055AD@1BDU800P1<C4`01@1HF5P0EUIF05IFEP1HF5P0DU9B0080
CDe=00@0@T9206EUI@1UIFD0IfMW0`1]KFd0101[Jf/0IVIV06IVIP1WIfL206ATI00505aLG01SHf<0
IFEU06EUI@1RHV800P1ADE401@1GEeL0NWYj07YjNP20P800LW9b0080MGEe00@0Ogmo0861P@21PH40
PH610P1oOgl01@1`L700NGUi07inOP1nOWh0Ogmo0080BTY:00D0Hf=S06MWI`1WIfL0MWIf07QhN002
07emO@05075aL@1RHV80HV9R05UIF@1>CTh00P1MGEd0101KFe/0FEUI05UIF@1SHf<204Q8B00507Yj
NP22PX80RXZ:08Z:RP1`L7000P1eMGD00`2;Rh/0TY:B09:BTP0208n?S`80Ph>300D0N7Qh08V9R@29
RHT0J6QX05UIF@0207=cL`0406i^KP2:RXX0RXZ:0:2PX080WIfM00<0W9bL0?ooo`3oool04`3oool8
0000oi40oh0010000?l40?n000`0003o3`3oool000T0oooo00@0^[Zj0;Vi^@2i^KT0/K6a0P1_Kfl0
1@2i^KT0]KFe0;Fe]@2`/;00];Bd0080[Jf]00D0/[:b0;>c/`2c/k<0]kNg0;Zj^P020;jn_P040;no
_`2j^[X0^[Zj0:JVYP80FUYJ00D0O7al08R8R02c/k<0/k>c0;Zj^P020;Vi^@050;jn_P2e]KD0]KFe
0;:b/P2^[Zh00P2UYJD30:b/[0050:NWY`1:BTX0BTY:0:ZZZP2d];@00P2c/k<01@2`/;00[Jf]0:f]
[@2`/;00XZ:R00<0[jn_0P2/[:`01@2QXJ40Vi^K09^KV`2=SHd0D51@0080WYjN00@0[:b/0:NWY`2W
YjL0Y:BT0`2XZ:P0102RXZ80WIfM09fMW@2MWId209FEU@0509nOW`2KVi/0O7al07alO015ADD00P1o
Ogl01@2:RXX0QHF508F5Q@27QhL0S8b<0080Shn?00<0Q8B408^;R`2;Rh/00`2>SXh01@2ATI40UIFE
08b<S02<S8`0EUIF0080L71`00D0NWYj07UiN@1kNg/0Ng]k07IfMP0207=cL`0506e]K@1XJ6P0J6QX
06ATI01HF5P00P1IFET0101GEeL0;2`/02`/;00g=cL205iNGP0505YJFP1EEED0F5QH05QHF01NGUh0
0P1TI6@01@1LG5`0EUIF05IFEP1QHF40FUYJ0080B4Q800<0?3`l05aLG01LG5`00P1UIFD205UIF@04
05EEE@1KFe/0Fe]K06ATI080J6QX00D0GemO05ADE01>CTh0CTi>04=3@`0202HV9P0503Ph>017AdL0
AdM703hn?P11@D400`0o?cl203`l?00504E5A@12@T80BDU904U9B@1=CDd00P1HF5P0101CDe<0?Shn
03hn?P14A4@E0?ooofd0oh003`000?l30?n000@0003o303oP0060000o`T0oh001P000?l50?n00004
0000o`3oP000oh000?n000l0oooo00090?ooo`040;Fe]@2d];@0];Bd0:j^[P80LG5a00D0/k>c0;Bd
]02d];@0]kNg0;:b/P020:j^[P050;6a/@2][Jd0[Jf]0;Ng]`2k^k/00P2j^[X0102g]kL0/K6a0;6a
/@2^[Zh204i>CP0508j>SP2EUID0Zj^[0:^[Z`2_[jl00P2g]kL01@2d];@0/K6a0;6a/@2[Zj/0Z:RX
0080YJFU00@0Z:RX0:BTY02TY:@0WYjN0P1CDe<01@2_[jl0[Zj^0;2`/02`/;00[Zj^0080YjNW00D0
/;2`0:j^[P2^[Zh0[Zj^0:^[Z`020:FUY@<0Zj^[00D0[:b/061PH02/[:`0[:b/0;6a/@020;:b/P05
0;Jf]P2e]KD0]KFe0;Bd]02`/;000P2[Zj/01@2KVi/0WIfM09fMW@2/[:`0/[:b0080Y:BT00@0De=C
09nOW`2OWil0YJFU0P2LW9`01@2KVi/0Y:BT0:NWY`2WYjL0YZJV0080YJFU00D0Xj>S0:JVYP2VYZH0
[:b/0:j^[P020;:b/P0307IfMP2i^KT0^KVi00@0_Kfm0`2o_kl01@30`<00_kno0;no_`2l_;`0][Jf
0080/k>c00@0^k^k03lo?`0o?cl0S8b<0P2WYjL01@2XZ:P0ZZZZ0:ZZZP2ZZZX0[jn_0080];Bd00D0
^;Rh0;^k^`2k^k/0^k^k0;Rh^00206e]K@0506i^KP2TY:@0Y:BT0:VYZ@2b/[800P2h^;P0102m_Kd0
^k^k0;^k^`2m_Kd20;^k^`050;Rh^02a/K40[jn_0:n_[`2NWYh00P1ADE401@2DU9@0[Zj^0:j^[P2Y
ZJT0[:b/0080];Bd00D0/k>c0;2`/02`/;00^KVi0;Ng]`020;jn_P<0_Kfm00@0[:b/06YZJP1ZJVX0
[Zj^5@3ooom]0?n000l0003o0`3oP0040000o``0oh001P000?l90?n000H0003o1@3oP00010000?l0
oh000?n0003oP00?0?ooo`002@3oool0102e]KD0];Bd0;Bd]02^[Zh2075aL@050;>c/`2d];@0];Bd
0;Ng]`2b/[800P2^[Zh01@2a/K40[Jf]0:f][@2g]kL0^k^k0080^[Zj00@0]kNg0;6a/@2a/K40[Zj^
0P1>CTh01@2>SXh0UIFE0:^[Z`2[Zj/0[jn_0080]kNg00D0];Bd0;6a/@2a/K40Zj^[0:RXZ0020:FU
Y@040:RXZ02TY:@0Y:BT09jNWP80De=C00D0[jn_0:j^[P2`/;00/;2`0:j^[P020:NWY`050;2`/02^
[Zh0[Zj^0:j^[P2[Zj/00P2UYJD30:^[Z`050:b/[01PH600[:b/0:b/[02a/K400P2b/[801@2f][H0
]KFe0;Fe]@2d];@0/;2`0080Zj^[00D0Vi^K09fMW@2MWId0[:b/0;:b/P020:BTY00405=CD`2OWil0
WinO0:FUY@80W9bL00D0Vi^K0:BTY02WYjL0YjNW0:JVYP020:FUY@050:>SX`2VYZH0YZJV0:b/[02^
[Zh00P2b/[800`1fMWH0^KVi0;Vi^@040;fm_@<0_kno00D0`<300;no_`2o_kl0_;bl0;Jf]P020;>c
/`040;^k^`0o?cl0?clo08b<S080YjNW00D0Z:RX0:ZZZP2ZZZX0ZZZZ0:n_[`020;Bd]0050;Rh^02k
^k/0^k^k0;^k^`2h^;P00P1]KFd01@1^KVh0Y:BT0:BTY02YZJT0/[:b0080^;Rh00@0_Kfm0;^k^`2k
^k/0_Kfm0P2k^k/01@2h^;P0/K6a0:n_[`2_[jl0WYjN0080DE5A00D0U9BD0:j^[P2^[Zh0ZJVY0:b/
[0020;Bd]0050;>c/`2`/;00/;2`0;Vi^@2g]kL00P2n_[h30;fm_@040:b/[01ZJVX0JVYZ0:j^[QD0
oooo>`3oP0020000oa00oh0010000?l70?n000P0003oBP3oP0020000o`030?n0003oool0oooo00d0
oooo00090?ooo`040;Fe]@2a/K40/K6a0:JVYP80KVi^00D0/k>c0;Rh^02h^;P0^KVi0;Bd]0020;6a
/@050:j^[P2[Zj/0Zj^[0;:b/P2g]kL00P2e]KD0102b/[80[:b/0:b/[02][Jd205eMG@050:VYZ@2S
Xj<0[Jf]0:f][@2YZJT00P2VYZH00`2YZJT0YjNW0:NWY`020:>SX`80YjNW00@0ZZZZ0:2PX02PX:00
RXZ:0P1OGel01@2^[Zh0[:b/0:ZZZP2ZZZX0ZJVY0080WYjN00D0YZJV0:ZZZP2TY:@0Y:BT0:JVYP02
0:NWY`050:JVYP2ZZZX0ZZZZ0;2`/01aLG400P2a/K40102][Jd0];Bd0;Bd]02a/K420:f][@050:FU
Y@2RXZ80WIfM09fMW@2RXZ800P2SXj<01@2ZZZX0[:b/0:JVYP2VYZH0Bd];00<0WYjN0P2?Shl01@2G
UiL0TY:B09jNWP2NWYh0W9bL0080WYjN00D0Y:BT0::RXP2RXZ80ZJVY0:f][@020;2`/005075aL@2i
^KT0^KVi0;jn_P2o_kl00P31`L401032`/80_[jn0;jn_P2_[jl20;:b/P050;Jf]P2e]KD0^;Rh0;Rh
^02i^KT00P1=CDd01@2TY:@0YjNW0:NWY`2[Zj/0ZJVY0080ZZZZ00@0[jn_0;:b/P2b/[80]KFe0P2d
];@01@2g]kL0][Jf06UYJ@1YJFT0L71`0080YjNW00D0[Zj^0;>c/`2g]kL0]kNg0;^k^`020;fm_@<0
^[Zj00D0]KFe0;:b/P2/[:`0[:b/08b<S00204Y:BP0309^KV`2ZZZX0ZZZZ0080[Zj^0P2_[jl01@2`
/;00/[:b0;:b/P2j^[X0^;Rh0080^k^k00@0^[Zj0;Vi^@2i^KT0[jn_0P1dM7@00`2a/K40oooo0?oo
o`0C0?oood80003o0P3oP0080000o`80oh000`000?mK0?n000030000o`3oool0oooo00d0oooo0009
0?ooo`040:n_[`2ZZZX0ZZZZ0:NWY`80MgMg00D0]KFe0;Ng]`2g]kL0^;Rh0:f][@020:6QX@050:BT
Y02YZJT0ZJVY0;>c/`2d];@00P2b/[80102][Jd0ZJVY0:VYZ@2WYjL205QHF0050:f][@2ZZZX0[:b/
0:b/[02^[Zh00P2TY:@01@2RXZ80YJFU0:FUY@2JVYX0X:2P0080Xj>S00@0YjNW0:ZZZP2ZZZX0Shn?
0P1JFUX01@2^[Zh0Z:RX0:VYZ@2YZJT0YjNW0080TY:B00D0VIVI09RHV02EUID0UIFE09VIV@020:RX
Z0050:ZZZP2WYjL0YjNW0:n_[`1TI6@00`2^[Zh20:b/[0050:j^[P2TY:@0Y:BT0:FUY@2VYZH00P2U
YJD01@2VYZH0Xj>S0:>SX`2QXJ40YJFU0080[jn_00@0CDe=09fMW@2MWId0Vi^K0P23Ph<01@1oOgl0
O7al08Z:RP2:RXX0TI6A0080U9BD00<0Xj>S0:2PX02PX:00102ZZZX01@1bLW80_Kfm0;fm_@31`L40
`<3000<0_Kfm0P2k^k/01@2i^KT0/k>c0;>c/`2k^k/0]kNg0080_;bl00<0^[Zj05QHF01HF5P00`2J
VYX01@2>SXh0U9BD0:2PX02PX:00YjNW0080/;2`00D0]KFe0;Vi^@2i^KT0^KVi0:j^[P0204i>CP05
06e]K@2[Zj/0Zj^[0:^[Z`2/[:`00P2[Zj/0102][Jd0]kNg0;Ng]`2e]KD20:j^[P050:ZZZP2SXj<0
Z:RX0:RXZ02DU9@00P1;Bd/00`2IVIT0XJ6Q0:6QX@040:JVYP0509NGU`2UYJD0YJFU0:2PX02QXJ40
0P2YZJT0102a/K40Z:RX0:RXZ02SXj<207emO@030;Bd]03oool0oooo01<0oooo[@000?l?0?ooo`00
2@3oool0102_[jl0ZZZZ0:ZZZP2WYjL207MgM`050;Fe]@2g]kL0]kNg0;Rh^02][Jd00P2QXJ401@2T
Y:@0ZJVY0:VYZ@2c/k<0];Bd0080/[:b00@0[Jf]0:VYZ@2YZJT0YjNW0P1HF5P01@2][Jd0ZZZZ0:b/
[02/[:`0[Zj^0080Y:BT00D0XZ:R0:FUY@2UYJD0VYZJ0:2PX0020:>SX`040:NWY`2ZZZX0ZZZZ08n?
S`80FUYJ00D0[Zj^0:RXZ02YZJT0ZJVY0:NWY`0209:BTP0509VIV@2HV9P0UIFE09FEU@2IVIT00P2X
Z:P01@2ZZZX0YjNW0:NWY`2_[jl0I6AT00<0[Zj^0P2/[:`01@2^[Zh0Y:BT0:BTY02UYJD0YZJV0080
YJFU00D0YZJV0:>SX`2SXj<0XJ6Q0:FUY@020:n_[`0404e=C@2MWId0WIfM09^KV`80Ph>300D0Ogmo
07alO02:RXX0RXZ:096AT@0209BDU0030:>SX`2PX:00X:2P00@0ZZZZ00D0LW9b0;fm_@2m_Kd0`L71
0<30`0030;fm_@80^k^k00D0^KVi0;>c/`2c/k<0^k^k0;Ng]`020;bl_0030;Zj^P1HF5P0F5QH00<0
VYZJ00D0SXj>09BDU02PX:00X:2P0:NWY`020;2`/0050;Fe]@2i^KT0^KVi0;Vi^@2^[Zh00P1>CTh0
1@1]KFd0Zj^[0:^[Z`2[Zj/0[:b/0080Zj^[00@0[Jf]0;Ng]`2g]kL0]KFe0P2^[Zh01@2ZZZX0Xj>S
0:RXZ02XZ:P0U9BD0080Bd];00<0VIVI0:6QX@2QXJ40102VYZH01@2GUiL0YJFU0:FUY@2PX:00XJ6Q
0080ZJVY00@0/K6a0:RXZ02XZ:P0Xj>S0P1mOGd00`2d];@0oooo0?ooo`0C0?ooojd0003o3`3oool0
00T0oooo00@0CDe=04A4A014A4@0<30`0P0W9bL01@10@400@d=304=3@`0h>3P0=SHf0080<c<c00D0
820P030`<00`<300>c/k03hn?P020451@@0403dm?@0n?Sh0?Shn038b<P80;2`/00@0>SXj04Q8B01<
C4`0C4a<0`18B4P01@11@D40>c/k03/k>`18B4P0CTi>0080D51@00@0EEEE04I6AP16ATH0@T920P0M
7Ad01@1LG5`0I6AT06IVIP1VIVH0IfMW0080Jf][00D0IfMW071`L01/K6`0K6a/06YZJP0207IfMP05
06i^KP1[Jf/0Jf][06m_K`0m?Cd00P1bLW80101gMgL0NGUi07UiN@1kNg/407=cL`80LG5a00D0K6a/
07IfMP1fMWH0N7Qh07alO00207UiN@0403Xj>P1mOGd0OGem07MgM`80N7Qh00D0LG5a06IVIP1hN7P0
N7Qh07inOP030861P@<0Rh^;00@0QhN708b<S02<S8`0EUIF0P2=SHd01@2:RXX0T92@08R8R028R8P0
QhN70080T92@00D0TI6A08F5Q@25QHD0UIFE09VIV@020::RXP040;6a/@1;Bd/0Bd];09VIV@80Z:RX
00D0V9RH08^;R`2GUiL0UiNG09:BTP0209RHV0050:JVYP2][Jd0[Jf]0;Rh^02`/;000P1>CTh01@1]
KFd0WIfM09fMW@2LW9`0WYjN0080XZ:R00@0Zj^[0:RXZ02XZ:P0ZJVY0P2TY:@01@2PX:00Rh^;09ZJ
VP2JVYX0SXj>0080FEUI00D0WinO09BDU02DU9@0U9BD09jNWP020:6QX@0509JFUP2ATI40TI6A08V9
R@2;Rh/00P2JVYX0102TY:@0[Zj^0:j^[P2SXj<207IfMP030;2`/03oool0oooo01<0ooooCP3oP00=
0000oaD0oh00>@000?l40?n000l0oooo00090?ooo`0406][J`14A4@0A4A408>3P`80T92@00D0Rh^;
08R8R028R8P0LW9b02`/;00206=SH`0508Z:RP2;Rh/0Rh^;0861P@1nOWh00P1WIfL0100`<300GemO
05mOG`22PX8308>3P`0407MgM`1dM7@0M7Ad03Hf=P80JFUY00D0KVi^069RHP1RHV80EeMG05iNGP02
05EEE@0402PX:00j>SX0>SXj04A4A080CDe=00D0IVIV069RHP0i>CT0>CTi02PX:00205iNGP0507Mg
M`1_Kfl0IVIV06IVIP1XJ6P00P1WIfL01@0[:b/0?Shn03hn?P1PH600Hf=S0080EeMG00@0BDU9055A
D@1ADE40=cLg0P1HF5P01@1DE5@0BTY:03`l?00l?3`0@4100080>SXj00<0:RXZ05aLG01HF5P00P1H
F5P204Q8B005030`<00Y:BT0:BTY02<S8`0[:b/00P0_;bl0100h>3P0=SHf03Hf=P0[:b/202LW9`05
03Xj>P15ADD0BDU904U9B@12@T800P0j>SX01@0f=SH0<c<c0451@@11@D40?Cdm0080>3Ph00D0=3@d
028R8P0R8R806ATI02HV9P0202d];@04034a<@0Z:RX0:RXZ02d];@80>SXj00D0ADE50451@@14A4@0
A4A404E5A@020451@@0503dm?@0i>CT0>CTi0492@P1GEeL00P1;Bd/304a<C080De=C0P1=CDd01019
BDT0CTi>04i>CP1GEeL205UIF@0505QHF01BDU80DU9B059BDP1EEED00P0f=SH0100Z:RX0>c/k03/k
>`11@D4304E5A@0505EEE@1GEeL0EeMG04Q8B017AdL00`1<C4`205aLG00404i>CP0`<300<30`04E5
AAD0oooo=P3oP0000`000?l0oh000?n000040?n001<0003o4`3oP00010000?l0oh000000o`000?m2
0?n000040000o`3oP000oh000?n000l0oooo00090?ooo`0409jNWP0m?Cd0?Cdm0;bl_080b<S800D0
bLW90<[:bP3:b/X0_Kfm02/[:`020861P@050;Bd]02g]kL0]kNg0;Ng]`2h^;P00P2NWYh00`0X:2P0
S8b<08b<S0040;Vi^@040:b/[02GUiL0UiNG04e=C@80TI6A00D0WIfM08b<S02<S8`0RXZ:08j>SP02
0820P00404e=C@1FEUH0EUIF05EEE@80IFEU00D0Ph>308n?S`22PX80PX:203<c<`0208f=S@050:j^
[P2MWId0UiNG09NGU`2QXJ400P2LW9`01@13@d<0MGEe07EeM@2YZJT0/K6a0080/;2`00@0/k>c0;Rh
^02h^;P0EEEE0P2QXJ401@2=SHd0I6AT05eMG@1MGEd0EUIF0080DE5A00D0B4Q80;Ng]`2i^KT0^KVi
0;Rh^0020;Jf]P050;:b/P1YJFT0JFUY05]KF`2WYjL00P2f][H0102g]kL0_;bl0;bl_02[Zj/20492
@P0308V9R@2e]KD0];Bd0080];Bd0P2j^[X01@2^[Zh0@d=30;Zj^P2j^[X0_kno0080a<C400D0aLG5
08^;R`2;Rh/0Ph>30;Zj^P020;:b/P040:RXZ02TY:@0Y:BT08b<S080DU9B00D0XJ6Q0:ZZZP2UYJD0
YJFU0:^[Z`020:ZZZP050:BTY01FEUH0EUIF0:n_[`2d];@00P2l_;`01@2i^KT0/k>c0;>c/`1<C4`0
K6a/0080X:2P00@0Ti>C092@T02@T900T92@0P2FUYH01@1OGel0B4Q808R8R028R8P0TI6A0080Xj>S
00D0XJ6Q08V9R@29RHT0>c/k06i^KP0208f=S@0509VIV@2HV9P0V9RH09VIV@2?Shl00P0f=SH0101Q
HF40SXj>08j>SP2IVIT20::RXP0309bLW03oool0oooo01<0oooo=P3oP0000`000?l0oh000?n00004
0?n001<0003o4`3oP00010000?l0oh000000o`000?m20?n000040000o`3oP000oh000?n000l0oooo
00090?ooo`0409jNWP0m?Cd0?Cdm0;bl_080b<S800D0bLW90<[:bP3:b/X0_Kfm02/[:`020861P@05
0;Bd]02g]kL0]kNg0;Ng]`2h^;P00P2NWYh00`0X:2P0S8b<08b<S0040;Vi^@040:b/[02GUiL0UiNG
04e=C@80TI6A00D0WIfM08b<S02<S8`0RXZ:08j>SP020820P00404e=C@1FEUH0EUIF05EEE@80IFEU
00D0Ph>308n?S`22PX80PX:203<c<`0208f=S@050:j^[P2MWId0UiNG09NGU`2QXJ400P2LW9`01@13
@d<0MGEe07EeM@2YZJT0/K6a0080/;2`00@0/k>c0;Rh^02h^;P0EEEE0P2QXJ401@2=SHd0I6AT05eM
G@1MGEd0EUIF0080DE5A00D0B4Q80;Ng]`2i^KT0^KVi0;Rh^0020;Jf]P050;:b/P1YJFT0JFUY05]K
F`2WYjL00P2f][H0102g]kL0_;bl0;bl_02[Zj/20492@P0308V9R@2e]KD0];Bd0080];Bd0P2j^[X0
1@2^[Zh0@d=30;Zj^P2j^[X0_kno0080a<C400D0aLG508^;R`2;Rh/0Ph>30;Zj^P020;:b/P040:RX
Z02TY:@0Y:BT08b<S080DU9B00D0XJ6Q0:ZZZP2UYJD0YJFU0:^[Z`020:ZZZP050:BTY01FEUH0EUIF
0:n_[`2d];@00P2l_;`01@2i^KT0/k>c0;>c/`1<C4`0K6a/0080X:2P00@0Ti>C092@T02@T900T92@
0P2FUYH01@1OGel0B4Q808R8R028R8P0TI6A0080Xj>S00D0XJ6Q08V9R@29RHT0>c/k06i^KP0208f=
S@0509VIV@2HV9P0V9RH09VIV@2?Shl00P0f=SH0101QHF40SXj>08j>SP2IVIT20::RXP0309bLW03o
ool0oooo01<0oooo2@000?l50?n00180003o1`3oP0020000oh<0oh0000<0003o0?ooo`3oool03@3o
ool000T0oooo00@0[jn_04E5A@15ADD0_[jn0P35aLD01@39bLT0b/[:0<[:bP2d];@092@T0080QHF5
00D0[jn_0:f][@2][Jd0/[:b0;Bd]0020:NWY`0402HV9P2BTY80TY:B0;Ng]`80/k>c00D0];Bd0:FU
Y@2CTi<0Ti>C03Xj>P0209>CT`040;>c/`2a/K40/K6a0;>c/`<0ZJVY00@0EEEE03dm?@0m?Cd0?Cdm
0P1;Bd/01@1]KFd0Ng]k07inOP1nOWh0@T920080R8R800D0/[:b0:FUY@2GUiL0UiNG0:>SX`020:2P
X00303/k>`23Ph<0Ph>30080]kNg0P2j^[X30;no_`0506=SH`2VYZH0YZJV0:JVYP2@T9000P1`L700
1@1OGel0Bd];04];B`1FEUH0]KFe0080^;Rh00@0^KVi0;bl_02l_;`0^;Rh0P1XJ6P01@1dM7@0/;2`
0;Bd]02d];@0^KVi0080`<3000D0^;Rh04];B`1;Bd/0U9BD0;Bd]0020:ZZZP050:j^[P2h^;P0^;Rh
0;bl_01XJ6P00P2m_Kd01031`L40`/;20<;2`P38b<P20;>c/`0506m_K`2XZ:P0Z:RX0:RXZ02MWId0
0P2SXj<01@2WYjL0H61P061PH02WYjL0Zj^[0080YJFU00@0XZ:R09bLW02LW9`0SHf=0P1BDU801@2g
]kL0^k^k0;^k^`2k^k/0]kNg0080^;Rh00D0KFe]07AdM02EUID0UIFE09bLW002092@T00508N7Q`2@
T900T92@05UIF@25QHD00P2^[Zh0102f][H0]kNg0;Ng]`2c/k<20:j^[P040451@@2OWil0^KVi0;Vi
^@<0^;Rh00D0/k>c0:f][@0n?Sh0?Shn0:6QX@020:RXZ0040:b/[02`/;00/;2`0;2`/1D0oooo00<0
003o0?n0003oP0001@3oP0000`000?l0oh000?n000070?n000030000o`3oP000oh0000H0oh001`00
0?l00`3oP000003o0?n0000L0?n000L0003oA`3oP0040000o`H0oh0010000?l40?n000D0003o1`3o
P00?0?ooo`002@3oool0102b/[80EEEE05EEE@2h^;P20<71`@050<30`036a/H0a/K60:RXZ00];Bd0
0P2?Shl01@2YZJT0Z:RX0:RXZ02[Zj/0Z:RX0080Ti>C00@08B4Q08j>SP2>SXh0/k>c0P2b/[801@2/
[:`0UiNG0820P020P800?clo0080V9RH00D0];Bd0:^[Z`2[Zj/0[:b/0;2`/0020:j^[P0404m?C`0g
=cL0=cLg01LG5`806ATI00D07QhN0451@@15ADD0ADE503<c<`0208B4Q00509nOW`1oOgl0NWYj07Yj
NP2CTi<00P2JVYX01@19BDT0Ogmo07moO`2YZJT0[jn_0080/;2`00@0^k^k0;jn_P2n_[h0Hf=S0P2L
W9`01@2[Zj/0ZJVY08>3P`23Ph<0LW9b0080GemO00D0CTi>0;>c/`2^[Zh0[Zj^0:b/[0020;:b/P05
0;Bd]01UIFD0IFEU07moO`2_[jl00P2d];@0102e]KD0]kNg0;Ng]`2ZZZX203Xj>P0509JFUP2a/K40
[:b/0:b/[02b/[800P2g]kL0102e]KD0H61P0;Zj^P2j^[X30;fm_@050<K6aP2_[jl0[jn_075aL@2V
YZH00P2QXJ40102WYjL0YJFU0:FUY@2GUiL2069RHP0509VIV@2UYJD0WIfM09fMW@2EUID00P24Q8@0
1@26QXH0AdM704M7A`2b/[80]KFe0080/k>c00D0[Zj^0;2`/02`/;00Hf=S06ATI00208Z:RP0408:2
PP1oOgl0Ogmo07]kN`80MGEe00D0B4Q808R8R02b/[80/[:b0;Jf]P020;Rh^0050;Ng]`2`/;00/;2`
03Hf=P2TY:@00P2c/k<01@2h^;P0][Jf0;Jf]P2a/K40Z:RX0080=cLg00@0V9RH0:FUY@2UYJD0[Jf]
0P2[Zj/00`2WYjL0oooo0?ooo`0C0?oooah0003o103oP0070000o`D0oh0000D0003o0?n0003oP000
003o0?n0001L0000o`X0oh000P000?l90?n000040000o`3oP000oh000?n000D0003o3`3oool000T0
oooo00@0/[:b05EEE@1EEED0^;Rh0P31`L401@30`<00a/K60<K6aP2XZ:P0;Bd]0080Shn?00D0ZJVY
0:RXZ02XZ:P0Zj^[0:RXZ00209>CT`04024Q8@2>SXh0SXj>0;>c/`80/[:b00D0[:b/09NGU`20P800
P82003lo?`0209RHV0050;Bd]02[Zj/0Zj^[0:b/[02`/;000P2^[Zh0101?Cdl0=cLg03Lg=`0G5aL2
01TI6@0501hN7P11@D40ADE504E5A@0c<c<00P24Q8@01@2OWil0Ogmo07YjNP1jNWX0Ti>C0080VYZJ
00D0BDU907moO`1oOgl0ZJVY0:n_[`020;2`/0040;^k^`2n_[h0_[jn06=SH`80W9bL00D0Zj^[0:VY
Z@23Ph<0Ph>3079bLP0205mOG`0504i>CP2c/k<0[Zj^0:j^[P2/[:`00P2b/[801@2d];@0IFEU06EU
I@1oOgl0[jn_0080];Bd00@0]KFe0;Ng]`2g]kL0ZZZZ0P0j>SX01@2FUYH0/K6a0:b/[02/[:`0/[:b
0080]kNg00@0]KFe061PH02j^[X0^[Zj0`2m_Kd01@36a/H0[jn_0:n_[`1aLG40YZJV0080XJ6Q00@0
YjNW0:FUY@2UYJD0UiNG0P1RHV801@2IVIT0YJFU09fMW@2MWId0UIFE0080Q8B400D0QXJ604M7A`17
AdL0/[:b0;Fe]@020;>c/`050:j^[P2`/;00/;2`06=SH`1TI6@00P2:RXX01022PX80Ogmo07moO`1k
Ng/207EeM@0504Q8B028R8P0/[:b0;:b/P2f][H00P2h^;P01@2g]kL0/;2`0;2`/00f=SH0Y:BT0080
/k>c00D0^;Rh0;Jf]P2f][H0/K6a0:RXZ00203Lg=`0409RHV02UYJD0YJFU0:f][@80Zj^[00<0YjNW
0?ooo`3oool04`3ooolN0000o`@0oh001`000?l50?n000050000o`3oP000oh000000o`3oP000G000
0?l:0?n00080003o2@3oP00010000?l0oh000?n0003oP0050000o`l0oooo00090?ooo`0408B4Q00c
<c<0<c<c07alO080QHF500D0OWin08:2PP22PX80MWIf03dm?@0205aLG00507moO`1jNWX0NWYj07If
MP27QhL00P1kNg/0100Z:RX0GemO05mOG`1]KFd2075aL@0505]KF`1CDe<0GemO05mOG`15ADD00P1R
HV801@1hN7P0PX:208:2PP22PX80QXJ60080SHf=00@0ATI603hn?P0n?Sh0;2`/0P0k>c/01@0l?3`0
@D5105ADE01DE5@0@4100080Hf=S00D0I6AT04];B`1EEED0EEEE061PH00206UYJ@0504M7A`1QHF40
HF5Q07alO01bLW800P1`L7001020P800QhN708N7Q`18B4P209ZJVP0509NGU`1dM7@0I6AT06ATI013
@d<00P1QHF401@17AdL0Ti>C08^;R`2;Rh/0OWin0080Ng]k00D0R8R805IFEP1FEUH0JFUY0820P002
08>3P`0409>CT`2PX:00X:2P08:2PP80=cLg00D0R8R809BDU02OWil0WinO0:2PX0020:^[Z`050:BT
Y01JFUX0UiNG09NGU`2IVIT00P2e]KD01@2f][H0X:2P0:2PX01/K6`0Z:RX0080YjNW00@0Y:BT0:NW
Y`2WYjL0W9bL0P1JFUX01@2FUYH0WinO09RHV02HV9P0Ti>C0080QHF500D0Ogmo04m?C`1?Cdl0ZZZZ
0:n_[`020:ZZZP050:BTY02WYjL0YjNW05ADE01>CTh00P29RHT01028R8P0O7al07alO01iNGT206e]
K@0504i>CP2BTY80^;Rh0;Rh^034a<@00P2l_;`01@2i^KT0/k>c0;>c/`0[:b/0X:2P0080][Jf00D0
^k^k0;Zj^P2j^[X0^KVi0;6a/@0203Ti>@040:BTY02VYZH0YZJV0:RXZ080/;2`00<0[Zj^0?ooo`3o
ool04`3oool80?n000030000o`3oP000oh0000<0oh001@000?l?0?n000@0003o1`3oP0040000oaT0
oh000`000?l;0?n00580003o0`3oP00?0?ooo`002@3oool01028R8P0Ng]k07]kN`1hN7P2079bLP05
0451@@1KFe/0Fe]K071`L01iNGT00P1nOWh01@1_Kfl0KFe]06e]K@1`L700NGUi0080JVYZ00@0J6QX
05QHF01HF5P0EEEE0P1HF5P01@0n?Sh0AdM706QXJ01XJ6P0Kfm_0080J6QX00D0GUiN05aLG01LG5`0
Bd];05EEE@0205]KF`0405YJFP1IFET0FEUI05iNGP80D51@00D0?3`l04U9B@1SHf<0Hf=S06YZJP02
06][J`04069RHP1LG5`0G5aL05aLG0<0GemO00D0HV9R05mOG`1OGel0F5QH05iNGP0204I6AP0403Xj
>P1ADE40DE5A05MGE`80EEEE0P1LG5`205]KF`0505eMG@1RHV80HV9R061PH01OGel00P1YJFT0101R
HV80CTi>04i>CP1EEED305]KF`0405IFEP1=CDd0CDe=04I6AP80C4a<00<0ATI6059BDP1BDU800P1R
HV8206IVIP05065QH@1=CDd0CDe=04Y:BP12@T800P0k>c/01014A4@0C4a<04a<C018B4P203hn?P05
04];B`1FEUH0BTY:04Y:BP1?Cdl00P1ADE401@1KFe/0De=C05=CD`1VIVH0I6AT0080HF5Q00@0FUYJ
06ATI01TI6@0Fe]K0P1CDe<01@1lO7`0Lg=c06e]K@1]KFd0JVYZ0080IVIV00D0C4a<0410@01OGel0
GemO06IVIP0205aLG00505eMG@1IFET0FEUI04a<C01ZJVX00P1hN7P01025QHD0Ph>308>3P`1fMWH2
07QhN0050451@@1_Kfl0Ng]k07]kN`21PH400P1eMGD01@1gMgL0LG5a03lo?`0o?cl0N7Qh0080O7al
00@0NGUi08>3P`23Ph<0OWin5@3oool40?n000030000o`3oP000oh0001L0oh003`000?l=0?n000`0
003o0P3oP00?0000o`040?n000000?l0oh000?n000@0003o:P3oP0000`000?l0oh000?n0000M0?n0
00<0003o00<0oh000?ooo`3oool03@3oool000T0oooo00@0R8R807]kN`1kNg/0N7Qh0P1bLW801@11
@D40Fe]K05]KF`1`L700NGUi0080OWin00D0Kfm_06e]K@1]KFd0L71`07UiN@0206YZJP0406QXJ01H
F5P0F5QH05EEE@80F5QH00D0?Shn04M7A`1XJ6P0J6QX06m_K`0206QXJ00505iNGP1LG5`0G5aL04];
B`1EEED00P1KFe/0101JFUX0FEUI05UIF@1NGUh2051@D00503`l?019BDT0Hf=S06=SH`1ZJVX00P1[
Jf/0101RHV80G5aL05aLG01LG5`305mOG`05069RHP1OGel0GemO05QHF01NGUh00P16ATH0100j>SX0
DE5A055AD@1GEeL205EEE@80G5aL0P1KFe/01@1MGEd0HV9R069RHP1PH600GemO0080JFUY00@0HV9R
04i>CP1>CTh0EEEE0`1KFe/0101FEUH0CDe=04e=C@16ATH204a<C00304I6AP1BDU80DU9B0080HV9R
0P1VIVH01@1QHF40CDe=04e=C@1:BTX0@T920080>c/k00@0A4A404a<C01<C4`0B4Q80P0n?Sh01@1;
Bd/0EUIF04Y:BP1:BTX0Cdm?0080DE5A00D0Fe]K05=CD`1CDe<0IVIV06ATI002065QH@0405YJFP1T
I6@0I6AT05]KF`80De=C00D0O7al07=cL`1]KFd0KFe]06YZJP0206IVIP0504a<C010@400GemO05mO
G`1VIVH00P1LG5`01@1MGEd0FEUI05UIF@1<C4`0JVYZ0080N7Qh00@0QHF508>3P`23Ph<0MWIf0P1h
N7P01@11@D40Kfm_07]kN`1kNg/0PH610080MGEe00D0MgMg075aL@0o?cl0?clo07QhN00207alO004
07UiN@23Ph<0Ph>307inOQD0ooooYP3oP0070000o`l0oooo00090?ooo`040;Bd]02`/;00/;2`0:NW
Y`80WinO00<0@T9209BDU02DU9@00P2[Zj/20:b/[0050:FUY@2b/[80/[:b0;Bd]02e]KD00P2`/;00
102ZZZX0Y:BT0:BTY02EUID209fMW@0506YZJP1nOWh0];Bd0;Bd]02[Zj/00P2VYZH0102PX:00[Jf]
0:f][@2][Jd30:b/[0040:RXZ02ZZZX0ZZZZ0:j^[P80/;2`00<0Lg=c08^;R`2a/K40102a/K400`2[
Zj/0[Zj^0:JVYP020:JVYP80ZJVY00D0YZJV0:b/[02/[:`0ZJVY0:^[Z`0207QhN004071`L02i^KT0
^KVi0;fm_@80_;bl00D0]KFe0;Rh^02g]kL0]kNg0;Fe]@020;6a/@050;Bd]02c/k<0^KVi0;Vi^@2e
]KD00P1YJFT01@2^[Zh0][Jf0;Jf]P2f][H0]kNg0080/k>c00@0YZJV0:ZZZP2ZZZX0/;2`0P2n_[h0
1@2i^KT0][Jf0<;2`P32`/80a<C400<0DU9B00<0Z:RX0:VYZ@2YZJT00`2d];@01@2a/K40ZZZZ0:ZZ
ZP2UYJD0WYjN0080Rh^;00@0Ng]k0451@@11@D40YJFU0P2_[jl01@2QXJ40PX:209>CT`2CTi<0S8b<
0080UYJF00D0Vi^K09jNWP2NWYh0WinO09VIV@0208V9R@05069RHP1FEUH0EUIF09FEU@2JVYX00P2>
SXh0102JVYX0XZ:R0::RXP2PX:020861P@0509RHV02QXJ40UiNG09NGU`2FUYH00P2EUID01@1BDU80
P8200820P02LW9`0T92@0080Q8B400D0Kfm_055AD@1ADE40EEEE06i^KP0208V9R@0406YZJP1SHf<0
Hf=S065QH@<0Cdm?5@3ooonV0?n000L0003o3`3oool000T0oooo00@0];Bd0:j^[P2^[Zh0Zj^[0P2W
YjL01@0h>3P0UiNG09NGU`2WYjL0YJFU0080XZ:R00D0Vi^K0:JVYP2VYZH0[:b/0:RXZ0030:FUY@80
Xj>S00D0XZ:R09bLW02LW9`0J6QX0861P@020:n_[`040;6a/@2WYjL0YjNW08V9R@80YJFU00D0XZ:R
0:BTY02WYjL0YjNW09bLW0020:6QX@050:f][@2b/[80/[:b07emO@2>SXh00P2f][H01@2d];@0/[:b
0;:b/P2f][H0/;2`0080YjNW00@0YZJV0:NWY`2WYjL0YjNW0P2[Zj/01@2WYjL0XJ6Q08b<S02<S8`0
TI6A0080/[:b00D0/K6a0;2`/02`/;00[Zj^0;>c/`020;Fe]@050;Bd]02b/[80/[:b0;6a/@2f][H0
0P2g]kL0102f][H0EeMG05MGE`2VYZH20;Bd]0050;2`/02a/K40/;2`0;2`/02QXJ400P2RXZ800`2W
YjL0_kno0;no_`020<30`080_Kfm00D0[Zj^04A4A014A4@0NWYj0:VYZ@020:n_[`040;Jf]P2h^;P0
^;Rh0:f][@80Z:RX00D0YZJV0:>SX`2SXj<0Xj>S0861P@0204E5A@<0^;Rh00D0_;bl0;Vi^@2i^KT0
^KVi0;Ng]`020;Jf]P050:^[Z`2DU9@0U9BD0:VYZ@2c/k<00P2e]KD01@2ATI40MGEe07EeM@2a/K40
/[:b0080[Jf]00@0];Bd0;^k^`2k^k/0_[jn0P2j^[X01@2l_;`0^k^k0;Ng]`2g]kL0[:b/0080];Bd
00D0Kfm_0:RXZ02XZ:P0/[:b0:VYZ@0209bLW00509nOW`2e]KD0]KFe0;Rh^02c/k<00P2d];@0102]
[Jd0/K6a0;6a/@2h^;P207YjNP0306e]K@3oool0oooo01<0oooo103oP0000`000?l0oh000?n0001/
0?n000<0003o00<0oh000000o`000?l00P000?l50?n000T0003o0P3oP0020000o`80oh001P000?l0
0`3oP000003o0000o`030000o`l0oh000`000?l?0?ooo`002@3oool0102XZ:P0Xj>S0:>SX`2VYZH2
09nOW`0303Lg=`2JVYX0VYZJ0080Xj>S0P2RXZ801@2NWYh0WinO09nOW`2UYJD0Z:RX0080ZJVY00@0
Xj>S09fMW@2MWId0Xj>S0P2PX:001@1^KVh0QXJ60;2`/02`/;00^;Rh0080/k>c00D0UiNG0:JVYP2V
YZH0WIfM0:2PX0020:VYZ@030:>SX`2UYJD0YJFU00<0];Bd00D0S8b<08B4Q02i^KT0^KVi0;Jf]P02
0;Bd]0050;>c/`2_[jl0YZJV0:JVYP2UYJD01@2ZZZX01@2XZ:P0[Jf]07IfMP1fMWH0Kfm_0080ZZZZ
00D0[Zj^0;6a/@2a/K40[Jf]0;2`/0020:f][@050;2`/02_[jl0[jn_0;6a/@2`/;000P2e]KD0102g
]kL0HF5Q065QH@2TY:@20:^[Z`040:j^[P2ZZZX0[Jf]0:f][@<0YJFU00D0YZJV0;Bd]02d];@0^k^k
0;no_`020;jn_P050:2PX00i>CT0>CTi07moO`2ZZZX00P2][Jd0102/[:`0[Zj^0:j^[P2ZZZX20::R
XP050:FUY@2SXj<0U9BD09BDU024Q8@00P19BDT01@2g]kL0^k^k0;^k^`33`l<0_[jn0080`/;200@0
_Kfm0;Zj^P2j^[X0YJFU0P2CTi<01@2_[jl0_;bl0;^k^`2k^k/0Ti>C0080P82000@0/[:b0;Bd]02e
]KD0]KFe102i^KT20;Bd]0050;bl_02k^k/0^;Rh0;Rh^02`/;000P2b/[801@1WIfL0YZJV0:JVYP2c
/k<0ZZZZ0080T92@00D0U9BD0;Jf]P2f][H0^[Zj0;Vi^@020;Ng]`040;Fe]@2i^KT0^KVi0;^k^`80
O7al00<0MWIf0?ooo`3oool04`3ooomf0000o`D0oh001`000?l40?n000<0003o3@3oP0030000oa40
oh000`000?l?0?ooo`002@3oool0102XZ:P0Xj>S0:>SX`2VYZH209nOW`0303Lg=`2JVYX0VYZJ0080
Xj>S0P2RXZ801@2NWYh0WinO09nOW`2UYJD0Z:RX0080ZJVY00@0Xj>S09fMW@2MWId0Xj>S0P2PX:00
1@1^KVh0QXJ60;2`/02`/;00^;Rh0080/k>c00D0UiNG0:JVYP2VYZH0WIfM0:2PX0020:VYZ@030:>S
X`2UYJD0YJFU00<0];Bd00D0S8b<08B4Q02i^KT0^KVi0;Jf]P020;Bd]0050;>c/`2_[jl0YZJV0:JV
YP2UYJD01@2ZZZX01@2XZ:P0[Jf]07IfMP1fMWH0Kfm_0080ZZZZ00D0[Zj^0;6a/@2a/K40[Jf]0;2`
/0020:f][@050;2`/02_[jl0[jn_0;6a/@2`/;000P2e]KD0102g]kL0HF5Q065QH@2TY:@20:^[Z`04
0:j^[P2ZZZX0[Jf]0:f][@<0YJFU00D0YZJV0;Bd]02d];@0^k^k0;no_`020;jn_P050:2PX00i>CT0
>CTi07moO`2ZZZX00P2][Jd0102/[:`0[Zj^0:j^[P2ZZZX20::RXP050:FUY@2SXj<0U9BD09BDU024
Q8@00P19BDT01@2g]kL0^k^k0;^k^`33`l<0_[jn0080`/;200@0_Kfm0;Zj^P2j^[X0YJFU0P2CTi<0
1@2_[jl0_;bl0;^k^`2k^k/0Ti>C0080P82000@0/[:b0;Bd]02e]KD0]KFe102i^KT20;Bd]0050;bl
_02k^k/0^;Rh0;Rh^02`/;000P2b/[801@1WIfL0YZJV0:JVYP2c/k<0ZZZZ0080T92@00D0U9BD0;Jf
]P2f][H0^[Zj0;Vi^@020;Ng]`040;Fe]@2i^KT0^KVi0;^k^`80O7al00<0MWIf0?ooo`3oool04`3o
ool00`3oP000003o0000o`2Z0000o`l0oooo00090?ooo`040;6a/@2c/k<0/k>c0;2`/080/[:b00D0
EeMG0::RXP2RXZ80XZ:R0:>SX`020::RXP0509:BTP2JVYX0VYZJ09VIV@2XZ:P00P2/[:`0102WYjL0
XJ6Q0:6QX@2SXj<20:2PX005069RHP20P800ZJVY0:VYZ@2_[jl00P2`/;001@2KVi/0[Jf]0:f][@2Q
XJ40YZJV0080ZJVY00@0XZ:R09bLW02LW9`0XZ:R0P2_[jl01@1oOgl0OWin0:n_[`2_[jl0/K6a0080
][Jf00D0];Bd0;>c/`2/[:`0[:b/0:FUY@020:f][@050:^[Z`2/[:`0[:b/0:RXZ02OWil00P1IFET0
0`1KFe/0XZ:R0::RXP030:ZZZP050:RXZ02WYjL0Z:RX0:RXZ02UYJD00P2YZJT01@2ZZZX0[Zj^0;>c
/`2c/k<0][Jf0080KVi^0`2SXj<01@2VYZH0YjNW0:RXZ02XZ:P0ZJVY0080[Jf]00D0ZZZZ0;Bd]02d
];@0^KVi0;Zj^P020;^k^`050:n_[`1=CDd0CDe=07IfMP2XZ:P00P2WYjL0102][Jd0Zj^[0:^[Z`2]
[Jd20:VYZ@050:FUY@2?Shl0R8R808R8R023Ph<00P1MGEd01@2a/K40][Jf0;Jf]P2h^;P0][Jf0080
_;bl00<0]kNg0;bl_02l_;`00`2XZ:P01@2h^;P0`L710;fm_@2m_Kd0UiNG0080Ph>300D0/[:b0;>c
/`2h^;P0^;Rh0;Vi^@020;Zj^P050;Vi^@2c/k<0/k>c0;Fe]@2i^KT00P2c/k<0102][Jd0/;2`0;2`
/01MGEd20:>SX`050;>c/`2YZJT0PX:208:2PP1eMGD00P2SXj<0102_[jl0/[:b0:f][@2][Jd30;Bd
]0040;Ng]`2:RXX0RXZ:0820P1D0oooo00<0oh000000o`000?l0ZP000?l?0?ooo`002@3oool00`1U
IFD0EeMG05MGE`0304Q8B005034a<@10@400@41004];B`1ADE400P1BDU801@1:BTX0?Shn03hn?P0Y
:BT0Bd];0080Hf=S00@0Fe]K04e=C@1=CDd0AdM70P0o?cl01@0n?Sh0Bd];05EEE@1EEED0JVYZ0080
H61P00<0E5AD04A4A014A4@00P0h>3P203Ti>@04034a<@0h>3P0>3Ph04E5A@80@41000D0>c/k04Y:
BP1IFET0FEUI05YJFP0206EUI@0506MWI`1GEeL0@T920492@P0l?3`00P1CDe<01@1ADE40CDe=04e=
C@11@D40?clo0080=SHf00@0:b/[05ADE01DE5@0DE5A0P1BDU801@0n?Sh0@d=303Ti>@0i>CT0=CDe
0080BDU900<0@D51059BDP1=CDd00P1=CDd203Lg=`05069RHP1WIfL0IfMW065QH@1SHf<00`1]KFd2
075aL@0506YZJP1`L700L71`06IVIP1[Jf/00P1XJ6P01@1CDe<0;2`/02`/;018B4P0IVIV0080HF5Q
00@0Fe]K06IVIP1VIVH0GEeM0P1HF5P01@1<C4`0GEeM06EUI@1UIFD0HF5Q0080>CTi00D0H61P06][
J`1[Jf/0Lg=c075aL@0207]kN`0407EeM@1lO7`0O7al06m_K`80MgMg00D0P82008F5Q@23Ph<0Ph>3
06UYJ@0205EEE@0507YjNP1lO7`0Ph>308>3P`20P8000P21PH401@1mOGd0PH610861P@1jNWX0PX:2
0080OWin00@0N7Qh07UiN@1iNGT0BTY:0P1kNg/01@1iNGT0HV9R05=CD`1CDe<0E5AD0080HF5Q00D0
LG5a07YjNP1jNWX0NWYj08:2PP0208f=S@0408R8R01UIFD0IFEU069RHQD0oooo[@3oP00?0?ooo`00
2@3oool00`1UIFD0EeMG05MGE`0304Q8B005034a<@10@400@41004];B`1ADE400P1BDU801@1:BTX0
?Shn03hn?P0Y:BT0Bd];0080Hf=S00@0Fe]K04e=C@1=CDd0AdM70P0o?cl01@0n?Sh0Bd];05EEE@1E
EED0JVYZ0080H61P00<0E5AD04A4A014A4@00P0h>3P203Ti>@04034a<@0h>3P0>3Ph04E5A@80@410
00D0>c/k04Y:BP1IFET0FEUI05YJFP0206EUI@0506MWI`1GEeL0@T920492@P0l?3`00P1CDe<01@1A
DE40CDe=04e=C@11@D40?clo0080=SHf00@0:b/[05ADE01DE5@0DE5A0P1BDU801@0n?Sh0@d=303Ti
>@0i>CT0=CDe0080BDU900<0@D51059BDP1=CDd00P1=CDd203Lg=`05069RHP1WIfL0IfMW065QH@1S
Hf<00`1]KFd2075aL@0506YZJP1`L700L71`06IVIP1[Jf/00P1XJ6P01@1CDe<0;2`/02`/;018B4P0
IVIV0080HF5Q00@0Fe]K06IVIP1VIVH0GEeM0P1HF5P01@1<C4`0GEeM06EUI@1UIFD0HF5Q0080>CTi
00D0H61P06][J`1[Jf/0Lg=c075aL@0207]kN`0407EeM@1lO7`0O7al06m_K`80MgMg00D0P82008F5
Q@23Ph<0Ph>306UYJ@0205EEE@0507YjNP1lO7`0Ph>308>3P`20P8000P21PH401@1mOGd0PH610861
P@1jNWX0PX:20080OWin00@0N7Qh07UiN@1iNGT0BTY:0P1kNg/01@1iNGT0HV9R05=CD`1CDe<0E5AD
0080HF5Q00D0LG5a07YjNP1jNWX0NWYj08:2PP0208f=S@0408R8R01UIFD0IFEU069RHQD0ooooRP3o
P0070000oa`0oh003`3oool000T0oooo00@0/K6a08Z:RP2:RXX0NGUi0P2JVYX01@2RXZ80ZJVY0:VY
Z@2/[:`0WYjN0080TY:B00D0SHf=0861P@21PH409RHV0:JVYP020:NWY`040:6QX@2PX:00X:2P09^K
V`<0VYZJ00@0UiNG09jNWP2NWYh0WYjN0P2;Rh/01@2?Shl0TY:B09:BTP1DE5@0TI6A0080W9bL00@0
XJ6Q0:j^[P2^[Zh0/K6a0P2c/k<20;Bd]080][Jf0`2_[jl01@2YZJT0RHV905UIF@1IFET0YZJV0080
XJ6Q00D0YjNW0:RXZ02XZ:P0XJ6Q0:>SX`0209nOW`0409FEU@2JVYX0VYZJ0::RXP80Z:RX00D0ZZZZ
06=SH`0j>SX0>SXj08j>SP0209RHV00309jNWP2VYZH0ZJVY0080ZJVY0P2PX:001@2@T900U9BD09BD
U02SXj<0[Jf]0080YjNW00@0N7Qh06IVIP1VIVH0WIfM0P2VYZH01@2TY:@0[jn_0;6a/@2a/K40[jn_
0080[Zj^00D0YZJV09ZJVP2/[:`0[:b/0;Jf]P020;:b/P0506QXJ01`L700L71`09^KV`2MWId00P2G
UiL0102FUYH0WIfM09fMW@2NWYh209fMW@0509VIV@2HV9P0V9RH09RHV02KVi/00P25QHD01@13@d<0
Jf][06][J`1hN7P0NWYj0080M7Ad00D0Lg=c07IfMP1fMWH0M7Ad06MWI`0205QHF00405aLG01BDU80
DU9B03Lg=`80HV9R00D0JVYZ06UYJ@1YJFT0JFUY06IVIP0206a/K00506m_K`1GEeL0EeMG05iNGP1/
K6`00P1[Jf/01@1cLg<0GemO05mOG`1:BTX0K6a/0080Jf][00@0JFUY06MWI`1WIfL0JFUY0P1XJ6P0
0`1TI6@0oooo0?ooo`0C0?ooogH0oh002@000?l[0?n00080003o00<0oh000?ooo`3oool03@3oool0
00T0oooo00@0];Bd0::RXP2RXZ80T92@0P2CTi<01@2TY:@0Z:RX0:RXZ02a/K40UIFE0080Rh^;00D0
XZ:R09bLW02LW9`0;2`/09^KV`020::RXP0409>CT`2=SHd0SHf=08b<S080QXJ600D0P82008^;R`29
RHT0RHV908F5Q@0206UYJ@05092@T02GUiL0UiNG03hn?P24Q8@00P2<S8`0102=SHd0WYjN09jNWP2P
X:0209fMW@050:JVYP2WYjL0Z:RX0:RXZ02WYjL00P2SXj<01@2PX:00Ti>C06e]K@1]KFd0XZ:R00<0
X:2P0P2SXj<01@2QXJ40X:2P09^KV`2KVi/0Rh^;0080V9RH00D0WinO0:BTY02TY:@0ZZZZ07AdM002
055AD@050:FUY@2QXJ40XJ6Q0:FUY@2YZJT00P2ZZZX0102VYZH0Xj>S0:>SX`2HV9P20:2PX0050:FU
Y@2^[Zh0/;2`0;2`/01_Kfl00P1iNGT01@2XZ:P0ZJVY0:VYZ@2[Zj/0]KFe0080/[:b00D0[jn_0;Vi
^@2i^KT0^KVi0;Jf]P020;Bd]0040;Jf]P2h^;P0^;Rh06m_K`80Ng]k0P2g]kL20;6a/@040:b/[02i
^KT0^KVi0;Vi^@80/k>c00D0[Zj^0;Ng]`2l_;`0_;bl0<30`0020;:b/P0503dm?@1mOGd0OGem0:NW
Y`2c/k<00P2_[jl01@2TY:@0W9bL09bLW02JVYX0S8b<0080XJ6Q00@0/;2`0;^k^`2k^k/0J6QX0P2E
UID01@2i^KT0/K6a0;:b/P2b/[80/;2`0080/k>c00D0YJFU0861P@21PH40XZ:R0:f][@020:ZZZP05
0;2`/025QHD0QHF508:2PP2i^KT00P30`<00102n_[h0`L710<71`@2h^;P20;Vi^@030;Rh^03oool0
oooo01<0ooooMP3oP0090000ob/0oh000P000?l00`3oP000oooo0?ooo`0=0?ooo`002@3oool0102d
];@0XZ:R0::RXP2@T90209>CT`050:BTY02XZ:P0Z:RX0;6a/@2EUID00P2;Rh/01@2RXZ80W9bL09bL
W00/;2`0Vi^K0080XZ:R00@0Ti>C08f=S@2=SHd0S8b<0P26QXH01@20P800Rh^;08V9R@29RHT0QHF5
0080JFUY00D0T92@09NGU`2GUiL0?Shn08B4Q00208b<S00408f=S@2NWYh0WYjN0:2PX080WIfM00D0
YZJV0:NWY`2XZ:P0Z:RX0:NWY`020:>SX`050:2PX02CTi<0KFe]06e]K@2RXZ800`2PX:020:>SX`05
0:6QX@2PX:00Vi^K09^KV`2;Rh/00P2HV9P01@2OWil0Y:BT0:BTY02ZZZX0M7Ad0080DE5A00D0YJFU
0:6QX@2QXJ40YJFU0:VYZ@020:ZZZP040:JVYP2SXj<0Xj>S09RHV080X:2P00D0YJFU0:j^[P2`/;00
/;2`06m_K`0207UiN@050:RXZ02YZJT0ZJVY0:^[Z`2e]KD00P2b/[801@2_[jl0^KVi0;Vi^@2i^KT0
][Jf0080];Bd00@0][Jf0;Rh^02h^;P0Kfm_0P1kNg/20;Ng]`80/K6a00@0[:b/0;Vi^@2i^KT0^KVi
0P2c/k<01@2^[Zh0]kNg0;bl_02l_;`0`<300080/[:b00D0?Cdm07emO@1mOGd0YjNW0;>c/`020:n_
[`050:BTY02LW9`0W9bL09ZJVP2<S8`00P2QXJ40102`/;00^k^k0;^k^`1XJ6P209FEU@050;Vi^@2a
/K40/[:b0;:b/P2`/;000P2c/k<01@2UYJD0PH610861P@2RXZ80[Jf]0080ZZZZ00D0/;2`08F5Q@25
QHD0PX:20;Vi^@020<30`0040;jn_P31`L40`L710;Rh^080^KVi00<0^;Rh0?ooo`3oool04`3ooolH
0000o`<0oh00E0000?l<0?n000@0003o;P3oP00?0?ooo`002@3oool0102[Zj/0YJFU0:FUY@2DU9@2
08f=S@050:2PX02VYZH0YZJV0:NWY`2>SXh00P29RHT01@2OWil0Ti>C09>CT`0/;2`0WYjN0080WinO
00@0V9RH08R8R028R8P0Q8B40P1iNGT01@24Q8@0RXZ:08J6QP26QXH0Shn?0080OWin00D0Ti>C096A
T@2ATI40=cLg08:2PP0209:BTP0408J6QP2ATI40TI6A09nOW`80X:2P00D0XJ6Q0:JVYP2YZJT0ZJVY
0:BTY0030:2PX00407moO`1[Jf/0Jf][096AT@80WIfM00D0UiNG09bLW02LW9`0WinO09^KV`0209bL
W00409BDU02FUYH0UYJF0:2PX080Xj>S00D0YJFU075aL@1FEUH0EUIF0:BTY0020:JVYP050:BTY02U
YJD0YJFU0:FUY@2WYjL00P2SXj<01@2JVYX0WYjN09jNWP2UYJD0Z:RX0080YJFU00@0JVYZ061PH01P
H600XJ6Q0P2TY:@01@2/[:`0/k>c0;Bd]02d];@0[Zj^0080]KFe00@0^k^k0;Ng]`2e]KD0]KFe0`2f
][H01@1/K6`0Ph>308>3P`2h^;P0];Bd0080Z:RX00@0ZJVY0;Jf]P2f][H0]kNg0P2c/k<00`2ZZZX0
]kNg0;bl_0020;bl_080^[Zj00D0B4Q809>CT`2CTi<0]kNg0;>c/`020:b/[00509^KV`2IVIT0VIVI
0:JVYP2[Zj/00P2/[:`0102_[jl0^;Rh0;Rh^01ZJVX209NGU`050;Fe]@2d];@0/K6a0;6a/@2c/k<0
0P2b/[801@2][Jd0XZ:R0::RXP2ZZZX0Zj^[0080YjNW00D0[jn_07QhN01hN7P0O7al0;Jf]P020;^k
^`040<C4a02m_Kd0_Kfm0:f][@80]kNg00<0]KFe0?ooo`3oool04`3ooon]0000o`l0oooo00090?oo
o`040:FUY@2QXJ40XJ6Q0:>SX`80WIfM00@0X:2P09jNWP2NWYh0W9bL0`2?Shl01@25QHD0OGem07em
O@0i>CT0WYjN0080X:2P00@0YZJV0:BTY02TY:@0Vi^K0P24Q8@01@28R8P0PH6108V9R@29RHT0T92@
0080Vi^K00D0UYJF09RHV02HV9P0?Shn0820P00308>3P`80TY:B00D0UYJF092@T02@T900SHf=096A
T@020:6QX@050:>SX`2PX:00X:2P09jNWP1aLG400P1GEeL0101WIfL0Ph>308>3P`2ATI4208f=S@05
09bLW02IVIT0W9bL09bLW026QXH00P2BTY801@2PX:00XJ6Q0:6QX@2OWil0QHF50080IVIV00D0WIfM
0:RXZ02XZ:P0YjNW0:>SX`020:6QX@040:>SX`2KVi/0Vi^K08n?S`80S8b<0P2CTi<2096AT@0407Ee
M@1QHF40HF5Q08^;R`80UIFE00D0X:2P0:NWY`2SXj<0Xj>S0:6QX@020:ZZZP050;6a/@2`/;00];Bd
0;Bd]02g]kL00P2e]KD01@1bLW80UIFE09FEU@2g]kL0/[:b0080VYZJ00@0ZJVY0;Bd]02d];@0/[:b
0P2^[Zh00`2XZ:P0][Jf0;Vi^@020;Vi^@80^;Rh00D0@D5109^KV`2KVi/0^[Zj0;Vi^@020:j^[P03
09^KV`2WYjL0YjNW00@0[Zj^00@0[jn_0;Vi^@2i^KT0J6QX0P2JVYX40;6a/@040;Bd]02_[jl0[jn_
0:JVYP80Z:RX00D0YJFU0:^[Z`2XZ:P0Z:RX0:j^[P0207emO@0508:2PP2i^KT0^k^k0;^k^`31`L40
0P2j^[X0102[Zj/0/;2`0;2`/02d];@E0?oooc80oh000`000?mh0?n000l0oooo00090?ooo`0407=c
L`1VIVH0IVIV06MWI`80G5aL00D0@41004I6AP16ATH0@T9203Xj>P0203Ti>@0502HV9P0W9bL09bLW
02TY:@15ADD00P1CDe<0101BDU80De=C05=CD`12@T8204Q8B00503dm?@19BDT0Cdm?04m?C`1LG5`0
0P1<C4`01@13@d<0=3@d03@d=00n?Sh0De=C0080BDU900@0CTi>05eMG@1MGEd0IVIV0P1CDe<01@1:
BTX0AdM704m?C`1?Cdl0FEUI0080D51@00D0HF5Q04e=C@19BDT0BDU904E5A@02051@D00504E5A@17
AdL0AdM704];B`1NGUh00P1GEeL0101?Cdl0EUIF05IFEP1FEUH205YJFP0505EEE@1:BTX0ATI604I6
AP1aLG400P1[Jf/01@1^KVh0JVYZ06QXJ01XJ6P0IVIV0080I6AT00D0KFe]06=SH`1SHf<0H61P06YZ
JP0206ATI00405IFEP1?Cdl0Cdm?04i>CP80Fe]K00D0L71`07=cL`1eMGD0MGEe07=cL`0206UYJ@05
06EUI@1aLG40Kfm_06m_K`1`L7000P1^KVh01@0k>c/0Hf=S06=SH`20P800Ng]k0080MGEe00@0PH61
08B4Q024Q8@0OGem0P23Ph<01@1jNWX0O7al07MgM`1gMgL0O7al0080MWIf00D0=CDe079bLP1bLW80
QHF508B4Q00207emO@0505aLG01dM7@0M7Ad07inOP24Q8@00P2<S8`0102@T900TY:B09:BTP1OGel2
07EeM@0508N7Q`2:RXX0QHF508F5Q@1nOWh00P1hN7P01@1`L700OWin07inOP20P800R8R80080PH61
00D0PX:206EUI@1UIFD0HF5Q09ZJVP020::RXP040:2PX02MWId0WIfM07]kN`80TI6A00<0UiNG0?oo
o`3oool04`3ooolb0?n000<0003oN03oP00?0?ooo`002@3oool0101cLg<0IVIV06IVIP1WIfL205aL
G0050410@016ATH0ATI60492@P0j>SX00P0i>CT01@0V9RH09bLW02LW9`0Y:BT0ADE50080De=C00@0
DU9B05=CD`1CDe<0@T920P18B4P01@0m?Cd0BDU904m?C`1?Cdl0G5aL0080C4a<00D0@d=303@d=00d
=3@0?Shn05=CD`0204U9B@0404i>CP1MGEd0GEeM06IVIP80De=C00D0BTY:04M7A`1?Cdl0Cdm?05UI
F@02051@D005065QH@1=CDd0BDU904U9B@15ADD00P1@D5001@15ADD0AdM704M7A`1;Bd/0GUiN0080
EeMG00@0Cdm?05IFEP1FEUH0EUIF0P1JFUX01@1EEED0BTY:04I6AP16ATH0LG5a0080Jf][00D0KVi^
06YZJP1XJ6P0J6QX06IVIP0206ATI00506e]K@1SHf<0Hf=S061PH01ZJVX00P1TI6@0101FEUH0Cdm?
04m?C`1>CTh205]KF`05071`L01cLg<0MGEe07EeM@1cLg<00P1YJFT01@1UIFD0LG5a06m_K`1_Kfl0
L71`0080KVi^00D0>c/k06=SH`1SHf<0P82007]kN`0207EeM@040861P@24Q8@0Q8B407emO@80Ph>3
00D0NWYj07alO01gMgL0MgMg07alO00207IfMP0503De=@1bLW80LW9b08F5Q@24Q8@00P1mOGd01@1L
G5`0M7Ad07AdM01nOWh0Q8B40080S8b<00@0T92@09:BTP2BTY80GemO0P1eMGD01@27QhL0RXZ:08F5
Q@25QHD0OWin0080N7Qh00D0L71`07inOP1nOWh0P82008R8R0020861P@0508:2PP1UIFD0IFEU065Q
H@2JVYX00P2RXZ80102PX:00WIfM09fMW@1kNg/2096AT@0309NGU`3oool0oooo01<0ooooK`3oP005
0000oa80oh007P000?l01@3oP000003o0?n0003oP000003o00@0oh003`3oool000T0oooo00@0[jn_
0:BTY02TY:@0YJFU0P2GUiL01@1<C4`0P8200820P02BTY80VIVI0080UiNG00D0Rh^;09:BTP2BTY80
UIFE0:6QX@020:>SX`040:RXZ02WYjL0YjNW0:VYZ@80UIFE00D0CDe=05MGE`2SXj<0Xj>S09VIV@02
0820P0050:2PX02RXZ80XZ:R09nOW`2KVi/00P2HV9P0102JVYX0WYjN09jNWP2PX:020:NWY`0507Ui
N@1XJ6P0VIVI09VIV@2JVYX00P2;Rh/01@24Q8@0TY:B08J6QP26QXH0SXj>0080U9BD00D0UIFE092@
T02@T900V9RH096AT@0205eMG@0407IfMP2LW9`0W9bL0:RXZ080YJFU00D0U9BD096AT@2@T900T92@
09>CT`02092@T080Rh^;0P2PX:00102TY:@0GemO05mOG`1dM7@208R8R00508N7Q`1oOgl0Ph>308>3
P`2=SHd00P26QXH01@2=SHd0RXZ:08Z:RP29RHT0Ph>30080QXJ600D0NGUi04I6AP16ATH0QHF50820
P0020861P@0408R8R02<S8`0S8b<08V9R@80M7Ad00D0I6AT06=SH`1OGel0GemO05aLG00202/[:`05
069RHP2:RXX0RXZ:08n?S`2<S8`00P2ATI40102>SXh0S8b<08b<S02<S8`208>3P`0507moO`22PX80
Ogmo07moO`1eMGD00P0j>SX01@1VIVH0Ng]k07]kN`1kNg/0MGEe0080Lg=c00D0MgMg079bLP1bLW80
L71`06UYJ@0206a/K00406IVIP1WIfL0IfMW03Lg=`80@41000D0EUIF05YJFP1?Cdl0Cdm?05MGE`03
05YJFP<0GEeM00@0GUiN069RHP1RHV80GEeM0P1OGel00`0k>c/0oooo0?ooo`0C0?ooodH0oh001000
0?l20?n00140003o1P3oP0000`000?l0oh000000o`030000o`d0oh002@000?l[0?n000<0003o3`3o
ool000T0oooo00@0][Jf0;6a/@2a/K40[:b/0P2ZZZX0101<C4`0R8R808R8R02YZJT30:n_[`040;6a
/@2b/[80/[:b0;Jf]P<0];Bd00@0YZJV0:>SX`2SXj<0[:b/0P2IVIT01@1GEeL0F5QH09bLW02LW9`0
UiNG0080RHV900D0VIVI092@T02@T900RXZ:08>3P`0208^;R`0409>CT`2KVi/0Vi^K0:6QX@80YZJV
00D0PX:206i^KP2/[:`0[:b/0:JVYP020:2PX0030:>SX`2KVi/0WinO0080WinO0P2KVi/01@2QXJ40
Y:BT0:BTY02JVYX0S8b<0080FUYJ00@0Ogmo0;Rh^02h^;P0^KVi0P2h^;P01@2QXJ40[jn_0:n_[`2_
[jl0[Jf]0080YZJV00D0YjNW0:FUY@2XZ:P0Z:RX0:^[Z`0207AdM0040:NWY`2`/;00/;2`0:n_[`<0
/;2`00@0];Bd0;Rh^02h^;P0][Jf0P2i^KT01@2j^[X0_[jn0;jn_P2n_[h0];Bd0080GUiN00D0^[Zj
0:n_[`2ZZZX0ZZZZ0;:b/P020;>c/`050;Vi^@2d];@0];Bd0;6a/@2VYZH00P2JVYX0102PX:00<30`
030`<02:RXX20;2`/0040:b/[02YZJT0/;2`0;2`/0<0]KFe00D0[Jf]0:b/[02/[:`0/K6a0;Jf]P02
0;bl_0050:FUY@0g=cL0=cLg0:JVYP2c/k<00P2a/K40102b/[80]KFe0;Fe]@2f][H20:b/[0050:f]
[@2^[Zh0/[:b0;:b/P2^[Zh00P2ZZZX0101TI6@0NGUi07UiN@2f][H30;Ng]`050;Zj^P2d];@0];Bd
0:RXZ02TY:@00P2`/;000`2^[Zh0/[:b0;:b/P030;6a/@03069RHP3oool0oooo01<0ooooAP3oP004
0000o`80oh004@000?l60?n000030000o`3oP000003o00<0003o3@3oP0090000ob/0oh000`000?l?
0?ooo`002@3oool0102f][H0/K6a0;6a/@2/[:`20:ZZZP0404a<C028R8P0R8R80:VYZ@<0[jn_00@0
/K6a0;:b/P2b/[80][Jf0`2d];@0102VYZH0Xj>S0:>SX`2/[:`209VIV@0505MGE`1HF5P0W9bL09bL
W02GUiL00P29RHT01@2IVIT0T92@092@T02:RXX0Ph>30080Rh^;00@0Ti>C09^KV`2KVi/0XJ6Q0P2V
YZH01@22PX80KVi^0:b/[02/[:`0YZJV0080X:2P00<0Xj>S09^KV`2OWil00P2OWil209^KV`050:6Q
X@2TY:@0Y:BT09ZJVP2<S8`00P1JFUX0101oOgl0^;Rh0;Rh^02i^KT20;Rh^0050:6QX@2_[jl0[jn_
0:n_[`2][Jd00P2VYZH01@2WYjL0YJFU0:RXZ02XZ:P0Zj^[0080M7Ad00@0YjNW0;2`/02`/;00[jn_
0`2`/;00102d];@0^;Rh0;Rh^02f][H20;Vi^@050;Zj^P2n_[h0_[jn0;jn_P2d];@00P1NGUh01@2j
^[X0[jn_0:ZZZP2ZZZX0/[:b0080/k>c00D0^KVi0;Bd]02d];@0/K6a0:JVYP0209ZJVP040:2PX00`
<300<30`08Z:RP80/;2`00@0[:b/0:VYZ@2`/;00/;2`0`2e]KD01@2][Jd0[:b/0:b/[02a/K40][Jf
0080_;bl00D0YJFU03Lg=`0g=cL0YZJV0;>c/`020;6a/@040;:b/P2e]KD0]KFe0;Jf]P80[:b/00D0
[Jf]0:j^[P2b/[80/[:b0:j^[P020:ZZZP0406ATI01iNGT0NGUi0;Jf]P<0]kNg00D0^[Zj0;Bd]02d
];@0Z:RX0:BTY0020;2`/0030:j^[P2b/[80/[:b00<0/K6a00<0HV9R0?ooo`3oool04`3oool80000
o`H0oh0080000?l50?n000h0003o203oP0040000ocT0oh0000<0003o0?n0003oP0008@3oP0030000
o`l0oooo00090?ooo`040;>c/`2^[Zh0[Zj^0:b/[080ZJVY00D0>c/k08N7Q`27QhL0[Zj^0:n_[`02
0:ZZZP030:f][@2^[Zh0[Zj^00@0]kNg00@0Y:BT0:6QX@2QXJ40YZJV0P2UYJD01@1XJ6P0E5AD0:FU
Y@2UYJD0XJ6Q00<0UiNG0P2<S8`01@23Ph<0Ng]k07alO01lO7`0Shn?0080WYjN00D0X:2P09nOW`2O
Wil0PX:2075aL@050:NWY`0509^KV`29RHT0W9bL09bLW02QXJ400P2EUID01@2RXZ80YJFU0:FUY@2D
U9@0Ph>30080C4a<00<0O7al0;Bd]02d];@00`2d];@01@2MWId0]KFe0:n_[`2_[jl0ZZZZ0080ZJVY
00D0YjNW0:j^[P2][Jd0[Jf]0:^[Z`02075aL@0509RHV02/[:`0[:b/0;6a/@2^[Zh00P2`/;00102g
]kL0^;Rh0;Rh^02i^KT20;bl_0050<71`@34a<@0_kno0;no_`2XZ:P00P1RHV800`2g]kL0/;2`0:^[
Z`020:^[Z`80[Jf]00D0][Jf0;:b/P2b/[80Zj^[0:>SX`0209nOW`04096AT@0`<300<30`07IfMP80
[Jf]00D0[:b/0:j^[P2_[jl0[jn_0;>c/`020;:b/P040;Bd]02_[jl0[jn_0;Fe]@<0^k^k00D0WYjN
03De=@0e=CD0YZJV0:RXZ0020:f][@040:RXZ02][Jd0[Jf]0:FUY@80Z:RX00D0[:b/0;2`/02`/;00
/;2`0:RXZ0020:^[Z`0506m_K`1fMWH0MWIf0;2`/02^[Zh00P2`/;001@2e]KD0Zj^[0:^[Z`2IVIT0
WinO0080Zj^[00@0/[:b0;6a/@2a/K40];Bd0P2a/K400`1ZJVX0oooo0?ooo`0C0?ooojd0003o3`3o
ool000T0oooo00@0/;2`0:ZZZP2ZZZX0Z:RX0P2ZZZX01@1ADE40MGEe07EeM@2VYZH0Z:RX0080XZ:R
00D0XJ6Q0:JVYP2VYZH0Zj^[0;2`/0020:NWY`040::RXP2PX:00X:2P09ZJVP80XJ6Q00D0IfMW059B
DP2RXZ80XZ:R09ZJVP0209NGU`0309RHV027QhL0QhN70080OGem0P1jNWX0101kNg/0Q8B408B4Q02:
RXX209BDU00507UiN@1fMWH0Y:BT0:BTY02XZ:P00P2VYZH01@2KVi/0UiNG0:BTY02TY:@0ZJVY00<0
X:2P0P2SXj<01@2GUiL0R8R8055AD@1ADE40Q8B400<0[Zj^0P2/[:`00`2OWil0[jn_0:b/[0020:b/
[080XZ:R00D0XJ6Q0:^[Z`2VYZH0YZJV0:FUY@0206=SH`0508V9R@2_[jl0[jn_0:n_[`2[Zj/00P2/
[:`0102XZ:P0WinO09nOW`2l_;`20;fm_@050<?3``32`/80`L710<71`@2LW9`00P1MGEd01@2e]KD0
/k>c0;:b/P2b/[80Xj>S0080WinO00D0ZZZZ0:^[Z`2[Zj/0ZJVY0:BTY00208N7Q`0407alO00m?Cd0
?Cdm06QXJ080YjNW00D0ZZZZ0:b/[02_[jl0[jn_0;Bd]0020;:b/P<0][Jf00D0/k>c0;2`/02_[jl0
[jn_0:b/[00203lo?`80[Jf]0P2ZZZX0102b/[80/k>c0;>c/`2][Jd20;2`/0050:j^[P2g]kL0^k^k
0;^k^`2h^;P00P2i^KT01@1lO7`0MgMg07MgM`2][Jd0/;2`0080/k>c00D0];Bd0:n_[`2_[jl0Zj^[
0:NWY`020:ZZZP040;Bd]02g]kL0]kNg0;Zj^P80/[:b00<0IfMW0?ooo`3oool04`3ooom]0?n000d0
003o303oP0000`000?l0oh000?n0000=0?n00180003o1@3oP00?0?ooo`002@3oool0102`/;00ZZZZ
0:ZZZP2XZ:P20:ZZZP05055AD@1eMGD0MGEe0:JVYP2XZ:P00P2RXZ801@2QXJ40YZJV0:JVYP2[Zj/0
/;2`0080YjNW00@0XZ:R0:2PX02PX:00VYZJ0P2QXJ401@1WIfL0DU9B0::RXP2RXZ80VYZJ0080UiNG
00<0V9RH08N7Q`27QhL00P1mOGd207YjNP0407]kN`24Q8@0Q8B408Z:RP80U9BD00D0NGUi07IfMP2T
Y:@0Y:BT0:RXZ0020:JVYP0509^KV`2GUiL0Y:BT0:BTY02YZJT00`2PX:020:>SX`0509NGU`28R8P0
DE5A055AD@24Q8@00`2^[Zh20:b/[00309nOW`2_[jl0[:b/0080[:b/0P2RXZ801@2QXJ40Zj^[0:JV
YP2VYZH0YJFU0080Hf=S00D0RHV90:n_[`2_[jl0[jn_0:^[Z`020:b/[0040:RXZ02OWil0WinO0;bl
_080_Kfm00D0`l?30<;2`P31`L40`L7109bLW00205eMG@050;Fe]@2c/k<0/[:b0;:b/P2SXj<00P2O
Wil01@2ZZZX0Zj^[0:^[Z`2YZJT0Y:BT0080QhN700@0O7al03dm?@0m?Cd0J6QX0P2WYjL01@2ZZZX0
[:b/0:n_[`2_[jl0];Bd0080/[:b0`2f][H01@2c/k<0/;2`0:n_[`2_[jl0[:b/0080?clo0P2][Jd2
0:ZZZP040;:b/P2c/k<0/k>c0:f][@80/;2`00D0[Zj^0;Ng]`2k^k/0^k^k0;Rh^0020;Vi^@0507al
O01gMgL0MgMg0:f][@2`/;000P2c/k<01@2d];@0[jn_0:n_[`2[Zj/0YjNW0080ZZZZ00@0];Bd0;Ng
]`2g]kL0^[Zj0P2b/[800`1WIfL0oooo0?ooo`0C0?ooofd0oh003@000?l<0?n000030000o`3oP000
oh0000d0oh004P000?l50?n000l0oooo00090?ooo`0407EeM@1aLG40LG5a06UYJ@80Hf=S00D0=3@d
05aLG01LG5`0KVi^06MWI`0306YZJP80Jf][00D0HF5Q06UYJ@1WIfL0IfMW06=SH`0205ADE00504i>
CP1<C4`0C4a<030`<00d=3@00P1]KFd0101eMGD0L71`071`L01`L70206ATI00505YJFP1IFET0Fe]K
05]KF`1CDe<00P1JFUX01@1QHF40J6QX06QXJ00l?3`0CTi>0080MWIf00D0L71`06m_K`1_Kfl0I6AT
065QH@0206IVIP04071`L01OGel0GemO05iNGP80HF5Q00D0E5AD04a<C00b<S80<S8b055AD@0207=c
L`0507EeM@1bLW80LW9b06m_K`1`L7000P1jNWX00`1eMGD0JVYZ06YZJP0205mOG`80EUIF00@0Cdm?
034a<@0a<C40AdM70P1EEED00`1UIFD0KVi^06MWI`0206MWI`80GUiN00D0NGUi08>3P`23Ph<0RXZ:
08J6QP0208>3P`0504Y:BP0o?cl0?clo08R8R022PX800P2<S8`0101oOgl0QhN708N7Q`22PX820820
P00508N7Q`1jNWX0IfMW06MWI`1^KVh00P14A4@01@1QHF40Shn?08n?S`2IVIT0UiNG0080XJ6Q00@0
WYjN092@T02@T900PX:20P2EUID01@2@T900VYZJ09>CT`2CTi<0P8200080=SHf00@0PH6109fMW@2@
T900T92@0`2DU9@01@2GUiL0W9bL09bLW02PX:00Y:BT0080Z:RX00@0Zj^[0:b/[02/[:`0P8200P1T
I6@01@2EUID0Y:BT0:ZZZP2ZZZX0YZJV0080ZZZZ00D0YJFU09fMW@2QXJ40XJ6Q0::RXP020:BTY004
0:ZZZP2YZJT0ZJVY06ATI1D0ooooI@3oP0080000o`H0oh0010000?l<0?n000H0003o7`3oP0020000
o`<0oh003`3oool000T0oooo00@0UiNG09RHV02HV9P0UIFE0P2@T9000`2EUID0T92@092@T00208B4
Q080U9BD00D0W9bL0:2PX02PX:00F5QH06QXJ00208n?S`0408f=S@21PH40PH6108:2PP80RHV900D0
T92@09>CT`2@T900T92@08V9R@0208>3P`0508B4Q01oOgl0Ogmo05ADE00i>CT00P1NGUh0101PH600
I6AT06ATI01[Jf/206UYJ@80H61P0P1/K6`01@1ZJVX0KVi^06i^KP1]KFd0JVYZ0080ATI600@0GemO
06IVIP1VIVH0K6a/0P1VIVH01@1^KVh0Lg=c07inOP1nOWh0MWIf0080NWYj00D0MWIf06][J`1[Jf/0
LG5a069RHP0204I6AP<0Kfm_00D0JFUY06YZJP1WIfL0IfMW06][J`0207AdM00507MgM`1/K6`0K6a/
07IfMP1hN7P00P1fMWH0101;Bd/0>CTi03Ti>@1UIFD2071`L00506][J`1UIFD0Jf][06][J`1_Kfl0
0P1gMgL01@1/K6`0KVi^075aL@1aLG40Kfm_0080IfMW00D0E5AD06a/K01/K6`0KFe]06YZJP02079b
LP<0N7Qh00D0M7Ad071`L01`L700K6a/06QXJ002069RHP0405mOG`0i>CT0>CTi02@T9080<C4a00D0
?3`l03dm?@1:BTX0BTY:04M7A`02055AD@05059BDP1GEeL0Bd];04];B`1?Cdl00P17AdL01@0o?cl0
>SXj03Xj>P1OGel0HF5Q0080HV9R00@0H61P05iNGP1NGUh0I6AT0P1SHf<01@1HF5P0GemO05aLG01L
G5`0EUIF0080D51@00D0=CDe04=3@`1QHF40HF5Q05eMG@02069RHP0405]KF`1PH600H61P05]KFaD0
oooo4P000?l80?n000@0003o7@3oP0030000o`h0oh001P000?mJ0?n000030000o`3oool0oooo00d0
oooo00090?ooo`040;jn_P2i^KT0^KVi0;Fe]@80][Jf00D0^;Rh0;:b/P2b/[80/K6a0:f][@020:j^
[P050;2`/02d];@0];Bd065QH@1kNg/00P2YZJT0102TY:@0WYjN09jNWP2FUYH309jNWP040:JVYP2R
XZ80XZ:R0:6QX@80Y:BT00D0YjNW0:>SX`2SXj<0Hf=S055AD@0208b<S00408V9R@2DU9@0U9BD09NG
U`80VYZJ0P2ZZZX20:f][@050:VYZ@2ZZZX0ZZZZ0:VYZ@2a/K400P1RHV801026QXH0[Zj^0:j^[P2g
]kL20;Rh^0040:j^[P2/[:`0[Jf]0:f][@<0[Zj^00D0[:b/0;2`/02`/;00[:b/0:BTY00206UYJ@05
0:ZZZP2SXj<0Xj>S09RHV02CTi<00P2@T900102OWil0YJFU0:FUY@2TY:@20:FUY@050:VYZ@2VYZH0
YZJV0:JVYP1bLW800P1PH6000`2ZZZX0/;2`0;2`/0020;>c/`80/K6a00D0^;Rh0;Ng]`2g]kL0^KVi
0;Jf]P020;Vi^@040;>c/`2[Zj/0Zj^[08>3P`80YjNW00D0/K6a0;Ng]`2f][H0][Jf0;>c/`020;Bd
]0<0[Zj^00D0]kNg0;Vi^@2g]kL0]kNg0;Rh^002071`L00506IVIP1oOgl0Ogmo0820P02PX:000P2R
XZ801@2ATI40MgMg07MgM`1JFUX0NWYj0080Q8B400@0QHF508>3P`23Ph<0GemO0P1=CDd01@2UYJD0
[:b/0:j^[P2^[Zh0];Bd0080^KVi00D0][Jf0:ZZZP2ZZZX0]kNg0;Vi^@020;no_`050;^k^`2i^KT0
^KVi04=3@`2BTY800P2ZZZX0102YZJT0/[:b0;:b/P2g]kL20;Fe]@030;6a/@3oool0oooo01<0oooo
2@3oP0090000o`@0oh0000<0003o0?n0003oP000KP3oP0070000oal0oh003`3oool000T0oooo00@0
_[jn0;Vi^@2i^KT0]KFe0P2f][H01@2h^;P0/[:b0;:b/P2a/K40[Jf]0080[Zj^00D0/;2`0;Bd]02d
];@0HF5Q07]kN`020:VYZ@040:BTY02NWYh0WYjN09JFUP<0WYjN00@0YZJV0::RXP2RXZ80XJ6Q0P2T
Y:@01@2WYjL0Xj>S0:>SX`1SHf<0DE5A0080S8b<00@0RHV909BDU02DU9@0UiNG0P2JVYX20:ZZZP80
[Jf]00D0ZJVY0:ZZZP2ZZZX0ZJVY0;6a/@02069RHP0408J6QP2^[Zh0[Zj^0;Ng]`80^;Rh00@0[Zj^
0:b/[02][Jd0[Jf]0`2^[Zh01@2/[:`0/;2`0;2`/02/[:`0Y:BT0080JFUY00D0ZZZZ0:>SX`2SXj<0
V9RH09>CT`02092@T00409nOW`2UYJD0YJFU0:BTY080YJFU00D0ZJVY0:JVYP2VYZH0YZJV079bLP02
061PH0030:ZZZP2`/;00/;2`0080/k>c0P2a/K401@2h^;P0]kNg0;Ng]`2i^KT0][Jf0080^KVi00@0
/k>c0:^[Z`2[Zj/0Ph>30P2WYjL01@2a/K40]kNg0;Jf]P2f][H0/k>c0080];Bd0`2^[Zh01@2g]kL0
^KVi0;Ng]`2g]kL0^;Rh0080L71`00D0IVIV07moO`1oOgl0P8200:2PX0020::RXP05096AT@1gMgL0
MgMg05YJFP1jNWX00P24Q8@01025QHD0Ph>308>3P`1OGel204e=C@050:FUY@2/[:`0[Zj^0:j^[P2d
];@00P2i^KT01@2f][H0ZZZZ0:ZZZP2g]kL0^KVi0080_kno00D0^k^k0;Vi^@2i^KT0@d=309:BTP02
0:ZZZP040:VYZ@2b/[80/[:b0;Ng]`80]KFe00<0/K6a0?ooo`3oool04`3oool90?n000T0003o103o
P0000`000?l0oh000?n0001^0?n000L0003o7`3oP00?0?ooo`002@3oool00`2n_[h0^[Zj0;Zj^P03
0;2`/0050;Jf]P2_[jl0[jn_0:n_[`2/[:`00P2_[jl01@2][Jd0/K6a0;6a/@1]KFd0QHF50080[:b/
00@0XJ6Q09^KV`2KVi/0UIFE0P2KVi/01@2IVIT0WIfM0:2PX02PX:00Xj>S0080YJFU00D0YZJV09ZJ
VP2JVYX0H61P051@D00208f=S@0409:BTP2?Shl0Shn?09VIV@80UIFE00D0XZ:R0:>SX`2ZZZX0ZZZZ
0:RXZ0020:>SX`0509nOW`2UYJD0K6a/06a/K023Ph<00P2/[:`01@2][Jd0/;2`0;2`/02RXZ80X:2P
0080Zj^[00@0[Jf]0:b/[02/[:`0ZJVY0P2XZ:P01@2YZJT0WIfM05IFEP1FEUH0YjNW0080Xj>S00D0
V9RH08J6QP2>SXh0SXj>0:BTY0020:JVYP0509^KV`2SXj<0Xj>S0:RXZ02ZZZX00P2WYjL0101^KVh0
JFUY06UYJ@2[Zj/20:n_[`050;Bd]02_[jl0[Zj^0:j^[P2`/;000P2c/k<01@2e]KD0^k^k0;fm_@2m
_Kd0^;Rh0080Y:BT00D0QXJ60:2PX02PX:00[Zj^0;Bd]0020;6a/@<0[jn_00D0YZJV0:b/[02/[:`0
[jn_0;Fe]@020;Rh^0040;>c/`1WIfL0IfMW09BDU080ZZZZ00D0T92@0:6QX@2FUYH0UYJF09VIV@02
08J6QP0505IFEP2FUYH0YjNW0:NWY`2ZZZX00P2/[:`01@1gMgL0G5aL05aLG02/[:`0YJFU0080YjNW
00@0[:b/0;:b/P2b/[80[Zj^0P2?Shl01@2NWYh0^;Rh0;^k^`2k^k/0][Jf0080^KVi00D0G5aL09>C
T`2][Jd0[Jf]0;2`/0020;6a/@040;Fe]@2a/K40/K6a0:f][AD0oooo4P000?l00`3oP000003o0000
o`1Y0000o`80oh002@000?l50?n001l0003o3`3oool000T0oooo00@0/k>c0;2`/02`/;00[:b/0P2X
Z:P01@2YZJT0[:b/0:b/[02[Zj/0[:b/0080[Jf]00D0[Zj^0:f][@2][Jd0N7Qh08B4Q0020::RXP04
09BDU01bLW80LW9b071`L080Ogmo00D0UiNG0:2PX02CTi<0Ti>C0:6QX@020:>SX`0509nOW`2@T900
T92@05EEE@1>CTh00P1oOgl01021PH40SHf=08f=S@2ATI4208J6QP0508Z:RP29RHT0WIfM09fMW@2P
X:000P2KVi/01@2MWId0XZ:R06EUI@1UIFD0Ogmo0080TI6A00D0Y:BT0:b/[02/[:`0XZ:R09JFUP02
09RHV0040:FUY@2TY:@0Y:BT0:NWY`80YZJV00D0YJFU09RHV01NGUh0GUiN0:2PX00209:BTP0509>C
T`28R8P0QHF508F5Q@2PX:000P2SXj<0102RXZ80YJFU0:FUY@2VYZH30:^[Z`0407IfMP22PX80PX:2
0:JVYP80ZJVY00D0[:b/0:JVYP2XZ:P0Z:RX0::RXP030:n_[`<0]KFe00@0/K6a0:FUY@2UYJD0QhN7
0P2IVIT00`2b/[80[jn_0:j^[P020:j^[P80ZJVY00D0X:2P0:NWY`2WYjL0Z:RX0:b/[0020;2`/004
0:RXZ01PH600H61P08^;R`80WYjN00D0Shn?09fMW@2;Rh/0Rh^;08f=S@0208j>SP0505UIF@2DU9@0
WIfM09fMW@2WYjL00P2ZZZX01@1jNWX0FEUI05UIF@2ZZZX0WIfM0080Zj^[00@0Z:RX0:n_[`2_[jl0
Z:RX0P2KVi/01@2a/K40^KVi0;Zj^P2j^[X0^;Rh0080^KVi00@0Kfm_09^KV`2XZ:P0Z:RX0`2_[jl3
0:j^[P030:^[Z`3oool0oooo01<0oooo3`3oP0070000o`P0oh002`000?l:0?n000<0003o403oP002
0000obP0oh009`000?l=0?n000H0003o0`3oP00?0?ooo`002@3oool0102c/k<0/;2`0;2`/02/[:`2
0:RXZ0050:VYZ@2/[:`0[:b/0:^[Z`2/[:`00P2][Jd01@2^[Zh0[Jf]0:f][@1hN7P0Q8B40080XZ:R
00@0U9BD079bLP1bLW80L71`0P1oOgl01@2GUiL0X:2P09>CT`2CTi<0XJ6Q0080Xj>S00D0WinO092@
T02@T900EEEE04i>CP0207moO`040861P@2=SHd0SHf=096AT@80QXJ600D0RXZ:08V9R@2MWId0WIfM
0:2PX00209^KV`0509fMW@2RXZ80IFEU06EUI@1oOgl00P2ATI401@2TY:@0[:b/0:b/[02RXZ80UYJF
0080V9RH00@0YJFU0:BTY02TY:@0YjNW0P2VYZH01@2UYJD0V9RH05iNGP1NGUh0X:2P0080TY:B00D0
Ti>C08R8R025QHD0QHF50:2PX0020:>SX`040::RXP2UYJD0YJFU0:JVYP<0Zj^[00@0MWIf08:2PP22
PX80YZJV0P2YZJT01@2/[:`0YZJV0:RXZ02XZ:P0XZ:R00<0[jn_0`2e]KD0102a/K40YJFU0:FUY@27
QhL209VIV@030;:b/P2_[jl0[Zj^0080[Zj^0P2YZJT01@2PX:00YjNW0:NWY`2XZ:P0[:b/0080/;2`
00@0Z:RX061PH01PH600Rh^;0P2NWYh01@2?Shl0WIfM08^;R`2;Rh/0SHf=0080SXj>00D0FEUI09BD
U02MWId0WIfM0:NWY`020:ZZZP0507YjNP1IFET0FEUI0:ZZZP2MWId00P2[Zj/0102XZ:P0[jn_0:n_
[`2XZ:P209^KV`050;6a/@2i^KT0^[Zj0;Zj^P2h^;P00P2i^KT0101_Kfl0Vi^K0:RXZ02XZ:P30:n_
[`<0[Zj^00<0Zj^[0?ooo`3oool04`3ooolC0?n000050000o`3oP000oh000?n000000?l00P3oP00A
0000o`P0oh001`000?l30?n000050000o`3oP000oh000?n000000?l0103oP00<0000o`/0oh002`00
0?l40?n000H0003o1P3oP0020000o`030?n000000?l0003o0080003o3P3oP0060000o`/0oh001`00
0?l40?n000@0003o3`3oool000T0oooo00@0QXJ607MgM`1gMgL0LW9b0P1eMGD3071`L00506e]K@1W
IfL0Jf][06][J`1XJ6P00P1ZJVX01@0h>3P0H61P07emO@1mOGd0PX:20080NWYj00D0Bd];05eMG@1M
GEd0GUiN06m_K`0207EeM@0406e]K@1aLG40LG5a0861P@80N7Qh00<0?Shn05IFEP1bLW800P1bLW82
07EeM@0507=cL`1WIfL0IfMW05YJFP1?Cdl00P1RHV801@1fMWH0LG5a075aL@1aLG40Jf][0080ATI6
00@0KFe]07MgM`1gMgL0RHV90P20P8001@1aLG40GUiN05ADE01DE5@0Kfm_0080NGUi00D0MWIf07=c
L`1cLg<0MgMg07YjNP0204e=C@0506e]K@1ZJVX0JVYZ07AdM01^KVh00P1UIFD0101ZJVX0GemO05mO
G`1OGel206][J`0506i^KP1_Kfl0I6AT06ATI01DE5@00P1YJFT01@1WIfL0JVYZ06YZJP1jNWX0OGem
0080Lg=c0`2:RXX01@29RHT0Shn?08:2PP22PX80Ogmo0080Q8B400D0LW9b06IVIP1VIVH0S8b<08f=
S@0208n?S`0409>CT`2DU9@0U9BD09BDU080W9bL0P2@T90209JFUP0408J6QP1IFET0FEUI08F5Q@80
PX:200D0P82007moO`1_Kfl0Kfm_07UiN@0206][J`0304];B`1oOgl0TI6A0080TI6A0P2PX:001@1[
Jf/0IVIV06IVIP1kNg/0O7al0080WIfM0`2LW9`01@2BTY80O7al07alO02XZ:P0Y:BT0080UIFE00D0
QhN7075aL@1aLG40EUIF06EUI@0209RHV0040:^[Z`2UYJD0YJFU0:>SX`80ZZZZ00<0/K6a0?ooo`3o
ool04`3ooolC0?n000050000o`3oP000oh000?n000000?l00P3oP00A0000o`P0oh001`000?l30?n0
00050000o`3oP000oh000?n000000?l0103oP00<0000o`/0oh002`000?l40?n000H0003o1P3oP002
0000o`030?n000000?l0003o0080003o3P3oP0060000o`/0oh001`000?l40?n000@0003o3`3oool0
00T0oooo00@0OWin06m_K`1_Kfl0Hf=S0P16ATH01@0`<300LG5a075aL@1cLg<0MGEe0080NGUi00D0
PX:208V9R@29RHT0RHV908B4Q00207QhN004071`L01kNg/0Ng]k07MgM`80EEEE00D0;Rh^05eMG@1W
IfL0IfMW06EUI@0205mOG`<0F5QH00D0EUIF05MGE`1DE5@0E5AD04m?C`03051@D080<c<c00@07QhN
05ADE01]KFd0KFe]0`1UIFD01@1QHF40HV9R06=SH`1SHf<0I6AT0080G5aL00D0I6AT061PH01PH600
GEeM04Q8B002038b<P0405eMG@1RHV80HV9R05mOG`80IFEU00D0HF5Q061PH01NGUh0GUiN05]KF`02
061PH00505iNGP1FEUH0D51@051@D00c<c<00P0X:2P01@0m?Cd0ATI604I6AP12@T80A4A40080FUYJ
00@0GemO05aLG01LG5`0G5aL0P1OGel2065QH@80FEUI00D0>SXj04M7A`17AdL0Hf=S06YZJP0206IV
IP0405mOG`1bLW80LW9b071`L080KFe]00D0MGEe07=cL`1eMGD0MGEe07YjNP02075aL@0503@d=01?
Cdl0Cdm?05iNGP1LG5`00P1:BTX0101JFUX0EeMG05MGE`1GEeL205=CD`0505EEE@16ATH0>SXj03Xj
>P0R8R800P0M7Ad01@0W9bL09RHV03Xj>P0j>SX0ATI60080F5QH00D0GEeM069RHP1RHV80IVIV06e]
K@0206a/K004065QH@1@D500D51@03Lg=`809BDU00D0BTY:03lo?`11@D40@D5103hn?P020410@005
04Q8B01BDU80J6QX06QXJ01cLg<00P1eMGD0101oOgl0MWIf07IfMP1SHf<E0?ooo`T0oh001P000?nN
0?n000l0oooo00090?ooo`040:BTY027QhL0QhN707=cL`80M7Ad00D0?Shn0:RXZ02XZ:P0ZJVY0:n_
[`020:ZZZP050:^[Z`2VYZH0YZJV0:f][@2XZ:P00P2ZZZX0102OWil0YjNW0:NWY`2QXJ4207moO`05
05UIF@2][Jd0Zj^[0:^[Z`2XZ:P00P2ZZZX01@2WYjL0Zj^[0:^[Z`2TY:@0V9RH0080Shn?00@0WYjN
0:>SX`2SXj<0XJ6Q0P1/K6`01@0m?Cd0[Zj^0:^[Z`2[Zj/0ZJVY0080Xj>S00D0WinO0:>SX`2PX:00
X:2P0::RXP020:JVYP050::RXP2BTY80TY:B08f=S@1nOWh00P0l?3`01028R8P0XJ6Q0:6QX@2[Zj/2
0:n_[`050;Bd]02e]KD0]KFe0;Fe]@2c/k<00P2g]kL01@2b/[80YZJV0:j^[P2^[Zh0HF5Q0080ADE5
00<0Lg=c07]kN`1kNg/00P1iNGT209>CT`0409RHV02?Shl0Shn?0861P@<0TY:B00@0R8R808Z:RP2:
RXX0FUYJ0P2EUID01@2`/;00/k>c0;Fe]@2e]KD0];Bd0080/;2`0`2f][H0102i^KT0]KFe0;2`/02`
/;030:j^[P05034a<@2?Shl0Shn?0:n_[`2c/k<00P31`L40102f][H0_[jn0;jn_P2g]kL20;Rh^005
0;jn_P31`L40^[Zj0;Zj^P2[Zj/00P0`<3001@13@d<0QXJ60:^[Z`2[Zj/0[jn_0080];Bd00D0^k^k
0;bl_02l_;`0^k^k0;Bd]0020;2`/0040;6a/@2YZJT0ZJVY09fMW@80M7Ad0P2b/[830:BTY080][Jf
00D0]kNg0;Rh^02l_;`0_;bl0<30`0020<G5a@040=;BdP3@d=00d=3@07IfMQD0oooo00<0003o0?n0
003oP000>P3oP0000`000?l0oh000?n0001Z0?n000<0003o3`3oool000T0oooo00@0Y:BT08N7Q`27
QhL0Lg=c0P1dM7@01@0n?Sh0Z:RX0:RXZ02YZJT0[jn_0080ZZZZ00D0Zj^[0:JVYP2VYZH0[Jf]0:RX
Z0020:ZZZP0409nOW`2WYjL0YjNW0:6QX@80Ogmo00D0FEUI0:f][@2[Zj/0Zj^[0:RXZ0020:ZZZP05
0:NWY`2[Zj/0Zj^[0:BTY02HV9P00P2?Shl0102NWYh0Xj>S0:>SX`2QXJ4206a/K00503dm?@2^[Zh0
Zj^[0:^[Z`2YZJT00P2SXj<01@2OWil0Xj>S0:2PX02PX:00XZ:R0080YZJV00D0XZ:R09:BTP2BTY80
SHf=07inOP0203`l?00408R8R02QXJ40XJ6Q0:^[Z`80[jn_00D0];Bd0;Fe]@2e]KD0]KFe0;>c/`02
0;Ng]`050;:b/P2VYZH0[Zj^0:j^[P1QHF400P15ADD00`1cLg<0Ng]k07]kN`0207UiN@80Ti>C00@0
V9RH08n?S`2?Shl0PH610`2BTY801028R8P0RXZ:08Z:RP1JFUX209FEU@050;2`/02c/k<0]KFe0;Fe
]@2d];@00P2`/;030;Jf]P040;Vi^@2e]KD0/;2`0;2`/0<0[Zj^00D0<C4a08n?S`2?Shl0[jn_0;>c
/`020<71`@040;Jf]P2n_[h0_[jn0;Ng]`80^;Rh00D0_[jn0<71`@2j^[X0^[Zj0:^[Z`02030`<005
04=3@`26QXH0Zj^[0:^[Z`2_[jl00P2d];@01@2k^k/0_;bl0;bl_02k^k/0];Bd0080/;2`00@0/K6a
0:VYZ@2YZJT0WIfM0P1dM7@20;:b/P<0Y:BT0P2f][H01@2g]kL0^;Rh0;bl_02l_;`0`<300080aLG5
00@0d];B0=3@d03@d=00MWIf5@3ooon;0000o`<0oh007`000?l?0?ooo`002@3oool0102^[Zh0UIFE
09FEU@1XJ6P207=cL`0505MGE`2`/;00/;2`0:j^[P2/[:`00P2ZZZX01@2UYJD0YZJV0:JVYP2TY:@0
ZJVY0080QHF500@0OGem09VIV@2IVIT0VYZJ0P2@T9000`1LG5`0Zj^[0:j^[P020:j^[P<0ZZZZ0P2[
Zj/01@2RXZ80XJ6Q09JFUP2FUYH0W9bL0080XJ6Q00D0WYjN07QhN01hN7P0?Cdm0:ZZZP020:f][@05
0:RXZ02QXJ40XJ6Q09jNWP2LW9`00P2MWId00`2RXZ80XJ6Q0:6QX@030::RXP050:2PX01nOWh0?clo
03lo?`2MWId00P2TY:@01@2YZJT0Zj^[0:^[Z`2][Jd0ZJVY0080[jn_00D0[Zj^0;2`/02`/;00[:b/
0:NWY`020:f][@04075aL@1GEeL0EeMG07EeM@<0KVi^00@0JVYZ07MgM`1gMgL0KVi^0P1YJFT0101S
Hf<0MWIf07IfMP29RHT308B4Q00505EEE@27QhL0QhN70;:b/P2e]KD00P2c/k<0102OWil0UYJF09JF
UP2_[jl30;>c/`040:n_[`2`/;00/;2`0:j^[P80Z:RX00D0=SHf09BDU02DU9@0ZJVY0:RXZ0020;6a
/@040:n_[`2g]kL0]kNg0;Rh^080]KFe0P2h^;P20;Zj^P050;Fe]@16ATH0ATI607IfMP2][Jd00P2S
Xj<0102@T900VIVI09VIV@2[Zj/20;6a/@050;:b/P2c/k<0[Zj^0:j^[P2][Jd00P2ZZZX01@2YZJT0
LW9b079bLP2g]kL0];Bd0080/K6a00D0/;2`0;Jf]P2f][H0/[:b0;Bd]0020;^k^`040;Ng]`2k^k/0
^k^k0<;2`P80`<3000<0LG5a0?ooo`3oool04`3ooon;0000o`<0oh007`000?l?0?ooo`002@3oool0
102/[:`0VYZJ09ZJVP1cLg<205]KF`0506MWI`2e]KD0]KFe0;Fe]@2ZZZX00P2][Jd01@2`/;00/k>c
0;>c/`2`/;00Zj^[0080JVYZ00@0O7al0:j^[P2^[Zh0ZZZZ0P2?Shl00`1QHF40[:b/0:b/[0020:b/
[080ZZZZ00<0Z:RX0:b/[02/[:`01@2IVIT208n?S`04096AT@1/K6`0K6a/03lo?`<0/;2`00D0Y:BT
0:RXZ02XZ:P0X:2P0:RXZ0020:NWY`040:^[Z`2WYjL0YjNW0:2PX080Xj>S00D0X:2P07inOP0_;bl0
;bl_09fMW@0209NGU`0509bLW02UYJD0YJFU0:ZZZP2WYjL00P2YZJT01@2/[:`0[jn_0:n_[`2ZZZX0
ZJVY0080[Zj^00@0LG5a04=3@`13@d<0IFEU0P1VIVH01@1ZJVX0Jf][06YZJP1ZJVX0J6QX0080F5QH
00<0Cdm?05iNGP1NGUh00P1eMGD207=cL`0504Q8B023Ph<0Ph>30:n_[`2a/K400P2^[Zh0102SXj<0
W9bL09bLW02MWId20;>c/`050;Bd]02/[:`0[jn_0:n_[`2c/k<00P2_[jl0100g=cL0TY:B09:BTP2Z
ZZX30:b/[0040;:b/P2f][H0][Jf0;bl_080^KVi00D0`<300;^k^`30`<00`<300;Jf]P02059BDP05
07emO@2[Zj/0YJFU0:FUY@2IVIT00P2UYJD01@2/[:`0];Bd0;Bd]02a/K40/[:b0080/;2`00@0[Zj^
0:b/[02/[:`0ZZZZ0P1]KFd20;6a/@80[jn_00<0[Jf]0;:b/P2b/[800P2c/k<20;Jf]P030;Fe]@2h
^;P0^;Rh00<0^;Rh00<0M7Ad0?ooo`3oool04`3oool00`000?l0oh000?n0000W0?n000<0003o3P3o
P0050000oaL0oh003P000?l20?n000030000o`3oP000oh0001`0oh004@000?l20?n00080003o1P3o
P00<0000o`l0oooo00090?ooo`040:b/[02JVYX0VYZJ07=cL`80Fe]K00D0IfMW0;Fe]@2e]KD0]KFe
0:ZZZP020:f][@050;2`/02c/k<0/k>c0;2`/02[Zj/00P1ZJVX0101lO7`0[Zj^0:j^[P2ZZZX208n?
S`03065QH@2/[:`0[:b/0080[:b/0P2ZZZX00`2XZ:P0[:b/0:b/[00509VIV@80Shn?00@0TI6A06a/
K01/K6`0?clo0`2`/;001@2TY:@0Z:RX0:RXZ02PX:00Z:RX0080YjNW00@0Zj^[0:NWY`2WYjL0X:2P
0P2SXj<01@2PX:00OWin02l_;`0_;bl0WIfM0080UiNG00D0W9bL0:FUY@2UYJD0ZZZZ0:NWY`020:VY
Z@050:b/[02_[jl0[jn_0:ZZZP2YZJT00P2^[Zh0101aLG40@d=304=3@`1UIFD206IVIP0506YZJP1[
Jf/0JVYZ06YZJP1XJ6P00P1HF5P00`1?Cdl0GUiN05iNGP0207EeM@80Lg=c00D0B4Q808>3P`23Ph<0
[jn_0;6a/@020:j^[P040:>SX`2LW9`0W9bL09fMW@80/k>c00D0];Bd0:b/[02_[jl0[jn_0;>c/`02
0:n_[`0403Lg=`2BTY80TY:B0:ZZZP<0[:b/00@0/[:b0;Jf]P2f][H0_;bl0P2i^KT01@30`<00^k^k
0<30`030`<00][Jf0080DU9B00D0OGem0:^[Z`2UYJD0YJFU09VIV@020:FUY@050:b/[02d];@0];Bd
0;6a/@2b/[800P2`/;00102^[Zh0[:b/0:b/[02ZZZX206e]K@80/K6a0P2_[jl00`2][Jd0/[:b0;:b
/P020;>c/`80][Jf00<0]KFe0;Rh^02h^;P00`2h^;P00`1dM7@0oooo0?ooo`0C0?oooah0003o00<0
oh000000o`000?l02P000?l60?n000P0003o103oP0050000o`80oh0020000?lA0?n000L0003o00<0
oh000000o`000?l01P000?l20?n000d0003o203oP0030000obD0oh0000<0003o0?ooo`3oool03@3o
ool000T0oooo00@0TI6A08R8R028R8P0K6a/0P1>CTh01@1?Cdl0Rh^;08^;R`25QHD0Lg=c0080MgMg
00D0PX:207EeM@1eMGD0MgMg07moO`0205aLG00406MWI`21PH40PH6108J6QP80IFEU00D0C4a<0861
P@1eMGD0MGEe07MgM`0207inOP0508J6QP28R8P0R8R808>3P`25QHD00P1XJ6P0101bLW80HF5Q065Q
H@1RHV8204Q8B0050410@02;Rh/0TI6A096AT@2@T9000P2;Rh/01@24Q8@0OGem07UiN@1iNGT0LW9b
0080R8R800D0M7Ad075aL@1aLG40K6a/05iNGP0202l_;`0407emO@1kNg/0Ng]k075aL@80PH6100D0
Ph>308R8R026QXH0QXJ607emO@0207QhN005079bLP1aLG40L71`071`L01=CDd00P0a<C401@0`<300
;Bd]02d];@0f=SH0=cLg0080A4A400@0?Shn0410@010@400@4100P1<C4`01@15ADD0E5AD04i>CP1>
CTh0B4Q80080OWin00D0TI6A08n?S`2EUID0UIFE08F5Q@0208N7Q`0507inOP2=SHd0SHf=08Z:RP2;
Rh/00P2<S8`0102CTi<0QHF508F5Q@0h>3P205QHF00508:2PP26QXH0RHV908V9R@1nOWh00P1mOGd0
1021PH40P8200820P01oOgl3075aL@0507MgM`0i>CT0>CTi061PH02JVYX00P2VYZH0102TY:@0Xj>S
0:>SX`2XZ:P20:j^[P050:f][@2YZJT0Xj>S0:>SX`2/[:`00P2NWYh01@1kNg/0Hf=S06=SH`2ATI40
UYJF0080U9BD00D0T92@09>CT`2CTi<0VIVI09^KV`0209fMW@040:BTY02YZJT0ZJVY0:FUY@80V9RH
00<0E5AD0?ooo`3oool04`3ooon]0?n000l0oooo00090?ooo`040451@@12@T80@T9205iNGP80IVIV
00D0KFe]06IVIP1VIVH0GEeM03Hf=P0204U9B@0505UIF@1@D500D51@05EEE@1IFET00P1ADE40100T
92@0=cLg03Lg=`1GEeL2055AD@05061PH01RHV80HF5Q065QH@16ATH00P10@4001@0g=cL0AdM704M7
A`1CDe<0E5AD0080Cdm?00@0:b/[02<S8`0S8b<0>3Ph0P16ATH01@1@D500CDe=034a<@0a<C408B4Q
0080>3Ph00D0ADE504a<C01ADE40DE5A05MGE`0204A4A005034a<@0n?Sh0?Shn06=SH`1YJFT00P1Z
JVX0101KFe/0GUiN05iNGP0V9RH201dM7@0504e=C@1BDU80DE5A055AD@1>CTh00P1BDU801@0/;2`0
?Shn04i>CP1>CTh0FUYJ0080HV9R00D0G5aL055AD@1ADE40:BTY03hn?P0205QHF004051@D01HF5P0
F5QH069RHP80?clo00D09bLW05=CD`1WIfL0IfMW06QXJ002065QH@80GemO0P0f=SH0101LG5`0IVIV
06IVIP1GEeL205aLG00505iNGP1DE5@09RHV02HV9P19BDT00`1RHV8206EUI@0505iNGP17AdL0ADE5
04E5A@1RHV800P1TI6@01@1RHV80De=C05=CD`1NGUh0>CTi0080EEEE00D0GEeM05UIF@1IFET0ATI6
04Q8B00203Lg=`0402TY:@0a<C40<C4a03Xj>P80<30`00D0>3Ph03Hf=P0Z:RX0:RXZ02/[:`0203Lg
=`050451@@0i>CT0>CTi0451@@0j>SX00P0T92@01@0_;bl0?Cdm03dm?@12@T80CTi>0080BDU900@0
@D5103<c<`0c<c<0CDe=0P1<C4`00`18B4P0oooo0?ooo`0C0?ooojd0oh003`3oool000T0oooo00@0
@D510492@P12@T80GUiN0P1VIVH01@1]KFd0IVIV06IVIP1MGEd0=SHf0080BDU900D0FEUI051@D01@
D500EEEE05UIF@02055AD@0402@T900g=cL0=cLg05MGE`80DE5A00D0H61P069RHP1QHF40HF5Q04I6
AP020410@00503Lg=`17AdL0AdM705=CD`1DE5@00P1?Cdl0100[:b/08b<S02<S8`0h>3P204I6AP05
051@D01=CDd0<C4a034a<@0Q8B400P0h>3P01@15ADD0C4a<055AD@1ADE40EeMG0080A4A400D0<C4a
03hn?P0n?Sh0Hf=S06UYJ@0206YZJP0405]KF`1NGUh0GUiN02HV9P807AdM00D0CDe=059BDP1ADE40
DE5A04i>CP02059BDP0502`/;00n?Sh0CTi>04i>CP1JFUX00P1RHV801@1LG5`0DE5A055AD@0Y:BT0
?Shn0080F5QH00@0D51@05QHF01HF5P0HV9R0P0o?cl01@0W9bL0De=C06MWI`1WIfL0J6QX0080HF5Q
0P1OGel203Hf=P0405aLG01VIVH0IVIV05MGE`80G5aL00D0GUiN05ADE00V9RH09RHV04U9B@03069R
HP80IFEU00D0GUiN04M7A`15ADD0ADE5069RHP0206ATI005069RHP1CDe<0De=C05iNGP0i>CT00P1E
EED01@1MGEd0FEUI05UIF@16ATH0B4Q80080=cLg00@0:BTY034a<@0a<C40>SXj0P0`<3001@0h>3P0
=SHf02XZ:P0Z:RX0:b/[0080=cLg00D0@D5103Ti>@0i>CT0@D5103Xj>P0202@T900502l_;`0m?Cd0
?Cdm0492@P1>CTh00P19BDT01011@D40<c<c03<c<`1=CDd204a<C00304Q8B03oool0oooo01<0oooo
4P3oP0000`000?l0oh000?n0000A0?n000030000o`3oP000oh0000h0oh000P000?lT0?n00080003o
4@3oP0020000oc/0oh003`3oool000T0oooo00@0NWYj05]KF`1KFe/0Y:BT0P2UYJD01@2ZZZX0/K6a
0;6a/@2g]kL0GUiN0080Ng]k00D0TI6A08R8R028R8P0V9RH0:6QX@0209NGU`0402XZ:P1=CDd0CDe=
09BDU080VIVI00D0Ti>C09bLW02YZJT0ZJVY04m?C`0206=SH`0509JFUP2JVYX0VYZJ09BDU02=SHd0
0P1lO7`303/k>`05065QH@1cLg<0Lg=c05MGE`1hN7P00P2BTY801@0m?Cd0Ng]k07]kN`2SXj<0X:2P
0080Xj>S00@0[Zj^08f=S@2=SHd0@4100P1YJFT01@2?Shl0Vi^K09jNWP2NWYh0TI6A0080TY:B00D0
>CTi06YZJP1ZJVX0[:b/0:>SX`0208R8R00508F5Q@2NWYh0WYjN04Y:BP1^KVh00P2[Zj/0102RXZ80
YZJV0:JVYP2MWId20::RXP0504U9B@2>SXh0[jn_0:n_[`2a/K400P2e]KD01@2m_Kd0YjNW0:NWY`0V
9RH0T92@0080/K6a00D0];Bd0;Jf]P2f][H0^;Rh0;jn_P0203Xj>P040:>SX`31`L40`L710;Vi^@80
/K6a00D0[Zj^09nOW`0_;bl0;bl_08:2PP0208R8R00509:BTP2HV9P0V9RH092@T01eMGD00P1hN7P0
102_[jl0[Zj^0:j^[P2/[:`20:n_[`050;Ng]`1MGEd0UYJF09JFUP2PX:000P2UYJD01@2ZZZX0ZJVY
07AdM01dM7@09RHV0080VYZJ00D0aLG50<71`@31`L40_;bl0:n_[`0205]KF`0403lo?`2XZ:P0Z:RX
0:RXZ080YjNW00D0Xj>S09RHV01<C4`0C4a<06QXJ00208j>SP80[Zj^0P2f][H0102PX:00@D510451
@@2`/;030;Rh^1D0oooo:P000?l00`3oP000003o0000o`1g0000o`80oh001`000?l?0?ooo`002@3o
ool0102;Rh/0KVi^06i^KP2PX:020:FUY@050:RXZ02e]KD0]KFe0;^k^`1SHf<00P1JFUX01@2SXj<0
Shn?08n?S`2OWil0Z:RX0080/;2`00@0BDU905=CD`1CDe<0SXj>0P2EUID01@2@T900SHf=09RHV02H
V9P0FUYJ0080HF5Q00D0Vi^K09ZJVP2JVYX0SXj>07emO@0207=cL`0403Xj>P0i>CT0>CTi05eMG@80
OWin00D0I6AT07MgM`26QXH0QXJ604a<C00207QhN00509FEU@2IVIT0UIFE09FEU@2XZ:P00P2@T900
1@1<C4`0Kfm_06m_K`2KVi/0Z:RX0080X:2P00@0VYZJ09bLW02LW9`0CTi>0P1bLW801@2_[jl0ZZZZ
0:2PX02PX:00WYjN0080Vi^K00D0Bd];06i^KP2ZZZX0ZZZZ0:RXZ0020:JVYP0509^KV`2MWId0WIfM
04U9B@2FUYH00P2h^;P0102f][H0^KVi0;Vi^@2n_[h20;Jf]P0505=CD`2NWYh0/K6a0;6a/@2/[:`0
0P2`/;001@2j^[X0^k^k03dm?@0m?Cd0ZJVY0080_kno00D0_;bl0;Fe]@2e]KD0/[:b09VIV@02038b
<P0407emO@2=SHd0SHf=08n?S`80TI6A00D0PH61069RHP1ZJVX0JVYZ0:j^[P020;>c/`050;Ng]`31
`L40`L710<30`01EEED00P26QXH01@2OWil0XZ:R0::RXP2UYJD0X:2P0080LW9b00@0>3Ph0;Fe]@2e
]KD0][Jf0P2g]kL01@2e]KD0]kNg06ATI01TI6@0MGEe0080[jn_00D0YjNW0:VYZ@2YZJT0[Jf]0:NW
Y`0204M7A`0507YjNP2IVIT0VIVI0::RXP2VYZH00P2_[jl0102b/[80Cdm?04m?C`2c/k<30;Rh^1D0
oooo0`000?l00`3oP000003o0?n000030?n001H0003o303oP0120000o`<0oh0020000?l60?n002<0
003o1@3oP0070000o`l0oooo00090?ooo`0408n?S`1gMgL0MgMg0:ZZZP80YZJV00D0/K6a0;jn_P2n
_[h0_kno05YJFP0207=cL`050:RXZ02>SXh0SXj>0:NWY`2d];@00P2][Jd01014A4@0JFUY06UYJ@2L
W9`2092@T00508f=S@2>SXh0XJ6Q0:6QX@1BDU800P1VIVH01@2?Shl0Ogmo07moO`1_Kfl0KFe]0080
HF5Q00@0=3@d03Ti>@0i>CT0DE5A0P1IFET01@1KFe/0HF5Q07EeM@1eMGD0?Shn0080Ng]k00D0Vi^K
0:6QX@2WYjL0YjNW0:RXZ00209NGU`0504M7A`1jNWX0NWYj09nOW`2GUiL00P2DU9@01027QhL0Ti>C
09>CT`1BDU8207YjNP050:f][@2XZ:P0W9bL09bLW02BTY800P2MWId01@1:BTX0LW9b0::RXP2RXZ80
YJFU0080Y:BT00D0YjNW09NGU`2GUiL0?clo09RHV0020;Rh^0<0]kNg00D0^;Rh0;:b/P2b/[80CDe=
09VIV@020:VYZ@050:NWY`2ZZZX0ZZZZ0;>c/`2i^KT00P0k>c/0102XZ:P0_Kfm0;fm_@2j^[X20;Rh
^0050;Vi^@2TY:@0=cLg03Lg=`20P8000P28R8P01@1oOgl0Ng]k07]kN`26QXH0J6QX0080LW9b00@0
/[:b0;Rh^02h^;P0^KVi0P30`<001@2k^k/0F5QH09jNWP2NWYh0ZJVY0080YjNW00D0YZJV0:6QX@1[
Jf/0Jf][04];B`020;Fe]@050;:b/P2_[jl0[jn_0;Bd]02c/k<00P1`L7000`1fMWH0/;2`0;2`/003
0:ZZZP050;6a/@2][Jd0?3`l03`l?01lO7`00P2FUYH20:FUY@80Vi^K00@0IVIV04U9B@19BDT0/[:b
0P2j^[X00`2g]kL0oooo0?ooo`0C0?ooo`<0003o00<0oh000000o`3oP0000`3oP00F0000o``0oh00
@P000?l30?n000P0003o1P3oP00S0000o`D0oh001`000?l?0?ooo`002@3oool0102?Shl0MgMg07Mg
M`2ZZZX20:JVYP050;6a/@2n_[h0_[jn0;no_`1JFUX00P1cLg<01@2XZ:P0SXj>08j>SP2WYjL0];Bd
0080[Jf]00@0A4A406UYJ@1YJFT0W9bL0P2@T9001@2=SHd0SXj>0:6QX@2QXJ40DU9B0080IVIV00D0
Shn?07moO`1oOgl0Kfm_06e]K@02065QH@0403@d=00i>CT0>CTi055AD@80FEUI00D0Fe]K065QH@1e
MGD0MGEe03hn?P0207]kN`0509^KV`2QXJ40YjNW0:NWY`2XZ:P00P2GUiL01@17AdL0NWYj07YjNP2O
Wil0UiNG0080U9BD00@0QhN709>CT`2CTi<0DU9B0P1jNWX01@2][Jd0Z:RX09bLW02LW9`0TY:B0080
WIfM00D0BTY:079bLP2RXZ80XZ:R0:FUY@020:BTY0050:NWY`2GUiL0UiNG03lo?`2HV9P00P2h^;P3
0;Ng]`050;Rh^02b/[80/[:b04e=C@2IVIT00P2YZJT01@2WYjL0ZZZZ0:ZZZP2c/k<0^KVi0080>c/k
00@0Z:RX0;fm_@2m_Kd0^[Zj0P2h^;P01@2i^KT0Y:BT03Lg=`0g=cL0P8200080R8R800D0Ogmo07]k
N`1kNg/0QXJ606QXJ002079bLP040;:b/P2h^;P0^;Rh0;Vi^@80`<3000D0^k^k05QHF02NWYh0WYjN
0:VYZ@020:NWY`050:JVYP2QXJ40Jf][06][J`1;Bd/00P2e]KD01@2b/[80[jn_0:n_[`2d];@0/k>c
0080L71`00<0MWIf0;2`/02`/;000`2ZZZX01@2a/K40[Jf]03`l?00l?3`0O7al0080UYJF0P2UYJD2
09^KV`0406IVIP19BDT0BDU90;:b/P80^[Zj00<0]kNg0?ooo`3oool04`3ooolJ0?n000D0003o9P3o
P0040000ob@0oh001`000?l40?n000@0003o<@3oP00?0?ooo`002@3oool0102=SHd0HV9R069RHP2L
W9`30:2PX080YJFU00D0W9bL04m?C`14A4@0A4A408J6QP0209RHV0050:j^[P2a/K40XJ6Q0:6QX@0d
=3@00P1LG5`01@2QXJ40TY:B09:BTP2@T900SHf=0080VIVI00@0AdM702`/;00/;2`0R8R80P2:RXX0
1@1eMGD0O7al07emO@1mOGd0CTi>0080FEUI00D0MgMg07EeM@1eMGD0IFEU05aLG0020820P00504];
B`25QHD0QHF509ZJVP2[Zj/00P2b/[80102YZJT0X:2P0:2PX013@d<2061PH0050:NWY`2OWil0T92@
092@T022PX800P28R8P01@1DE5@0L71`071`L02IVIT0WIfM0080TY:B00D0QXJ607MgM`1gMgL0@d=3
07AdM00209fMW@0408N7Q`22PX80PX:209RHV080Vi^K00<0IVIV09^KV`2b/[800P2b/[820;Fe]@05
0:^[Z`2=SHd0SHf=0492@P2IVIT00P2SXj<00`2ZZZX0/K6a0;6a/@020;Rh^080C4a<00@0Xj>S0;Fe
]@2e]KD0/;2`0P2XZ:P01@2TY:@0T92@038b<P0b<S80Bd];0080GUiN00D0K6a/08>3P`23Ph<0Ph>3
05aLG00205IFEP0408b<S02GUiL0UiNG09JFUP80V9RH00D0XZ:R096AT@2][Jd0[Jf]0;:b/P020;6a
/@050:^[Z`2VYZH0LW9b079bLP1TI6@00P2f][H30;Bd]0050;Vi^@2k^k/0LW9b079bLP23Ph<00P2`
/;001@2[Zj/0[:b/0:b/[02`/;00[Zj^0080ATI600D0Ng]k0:j^[P2^[Zh0Z:RX0:2PX00209:BTP04
07emO@1BDU80DU9B0;:b/P80/k>c00<0];Bd0?ooo`3oool04`3ooon]0?n000l0oooo00090?ooo`04
06UYJ@1HF5P0F5QH051@D080?clo00D0<S8b03@d=00d=3@0=CDe03<c<`0203/k>`0504U9B@1?Cdl0
Cdm?04i>CP1CDe<00P1@D500101;Bd/0EEEE05EEE@1FEUH203lo?`0503Ti>@18B4P0CDe=04e=C@1A
DE400P1;Bd/01@1@D500De=C05=CD`1JFUX0DE5A0080ATI600@0>SXj038b<P0b<S80?Shn0P0T92@0
1@0Z:RX0C4a<04A4A014A4@0>SXj0080Bd];00D0CTi>06UYJ@1[Jf/0Jf][06m_K`02069RHP0505=C
D`1OGel0GemO05QHF00];Bd00P1CDe<0101JFUX0ADE504E5A@18B4P204M7A`0506QXJ01bLW80N7Qh
07QhN01@D5000P1HF5P01@1GEeL0BTY:03Ph>00h>3P092@T0080C4a<00D0FEUI05iNGP1NGUh0F5QH
05]KF`0206IVIP<0IfMW00D0FUYJ05=CD`1CDe<0BDU904];B`0204M7A`0502l_;`1;Bd/0Bd];05YJ
FP1RHV800P1IFET0101]KFd0LG5a075aL@1XJ6P206IVIP0506ATI01JFUX0FEUI05UIF@1DE5@00P11
@D401@0g=cL0Bd];04];B`1GEeL0@T920080ADE500@0EUIF05YJFP1JFUX0D51@0P1HF5P01@1^KVh0
Ogmo07UiN@1iNGT0KVi^0080@T9200D0EeMG06EUI@1QHF40HF5Q06IVIP0208>3P`0308B4Q01nOWh0
OWin0080O7al0P1HF5P0101NGUh0G5aL05aLG01BDU8205MGE`05069RHP1MGEd0Bd];04];B`1MGEd0
0P1RHV801@1MGEd0EUIF05ADE01DE5@0@T920080>c/k00@0CDe=05=CD`1CDe<0EUIF5@3ooon]0?n0
00l0oooo00090?ooo`0406UYJ@1HF5P0F5QH051@D080?clo00D0<S8b03@d=00d=3@0=CDe03<c<`02
03/k>`0504U9B@1?Cdl0Cdm?04i>CP1CDe<00P1@D500101;Bd/0EEEE05EEE@1FEUH203lo?`0503Ti
>@18B4P0CDe=04e=C@1ADE400P1;Bd/01@1@D500De=C05=CD`1JFUX0DE5A0080ATI600@0>SXj038b
<P0b<S80?Shn0P0T92@01@0Z:RX0C4a<04A4A014A4@0>SXj0080Bd];00D0CTi>06UYJ@1[Jf/0Jf][
06m_K`02069RHP0505=CD`1OGel0GemO05QHF00];Bd00P1CDe<0101JFUX0ADE504E5A@18B4P204M7
A`0506QXJ01bLW80N7Qh07QhN01@D5000P1HF5P01@1GEeL0BTY:03Ph>00h>3P092@T0080C4a<00D0
FEUI05iNGP1NGUh0F5QH05]KF`0206IVIP<0IfMW00D0FUYJ05=CD`1CDe<0BDU904];B`0204M7A`05
02l_;`1;Bd/0Bd];05YJFP1RHV800P1IFET0101]KFd0LG5a075aL@1XJ6P206IVIP0506ATI01JFUX0
FEUI05UIF@1DE5@00P11@D401@0g=cL0Bd];04];B`1GEeL0@T920080ADE500@0EUIF05YJFP1JFUX0
D51@0P1HF5P01@1^KVh0Ogmo07UiN@1iNGT0KVi^0080@T9200D0EeMG06EUI@1QHF40HF5Q06IVIP02
08>3P`0308B4Q01nOWh0OWin0080O7al0P1HF5P0101NGUh0G5aL05aLG01BDU8205MGE`05069RHP1M
GEd0Bd];04];B`1MGEd00P1RHV801@1MGEd0EUIF05ADE01DE5@0@T920080>c/k00@0CDe=05=CD`1C
De<0EUIF5@3ooon]0?n000l0oooo00090?ooo`040:ZZZP2WYjL0YjNW09fMW@80KVi^00D0=cLg08^;
R`2;Rh/0W9bL0:2PX0050:NWY`050:b/[02^[Zh0[Zj^0:j^[P2ZZZX00P2/[:`01@2XZ:P0MWIf07If
MP1SHf<0T92@0080S8b<00@0W9bL08>3P`23Ph<0Q8B40P2JVYX01@2MWId0UIFE08f=S@2=SHd0N7Qh
0080Rh^;00D0SHf=065QH@1QHF40HV9R0:6QX@020:JVYP050:NWY`2UYJD0YJFU0::RXP2VYZH00P2[
Zj/00`2^[Zh0/K6a0;6a/@030;6a/@050;:b/P1<C4`0Ti>C09>CT`2XZ:P00`2OWil209VIV@050:^[
Z`2^[Zh0[:b/0:b/[02VYZH00P2RXZ801@2ZZZX0X:2P0:BTY02TY:@0?3`l0080YZJV00@0ZZZZ0:n_
[`2_[jl0Z:RX0`2UYJD0102/[:`0Zj^[0:^[Z`2^[Zh20;2`/0050;6a/@2b/[80/[:b0;:b/P12@T80
0P2OWil01@2XZ:P0/[:b0:n_[`2_[jl0/K6a0080^;Rh00D0/K6a0;:b/P2b/[80[:b/0:FUY@020:RX
Z0040:b/[02LW9`0W9bL08F5Q@80];Bd00D0^;Rh0:ZZZP2UYJD0YJFU0;6a/@020:j^[P050;Jf]P2c
/k<0/k>c0;bl_02j^[X00P2a/K401@2^[Zh0EUIF05IFEP2[Zj/0/k>c0080^KVi00@0]kNg0;Zj^P2j
^[X0^k^k0P2j^[X01@2h^;P0/K6a0:NWY`2WYjL0Y:BT0080[Zj^00D0L71`06ATI01TI6@0SHf=09NG
U`020::RXP030:b/[02`/;00/;2`0080[Zj^0P2b/[80102a/K40/k>c0;>c/`2g]kL20:j^[P03065Q
H@3oool0oooo01<0oooo9P000?l00`3oP000003o0000o`240000o`l0oooo00090?ooo`040:^[Z`2T
Y:@0Y:BT0:ZZZP80IVIV00D0HF5Q0:RXZ02XZ:P0WYjN08Z:RP0209RHV0050:2PX02MWId0WIfM09jN
WP2QXJ400P2TY:@0102OWil0Y:BT0:BTY02SXj<208R8R00506QXJ02IVIT0VYZJ09ZJVP2RXZ800P2<
S8`01@29RHT0Shn?08n?S`2JVYX0Shn?0080SXj>00@0SHf=09NGU`2GUiL0TI6A0P1XJ6P01@24Q8@0
Y:BT0:VYZ@2YZJT0YJFU0080XJ6Q00D0WYjN09bLW02MWId0WIfM09nOW`020:>SX`050:JVYP2ZZZX0
ZZZZ0;:b/P1XJ6P00P2IVIT0102YZJT0WYjN09jNWP2GUiL208f=S@050:JVYP2ZZZX0YjNW0:NWY`2Y
ZJT00P2IVIT01@2VYZH0XJ6Q0:BTY02TY:@0GemO0080X:2P00D0Y:BT0:JVYP2VYZH0Y:BT092@T002
09ZJVP040:BTY02RXZ80XZ:R0:FUY@80YZJV00D0ZZZZ0:f][@2][Jd0[Jf]03lo?`020:BTY0050:RX
Z02^[Zh0/[:b0;:b/P2a/K400P2][Jd01@2TY:@0WinO09nOW`2ZZZX0[Jf]0080/[:b00@0/K6a0:2P
X02PX:00QXJ60`2h^;P0102][Jd0Zj^[0:^[Z`2j^[X20;Fe]@050;bl_02g]kL0]kNg0<71`@2o_kl0
0P2i^KT01@2c/k<0GUiN05iNGP2^[Zh0];Bd0080][Jf00<0_[jn0;fm_@2m_Kd00`30`<001@2n_[h0
/[:b0:JVYP2VYZH0YjNW0080]KFe00D0MWIf07QhN01hN7P0Z:RX0:^[Z`020:RXZ0050:^[Z`2][Jd0
[Jf]0:NWY`2YZJT00`2WYjL20:ZZZP040:^[Z`2][Jd0[Jf]06IVIQD0ooooD@000?l00`3oP000003o
0000o`1I0000o`l0oooo00090?ooo`040:^[Z`2TY:@0Y:BT0:ZZZP80IVIV00D0HF5Q0:RXZ02XZ:P0
WYjN08Z:RP0209RHV0050:2PX02MWId0WIfM09jNWP2QXJ400P2TY:@0102OWil0Y:BT0:BTY02SXj<2
08R8R00506QXJ02IVIT0VYZJ09ZJVP2RXZ800P2<S8`01@29RHT0Shn?08n?S`2JVYX0Shn?0080SXj>
00@0SHf=09NGU`2GUiL0TI6A0P1XJ6P01@24Q8@0Y:BT0:VYZ@2YZJT0YJFU0080XJ6Q00D0WYjN09bL
W02MWId0WIfM09nOW`020:>SX`050:JVYP2ZZZX0ZZZZ0;:b/P1XJ6P00P2IVIT0102YZJT0WYjN09jN
WP2GUiL208f=S@050:JVYP2ZZZX0YjNW0:NWY`2YZJT00P2IVIT01@2VYZH0XJ6Q0:BTY02TY:@0GemO
0080X:2P00D0Y:BT0:JVYP2VYZH0Y:BT092@T00209ZJVP040:BTY02RXZ80XZ:R0:FUY@80YZJV00D0
ZZZZ0:f][@2][Jd0[Jf]03lo?`020:BTY0050:RXZ02^[Zh0/[:b0;:b/P2a/K400P2][Jd01@2TY:@0
WinO09nOW`2ZZZX0[Jf]0080/[:b00@0/K6a0:2PX02PX:00QXJ60`2h^;P0102][Jd0Zj^[0:^[Z`2j
^[X20;Fe]@050;bl_02g]kL0]kNg0<71`@2o_kl00P2i^KT01@2c/k<0GUiN05iNGP2^[Zh0];Bd0080
][Jf00<0_[jn0;fm_@2m_Kd00`30`<001@2n_[h0/[:b0:JVYP2VYZH0YjNW0080]KFe00D0MWIf07Qh
N01hN7P0Z:RX0:^[Z`020:RXZ0050:^[Z`2][Jd0[Jf]0:NWY`2YZJT00`2WYjL20:ZZZP040:^[Z`2]
[Jd0[Jf]06IVIQD0ooooD@000?l00`3oP000003o0000o`1I0000o`l0oooo00090?ooo`040:n_[`2Y
ZJT0ZJVY0:b/[080GEeM00D0AdM70:FUY@2UYJD0WinO08f=S@02096AT@050::RXP2VYZH0YZJV0:NW
Y`2TY:@00P2PX:00102NWYh0YjNW0:NWY`2TY:@208b<S00506EUI@2QXJ40XZ:R0::RXP2UYJD00P2O
Wil01@2JVYX0S8b<08b<S02<S8`0VIVI0080PX:200@0N7Qh08N7Q`27QhL0SHf=0P1YJFT01@24Q8@0
Xj>S09^KV`2KVi/0XJ6Q0080WYjN00D0VIVI08J6QP29RHT0RHV909^KV`0209nOW`0509^KV`2VYZH0
YZJV0:b/[01ZJVX00P2LW9`0102XZ:P0Xj>S0:>SX`2SXj<2096AT@050::RXP2QXJ40YJFU0:FUY@2[
Zj/00P2RXZ801@2UYJD0Xj>S09fMW@2MWId0GEeM0080XZ:R00D0WIfM09ZJVP2JVYX0VYZJ09BDU002
09ZJVP0409NGU`2=SHd0SHf=0:2PX080Y:BT00D0YZJV0:RXZ02][Jd0[Jf]04i>CP020:BTY0050::R
XP2TY:@0[Jf]0:f][@2/[:`00P2^[Zh01@2UYJD0XZ:R0::RXP2_[jl0/;2`00<0[Jf]0P2PX:001@24
Q8@0^;Rh0;Rh^02l_;`0/[:b0080[Zj^0`2f][H01@2n_[h0^k^k0;^k^`32`/80_Kfm0080_;bl00<0
]kNg06m_K`1_Kfl00P2b/[820;^k^`040<;2`P2l_;`0_;bl0;jn_P80_Kfm00D0^k^k0:^[Z`2QXJ40
XJ6Q0:VYZ@020;>c/`0506QXJ01aLG40LG5a0:2PX02VYZH00P2ZZZX01@2YZJT0YZJV0:JVYP2NWYh0
WIfM0080X:2P00@0XJ6Q0:RXZ02XZ:P0Xj>S0P2XZ:P00`1gMgL0oooo0?ooo`0C0?ooojd0oh003`3o
ool000T0oooo0`2h^;P0102f][H0LW9b079bLP11@D4209fMW@050:>SX`2PX:00Xj>S0:>SX`2MWId0
0P2OWil01@2UYJD0Z:RX0:j^[P2^[Zh0[:b/0080YjNW00D0XJ6Q08B4Q024Q8@0Hf=S09>CT`020:6Q
X@040:JVYP2TY:@0Y:BT0:6QX@80WinO00D0WIfM09ZJVP29RHT0RHV907EeM@0207]kN`0509VIV@1U
IFD0IFEU08B4Q02RXZ800P2LW9`01@2OWil0WIfM09fMW@2QXJ40S8b<0080Q8B400@0OWin08R8R028
R8P0RXZ:0P2RXZ801@2EUID0ADE509JFUP2FUYH0V9RH0080Q8B400D0V9RH09^KV`2KVi/0ZZZZ0:RX
Z0020:NWY`050:JVYP2MWId0WIfM09nOW`2NWYh00P2JVYX01017AdL0PH610861P@25QHD307alO004
07UiN@24Q8@0Q8B408J6QP80Ti>C00D0VYZJ09nOW`2OWil0YjNW0:RXZ0020:ZZZP0504i>CP2OWil0
WinO09nOW`2VYZH00P2/[:`0102ZZZX0YJFU0:FUY@2JVYX209FEU@0509RHV02NWYh0XJ6Q0:6QX@2L
W9`00P1nOWh01@1hN7P0/;2`0;2`/02b/[80Y:BT0080XJ6Q00@0];Bd0;Vi^@2i^KT0^k^k0P2g]kL0
1@2i^KT0_Kfm0;Vi^@2i^KT0]KFe0080LG5a00D0X:2P0:>SX`2c/k<0/k>c0;Ng]`030;Rh^080/k>c
00D0/[:b0:>SX`2GUiL0UiNG0:>SX`020:n_[`0405]KF`1TI6@0I6AT0:^[Z`<0YJFU00@0YZJV0:>S
X`2SXj<0W9bL0`2OWil0102IVIT0WYjN09jNWP2VYZH20:2PX00308>3P`3oool0oooo01<0oooo[@3o
P00?0?ooo`002@3oool0101VIVH0JFUY06UYJ@1TI6@205ADE00503lo?`1@D500D51@05iNGP1KFe/0
0P1WIfL01@1NGUh0A4A404A4A011@D40BTY:00<0Bd];0P0/;2`01@0[:b/0;Rh^02h^;P0_;bl0<c<c
0080@D5100@0Bd];05YJFP1JFUX0Cdm?0P0m?Cd01@0d=3@0>SXj03Ti>@0i>CT0FEUI0080D51@00D0
HV9R04A4A014A4@0Fe]K06UYJ@0206MWI`0505]KF`1=CDd0CDe=0410@00g=cL00P0l?3`00`19BDT0
Cdm?04m?C`03055AD@0503De=@0X:2P0?3`l03`l?010@4000P0n?Sh01@0m?Cd0@4100410@01=CDd0
>CTi0080<C4a00D0?Shn03lo?`0o?cl0@4100492@P0203`l?00403@d=00`<300<30`03/k>`80<30`
00D0=SHf02l_;`0^;Rh0;Rh^02@T9002038b<P0503/k>`1CDe<0De=C04Q8B01?Cdl00P19BDT01@0^
;Rh0B4Q804Q8B01=CDd0EEEE0080FEUI00@0C4a<055AD@1ADE40<S8b0P14A4@01@16ATH0FEUI05]K
F`1KFe/0GemO0080K6a/00D0IVIV061PH01PH600I6AT05]KF`0204I6AP0403lo?`0d=3@0=3@d038b
<P80CDe=00D0BTY:059BDP1@D500D51@05=CD`0204Y:BP0504U9B@1BDU80GEeM05eMG@1HF5P00P1K
Fe/01@1EEED0IVIV06IVIP1OGel0HF5Q0080F5QH00@0JVYZ06][J`1[Jf/0BTY:0P0c<c<01@1<C4`0
Bd];04=3@`13@d<0@T920080@D5100D0CTi>05MGE`1?Cdl0Cdm?05mOG`0205=CD`0404i>CP18B4P0
B4Q803Ti>AD0ooooAP3oP0020000oa40oh000P000?mB0?n000l0oooo00090?ooo`0406IVIP1YJFT0
JFUY06ATI080E5AD00D0?clo051@D01@D500GUiN05]KF`0206MWI`0505iNGP14A4@0A4A40451@@1:
BTX00`1;Bd/202`/;00502/[:`0^;Rh0;Rh^02l_;`0c<c<00P11@D40101;Bd/0FUYJ05YJFP1?Cdl2
03dm?@0503@d=00j>SX0>CTi03Ti>@1IFET00P1@D5001@1RHV80A4A404A4A01KFe/0JFUY0080IfMW
00D0Fe]K04e=C@1=CDd0@41003Lg=`0203`l?00304U9B@1?Cdl0Cdm?00<0DE5A00D0=CDe02PX:00l
?3`0?3`l0410@00203hn?P0503dm?@10@400@41004e=C@0i>CT00P0a<C401@0n?Sh0?clo03lo?`10
@400@T920080?3`l00@0=3@d030`<00`<300>c/k0P0`<3001@0f=SH0;bl_02h^;P0^;Rh092@T0080
<S8b00D0>c/k05=CD`1CDe<0B4Q804m?C`0204U9B@0502h^;P18B4P0B4Q804e=C@1EEED00P1IFET0
101<C4`0DE5A055AD@0b<S8204A4A00504I6AP1IFET0Fe]K05]KF`1OGel00P1/K6`01@1VIVH0H61P
061PH01TI6@0Fe]K0080ATI600@0?clo03@d=00d=3@0<S8b0P1=CDd01@1:BTX0DU9B051@D01@D500
De=C0080BTY:00D0BDU9059BDP1MGEd0GEeM05QHF00205]KF`0505EEE@1VIVH0IVIV05mOG`1QHF40
0P1HF5P0101ZJVX0Jf][06][J`1:BTX203<c<`0504a<C01;Bd/0@d=304=3@`12@T800P11@D401@1>
CTh0EeMG04m?C`1?Cdl0GemO0080De=C00@0CTi>04Q8B018B4P0>CTi5@3ooom60?n00080003o4@3o
P0020000oe80oh003`3oool000T0oooo00@0Z:RX0:>SX`2SXj<0Xj>S0P2QXJ401@2PX:00Xj>S0:>S
X`2UYJD0WYjN0080W9bL00D0UIFE05IFEP1FEUH0HV9R0;2`/0020:^[Z`040::RXP2ZZZX0ZZZZ0:FU
Y@80YjNW00@0Z:RX0:VYZ@2`/;00/;2`0`2c/k<01@2`/;00DU9B059BDP1EEED0T92@0080U9BD00@0
UIFE0:2PX02PX:00YZJV0P2_[jl01@2`/;00XZ:R09fMW@2MWId0VYZJ0080YZJV00D0WIfM05aLG018
B4P0B4Q80:RXZ0020:>SX`040:2PX02XZ:P0Z:RX0:ZZZP<0Y:BT00@0XJ6Q0:BTY02TY:@0[:b/0P2_
[jl01@2a/K40OGem02`/;00/;2`0P8200080RHV900D0Ti>C09FEU@2MWId0WIfM09JFUP0209RHV005
09>CT`2KVi/0Vi^K09FEU@2TY:@00P2EUID0100m?Cd0GemO05mOG`1UIFD206a/K00506e]K@1fMWH0
QHF508F5Q@2CTi<00P2IVIT01@2BTY80RHV908F5Q@25QHD0Vi^K0080I6AT00D0C4a<0;:b/P2b/[80
]KFe0;>c/`020:^[Z`030;>c/`2k^k/0^k^k00<0_Kfm00D0`/;20;Jf]P2GUiL0UiNG07alO00205YJ
FP0508:2PP3;bl/0bl_;0<?3``2m_Kd00P2g]kL01@2e]KD0]kNg0;Ng]`2c/k<0/[:b00<0][Jf0P2H
V9P00`1`L700][Jf0;Jf]P020;Zj^P80/K6a00@0/;2`0;Fe]@2e]KD0^;Rh0P2c/k<01@2^[Zh0/;2`
0:n_[`2_[jl0Q8B40080?3`l00D0YJFU09jNWP2RXZ80XZ:R0;:b/P020;Fe]@040;>c/`2^[Zh0[Zj^
0:j^[QD0oooo:@000?l90?n003X0003o103oP0080000o`@0oh00<@000?l?0?ooo`002@3oool0102V
YZH0WIfM09fMW@2JVYX2092@T0<0S8b<00D0WIfM09JFUP2>SXh0SXj>08n?S`0205eMG@0506][J`2]
[Jd0[Zj^0:j^[P2RXZ800P2SXj<01@2QXJ40XZ:R0::RXP2RXZ80YjNW0080ZJVY00@0/k>c0;Bd]02d
];@0[jn_0P1oOgl01@1WIfL0UiNG07]kN`1kNg/0NGUi0080W9bL00<0X:2P09nOW`2OWil00P2IVIT2
08b<S00508n?S`2:RXX0RXZ:08R8R01QHF400P0f=SH0102FUYH0X:2P0:2PX02IVIT209fMW@050:6Q
X@2MWId0WYjN09jNWP28R8P00P2SXj<01@2ZZZX0[Zj^0:j^[P2^[Zh0PH610080ADE500D0YjNW0:>S
X`2SXj<0YZJV0:BTY0030:JVYP80Z:RX00D0YZJV0:NWY`2WYjL0Rh^;0::RXP020:VYZ@0405YJFP1U
IFD0IFEU079bLP80MWIf00D0Ph>307]kN`1aLG40LG5a07alO00208F5Q@0508B4Q01kNg/0PH610861
P@1jNWX00P1QHF400`0o?cl0WYjN09jNWP020:j^[P80Xj>S00@0[Jf]0;6a/@2a/K40/[:b0P2d];@0
1@2f][H0];Bd0;Bd]02d];@0]KFe0080KFe]00<0TY:B0;^k^`2k^k/00P2h^;P20;Bd]0<0/K6a00D0
[Jf]0;6a/@2`/;00/;2`0:VYZ@0306m_K`80]kNg00D0][Jf0;Fe]@2d];@0];Bd0;Ng]`020;Fe]@05
0;Ng]`2d];@0];Bd0:n_[`2][Jd00P2^[Zh01@2MWId0DU9B059BDP2RXZ80Xj>S0080YZJV00@0/k>c
0;6a/@2a/K40[Zj^0P2][Jd00`2b/[80oooo0?ooo`0C0?ooobX0003o103oP00k0000o`T0oh00>`00
0?l?0?ooo`002@3oool0102VYZH0WIfM09fMW@2JVYX2092@T0<0S8b<00D0WIfM09JFUP2>SXh0SXj>
08n?S`0205eMG@0506][J`2][Jd0[Zj^0:j^[P2RXZ800P2SXj<01@2QXJ40XZ:R0::RXP2RXZ80YjNW
0080ZJVY00@0/k>c0;Bd]02d];@0[jn_0P1oOgl01@1WIfL0UiNG07]kN`1kNg/0NGUi0080W9bL00<0
X:2P09nOW`2OWil00P2IVIT208b<S00508n?S`2:RXX0RXZ:08R8R01QHF400P0f=SH0102FUYH0X:2P
0:2PX02IVIT209fMW@050:6QX@2MWId0WYjN09jNWP28R8P00P2SXj<01@2ZZZX0[Zj^0:j^[P2^[Zh0
PH610080ADE500D0YjNW0:>SX`2SXj<0YZJV0:BTY0030:JVYP80Z:RX00D0YZJV0:NWY`2WYjL0Rh^;
0::RXP020:VYZ@0405YJFP1UIFD0IFEU079bLP80MWIf00D0Ph>307]kN`1aLG40LG5a07alO00208F5
Q@0508B4Q01kNg/0PH610861P@1jNWX00P1QHF400`0o?cl0WYjN09jNWP020:j^[P80Xj>S00@0[Jf]
0;6a/@2a/K40/[:b0P2d];@01@2f][H0];Bd0;Bd]02d];@0]KFe0080KFe]00<0TY:B0;^k^`2k^k/0
0P2h^;P20;Bd]0<0/K6a00D0[Jf]0;6a/@2`/;00/;2`0:VYZ@0306m_K`80]kNg00D0][Jf0;Fe]@2d
];@0];Bd0;Ng]`020;Fe]@050;Ng]`2d];@0];Bd0:n_[`2][Jd00P2^[Zh01@2MWId0DU9B059BDP2R
XZ80Xj>S0080YZJV00@0/k>c0;6a/@2a/K40[Zj^0P2][Jd00`2b/[80oooo0?ooo`0C0?ooojd0oh00
3`3oool000T0oooo00@0Z:RX0:>SX`2SXj<0X:2P0`2BTY8208:2PP0509BDU02EUID0Rh^;08^;R`24
Q8@00P1QHF401@1VIVH0Zj^[0:b/[02/[:`0XZ:R00<0WIfM0P2JVYX01@2TY:@0X:2P0:JVYP2VYZH0
ZZZZ0080/K6a00D0Zj^[0820P020P800J6QX09>CT`020861P@0408J6QP2:RXX0RXZ:08f=S@80[:b/
00D0ZJVY0:j^[P2[Zj/0Zj^[0:b/[0020:NWY`0509RHV01ZJVX0;Bd]02d];@2JVYX00P2WYjL01@2T
Y:@0ZZZZ0:ZZZP2VYZH0Xj>S0080WinO00@0T92@0:BTY02TY:@0[Jf]0P2c/k<01@2^[Zh0R8R804Q8
B018B4P0ZJVY00<0];Bd00@0ZZZZ0:>SX`2SXj<0YjNW0P2TY:@01@2VYZH0X:2P0:2PX01nOWh0X:2P
0080Zj^[00@0GEeM06IVIP1VIVH0Ogmo0P2;Rh/00`29RHT0Ogmo07emO@0207emO@80Ogmo00D0QhN7
08F5Q@28R8P0R8R807UiN@0206QXJ0050492@P22PX80PX:207alO01YJFT00P1]KFd0102OWil0ZZZZ
0:ZZZP2^[Zh20:^[Z`80[jn_0`2][Jd205mOG`0509:BTP2c/k<0/k>c0;6a/@2b/[800P2ZZZX01@2[
Zj/0ZZZZ0:ZZZP2YZJT0YJFU0080Y:BT00@0YJFU05UIF@1IFET0OWin0P3:b/X01@34a<@0_Kfm0;Bd
]02d];@0][Jf0080];Bd00<0][Jf0;Rh^02h^;P0102c/k<01@2XZ:P0GUiN05iNGP2NWYh0XJ6Q0080
YjNW00@0[Jf]0:n_[`2_[jl0Z:RX0P2/[:`00`2^[Zh0oooo0?ooo`0C0?ooojd0oh003`3oool000T0
oooo00@0YJFU0:>SX`2SXj<0VIVI0P2KVi/01@2?Shl0SHf=08f=S@2ATI40R8R80080Shn?00D0Ti>C
06YZJP1ZJVX0G5aL0:ZZZP020:NWY`040:>SX`2TY:@0Y:BT09fMW@80VYZJ00D0WinO0:2PX02YZJT0
ZJVY0:ZZZP020:j^[P050:FUY@1ZJVX0JVYZ075aL@2<S8`00P2:RXX0101hN7P0PH610861P@23Ph<2
09jNWP040:NWY`2[Zj/0[Jf]0:f][@<0ZJVY00D0XZ:R06YZJP0b<S80<S8b09RHV0020:j^[P030:f]
[@2a/K40/K6a0080[:b/0P2UYJD0102QXJ40ZJVY0:VYZ@2/[:`20;2`/0050:NWY`2HV9P0@4100410
@02UYJD00P2RXZ820:NWY`80XJ6Q00@0TY:B09VIV@2IVIT0XZ:R0P2PX:001@2:RXX0SHf=0:FUY@2U
YJD0JVYZ0080MgMg0`2OWil01@2HV9P0NWYj06i^KP1^KVh0MWIf0080O7al00D0Shn?09:BTP25QHD0
QHF508J6QP0207=cL`0306UYJ@2PX:00X:2P0080WYjN0P1/K6`01020P800RXZ:08Z:RP2QXJ420:>S
X`0509^KV`2MWId0Ti>C09>CT`2;Rh/00P0n?Sh01@20P800WinO09nOW`2IVIT0V9RH0080UYJF00D0
XJ6Q09bLW02LW9`0X:2P09^KV`0309VIV@80H61P00<0LW9b0;bl_02l_;`00P2l_;`20;Fe]@040:n_
[`2YZJT0ZJVY0:6QX@80Z:RX00D0/;2`0:2PX02NWYh0WYjN09ZJVP0205EEE@0509bLW02NWYh0YJFU
0:FUY@2ZZZX00P2][Jd0102UYJD0Xj>S0:>SX`2XZ:PE0?ooojd0oh003`3oool000T0oooo00@0IFEU
05QHF01HF5P0AdM70P0i>CT00`0k>c/0@T920492@P0204Q8B080BDU900D0?clo02HV9P0V9RH0;2`/
061PH002075aL@0407QhN01dM7@0M7Ad06UYJ@80AdM700D0BDU904e=C@19BDT0BDU904m?C`0204Y:
BP0503hn?P0/;2`0;2`/03`l?013@d<00P1;Bd/304=3@`0504I6AP1<C4`0C4a<059BDP1>CTh00P1C
De<01@1QHF40GUiN05iNGP0n?Sh092@T0080:b/[00@0BDU905ADE01DE5@0G5aL0`1?Cdl01012@T80
ATI604I6AP17AdL204=3@`0504Q8B014A4@0A4A402l_;`0i>CT00P0g=cL01@1=CDd0D51@051@D01<
C4`0?clo0080@D5100@0<C4a030`<00`<300<c<c0P11@D420492@P80@d=30`10@4001@16ATH0C4a<
04a<C019BDT0?clo0080<30`00D0>3Ph03@d=00d=3@0>c/k03Lg=`0203Ti>@0403lo?`0b<S80<S8b
03/k>`80?clo00D0=CDe0410@017AdL0AdM704=3@`0202d];@05024Q8@0h>3P0>3Ph03/k>`11@D40
0P0m?Cd0100k>c/0>CTi03Ti>@10@40204];B`0504=3@`0o?cl0A4A404A4A00l?3`00P0S8b<01@0c
<c<0=SHf03De=@0e=CD0?3`l0080A4A400D0?Cdm04A4A014A4@0B4Q804U9B@0204Q8B00403<c<`0b
<S80<S8b01`L7080;Rh^00D0?3`l03Lg=`0f=SH0=SHf04A4A00204Y:BP0505ADE01IFET0Hf=S06=S
H`1MGEd00`1>CTh204I6AP0305]KF`3oool0oooo01<0oooo[@3oP00?0?ooo`002@3oool0101UIFD0
F5QH05QHF017AdL203Ti>@0303/k>`12@T80@T920080B4Q80P19BDT01@0o?cl09RHV02HV9P0/;2`0
H61P0080LG5a00@0N7Qh07AdM01dM7@0JFUY0P17AdL01@19BDT0CDe=04U9B@19BDT0Cdm?0080BTY:
00D0?Shn02`/;00/;2`0?3`l04=3@`0204];B`<0@d=300D0ATI604a<C01<C4`0DU9B04i>CP0205=C
D`05065QH@1NGUh0GUiN03hn?P0T92@00P0[:b/01019BDT0E5AD05ADE01LG5`304m?C`040492@P16
ATH0ATI604M7A`80@d=300D0B4Q804A4A014A4@0;bl_03Ti>@0203Lg=`0504e=C@1@D500D51@04a<
C00o?cl00P11@D40100a<C40<30`030`<00c<c<20451@@80@T920P13@d<30410@00504I6AP1<C4`0
C4a<04U9B@0o?cl00P0`<3001@0h>3P0=3@d03@d=00k>c/0=cLg0080>CTi00@0?clo038b<P0b<S80
>c/k0P0o?cl01@0e=CD0@41004M7A`17AdL0@d=30080;Bd]00D08B4Q03Ph>00h>3P0>c/k0451@@02
03dm?@0403/k>`0i>CT0>CTi0410@080Bd];00D0@d=303lo?`14A4@0A4A403`l?00202<S8`0503<c
<`0f=SH0=CDe03De=@0l?3`00P14A4@01@0m?Cd0A4A404A4A018B4P0BDU90080B4Q800@0<c<c038b
<P0b<S8071`L0P0^;Rh01@0l?3`0=cLg03Hf=P0f=SH0A4A40080BTY:00D0E5AD05UIF@1SHf<0Hf=S
05eMG@0304i>CP80ATI600<0Fe]K0?ooo`3oool04`3ooon]0000o`l0oooo00090?ooo`040;:b/P2X
Z:P0Z:RX0:>SX`80FUYJ00D0O7al09:BTP2BTY80M7Ad07emO@0209NGU`0509BDU02TY:@0Y:BT0:ZZ
ZP2?Shl00P2/[:`0102ZZZX0YjNW0:NWY`2UYJD203Ti>@0506QXJ028R8P0XZ:R0::RXP2][Jd00P2_
[jl01@2^[Zh0[:b/0:b/[02ZZZX0XZ:R0080XJ6Q00@0XZ:R0:2PX02PX:00ZJVY0P1HF5P01@1jNWX0
YZJV0:RXZ02XZ:P0Zj^[0080Xj>S00D0YjNW0:2PX02UYJD0YJFU0:ZZZP020:6QX@050:RXZ02_[jl0
[jn_09jNWP16ATH00P1`L7001021PH40SHf=08f=S@2JVYX209^KV`030:2PX02LW9`0XJ6Q00@0XJ6Q
0P2JVYX209NGU`0404U9B@2OWil0WinO0:f][@80[jn_00D0];Bd0<30`02g]kL0]kNg0;2`/0020:f]
[@050;2`/02^[Zh0[Zj^0;>c/`2d];@00P2EUID01@1YJFT0Y:BT0:BTY02^[Zh0Zj^[0080[Zj^00@0
]kNg0;Zj^P2j^[X0^k^k0P2g]kL01@2f][H0];Bd0;2`/02`/;00/k>c0080AdM700D0HF5Q0;Vi^@2i
^KT0_;bl0;Zj^P020:n_[`040;Bd]02k^k/0^k^k0;fm_@80^[Zj00D0_Kfm0;bl_02j^[X0^[Zj0:NW
Y`0203dm?@030;^k^`2g]kL0^[Zj00@0^[Zj00<0][Jf0;Bd]02d];@00P2a/K420;:b/P040:f][@2U
YJD0YJFU06QXJ080XZ:R00D0];Bd0;2`/02d];@0];Bd0;6a/@030;2`/0040:ZZZP2TY:@0Y:BT0:JV
YP80Y:BT00@0ZZZZ075aL@1aLG40X:2P5@3ooon]0000o`l0oooo00090?ooo`040:ZZZP2WYjL0YjNW
0:FUY@80I6AT00D0N7Qh09BDU02DU9@0G5aL07YjNP0208V9R@0507]kN`2BTY80TY:B09FEU@1UIFD0
1@2NWYh01@2MWId0;Bd]02d];@1UIFD0NWYj0080P82000@0WIfM09ZJVP2JVYX0UYJF0P2HV9P01@2G
UiL0TI6A09BDU02DU9@0TY:B0080UiNG00@0Z:RX06IVIP1VIVH0R8R80`2ZZZX01@2VYZH0YJFU0:FU
Y@2TY:@0W9bL0080XJ6Q00@0X:2P09jNWP2NWYh0YZJV0P2ZZZX01@2[Zj/0FUYJ07UiN@1iNGT0VIVI
0080V9RH00D0WinO0:>SX`2SXj<0YJFU0:2PX00209ZJVP05092@T02>SXh0SXj>08f=S@2?Shl00P2:
RXX0100o?cl0Xj>S0:>SX`2b/[820;Rh^0050;Fe]@2k^k/0];Bd0;Bd]02`/;000P2_[jl01@2/[:`0
[Zj^0:j^[P2[Zj/0/;2`0080UiNG00D0JFUY09fMW@2MWId0Xj>S0:b/[0020;>c/`040:n_[`2c/k<0
/k>c0;Rh^080][Jf00D0/[:b0:^[Z`2/[:`0[:b/0:j^[P0204e=C@0508:2PP2m_Kd0_Kfm0<G5a@2o
_kl00P2d];@0102g]kL0`<300<30`02o_kl20<C4a0050<G5a@36a/H0_[jn0;jn_P2][Jd00P15ADD0
1@2d];@0/K6a0;Bd]02d];@0/k>c0080];Bd00D0YjNW0:JVYP2VYZH0YZJV0:j^[P030:n_[`80ZJVY
00D0H61P0:f][@2][Jd0]KFe0:f][@020;2`/0050;6a/@2`/;00/;2`0;Jf]P2/[:`00P2XZ:P0102`
/;00/K6a0;6a/@2b/[8207UiN@030:b/[03oool0oooo01<0ooooO0000?l40?n000T0003o00<0oh00
0000o`000?l08@000?l?0?ooo`002@3oool0102ZZZX0YjNW0:NWY`2UYJD206ATI00507QhN02DU9@0
U9BD05aLG01jNWX00P29RHT01@1kNg/0TY:B09:BTP2EUID0IFEU00D0WYjN00D0WIfM02d];@0];Bd0
IFEU07YjNP020820P00409fMW@2JVYX0VYZJ09JFUP80V9RH00D0UiNG096AT@2DU9@0U9BD09:BTP02
09NGU`040:RXZ01VIVH0IVIV08R8R0<0ZZZZ00D0YZJV0:FUY@2UYJD0Y:BT09bLW0020:6QX@040:2P
X02NWYh0WYjN0:JVYP80ZZZZ00D0Zj^[05YJFP1iNGT0NGUi09VIV@0209RHV00509nOW`2SXj<0Xj>S
0:FUY@2PX:000P2JVYX01@2@T900SXj>08j>SP2=SHd0Shn?0080RXZ:00@0?clo0:>SX`2SXj<0/[:b
0P2h^;P01@2e]KD0^k^k0;Bd]02d];@0/;2`0080[jn_00D0[:b/0:j^[P2^[Zh0Zj^[0;2`/00209NG
U`0506UYJ@2MWId0WIfM0:>SX`2/[:`00P2c/k<0102_[jl0/k>c0;>c/`2h^;P20;Jf]P050;:b/P2[
Zj/0[:b/0:b/[02^[Zh00P1=CDd01@22PX80_Kfm0;fm_@35aLD0_kno0080];Bd00@0]kNg0<30`030
`<00_kno0P34a<@01@35aLD0a/K60;jn_P2n_[h0[Jf]0080ADE500D0];Bd0;6a/@2d];@0];Bd0;>c
/`020;Bd]0050:NWY`2VYZH0YZJV0:JVYP2^[Zh00`2_[jl20:VYZ@05061PH02][Jd0[Jf]0;Fe]@2]
[Jd00P2`/;001@2a/K40/;2`0;2`/02f][H0[:b/0080Z:RX00@0/;2`0;6a/@2a/K40/[:b0P1iNGT0
0`2/[:`0oooo0?ooo`0C0?ooojd0oh003`3oool000T0oooo00@0XJ6Q09fMW@2MWId0WinO0P1MGEd0
1@1cLg<0RXZ:08Z:RP1DE5@0RHV90080TI6A00D0Ogmo09>CT`2CTi<0PH6106IVIP0209ZJVP<0V9RH
00@0WinO03Lg=`0g=cL0GUiN0`1iNGT0102NWYh0W9bL09bLW02GUiL2096AT@040861P@28R8P0T92@
092@T0<0TY:B00D0U9BD059BDP1BDU80Lg=c0:6QX@020:>SX`<0XJ6Q00D0X:2P09>CT`2FUYH0UYJF
09:BTP0209>CT`050:2PX02TY:@0Y:BT0:6QX@1:BTX00P1YJFT0102IVIT0VYZJ09ZJVP2QXJ4209fM
W@0508j>SP2:RXX0RHV908V9R@25QHD00P24Q8@01@2>SXh0S8b<08V9R@29RHT0@D510080Vi^K0`2]
[Jd01@2^[Zh0];Bd0;2`/02`/;00ZJVY0080YjNW00D0Y:BT0:>SX`2SXj<0YJFU0:VYZ@020:>SX`05
06EUI@2BTY80TY:B09JFUP2PX:000P2XZ:P0102QXJ40[:b/0:b/[02^[Zh20:b/[0050:RXZ02TY:@0
YjNW0:NWY`2ZZZX00P1<C4`01@2=SHd0_kno0;no_`32`/80_kno0080^k^k00@0^[Zj0;jn_P2n_[h0
`l?30P39bLT01@35aLD0_Kfm0;^k^`2k^k/0/[:b0080BTY:00D0/k>c0;6a/@2e]KD0]KFe0;Jf]P02
0;6a/@050:NWY`2OWil0WinO09VIV@2HV9P00P2OWil0102YZJT0Xj>S0:>SX`1FEUH20:f][@050;:b
/P2][Jd0[:b/0:b/[02^[Zh00P2_[jl01@2a/K40[Jf]0:f][@2][Jd0];Bd0080][Jf00@0[jn_07If
MP1fMWH0ZJVY5@3ooon]0?n000l0oooo00090?ooo`040:6QX@2LW9`0W9bL09^KV`80IFEU00D0LG5a
08n?S`2?Shl0Kfm_09nOW`0209^KV`0509ZJVP2TY:@0Y:BT0820P01mOGd00P2QXJ40102PX:00WIfM
09fMW@2CTi<204=3@`0505iNGP23Ph<0S8b<08b<S02LW9`00P2SXj<01@2OWil0VYZJ09ZJVP2ATI40
T92@0080SXj>00@0SHf=09>CT`2CTi<0PX:20P0d=3@01@1eMGD0WYjN09jNWP2NWYh0WIfM0080UiNG
00D0X:2P09RHV02=SHd0SHf=08R8R00209>CT`0509NGU`2IVIT0VIVI09VIV@1?Cdl00P1SHf<01028
R8P0UIFE09FEU@2JVYX209VIV@0508n?S`23Ph<0Ogmo07moO`1nOWh00P20P8001@25QHD0R8R807Mg
M`1gMgL0@T920080RXZ:00D0WYjN0:BTY02TY:@0WIfM0:BTY0020:JVYP0409nOW`2GUiL0UiNG09BD
U080TI6A00D0WIfM09ZJVP2GUiL0UiNG05]KF`0209NGU`0408J6QP29RHT0WIfM09fMW@<0VIVI00D0
WYjN09VIV@2IVIT0UYJF09NGU`0209jNWP0409ZJVP0i>CT0>CTi0820P080YjNW00D0Y:BT0;2`/02^
[Zh0[Zj^0:n_[`020:b/[0050:>SX`2d];@0];Bd0:JVYP2WYjL00P2_[jl01@2IVIT0DE5A055AD@2<
S8`0SHf=0080VIVI00@0ZZZZ0:NWY`2WYjL0TY:B0P26QXH01@27QhL0R8R808B4Q024Q8@0U9BD0080
V9RH00@0Fe]K0:>SX`2SXj<0Xj>S0`2TY:@01@2YZJT0VYZJ09ZJVP2OWil0UYJF0080Xj>S00@0Y:BT
0:2PX02PX:00VYZJ0P1MGEd00`2EUID0oooo0?ooo`0C0?ooojd0oh003`3oool000T0oooo00@0XJ6Q
09bLW02LW9`0Vi^K0P1UIFD01@1aLG40Shn?08n?S`1_Kfl0WinO0080Vi^K00D0VYZJ0:BTY02TY:@0
P82007emO@020:6QX@040:2PX02MWId0WIfM09>CT`80@d=300D0GUiN08>3P`2<S8`0S8b<09bLW002
0:>SX`0509nOW`2JVYX0VYZJ096AT@2@T9000P2>SXh0102=SHd0Ti>C09>CT`22PX8203@d=00507Ee
M@2NWYh0WYjN09jNWP2MWId00P2GUiL01@2PX:00V9RH08f=S@2=SHd0R8R80080Ti>C00D0UiNG09VI
V@2IVIT0VIVI04m?C`0206=SH`0408R8R02EUID0UIFE09ZJVP80VIVI00D0Shn?08>3P`1oOgl0Ogmo
07inOP020820P00508F5Q@28R8P0MgMg07MgM`12@T800P2:RXX01@2NWYh0Y:BT0:BTY02MWId0Y:BT
0080YZJV00@0WinO09NGU`2GUiL0U9BD0P2ATI401@2MWId0VYZJ09NGU`2GUiL0Fe]K0080UiNG00@0
QXJ608V9R@2MWId0WIfM0`2IVIT01@2NWYh0VIVI09VIV@2FUYH0UiNG0080WYjN00@0VYZJ03Ti>@0i
>CT0P8200P2WYjL01@2TY:@0/;2`0:j^[P2^[Zh0[jn_0080[:b/00D0Xj>S0;Bd]02d];@0YZJV0:NW
Y`020:n_[`0509VIV@1ADE40DE5A08b<S02=SHd00P2IVIT0102ZZZX0YjNW0:NWY`2BTY8208J6QP05
08N7Q`28R8P0Q8B408B4Q02DU9@00P2HV9P0101KFe/0Xj>S0:>SX`2SXj<30:BTY0050:VYZ@2JVYX0
VYZJ09nOW`2FUYH00P2SXj<0102TY:@0X:2P0:2PX02JVYX205eMG@0309FEU@3oool0oooo01<0oooo
103oP00?0000o`T0oh001P000?l?0?n000H0003o0`3oP00@0000of<0oh003`3oool000T0oooo00@0
FEUI04];B`1;Bd/0BTY:0P0i>CT01@0k>c/0Bd];04];B`0o?cl0A4A40080B4Q800D0Cdm?04i>CP1>
CTh0>c/k04Y:BP02051@D00404M7A`14A4@0A4A403Xj>P806a/K00@092@T03`l?00l?3`0?3`l0`0h
>3P01@12@T80>3Ph03Ph>00];Bd0>SXj0080C4a<00@0Cdm?05=CD`1CDe<0?3`l0P0O7al01@16ATH0
GUiN05UIF@1IFET0GemO00<0EEEE00@0CTi>04Y:BP1:BTX0AdM70P16ATH01@1@D500CDe=04e=C@18
B4P08B4Q0080=cLg00@0Bd];059BDP1BDU80De=C0P1BDU801@1=CDd0DE5A04E5A@15ADD0B4Q80080
@d=300D0@T9203Xj>P0g=cL0=cLg020P800202`/;00502l_;`0^;Rh0;Rh^02HV9P0m?Cd00P12@T80
100h>3P0=cLg03Lg=`0_;bl202TY:@05030`<00c<c<0:BTY02TY:@0V9RH00P1>CTh01@11@D40?3`l
03/k>`0k>c/0>SXj0080@D5100D0ATI603Hf=P0f=SH0<30`034a<@0202d];@0402<S8`0O7al07alO
01hN7P8092@T00D09BDU02XZ:P0/;2`0;2`/02HV9P0202PX:00503Xj>P10@400@4100451@@19BDT0
0P1<C4`01@1=CDd0@T920492@P0n?Sh0>SXj00808b<S00@09bLW02PX:00X:2P04Q8B0P0P8200100W
9bL09RHV01lO7`0O7al302HV9P0501HF5P0I6AT06ATI020P800K6a/00P0R8R801@0J6QX03@d=00d=
3@0F5QH09bLW00<0<C4a0P0_;bl0100Y:BT08R8R028R8P0R8R8E0?ooob00oh000`000?l@0?n00080
003o303oP00;0000o`D0oh00F@000?l30?n000l0oooo00090?ooo`0409>CT`28R8P0R8R808N7Q`80
PH6100<0OGem07UiN@1iNGT00P1dM7@207UiN@0507emO@24Q8@0Q8B4030`<018B4P00P1[Jf/0101j
NWX0MGEe07EeM@1kNg/20820P00507IfMP1nOWh0OWin07inOP1lO7`00P1bLW801@1^KVh0J6QX06QX
J00T92@0O7al0080RXZ:00@0QXJ608n?S`2?Shl0WIfM0P2VYZH01@2JVYX0V9RH09^KV`2KVi/0UIFE
0080R8R800D0SHf=08>3P`0_;bl0;bl_05eMG@0207emO@0508V9R@23Ph<0Ph>307UiN@1gMgL00P1d
M7@0101TI6@0JVYZ06YZJP1^KVh206][J`0506a/K01eMGD0<c<c03<c<`1_Kfl00P1`L7001@1WIfL0
M7Ad07QhN01hN7P0P8200080Q8B400<0RXZ:08j>SP2>SXh00P2FUYH2092@T00407AdM01^KVh0KVi^
09RHV080S8b<00D0U9BD09fMW@2IVIT0VIVI09bLW00309NGU`040:RXZ02YZJT0ZJVY0:^[Z`80IFEU
00@0Ph>309ZJVP2JVYX0Ti>C0`2>SXh0102CTi<0VYZJ09ZJVP2IVIT209nOW`050::RXP2OWil0XJ6Q
0:6QX@1jNWX00P1XJ6P01@2HV9P0WYjN09jNWP2`/;00]KFe0080Z:RX00D0[Zj^09fMW@2MWId0Vi^K
0:2PX00209ZJVP0408V9R@2TY:@0Y:BT05ADE080RXZ:00D0GUiN07alO02GUiL0UiNG0::RXP0209bL
W00507=cL`1kNg/0Ng]k07emO@2;Rh/00P2RXZ801@2PX:00H61P061PH021PH40XJ6Q0080Y:BT00@0
YJFU0:NWY`2WYjL0YjNW0P2LW9`00`26QXH0oooo0?ooo`0C0?ooob00oh000`000?l@0?n00080003o
303oP00;0000o`D0oh00F@000?l30?n000l0oooo00090?ooo`030:n_[`2QXJ40XJ6Q00<0XJ6Q00D0
WIfM0:FUY@2UYJD0YZJV0:>SX`020::RXP0509^KV`2QXJ40XJ6Q03`l?02:RXX00P2GUiL0102PX:00
Y:BT0:BTY02MWId209JFUP0508f=S@2OWil0Y:BT0:BTY02SXj<00P2CTi<01@2=SHd0PX:208:2PP0]
;Bd0RXZ:0080Vi^K00@0V9RH09fMW@2MWId0W9bL0`2TY:@0102SXj<0Y:BT0:BTY02IVIT208b<S005
08^;R`29RHT0Bd];04];B`2KVi/00P2CTi<01@2MWId0XJ6Q0:6QX@2VYZH0Xj>S0080VYZJ00@0Ti>C
08>3P`23Ph<0QXJ60P1fMWH01020P800UYJF03@d=00d=3@308V9R@0508Z:RP27QhL0UiNG09NGU`2M
WId00P2BTY801@2@T900Shn?08n?S`2QXJ40XZ:R0080TY:B00@0MgMg05=CD`1CDe<0RXZ:0P2=SHd0
1@2CTi<0VIVI09^KV`2KVi/0WinO00<0X:2P00@0ZJVY0:ZZZP2ZZZX0ZZZZ0P1=CDd01@2KVi/0YZJV
0:JVYP2NWYh0X:2P0080WYjN00@0Z:RX0:ZZZP2ZZZX0YJFU0P2ZZZX01@2/[:`0Zj^[0:>SX`2SXj<0
PX:20080FUYJ00<0Xj>S0::RXP2RXZ800P2[Zj/209:BTP050:>SX`22PX80PX:208j>SP2FUYH00P2?
Shl01026QXH0VYZJ09ZJVP1JFUX208B4Q00504M7A`2@T900VYZJ09ZJVP2OWil00P2IVIT01@1`L700
KFe]06e]K@1XJ6P0L71`0080Ti>C00D0YZJV06a/K01/K6`0Ng]k09>CT`0209jNWP040:2PX02TY:@0
Y:BT0:NWY`80Xj>S00<0YZJV0?ooo`3oool04`3oool;0000o`<0oh0060000?l70?n001`0003o00<0
oh000000o`000?l030000?lD0?n002<0003o0`3oP00K0000o`l0oooo00090?ooo`030:n_[`2QXJ40
XJ6Q00<0XJ6Q00D0WIfM0:FUY@2UYJD0YZJV0:>SX`020::RXP0509^KV`2QXJ40XJ6Q03`l?02:RXX0
0P2GUiL0102PX:00Y:BT0:BTY02MWId209JFUP0508f=S@2OWil0Y:BT0:BTY02SXj<00P2CTi<01@2=
SHd0PX:208:2PP0];Bd0RXZ:0080Vi^K00@0V9RH09fMW@2MWId0W9bL0`2TY:@0102SXj<0Y:BT0:BT
Y02IVIT208b<S00508^;R`29RHT0Bd];04];B`2KVi/00P2CTi<01@2MWId0XJ6Q0:6QX@2VYZH0Xj>S
0080VYZJ00@0Ti>C08>3P`23Ph<0QXJ60P1fMWH01020P800UYJF03@d=00d=3@308V9R@0508Z:RP27
QhL0UiNG09NGU`2MWId00P2BTY801@2@T900Shn?08n?S`2QXJ40XZ:R0080TY:B00@0MgMg05=CD`1C
De<0RXZ:0P2=SHd01@2CTi<0VIVI09^KV`2KVi/0WinO00<0X:2P00@0ZJVY0:ZZZP2ZZZX0ZZZZ0P1=
CDd01@2KVi/0YZJV0:JVYP2NWYh0X:2P0080WYjN00@0Z:RX0:ZZZP2ZZZX0YJFU0P2ZZZX01@2/[:`0
Zj^[0:>SX`2SXj<0PX:20080FUYJ00<0Xj>S0::RXP2RXZ800P2[Zj/209:BTP050:>SX`22PX80PX:2
08j>SP2FUYH00P2?Shl01026QXH0VYZJ09ZJVP1JFUX208B4Q00504M7A`2@T900VYZJ09ZJVP2OWil0
0P2IVIT01@1`L700KFe]06e]K@1XJ6P0L71`0080Ti>C00D0YZJV06a/K01/K6`0Ng]k09>CT`0209jN
WP040:2PX02TY:@0Y:BT0:NWY`80Xj>S00<0YZJV0?ooo`3oool04`3oool_0?n000H0003o8`3oP00=
0000odP0oh003`3oool000T0oooo00@0/K6a0:BTY02TY:@0XJ6Q0P2NWYh01@2FUYH0TI6A096AT@2L
W9`0XJ6Q0080U9BD00D0Ph>308F5Q@25QHD0>SXj06UYJ@0208>3P`0408n?S`2JVYX0VYZJ092@T080
R8R800D0Ph>3092@T02NWYh0WYjN09:BTP0208F5Q@<0MgMg00D0;Rh^0861P@2?Shl0Shn?092@T002
08n?S`0507inOP1iNGT0NGUi07moO`2;Rh/00P2NWYh01@1nOWh0KFe]06e]K@1fMWH0L71`0080?Cdm
00@0SXj>09nOW`2OWil0XZ:R0P2UYJD01@2TY:@0XJ6Q09JFUP2FUYH0Rh^;0080LW9b00D0Ph>307em
O@1mOGd0Shn?09fMW@02030`<00509ZJVP2LW9`0W9bL09jNWP2ATI400P2EUID0102CTi<0Ph>308>3
P`28R8P20861P@0509ZJVP2QXJ40U9BD09BDU01_Kfl00P1OGel01@2FUYH0TI6A096AT@2LW9`0WIfM
0080T92@00D0U9BD08n?S`2?Shl0WYjN0:NWY`020:f][@040:^[Z`1TI6@0I6AT0:2PX080YJFU102W
YjL0102VYZH0ZJVY0:VYZ@2UYJD20:NWY`050:VYZ@2VYZH0Y:BT0:BTY02=SHd00P1PH6001@2OWil0
Xj>S0:>SX`2_[jl0UYJF0080[:b/00D0WIfM08:2PP22PX80U9BD09ZJVP0209VIV@0409:BTP2LW9`0
W9bL03lo?`80C4a<00D0DE5A08J6QP26QXH0QXJ608R8R00208V9R@0505]KF`1XJ6P0J6QX05=CD`1d
M7@00P2IVIT01@2QXJ40Fe]K05]KF`1lO7`0PH610080UiNG00@0W9bL0:FUY@2UYJD0X:2P0P2OWil0
0`2SXj<0oooo0?ooo`0C0?ooo`L0003oYP3oP00?0?ooo`002@3oool0102[Zj/0YJFU0:FUY@2UYJD2
09nOW`0509ZJVP2ATI40TI6A09^KV`2MWId00P2=SHd01@24Q8@0RHV908V9R@11@D40N7Qh0080S8b<
00@0QHF508^;R`2;Rh/0RXZ:0P27QhL01@28R8P0Ph>309NGU`2GUiL0RXZ:0080JVYZ00D0HF5Q075a
L@1aLG40;bl_08J6QP0209>CT`0409VIV@28R8P0R8R807UiN@80NWYj00D0NGUi08N7Q`2TY:@0Y:BT
08^;R`0206UYJ@0506EUI@1FEUH0<30`030`<021PH400P29RHT01@2DU9@0UiNG09NGU`2CTi<0S8b<
0080RHV900@0NGUi07IfMP1fMWH0P8200P2CTi<01@2FUYH0S8b<0410@010@400Ti>C0080UiNG00D0
SXj>08>3P`29RHT0RHV908N7Q`0208V9R@0409ZJVP2?Shl0Shn?09>CT`<0Shn?00@0JFUY059BDP1B
DU80IFEU0P1RHV801@1XJ6P0KVi^06m_K`1_Kfl0M7Ad0080LG5a00D0NGUi08f=S@2EUID0UIFE07Qh
N00204m?C`0507inOP2GUiL0UiNG09FEU@2QXJ400`2UYJD20:NWY`050:>SX`2GUiL0UiNG0:JVYP2I
VIT00P2KVi/00`25QHD0J6QX06QXJ00309JFUP050;2`/02e]KD0ZZZZ0:ZZZP2EUID00P2LW9`01@2;
Rh/0UiNG09ZJVP2JVYX0UiNG0080WYjN00D0>CTi051@D01@D500I6AT09:BTP0208V9R@0408^;R`1S
Hf<0Hf=S04Q8B080FUYJ00<0D51@07UiN@23Ph<00P23Ph<203hn?P0506UYJ@2GUiL0XZ:R0::RXP2I
VIT00P2ATI40102NWYh0XJ6Q0:6QX@2PX:0E0?ooo`L0003oYP3oP00?0?ooo`002@3oool0102[Zj/0
YJFU0:FUY@2UYJD209nOW`0509ZJVP2ATI40TI6A09^KV`2MWId00P2=SHd01@24Q8@0RHV908V9R@11
@D40N7Qh0080S8b<00@0QHF508^;R`2;Rh/0RXZ:0P27QhL01@28R8P0Ph>309NGU`2GUiL0RXZ:0080
JVYZ00D0HF5Q075aL@1aLG40;bl_08J6QP0209>CT`0409VIV@28R8P0R8R807UiN@80NWYj00D0NGUi
08N7Q`2TY:@0Y:BT08^;R`0206UYJ@0506EUI@1FEUH0<30`030`<021PH400P29RHT01@2DU9@0UiNG
09NGU`2CTi<0S8b<0080RHV900@0NGUi07IfMP1fMWH0P8200P2CTi<01@2FUYH0S8b<0410@010@400
Ti>C0080UiNG00D0SXj>08>3P`29RHT0RHV908N7Q`0208V9R@0409ZJVP2?Shl0Shn?09>CT`<0Shn?
00@0JFUY059BDP1BDU80IFEU0P1RHV801@1XJ6P0KVi^06m_K`1_Kfl0M7Ad0080LG5a00D0NGUi08f=
S@2EUID0UIFE07QhN00204m?C`0507inOP2GUiL0UiNG09FEU@2QXJ400`2UYJD20:NWY`050:>SX`2G
UiL0UiNG0:JVYP2IVIT00P2KVi/00`25QHD0J6QX06QXJ00309JFUP050;2`/02e]KD0ZZZZ0:ZZZP2E
UID00P2LW9`01@2;Rh/0UiNG09ZJVP2JVYX0UiNG0080WYjN00D0>CTi051@D01@D500I6AT09:BTP02
08V9R@0408^;R`1SHf<0Hf=S04Q8B080FUYJ00<0D51@07UiN@23Ph<00P23Ph<203hn?P0506UYJ@2G
UiL0XZ:R0::RXP2IVIT00P2ATI40102NWYh0XJ6Q0:6QX@2PX:0E0?ooobd0oh004@000?lD0?n00140
003o00@0oh000000o`000?l0003o1P3oP00:0000oc80oh0000@0003o0?n0003oP000oh003`3oool0
00T0oooo00@0L71`06MWI`1WIfL0Jf][0P1XJ6P01@1RHV80Hf=S06=SH`1TI6@0IVIV0080De=C00D0
F5QH065QH@1QHF40=SHf04I6AP0205IFEP<0E5AD00D0DU9B05=CD`1CDe<0CDe=04M7A`0204a<C004
04i>CP0g=cL0=cLg03Xj>P80@41000D07QhN055AD@1KFe/0Fe]K06ATI002065QH@0506ATI01RHV80
HV9R05eMG@1SHf<00P1TI6@01@1PH600Cdm?04m?C`15ADD0=cLg0080;2`/00@0EUIF05UIF@1IFET0
FUYJ0P1OGel01@1KFe/0BTY:04A4A014A4@0DE5A0080ATI600D0B4Q804];B`1;Bd/0Bd];04=3@`02
01`L7005069RHP1NGUh0GUiN06ATI01NGUh00P1HF5P0101BDU80FEUI05UIF@1VIVH2059BDP0505mO
G`1MGEd0ADE504E5A@0h>3P00P0_;bl01@14A4@0@d=304=3@`0j>SX0<S8b0080=CDe00<0@T92051@
D01@D5000P1CDe<205EEE@0402XZ:P0U9BD09BDU01hN7P80BDU900D0EUIF05QHF018B4P0B4Q804U9
B@0204];B`0503dm?@10@400@41005ADE018B4P00P0k>c/0100Q8B409BDU02DU9@0];Bd201HF5P05
02DU9@0`<300:BTY02TY:@0e=CD00P0Q8B401@0P82009RHV02DU9@0U9BD0:BTY00807alO00@030`<
014A4@0A4A407QhN0`0U9BD0100K6a/071`L01`L700H61P201TI6@0501dM7@0W9bL09bLW02LW9`0]
;Bd00P0T92@0100V9RH0:RXZ038b<P0b<S8302@T90040410@011@D40@D5104A4A1D0oooo;@3oP009
0000och0oh005@000?l00`3oP000003o0000o`0A0000o`040?n000000?l0oh000?n000P0003o103o
P00?0?ooo`002@3oool0101WIfL0EEEE05EEE@13@d<203Ti>@0501PH600a<C40<C4a05aLG010@400
0P1?Cdl01@1CDe<0CDe=04e=C@1LG5`0IFEU0080GUiN0`1MGEd01@1JFUX0EUIF05IFEP19BDT0CTi>
0080Ng]k00@0LW9b06YZJP1ZJVX0IfMW0P1XJ6P01@1]KFd0Jf][06i^KP1^KVh0N7Qh0080KFe]00D0
Lg=c06a/K01/K6`0@410061PH00206UYJ@05065QH@1OGel0GemO05UIF@1NGUh00`1PH602065QH@05
069RHP1KFe/0Fe]K06ATI01NGUh00P12@T80101UIFD0IVIV06IVIP1SHf<204];B`0504e=C@1QHF40
KVi^06i^KP1NGUh00P1FEUH01@1IFET0GUiN06EUI@1UIFD0>c/k0080@T9200D0K6a/07]kN`1kNg/0
N7Qh07]kN`0207QhN004079bLP1eMGD0MGEe075aL@80Hf=S00D0IfMW06][J`1ZJVX0JVYZ02TY:@02
04Y:BP0506IVIP1eMGD0LG5a075aL@1nOWh00P28R8P01@26QXH0Q8B408B4Q02:RXX0NGUi0080N7Qh
00@0PX:2079bLP1bLW80:b/[0P1kNg/01@25QHD0U9BD08R8R028R8P0SXj>0080YZJV00D0WYjN0::R
XP2RXZ80X:2P0::RXP0209nOW`0509bLW00n?Sh0?Shn07YjNP25QHD00P2?Shl309NGU`0409ZJVP2R
XZ80XZ:R0:>SX`<0WinO00@0V9RH09>CT`2CTi<0IfMW0P1dM7@01@2BTY80SXj>08J6QP26QXH0PH61
0080HF5Q00@0JVYZ08Z:RP2DU9@0U9BD0`2=SHd0102EUID0Rh^;08^;R`1TI6@E0?oooc40003o2P3o
P01b0000o`l0oooo00090?ooo`0406MWI`1EEED0EEEE04=3@`80>CTi00D061PH034a<@0a<C40G5aL
0410@00204m?C`0505=CD`1=CDd0CDe=05aLG01UIFD00P1NGUh305eMG@0505YJFP1FEUH0EUIF04U9
B@1>CTh00P1kNg/0101bLW80JVYZ06YZJP1WIfL206QXJ00506e]K@1[Jf/0KVi^06i^KP1hN7P00P1]
KFd01@1cLg<0K6a/06a/K010@400H61P0080JFUY00D0HF5Q05mOG`1OGel0FEUI05iNGP03061PH080
HF5Q00D0HV9R05]KF`1KFe/0I6AT05iNGP020492@P0406EUI@1VIVH0IVIV06=SH`80Bd];00D0CDe=
065QH@1^KVh0KVi^05iNGP0205IFEP0505UIF@1NGUh0IFEU06EUI@0k>c/00P12@T801@1/K6`0Ng]k
07]kN`1hN7P0Ng]k0080N7Qh00@0LW9b07EeM@1eMGD0LG5a0P1SHf<01@1WIfL0Jf][06YZJP1ZJVX0
:BTY0080BTY:00D0IVIV07EeM@1aLG40LG5a07inOP0208R8R00508J6QP24Q8@0Q8B408Z:RP1iNGT0
0P1hN7P01022PX80LW9b079bLP0[:b/207]kN`0508F5Q@2DU9@0R8R808R8R02>SXh00P2VYZH01@2N
WYh0XZ:R0::RXP2PX:00XZ:R0080WinO00D0W9bL03hn?P0n?Sh0NWYj08F5Q@0208n?S`<0UiNG00@0
VYZJ0::RXP2RXZ80Xj>S0`2OWil0102HV9P0Ti>C09>CT`1WIfL207AdM00509:BTP2>SXh0QXJ608J6
QP21PH400P1QHF40101ZJVX0RXZ:09BDU02DU9@308f=S@0409FEU@2;Rh/0Rh^;06ATI1D0oooo<@00
0?l:0?n00780003o3`3oool000T0oooo00@0[jn_0;6a/@2a/K40];Bd0P2ZZZX01@0n?Sh0GEeM05eM
G@2CTi<0De=C0080EEEE00D0Ogmo08F5Q@25QHD0Shn?08R8R00208b<S00408F5Q@24Q8@0Q8B407in
OP80MgMg00<0EEEE08F5Q@2l_;`00P2l_;`20;^k^`050;Fe]@2f][H0][Jf0;Jf]P2d];@00P2`/;00
102c/k<0/;2`0;2`/02b/[820:n_[`0505aLG01mOGd0QXJ608J6QP1iNGT00P1aLG401@1YJFT0IfMW
06EUI@1UIFD0HF5Q0080I6AT00D0Jf][06a/K01/K6`0MgMg07emO@0205aLG00409ZJVP2DU9@0U9BD
09NGU`80Xj>S00D0ZJVY0:RXZ02ZZZX0ZZZZ0:BTY0020:6QX@050::RXP2TY:@0ZJVY0:VYZ@1dM7@0
0P1ZJVX01@2UYJD0Z:RX0:RXZ02[Zj/0ZZZZ0080Xj>S00@0YJFU0:BTY02TY:@0Xj>S0P2TY:@01@2S
Xj<0WinO0:2PX02PX:00=cLg0080Lg=c00D0X:2P0:>SX`2VYZH0YZJV0:NWY`020:JVYP050:BTY02R
XZ80XZ:R0:FUY@2?Shl00P2CTi<0102JVYX0Ogmo07moO`1CDe<209FEU@050::RXP2KVi/0V9RH09RH
V02PX:000P2RXZ801@2WYjL0YZJV0:JVYP2UYJD0YjNW0080ZJVY00D0VYZJ03Hf=P0f=SH0W9bL0:2P
X0020:RXZ0040:n_[`2XZ:P0Z:RX0::RXP80YJFU00D0YZJV0:FUY@2LW9`0W9bL09JFUP0209RHV005
05aLG020P800P82009jNWP2JVYX00P28R8P01@2@T900V9RH09RHV02IVIT0QhN70080RXZ:00@0S8b<
08f=S@2=SHd0X:2P0P2;Rh/00`1eMGD0oooo0?ooo`0C0?ooo`<0oh008@000?ll0?n000<0003o303o
P0000`000?l0oh000?n0000=0?n000@0003o:P3oP00?0?ooo`002@3oool0102c/k<0/;2`0;2`/02_
[jl20:RXZ0050451@@1IFET0FEUI08R8R019BDT00P1DE5@01@1iNGT0MgMg07MgM`1oOgl0NWYj0080
O7al00@0P82007MgM`1gMgL0O7al0P1cLg<01@1?Cdl0R8R80;Jf]P2f][H0^;Rh0080/k>c00D0Zj^[
0:f][@2][Jd0ZJVY0:2PX0020:>SX`040:FUY@2JVYX0VYZJ0:NWY`80YJFU00D0HV9R07IfMP27QhL0
QhN708F5Q@0206=SH`0507=cL`1XJ6P0HF5Q065QH@1KFe/00P1CDe<01@1FEUH0HF5Q065QH@1RHV80
J6QX0080EEEE00@0UIFE0:6QX@2QXJ40WIfM0P2QXJ401@2UYJD0YZJV0:j^[P2^[Zh0YZJV0080Vi^K
0P2PX:020:FUY@0306IVIP1ZJVX0JVYZ00<0YjNW00D0[:b/0:BTY02QXJ40XJ6Q0:BTY0020::RXP05
0:6QX@2RXZ80XZ:R0:BTY02RXZ800P2LW9`01@0l?3`0LG5a075aL@2?Shl0Xj>S00<0Y:BT0P2IVIT0
1@2PX:00Xj>S0:>SX`2PX:00OWin0080U9BD00@0VIVI06e]K@1]KFd0DU9B0P2HV9P01@2JVYX0Vi^K
09nOW`2OWil0YJFU0080X:2P00D0Xj>S092@T02@T900WinO0:ZZZP020:6QX@05071`L00U9BD09BDU
09>CT`2PX:000P2ZZZX0102`/;00[Jf]0:f][@2^[Zh20:^[Z`050:6QX@2NWYh0WYjN09jNWP2HV9P0
0P2;Rh/01@1DE5@0MWIf07IfMP2EUID0VYZJ0080WinO00D0Rh^;08R8R028R8P0WinO08Z:RP0207Yj
NP0408j>SP2TY:@0Y:BT0:ZZZP80S8b<00<0LG5a0?ooo`3oool04`3oool00`3oP000003o0000o`04
0000o`D0oh000`000?l40?n000L0003o1P3oP0040000obP0oh0020000?l@0?n000D0003oA03oP00?
0?ooo`002@3oool0102][Jd0Z:RX0:RXZ02TY:@209:BTP050410@018B4P0B4Q807inOP15ADD00P1G
EeL01@22PX80NWYj07YjNP1kNg/0OWin0080L71`00@0NWYj07UiN@1iNGT0NWYj0P1hN7P01@16ATH0
OWin0;2`/02`/;00ZZZZ00<0WYjN0P2OWil01@2PX:00VYZJ08b<S02<S8`0T92@0080Ph>300D0Ti>C
09:BTP2BTY80J6QX06m_K`0208J6QP0508>3P`1[Jf/0Jf][079bLP1hN7P00P25QHD0102<S8`0TI6A
096AT@2BTY8208J6QP0507EeM@1cLg<0F5QH05QHF02?Shl00P2FUYH01@2CTi<0WIfM09fMW@2NWYh0
XJ6Q0080XZ:R00D0V9RH08j>SP2>SXh0RHV908^;R`0209JFUP0405YJFP1ZJVX0JVYZ0:>SX`<0XJ6Q
00@0VIVI09RHV02HV9P0WIfM0P2IVIT01@2@T900Xj>S0:>SX`2UYJD0XZ:R0080WinO00D0=CDe05AD
E01DE5@0OGem09VIV@020::RXP0409NGU`2DU9@0U9BD09bLW080Xj>S00D0WIfM06MWI`1jNWX0NWYj
071`L00206IVIP0506=SH`2SXj<0Xj>S0:6QX@2RXZ800P2UYJD0102VYZH0X:2P0:2PX02GUiL207Mg
M`050820P02@T900O7al07alO01aLG400P0n?Sh01@2BTY80WYjN0:^[Z`2[Zj/0ZJVY0080YZJV00D0
Z:RX0:BTY02TY:@0WinO09jNWP0209NGU`0409jNWP24Q8@0Q8B403lo?`80MGEe0P2;Rh/209FEU@05
08B4Q01lO7`0O7al096AT@1gMgL00P1jNWX309nOW`040:RXZ023Ph<0Ph>306][JaD0oooo9`3oP007
0000o`D0oh000`000?li0?n001P0003o303oP0030000o`<0oh004@000?l30?n000l0oooo00090?oo
o`040:f][@2XZ:P0Z:RX0:BTY080TY:B00D0@41004Q8B018B4P0OWin04E5A@0205MGE`0508:2PP1j
NWX0NWYj07]kN`1nOWh00P1`L700101jNWX0NGUi07UiN@1jNWX207QhN00504I6AP1nOWh0/;2`0;2`
/02ZZZX00`2NWYh209nOW`050:2PX02JVYX0S8b<08b<S02@T9000P23Ph<01@2CTi<0TY:B09:BTP1X
J6P0Kfm_0080QXJ600D0Ph>306][J`1[Jf/0LW9b07QhN00208F5Q@0408b<S02ATI40TI6A09:BTP80
QXJ600D0MGEe07=cL`1HF5P0F5QH08n?S`0209JFUP0509>CT`2MWId0WIfM09jNWP2QXJ400P2RXZ80
1@2HV9P0SXj>08j>SP29RHT0Rh^;0080UYJF00@0FUYJ06YZJP1ZJVX0Xj>S0`2QXJ40102IVIT0V9RH
09RHV02MWId209VIV@05092@T02SXj<0Xj>S0:FUY@2RXZ800P2OWil01@0e=CD0E5AD05ADE01mOGd0
VIVI0080XZ:R00@0UiNG09BDU02DU9@0W9bL0P2SXj<01@2MWId0IfMW07YjNP1jNWX0L71`0080IVIV
00D0Hf=S0:>SX`2SXj<0XJ6Q0::RXP020:FUY@040:JVYP2PX:00X:2P09NGU`80MgMg00D0P820092@
T01lO7`0O7al075aL@0203hn?P0509:BTP2NWYh0Zj^[0:^[Z`2YZJT00P2VYZH01@2XZ:P0Y:BT0:BT
Y02OWil0WYjN0080UiNG00@0WYjN08B4Q024Q8@0?clo0P1eMGD208^;R`80UIFE00D0Q8B407alO01l
O7`0TI6A07MgM`0207YjNP<0WinO00@0Z:RX08>3P`23Ph<0Jf][5@3ooolW0?n000L0003o1@3oP003
0000ocT0oh0060000?l<0?n000<0003o0`3oP00A0000o`<0oh003`3oool000T0oooo00@0P82006YZ
JP1ZJVX0B4Q80P1EEED01@0m?Cd0EEEE05EEE@1[Jf/0CDe=0080HV9R00D0GEeM06IVIP1VIVH0MgMg
06MWI`0205UIF@0406a/K01_Kfl0Kfm_06EUI@80E5AD00D0=cLg05IFEP2GUiL0UiNG09BDU002092@
T00508V9R@21PH40PH6107IfMP1eMGD00P1cLg<0101ZJVX0I6AT06ATI01@D50204A4A00503<c<`0V
9RH0EEEE05EEE@1?Cdl00P1:BTX0101ADE40Cdm?06EUI@1UIFD305YJFP0506MWI`1FEUH0EUIF055A
D@1?Cdl00P0U9BD0101@D500FUYJ05YJFP1FEUH206QXJ00506a/K01PH600IVIV06IVIP1`L7000P1W
IfL01@1JFUX0DU9B05iNGP1NGUh0@D510080CDe=00D0N7Qh075aL@1aLG40I6AT06QXJ002069RHP04
06IVIP1GEeL0EeMG055AD@80Hf=S00D0KFe]06a/K01VIVH0IVIV02l_;`0203dm?@0505MGE`1LG5`0
KFe]06e]K@1bLW800P1_Kfl3079bLP0506IVIP1;Bd/0DE5A055AD@0i>CT00P0X:2P01@10@400EUIF
05IFEP1IFET0EEEE00<0GUiN0P1OGel01@1JFUX0GUiN05iNGP1KFe/0IfMW0080EeMG00D0CDe=024Q
8@0Q8B40ATI605EEE@02061PH00405QHF01GEeL0EeMG05mOG`80GUiN00D0Fe]K05ADE01DE5@0E5AD
04Y:BP0203hn?P0502XZ:P13@d<0@d=3051@D015ADD00P1CDe<01@1GEeL0De=C05=CD`1DE5@0B4Q8
0080A4A40`18B4P0101<C4`0<S8b038b<P0h>3PE0?ooobL0oh001`000?m:0?n000X0003o4@3oP003
0000o`030?n000000?l0003o0080003o0P3oP0000`000?l0oh000?n000050?n000030000o`3oP000
oh0000D0oh003`3oool000T0oooo00@0H61P030`<00`<300:2PX0P1DE5@01@1KFe/0DE5A055AD@14
A4@0?Shn008071`L00D08R8R05=CD`1CDe<0De=C04];B`0204U9B@0403Hf=P0L71`071`L00X:2P80
DE5A00D0G5aL06e]K@1XJ6P0J6QX06YZJP020492@P05024Q8@0k>c/0>c/k04Q8B01<C4`00P1ADE40
101KFe/0A4A404A4A00Y:BT305]KF`<0GUiN00D0HF5Q04Q8B018B4P09RHV05MGE`0206YZJP04075a
L@1cLg<0Lg=c07YjNP80?clo00D09BDU05YJFP1JFUX0FUYJ05mOG`0206=SH`0505aLG00X:2P0:2PX
03Lg=`1UIFD00P1aLG401021PH40MgMg07MgM`1bLW8302/[:`<0ADE500D0Cdm?05=CD`1CDe<0820P
02XZ:P0206EUI@0406a/K01MGEd0GEeM069RHP80GemO00<0@41004U9B@1XJ6P00P1XJ6P206ATI005
065QH@0o?cl07QhN01hN7P16ATH00P1SHf<01@1RHV80Jf][06][J`1cLg<0:RXZ0080AdM700@0N7Qh
08F5Q@25QHD0R8R80P1kNg/01@1VIVH0:b/[06YZJP1ZJVX0PH610080QhN700D0RHV908R8R028R8P0
BTY:0492@P0206][J`0508B4Q02>SXh0SXj>08^;R`1JFUX00P071`L0100c<c<0E5AD05ADE014A4@2
03Ph>005069RHP1CDe<06ATI01TI6@1TI6@00P1kNg/01@28R8P0RXZ:08Z:RP1mOGd0BTY:0080=SHf
0`1]KFd01@1`L700O7al07inOP1nOWh0?Shn0080I6AT00@0PX:208j>SP2>SXh0U9BD5@3oool_0000
o`80oh009`000?l40?n004<0003o0P3oP00<0000o`l0oooo00090?ooo`04061PH00`<300<30`02PX
:080E5AD00D0Fe]K055AD@1ADE40A4A403hn?P0201`L7005028R8P1CDe<0De=C05=CD`1;Bd/00P19
BDT0100f=SH071`L01`L700:2PX2055AD@0505aLG01]KFd0J6QX06QXJ01ZJVX00P12@T801@0Q8B40
>c/k03/k>`18B4P0C4a<0080DE5A00@0Fe]K04A4A014A4@0:BTY0`1KFe/305iNGP05065QH@18B4P0
B4Q802HV9P1GEeL00P1ZJVX0101aLG40Lg=c07=cL`1jNWX203lo?`0502DU9@1JFUX0FUYJ05YJFP1O
Gel00P1SHf<01@1LG5`0:2PX02PX:00g=cL0IFEU0080LG5a00@0PH6107MgM`1gMgL0LW9b0`0[:b/3
04E5A@0504m?C`1CDe<0De=C020P800Z:RX00P1UIFD0101/K6`0GEeM05eMG@1RHV8205mOG`030410
@019BDT0J6QX0080J6QX0P1TI6@01@1QHF40?clo01hN7P0N7Qh0ATI60080Hf=S00D0HV9R06][J`1[
Jf/0Lg=c02XZ:P0204M7A`0407QhN025QHD0QHF508R8R080Ng]k00D0IVIV02/[:`1ZJVX0JVYZ0861
P@0208N7Q`0508V9R@28R8P0R8R804Y:BP12@T800P1[Jf/01@24Q8@0SXj>08j>SP2;Rh/0FUYJ0080
1`L700@0<c<c05ADE01DE5@0A4A40P0h>3P01@1RHV80De=C01TI6@0I6AT0I6AT0080Ng]k00D0R8R8
08Z:RP2:RXX0OGem04Y:BP0203Hf=P<0KFe]00D0L71`07alO01nOWh0OWin03hn?P0206ATI00408:2
PP2>SXh0SXj>09BDU1D0oooo20000?l70?n000<0003o303oP0020000o`d0oh0000<0003o0?n0003o
P0008@3oP00;0000o`030?n000000?l0003o0480oh0010000?l70?n000030000o`3oool0oooo00d0
oooo00090?ooo`040;bl_01YJFT0JFUY05ADE080ZZZZ00D0U9BD08N7Q`27QhL0RHV9092@T00203Ph
>00504U9B@2GUiL0UiNG0:BTY02`/;000P2c/k<0102SXj<0D51@051@D00Z:RX20;:b/P050;>c/`2h
^;P0^k^k0;^k^`2l_;`00P1mOGd01@0J6QX0UYJF09JFUP2UYJD0Vi^K00<0VYZJ0P1hN7P01@0d=3@0
QXJ608J6QP24Q8@0MGEe0080PH6100D0Ng]k05=CD`1CDe<0A4A408>3P`0208f=S@0409BDU02<S8`0
S8b<092@T080EeMG00D0=CDe0::RXP2KVi/0Vi^K09JFUP020:2PX0050::RXP1EEED0EEEE065QH@2U
YJD00P2VYZH30:VYZ@05096AT@0n?Sh0O7al07alO02;Rh/00P28R8P01@2<S8`0OWin07inOP1iNGT0
DE5A00<0XZ:R0P2YZJT01@2[Zj/0R8R808R8R01SHf<0M7Ad0080X:2P00D0UYJF08N7Q`27QhL0V9RH
09jNWP020492@P0409fMW@2KVi/0Vi^K09FEU@80X:2P00D0WYjN05IFEP1iNGT0NGUi0:2PX0020:JV
YP050:NWY`2VYZH0YZJV09RHV00i>CT00P2<S8`0102XZ:P0ZZZZ0:ZZZP2UYJD20:BTY00505MGE`1c
Lg<0[Zj^0:j^[P2d];@00P2c/k<01@2d];@0QHF501DE5@0E5AD0Ng]k0080YZJV00D0XZ:R0:FUY@2U
YJD0Zj^[09:BTP0201hN7P0408^;R`2?Shl0Shn?096AT@80W9bL00D0Y:BT05QHF00e=CD0=CDe09NG
U`020:2PX0050:f][@2d];@0];Bd0;Bd]016ATH00P2@T900102ZZZX0/[:b0;:b/P2h^;PE0?ooo`P0
003o1`3oP0030000o``0oh000P000?l=0?n000030000o`3oP000oh000240oh002`000?l00`3oP000
003o0000o`120?n000@0003o1`3oP0000`000?l0oooo0?ooo`0=0?ooo`002@3oool0102k^k/0HV9R
069RHP1=CDd20:>SX`050:JVYP2PX:00X:2P09>CT`1oOgl00P0a<C401@19BDT0Y:BT0:BTY02OWil0
WYjN0080Zj^[00@0Z:RX05IFEP1FEUH0:BTY0P2^[Zh01@2i^KT0_;bl0;Ng]`2g]kL0^KVi0080M7Ad
00D07alO0::RXP2RXZ80YJFU092@T00208f=S@0408n?S`1bLW80LW9b02d];@80R8R800D0T92@09RH
V02@T900T92@07]kN`0204M7A`0503<c<`1gMgL0TI6A096AT@2IVIT00P2ATI401@2JVYX0E5AD05AD
E00/;2`0WIfM0080XZ:R0`2LW9`01@2OWil0De=C05=CD`1XJ6P0YJFU0080ZJVY00D0Z:RX0:2PX02P
X:00U9BD04=3@`0207QhN00407]kN`2@T900T92@09BDU080KFe]00D0C4a<05IFEP2BTY80TY:B09ZJ
VP020:JVYP050:j^[P2ZZZX0ZZZZ05QHF01gMgL00P2EUID01@23Ph<0Q8B408B4Q02<S8`0PX:20080
CDe=00@0XJ6Q0:2PX02PX:00SXj>0P26QXH01@2FUYH0FUYJ07inOP1nOWh0[:b/0080ZZZZ00D0ZJVY
09ZJVP2JVYX0T92@04A4A0020:2PX0040;2`/02c/k<0/k>c0;6a/@80[Zj^00D0J6QX07UiN@2][Jd0
[Jf]0;Jf]P020;Rh^0050;Jf]P29RHT03`l?00l?3`1_Kfl00P2QXJ401@2WYjL0ZZZZ0:ZZZP2][Jd0
YZJV00807AdM00@0PH6109FEU@2EUID0WIfM0P2PX:001@2KVi/0C4a<0451@@11@D40YjNW0080ZJVY
00D0Zj^[0:b/[02UYJD0YJFU04=3@`0208^;R`040:^[Z`2][Jd0[Jf]0;Bd]1D0oooo203oP0060000
o`@0oh0010000?l60?n00080003o1@3oP00:0000o`T0oh001`000?l40?n001P0003o1`3oP0030000
odL0oh000`000?l?0?ooo`002@3oool0102g]kL0IfMW06MWI`1EEED20:BTY0050:FUY@2SXj<0Xj>S
09fMW@22PX800P0l?3`01@1<C4`0WinO09nOW`2NWYh0VYZJ00<0Y:BT0P1HF5P01@0X:2P0[Jf]0:f]
[@2h^;P0/[:b0080[jn_00@0];Bd07EeM@1eMGD08R8R0P2NWYh01@2RXZ80W9bL09RHV02HV9P0U9BD
0080KFe]00D0=cLg08f=S@2=SHd0VIVI08F5Q@0208^;R`05092@T01OGel0GemO03dm?@2>SXh00P2T
Y:@0102ZZZX0Y:BT0:BTY02TY:@207MgM`0304I6AP2QXJ40XZ:R0080XZ:R0P2ATI401@2MWId0GUiN
05iNGP1WIfL0YjNW0080[Zj^00D0[jn_0::RXP2RXZ80Ti>C03/k>`0208j>SP0409nOW`2ATI40TI6A
08J6QP80HV9R00D0>SXj0451@@1fMWH0MWIf07moO`0208Z:RP0509>CT`28R8P0R8R8055AD@1iNGT0
0P2<S8`01@1oOgl0Ph>308>3P`2:RXX0SHf=0080AdM700@0Shn?09nOW`2OWil0V9RH0P2;Rh/0102J
VYX0H61P075aL@1aLG430:RXZ0050:NWY`2LW9`0W9bL09>CT`0j>SX00P2][Jd0102h^;P0];Bd0;Bd
]02c/k<20;:b/P0505aLG02;Rh/0]kNg0;Ng]`2i^KT00P2f][H01@2ZZZX0QXJ604A4A014A4@0PH61
0080YJFU00D0Zj^[0;6a/@2a/K40/;2`09nOW`02028R8P0408Z:RP2EUID0UIFE0:2PX080Xj>S00D0
YjNW05mOG`1LG5`0G5aL0:^[Z`020:BTY005096AT@1mOGd0O7al07alO00g=cL00P2;Rh/0102VYZH0
ZZZZ0:ZZZP2[Zj/E0?ooof@0oh0000<0003o0?n0003oP000103oP00010000?l0oh000?n0003oP004
0000o`L0oh0000<0003o0?n000000?l01@000?l40?n000L0003o103oP0020000o`L0oh003P000?l5
0?n000l0oooo00090?ooo`040;Ng]`1WIfL0IfMW05EEE@80Y:BT00D0YJFU0:>SX`2SXj<0WIfM08:2
PP0203`l?00504a<C02OWil0WinO09jNWP2JVYX00`2TY:@205QHF00502PX:02][Jd0[Jf]0;Rh^02b
/[800P2_[jl0102d];@0MGEe07EeM@0R8R8209jNWP050::RXP2LW9`0V9RH09RHV02DU9@00P1]KFd0
1@0g=cL0SHf=08f=S@2IVIT0QHF50080Rh^;00D0T92@05mOG`1OGel0?Cdm08j>SP020:BTY0040:ZZ
ZP2TY:@0Y:BT0:BTY080MgMg00<0ATI60:6QX@2RXZ800P2RXZ82096AT@0509fMW@1NGUh0GUiN06MW
I`2WYjL00P2^[Zh01@2_[jl0XZ:R0::RXP2CTi<0>c/k0080SXj>00@0WinO096AT@2ATI40QXJ60P1R
HV801@0j>SX0@D5107IfMP1fMWH0Ogmo0080RXZ:00D0Ti>C08R8R028R8P0DE5A07UiN@0208b<S005
07moO`23Ph<0Ph>308Z:RP2=SHd00P17AdL0102?Shl0WinO09nOW`2HV9P208^;R`0409ZJVP1PH600
LG5a075aL@<0Z:RX00D0YjNW09bLW02LW9`0Ti>C03Xj>P020:f][@040;Rh^02d];@0];Bd0;>c/`80
/[:b00D0G5aL08^;R`2g]kL0]kNg0;Vi^@020;Jf]P050:ZZZP26QXH0A4A404A4A021PH400P2UYJD0
1@2[Zj/0/K6a0;6a/@2`/;00WinO00808R8R00@0RXZ:09FEU@2EUID0X:2P0P2SXj<01@2WYjL0GemO
05aLG01LG5`0Zj^[0080Y:BT00D0TI6A07emO@1lO7`0O7al03Lg=`0208^;R`040:JVYP2ZZZX0ZZZZ
0:^[ZaD0ooooY03oP0050000o`@0oh003`3oool000T0oooo00@0RHV9059BDP1BDU80FEUI0P2KVi/0
1@2:RXX0VYZJ09ZJVP2KVi/0S8b<0080AdM700D092@T04M7A`17AdL0RXZ:08j>SP0208^;R`0408F5
Q@19BDT0BDU901`L7080@d=300D0MWIf09JFUP2KVi/0Vi^K069RHP0205aLG003024Q8@27QhL0QhN7
0080QhN70P21PH40101hN7P0>c/k03/k>`0W9bL204Y:BP0505UIF@1VIVH0MWIf07IfMP25QHD00P1C
De<01@17AdL0N7Qh08b<S02<S8`0TY:B0080Ti>C00D0T92@04U9B@19BDT0:BTY06i^KP0207YjNP04
07]kN`1iNGT0NGUi08b<S080DU9B00D0DE5A06m_K`1lO7`0O7al07UiN@0207]kN`0506e]K@0^;Rh0
MGEe07EeM@25QHD00P1XJ6P01@1CDe<0A4A404A4A018B4P0<c<c0080J6QX00@0KFe]06=SH`1SHf<0
JFUY0P1VIVH01@0_;bl0C4a<065QH@1QHF40IVIV0080Hf=S00D0Jf][069RHP0F5QH05QHF00000002
0410@00505=CD`1IFET0FEUI06a/K014A4@00P0R8R80100m?Cd0KVi^06i^KP1/K6`206UYJ@0505YJ
FP0`<300EEEE05EEE@1HF5P00P1EEED01@18B4P0A4A404A4A00U9BD0EEEE0080Fe]K00D0IVIV06EU
I@1UIFD0GUiN038b<P0201DE5@0305YJFP1dM7@0M7Ad00<0MgMg00D0K6a/065QH@0X:2P0:2PX04];
B`0205eMG@<0JFUY00D0Kfm_0410@00L71`071`L06MWI`0206UYJ@0505eMG@1;Bd/0BTY:04Y:BP0c
<c<00P1RHV80101YJFT0I6AT06ATI01PH60E0?oooj@0oh001@000?l40?n000l0oooo00090?ooo`04
05mOG`1JFUX0FUYJ04i>CP80820P00D04a<C02DU9@0U9BD08R8R03dm?@0303lo?`80;2`/00D08b<S
02`/;00a<C40<C4a03Xj>P020492@P0504U9B@0F5QH05QHF00P8200E5AD00P0Q8B40100S8b<0:RXZ
02XZ:P0];Bd2038b<P0503<c<`0a<C40?3`l03`l?00m?Cd00`10@402028R8P0500X:2P12@T80BDU9
04U9B@12@T800P0i>CT01@0[:b/0?Cdm04E5A@15ADD0C4a<0080CDe=00D0Cdm?05IFEP1FEUH0EeMG
03dm?@0201LG5`0402h^;P0m?Cd0?Cdm03Xj>P80@41000D0BTY:05IFEP1=CDd0CDe=0410@00203Hf
=P0503/k>`1ADE40DU9B059BDP0];Bd00P0Q8B401@14A4@0@T920492@P1<C4`0@D510080@d=300@0
B4Q804i>CP1>CTh0CTi>0P1BDU801@1RHV80Hf=S05iNGP1NGUh08R8R0080?3`l00D0EEEE06IVIP1e
MGD0MGEe08>3P`0208J6QP0508B4Q01hN7P0N7Qh079bLP23Ph<00P26QXH0102=SHd0JVYZ06YZJP0g
=cL206EUI@05055AD@1TI6@0J6QX06QXJ01/K6`00P1^KVh01@1WIfL0EEEE05EEE@1[Jf/0OWin0080
PH6100D0HV9R02`/;00/;2`0D51@07inOP0208R8R00408J6QP1cLg<0Lg=c079bLP80MWIf00<0LW9b
06ATI01iNGT00P1iNGT206YZJP050451@@1=CDd0CDe=06YZJP1^KVh00P21PH401@25QHD0P8200820
P01cLg<0FEUI0080BDU900@0JFUY08b<S02<S8`0R8R80P0j>SX00`1ADE40oooo0?ooo`0C0?ooojd0
003o3`3oool000T0oooo00@0GemO05YJFP1JFUX0CTi>0P0P82001@0C4a<09BDU02DU9@0R8R80?Cdm
00<0?clo0P0/;2`01@0S8b<0;2`/034a<@0a<C40>SXj0080@T9200D0BDU901HF5P0F5QH020P801DE
5@02024Q8@0402<S8`0Z:RX0:RXZ02d];@80<S8b00D0<c<c034a<@0l?3`0?3`l03dm?@030410@080
8R8R00D02PX:0492@P19BDT0BDU90492@P0203Ti>@0502/[:`0m?Cd0ADE504E5A@1<C4`00P1=CDd0
1@1?Cdl0EUIF05IFEP1GEeL0?Cdm00805aLG00@0;Rh^03dm?@0m?Cd0>SXj0P10@4001@1:BTX0EUIF
04e=C@1=CDd0@4100080=SHf00D0>c/k055AD@1BDU80DU9B02d];@02024Q8@0504A4A012@T80@T92
04a<C011@D400P13@d<01018B4P0CTi>04i>CP1>CTh2059BDP05069RHP1SHf<0GUiN05iNGP0R8R80
0P0l?3`01@1EEED0IVIV07EeM@1eMGD0Ph>30080QXJ600D0Q8B407QhN01hN7P0LW9b08>3P`0208J6
QP0408f=S@1ZJVX0JVYZ03Lg=`80IFEU00D0DE5A06ATI01XJ6P0J6QX06a/K00206i^KP0506MWI`1E
EED0EEEE06][J`1nOWh00P21PH401@1RHV80;2`/02`/;01@D500OWin0080R8R800@0QXJ607=cL`1c
Lg<0LW9b0P1fMWH00`1bLW80I6AT07UiN@0207UiN@80JVYZ00D0@D5104e=C@1=CDd0JVYZ06i^KP02
0861P@0508F5Q@20P800P82007=cL`1IFET00P19BDT0101YJFT0S8b<08b<S028R8P203Xj>P03055A
D@3oool0oooo01<0oooo0`3oP0080000o`P0oh001@000?lB0?n000030000o`3oP000oh0003/0oh00
0`000?m20?n000l0oooo00090?ooo`040:BTY02MWId0WIfM0:2PX080E5AD00D0BTY:071`L01`L700
JVYZ09ZJVP020:6QX@050:2PX022PX80PX:206e]K@21PH400P2;Rh/0102[Zj/0[jn_0:n_[`2VYZH2
0410@00500`<302JVYX0Z:RX0:RXZ02WYjL00P2XZ:P01@2RXZ80YJFU0:FUY@2OWil0T92@0080R8R8
00@0Vi^K09RHV02HV9P0W9bL0P1SHf<01@0F5QH0Z:RX0:FUY@2UYJD0WYjN0080U9BD00<0Ogmo09:B
TP2^[Zh00P2^[Zh20;2`/0050:f][@2_[jl0[jn_0;Bd]02KVi/00P0Q8B40102HV9P0WinO09nOW`2C
Ti<208Z:RP0508>3P`2ATI40TY:B09:BTP2>SXh00P1dM7@01@22PX80Xj>S0:^[Z`2[Zj/0P8200080
CDe=00D0ZZZZ09^KV`2KVi/0V9RH0820P00208J6QP0409>CT`2EUID0UIFE09fMW@80WYjN0P2WYjL2
0:>SX`0503lo?`1MGEd0GEeM08F5Q@23Ph<00`2EUID209>CT`0509JFUP2HV9P0V9RH09>CT`2NWYh0
0P2OWil30::RXP0506e]K@2NWYh0WYjN08N7Q`29RHT00P2RXZ80102PX:00Xj>S0:>SX`2BTY8308n?
S`040:j^[P2d];@0];Bd0;2`/080AdM700D0Zj^[0:RXZ02RXZ80XZ:R0:NWY`020:JVYP030:BTY02W
YjL0YjNW0080XZ:R0P2LW9`0102FUYH0Xj>S0:>SX`1XJ6P208Z:RP050:6QX@2JVYX0TI6A096AT@2O
Wil00P2QXJ401@2IVIT0Ng]k059BDP1BDU80Q8B40080WYjN00@0ZJVY03`l?00l?3`0J6QX5@3oool3
0?n000P0003o203oP0050000oa80oh0000<0003o0?n0003oP000>`3oP0030000od80oh003`3oool0
00T0oooo00@0WIfM09BDU02DU9@0V9RH0P1BDU801@1PH600T92@092@T01dM7@0U9BD0080T92@00D0
U9BD08J6QP26QXH0JFUY07inOP0208n?S`<0YZJV00D0ZZZZ04];B`1;Bd/0=SHf0::RXP020:JVYP04
0:NWY`2ZZZX0ZZZZ0:ZZZP80YZJV00@0WinO092@T021PH40PH610`2CTi<01@2FUYH0Hf=S06=SH`0H
61P0X:2P0080Xj>S00D0W9bL09JFUP2FUYH0OGem08F5Q@030:JVYP80[:b/0`2_[jl01@2a/K40XJ6Q
02PX:00X:2P0VIVI0080V9RH00D0VIVI08Z:RP2:RXX0MgMg08V9R@02092@T00508n?S`25QHD0QHF5
08B4Q02JVYX00P2TY:@0101nOWh0AdM704M7A`2VYZH20:FUY@0508V9R@1kNg/0N7Qh07QhN022PX80
0P2>SXh01@2HV9P0VYZJ09ZJVP2VYZH0Z:RX0080YJFU00D0AdM706MWI`1WIfL0P82008^;R`0208b<
S00408N7Q`24Q8@0Q8B408V9R@80QhN700D0QHF5092@T02DU9@0U9BD08b<S00209NGU`05075aL@2]
[Jd0[Jf]0:2PX02BTY800P2LW9`0102FUYH0WIfM09fMW@2LW9`2096AT@0509FEU@2UYJD0ZZZZ0:ZZ
ZP2_[jl00P1<C4`00`2DU9@0X:2P0:ZZZP020:ZZZP80YjNW00D0WYjN0:>SX`2SXj<0Y:BT09nOW`02
09fMW@040:6QX@2SXj<0Xj>S04m?C`80RXZ:00D0WYjN09:BTP23Ph<0Ph>309JFUP0209^KV`0509RH
V023Ph<0DE5A055AD@24Q8@00P2PX:00102TY:@0ATI604I6AP1cLg<E0?ooob@0oh002@000?l90?n0
00/0003o1`3oP0090000o`L0oh000`000?l50?n000`0003o?P3oP0030000o`l0oooo00090?ooo`04
09fMW@2DU9@0U9BD09RHV080DU9B00D0H61P092@T02@T900M7Ad09BDU002092@T00509BDU026QXH0
QXJ606UYJ@1nOWh00P2?Shl30:JVYP050:ZZZP1;Bd/0Bd];03Hf=P2RXZ800P2VYZH0102WYjL0ZZZZ
0:ZZZP2ZZZX20:JVYP0409nOW`2@T900PH610861P@<0Ti>C00D0UYJF06=SH`1SHf<061PH0:2PX002
0:>SX`0509bLW02FUYH0UYJF07emO@25QHD00`2VYZH20:b/[0<0[jn_00D0/K6a0:6QX@0X:2P0:2PX
09VIV@0209RHV00509VIV@2:RXX0RXZ:07MgM`29RHT00P2@T9001@2?Shl0QHF508F5Q@24Q8@0VYZJ
0080Y:BT00@0OWin04M7A`17AdL0YZJV0P2UYJD01@29RHT0Ng]k07QhN01hN7P0PX:20080SXj>00D0
V9RH09ZJVP2JVYX0YZJV0:RXZ0020:FUY@0504M7A`1WIfL0IfMW0820P02;Rh/00P2<S8`01027QhL0
Q8B408B4Q029RHT208N7Q`0508F5Q@2@T900U9BD09BDU02<S8`00P2GUiL01@1aLG40[Jf]0:f][@2P
X:00TY:B0080W9bL00@0UYJF09fMW@2MWId0W9bL0P2ATI401@2EUID0YJFU0:ZZZP2ZZZX0[jn_0080
C4a<00<0U9BD0:2PX02ZZZX00P2ZZZX20:NWY`0509jNWP2SXj<0Xj>S0:BTY02OWil00P2MWId0102Q
XJ40Xj>S0:>SX`1?Cdl208Z:RP0509jNWP2BTY80Ph>308>3P`2FUYH00P2KVi/01@2HV9P0Ph>3055A
D@1ADE40Q8B40080X:2P00@0Y:BT04I6AP16ATH0Lg=c5@3ooonB0?n000P0003o1@3oP0050000o`@0
oh0000<0003o0?n0003oP0000P3oP00?0?ooo`002@3oool0102YZJT0Xj>S0:>SX`2NWYh205YJFP05
05aLG02OWil0WinO07UiN@2LW9`00P2MWId01@2KVi/0V9RH09RHV01dM7@0V9RH0080UiNG00@0YJFU
0:b/[02/[:`0Z:RX0P1GEeL01@0a<C40Xj>S0:f][@2][Jd0[jn_0080[Zj^00D0Zj^[0:NWY`2WYjL0
XZ:R09>CT`0207emO@<0SHf=00D0SXj>07EeM@1eMGD061PH09bLW00209VIV@0509bLW02QXJ40XJ6Q
08J6QP1lO7`00P2RXZ80102[Zj/0[Zj^0:j^[P2_[jl20;2`/0050:b/[02QXJ40=cLg03Lg=`2KVi/0
0P2MWId01@2RXZ80WinO09nOW`25QHD0UYJF0080VYZJ00D0W9bL08N7Q`27QhL0Q8B409fMW@0209RH
V00407emO@1@D500D51@09JFUP80YJFU00D0Rh^;07inOP1lO7`0O7al08Z:RP0209ZJVP0509bLW02S
Xj<0Xj>S0:FUY@2XZ:P00P2TY:@01@19BDT0F5QH05QHF01hN7P0SXj>0080V9RH00@0QHF507alO01l
O7`0N7Qh0P1eMGD01@22PX80R8R808V9R@29RHT0U9BD0080SHf=00D0KVi^0:RXZ02XZ:P0Y:BT08^;
R`0309nOW`80Y:BT00D0UiNG08f=S@2=SHd0VYZJ0:VYZ@030:^[Z`80@D5100D0VYZJ0:NWY`2/[:`0
[:b/0:j^[P020:n_[`050:f][@2ZZZX0ZZZZ0:^[Z`2YZJT00P2IVIT0102EUID0U9BD09BDU01CDe<2
096AT@0409^KV`2MWId0WIfM09fMW@<0W9bL00D0Xj>S08>3P`1LG5`0G5aL08V9R@020:6QX@040:>S
X`1EEED0EEEE0820P1D0oooo[@3oP00?0?ooo`002@3oool0102NWYh0Ti>C09>CT`26QXH202d];@05
055AD@2HV9P0V9RH07IfMP2>SXh00P2@T9001@2FUYH0U9BD09BDU01VIVH0PH610080O7al00@0TI6A
092@T02@T900W9bL0P1>CTh01@0D51@0Rh^;09:BTP2BTY80Rh^;0080RHV900D0QhN70820P020P800
OGem07IfMP0206QXJ00405]KF`1TI6@0I6AT05YJFP80B4Q800D03Ph>06e]K@1aLG40LG5a07QhN002
07EeM@0407AdM01OGel0PH610861P@<0OGem00D0M7Ad07=cL`1cLg<0KFe]05QHF00202XZ:P04061P
H01`L700L71`07emO@80I6AT00D0HF5Q07AdM01bLW80LW9b06i^KP02069RHP0505EEE@1PH600IFEU
06EUI@0j>SX00P0m?Cd01@1cLg<0MgMg07MgM`1hN7P0L71`0080Jf][00@0H61P06MWI`1WIfL0J6QX
0P1PH6001@1HF5P0HF5Q065QH@1QHF40>SXj0080>c/k00<0Cdm?05IFEP1bLW800P1bLW8205iNGP05
06IVIP1LG5`0G5aL04e=C@14A4@00P0g=cL0100U9BD0CDe=04e=C@0K6a/205IFEP0505]KF`1?Cdl0
Hf=S06=SH`1OGel00P1VIVH01@1DE5@0BTY:04Y:BP1NGUh0GEeM0080Hf=S00D0JFUY028R8P0R8R80
GemO071`L00206e]K@04071`L01HF5P0F5QH06UYJ@80L71`00D0J6QX06UYJ@1DE5@0E5AD03Ph>002
03dm?@0504a<C01@D500D51@05YJFP1QHF400P1SHf<01@1PH600GUiN05iNGP1KFe/0ATI60080>SXj
00@0@D51051@D01@D500BDU90P0/;2`00`0d=3@0oooo0?ooo`0C0?ooojd0oh003`3oool000T0oooo
00@0?Cdm03<c<`0c<c<0<C4a0P0];Bd01@0d=3@0>3Ph03Ph>00n?Sh0>3Ph0080?3`l00@0820P00l?
3`0?3`l04Q8B0`0C4a<0100@410061PH01PH600U9BD203De=@05038b<P0Z:RX0;Bd]02d];@0e=CD0
0P0a<C401@0c<c<04A4A014A4@0a<C40;Rh^0080:BTY00@09BDU028R8P0R8R806a/K0P0R8R801@0S
8b<07alO02<S8`0S8b<09bLW008092@T00D07AdM01<C4`0Y:BT0:BTY02d];@02028R8P<0<C4a00<0
:b/[034a<@0o?cl00P0o?cl203@d=00302XZ:P0`<300<30`00807AdM0P0e=CD01@0X:2P08B4Q024Q
8@0U9BD0;bl_0080=SHf00@0>CTi03hn?P0n?Sh0<c<c0P0T92@01@0V9RH06ATI014A4@0A4A407QhN
0080;Bd]00D0;bl_03lo?`0o?cl0AdM703hn?P0203Ti>@0502d];@0j>SX0>SXj03Hf=P19BDT00P0m
?Cd0100];Bd08b<S02<S8`1?Cdl204e=C@0404m?C`1@D500GEeM05eMG@<0IVIV00D0GEeM04M7A`17
AdL0>c/k04Y:BP0204U9B@0402@T9017AdL0AdM705]KF`80GEeM00D0GUiN05QHF01QHF40HF5Q05YJ
FP02061PH00505]KF`1HF5P0E5AD05ADE01GEeL00P0V9RH01@15ADD0H61P061PH01]KFd0L71`0080
MgMg00@0N7Qh08R8R028R8P0P8200P1dM7@01@1ZJVX0Jf][0820P020P800EEEE0080<30`00D0I6AT
07AdM01hN7P0N7Qh08>3P`0209BDU00409VIV@2NWYh0WYjN09^KVaD0oooo<@000?l00`3oP000003o
0?n000050?n000d0003o103oP01S0000o`l0oooo00090?ooo`0403dm?@0c<c<0<c<c034a<@80;Bd]
00D0=3@d03Ph>00h>3P0?Shn03Ph>00203`l?004020P800?3`l03`l?018B4P<04a<C00@0410@01PH
600H61P09BDU0P0e=CD01@0b<S80:RXZ02d];@0];Bd0=CDe0080<C4a00D0<c<c014A4@0A4A40<C4a
02h^;P0202TY:@0402DU9@0R8R808R8R01/K6`808R8R00D08b<S01lO7`0S8b<08b<S02LW9`0202@T
900501dM7@0C4a<0:BTY02TY:@0];Bd00P0R8R83034a<@0302/[:`0a<C40?clo0080?clo0P0d=3@0
0`0Z:RX0<30`030`<00201dM7@80=CDe00D0:2PX024Q8@0Q8B409BDU02l_;`0203Hf=P0403Ti>@0n
?Sh0?Shn03<c<`8092@T00D09RHV01TI6@0A4A404A4A01hN7P0202d];@0502l_;`0o?cl0?clo04M7
A`0n?Sh00P0i>CT01@0];Bd0>SXj03Xj>P0f=SH0BDU90080?Cdm00@0;Bd]02<S8`0S8b<0Cdm?0P1=
CDd0101?Cdl0D51@05eMG@1MGEd306IVIP0505eMG@17AdL0AdM703/k>`1:BTX00P19BDT0100T92@0
AdM704M7A`1KFe/205eMG@0505iNGP1HF5P0HF5Q065QH@1JFUX00P1PH6001@1KFe/0F5QH05ADE01D
E5@0EeMG00809RHV00D0ADE5061PH01PH600KFe]071`L00207MgM`0407QhN028R8P0R8R80820P080
M7Ad00D0JVYZ06][J`20P800P82005EEE@02030`<00506ATI01dM7@0N7Qh07QhN023Ph<00P2DU9@0
102IVIT0WYjN09jNWP2KVi/E0?ooobX0003o0`3oP0020000o`<0oh0000<0003o0?n0003oP000103o
P0090000o`<0oh0050000?l80?n00080003oA`3oP0030000o`l0oooo00090?ooo`0309BDU02IVIT0
VIVI00<0YjNW00D0Zj^[0:ZZZP2ZZZX0[jn_0:^[Z`020:FUY@0405]KF`0@4100410@07MgM`<0OGem
00@0Ng]k08Z:RP2:RXX0TI6A0P29RHT01@2;Rh/0Ti>C09bLW02LW9`0VYZJ0080XJ6Q00D0VIVI02l_
;`0_;bl0WIfM09BDU00209FEU@0408J6QP1lO7`0O7al07moO`80QhN700D0U9BD08N7Q`2?Shl0Shn?
09FEU@0209BDU00507EeM@0[:b/0V9RH09RHV02JVYX00P2UYJD01@2WYjL0Y:BT0:BTY027QhL0XZ:R
0080YZJV00@0ZJVY0:ZZZP2ZZZX0WYjN0P2UYJD00`1bLW80IVIV0:JVYP020:JVYP80Y:BT00D0W9bL
0:>SX`2RXZ80XZ:R0:NWY`020:BTY0050:>SX`2TY:@0Y:BT0:VYZ@2ATI400P17AdL00`1bLW80VYZJ
09ZJVP0309^KV`0509>CT`2LW9`0UYJF09JFUP28R8P00P2FUYH01@2CTi<0XJ6Q0:b/[02/[:`0UiNG
0080FEUI00D0[Jf]0:ZZZP2ZZZX0Xj>S0:RXZ0020:f][@040:b/[02a/K40/K6a0:n_[`80YjNW00D0
[Zj^0:f][@2WYjL0YjNW059BDP0209RHV0050;2`/02WYjL0YjNW0:FUY@2SXj<00P2WYjL01@2RXZ80
Xj>S0:>SX`2=SHd0O7al0080Ph>300@0ZJVY05EEE@1EEED0P8200`2_[jl0102][Jd0YZJV0:JVYP2H
V9P20:JVYP0509fMW@2QXJ40XJ6Q0:2PX026QXH00P2WYjL01@1fMWH0CDe=04e=C@2IVIT0RXZ:0080
VYZJ00@0YJFU0:n_[`2_[jl0/k>c0P2e]KD00`2b/[80oooo0?ooo`0C0?ooofD0oh001`000?l;0?n0
00P0003o0`3oP0040000ob80oh000P000?l30?n000l0oooo00090?ooo`040:2PX025QHD0QHF5092@
T0<0W9bL0P2QXJ420:FUY@80WIfM00D0Rh^;028R8P0R8R80Ph>3092@T00209fMW@0409JFUP26QXH0
QXJ608N7Q`80Ogmo00D0Q8B4092@T02BTY80TY:B09bLW00209ZJVP0509RHV00l?3`0?3`l09:BTP2V
YZH00P2SXj<0102QXJ40R8R808R8R020P80208^;R`80U9BD0P2EUID01@2>SXh0WIfM09fMW@2;Rh/0
=CDe0080K6a/00@0LW9b07alO01lO7`0MWIf0P29RHT01@2:RXX0VYZJ09NGU`2GUiL0Y:BT0080X:2P
00D0XZ:R0:>SX`2SXj<0Ogmo04i>CP020861P@0508R8R01nOWh0OWin08B4Q023Ph<00P2;Rh/0102D
U9@0T92@092@T02>SXh2092@T005096AT@2BTY80Fe]K05]KF`1OGel00P2;Rh/01@2?Shl0W9bL09bL
W02CTi<0T92@0080QhN700D0Q8B408n?S`2?Shl0UiNG09ZJVP020:RXZ004092@T01XJ6P0J6QX0:^[
Z`80[Jf]00D0YjNW0:RXZ02ZZZX0ZZZZ0:^[Z`020:RXZ0050:b/[02][Jd0[Jf]0;Fe]@2`/;000P2X
Z:P0101KFe/0ZZZZ0:ZZZP2^[Zh20:BTY00509^KV`2RXZ80ZZZZ0:ZZZP2[Zj/00P2/[:`01@2KVi/0
VIVI0:>SX`2SXj<0ZJVY0080H61P00<0QhN70:f][@2][Jd00P2][Jd20:NWY`0409fMW@2TY:@0Y:BT
0::RXP80WYjN00D0X:2P09>CT`2XZ:P0Z:RX07=cL`0205mOG`0509FEU@28R8P0U9BD09BDU02EUID0
0P2JVYX0102UYJD0[Zj^0:j^[P2a/K4E0?ooofD0oh001`000?l;0?n000P0003o0`3oP0040000ob80
oh000P000?l30?n000l0oooo00090?ooo`040:2PX025QHD0QHF5092@T0<0W9bL0P2QXJ420:FUY@80
WIfM00D0Rh^;028R8P0R8R80Ph>3092@T00209fMW@0409JFUP26QXH0QXJ608N7Q`80Ogmo00D0Q8B4
092@T02BTY80TY:B09bLW00209ZJVP0509RHV00l?3`0?3`l09:BTP2VYZH00P2SXj<0102QXJ40R8R8
08R8R020P80208^;R`80U9BD0P2EUID01@2>SXh0WIfM09fMW@2;Rh/0=CDe0080K6a/00@0LW9b07al
O01lO7`0MWIf0P29RHT01@2:RXX0VYZJ09NGU`2GUiL0Y:BT0080X:2P00D0XZ:R0:>SX`2SXj<0Ogmo
04i>CP020861P@0508R8R01nOWh0OWin08B4Q023Ph<00P2;Rh/0102DU9@0T92@092@T02>SXh2092@
T005096AT@2BTY80Fe]K05]KF`1OGel00P2;Rh/01@2?Shl0W9bL09bLW02CTi<0T92@0080QhN700D0
Q8B408n?S`2?Shl0UiNG09ZJVP020:RXZ004092@T01XJ6P0J6QX0:^[Z`80[Jf]00D0YjNW0:RXZ02Z
ZZX0ZZZZ0:^[Z`020:RXZ0050:b/[02][Jd0[Jf]0;Fe]@2`/;000P2XZ:P0101KFe/0ZZZZ0:ZZZP2^
[Zh20:BTY00509^KV`2RXZ80ZZZZ0:ZZZP2[Zj/00P2/[:`01@2KVi/0VIVI0:>SX`2SXj<0ZJVY0080
H61P00<0QhN70:f][@2][Jd00P2][Jd20:NWY`0409fMW@2TY:@0Y:BT0::RXP80WYjN00D0X:2P09>C
T`2XZ:P0Z:RX07=cL`0205mOG`0509FEU@28R8P0U9BD09BDU02EUID00P2JVYX0102UYJD0[Zj^0:j^
[P2a/K4E0?oooiH0oh0010000?l80?n000H0003o1@3oP00?0?ooo`002@3oool0102PX:00QhN708N7
Q`2:RXX209FEU@0509>CT`2NWYh0WYjN09VIV@2FUYH00P2;Rh/01@1lO7`0=CDe03De=@26QXH0UIFE
00<0WYjN0P2<S8`01@2>SXh0O7al07alO01]KFd0SXj>0080W9bL00@0Y:BT09jNWP2NWYh0QhN70P12
@T800`2HV9P0Xj>S0:ZZZP020:ZZZP80V9RH00D0RHV90:6QX@2QXJ40Xj>S0:BTY0020:JVYP050::R
XP2VYZH0YZJV08F5Q@0f=SH00P2IVIT0102OWil0YZJV0:JVYP2MWId20820P005096AT@2HV9P0Q8B4
08B4Q029RHT00P2<S8`01@2KVi/0XZ:R0::RXP23Ph<0CDe=0080Ph>300D0QhN708B4Q024Q8@0NGUi
07alO00207moO`0408J6QP2>SXh0SXj>08F5Q@80SHf=00D0P82007inOP1?Cdl0Cdm?06i^KP0209:B
TP05092@T02HV9P0V9RH0:JVYP2OWil00P2;Rh/01@2?Shl0W9bL09bLW02MWId0V9RH0080Xj>S00@0
S8b<05QHF01HF5P0/K6a0P2c/k<01@2][Jd0/;2`0:f][@2][Jd0[:b/0080[Zj^00D0/[:b0;Bd]02d
];@0]kNg0;Fe]@020:f][@0404Q8B02NWYh0WYjN0;2`/080ZZZZ00D0[Jf]0:n_[`2e]KD0]KFe0:j^
[P020;Fe]@050:b/[02QXJ40ZJVY0:VYZ@2/[:`00P1IFET00`25QHD0[Zj^0:j^[P020:b/[080YjNW
00<0XZ:R0:RXZ02XZ:P00`2XZ:P01@2WYjL0XJ6Q0;Jf]P2f][H0QHF50080J6QX00D0R8R807]kN`28
R8P0R8R80861P@0208J6QP040:6QX@2XZ:P0Z:RX0:RXZ1D0ooooUP3oP0000`000?l0oh000?n0000?
0?n000030000o`3oP000oh000080oh003`3oool000T0oooo00@0XZ:R09:BTP2BTY80VYZJ0P2NWYh0
1@2:RXX0SHf=08f=S@2ATI40RHV90080Ng]k00D0MWIf02LW9`0W9bL0P82009RHV00209fMW@040:JV
YP2LW9`0W9bL09fMW@80VIVI00D0SHf=0820P02DU9@0U9BD09ZJVP0208>3P`0506EUI@17AdL0AdM7
09jNWP2RXZ800P2VYZH0102[Zj/0WinO09nOW`2GUiL209fMW@050:2PX02TY:@0WYjN09jNWP2FUYH0
0P2BTY801@1kNg/0<30`08Z:RP2:RXX0VIVI0080WIfM00D0XZ:R08>3P`23Ph<0Ng]k07moO`0206e]
K@0406a/K01]KFd0KFe]08V9R@80PH6100D0EEEE04E5A@1bLW80LW9b07MgM`0207]kN`0507UiN@1Y
JFT0JFUY06UYJ@1cLg<00P1/K6`01@1^KVh0O7al07alO01fMWH0P8200080C4a<00@0GUiN07UiN@1i
NGT0PX:20P25QHD01@28R8P0SHf=08f=S@2=SHd0Ng]k0080Rh^;0P25QHD20861P@0405YJFP0Y:BT0
:BTY08J6QP80Ti>C00D0SXj>08n?S`23Ph<0Ph>30861P@0208:2PP0508F5Q@27QhL0QhN708Z:RP26
QXH00P1oOgl0100];Bd0J6QX06QXJ022PX8207moO`0508j>SP29RHT0RXZ:08Z:RP1`L7000P1fMWH0
1@1nOWh0Lg=c06i^KP1^KVh0JFUY0080<C4a00D0BDU9071`L01`L700LG5a06m_K`0206][J`0406EU
I@1EEED0EEEE05EEE@80FUYJ00D0EUIF05=CD`14A4@0A4A402<S8`0202TY:@0503`l?00g=cL0?3`l
03`l?014A4@00P1FEUH0101RHV80GemO05mOG`1KFe/E0?oooaX0003o1@3oP00L0000o`<0oh006P00
0?l00`3oP000003o0000o`0:0000o`X0oh008P000?l50?n001L0003o3`3oool000T0oooo00@0XZ:R
09:BTP2BTY80VYZJ0P2NWYh01@2:RXX0SHf=08f=S@2ATI40RHV90080Ng]k00D0MWIf02LW9`0W9bL0
P82009RHV00209fMW@040:JVYP2LW9`0W9bL09fMW@80VIVI00D0SHf=0820P02DU9@0U9BD09ZJVP02
08>3P`0506EUI@17AdL0AdM709jNWP2RXZ800P2VYZH0102[Zj/0WinO09nOW`2GUiL209fMW@050:2P
X02TY:@0WYjN09jNWP2FUYH00P2BTY801@1kNg/0<30`08Z:RP2:RXX0VIVI0080WIfM00D0XZ:R08>3
P`23Ph<0Ng]k07moO`0206e]K@0406a/K01]KFd0KFe]08V9R@80PH6100D0EEEE04E5A@1bLW80LW9b
07MgM`0207]kN`0507UiN@1YJFT0JFUY06UYJ@1cLg<00P1/K6`01@1^KVh0O7al07alO01fMWH0P820
0080C4a<00@0GUiN07UiN@1iNGT0PX:20P25QHD01@28R8P0SHf=08f=S@2=SHd0Ng]k0080Rh^;0P25
QHD20861P@0405YJFP0Y:BT0:BTY08J6QP80Ti>C00D0SXj>08n?S`23Ph<0Ph>30861P@0208:2PP05
08F5Q@27QhL0QhN708Z:RP26QXH00P1oOgl0100];Bd0J6QX06QXJ022PX8207moO`0508j>SP29RHT0
RXZ:08Z:RP1`L7000P1fMWH01@1nOWh0Lg=c06i^KP1^KVh0JFUY0080<C4a00D0BDU9071`L01`L700
LG5a06m_K`0206][J`0406EUI@1EEED0EEEE05EEE@80FUYJ00D0EUIF05=CD`14A4@0A4A402<S8`02
02TY:@0503`l?00g=cL0?3`l03`l?014A4@00P1FEUH0101RHV80GemO05mOG`1KFe/E0?oooaX0003o
1@3oP00L0000o`<0oh006P000?l00`3oP000003o0000o`0:0000o`X0oh008P000?l50?n001L0003o
3`3oool000T0oooo00@0;2`/02DU9@0U9BD06QXJ0P0N7Qh01@0B4Q804A4A014A4@0C4a<02`/;0080
3@d=00D02@T900X:2P0:2PX05QHF01XJ6P0201PH600301lO7`0P8200820P00<07AdM00D06ATI01<C
4`0E5AD05ADE01TI6@0201@D500501hN7P0h>3P0>3Ph02l_;`0Y:BT00P0V9RH302DU9@05024Q8@0K
6a/06a/K01XJ6P0W9bL00P0X:2P01@0T92@07QhN01hN7P0N7Qh05aLG008071`L00@0410@01DE5@0E
5AD06QXJ0P0P82001@0?3`l07AdM02@T900T92@05QHF00808B4Q00D092@T02d];@0];Bd0<30`03@d
=00203<c<`0502@T900S8b<08b<S01lO7`0J6QX00P0C4a<0100[:b/0=3@d03@d=00c<c<203Ti>@05
03De=@0^;Rh0>3Ph03Ph>010@4000P15ADD01@11@D40?Cdm03dm?@0j>SX08R8R0080820P00D09RHV
03<c<`0c<c<0>CTi04I6AP0204];B`0404M7A`1=CDd0CDe=04A4A080=SHf00D0=3@d02l_;`0a<C40
<C4a01lO7`0202PX:00503<c<`0V9RH09RHV03Lg=`0^;Rh00P0l?3`01016ATH0AdM704M7A`1=CDd2
04Y:BP0504e=C@1?Cdl08b<S02<S8`0g=cL00P1LG5`01@1RHV80GUiN065QH@1QHF40Hf=S0080JVYZ
00D0KFe]06MWI`1WIfL0J6QX06MWI`0206i^KP04069RHP0j>SX0>SXj06e]K@80Lg=c00D0NWYj07mo
O`1jNWX0NWYj07AdM002075aL@0506][J`1`L700M7Ad07AdM01jNWX00P1mOGd0100W9bL0IVIV06IV
IP2=SHdE0?ooof`0003o00<0oh000000o`000?l040000?lY0?n000D0003o3`3oool000T0oooo00@0
Vi^K09FEU@2EUID0RXZ:0P1CDe<00`2_[jl0YjNW0:NWY`0208B4Q080TI6A0`2MWId01@2SXj<0[Jf]
0:RXZ02XZ:P0]KFe0080/[:b00D0MWIf03`l?00l?3`0T92@0:6QX@020:JVYP040:b/[02TY:@0Y:BT
0::RXP80WYjN00D0UYJF08V9R@26QXH0QXJ608^;R`0209fMW@0503Ti>@1LG5`0G5aL09JFUP2MWId0
0P2YZJT0102GUiL0T92@092@T02?Shl308R8R00408N7Q`2LW9`0W9bL09nOW`80VYZJ00D0:RXZ08:2
PP2CTi<0Ti>C08b<S003092@T080V9RH00D0X:2P09nOW`2PX:00X:2P0::RXP0309jNWP0406m_K`0j
>SX0>SXj0:NWY`80YJFU00D0YjNW0:6QX@2QXJ40UIFE09NGU`020:6QX@040::RXP2UYJD0YJFU0:JV
YP80YJFU00@0XJ6Q04i>CP1[Jf/0Jf][0`2HV9P01@2DU9@0XZ:R0:NWY`2WYjL0[:b/00<0[Zj^0P2Z
ZZX01@2SXj<0Ng]k096AT@2ATI40A4A40080X:2P00D0^k^k0;jn_P2n_[h0_;bl0;Zj^P030;Vi^@80
_kno00D0a<C40<?3``33`l<0aLG50<O7a`0204m?C`0507YjNP2c/k<0/k>c0;Rh^02b/[800P2_[jl0
102`/;00[:b/0:b/[02/[:`20:FUY@0508j>SP2BTY80V9RH09RHV024Q8@00P1=CDd308R8R00508^;
R`2BTY80Shn?08n?S`29RHT00P2;Rh/01@28R8P0Ti>C09NGU`2GUiL0X:2P0080WIfM00@0>c/k0:2P
X02PX:00];Bd5@3ooon20?n000P0003o00<0oh000000o`000?l010000?lH0?n000040000o`3oP000
oh000?n000l0oooo00090?ooo`040:^[Z`2WYjL0YjNW0:VYZ@80C4a<0`2ZZZX01@2OWil0V9RH09VI
V@2IVIT0XJ6Q00<0YJFU00@0YjNW0:f][@2][Jd0[:b/0P2^[Zh01@2ATI40?Shn03hn?P2=SHd0VIVI
0080V9RH00@0VYZJ096AT@2ATI40TI6A0P2BTY801@2?Shl0Ti>C08B4Q024Q8@0P8200080V9RH00@0
BDU906m_K`1_Kfl0WYjN0`2VYZH01@2DU9@0R8R808R8R027QhL0Q8B40080OWin00@0Ph>309NGU`2G
UiL0VYZJ0P2ATI401@0T92@0LG5a07EeM@1eMGD0NGUi0080PH6100D0SXj>09ZJVP2JVYX0SXj>09FE
U@0209>CT`050:BTY02XZ:P0Z:RX0:JVYP1UIFD00P0l?3`00`2TY:@0XZ:R0::RXP0309jNWP050:6Q
X@2JVYX0UIFE09FEU@2DU9@00P2EUID01@2>SXh0U9BD09BDU02QXJ40G5aL0080Hf=S00D0SXj>09:B
TP2BTY80V9RH08N7Q`0208f=S@0409jNWP2GUiL0UiNG096AT@80SHf=00D0RHV908^;R`1oOgl0Ogmo
04=3@`020;2`/0050;fm_@2j^[X0^[Zj0;Ng]`2c/k<00P2j^[X0102c/k<0];Bd0;Bd]02k^k/20;Zj
^P050;no_`31`L40Hf=S06=SH`22PX800`2/[:`0102QXJ40Xj>S0:>SX`2QXJ4209bLW00509ZJVP2I
VIT0VIVI07AdM01`L7000P1gMgL00`1]KFd0BDU904U9B@030820P00508N7Q`22PX80Q8B408B4Q01o
Ogl00P1mOGd01@1oOgl0Ng]k08F5Q@25QHD0Ti>C0080V9RH00@0=cLg09bLW02LW9`0ZJVY5@3ooonB
0?n00180003o103oP0000`000?l0oh000?n000020?n000l0oooo00090?ooo`040:^[Z`2WYjL0YjNW
0:VYZ@80C4a<0`2ZZZX01@2OWil0V9RH09VIV@2IVIT0XJ6Q00<0YJFU00@0YjNW0:f][@2][Jd0[:b/
0P2^[Zh01@2ATI40?Shn03hn?P2=SHd0VIVI0080V9RH00@0VYZJ096AT@2ATI40TI6A0P2BTY801@2?
Shl0Ti>C08B4Q024Q8@0P8200080V9RH00@0BDU906m_K`1_Kfl0WYjN0`2VYZH01@2DU9@0R8R808R8
R027QhL0Q8B40080OWin00@0Ph>309NGU`2GUiL0VYZJ0P2ATI401@0T92@0LG5a07EeM@1eMGD0NGUi
0080PH6100D0SXj>09ZJVP2JVYX0SXj>09FEU@0209>CT`050:BTY02XZ:P0Z:RX0:JVYP1UIFD00P0l
?3`00`2TY:@0XZ:R0::RXP0309jNWP050:6QX@2JVYX0UIFE09FEU@2DU9@00P2EUID01@2>SXh0U9BD
09BDU02QXJ40G5aL0080Hf=S00D0SXj>09:BTP2BTY80V9RH08N7Q`0208f=S@0409jNWP2GUiL0UiNG
096AT@80SHf=00D0RHV908^;R`1oOgl0Ogmo04=3@`020;2`/0050;fm_@2j^[X0^[Zj0;Ng]`2c/k<0
0P2j^[X0102c/k<0];Bd0;Bd]02k^k/20;Zj^P050;no_`31`L40Hf=S06=SH`22PX800`2/[:`0102Q
XJ40Xj>S0:>SX`2QXJ4209bLW00509ZJVP2IVIT0VIVI07AdM01`L7000P1gMgL00`1]KFd0BDU904U9
B@030820P00508N7Q`22PX80Q8B408B4Q01oOgl00P1mOGd01@1oOgl0Ng]k08F5Q@25QHD0Ti>C0080
V9RH00@0=cLg09bLW02LW9`0ZJVY5@3ooonB0?n00180003o103oP0000`000?l0oh000?n000020?n0
00l0oooo00090?ooo`040:JVYP2OWil0WinO0:VYZ@80CDe=0`2WYjL01@2UYJD0XZ:R09RHV02HV9P0
WinO0080WYjN00D0UiNG09RHV02WYjL0YjNW0:n_[`020:b/[00508f=S@0o?cl0?clo08b<S02KVi/0
0P2UYJD0102WYjL0Y:BT0:BTY02MWId20:6QX@050:NWY`2OWil0QXJ608J6QP2>SXh00P2EUID01@16
ATH0IVIV06IVIP2SXj<0Z:RX0080Y:BT00D0V9RH08n?S`2?Shl0QhN707]kN`0207QhN004079bLP24
Q8@0Q8B409VIV@80TI6A00D0<S8b07AdM01lO7`0O7al08f=S@0208^;R`0508Z:RP2QXJ40XJ6Q0:6Q
X@2OWil00P2HV9P01@2KVi/0Xj>S0:>SX`2KVi/08b<S0080@41000@0YjNW0:RXZ02XZ:P0XZ:R0P2S
Xj<01@2MWId0Ti>C09FEU@2EUID0Ti>C00D0WYjN00D0YZJV06=SH`1FEUH0EUIF07inOP0208Z:RP80
VIVI0P2NWYh0102TY:@0WIfM09fMW@2PX:020:BTY00509BDU02:RXX0VIVI09VIV@19BDT00P2`/;00
1030`<00^;Rh0;Rh^02g]kL30;Bd]0040:f][@2XZ:P0Z:RX0:RXZ080[Jf]00D0_Kfm0<[:bP1UIFD0
IFEU08B4Q0020:VYZ@030:>SX`2LW9`0V9RH0080V9RH0P2DU9@01@2BTY80TI6A096AT@1lO7`0MGEe
0080LG5a00@0IfMW055AD@1ADE40UIFE0P2HV9P01@2BTY80R8R808B4Q024Q8@0N7Qh0080PX:200D0
P82007moO`29RHT0RHV909JFUP0209VIV@0402TY:@2:RXX0RXZ:09JFUQD0oooo3P3oP0000`000?l0
oh000?n0000?0?n00080003oN03oP0070000o`D0oh0010000?l30?n000l0oooo00090?ooo`040:b/
[02VYZH0YZJV09RHV080Bd];00D0Zj^[0:NWY`2WYjL0WinO0:2PX00209RHV00509NGU`24Q8@0Q8B4
092@T021PH400P2GUiL0102KVi/0Shn?08n?S`1iNGT20410@00508J6QP2LW9`0Z:RX0:RXZ02YZJT0
0P2/[:`01@2^[Zh0ZJVY0:VYZ@2UYJD0Vi^K0080VYZJ00@0W9bL08^;R`2;Rh/09BDU0P1]KFd01@2Q
XJ40Ti>C0:6QX@2QXJ40Ti>C0080MGEe00D0M7Ad07EeM@1^KVh0KVi^071`L00207moO`0509VIV@2D
U9@0U9BD03Ti>@1oOgl00P22PX80102:RXX0U9BD09BDU028R8P209JFUP80Vi^K0P2ATI401@2=SHd0
WIfM09fMW@2DU9@0EEEE0080@T9200<0Y:BT0:VYZ@2YZJT00`2ZZZX01@2SXj<0UIFE08J6QP26QXH0
NGUi0080UYJF0`2HV9P01@2JVYX0J6QX04e=C@1=CDd0N7Qh0080Rh^;00D0XJ6Q0:FUY@2VYZH0YZJV
09BDU00209fMW@0509NGU`2@T900T92@08^;R`1lO7`00P2HV9P0101CDe<0W9bL09bLW02JVYX20:b/
[0050;jn_P2`/;00Y:BT0:BTY02HV9P00P2PX:001@2EUID0TI6A096AT@2=SHd0WYjN0080CDe=00D0
LW9b07inOP1nOWh0MWIf07inOP0207EeM@04079bLP1gMgL0MgMg07=cL`80LW9b00D0GEeM05MGE`19
BDT0BDU903Ph>00203<c<`0505aLG01SHf<0Hf=S06EUI@1KFe/00P19BDT01@13@d<0BDU904U9B@1C
De<0CDe=00<0De=C0P16ATH0100L71`0GUiN05iNGP1ZJVXE0?ooo`030?n000000?l0003o00P0003o
00@0oh000000o`000?l0003o0`3oP00A0000o`030?n000000?l0003o04L0003o1`3oP00]0000o`L0
oh001@000?l?0?ooo`002@3oool0102/[:`0YZJV0:JVYP2HV9P204];B`050:^[Z`2WYjL0YjNW09nO
W`2PX:000P2HV9P01@2GUiL0Q8B408B4Q02@T900PH610080UiNG00@0Vi^K08n?S`2?Shl0NGUi0P10
@4001@26QXH0W9bL0:RXZ02XZ:P0ZJVY0080[:b/00D0[Zj^0:VYZ@2YZJT0YJFU09^KV`0209ZJVP04
09bLW02;Rh/0Rh^;02DU9@80KFe]00D0XJ6Q09>CT`2QXJ40XJ6Q09>CT`0207EeM@0507AdM01eMGD0
KVi^06i^KP1`L7000P1oOgl01@2IVIT0U9BD09BDU00i>CT0Ogmo0080PX:200@0RXZ:09BDU02DU9@0
R8R80P2FUYH209^KV`80TI6A00D0SHf=09fMW@2MWId0U9BD05EEE@020492@P030:BTY02YZJT0ZJVY
00<0ZZZZ00D0Xj>S09FEU@26QXH0QXJ607UiN@0209JFUP<0V9RH00D0VYZJ06QXJ01=CDd0CDe=07Qh
N00208^;R`050:6QX@2UYJD0YZJV0:JVYP2DU9@00P2MWId01@2GUiL0T92@092@T02;Rh/0O7al0080
V9RH00@0De=C09bLW02LW9`0VYZJ0P2/[:`01@2n_[h0/;2`0:BTY02TY:@0V9RH0080X:2P00D0UIFE
096AT@2ATI40SHf=09jNWP0204e=C@05079bLP1nOWh0OWin07IfMP1nOWh00P1eMGD0101bLW80MgMg
07MgM`1cLg<2079bLP0505eMG@1GEeL0BDU904U9B@0h>3P00P0c<c<01@1LG5`0Hf=S06=SH`1UIFD0
Fe]K0080BDU900D0@d=304U9B@19BDT0De=C04e=C@0305=CD`80ATI600@071`L05iNGP1NGUh0JVYZ
5@3ooom[0000o`D0oh001`000?lG0?n000030000o`3oP000oh0001/0oh0000<0003o0?ooo`3oool0
3@3oool000T0oooo00@0GEeM04M7A`17AdL0>3Ph0P0V9RH01@0g=cL0?3`l03`l?00h>3P0>SXj0080
=cLg00D0<c<c02`/;00/;2`071`L024Q8@0202HV9P0402@T900Z:RX0:RXZ028R8P80410@00D0?clo
04M7A`11@D40@D5104I6AP0204Q8B00504];B`1IFET0FEUI04I6AP0f=SH00P0c<c<0100i>CT06QXJ
01XJ6P061PH200d=3@804a<C0P0K6a/01@0I6AT071`L01`L700M7Ad07QhN00806ATI00@07QhN020P
800P82007AdM0P0O7al01@0M7Ad05aLG01/K6`0K6a/07alO0080820P00D06QXJ020P800P82008b<S
01TI6@0202LW9`0302<S8`0U9BD09BDU0080820P0P0Q8B40100[:b/0?Shn03hn?P0o?cl203Ti>@05
03@d=00/;2`08b<S02<S8`0820P00P0G5aL01@0[:b/0<S8b038b<P0a<C40<30`0080;2`/00D0>SXj
03Ph>00h>3P0@41005=CD`02055AD@0403Lg=`0T92@092@T01lO7`809RHV00D0:BTY03Lg=`0n?Sh0
?Shn03/k>`0203Xj>P0503Lg=`14A4@0A4A404];B`1>CTh00P1<C4`0100e=CD07QhN01hN7P0k>c/2
03dm?@050492@P13@d<0CDe=04e=C@16ATH00`14A4@00`0m?Cd0AdM704M7A`0304U9B@0501`L700k
>c/0>c/k061PH01OGel00P1QHF40101[Jf/0JVYZ06YZJP1RHV82071`L0050861P@1mOGd0O7al07al
O01VIVH00P0i>CT01@1oOgl0NGUi07]kN`1kNg/0P8200080Q8B400@0S8b<07YjNP1jNWX0Kfm_5@3o
oom[0000o`D0oh001`000?lG0?n000030000o`3oP000oh0001/0oh0000<0003o0?ooo`3oool03@3o
ool000T0oooo00@0V9RH09BDU02DU9@0UYJF0P2IVIT01@2JVYX0V9RH09RHV02=SHd0V9RH00<0X:2P
0P2CTi<01@0R8R80JFUY08V9R@29RHT0QHF50080UYJF00D0Ti>C08b<S02<S8`0OWin07alO0020820
P004096AT@2JVYX0VYZJ0:6QX@80WYjN00D0<S8b06ATI025QHD0QHF508J6QP0208R8R0050:BTY02S
Xj<0Xj>S09RHV02SXj<00P2PX:0309bLW00509RHV01nOWh0=SHf03Hf=P27QhL00P2LW9`01@2JVYX0
Vi^K09^KV`2PX:00WIfM0080XZ:R00@0WinO0:2PX02PX:00XZ:R0P2SXj<01@2UYJD0=CDe0861P@21
PH40OWin0080P82000D0MgMg06i^KP1eMGD0MGEe096AT@0209JFUP0509>CT`2ATI40TI6A08>3P`22
PX800P1aLG40100b<S80Ng]k07]kN`26QXH209>CT`0509RHV02LW9`0VYZJ09ZJVP2EUID00P2DU9@0
1@2QXJ40X:2P0:NWY`2WYjL0Y:BT0080EUIF00D0O7al0:ZZZP2ZZZX0YJFU0:BTY0020:JVYP040:BT
Y02UYJD0YJFU0:>SX`80Z:RX00D0VYZJ07=cL`1bLW80LW9b06m_K`02051@D0050;Jf]P2[Zj/0Zj^[
09jNWP2SXj<00`2c/k<20:ZZZP0509jNWP2?Shl0YJFU0:FUY@2ZZZX00P2TY:@01@1BDU80XJ6Q0:6Q
X@2KVi/0Rh^;0080O7al00@0M7Ad08B4Q024Q8@0MWIf0P1lO7`01@2DU9@0VIVI09BDU02DU9@0LW9b
0080=CDe0P2JVYX209RHV00409^KV`2PX:00X:2P08Z:RP80Q8B400<0NGUi0?ooo`3oool04`3ooomg
0?n000T0003o1`3oP0060000o`030?n000000?l0oh0001T0oh000`000?l00`3oP000oooo0?ooo`0=
0?ooo`002@3oool0102HV9P0U9BD09BDU02FUYH209VIV@0509ZJVP2HV9P0V9RH08f=S@2HV9P00`2P
X:0209>CT`05028R8P1YJFT0RHV908V9R@25QHD00P2FUYH01@2CTi<0S8b<08b<S01nOWh0O7al0080
P82000@0TI6A09ZJVP2JVYX0XJ6Q0P2NWYh01@0b<S80I6AT08F5Q@25QHD0QXJ60080R8R800D0Y:BT
0:>SX`2SXj<0V9RH0:>SX`020:2PX0<0W9bL00D0V9RH07inOP0f=SH0=SHf08N7Q`0209bLW00509ZJ
VP2KVi/0Vi^K0:2PX02MWId00P2RXZ80102OWil0X:2P0:2PX02RXZ820:>SX`050:FUY@0e=CD0PH61
0861P@1nOWh00P20P8001@1gMgL0KVi^07EeM@1eMGD0TI6A0080UYJF00D0Ti>C096AT@2ATI40Ph>3
08:2PP02075aL@04038b<P1kNg/0Ng]k08J6QP80Ti>C00D0V9RH09bLW02JVYX0VYZJ09FEU@0209BD
U0050:6QX@2PX:00YjNW0:NWY`2TY:@00P1FEUH01@1lO7`0ZZZZ0:ZZZP2UYJD0Y:BT0080YZJV00@0
Y:BT0:FUY@2UYJD0Xj>S0P2XZ:P01@2JVYX0Lg=c079bLP1bLW80Kfm_0080D51@00D0][Jf0:^[Z`2[
Zj/0WYjN0:>SX`030;>c/`80ZZZZ00D0WYjN08n?S`2UYJD0YJFU0:ZZZP020:BTY005059BDP2QXJ40
XJ6Q09^KV`2;Rh/00P1lO7`0101dM7@0Q8B408B4Q01fMWH207alO00509BDU02IVIT0U9BD09BDU01b
LW800P0e=CD209ZJVP80V9RH00@0Vi^K0:2PX02PX:00RXZ:0P24Q8@00`1iNGT0oooo0?ooo`0C0?oo
oiH0oh0010000?l;0?n000@0003o103oP00?0?ooo`002@3oool00`2g]kL0/;2`0;2`/0030:j^[P05
0;2`/02^[Zh0[Zj^0:NWY`2UYJD00P2TY:@01@2ZZZX0Zj^[0:^[Z`0f=SH0Shn?00<0ZJVY0P2TY:@0
1@2:RXX0MgMg07MgM`26QXH0Vi^K0080QXJ600@0Rh^;0:6QX@2QXJ40Y:BT0P2OWil01@0i>CT0TY:B
0:2PX02PX:00Ti>C00<0YZJV0P2RXZ801@2BTY80SHf=08B4Q024Q8@0UiNG0080X:2P00D0SXj>07Ui
N@11@D40@D5108R8R0020:6QX@0509fMW@2RXZ80XZ:R09VIV@2MWId00P2IVIT01029RHT0S8b<08b<
S02HV9P20:FUY@040:VYZ@0i>CT0IVIV06IVIP<0OWin00D0NGUi06a/K01aLG40LG5a07MgM`0507em
O@0507alO01kNg/0P8200820P013@d<00P21PH401@1oOgl0NWYj07YjNP25QHD0QXJ60080Ph>300D0
T92@08Z:RP2:RXX0Ti>C09ZJVP020:2PX0040:b/[01PH600H61P07moO`80Z:RX00D0XZ:R08^;R`26
QXH0QXJ608:2PP0208B4Q00508f=S@2KVi/0Vi^K09JFUP1nOWh00P1hN7P0101SHf<0A4A404A4A02]
[Jd20:RXZ0050:NWY`2RXZ80YJFU0:FUY@2[Zj/00P2VYZH01@2TY:@0XJ6Q0:BTY02TY:@0Xj>S0080
Vi^K00D0ATI609fMW@2MWId0SHf=08F5Q@0207MgM`0406i^KP1jNWX0NWYj07EeM@80LW9b00D0RHV9
09>CT`2QXJ40XJ6Q07QhN002034a<@0508b<S02=SHd0RHV908V9R@2?Shl00P2PX:001026QXH0NWYj
07YjNP23Ph<E0?ooo`@0003o403oP0040000oi00oh001@000?l?0?ooo`002@3oool0102g]kL0[Zj^
0:j^[P2a/K420:f][@050;Bd]02_[jl0[jn_0:ZZZP2WYjL00P2ZZZX01@2b/[80VIVI09VIV@0Z:RX0
Rh^;0080Y:BT00@0YjNW0::RXP2RXZ80PX:20P1hN7P20861P@80OWin00@0S8b<09RHV02HV9P0Y:BT
0P2PX:001@0g=cL0Vi^K09RHV02HV9P0Shn?0080WIfM00D0UYJF09fMW@2MWId0UYJF092@T00208B4
Q00508b<S02GUiL0UiNG08^;R`1nOWh00P0m?Cd0102ATI40XJ6Q0:6QX@2QXJ4209nOW`0509FEU@2K
Vi/0UIFE09FEU@2GUiL00P2@T9001@2BTY80Xj>S0:>SX`2UYJD0<c<c0080HV9R00D0Lg=c07moO`1o
Ogl0QXJ606QXJ00206MWI`04079bLP1hN7P0N7Qh0820P080PX:200D0R8R808J6QP1oOgl0Ogmo04Q8
B00207moO`0507IfMP1^KVh0KVi^07QhN021PH400P1lO7`01@1hN7P0Ogmo07moO`1lO7`0TY:B0080
Ti>C00@0Zj^[06a/K01/K6`0Ng]k0P2VYZH01@2RXZ80VYZJ096AT@2ATI40Ti>C0080T92@00D0Ti>C
0::RXP2RXZ80S8b<08>3P`0208B4Q00406QXJ01EEED0EEEE0:ZZZP80Z:RX00D0/;2`0:b/[02_[jl0
[jn_0:VYZ@020:RXZ0050:NWY`2PX:00XZ:R0::RXP2MWId00P2<S8`01@0T92@0W9bL09bLW02UYJD0
QXJ60080Kfm_00@0JFUY05iNGP1NGUh0JFUY0P1VIVH01@2@T900Vi^K09jNWP2NWYh0OGem0080B4Q8
00<0XZ:R09nOW`2VYZH00P2VYZH20:n_[`040:JVYP2PX:00X:2P0:>SXaD0oooo10000?l@0?n000@0
003oT03oP0050000o`l0oooo00090?ooo`040;Rh^02c/k<0/k>c0;Bd]080ZZZZ00D0ZJVY0:j^[P2^
[Zh0ZJVY0:ZZZP020:>SX`050:2PX02OWil0WinO04U9B@2OWil00P2PX:00102QXJ40UiNG09NGU`29
RHT207alO00507emO@1hN7P0TI6A096AT@2JVYX00P2KVi/01@2SXj<0UiNG09NGU`0m?Cd0Vi^K0080
VIVI00@0TY:B0:BTY02TY:@0X:2P0P2UYJD01@2<S8`0T92@07IfMP1fMWH0QhN70080QHF500D0Ph>3
07EeM@15ADD0ADE509>CT`0209bLW00309>CT`2ATI40TI6A0080WYjN0P2IVIT0102GUiL0Shn?08n?
S`2DU9@209jNWP0509fMW@15ADD0JVYZ06YZJP1]KFd00P21PH401@1kNg/0P82006IVIP1VIVH0M7Ad
0080MGEe00D0LG5a06][J`1[Jf/0O7al07IfMP0207MgM`0404];B`1QHF40HF5Q061PH080Hf=S00D0
Jf][075aL@1ZJVX0JVYZ07=cL`0207]kN`0508R8R02?Shl0UYJF09JFUP2JVYX00P1YJFT01@1oOgl0
QXJ608J6QP1fMWH0Ph>30080S8b<00@0R8R8096AT@2ATI40UYJF0P2;Rh/0101mOGd0JVYZ06IVIP1V
IVH304];B`0508n?S`2<S8`0S8b<08n?S`2:RXX00P2<S8`01029RHT0OGem07emO@1oOgl307YjNP04
07]kN`1NGUh0GUiN01LG5`80JVYZ00D0M7Ad06IVIP1>CTh0CTi>03`l?00203Hf=P0403hn?P0f=SH0
=SHf04a<C0<0G5aL00D0ATI602h^;P0^;Rh0A4A404e=C@0204m?C`040451@@17AdL0AdM705YJFP80
IVIV00<0I6AT0?ooo`3oool04`3oool30?n00100003o103oP02C0000o`<0oh003`3oool000T0oooo
00@0^;Rh0;>c/`2c/k<0];Bd0P2ZZZX01@2YZJT0[Zj^0:j^[P2YZJT0ZZZZ0080Xj>S00D0X:2P09nO
W`2OWil0BDU909nOW`020:2PX0040:6QX@2GUiL0UiNG08V9R@80O7al00D0OGem07QhN02ATI40TI6A
09ZJVP0209^KV`050:>SX`2GUiL0UiNG03dm?@2KVi/00P2IVIT0102BTY80Y:BT0:BTY02PX:020:FU
Y@0508b<S02@T900MWIf07IfMP27QhL00P25QHD01@23Ph<0MGEe04E5A@15ADD0Ti>C0080W9bL00<0
Ti>C096AT@2ATI400P2NWYh209VIV@0409NGU`2?Shl0Shn?09BDU080WYjN00D0WIfM04E5A@1ZJVX0
JVYZ06e]K@020861P@0507]kN`20P800IVIV06IVIP1dM7@00P1eMGD01@1aLG40Jf][06][J`1lO7`0
MWIf0080MgMg00@0Bd];065QH@1QHF40H61P0P1SHf<01@1[Jf/0LG5a06YZJP1ZJVX0Lg=c0080Ng]k
00D0R8R808n?S`2FUYH0UYJF09ZJVP0206UYJ@0507moO`26QXH0QXJ607IfMP23Ph<00P2<S8`01028
R8P0TI6A096AT@2FUYH208^;R`0407emO@1ZJVX0IVIV06IVIP<0Bd];00D0Shn?08b<S02<S8`0Shn?
08Z:RP0208b<S00408V9R@1mOGd0OGem07moO`<0NWYj00@0Ng]k05iNGP1NGUh05aLG0P1ZJVX01@1d
M7@0IVIV04i>CP1>CTh0?3`l0080=SHf00@0?Shn03Hf=P0f=SH0C4a<0`1LG5`01@16ATH0;Rh^02h^
;P14A4@0CDe=0080Cdm?00@0@D5104M7A`17AdL0FUYJ0P1VIVH00`1TI6@0oooo0?ooo`0C0?oooel0
003o0P3oP0030000o`030?n000000?l0003o0080oh002`000?l<0?n000T0003o0P3oP0020000oal0
oh0000<0003o0?ooo`3oool03@3oool000T0oooo00@0HF5Q05MGE`1GEeL0HF5Q0P1<C4`01@15ADD0
>3Ph03Ph>00n?Sh0@4100080?Cdm00D0=3@d02TY:@0Y:BT05ADE055AD@02051@D00404m?C`13@d<0
@d=304M7A`80BDU900D0DE5A04U9B@0l?3`0?3`l04A4A00204M7A`0504E5A@0o?cl0?clo01XJ6P10
@4000P19BDT0100o?cl0>SXj03Xj>P0c<c<303Hf=P0402XZ:P0O7al07alO01LG5`8061PH00D05QHF
00l?3`0B4Q804Q8B02XZ:P0203<c<`0503De=@0d=3@0=3@d03Xj>P0d=3@00P0`<300100/;2`07AdM
01dM7@0_;bl2034a<@0501`L700Z:RX092@T02@T900M7Ad00P0N7Qh01@0Q8B406a/K01/K6`0K6a/0
8b<S0080;bl_00D0:BTY028R8P0R8R80;Rh^02/[:`0202`/;00302h^;P0d=3@0=3@d00<0<S8b00D0
:b/[02PX:00T92@092@T02TY:@0205ADE00505QHF01BDU80?Shn03hn?P0^;Rh00P0i>CT01@0l?3`0
>c/k03/k>`0l?3`0>SXj0080=3@d00@0<c<c01TI6@0I6AT0<30`0P19BDT01@1@D500EeMG04i>CP1>
CTh0F5QH00D0GEeM00D0GUiN04i>CP1?Cdl0Cdm?02h^;P0202XZ:P80@4100P19BDT01018B4P0CDe=
04e=C@1CDe<2059BDP0504];B`1?Cdl0B4Q804Q8B01>CTh00P0^;Rh01@1VIVH0L71`071`L02:RXX0
V9RH0080UYJF00D0XZ:R09ZJVP2JVYX0Ti>C08^;R`0209NGU`0409JFUP25QHD0QHF50451@@80QHF5
00<0T92@0?ooo`3oool04`3ooomO0000o`80oh000`000?l00`3oP000003o0000o`020?n000/0003o
303oP0090000o`80oh000P000?lO0?n000030000o`3oool0oooo00d0oooo00090?ooo`0408F5Q@1k
Ng/0Ng]k08J6QP80?Cdm00D0EUIF09VIV@2IVIT0S8b<08n?S`0207emO@0508B4Q027QhL0QhN709JF
UP2XZ:P00P2SXj<0102NWYh0ZJVY0:VYZ@2YZJT203@d=00403`l?01oOgl0O7al07alO0@0Ph>30P25
QHD01@26QXH0SXj>08J6QP26QXH0Shn?0080UiNG00D0U9BD05=CD`1CDe<0De=C06MWI`0209^KV`05
0:6QX@2TY:@0Y:BT0:RXZ02LW9`00P2UYJD0102XZ:P0ZJVY0:VYZ@2TY:@208j>SP050:ZZZP0l?3`0
Jf][06][J`2JVYX00P23Ph<01@1kNg/0QhN708N7Q`2?Shl0TI6A0080PX:200D0OWin07IfMP1fMWH0
PX:208>3P`0207]kN`0401HF5P1nOWh0OWin0:>SX`80W9bL00D0YjNW09>CT`2PX:00X:2P0::RXP02
0:NWY`0508N7Q`2@T900T92@09:BTP2[Zj/00P1oOgl01@1KFe/0YjNW0:NWY`26QXH0Xj>S0080[Jf]
00@0/[:b0:j^[P2^[Zh0YjNW0P2UYJD01@2LW9`0UIFE09VIV@2IVIT0Vi^K0080@41000D0TI6A0;Jf
]P2f][H0];Bd0;6a/@020:b/[0040:n_[`2e]KD0]KFe0;bl_080_[jn00D0aLG50<;2`P35aLD0aLG5
07=cL`0209NGU`050;Vi^@2e]KD0^;Rh0;Rh^02j^[X00P2k^k/00`2m_Kd0`/;20<;2`P020<71`@80
_;bl00@0];Bd05ADE01DE5@0UYJF0P2b/[801@2c/k<0/K6a0:RXZ02XZ:P0YZJV0080Zj^[00D0[:b/
0:^[Z`2[Zj/0Zj^[0:j^[P020:>SX`0405MGE`2LW9`0W9bL0:BTY1D0oooo503oP0040000of80oh00
2@000?lW0?n000<0003o3`3oool000T0oooo00@0QHF507]kN`1kNg/0QXJ60P0m?Cd01@1FEUH0VIVI
09VIV@2<S8`0Shn?0080OGem00D0Q8B408N7Q`27QhL0UYJF0:RXZ0020:>SX`0409jNWP2YZJT0ZJVY
0:VYZ@80=3@d00@0?3`l07moO`1lO7`0O7al1023Ph<208F5Q@0508J6QP2>SXh0QXJ608J6QP2?Shl0
0P2GUiL01@2DU9@0De=C05=CD`1CDe<0IfMW0080Vi^K00D0XJ6Q0:BTY02TY:@0Z:RX09bLW0020:FU
Y@040:RXZ02YZJT0ZJVY0:BTY080SXj>00D0ZZZZ03`l?01[Jf/0Jf][09ZJVP0208>3P`0507]kN`27
QhL0QhN708n?S`2ATI400P22PX801@1nOWh0MWIf07IfMP22PX80Ph>30080Ng]k00@05QHF07inOP1n
OWh0Xj>S0P2LW9`01@2WYjL0Ti>C0:2PX02PX:00XZ:R0080YjNW00D0QhN7092@T02@T900TY:B0:^[
Z`0207moO`0505]KF`2WYjL0YjNW08J6QP2SXj<00P2][Jd0102b/[80[Zj^0:j^[P2WYjL20:FUY@05
09bLW02EUID0VIVI09VIV@2KVi/00P10@4001@2ATI40][Jf0;Jf]P2d];@0/K6a0080[:b/00@0[jn_
0;Fe]@2e]KD0_;bl0P2n_[h01@35aLD0`/;20<G5a@35aLD0Lg=c0080UiNG00D0^KVi0;Fe]@2h^;P0
^;Rh0;Zj^P020;^k^`030;fm_@32`/80`/;20080`L710P2l_;`0102d];@0E5AD05ADE02FUYH20;:b
/P050;>c/`2a/K40Z:RX0:RXZ02VYZH00P2[Zj/01@2/[:`0Zj^[0:^[Z`2[Zj/0[Zj^0080Xj>S00@0
EeMG09bLW02LW9`0Y:BT5@3ooon60?n000D0003o103oP0060000o`T0oh001P000?l60?n00080003o
00<0oh000?ooo`3oool03@3oool000T0oooo00@0Zj^[0;:b/P2b/[80/;2`0P1:BTX01@1[Jf/0WinO
09nOW`2KVi/0T92@00<0QHF50P2:RXX0102GUiL0XZ:R09jNWP2NWYh30:RXZ0050;2`/01OGel0GemO
05]KF`2GUiL00P21PH401022PX80Ogmo07moO`1kNg/207MgM`0507=cL`1nOWh0PH610861P@1iNGT0
0P26QXH01@2HV9P0DE5A055AD@1RHV80I6AT0080TI6A00D0YjNW0:JVYP2VYZH0XJ6Q08>3P`0209ZJ
VP0409fMW@2TY:@0Y:BT0:BTY080SXj>00D0[:b/04=3@`1aLG40LG5a08j>SP0207]kN`0407UiN@1j
NWX0NWYj07emO@<0OWin00D0O7al07inOP1nOWh0OWin08F5Q@0207moO`04020P802;Rh/0Rh^;0:2P
X080XJ6Q00D0Xj>S09NGU`2MWId0WIfM0:JVYP020:BTY00507UiN@1jNWX0NWYj08J6QP2/[:`00P2G
UiL01@1NGUh0UYJF09JFUP2FUYH0WIfM0080WYjN00@0XZ:R0:>SX`2SXj<0VYZJ0P2OWil01@2KVi/0
TI6A09ZJVP2JVYX0Ti>C0080?clo00<0/[:b0;fm_@2m_Kd0102h^;P00`2l_;`0_[jn0;jn_P030<71
`@050;^k^`30`<00_[jn0;jn_P1YJFT00P26QXH01@2ZZZX0[jn_0:JVYP2VYZH0XJ6Q0080V9RH00@0
XZ:R0:RXZ02XZ:P0]kNg0`2^[Zh0102XZ:P0EeMG05MGE`2SXj<20:JVYP030:>SX`2UYJD0Y:BT00@0
Y:BT00D0XZ:R0:FUY@2WYjL0YjNW0:^[Z`0209RHV00404m?C`2;Rh/0Rh^;09fMWAD0oooo1@000?l7
0?n00080003o0P3oP0030000o`P0oh0000<0003o0?n0003oP0006@3oP0020000o`P0oh000`000?m=
0?n000030000o`3oP000oh0000d0oh0010000?l50?n000<0003o3`3oool000T0oooo00@0ZZZZ0:b/
[02/[:`0ZZZZ0P16ATH01@1TI6@0V9RH09RHV02LW9`0UYJF0080Rh^;00D0R8R808^;R`2;Rh/0QhN7
08n?S`0208f=S@0409RHV02OWil0WinO0:NWY`80F5QH00<0AdM707emO@2:RXX00P2:RXX208B4Q004
07YjNP1hN7P0N7Qh07EeM@<0QXJ60`1hN7P01@2;Rh/0F5QH05QHF01RHV80FUYJ0080Ph>300D0YJFU
09nOW`2OWil0Vi^K07MgM`0209JFUP0409^KV`2NWYh0WYjN09nOW`80O7al00D0XJ6Q03hn?P1TI6@0
I6AT07inOP0307AdM0<0Kfm_00@0MGEe07QhN01hN7P0N7Qh0P1mOGd01@1hN7P0NGUi07IfMP1fMWH0
;Rh^0080S8b<00D0RXZ:09NGU`2GUiL0TI6A09JFUP0209jNWP040:BTY02VYZH0YZJV08N7Q`80Ph>3
00D0Rh^;0:BTY02?Shl0Shn?04a<C00209^KV`0509VIV@2OWil0XZ:R0::RXP2OWil00P2SXj<309nO
W`0508j>SP2CTi<0TY:B09:BTP2CTi<00P0n?Sh00`2`/;00_[jn0;jn_P040;fm_@040;Vi^@2j^[X0
^[Zj0;Vi^@80]kNg00D0/k>c0;6a/@2/[:`0[:b/05ADE00207UiN@0509ZJVP2ATI40MWIf07IfMP1e
MGD00P29RHT01@2GUiL0I6AT06ATI02WYjL0TY:B0080U9BD00@0Shn?05IFEP1FEUH0U9BD0P2QXJ40
102OWil0W9bL09VIV@2IVIT409RHV0<0XZ:R00@0Y:BT08B4Q024Q8@0=SHf0P2;Rh/00`2IVIT0oooo
0?ooo`0C0?ooo`D0003o1`3oP0020000o`80oh000`000?l80?n000030000o`3oP000oh0001T0oh00
0P000?l80?n000<0003oC@3oP0000`000?l0oh000?n0000=0?n000@0003o1@3oP0030000o`l0oooo
00090?ooo`040:j^[P2][Jd0[Jf]0:>SX`80@D5100<0EeMG09^KV`2KVi/00P2OWil209ZJVP0509VI
V@2RXZ80XZ:R09nOW`2EUID00P1lO7`0102<S8`0UIFE09FEU@2UYJD204i>CP0502h^;P1aLG40MgMg
07MgM`24Q8@00P22PX80101mOGd0RXZ:08Z:RP2=SHd308^;R`<0QXJ600D0Shn?05YJFP1JFUX0CDe=
06ATI00208b<S00509JFUP2>SXh0SXj>09:BTP1[Jf/00P1eMGD01022PX80TI6A096AT@2;Rh/206YZ
JP0506UYJ@0/;2`0@d=304=3@`1kNg/00P1jNWX01@1hN7P0KFe]06e]K@1aLG40Ng]k0080P82000D0
PH6107QhN01hN7P0KFe]06MWI`02069RHP0403hn?P26QXH0QXJ608^;R`@0QXJ60P2BTY80102JVYX0
YjNW0:NWY`2KVi/209BDU00508V9R@2;Rh/0De=C05=CD`0G5aL00P25QHD01@2?Shl0QHF508>3P`23
Ph<0Rh^;0080S8b<00D0QhN708B4Q024Q8@0Ph>308f=S@0207moO`0407UiN@0h>3P0>3Ph08N7Q`80
W9bL00D0TY:B08n?S`2CTi<0Ti>C08N7Q`0208:2PP05096AT@2?Shl0Shn?08j>SP2<S8`00P1iNGT0
1@10@400KFe]06e]K@1HF5P0BDU90080>c/k00@0ADE504U9B@19BDT0@D510P15ADD01@18B4P0=SHf
03lo?`0o?cl0=cLg0080<C4a00D0ATI604a<C01<C4`0EEEE04];B`0204e=C@0504Q8B01;Bd/0Bd];
04i>CP19BDT00P11@D40100j>SX08R8R028R8P0C4a<202<S8`0303Lg=`3oool0oooo01<0oooo403o
P0060000o`030?n000000?l0003o00D0003o00<0oh000000o`000?l040000?l40?n000050000o`3o
P000003o0000o`3oP000;`000?l30?n00440003o3`3oool000T0oooo00@0[Zj^0:f][@2][Jd0Xj>S
0P11@D400`1GEeL0Vi^K09^KV`0209nOW`80VYZJ00D0VIVI0::RXP2RXZ80WinO09FEU@0207alO004
08b<S02EUID0UIFE0:FUY@80CTi>00D0;Rh^075aL@1gMgL0MgMg08B4Q00208:2PP0407emO@2:RXX0
RXZ:08f=S@<0Rh^;0`26QXH01@2?Shl0FUYJ05YJFP1=CDd0I6AT0080S8b<00D0UYJF08j>SP2>SXh0
TY:B06][J`0207EeM@0408:2PP2ATI40TI6A08^;R`80JVYZ00D0JFUY02`/;013@d<0@d=307]kN`02
07YjNP0507QhN01]KFd0KFe]075aL@1kNg/00P20P8001@21PH40N7Qh07QhN01]KFd0IfMW0080HV9R
00@0?Shn08J6QP26QXH0Rh^;1026QXH209:BTP0409ZJVP2WYjL0YjNW09^KV`80U9BD00D0RHV908^;
R`1CDe<0De=C01LG5`0208F5Q@0508n?S`25QHD0Ph>308>3P`2;Rh/00P2<S8`01@27QhL0Q8B408B4
Q023Ph<0SHf=0080Ogmo00@0NGUi03Ph>00h>3P0QhN70P2LW9`01@2BTY80Shn?09>CT`2CTi<0QhN7
0080PX:200D0TI6A08n?S`2?Shl0SXj>08b<S00207UiN@050410@01]KFd0KFe]05QHF019BDT00P0k
>c/01015ADD0BDU904U9B@11@D4204E5A@0504Q8B00f=SH0?clo03lo?`0g=cL00P0a<C401@16ATH0
C4a<04a<C01EEED0Bd];0080CDe=00D0B4Q804];B`1;Bd/0CTi>04U9B@020451@@0403Xj>P0R8R80
8R8R01<C4`808b<S00<0=cLg0?ooo`3oool04`3ooolD0000o`@0oh007P000?l00`3oP000003o0000
o`050?n002X0003o2P3oP0060000oc80oh000`000?l?0?ooo`002@3oool0101VIVH0K6a/06a/K01Q
HF4203<c<`05038b<P1PH600H61P06IVIP1QHF400P1KFe/305aLG00505YJFP1PH600Fe]K05]KF`1T
I6@00P1JFUX0101RHV80=CDe03De=@0a<C4304=3@`0403/k>`14A4@0A4A403Lg=`80=CDe00D0;2`/
03Lg=`0`<300<30`03Lg=`0202d];@0502/[:`0S8b<08b<S028R8P0X:2P00P0_;bl01@0a<C408R8R
028R8P0E5AD05QHF00804Q8B00@05ADE02h^;P0^;Rh09bLW0P0N7Qh0100G5aL04A4A01DE5@0E5AD3
02/[:`05034a<@19BDT0BDU903hn?P13@d<00P16ATH01@18B4P0<S8b038b<P0b<S80@d=30080>c/k
00@04Q8B01/K6`0K6a/08b<S0P0`<3001@0o?cl0?3`l02`/;00/;2`0<S8b0080@41000D0>c/k038b
<P0b<S80;2`/01TI6@0201hN7P0502l_;`0g=cL0=cLg02XZ:P0D51@00P0U9BD0100e=CD0>c/k03/k
>`11@D420492@P0501HF5P0Q8B40<S8b038b<P0a<C400P0];Bd01@0c<c<0=cLg03Lg=`0K6a/0;bl_
0080BDU9101>CTh203Hf=P0504];B`1@D500IFEU06EUI@1kNg/00P2:RXX01@1VIVH0DE5A075aL@1a
LG40L71`0080Kfm_00D0Jf][06ATI01TI6@08b<S06i^KP0207AdM00406YZJP1XJ6P0J6QX06=SH`80
:BTY00D0:b/[061PH01YJFT0JFUY07IfMP0207inOP0307IfMP0L71`0Lg=c0080Lg=c0P1jNWX0102?
Shl0QhN708N7Q`1:BTXE0?ooo`@0003o00<0oh000000o`000?l010000?l00`3oP000003o0000o`0O
0000o`X0oh000`000?l60?n000D0003o3`3oP0000`000?l0oh000?n000020000o`<0oh000`000?l8
0?n000@0003o1`3oP0000`000?l0oh000?n0000h0?n000l0oooo00090?ooo`0407IfMP1@D500D51@
07alO080NWYj00D0MWIf07inOP1nOWh0PX:203De=@0203Hf=P0507=cL`1kNg/0Ng]k07YjNP2<S8`0
0P2;Rh/0100X:2P0DE5A055AD@2LW9`209^KV`050:RXZ02/[:`0U9BD09BDU00n?Sh00P1_Kfl01@2I
VIT0W9bL09bLW02LW9`0TI6A0080MgMg00@0:2PX09FEU@2EUID0ZZZZ0P2][Jd01@2XZ:P0[Zj^05aL
G01LG5`0:b/[0080SHf=00<0U9BD08n?S`2:RXX00P2:RXX204I6AP05028R8P13@d<0@d=305YJFP1M
GEd00P1cLg<01023Ph<0?Cdm03dm?@0e=CD206YZJP0506EUI@1aLG40L71`071`L01_Kfl00P0`<300
1@0^;Rh0JVYZ07UiN@1iNGT0MgMg0080Kfm_00D0I6AT02l_;`0_;bl0KFe]08:2PP0207EeM@040861
P@2DU9@0U9BD05QHF08030`<00D0NWYj09FEU@2BTY80TY:B08b<S00209jNWP0507EeM@0e=CD0ZZZZ
0:ZZZP2_[jl00P2][Jd01@2TY:@0WYjN09jNWP0W9bL0MWIf0080[Jf]00@0[jn_0;>c/`2c/k<0_Kfm
0P2f][H01@0^;Rh0YJFU0;^k^`2k^k/0^KVi0080^k^k00D0]kNg05IFEP1FEUH0WIfM0;Rh^0020;Vi
^@050;Jf]P2b/[80/[:b08B4Q01aLG400P2YZJT0102e]KD0][Jf0;Jf]P2d];@20:RXZ00503De=@2Y
ZJT0[jn_0:n_[`2XZ:P00`2WYjL20451@@0306a/K02YZJT0/K6a0080/K6a0P2d];@01@2QXJ407alO
0820P020P800MgMg0080HF5Q00@0Jf][06a/K01/K6`0@4105@3oool40000o`030?n000000?l0003o
00@0003o00<0oh000000o`000?l07`000?l:0?n000<0003o1P3oP0050000o`l0oh0000<0003o0?n0
003oP0000P000?l30?n000<0003o203oP0040000o`L0oh0000<0003o0?n0003oP000>03oP00?0?oo
o`002@3oool0101fMWH0D51@051@D01lO7`207YjNP0507IfMP1nOWh0OWin08:2PP0e=CD00P0f=SH0
1@1cLg<0Ng]k07]kN`1jNWX0S8b<0080Rh^;00@0:2PX055AD@1ADE40W9bL0P2KVi/01@2XZ:P0[:b/
09BDU02DU9@0?Shn0080Kfm_00D0VIVI09bLW02LW9`0W9bL096AT@0207MgM`0402PX:02EUID0UIFE
0:ZZZP80[Jf]00D0Z:RX0:j^[P1LG5`0G5aL02/[:`0208f=S@0309BDU02?Shl0RXZ:0080RXZ:0P16
ATH01@0R8R80@d=304=3@`1JFUX0GEeM0080Lg=c00@0Ph>303dm?@0m?Cd0=CDe0P1ZJVX01@1UIFD0
LG5a071`L01`L700Kfm_0080<30`00D0;Rh^06YZJP1iNGT0NGUi07MgM`0206m_K`0506ATI00_;bl0
;bl_06e]K@22PX800P1eMGD01021PH40U9BD09BDU01HF5P200`<300507YjNP2EUID0TY:B09:BTP2<
S8`00P2NWYh01@1eMGD0=CDe0:ZZZP2ZZZX0[jn_0080[Jf]00D0Y:BT09jNWP2NWYh09bLW07IfMP02
0:f][@040:n_[`2c/k<0/k>c0;fm_@80][Jf00D0;Rh^0:FUY@2k^k/0^k^k0;Vi^@020;^k^`050;Ng
]`1FEUH0EUIF09fMW@2h^;P00P2i^KT01@2f][H0/[:b0;:b/P24Q8@0LG5a0080ZJVY00@0]KFe0;Jf
]P2f][H0];Bd0P2XZ:P01@0e=CD0ZJVY0:n_[`2_[jl0Z:RX00<0YjNW0P11@D400`1/K6`0ZJVY0;6a
/@020;6a/@80];Bd00D0XJ6Q01lO7`20P800P82007MgM`02065QH@0406][J`1/K6`0K6a/0410@1D0
oooo0`000?l20?n00240003o0`3oP0020000o`X0oh0010000?l80?n000@0003o3`3oP0000`000?l0
oh000?n000060000o``0oh000P000?l50?n000<0003o3`3oP0020000obP0oh0000<0003o0?ooo`3o
ool03@3oool000T0oooo00@0Ti>C05ADE01DE5@0Zj^[0P2`/;001@2[Zj/0/;2`0;2`/02a/K40GEeM
0080L71`00D0]KFe0;Ng]`2g]kL0^;Rh0;bl_0020;fm_@0403Hf=P1RHV80HV9R0:j^[P80/k>c00D0
^KVi0;Ng]`2g]kL0]kNg04M7A`0208>3P`050;Fe]@2c/k<0/k>c0:n_[`2`/;000P23Ph<0100P8200
VIVI09VIV@2QXJ420:NWY`050:JVYP2XZ:P0IFEU06EUI@12@T800P2TY:@01@2[Zj/0ZJVY0:j^[P2^
[Zh0[:b/0080FEUI00D0=SHf05YJFP1JFUX0IfMW06][J`0206i^KP0406a/K00e=CD0=CDe03De=@<0
MGEe00@0MgMg06UYJ@1YJFT0Hf=S0P0X:2P01@0^;Rh0GUiN06YZJP1ZJVX0KVi^0080J6QX00D0IFEU
028R8P0R8R80IVIV07YjNP02079bLP04075aL@2<S8`0S8b<05aLG0803@d=00D0NWYj09bLW02LW9`0
W9bL09ZJVP0209BDU005069RHP1FEUH0[jn_0:n_[`2a/K400P2TY:@01@2EUID0SHf=08f=S@0V9RH0
MGEe0080ZJVY00@0Z:RX0;>c/`2c/k<0^k^k0P2a/K401@0];Bd0/;2`0;bl_02l_;`0^KVi0080^k^k
00D0^KVi05ADE01DE5@0VIVI0;Ng]`020;Zj^P050;^k^`2i^KT0^KVi08F5Q@1aLG400P2`/;00102a
/K40[:b/0:b/[02XZ:P20::RXP0503`l?02XZ:P0[jn_0:n_[`2ZZZX00`2TY:@20492@P0308>3P`2d
];@0/;2`0080/;2`0P2c/k<01@2LW9`08R8R08N7Q`27QhL0NWYj0080IfMW00@0O7al08J6QP26QXH0
CDe=d@3oool000T0oooo00@0U9BD05IFEP1FEUH0Y:BT0P2[Zj/01@2ZZZX0Y:BT0:BTY02OWil0Cdm?
0080NGUi00@0^KVi0;bl_02l_;`0^KVi0`2j^[X0101;Bd/0J6QX06QXJ02TY:@20;Bd]0050;Rh^02i
^KT0]kNg0;Ng]`0o?cl00P26QXH01@2_[jl0/;2`0;2`/02/[:`0[jn_0080V9RH00<0=cLg0:^[Z`2[
Zj/00`2a/K401@2`/;00Zj^[065QH@1QHF40=SHf0080VIVI00D0ZZZZ0:f][@2_[jl0[jn_0:j^[P02
05EEE@05034a<@1IFET0FEUI05iNGP1KFe/00P1;Bd/0101WIfL0?clo03lo?`16ATH208b<S00508N7
Q`20P800LW9b079bLP1WIfL00P0X:2P01@0_;bl0EeMG05QHF01HF5P0HF5Q0080Hf=S00D0HF5Q02DU
9@0U9BD0M7Ad08^;R`0208B4Q00407inOP2BTY80TY:B05mOG`803@d=00D0Ti>C0;Fe]@2^[Zh0[Zj^
0:BTY0020:6QX@0506MWI`1SHf<0/K6a0;6a/@2b/[800`2a/K420:f][@0503<c<`1oOgl0ZJVY0:VY
Z@2_[jl00P2d];@0102j^[X0]KFe0;Fe]@0d=3@30;Ng]`<0_kno00D0^[Zj05ADE01DE5@0Vi^K0;fm
_@020;Zj^P050;Jf]P2e]KD0]KFe08V9R@1cLg<00P2PX:00102MWId0W9bL09bLW02BTY8207moO`05
03Hf=P2VYZH0[:b/0:b/[02[Zj/00P2XZ:P0102SXj<0?clo03lo?`20P8030:j^[P050;2`/02/[:`0
[:b/0:JVYP0g=cL00P2[Zj/0102;Rh/0QhN708N7Q`2ATI4208N7Q`0304Y:BP3oool0oooo0<l0oooo
00090?ooo`0409BDU01FEUH0EUIF0:BTY080Zj^[00D0ZZZZ0:BTY02TY:@0WinO04m?C`0207UiN@04
0;Vi^@2l_;`0_;bl0;Vi^@<0^[Zj00@0Bd];06QXJ01XJ6P0Y:BT0P2d];@01@2h^;P0^KVi0;Ng]`2g
]kL0?clo0080QXJ600D0[jn_0;2`/02`/;00[:b/0:n_[`0209RHV00303Lg=`2[Zj/0Zj^[00<0/K6a
00D0/;2`0:^[Z`1QHF40HF5Q03Hf=P0209VIV@050:ZZZP2][Jd0[jn_0:n_[`2^[Zh00P1EEED01@0a
<C40FEUI05UIF@1NGUh0Fe]K0080Bd];00@0IfMW03lo?`0o?cl0ATI60P2<S8`01@27QhL0P820079b
LP1bLW80IfMW0080:2PX00D0;bl_05MGE`1HF5P0F5QH065QH@0206=SH`05065QH@0U9BD09BDU07Ad
M02;Rh/00P24Q8@0101nOWh0TY:B09:BTP1OGel200d=3@0509>CT`2e]KD0[Zj^0:j^[P2TY:@00P2Q
XJ401@1WIfL0Hf=S0;6a/@2a/K40/[:b00<0/K6a0P2][Jd01@0c<c<0Ogmo0:VYZ@2YZJT0[jn_0080
];Bd00@0^[Zj0;Fe]@2e]KD0=3@d0`2g]kL30;no_`050;Zj^P1DE5@0E5AD09^KV`2m_Kd00P2j^[X0
1@2f][H0]KFe0;Fe]@29RHT0Lg=c0080X:2P00@0WIfM09bLW02LW9`0TY:B0P1oOgl01@0f=SH0YZJV
0:b/[02/[:`0Zj^[0080Z:RX00@0Xj>S03lo?`0o?cl0P8200`2^[Zh01@2`/;00[:b/0:b/[02VYZH0
=cLg0080Zj^[00@0Rh^;08N7Q`27QhL0TI6A0P27QhL00`1:BTX0oooo0?ooo`3?0?ooo`002@3oool0
102DU9@0FUYJ05YJFP2TY:@20:^[Z`<0YjNW00D0XZ:R059BDP1gMgL0MgMg0:n_[`030;2`/0040;:b
/P2h^;P0^;Rh05=CD`80I6AT00D0PH6108b<S02<S8`0WinO0:2PX00209ZJVP04034a<@28R8P0R8R8
0:f][@80ZZZZ00D0YZJV0:^[Z`26QXH0QXJ603/k>`020:FUY@050:NWY`2][Jd0[Jf]0:f][@2KVi/0
0P1JFUX00`1HF5P0Xj>S0:>SX`020:^[Z`<0/;2`0P1NGUh01@1`L700IFEU06EUI@1cLg<0E5AD0080
H61P00@0Lg=c05UIF@1IFET0Kfm_0P2TY:@01@2IVIT0QhN707emO@1mOGd0Kfm_0080;2`/00<0;Rh^
04=3@`1:BTX00P1:BTX203hn?P050451@@0L71`071`L08^;R`2IVIT00P2@T900102=SHd0UIFE09FE
U@1EEED201`L700509JFUP2ZZZX0Zj^[0:^[Z`2SXj<00P2GUiL0101_Kfl0De=C09nOW`2OWil30:VY
Z@050:FUY@2SXj<0Xj>S03Ph>01XJ6P00P1dM7@0101cLg<0Z:RX0:RXZ02c/k<20;:b/P0503Hf=P25
QHD0PX:208:2PP28R8P00P21PH401@1eMGD0<S8b038b<P1fMWH0Ph>300<0Ogmo0P1]KFd01@11@D40
DE5A06e]K@1]KFd0JFUY0080IVIV00D0G5aL05IFEP1FEUH0:2PX05YJFP03069RHP80Fe]K00D0ATI6
02<S8`0S8b<0@d=3055AD@02059BDP0504U9B@13@d<0@d=3038b<P0N7Qh00P0o?cl0100b<S80=CDe
03De=@0a<C42030`<00301/K6`3oool0oooo0<l0oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-6.66875, \
-5.69068, 0.701906, 0.701906}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-158.076, -10.2805, 0.742805, 0.742805}, {{9.5, 190.438}, {190.438, 9.5}} -> \
{-6.66875, -145.392, 0.701906, 0.701906}, {{208.5, 389.438}, {190.438, 9.5}} -> \
{-158.076, -158.122, 0.742805, 0.742805}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute classification error", "Subsection"],

Cell[BoxData[{
    \(\(brickStats\  = \ 
        First\  /@ \ 
          Frequencies[
            Partition[Flatten[c1[\([1, 1]\)]], 
              3]];\)\), "\[IndentingNewLine]", 
    \(\(woodStats\  = \ 
        First\  /@ \ \ Frequencies[
            Partition[Flatten[c2[\([1, 1]\)]], 
              3]];\)\), "\[IndentingNewLine]", 
    \(\(bar2\  = \ {brickStats/\((Plus\  @@ \ brickStats)\), 
            woodStats/\((Plus\  @@ \ woodStats)\)}\  // \ 
          Transpose;\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show classification error", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BarChart[bar2[\([1]\)], \ bar2[\([2]\)], \ 
        BarStyle \[Rule] {Blue, Orange}, \ \[IndentingNewLine]Frame \[Rule] 
          True, BarLabels \[Rule] {"\<Brick\>", "\<Wood\>"}, \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.635038 [
[.27273 -0.0125 -17 -12 ]
[.27273 -0.0125 17 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14172 -18 -4.5 ]
[-0.0125 .14172 0 4.5 ]
[-0.0125 .26873 -18 -4.5 ]
[-0.0125 .26873 0 4.5 ]
[-0.0125 .39574 -18 -4.5 ]
[-0.0125 .39574 0 4.5 ]
[-0.0125 .52275 -18 -4.5 ]
[-0.0125 .52275 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -17 0 ]
[.27273 .63053 17 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -78 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Brick) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wood) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .14172 m
.00625 .14172 L
s
[(0.2)] -0.0125 .14172 1 0 Mshowa
0 .26873 m
.00625 .26873 L
s
[(0.4)] -0.0125 .26873 1 0 Mshowa
0 .39574 m
.00625 .39574 L
s
[(0.6)] -0.0125 .39574 1 0 Mshowa
0 .52275 m
.00625 .52275 L
s
[(0.8)] -0.0125 .52275 1 0 Mshowa
.125 Mabswid
0 .04647 m
.00375 .04647 L
s
0 .07822 m
.00375 .07822 L
s
0 .10997 m
.00375 .10997 L
s
0 .17347 m
.00375 .17347 L
s
0 .20523 m
.00375 .20523 L
s
0 .23698 m
.00375 .23698 L
s
0 .30048 m
.00375 .30048 L
s
0 .33223 m
.00375 .33223 L
s
0 .36399 m
.00375 .36399 L
s
0 .42749 m
.00375 .42749 L
s
0 .45924 m
.00375 .45924 L
s
0 .49099 m
.00375 .49099 L
s
0 .5545 m
.00375 .5545 L
s
0 .58625 m
.00375 .58625 L
s
0 .618 m
.00375 .618 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Brick) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Wood) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14172 m
1 .14172 L
s
.99375 .26873 m
1 .26873 L
s
.99375 .39574 m
1 .39574 L
s
.99375 .52275 m
1 .52275 L
s
.125 Mabswid
.99625 .04647 m
1 .04647 L
s
.99625 .07822 m
1 .07822 L
s
.99625 .10997 m
1 .10997 L
s
.99625 .17347 m
1 .17347 L
s
.99625 .20523 m
1 .20523 L
s
.99625 .23698 m
1 .23698 L
s
.99625 .30048 m
1 .30048 L
s
.99625 .33223 m
1 .33223 L
s
.99625 .36399 m
1 .36399 L
s
.99625 .42749 m
1 .42749 L
s
.99625 .45924 m
1 .45924 L
s
.99625 .49099 m
1 .49099 L
s
.99625 .5545 m
1 .5545 L
s
.99625 .58625 m
1 .58625 L
s
.99625 .618 m
1 .618 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.09091 .01472 m
.09091 .25665 L
.27273 .25665 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .25665 L
.27273 .25665 L
.27273 .01472 L
.09091 .01472 L
s
0 0 1 r
.54545 .01472 m
.54545 .60332 L
.72727 .60332 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .60332 L
.72727 .60332 L
.72727 .01472 L
.54545 .01472 L
s
1 .5 0 r
.27273 .01472 m
.27273 .40782 L
.45455 .40782 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .40782 L
.45455 .40782 L
.45455 .01472 L
.27273 .01472 L
s
1 .5 0 r
.72727 .01472 m
.72727 .06115 L
.90909 .06115 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .06115 L
.90909 .06115 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00M@3oool4o`000080oooo0ol0
00030?ooo`Go00000P3oool3o`000080oooo0_l000000`3ooooo0000o`0000240?ooo`03o`00003o
oooo000000<0oooo0ol000030?ooo`?o00000`3oool4o`0006@0oooo001f0?ooo`04o`00003oool0
ooooo`000080oooo00?o00000?ooo`3oool0103oool01Ol00000oooo0?ooo`3ooooo000000<0oooo
00Ko00000?ooo`3ooooo00000?ooool000250?ooo`03o`00003ooooo00000080oooo00Oo00000?oo
o`3oool0ooooo`00003ooooo000000<0oooo00?o00000?ooool000000P3oool00ol00000oooo0?oo
o`1S0?ooo`00MP3oool01?l00000oooo0?ooool000020?ooo`03o`00003oool0oooo00@0oooo00Go
00000?ooo`3oool0ooooo`0000060?ooo`;o0000QP3oool00ol00000ooooo`0000020?ooo`07o`00
003oool0oooo0?ooool00000ooooo`0000030?ooo`03o`00003ooooo00000080oooo00?o00000?oo
o`3oool0H`3oool007H0oooo0ol000030?ooo`;o00001@3oool01Ol00000oooo0?ooo`3ooooo0000
00<0oooo00Ko00000?ooo`3ooooo00000?ooool000240?ooo`07o`00003ooooo00000?ooool00000
ooooo`0000030?ooo`03o`00003ooooo000000<0oooo00?o00000?ooool000000P3oool00ol00000
oooo0?ooo`1S0?ooo`00MP3oool01Ol00000oooo0?ooool00000oooo00;o000000@0ooooo`000?l0
0000oooo0ol000040?ooo`?o00000`3oool01?l00000ooooo`000?l000230?ooo`05o`00003ooooo
00000?ooool000000P3oool3o`0000<0oooo0ol000030?ooo`?o0000I@3oool007H0oooo00Co0000
0?ooo`3ooooo0000503oool00ol00000oooo0?ooo`240?ooo`05o`00003ooooo00000?ooool00000
403oool00ol00000oooo0?ooo`1S0?ooo`00M@3oool4o`0000X0oooo00?o00000?ooo`3oool01`3o
ool2o`0008H0oooo1_l0000>0?ooo`;o0000I@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool002D0ooooo`00001L0000
0100oooo000U0?ooo`030000003oool0oooo05`0oooo00?o00000?ooo`3oool0VP3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000M0?ooo`;o00001P3oool00`000000oooo
0?ooo`1L0?ooo`03o`00003oool0oooo09X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0>0?ooo`00703oool01?l00000oooo0?ooool000050?ooo`030000003oool0oooo0?l0oooo
F03oool00`000000oooo0?ooo`0>0?ooo`00703oool01?l00000oooo0?ooool000050?ooo`030000
003oool0oooo0?l0ooooF03oool00`000000oooo0?ooo`0>0?ooo`00703oool01?l00000oooo0?oo
ool000050?ooool00000G000000@0?ooo`00703oool01?l00000oooo0?ooool000050?ooo`030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool001`0oooo00Co00000?ooo`3ooooo0000
1@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00
>oooO`000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo000M0?ooo`;o00001P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0
oooo01d0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0
oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0
oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0
oomo000koomo00030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool002D0oooo00<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M
0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M
0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00
ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00
ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<000000?oo
o`3oool03P3oool002D0oooo0`00000M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`000000oooo0?ooo`0L0?ooo`03o`0000000000oooo00l0oooo000U0?ooo`030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3o
ool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3o
ool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool002D0
oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00ocl000007`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o
00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?oo
o`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?oo
o`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000
oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?oo
o`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?oo
o`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?oo
o`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?oo
O`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool3000001d0oooo00<00000o`00ool00?l0
??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0
??l00?l00`000000oooo0?ooo`1J0?ooo`03o`0000000000oooo00l0oooo000U0?ooo`030000003o
ool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003o
ool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l0
0`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003o
ogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo
00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo
00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo
000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo
000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000
o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000
o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?oo
o`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo
00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool0
0?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool0
0?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo00h0oooo000U0?ooo`<000007@3oool00`00003o003oo`00o`0lo`00o`0300000?oo
O`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003o
ool0oooo05X0oooo00?o00000000003oool03`3oool002D0oooo00<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
02D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl0
03_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo
05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o
003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o
003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00
o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00
o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<00000
0?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<00000
0?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00
o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool00140oooo0_l000040?ooo`04
o`00003oool0oooo0?ooo`Go00001@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o
03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o
03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`00403oool01?l00000
oooo0?ooool000080?ooo`04o`00003oool0ooooo`0000D0oooo00<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
0100oooo00Co00000?ooo`3ooooo00002@3oool00ol00000oooo0?ooo`050?ooo`030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000X0oooo00?o00000?ooo`3oool0103oool3
000001d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1I0?ooo`<00000403oool0
0100oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3ooooo000000D0oooo00<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool03P3oool00100oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?oo
o`3ooooo000000D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000
003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool00140oooo0_l000090?ooo`?o00001P3o
ool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00
0000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo
0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo
0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M
0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M
0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>
0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo
0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool3000001d0oooo00<00000o`00ool0
0?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool0
0?l0??l00?l00`000000oooo0?ooo`1J0?ooo`03o`0000000000oooo00l0oooo000U0?ooo`030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000
003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l0
0?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l0
0?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0
oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00
003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0
oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0
oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0
oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0
oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<0
0000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<0
0000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U
0?ooo`030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000k
oomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00000o`00
ool00?l0??l00?l00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00
ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`03
0000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`00003oogl0oomo000koomo0003
0000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo00h0oooo000U0?ooo`<000007@3oool00`00003o003oo`00o`0lo`00o`030000
0?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000
003oool0oooo05X0oooo00?o00000000003oool03`3oool002D0oooo00<000000?ooo`3oool07@3o
ool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3o
ool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3o
ool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3o
ogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0
oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00
003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00
003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0
oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_o
ogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0
oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003o
o`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003o
o`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0l
o`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0l
o`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?oo
o`3oool07@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?oo
o`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?oo
o`3oool03P3oool002D0oooo00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
00000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0
7@3oool00`00003o003oo`00o`0lo`00o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool0
7@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
3P3oool002D0oooo0`00000M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>ooo
O`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0FP3o
ool00ol0000000000?ooo`0?0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo
003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`00
0000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`00
0000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co
003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo
0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000oomo0?ooO`00>oooO`000`000000oooo
0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<0
0000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`0M
0?oood000000?OooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?oo
o`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool00140oooo0_l000040?ooo`03
o`00003oool0oooo00<0oooo0ol000050?ooo`030000003oool0oooo05`0oooo00<00000oomo0?oo
O`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0>0?ooo`00403oool01?l00000oooo0?ooool0000:0?ooo`03
o`00003oool0oooo00@0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo0003
0000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000L0oooo1Ol000050?ooo`<0
0000G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool0
0?l0??l00?l00`000000oooo0?ooo`1I0?ooo`<00000403oool00100oooo00Co00000?ooo`3ooooo
00001`3oool01?l00000oooo0?ooool000060?ooo`030000003oool0oooo05`0oooo00<00000oomo
0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`00403oool01?l00000oooo0?ooool000080?oo
o`03o`00003ooooo000000H0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo
00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000T0oooo0_l000060?oo
o`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?oo
o`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?oo
o`004@3oool2o`0000/0oooo00?o00000?ooo`3oool0103oool00`000000oooo0?ooo`1L0?ooo`03
00000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0
G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0
??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003o
ool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l0
0?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool0
0`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
02D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo00030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000
oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool002D0oooo0`00001L0?ooo`0300000?ooO`3oogl003_oogl000<0
00000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05X0oooo00?o
00000000003oool03`3oool002D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000k
oomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo
0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`03
00000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0
G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0
??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003o
ool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l0
0?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool0
0`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
02D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo00030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000
oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo
000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`<00000G03oool00`00003oogl0oomo000k
oomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1J
0?ooo`03o`0000000000oooo00l0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo
0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`03
00000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0
G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0
??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003o
ool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l0
0?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool0
0`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
02D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo00030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000
oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo
000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000
oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool3000005`0oooo00<00000oomo
0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?oo
o`3oool0FP3oool00ol0000000000?ooo`0?0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`03
00000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0
G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0
??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003o
ool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l0
0?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool0
0`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl000<000000?ooo`3oool07@3oool0
0`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool0
02D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo00030000003oool0oooo
01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000
oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo
000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00h0oooo000A0?ooo`;o0000103oool00ol00000oooo0?ooo`02
0?ooo`?o00001P3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl000<00000
0?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool03P3oool00100oooo00Co00000?ooo`3ooooo00001`3oool01Ol00000oooo0?ooo`3o
oooo000000D0oooo00<000000?ooo`3oool0G03oool00`00003oogl0oomo000koomo00030000003o
ool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003o
ool0oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0oooo
o`0000050?ooo`<00000G03oool00`00003oogl0oomo000koomo00030000003oool0oooo01d0oooo
00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1I0?ooo`<00000403oool00100oooo00Co
00000?ooo`3ooooo00001`3oool4o`0000H0oooo00<000000?ooo`3oool0G03oool00`00003oogl0
oomo000koomo00030000003oool0oooo01d0oooo00<00000o`00ool00?l0??l00?l00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000L0oooo
00?o00000?ooo`3oool01`3oool00`000000oooo0?ooo`1L0?ooo`0300000?ooO`3oogl003_oogl0
00<000000?ooo`3oool07@3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo
00<000000?ooo`3oool03P3oool00100oooo00Co00000?ooo`3ooooo0000203oool00ol00000oooo
0?ooo`060?ooo`030000003oool0oooo05`0oooo00<00000oomo0?ooO`00>oooO`000`000000oooo
0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`0>0?ooo`004@3oool2o`0000X0oooo0_l000060?ooo`030000003oool0oooo05`0oooo00<0
0000oomo0?ooO`00>oooO`000`000000oooo0?ooo`0M0?ooo`0300000?l00?oo003o03co003o00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`1L
0?ooocl000007`3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3o
ool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000
003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3o
ool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3o
ool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0
oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo0`00002j0?ooo`0300000?l00?oo003o
03co003o00<000000?ooo`3oool0FP3oool00ol0000000000?ooo`0?0?ooo`009@3oool00`000000
oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o
00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?oo
o`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?oo
o`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?oo
o`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`030000
0?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3o
ool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo
003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`00
0000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0>0?ooo`009@3oool300000;X0oooo00<00000o`00ool00?l0??l00?l00`000000
oooo0?ooo`1J0?ooo`03o`0000000000oooo00l0oooo000U0?ooo`030000003oool0oooo0;X0oooo
00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo
000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000
o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?oo
o`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool0
0?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000
003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l0
0?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0
oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0
oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0
oooo000U0?ooo`<00000^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05X0oooo
00?o00000000003oool03`3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00
o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<00000
0?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<00000
0?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00
o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3o
ool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000
003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3o
ool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3o
ool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0
oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00
003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool00140
oooo0_l000040?ooo`03o`00003oool0oooo0080oooo0ol000060?ooo`030000003oool0oooo0;X0
oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0
oooo000@0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?ooo`3oool0ooooo`0000050?oo
o`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00h0oooo000@0?ooo`04o`00003oool0ooooo`0000L0oooo00Go00000?oo
o`3oool0ooooo`0000050?ooo`<00000^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0
oooo05T0oooo0`00000@0?ooo`00403oool01?l00000oooo0?ooool000080?ooo`?o00001P3oool0
0`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0>0?ooo`00403oool01?l00000oooo0?ooool000070?ooo`05o`00003oool0
oooo0?ooool000001@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`00403oool01?l00000oooo0?ooool0
00070?ooo`05o`00003oool0oooo0?ooool000001@3oool00`000000oooo0?ooo`2j0?ooo`030000
0?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`004@3o
ool2o`0000T0oooo0ol000060?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l0
0?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0
oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0
oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0
oooo000U0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo0;X0oooo00<0
0000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U
0?ooo`030000003oool0oooo0;X0oooo00<00000o`00ool00?l0??l00?l00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo00h0oooo000U0?ooo`<00000^P3oool00`00003o003oo`00o`0lo`00
o`030000003oool0oooo05X0oooo00?o00000000003oool03`3oool002D0oooo00<000000?ooo`3o
ool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000
003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3o
ool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3o
ool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0
oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00
003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0
oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0
oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003o
o`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<0
00000?ooo`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0^P3oool00`00003o003oo`00o`0l
o`00o`030000003oool0oooo05/0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?oo
o`3oool0^P3oool00`00003o003oo`00o`0lo`00o`030000003oool0oooo05/0oooo00<000000?oo
o`3oool03P3oool002D0oooo0`00002j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3o
ool0FP3oool00ol0000000000?ooo`0?0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`030000
0?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3o
ool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo
003o03co003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`00
0000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co003o00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?ooo`2j0?ooo`0300000?l00?oo003o03co
003o00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo
0?ooo`2j0?oood000000G@3oool00`000000oooo0?ooo`0>0?ooo`009@3oool00`000000oooo0?oo
o`3o0?oooeP0oooo00<000000?ooo`3oool03P3oool002D0oooo00<000000?ooo`3oool0o`3ooomH
0?ooo`030000003oool0oooo00h0oooo000U0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo000U0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo00h0oooo000U0?ooool00000FP0000000ol0000000000?ooo`0?0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00M@3oool4o`000080oooo0ol000030?ooo`Go00000P3oool3o`00
0080oooo0_l000000`3ooooo0000o`0000240?ooo`03o`00003ooooo000000<0oooo0ol000030?oo
o`?o00000`3oool4o`0006@0oooo001f0?ooo`04o`00003oool0ooooo`000080oooo00?o00000?oo
o`3oool0103oool01Ol00000oooo0?ooo`3ooooo000000<0oooo00Ko00000?ooo`3ooooo00000?oo
ool000250?ooo`03o`00003ooooo00000080oooo00Oo00000?ooo`3oool0ooooo`00003ooooo0000
00<0oooo00?o00000?ooool000000P3oool00ol00000oooo0?ooo`1S0?ooo`00MP3oool01?l00000
oooo0?ooool000020?ooo`03o`00003oool0oooo00@0oooo00Go00000?ooo`3oool0ooooo`000006
0?ooo`;o0000QP3oool00ol00000ooooo`0000020?ooo`07o`00003oool0oooo0?ooool00000oooo
o`0000030?ooo`03o`00003ooooo00000080oooo00?o00000?ooo`3oool0H`3oool007H0oooo0ol0
00030?ooo`;o00001@3oool01Ol00000oooo0?ooo`3ooooo000000<0oooo00Ko00000?ooo`3ooooo
00000?ooool000240?ooo`07o`00003ooooo00000?ooool00000ooooo`0000030?ooo`03o`00003o
oooo000000<0oooo00?o00000?ooool000000P3oool00ol00000oooo0?ooo`1S0?ooo`00MP3oool0
1Ol00000oooo0?ooool00000oooo00;o000000@0ooooo`000?l00000oooo0ol000040?ooo`?o0000
0`3oool01?l00000ooooo`000?l000230?ooo`05o`00003ooooo00000?ooool000000P3oool3o`00
00<0oooo0ol000030?ooo`?o0000I@3oool007H0oooo00Co00000?ooo`3ooooo0000503oool00ol0
0000oooo0?ooo`240?ooo`05o`00003ooooo00000?ooool00000403oool00ol00000oooo0?ooo`1S
0?ooo`00M@3oool4o`0000X0oooo00?o00000?ooo`3oool01`3oool2o`0008H0oooo1_l0000>0?oo
o`;o0000I@3oool00?l0ooooT@3oool00?l0ooooT@3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.359117, -0.0975496, \
0.00636706, 0.00455739}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{779, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 57, 0, 62, "Title"],
Cell[1814, 53, 204, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[2043, 62, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2104, 66, 58, 0, 49, "Subsection"],
Cell[2165, 68, 123, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2325, 75, 38, 0, 49, "Subsection"],
Cell[2366, 77, 295, 6, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2698, 88, 37, 0, 49, "Subsection"],
Cell[2738, 90, 275, 5, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3050, 100, 55, 0, 49, "Subsection"],
Cell[3108, 102, 660, 12, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3805, 119, 41, 0, 33, "Subsection"],
Cell[3849, 121, 170, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4056, 129, 41, 0, 33, "Subsection"],
Cell[4100, 131, 193, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4330, 139, 41, 0, 33, "Subsection"],
Cell[4374, 141, 750, 13, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5161, 159, 41, 0, 33, "Subsection"],
Cell[5205, 161, 962, 16, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6204, 182, 53, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[6282, 186, 36, 0, 43, "Subsubsection"],
Cell[6321, 188, 168, 4, 63, "Input"],
Cell[6492, 194, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6703, 202, 53, 0, 43, "Subsubsection"],
Cell[6759, 204, 207, 4, 63, "Input"],
Cell[6969, 210, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7114, 218, 35, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[7174, 222, 38, 0, 49, "Subsection"],
Cell[7215, 224, 139, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7391, 232, 35, 0, 49, "Subsection"],
Cell[7429, 234, 167, 3, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7645, 243, 54, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[7724, 247, 41, 0, 49, "Subsection"],
Cell[7768, 249, 210, 3, 95, "Input"],
Cell[7981, 254, 152, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8170, 261, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8233, 265, 108, 2, 47, "Input"],
Cell[8344, 269, 423092, 5523, 199, 68404, 1141, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[431485, 5798, 105, 3, 49, "Subsection"],
Cell[431593, 5803, 121, 2, 63, "Input"],
Cell[431717, 5807, 137, 3, 47, "Input"],
Cell[431857, 5812, 72, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[431966, 5818, 47, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[432038, 5822, 76, 1, 47, "Input"],
Cell[432117, 5825, 25301, 476, 256, 2962, 197, "GraphicsData", "PostScript", \
"Graphics"],
Cell[457421, 6303, 52, 1, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[457522, 6310, 54, 0, 49, "Subsection"],
Cell[457579, 6312, 248, 6, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457864, 6323, 49, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[457938, 6327, 150, 2, 63, "Input"],
Cell[458091, 6331, 766709, 10184, 408, 269060, 4037, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1224849, 16521, 50, 0, 49, "Subsection"],
Cell[1224902, 16523, 496, 12, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1225435, 16540, 47, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1225507, 16544, 238, 4, 63, "Input"],
Cell[1225748, 16550, 54052, 1131, 256, 9908, 583, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1279861, 17688, 54, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1279940, 17692, 41, 0, 49, "Subsection"],
Cell[1279984, 17694, 210, 3, 95, "Input"],
Cell[1280197, 17699, 108, 2, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1280342, 17706, 38, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1280405, 17710, 108, 2, 47, "Input"],
Cell[1280516, 17714, 423092, 5523, 199, 68404, 1141, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1703657, 23243, 69, 0, 49, "Subsection"],
Cell[1703729, 23245, 218, 3, 79, "Input"],
Cell[1703950, 23250, 533, 13, 111, "Input"],
Cell[1704486, 23265, 256, 4, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1704779, 23274, 66, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1704870, 23278, 139, 2, 47, "Input"],
Cell[1705012, 23282, 828679, 10798, 408, 136174, 2245, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2533740, 34086, 93, 3, 49, "Subsection"],
Cell[2533836, 34091, 77, 1, 47, "Input"],
Cell[2533916, 34094, 201, 4, 63, "Input"],
Cell[2534120, 34100, 285, 6, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2534442, 34111, 95, 3, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2534562, 34118, 175, 3, 63, "Input"],
Cell[2534740, 34123, 589559, 27281, 296, 436674, 25390, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3124348, 61410, 50, 0, 49, "Subsection"],
Cell[3124401, 61412, 148, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3124586, 61419, 47, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[3124658, 61423, 109, 2, 47, "Input"],
Cell[3124770, 61427, 452564, 11253, 333, 283787, 9166, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3577383, 72686, 46, 0, 49, "Subsection"],
Cell[3577432, 72688, 212, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3577681, 72697, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3577749, 72701, 106, 2, 47, "Input"],
Cell[3577858, 72705, 565339, 27772, 199, 451257, 26360, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4143246, 100483, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4143315, 100487, 71, 1, 47, "Input"],
Cell[4143389, 100490, 52, 1, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4143490, 100497, 54, 0, 49, "Subsection"],
Cell[4143547, 100499, 204, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4143788, 100508, 49, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4143862, 100512, 122, 2, 47, "Input"],
Cell[4143987, 100516, 651335, 8760, 408, 269054, 4037, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4795371, 109282, 50, 0, 49, "Subsection"],
Cell[4795424, 109284, 496, 12, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4795957, 109301, 47, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[4796029, 109305, 238, 4, 63, "Input"],
Cell[4796270, 109311, 47889, 954, 256, 8617, 466, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

